diff --git a/Makefile b/Makefile
index 9c60120..f6de6be 100644
--- a/Makefile
+++ b/Makefile
@@ -2,6 +2,7 @@ VERSION = 4
 PATCHLEVEL = 4
 SUBLEVEL = 115
 EXTRAVERSION =
+EXTRAVERSION = -buffalo
 NAME = Blurry Fish Butt
 
 # *DOCUMENTATION*
@@ -388,6 +389,11 @@ LINUXINCLUDE    := \
 		$(if $(KBUILD_SRC), -I$(srctree)/include) \
 		-Iinclude \
 		$(USERINCLUDE)
+BUFFALOINCLUDE := -I$(srctree)/buffalo/arch/$(hdr-arch)/include \
+		-Ibuffalo/arch/$(hdr-arch)/include/generated \
+		-Ibuffalo/include/generated \
+		-I$(srctree)/buffalo/include
+LINUXINCLUDE   += $(BUFFALOINCLUDE)
 
 KBUILD_CPPFLAGS := -D__KERNEL__
 
@@ -903,6 +909,7 @@ export mod_sign_cmd
 
 
 ifeq ($(KBUILD_EXTMOD),)
+core-y		+= buffalo/
 core-y		+= kernel/ certs/ mm/ fs/ ipc/ security/ crypto/ block/
 
 vmlinux-dirs	:= $(patsubst %/,%,$(filter %/, $(init-y) $(init-m) \
@@ -1197,6 +1204,7 @@ CLEAN_DIRS  += $(MODVERDIR)
 # Directories & files removed with 'make mrproper'
 MRPROPER_DIRS  += include/config usr/include include/generated          \
 		  arch/*/include/generated .tmp_objdiff
+MRPRPPER_DIRS  += buffalo/include/generated buffalo/arch/*/include/generated
 MRPROPER_FILES += .config .config.old .version .old_version \
 		  Module.symvers tags TAGS cscope* GPATH GTAGS GRTAGS GSYMS \
 		  signing_key.pem signing_key.priv signing_key.x509	\
@@ -1261,8 +1269,10 @@ rpm: include/config/kernel.release FORCE
 # ---------------------------------------------------------------------------
 
 boards := $(wildcard $(srctree)/arch/$(SRCARCH)/configs/*_defconfig)
+boards += $(wildcard $(srctree)/buffalo/arch/$(SRCARCH)/configs/*_defconfig)
 boards := $(sort $(notdir $(boards)))
 board-dirs := $(dir $(wildcard $(srctree)/arch/$(SRCARCH)/configs/*/*_defconfig))
+board-dirs += $(dir $(wildcard $(srctree)/buffalo/arch/$(SRCARCH)/configs/*/*_defconfig))
 board-dirs := $(sort $(notdir $(board-dirs:/=)))
 
 help:
diff --git a/README-TSx010.txt b/README-TSx010.txt
new file mode 100644
index 00000000..af70ef1
--- /dev/null
+++ b/README-TSx010.txt
@@ -0,0 +1,70 @@
+BUFFALO TeraStation [537]010 Series kernel README
+=================================================
+
+Repository Infomation
+---------------------
+
+Branch:	linux-4.1.y
+Commit:	35327468a79dd9e343eaf7e66cc372f8277b2a84
+Tag:	v4.1.37
+Description:
+	Base revision of Annapurna SDK 6.1
+
+Branch:	develop-4.1.37+alpine-sdk-6.1-sa
+Commit:	72ff845711087fe579e8ae35ad080fada465e2d4
+Tag:	al_storage_adv-al-V_6.1.3-5851039
+Description:
+	Base revision of TS[537]010 series kernel development.
+	This is 'linux-4.1.37' source + patches followed:
+	+ linux-4.1.37-6.1.3-5851039.patch
+
+Branch: develop-4.1.37+alpine-sdk-6.1-sa+buffalo-ts5010
+Commit: HEAD
+Tag:	(not-yet)
+Description:
+	Development line of TS[537]010 series kernel.
+
+How to build the standalone kernel
+-----------------------------------
+This section describes how to build standalone (not packaged) kernel, DTBs,
+modules.  See [How to build kernel debian package] section instead, if you
+want kernel packages.
+
+Abstract of kernel building step is followed:
+
+* make *_defconfig
+* make uImage dtbs modules
+* make modules_install
+
+typical build script is followed:
+
+<pre>
+#!/bin/sh
+ARCH="arm"
+#MACHINE=alpine
+MACHINE=ts5010
+CROSS_COMPILE=arm-linux-gnueabihf-
+BUILDDIR="${HOME}/obj/${ARCH}/${MACHINE}"
+MODULEDIR="${BUILDDIR}/modules"
+MAKEOPTS="V=1 ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} O=${BUILDDIR}"
+export ARCH CROSS_COMPILE
+
+mkdir -p ${BUILDDIR} ${MODULEDIR}
+
+case "${MACHINE}" in
+alpine) DEFCONFIG=alpine_defconfig;;
+*)      DEFCONFIG=buffalo_ts5010_defconfig;;
+esac
+
+make ${MAKEOPTS} ${DEFCONFIG} || exit 1
+make ${MAKEOPTS} uImage dtbs modules || exit 1
+make ${MAKEOPTS} INSTALL_MOD_PATH=${MODULEDIR} modules_install || exit 1
+</pre>
+
+
+How to build kernel debian package
+----------------------------------
+Debian style kernel packages for ubuntu-14.04 can be built by script
+named "debiansize.sh".  At the top of kernel source tree, ivoke:
+
+	sh buffalo/scripts/debianize.sh
diff --git a/arch/arm/Kconfig b/arch/arm/Kconfig
index 34e1569..cd4b32e 100644
--- a/arch/arm/Kconfig
+++ b/arch/arm/Kconfig
@@ -2169,3 +2169,5 @@ endif
 source "lib/Kconfig"
 
 source "arch/arm/kvm/Kconfig"
+
+source "buffalo/Kconfig"
diff --git a/arch/arm/boot/compressed/misc.c b/arch/arm/boot/compressed/misc.c
index d4f891f..6dfbc8a 100644
--- a/arch/arm/boot/compressed/misc.c
+++ b/arch/arm/boot/compressed/misc.c
@@ -21,6 +21,11 @@ unsigned int __machine_arch_type;
 #include <linux/compiler.h>	/* for inline */
 #include <linux/types.h>
 #include <linux/linkage.h>
+#ifdef CONFIG_BUFFALO_PLATFORM
+#include "builddate.h"
+const char buffalo_builddate[] =
+	"BUILDDATE=" BUFFALO_BUILD_DATE " " BUFFALO_BUILD_TIME "\n";
+#endif /*CONFIG_BUFFALO_PLATFORM*/
 
 static void putstr(const char *ptr);
 extern void error(char *x);
diff --git a/arch/arm/boot/install.sh b/arch/arm/boot/install.sh
index 2a45092..83bea24a 100644
--- a/arch/arm/boot/install.sh
+++ b/arch/arm/boot/install.sh
@@ -35,6 +35,10 @@ verify "$2"
 verify "$3"
 
 # User may have a custom install script
+if [ -x ${srctree}/buffalo/arch/arm/boot/${INSTALLKERNEL} ]; then
+	# Don't execute /sbin/installkernel on host ubuntu system
+	exec ${srctree}/buffalo/arch/arm/boot/${INSTALLKERNEL} "$@";
+fi
 if [ -x ~/bin/${INSTALLKERNEL} ]; then exec ~/bin/${INSTALLKERNEL} "$@"; fi
 if [ -x /sbin/${INSTALLKERNEL} ]; then exec /sbin/${INSTALLKERNEL} "$@"; fi
 
diff --git a/arch/arm/kernel/reboot.c b/arch/arm/kernel/reboot.c
index 3826935..79b32f0 100644
--- a/arch/arm/kernel/reboot.c
+++ b/arch/arm/kernel/reboot.c
@@ -12,6 +12,9 @@
 
 #include <asm/cacheflush.h>
 #include <asm/idmap.h>
+#ifdef CONFIG_BUFFALO_MICON_V3
+#include <buffalo/micon_v3.h>
+#endif	/* CONFIG_BUFFALO_MICON_V3 */
 
 #include "reboot.h"
 
@@ -93,6 +96,11 @@ void soft_restart(unsigned long addr)
 void machine_shutdown(void)
 {
 	disable_nonboot_cpus();
+#if 0	/* XXX: this function is for kexec, maybe it is no need to micon op */
+#ifdef CONFIG_BUFFALO_MICON_V3
+	miconCntl_PowerOff();
+#endif	/* CONFIG_BUFFALO_MICON_V3 */
+#endif
 }
 
 /*
@@ -106,9 +114,26 @@ void machine_halt(void)
 	smp_send_stop();
 
 	local_irq_disable();
+#ifdef CONFIG_BUFFALO_MICON_V3
+	miconCntl_PowerOff();
+#else	/* CONFIG_BUFFALO_MICON_V3 */
+#ifdef CONFIG_BUFFALO_MICON_REBOOT
+	printk(KERN_EMERG "Waiting for MICON halt.\n");
+#endif	/* CONFIG_BUFFALO_MICON_REBOOT */
 	while (1);
+#endif	/* CONFIG_BUFFALO_MICON_V3 */
 }
 
+#ifdef CONFIG_BUFFALO_MICON_REBOOT
+static inline void longdelay(int sec)
+{
+	int i;
+	for (i = 0; i < sec; i++) {
+	    mdelay(1000);
+	    touch_softlockup_watchdog();
+	}
+}
+#endif	/* CONFIG_BUFFALO_MICON_REBOOT */
 /*
  * Power-off simply requires that the secondary CPUs stop performing any
  * activity (executing tasks, handling interrupts). smp_send_stop()
@@ -120,8 +145,16 @@ void machine_power_off(void)
 	local_irq_disable();
 	smp_send_stop();
 
+#ifdef CONFIG_BUFFALO_MICON_V3
+	miconCntl_PowerOff();
+#else	/* CONFIG_BUFFALO_MICON_V3 */
+#ifdef CONFIG_BUFFALO_MICON_REBOOT
+	printk(KERN_EMERG "Waiting for MICON power-off.\n");
+	longdelay(10);	/* wait 10 secends */
+#endif	/* CONFIG_BUFFALO_MICON_REBOOT */
 	if (pm_power_off)
 		pm_power_off();
+#endif	/* CONFIG_BUFFALO_MICON_V3 */
 }
 
 /*
@@ -140,10 +173,18 @@ void machine_restart(char *cmd)
 	local_irq_disable();
 	smp_send_stop();
 
+#ifdef CONFIG_BUFFALO_MICON_V3
+	miconCntl_Reboot();
+#else	/* CONFIG_BUFFALO_MICON_V3 */
+#ifdef CONFIG_BUFFALO_MICON_REBOOT
+	printk(KERN_EMERG "Waiting for MICON restart.\n");
+	longdelay(10);	/* wait 10 seconds */
+#endif	/* CONFIG_BUFFALO_MICON_REBOOT */
 	if (arm_pm_restart)
 		arm_pm_restart(reboot_mode, cmd);
 	else
 		do_kernel_restart(cmd);
+#endif	/* CONFIG_BUFFALO_MICON_V3 */
 
 	/* Give a grace period for failure to restart of 1s */
 	mdelay(1000);
diff --git a/arch/x86/Kconfig b/arch/x86/Kconfig
index 2db9304..452901a 100644
--- a/arch/x86/Kconfig
+++ b/arch/x86/Kconfig
@@ -2694,3 +2694,5 @@ source "crypto/Kconfig"
 source "arch/x86/kvm/Kconfig"
 
 source "lib/Kconfig"
+
+source "buffalo/Kconfig"
diff --git a/arch/x86/boot/install.sh b/arch/x86/boot/install.sh
index d13ec1c..a3e0981 100644
--- a/arch/x86/boot/install.sh
+++ b/arch/x86/boot/install.sh
@@ -33,6 +33,10 @@ verify "$3"
 
 # User may have a custom install script
 
+if [ -x ${srctree}/buffalo/arch/x86/boot/${INSTALLKERNEL} ]; then
+	# Don't execute /sbin/installkernel on host ubuntu system
+	exec ${srctree}/buffalo/arch/x86/boot/${INSTALLKERNEL} "$@";
+fi
 if [ -x ~/bin/${INSTALLKERNEL} ]; then exec ~/bin/${INSTALLKERNEL} "$@"; fi
 if [ -x /sbin/${INSTALLKERNEL} ]; then exec /sbin/${INSTALLKERNEL} "$@"; fi
 
diff --git a/block/blk-core.c b/block/blk-core.c
index f5f1a55..1346587 100644
--- a/block/blk-core.c
+++ b/block/blk-core.c
@@ -39,6 +39,9 @@
 
 #include "blk.h"
 #include "blk-mq.h"
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+#include <buffalo/kernevnt.h>
+#endif	/* CONFIG_BUFFALO_USE_KERNEVNT */
 
 EXPORT_TRACEPOINT_SYMBOL_GPL(block_bio_remap);
 EXPORT_TRACEPOINT_SYMBOL_GPL(block_rq_remap);
@@ -1935,6 +1938,28 @@ generic_make_request_checks(struct bio *bio)
 		goto end_io;
 	}
 
+#ifdef CONFIG_BUFFALO_IOERRS
+	if (bio->bi_bdev->bd_disk->limit_io_errors > 0 &&
+	    (bio->bi_bdev->bd_disk->io_errors > bio->bi_bdev->bd_disk->limit_io_errors)) {
+		//printk("%s:io error limit\n",bdevname(bio->bi_bdev, b));
+#ifdef CONFIG_BUFFALO_ALPINE_PLATFORM
+		/* NOTE: (Temporary Fix)
+		 *	Skip setting the QUEUE_FLAG_DEAD flag here, because
+		 *	this setting causes process hang-up when opening
+		 *	'/dev/sd*' device file at Alpine platform by unknown
+		 *	reason.  Instead, stop issueing 'ioerror' event
+		 *	when ioerror counter reaches its limit.
+		 *	See NOTE in blk_update_request() function below.
+		 */
+#else /* CONFIG_BUFFALO_ALPINE_PLATFORM */
+		set_bit(QUEUE_FLAG_DEAD, &q->queue_flags);
+#endif /* CONFIG_BUFFALO_ALPINE_PLATFORM */
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+		kernevnt_DriveDead(bdevname(bio->bi_bdev, b));
+#endif	/* CONFIG_BUFFALO_USE_KERNEVNT */
+		goto end_io;
+	}
+#endif	/* CONFIG_BUFFALO_IOERRS */
 	part = bio->bi_bdev->bd_part;
 	if (should_fail_request(part, bio->bi_iter.bi_size) ||
 	    should_fail_request(&part_to_disk(part)->part0,
@@ -2642,6 +2667,31 @@ bool blk_update_request(struct request *req, int error, unsigned int nr_bytes)
 
 	}
 
+#ifdef CONFIG_BUFFALO_IOERRS
+	if (error && req->cmd_type != REQ_TYPE_BLOCK_PC && req->rq_disk) {
+#ifdef CONFIG_BUFFALO_ERRCNT
+		if (atomic_inc_return(&req->rq_disk->nr_errs) < 0)
+			atomic_set(&req->rq_disk->nr_errs, INT_MAX);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+#ifdef CONFIG_BUFFALO_ALPINE_PLATFORM
+		if (req->rq_disk->io_errors > req->rq_disk->limit_io_errors) {
+			/* NOTE: (Temporary Fix)
+			 *	Stop issueing 'ioerror' event when io_erroes
+			 *	counter reaches its limit, to avoid process
+			 *	hang-up at open() system-call for disk-device
+			 *	on Alpine Platform.
+			 */
+			;
+		} else
+#endif /* CONFIG_BUFFALO_ALPINE_PLATFORM */
+		kernevnt_IOErr(req->rq_disk->disk_name,
+			       (rq_data_dir(req) == WRITE) ? "WRITE" : "READ",
+			       (unsigned long long)blk_rq_pos(req),
+			       ++req->rq_disk->io_errors);
+#endif	/* CONFIG_BUFFALO_USE_KERNEVNT */
+	}
+#endif	/* CONFIG_BUFFALO_IOERRS */
 	blk_account_io_completion(req, nr_bytes);
 
 	total_bytes = 0;
diff --git a/block/genhd.c b/block/genhd.c
index 3032453..ff42084 100644
--- a/block/genhd.c
+++ b/block/genhd.c
@@ -979,6 +979,74 @@ static ssize_t disk_discard_alignment_show(struct device *dev,
 	return sprintf(buf, "%d\n", queue_discard_alignment(disk->queue));
 }
 
+#ifdef CONFIG_BUFFALO_IOERRS
+static ssize_t disk_io_error_show(struct device *dev,
+				  struct device_attribute *attr, char *buf)
+{
+	struct gendisk *disk = dev_to_disk(dev);
+
+	return sprintf(buf, "%u\n", disk->io_errors);
+}
+
+static ssize_t disk_limit_io_error_show(struct device *dev,
+					struct device_attribute *attr,
+					char *buf)
+{
+	struct gendisk *disk = dev_to_disk(dev);
+
+	return sprintf(buf, "%u\n", disk->limit_io_errors);
+}
+
+#define STORE_FUNCTION(__FUNC, __PTR, MIN, MAX, __CONV)			\
+ssize_t __FUNC(struct device *dev, struct device_attribute *attr,	\
+	       const char *buf, size_t count)				\
+{									\
+	struct gendisk *disk = dev_to_disk(dev);			\
+	unsigned int __data;						\
+	char *p = (char *) buf;						\
+									\
+	__data = simple_strtoul(p, &p, 10);				\
+	if (__data < (MIN))						\
+		__data = (MIN);						\
+	else if (__data > (MAX))					\
+		__data = (MAX);						\
+	if (__CONV)							\
+		*(__PTR) = msecs_to_jiffies(__data);			\
+	else								\
+		*(__PTR) = __data;					\
+	return count;							\
+}
+
+static STORE_FUNCTION(disk_io_error_store, &disk->io_errors, 0, UINT_MAX, 0)
+static STORE_FUNCTION(disk_limit_io_error_store, &disk->limit_io_errors, 0, UINT_MAX, 0)
+
+#ifdef CONFIG_BUFFALO_ERRCNT
+static ssize_t disk_nr_errs_show(struct device *dev,
+				 struct device_attribute *attr, char *buf)
+{
+	struct gendisk *disk = dev_to_disk(dev);
+
+	return sprintf(buf, "%d\n", atomic_read(&disk->nr_errs));
+}
+
+static ssize_t disk_nr_errs_store(struct device *dev,
+				  struct device_attribute *attr,
+				  const char *buf, size_t count)
+{
+	struct gendisk *disk = dev_to_disk(dev);
+	long n;
+	char *e, *p = (char *) buf;
+
+	n = simple_strtoul(p, &e, 10);
+	if (*p && (*e == 0 || *e == '\n') && n >= 0 ) {
+		atomic_set(&disk->nr_errs, n);
+		return count;
+	}
+	return -EINVAL;
+}
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#endif	/* CONFIG_BUFFALO_IOERRS */
+
 static DEVICE_ATTR(range, S_IRUGO, disk_range_show, NULL);
 static DEVICE_ATTR(ext_range, S_IRUGO, disk_ext_range_show, NULL);
 static DEVICE_ATTR(removable, S_IRUGO, disk_removable_show, NULL);
@@ -999,6 +1067,13 @@ static struct device_attribute dev_attr_fail_timeout =
 	__ATTR(io-timeout-fail,  S_IRUGO|S_IWUSR, part_timeout_show,
 		part_timeout_store);
 #endif
+#ifdef CONFIG_BUFFALO_IOERRS
+static DEVICE_ATTR(io_errors, S_IRUGO|S_IWUSR, disk_io_error_show, disk_io_error_store);
+static DEVICE_ATTR(limit_io_errors, S_IRUGO|S_IWUSR, disk_limit_io_error_show, disk_limit_io_error_store);
+#ifdef CONFIG_BUFFALO_ERRCNT
+static DEVICE_ATTR(nr_errs, S_IRUGO|S_IWUSR, disk_nr_errs_show, disk_nr_errs_store);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#endif	/* CONFIG_BUFFALO_IOERRS */
 
 static struct attribute *disk_attrs[] = {
 	&dev_attr_range.attr,
@@ -1017,6 +1092,13 @@ static struct attribute *disk_attrs[] = {
 #ifdef CONFIG_FAIL_IO_TIMEOUT
 	&dev_attr_fail_timeout.attr,
 #endif
+#ifdef CONFIG_BUFFALO_IOERRS
+	&dev_attr_io_errors.attr,
+	&dev_attr_limit_io_errors.attr,
+#ifdef CONFIG_BUFFALO_ERRCNT
+	&dev_attr_nr_errs.attr,
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#endif	/* CONFIG_BUFFALO_IOERRS */
 	NULL
 };
 
@@ -1293,6 +1375,9 @@ struct gendisk *alloc_disk_node(int minors, int node_id)
 		}
 
 		disk->minors = minors;
+#ifdef CONFIG_BUFFALO_ERRCNT
+		atomic_set(&disk->nr_errs, 0);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 		rand_initialize_disk(disk);
 		disk_to_dev(disk)->class = &block_class;
 		disk_to_dev(disk)->type = &disk_type;
diff --git a/buffalo/Kconfig b/buffalo/Kconfig
new file mode 100644
index 00000000..7723aa4
--- /dev/null
+++ b/buffalo/Kconfig
@@ -0,0 +1,140 @@
+menu "BUFFALO Features"
+
+config BUFFALO_PLATFORM
+	bool "BUFFALO_PLATFORM"
+	---help---
+	  Hardware/Software is for BUFFALO platfrom
+
+config BUFFALO_USE_KERNEVNT
+	bool "BUFFALO_USE_KERNEVNT"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  Use kernelevent
+
+config BUFFALO_USE_MD_KERNEVNT
+	bool "BUFFALO_USE_MD_KERNEVNT"
+	depends on BUFFALO_PLATFORM
+	depends on BUFFALO_USE_KERNEVNT
+	---help---
+	  Use kernelevent of md driver.
+
+config BUFFALO_USE_MD_DEGRADE_KERNEVNT
+	bool "BUFFALO_USE_MD_DEGRADE_KERNEVNT"
+	depends on BUFFALO_PLATFORM
+	depends on BUFFALO_USE_MD_KERNEVNT
+	---help---
+	  Use kernelevent of md driver.
+
+config BUFFALO_USE_MD_SCAN_KERNEVNT
+	bool "BUFFALO_USE_MD_SCAN_KERNEVNT"
+	depends on BUFFALO_PLATFORM
+	depends on BUFFALO_USE_MD_KERNEVNT
+	---help---
+	  Use kernelevent of md driver.
+
+config BUFFALO_USE_MD_REBUILD_KERNEVNT
+	bool "BUFFALO_USE_MD_REBUILD_KERNEVNT"
+	depends on BUFFALO_PLATFORM
+	depends on BUFFALO_USE_MD_KERNEVNT
+	---help---
+	  Use kernelevent of md driver.
+
+config BUFFALO_ERRCNT
+	bool "BUFFALO_ERRCNT"
+	depends on BUFFALO_PLATFORM
+	depends on BUFFALO_IOERRS
+	---help---
+	disk I/O error counter and auto MD degrading.	 
+
+config BUFFALO_USE_UPS
+	bool "BUFFALO_USE_UPS"
+	depends on BUFFALO_PLATFORM
+	---help---
+	Enable kernel support of ups shutdown.
+
+config BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN
+       bool "BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN"
+       depends on BUFFALO_USE_UPS
+       default n
+       ---help---
+	 Support OMRON UPS
+
+config BUFFALO_SUPPORT_UPS_RECOVER
+       bool "BUFFALO_SUPPORT_UPS_RECOVER"
+       depends on BUFFALO_USE_UPS
+       default n
+       ---help---
+	 Support /proc/buffalo/ups/ups_recover
+
+config BUFFALO_DUPLICATE_SUPERBLOCK_DEBUG
+	bool "BUFFALO_DUPLICATE_SUPERBLOCK_DEBUG"
+	depends on BUFFALO_DUPLICATE_SUPERBLOCK
+	---help---
+	  enable duplicate superblock debug mode.
+
+config BUFFALO_UBOOT_PARAMS
+	bool "BUFFALO_UBOOT_PARAMS"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  add u-boot parameters
+
+config BUFFALO_IOERRS
+	bool "BUFFALO_IOERRS"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  disk I/O error counter
+
+config BUFFALO_SKIP_RESYNC
+	bool "BUFFALO_SKIP_RESYNC"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  skip resync of md device
+
+config BUFFALO_IGNORE_LUN
+	bool "BUFFALO_IGNORE_LUN"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  ignore lun of SCSI device
+
+config BUFFALO_SCSI_GUID
+	bool "BUFFALO_SCSI_GUID"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  add guid of SCSI device
+
+config BUFFALO_EXT23_EXTENSION
+	bool "BUFFALO_EXT23_EXTENSION"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  extend ext2/ext3 magic number
+
+choice BUFFALO_SATA_HOTPLUG_EVENT_CHOICE
+	prompt "support SATA HOTPLUG EVENT"
+	depends on BUFFALO_SATA_HOTPLUG_EVENT
+	default BUFFALO_SATA_HOTPLUG_EVENT_INTERRUPT
+
+config BUFFALO_SATA_HOTPLUG_EVENT_INTERRUPT
+	bool "SATA HOTPLUG EVENT INTERRUPT"
+
+config BUFFALO_SATA_HOTPLUG_EVENT_POLLING
+	bool "SATA HOTPLUG EVENT POLLING"
+
+endchoice
+
+config BUFFALO_SUPPORT_WOL
+	bool "BUFFALO_SUPPORT_WOL"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  Support WOL function.
+	  Below is supported phy lists.
+	    1318
+
+config BUFFALO_DISCONIRQ
+	bool "BUFFALO_DISCONIRQ"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  disable interrupt for ttyS0/COM1/IRQ11
+
+source "buffalo/arch/$SRCARCH/Kconfig"
+
+endmenu
diff --git a/buffalo/Makefile b/buffalo/Makefile
new file mode 100644
index 00000000..6376ae6
--- /dev/null
+++ b/buffalo/Makefile
@@ -0,0 +1,3 @@
+obj-y					+= drivers/
+
+include $(srctree)/buffalo/arch/$(SRCARCH)/Makefile
diff --git a/buffalo/arch/arm/Kconfig b/buffalo/arch/arm/Kconfig
new file mode 100644
index 00000000..32e5af0
--- /dev/null
+++ b/buffalo/arch/arm/Kconfig
@@ -0,0 +1,44 @@
+config BUFFALO_SUPPORT_BOARD_INFO
+	 bool "support board info from kernel"
+	 depends on BUFFALO_PLATFORM
+	 depends on ARM
+	 default y
+	 ---help---
+	  BUFFALO board information
+
+config BUFFALO_ALPINE_PLATFORM
+	bool "ALPINE_PLATFORM"
+	depends on BUFFALO_PLATFORM
+	depends on ARCH_ALPINE
+	---help---
+	  for TS5x10 (featured Annapurna alpine SoC)
+
+config BUFFALO_USE_MICON
+	bool "USE MICON control"
+	depends on ARM
+	default y
+	---help---
+	  BUFFALO Micon
+
+config BUFFALO_MICON_V3
+	bool "featuring Micon version 3"
+	depends on BUFFALO_USE_MICON
+	depends on BUFFALO_ALPINE_PLATFORM
+	default y
+	---help---
+	  BUFFALO Micon version 3
+
+config BUFFALO_MICON_V3_DEVTTY
+	string "tty device name used by Micon v3"
+	depends on BUFFALO_MICON_V3
+	default "/dev/ttyS1"
+	---help---
+	  Micon connected tty device name
+
+config BUFFALO_MICON_REBOOT
+	bool "USE MICON level reboot"
+	depends on BUFFALO_PLATFORM
+	depends on ARCH_ALPINE
+	default n
+	---help---
+	    Uer Micon level reboot instead of kernel level reboot.
diff --git a/buffalo/arch/arm/Makefile b/buffalo/arch/arm/Makefile
new file mode 100644
index 00000000..db48cf8
--- /dev/null
+++ b/buffalo/arch/arm/Makefile
@@ -0,0 +1,4 @@
+# Note:	This file is included from $(srctree)/buffalo/Makefile,
+#	you have to specify relatively from $(srctree)/buffalo
+
+obj-$(CONFIG_BUFFALO_ALPINE_PLATFORM)	+= arch/arm/plat-alpine/
diff --git a/buffalo/arch/arm/boot/installkernel b/buffalo/arch/arm/boot/installkernel
new file mode 100644
index 00000000..b38fa11
--- /dev/null
+++ b/buffalo/arch/arm/boot/installkernel
@@ -0,0 +1,12 @@
+#!/bin/sh
+#
+# "make install" script for arm architecture
+#
+# Arguments:
+#   $1 - kernel version
+#   $2 - kernel image file
+#   $3 - kernel map file
+#   $4 - default install path (blank if root directory)
+#
+
+cp $2 $4
diff --git a/buffalo/arch/arm/configs/buffalo_ts5010_defconfig b/buffalo/arch/arm/configs/buffalo_ts5010_defconfig
new file mode 100644
index 00000000..dd015ee
--- /dev/null
+++ b/buffalo/arch/arm/configs/buffalo_ts5010_defconfig
@@ -0,0 +1,291 @@
+# CONFIG_LOCALVERSION_AUTO is not set
+CONFIG_SYSVIPC=y
+CONFIG_POSIX_MQUEUE=y
+CONFIG_FHANDLE=y
+CONFIG_NO_HZ=y
+CONFIG_HIGH_RES_TIMERS=y
+CONFIG_IKCONFIG=y
+CONFIG_IKCONFIG_PROC=y
+CONFIG_CGROUPS=y
+CONFIG_BLK_DEV_INITRD=y
+CONFIG_EXPERT=y
+CONFIG_SYSCTL_SYSCALL=y
+CONFIG_SLAB=y
+CONFIG_PROFILING=y
+CONFIG_MODULES=y
+CONFIG_MODULE_UNLOAD=y
+CONFIG_BLK_DEV_INTEGRITY=y
+CONFIG_PARTITION_ADVANCED=y
+CONFIG_LDM_PARTITION=y
+CONFIG_ARCH_ALPINE=y
+CONFIG_ARM_LPAE=y
+CONFIG_PCI_IOV=y
+CONFIG_PCI_INTERNAL_ALPINE=y
+CONFIG_PCI_EXTERNAL_ALPINE=y
+CONFIG_SMP=y
+CONFIG_AEABI=y
+CONFIG_HIGHMEM=y
+# CONFIG_TRANSPARENT_HUGEPAGE is not set
+# CONFIG_TRANSPARENT_HUGEPAGE_MADVISE is not set
+CONFIG_VFP=y
+CONFIG_NEON=y
+# CONFIG_SUSPEND is not set
+CONFIG_NET=y
+CONFIG_PACKET=y
+CONFIG_UNIX=y
+# CONFIG_XFRM_USER is not set
+# CONFIG_NET_KEY is not set
+CONFIG_INET=y
+CONFIG_IP_MULTICAST=y
+CONFIG_IP_PNP=y
+CONFIG_IP_PNP_BOOTP=y
+# CONFIG_INET_AH is not set
+# CONFIG_INET_ESP is not set
+# CONFIG_INET_DIAG is not set
+# CONFIG_IPV6 is not set
+CONFIG_NETFILTER=y
+CONFIG_NF_CONNTRACK=m
+CONFIG_NF_CONNTRACK_EVENTS=y
+CONFIG_NF_CONNTRACK_FTP=m
+CONFIG_NF_CONNTRACK_SIP=m
+CONFIG_NF_CT_NETLINK=m
+CONFIG_NF_CT_NETLINK_TIMEOUT=m
+CONFIG_NF_CONNTRACK_IPV4=m
+CONFIG_NF_CONNTRACK_PROC_COMPAT=m
+CONFIG_NF_NAT_IPV4=m
+CONFIG_NF_NAT_AMANDA=m
+CONFIG_NF_NAT_TFTP=m
+CONFIG_NF_NAT_MASQUERADE_IPV4=m
+CONFIG_IP_NF_IPTABLES=m
+CONFIG_IP_NF_FILTER=m
+# CONFIG_BRIDGE_NF_EBTABLES is not set
+# CONFIG_BRIDGE_EBT_BROUTE is not set
+# CONFIG_BRIDGE_EBT_T_FILTER is not set
+# CONFIG_BRIDGE_EBT_T_NAT is not set
+# CONFIG_BRIDGE_EBT_802_3 is not set
+# CONFIG_BRIDGE_EBT_AMONG is not set
+# CONFIG_BRIDGE_EBT_ARP is not set
+# CONFIG_BRIDGE_EBT_IP is not set
+# CONFIG_BRIDGE_EBT_LIMIT is not set
+# CONFIG_BRIDGE_EBT_MARK is not set
+# CONFIG_BRIDGE_EBT_PKTTYPE is not set
+# CONFIG_BRIDGE_EBT_STP is not set
+# CONFIG_BRIDGE_EBT_VLAN is not set
+# CONFIG_BRIDGE_EBT_ARPREPLY is not set
+# CONFIG_BRIDGE_EBT_DNAT is not set
+# CONFIG_BRIDGE_EBT_MARK_T is not set
+# CONFIG_BRIDGE_EBT_REDIRECT is not set
+# CONFIG_BRIDGE_EBT_SNAT is not set
+# CONFIG_BRIDGE_EBT_LOG is not set
+# CONFIG_BRIDGE_EBT_NFLOG is not set
+# CONFIG_BRIDGE is not set
+CONFIG_VLAN_8021Q=m
+CONFIG_DEVTMPFS=y
+CONFIG_DEVTMPFS_MOUNT=y
+CONFIG_MTD=y
+CONFIG_MTD_CMDLINE_PARTS=y
+CONFIG_MTD_BLOCK=y
+CONFIG_MTD_CFI=y
+CONFIG_MTD_CFI_ADV_OPTIONS=y
+CONFIG_MTD_CFI_INTELEXT=y
+CONFIG_MTD_COMPLEX_MAPPINGS=y
+CONFIG_MTD_PHYSMAP_OF=y
+CONFIG_MTD_M25P80=y
+CONFIG_MTD_BLOCK2MTD=y
+CONFIG_MTD_NAND=y
+CONFIG_MTD_NAND_AL=y
+CONFIG_MTD_SPI_NOR=y
+CONFIG_MTD_UBI=y
+CONFIG_BLK_DEV_LOOP=y
+CONFIG_BLK_DEV_NVME=y
+CONFIG_BLK_DEV_RAM=y
+CONFIG_BLK_DEV_RAM_COUNT=8
+CONFIG_BLK_DEV_RAM_SIZE=131072
+CONFIG_RAID_ATTRS=y
+CONFIG_BLK_DEV_SD=y
+CONFIG_SCSI_SAS_ATTRS=y
+CONFIG_SCSI_MPT2SAS=m
+CONFIG_ATA=y
+# CONFIG_SATA_PMP is not set
+CONFIG_SATA_AHCI=y
+CONFIG_SATA_AHCI_PLATFORM=y
+CONFIG_AHCI_ALPINE=y
+CONFIG_SATA_SIL24=m
+CONFIG_SATA_MV=y
+CONFIG_MD=y
+CONFIG_MD_RAID0=y
+CONFIG_BLK_DEV_DM=y
+CONFIG_DM_CRYPT=y
+CONFIG_DM_RAID=y
+CONFIG_DM_MULTIPATH=y
+CONFIG_DM_UEVENT=y
+CONFIG_TARGET_CORE=m
+CONFIG_ISCSI_TARGET=m
+CONFIG_NETDEVICES=y
+CONFIG_BONDING=m
+CONFIG_NET_TEAM=m
+CONFIG_NET_TEAM_MODE_BROADCAST=m
+CONFIG_NET_TEAM_MODE_ROUNDROBIN=m
+CONFIG_NET_TEAM_MODE_RANDOM=m
+CONFIG_NET_TEAM_MODE_ACTIVEBACKUP=m
+CONFIG_NET_TEAM_MODE_LOADBALANCE=m
+# CONFIG_TUN is not set
+# CONFIG_VHOST_NET is not set
+CONFIG_NET_AL_ETH=y
+# CONFIG_E100 is not set
+# CONFIG_E1000 is not set
+# CONFIG_E1000E is not set
+# CONFIG_IGB is not set
+# CONFIG_IGBVF is not set
+# CONFIG_IXGBE is not set
+# CONFIG_IXGBEVF is not set
+CONFIG_AT803X_PHY=y
+CONFIG_INPUT_EVDEV=y
+# CONFIG_SERIO_SERPORT is not set
+CONFIG_SERIO_AMBAKMI=y
+CONFIG_LEGACY_PTY_COUNT=16
+CONFIG_SERIAL_8250=y
+CONFIG_SERIAL_8250_CONSOLE=y
+CONFIG_SERIAL_8250_RUNTIME_UARTS=4
+CONFIG_SERIAL_8250_EXTENDED=y
+CONFIG_SERIAL_8250_MANY_PORTS=y
+CONFIG_SERIAL_8250_SHARE_IRQ=y
+CONFIG_SERIAL_8250_RSA=y
+CONFIG_SERIAL_8250_DW=y
+CONFIG_SERIAL_AMBA_PL011=y
+CONFIG_SERIAL_AMBA_PL011_CONSOLE=y
+CONFIG_SERIAL_OF_PLATFORM=y
+CONFIG_HW_RANDOM=y
+CONFIG_I2C=y
+CONFIG_I2C_CHARDEV=y
+CONFIG_I2C_MUX=y
+CONFIG_I2C_MUX_PCA954x=y
+# CONFIG_I2C_HELPER_AUTO is not set
+CONFIG_I2C_DESIGNWARE_PLATFORM=y
+CONFIG_SPI=y
+CONFIG_SPI_DESIGNWARE=y
+CONFIG_SPI_DW_MMIO=y
+CONFIG_GPIOLIB=y
+CONFIG_GPIO_PL061=y
+CONFIG_POWER_SUPPLY=y
+CONFIG_POWER_RESET=y
+CONFIG_GPIO_SYSFS=y
+# CONFIG_HWMON is not set
+CONFIG_THERMAL=y
+CONFIG_AL_THERMAL=y
+CONFIG_WATCHDOG=y
+CONFIG_ARM_SP805_WATCHDOG=y
+CONFIG_USB=y
+CONFIG_USB_XHCI_HCD=y
+CONFIG_USB_EHCI_HCD=y
+CONFIG_USB_EHCI_HCD_PLATFORM=y
+CONFIG_USB_OHCI_HCD=y
+CONFIG_USB_STORAGE=y
+CONFIG_EDAC=y
+CONFIG_EDAC_MM_EDAC=y
+CONFIG_EDAC_AL_MC=y
+CONFIG_RTC_CLASS=y
+CONFIG_RTC_DRV_RX8010=y
+CONFIG_DMADEVICES=y
+CONFIG_ASYNC_TX_DMA=y
+CONFIG_AL_DMA=y
+CONFIG_AL_DMA_STATS=y
+CONFIG_AL_DMA_PCI_IOV=y
+CONFIG_UIO=y
+# CONFIG_IOMMU_SUPPORT is not set
+CONFIG_MEMORY=y
+CONFIG_EXT2_FS=y
+CONFIG_EXT3_FS=y
+CONFIG_EXT4_FS=y
+CONFIG_DNOTIFY=y
+CONFIG_INOTIFY_USER=y
+CONFIG_VFAT_FS=y
+CONFIG_TMPFS=y
+CONFIG_TMPFS_POSIX_ACL=y
+# CONFIG_HUGETLBFS is not set
+CONFIG_CONFIGFS_FS=y
+CONFIG_ECRYPT_FS=y
+CONFIG_UBIFS_FS=y
+CONFIG_CRAMFS=y
+CONFIG_SQUASHFS=y
+CONFIG_SQUASHFS_ZLIB=y
+CONFIG_SQUASHFS_LZO=y
+CONFIG_SQUASHFS_XZ=y
+CONFIG_SQUASHFS_4K_DEVBLK_SIZE=y
+CONFIG_SQUASHFS_EMBEDDED=y
+CONFIG_SQUASHFS_FRAGMENT_CACHE_SIZE=3
+CONFIG_MINIX_FS=y
+CONFIG_ROMFS_FS=y
+CONFIG_NFS_FS=y
+CONFIG_ROOT_NFS=y
+CONFIG_NFSD=y
+CONFIG_NFSD_V3=y
+CONFIG_CIFS=y
+CONFIG_NLS_CODEPAGE_437=y
+CONFIG_NLS_CODEPAGE_850=y
+CONFIG_NLS_ISO8859_1=y
+CONFIG_PRINTK_TIME=y
+CONFIG_MESSAGE_LOGLEVEL_DEFAULT=7
+CONFIG_DYNAMIC_DEBUG=y
+CONFIG_DEBUG_INFO=y
+CONFIG_MAGIC_SYSRQ=y
+CONFIG_ENABLE_DEFAULT_TRACERS=y
+# CONFIG_DEBUG_USER is not set
+CONFIG_KEYS=y
+CONFIG_ENCRYPTED_KEYS=y
+# CONFIG_CRYPTO_MANAGER_DISABLE_TESTS is not set
+CONFIG_CRYPTO_CMAC=y
+CONFIG_CRYPTO_MD4=y
+CONFIG_CRYPTO_ARC4=y
+CONFIG_CRYPTO_DEV_AL_CRYPTO=y
+CONFIG_CRYPTO_DEV_AL_CRYPTO_STATS=y
+CONFIG_LIBCRC32C=y
+CONFIG_LOCALVERSION="-6.1.3-5851039_sa"
+CONFIG_XFS_FS=y
+CONFIG_XFS_QUOTA=y
+CONFIG_XFS_POSIX_ACL=y
+# CONFIG_DEBUG_KERNEL is not set
+# CONFIG_NET_MQ_TX_LOCK_OPT is not set
+# CONFIG_VIRTUALIZATION is not set
+# CONFIG_KVM is not set
+# CONFIG_CAIF is not set
+# CONFIG_CAIF_VIRTIO is not set
+# CONFIG_CC_STACKPROTECTOR is not set
+CONFIG_NETFILTER_ADVANCED=y
+CONFIG_ARM_PAGE_SIZE_LARGE=y
+CONFIG_LFS_ON_32CPU=y
+CONFIG_BTRFS_FS=y
+CONFIG_QUOTA=y
+CONFIG_QUOTACTL=y
+CONFIG_ISCSI_TCP=m
+CONFIG_ZLIB_INFLATE=y
+CONFIG_ZLIB_DEFLATE=y
+CONFIG_LZO_COMPRESS=y
+CONFIG_LZO_DECOMPRESS=y
+CONFIG_XZ_DEC=y
+#
+# BUFFALO Features
+#
+CONFIG_BUFFALO_PLATFORM=y
+CONFIG_BUFFALO_USE_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_DEGRADE_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT=y
+CONFIG_BUFFALO_ERRCNT=y
+CONFIG_BUFFALO_USE_UPS=y
+CONFIG_BUFFALO_SUPPORT_UPS_RECOVER=y
+# CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN is not set
+# CONFIG_BUFFALO_UBOOT_PARAMS is not set
+CONFIG_BUFFALO_IOERRS=y
+CONFIG_BUFFALO_SKIP_RESYNC=y
+CONFIG_BUFFALO_IGNORE_LUN=y
+CONFIG_BUFFALO_SCSI_GUID=y
+CONFIG_BUFFALO_EXT23_EXTENSION=y
+# CONFIG_BUFFALO_SUPPORT_WOL is not set
+CONFIG_BUFFALO_SUPPORT_BOARD_INFO=y
+CONFIG_BUFFALO_ALPINE_PLATFORM=y
+# CONFIG_BUFFALO_USE_MICON is not set
+# CONFIG_BUFFALO_MICON_V3 is not set
+# CONFIG_BUFFALO_MICON_V3_DEVTTY is not set
+CONFIG_BUFFALO_MICON_REBOOT=y
diff --git a/buffalo/arch/arm/plat-alpine/Makefile b/buffalo/arch/arm/plat-alpine/Makefile
new file mode 100644
index 00000000..56bafc7
--- /dev/null
+++ b/buffalo/arch/arm/plat-alpine/Makefile
@@ -0,0 +1 @@
+obj-$(CONFIG_BUFFALO_ALPINE_PLATFORM)	+= sysfs.o
diff --git a/buffalo/arch/arm/plat-alpine/sysfs.c b/buffalo/arch/arm/plat-alpine/sysfs.c
new file mode 100644
index 00000000..5520b46
--- /dev/null
+++ b/buffalo/arch/arm/plat-alpine/sysfs.c
@@ -0,0 +1,35 @@
+/*
+ *
+ */
+
+#include <linux/device.h>
+#include <linux/module.h>
+#include <linux/sysfs.h>
+
+static struct class *ts5010_cls = NULL;
+
+static int
+init_sysfs_files(void)
+{
+	/* create /sys/class/ts5010 */
+	ts5010_cls = class_create(THIS_MODULE, "ts5010");
+
+	return 0;
+}
+
+static int __init
+ts5010_platform_init(void)
+{  	
+	return init_sysfs_files();
+}
+
+static void __exit
+ts5010_platform_exit(void)
+{
+	class_destroy(ts5010_cls);
+}
+
+module_init(ts5010_platform_init);
+module_exit(ts5010_platform_exit);
+MODULE_LICENSE("GPL");
+MODULE_AUTHOR("BUFFALO");
diff --git a/buffalo/arch/x86/Kconfig b/buffalo/arch/x86/Kconfig
new file mode 100644
index 00000000..fe190d3
--- /dev/null
+++ b/buffalo/arch/x86/Kconfig
@@ -0,0 +1,31 @@
+config BUFFALO_MATSU_PLATFORM
+	bool "MATSU_PLATFORM"
+	depends on BUFFALO_PLATFORM
+	depends on X86
+	---help---
+	  Enable hdd control driver / button control driver for matsu platform.
+
+config BUFFALO_MATSU_USE_EVT_BOARD
+	bool "MATSU_EVT_BOARD"
+	depends on BUFFALO_MATSU_PLATFORM
+	---help---
+	  EVT board and DVT board has difference for GPIO pin.
+	  If this value set to enable, use EVT GPIO settings.
+
+config BUFFALO_KIRI_PLATFORM
+	bool "KIRI_PLATFORM"
+	depends on BUFFALO_PLATFORM
+	depends on X86
+	---help---
+	  Enable hdd control driver / button control driver for kiri platform.
+
+config BUFFALO_USI_PLATFORM
+	bool "USI_PLATFORM"
+	depends on BUFFALO_PLATFORM
+	depends on X86
+	---help---
+	  Enable below drivers for usi platform.
+	  * hdd control driver(hot plug / power control)
+	  * fan control driver
+	  * button control driver
+	  * CMOS settings control driver
diff --git a/buffalo/arch/x86/Makefile b/buffalo/arch/x86/Makefile
new file mode 100644
index 00000000..e974bbf
--- /dev/null
+++ b/buffalo/arch/x86/Makefile
@@ -0,0 +1,4 @@
+# Note:	This file is included from $(srctree)/buffalo/Makefile,
+#	you have to specify relatively from $(srctree)/buffalo
+
+obj-$(CONFIG_BUFFALO_USI_PLATFORM)	+= arch/x86/plat-usi/
diff --git a/buffalo/arch/x86/boot/installkernel b/buffalo/arch/x86/boot/installkernel
new file mode 100755
index 00000000..1c5f89b
--- /dev/null
+++ b/buffalo/arch/x86/boot/installkernel
@@ -0,0 +1,83 @@
+#!/bin/sh
+# 
+# Copyright (C) 1995 - 1998, Ian A. Murdock <imurdock@debian.org>
+# Copyright (C) 1998, 1999, Guy Maor
+# Copyright (C) 2002, Matthew Wilcox
+# Copyright (C) 2002, 2004, 2005, 2007, 2009  Clint Adams
+# Copyright (C) 2009  Manoj Srivasta
+#
+# Install the kernel on a Debian Linux system.
+#
+# This script is called from /usr/src/linux/arch/i386/boot/install.sh.
+# If you install it as /sbin/installkernel, you can do a "make install"
+# from a generic kernel source tree, and the image will be installed to
+# the proper place for Debian GNU/Linux.
+
+set -e
+
+# Parse the command line options.  Of course, powerpc has to be all
+# different, and passes in a fifth argument, just because it is
+# "special". We ignore the fifth argument, and do not flag is as an
+# error, which it would be for any arch apart from powerpc
+if [ $# -eq 3 ] || [ $# -eq 4 ] || [ $# -eq 5 ] ; then
+  img="$2"
+  map="$3"
+  ver="$1"
+  if [ $# -ge 4 ] && [ -n "$4" ] ; then
+      dir="$4"
+  else
+      dir="/boot"
+  fi
+else
+  echo "Usage: installkernel <version> <image> <System.map> <directory>"
+  exit 1
+fi
+
+# Create backups of older versions before installing
+updatever () {
+  if [ -f "$dir/$1-$ver" ] ; then
+    mv "$dir/$1-$ver" "$dir/$1-$ver.old"
+  fi
+
+  cat "$2" > "$dir/$1-$ver"
+
+  # This section is for backwards compatibility only
+  if test -f "$dir/$1" ; then
+    # The presence of "$dir/$1" is unusual in modern intallations, and
+    # the results are mostly unused.  So only recreate them if they
+    # already existed.
+    if test -L "$dir/$1" ; then
+        # If we were using links, continue to use links, updating if
+        # we need to.
+        if [ "$(readlink -f ${dir}/${1})" = "${dir}/${1}-${ver}" ]; then
+            # Yup, we need to change
+            ln -sf "$1-$ver.old" "$dir/$1.old"
+        else
+            mv "$dir/$1" "$dir/$1.old"
+        fi
+        ln -sf "$1-$ver" "$dir/$1"
+    else                        # No links
+        mv "$dir/$1" "$dir/$1.old"
+        cat "$2" > "$dir/$1"
+    fi
+  fi
+}
+
+if [ "$(basename $img)" = "vmlinux" ] ; then
+  img_dest=vmlinux
+else
+  img_dest=vmlinuz
+fi
+updatever $img_dest "$img"
+updatever System.map "$map"
+
+config=$(dirname "$map")
+config="${config}/.config"
+if [ -f "$config" ] ; then
+  updatever config "$config"
+fi
+
+#run-parts --verbose --exit-on-error --arg="$ver" --arg="$dir/$img_dest-$ver" \
+#  /etc/kernel/postinst.d
+ 
+exit 0
diff --git a/buffalo/arch/x86/configs/buffalo_ts5000_defconfig b/buffalo/arch/x86/configs/buffalo_ts5000_defconfig
new file mode 100644
index 00000000..3a57f5d
--- /dev/null
+++ b/buffalo/arch/x86/configs/buffalo_ts5000_defconfig
@@ -0,0 +1,3042 @@
+#
+# Automatically generated file; DO NOT EDIT.
+# Linux/x86_64 3.10.20-buffalo Kernel Configuration
+#
+CONFIG_64BIT=y
+CONFIG_X86_64=y
+CONFIG_X86=y
+CONFIG_INSTRUCTION_DECODER=y
+CONFIG_OUTPUT_FORMAT="elf64-x86-64"
+CONFIG_ARCH_DEFCONFIG="arch/x86/configs/x86_64_defconfig"
+CONFIG_LOCKDEP_SUPPORT=y
+CONFIG_STACKTRACE_SUPPORT=y
+CONFIG_HAVE_LATENCYTOP_SUPPORT=y
+CONFIG_MMU=y
+CONFIG_NEED_DMA_MAP_STATE=y
+CONFIG_NEED_SG_DMA_LENGTH=y
+CONFIG_GENERIC_BUG=y
+CONFIG_GENERIC_BUG_RELATIVE_POINTERS=y
+CONFIG_GENERIC_HWEIGHT=y
+CONFIG_RWSEM_XCHGADD_ALGORITHM=y
+CONFIG_GENERIC_CALIBRATE_DELAY=y
+CONFIG_ARCH_HAS_CPU_RELAX=y
+CONFIG_ARCH_HAS_CACHE_LINE_SIZE=y
+CONFIG_ARCH_HAS_CPU_AUTOPROBE=y
+CONFIG_HAVE_SETUP_PER_CPU_AREA=y
+CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK=y
+CONFIG_NEED_PER_CPU_PAGE_FIRST_CHUNK=y
+CONFIG_ARCH_HIBERNATION_POSSIBLE=y
+CONFIG_ARCH_SUSPEND_POSSIBLE=y
+CONFIG_ZONE_DMA32=y
+CONFIG_AUDIT_ARCH=y
+CONFIG_ARCH_SUPPORTS_OPTIMIZED_INLINING=y
+CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC=y
+CONFIG_X86_64_SMP=y
+CONFIG_X86_HT=y
+CONFIG_ARCH_HWEIGHT_CFLAGS="-fcall-saved-rdi -fcall-saved-rsi -fcall-saved-rdx -fcall-saved-rcx -fcall-saved-r8 -fcall-saved-r9 -fcall-saved-r10 -fcall-saved-r11"
+CONFIG_ARCH_CPU_PROBE_RELEASE=y
+CONFIG_ARCH_SUPPORTS_UPROBES=y
+CONFIG_DEFCONFIG_LIST="/lib/modules/$UNAME_RELEASE/.config"
+CONFIG_IRQ_WORK=y
+CONFIG_BUILDTIME_EXTABLE_SORT=y
+
+#
+# General setup
+#
+CONFIG_INIT_ENV_ARG_LIMIT=32
+CONFIG_CROSS_COMPILE=""
+CONFIG_LOCALVERSION=""
+# CONFIG_LOCALVERSION_AUTO is not set
+CONFIG_HAVE_KERNEL_GZIP=y
+CONFIG_HAVE_KERNEL_BZIP2=y
+CONFIG_HAVE_KERNEL_LZMA=y
+CONFIG_HAVE_KERNEL_XZ=y
+CONFIG_HAVE_KERNEL_LZO=y
+CONFIG_KERNEL_GZIP=y
+# CONFIG_KERNEL_BZIP2 is not set
+# CONFIG_KERNEL_LZMA is not set
+# CONFIG_KERNEL_XZ is not set
+# CONFIG_KERNEL_LZO is not set
+CONFIG_DEFAULT_HOSTNAME="(none)"
+CONFIG_SWAP=y
+CONFIG_SYSVIPC=y
+CONFIG_SYSVIPC_SYSCTL=y
+CONFIG_POSIX_MQUEUE=y
+CONFIG_POSIX_MQUEUE_SYSCTL=y
+# CONFIG_FHANDLE is not set
+CONFIG_AUDIT=y
+CONFIG_AUDITSYSCALL=y
+CONFIG_AUDIT_WATCH=y
+CONFIG_AUDIT_TREE=y
+# CONFIG_AUDIT_LOGINUID_IMMUTABLE is not set
+CONFIG_HAVE_GENERIC_HARDIRQS=y
+
+#
+# IRQ subsystem
+#
+CONFIG_GENERIC_HARDIRQS=y
+CONFIG_GENERIC_IRQ_PROBE=y
+CONFIG_GENERIC_IRQ_SHOW=y
+CONFIG_GENERIC_PENDING_IRQ=y
+CONFIG_IRQ_DOMAIN=y
+# CONFIG_IRQ_DOMAIN_DEBUG is not set
+CONFIG_IRQ_FORCED_THREADING=y
+CONFIG_SPARSE_IRQ=y
+CONFIG_CLOCKSOURCE_WATCHDOG=y
+CONFIG_ARCH_CLOCKSOURCE_DATA=y
+CONFIG_GENERIC_TIME_VSYSCALL=y
+CONFIG_GENERIC_CLOCKEVENTS=y
+CONFIG_GENERIC_CLOCKEVENTS_BUILD=y
+CONFIG_GENERIC_CLOCKEVENTS_BROADCAST=y
+CONFIG_GENERIC_CLOCKEVENTS_MIN_ADJUST=y
+CONFIG_GENERIC_CMOS_UPDATE=y
+
+#
+# Timers subsystem
+#
+CONFIG_TICK_ONESHOT=y
+CONFIG_NO_HZ_COMMON=y
+# CONFIG_HZ_PERIODIC is not set
+CONFIG_NO_HZ_IDLE=y
+# CONFIG_NO_HZ_FULL is not set
+CONFIG_NO_HZ=y
+CONFIG_HIGH_RES_TIMERS=y
+
+#
+# CPU/Task time and stats accounting
+#
+CONFIG_TICK_CPU_ACCOUNTING=y
+# CONFIG_VIRT_CPU_ACCOUNTING_GEN is not set
+# CONFIG_IRQ_TIME_ACCOUNTING is not set
+CONFIG_BSD_PROCESS_ACCT=y
+CONFIG_BSD_PROCESS_ACCT_V3=y
+CONFIG_TASKSTATS=y
+CONFIG_TASK_DELAY_ACCT=y
+CONFIG_TASK_XACCT=y
+CONFIG_TASK_IO_ACCOUNTING=y
+
+#
+# RCU Subsystem
+#
+CONFIG_TREE_RCU=y
+# CONFIG_PREEMPT_RCU is not set
+CONFIG_RCU_STALL_COMMON=y
+# CONFIG_RCU_USER_QS is not set
+CONFIG_RCU_FANOUT=64
+CONFIG_RCU_FANOUT_LEAF=16
+# CONFIG_RCU_FANOUT_EXACT is not set
+CONFIG_RCU_FAST_NO_HZ=y
+# CONFIG_TREE_RCU_TRACE is not set
+# CONFIG_RCU_NOCB_CPU is not set
+CONFIG_IKCONFIG=y
+CONFIG_IKCONFIG_PROC=y
+CONFIG_LOG_BUF_SHIFT=18
+CONFIG_HAVE_UNSTABLE_SCHED_CLOCK=y
+CONFIG_ARCH_SUPPORTS_NUMA_BALANCING=y
+CONFIG_ARCH_WANTS_PROT_NUMA_PROT_NONE=y
+# CONFIG_NUMA_BALANCING is not set
+CONFIG_CGROUPS=y
+# CONFIG_CGROUP_DEBUG is not set
+CONFIG_CGROUP_FREEZER=y
+CONFIG_CGROUP_DEVICE=y
+CONFIG_CPUSETS=y
+CONFIG_PROC_PID_CPUSET=y
+CONFIG_CGROUP_CPUACCT=y
+CONFIG_RESOURCE_COUNTERS=y
+# CONFIG_MEMCG is not set
+# CONFIG_CGROUP_HUGETLB is not set
+# CONFIG_CGROUP_PERF is not set
+CONFIG_CGROUP_SCHED=y
+CONFIG_FAIR_GROUP_SCHED=y
+# CONFIG_CFS_BANDWIDTH is not set
+CONFIG_RT_GROUP_SCHED=y
+CONFIG_BLK_CGROUP=y
+# CONFIG_DEBUG_BLK_CGROUP is not set
+# CONFIG_CHECKPOINT_RESTORE is not set
+CONFIG_NAMESPACES=y
+CONFIG_UTS_NS=y
+CONFIG_IPC_NS=y
+CONFIG_PID_NS=y
+CONFIG_NET_NS=y
+CONFIG_SCHED_AUTOGROUP=y
+# CONFIG_SYSFS_DEPRECATED is not set
+CONFIG_RELAY=y
+CONFIG_BLK_DEV_INITRD=y
+CONFIG_INITRAMFS_SOURCE=""
+CONFIG_RD_GZIP=y
+CONFIG_RD_BZIP2=y
+CONFIG_RD_LZMA=y
+CONFIG_RD_XZ=y
+CONFIG_RD_LZO=y
+# CONFIG_CC_OPTIMIZE_FOR_SIZE is not set
+CONFIG_SYSCTL=y
+CONFIG_ANON_INODES=y
+CONFIG_HAVE_UID16=y
+CONFIG_SYSCTL_EXCEPTION_TRACE=y
+CONFIG_HOTPLUG=y
+CONFIG_HAVE_PCSPKR_PLATFORM=y
+CONFIG_EXPERT=y
+CONFIG_UID16=y
+CONFIG_SYSCTL_SYSCALL=y
+CONFIG_KALLSYMS=y
+# CONFIG_KALLSYMS_ALL is not set
+CONFIG_PRINTK=y
+CONFIG_BUG=y
+CONFIG_ELF_CORE=y
+CONFIG_PCSPKR_PLATFORM=y
+CONFIG_BASE_FULL=y
+CONFIG_FUTEX=y
+CONFIG_EPOLL=y
+CONFIG_SIGNALFD=y
+CONFIG_TIMERFD=y
+CONFIG_EVENTFD=y
+CONFIG_SHMEM=y
+CONFIG_AIO=y
+CONFIG_PCI_QUIRKS=y
+# CONFIG_EMBEDDED is not set
+CONFIG_HAVE_PERF_EVENTS=y
+
+#
+# Kernel Performance Events And Counters
+#
+CONFIG_PERF_EVENTS=y
+# CONFIG_DEBUG_PERF_USE_VMALLOC is not set
+CONFIG_VM_EVENT_COUNTERS=y
+# CONFIG_SLUB_DEBUG is not set
+# CONFIG_COMPAT_BRK is not set
+# CONFIG_SLAB is not set
+CONFIG_SLUB=y
+# CONFIG_SLOB is not set
+CONFIG_PROFILING=y
+CONFIG_TRACEPOINTS=y
+# CONFIG_OPROFILE is not set
+CONFIG_HAVE_OPROFILE=y
+CONFIG_OPROFILE_NMI_TIMER=y
+CONFIG_KPROBES=y
+CONFIG_JUMP_LABEL=y
+CONFIG_OPTPROBES=y
+CONFIG_KPROBES_ON_FTRACE=y
+# CONFIG_HAVE_64BIT_ALIGNED_ACCESS is not set
+CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS=y
+CONFIG_ARCH_USE_BUILTIN_BSWAP=y
+CONFIG_KRETPROBES=y
+CONFIG_HAVE_IOREMAP_PROT=y
+CONFIG_HAVE_KPROBES=y
+CONFIG_HAVE_KRETPROBES=y
+CONFIG_HAVE_OPTPROBES=y
+CONFIG_HAVE_KPROBES_ON_FTRACE=y
+CONFIG_HAVE_ARCH_TRACEHOOK=y
+CONFIG_HAVE_DMA_ATTRS=y
+CONFIG_USE_GENERIC_SMP_HELPERS=y
+CONFIG_GENERIC_SMP_IDLE_THREAD=y
+CONFIG_HAVE_REGS_AND_STACK_ACCESS_API=y
+CONFIG_HAVE_DMA_API_DEBUG=y
+CONFIG_HAVE_HW_BREAKPOINT=y
+CONFIG_HAVE_MIXED_BREAKPOINTS_REGS=y
+CONFIG_HAVE_USER_RETURN_NOTIFIER=y
+CONFIG_HAVE_PERF_EVENTS_NMI=y
+CONFIG_HAVE_PERF_REGS=y
+CONFIG_HAVE_PERF_USER_STACK_DUMP=y
+CONFIG_HAVE_ARCH_JUMP_LABEL=y
+CONFIG_ARCH_HAVE_NMI_SAFE_CMPXCHG=y
+CONFIG_HAVE_ALIGNED_STRUCT_PAGE=y
+CONFIG_HAVE_CMPXCHG_LOCAL=y
+CONFIG_HAVE_CMPXCHG_DOUBLE=y
+CONFIG_ARCH_WANT_COMPAT_IPC_PARSE_VERSION=y
+CONFIG_ARCH_WANT_OLD_COMPAT_IPC=y
+CONFIG_HAVE_ARCH_SECCOMP_FILTER=y
+CONFIG_SECCOMP_FILTER=y
+CONFIG_HAVE_CONTEXT_TRACKING=y
+CONFIG_HAVE_IRQ_TIME_ACCOUNTING=y
+CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE=y
+CONFIG_MODULES_USE_ELF_RELA=y
+CONFIG_OLD_SIGSUSPEND3=y
+CONFIG_COMPAT_OLD_SIGACTION=y
+
+#
+# GCOV-based kernel profiling
+#
+# CONFIG_GCOV_KERNEL is not set
+# CONFIG_HAVE_GENERIC_DMA_COHERENT is not set
+CONFIG_RT_MUTEXES=y
+CONFIG_BASE_SMALL=0
+CONFIG_MODULES=y
+# CONFIG_MODULE_FORCE_LOAD is not set
+CONFIG_MODULE_UNLOAD=y
+# CONFIG_MODULE_FORCE_UNLOAD is not set
+CONFIG_MODVERSIONS=y
+CONFIG_MODULE_SRCVERSION_ALL=y
+# CONFIG_MODULE_SIG is not set
+CONFIG_STOP_MACHINE=y
+CONFIG_BLOCK=y
+CONFIG_BLK_DEV_BSG=y
+# CONFIG_BLK_DEV_BSGLIB is not set
+CONFIG_BLK_DEV_INTEGRITY=y
+CONFIG_BLK_DEV_THROTTLING=y
+
+#
+# Partition Types
+#
+CONFIG_PARTITION_ADVANCED=y
+# CONFIG_ACORN_PARTITION is not set
+# CONFIG_OSF_PARTITION is not set
+# CONFIG_AMIGA_PARTITION is not set
+# CONFIG_ATARI_PARTITION is not set
+CONFIG_MAC_PARTITION=y
+CONFIG_MSDOS_PARTITION=y
+CONFIG_BSD_DISKLABEL=y
+CONFIG_MINIX_SUBPARTITION=y
+CONFIG_SOLARIS_X86_PARTITION=y
+CONFIG_UNIXWARE_DISKLABEL=y
+# CONFIG_LDM_PARTITION is not set
+# CONFIG_SGI_PARTITION is not set
+# CONFIG_ULTRIX_PARTITION is not set
+# CONFIG_SUN_PARTITION is not set
+# CONFIG_KARMA_PARTITION is not set
+CONFIG_EFI_PARTITION=y
+# CONFIG_SYSV68_PARTITION is not set
+CONFIG_BLOCK_COMPAT=y
+
+#
+# IO Schedulers
+#
+CONFIG_IOSCHED_NOOP=y
+CONFIG_IOSCHED_DEADLINE=y
+CONFIG_IOSCHED_CFQ=y
+CONFIG_CFQ_GROUP_IOSCHED=y
+# CONFIG_DEFAULT_DEADLINE is not set
+CONFIG_DEFAULT_CFQ=y
+# CONFIG_DEFAULT_NOOP is not set
+CONFIG_DEFAULT_IOSCHED="cfq"
+CONFIG_INLINE_SPIN_UNLOCK_IRQ=y
+CONFIG_INLINE_READ_UNLOCK=y
+CONFIG_INLINE_READ_UNLOCK_IRQ=y
+CONFIG_INLINE_WRITE_UNLOCK=y
+CONFIG_INLINE_WRITE_UNLOCK_IRQ=y
+CONFIG_MUTEX_SPIN_ON_OWNER=y
+CONFIG_FREEZER=y
+
+#
+# Processor type and features
+#
+CONFIG_ZONE_DMA=y
+CONFIG_SMP=y
+CONFIG_X86_MPPARSE=y
+CONFIG_X86_EXTENDED_PLATFORM=y
+# CONFIG_X86_VSMP is not set
+# CONFIG_X86_INTEL_LPSS is not set
+CONFIG_X86_SUPPORTS_MEMORY_FAILURE=y
+CONFIG_SCHED_OMIT_FRAME_POINTER=y
+# CONFIG_HYPERVISOR_GUEST is not set
+CONFIG_NO_BOOTMEM=y
+# CONFIG_MEMTEST is not set
+# CONFIG_MK8 is not set
+# CONFIG_MPSC is not set
+# CONFIG_MCORE2 is not set
+# CONFIG_MATOM is not set
+CONFIG_GENERIC_CPU=y
+CONFIG_X86_INTERNODE_CACHE_SHIFT=6
+CONFIG_X86_L1_CACHE_SHIFT=6
+CONFIG_X86_TSC=y
+CONFIG_X86_CMPXCHG64=y
+CONFIG_X86_CMOV=y
+CONFIG_X86_MINIMUM_CPU_FAMILY=64
+CONFIG_X86_DEBUGCTLMSR=y
+CONFIG_PROCESSOR_SELECT=y
+CONFIG_CPU_SUP_INTEL=y
+CONFIG_CPU_SUP_AMD=y
+CONFIG_CPU_SUP_CENTAUR=y
+CONFIG_HPET_TIMER=y
+CONFIG_HPET_EMULATE_RTC=y
+CONFIG_DMI=y
+CONFIG_GART_IOMMU=y
+CONFIG_CALGARY_IOMMU=y
+CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT=y
+CONFIG_SWIOTLB=y
+CONFIG_IOMMU_HELPER=y
+# CONFIG_MAXSMP is not set
+CONFIG_NR_CPUS=256
+CONFIG_SCHED_SMT=y
+CONFIG_SCHED_MC=y
+# CONFIG_PREEMPT_NONE is not set
+CONFIG_PREEMPT_VOLUNTARY=y
+# CONFIG_PREEMPT is not set
+CONFIG_X86_LOCAL_APIC=y
+CONFIG_X86_IO_APIC=y
+CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS=y
+CONFIG_X86_MCE=y
+CONFIG_X86_MCE_INTEL=y
+CONFIG_X86_MCE_AMD=y
+CONFIG_X86_MCE_THRESHOLD=y
+# CONFIG_X86_MCE_INJECT is not set
+CONFIG_X86_THERMAL_VECTOR=y
+# CONFIG_I8K is not set
+# CONFIG_MICROCODE is not set
+# CONFIG_X86_MSR is not set
+# CONFIG_X86_CPUID is not set
+CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
+CONFIG_ARCH_DMA_ADDR_T_64BIT=y
+CONFIG_DIRECT_GBPAGES=y
+CONFIG_NUMA=y
+CONFIG_AMD_NUMA=y
+CONFIG_X86_64_ACPI_NUMA=y
+CONFIG_NODES_SPAN_OTHER_NODES=y
+# CONFIG_NUMA_EMU is not set
+CONFIG_NODES_SHIFT=6
+CONFIG_ARCH_SPARSEMEM_ENABLE=y
+CONFIG_ARCH_SPARSEMEM_DEFAULT=y
+CONFIG_ARCH_SELECT_MEMORY_MODEL=y
+CONFIG_ARCH_PROC_KCORE_TEXT=y
+CONFIG_ILLEGAL_POINTER_VALUE=0xdead000000000000
+CONFIG_SELECT_MEMORY_MODEL=y
+CONFIG_SPARSEMEM_MANUAL=y
+CONFIG_SPARSEMEM=y
+CONFIG_NEED_MULTIPLE_NODES=y
+CONFIG_HAVE_MEMORY_PRESENT=y
+CONFIG_SPARSEMEM_EXTREME=y
+CONFIG_SPARSEMEM_VMEMMAP_ENABLE=y
+CONFIG_SPARSEMEM_ALLOC_MEM_MAP_TOGETHER=y
+CONFIG_SPARSEMEM_VMEMMAP=y
+CONFIG_HAVE_MEMBLOCK=y
+CONFIG_HAVE_MEMBLOCK_NODE_MAP=y
+CONFIG_ARCH_DISCARD_MEMBLOCK=y
+CONFIG_MEMORY_ISOLATION=y
+# CONFIG_MOVABLE_NODE is not set
+# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
+# CONFIG_MEMORY_HOTPLUG is not set
+CONFIG_PAGEFLAGS_EXTENDED=y
+CONFIG_SPLIT_PTLOCK_CPUS=4
+CONFIG_COMPACTION=y
+CONFIG_MIGRATION=y
+CONFIG_PHYS_ADDR_T_64BIT=y
+CONFIG_ZONE_DMA_FLAG=1
+CONFIG_BOUNCE=y
+CONFIG_NEED_BOUNCE_POOL=y
+CONFIG_VIRT_TO_BUS=y
+CONFIG_KSM=y
+CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
+CONFIG_ARCH_SUPPORTS_MEMORY_FAILURE=y
+CONFIG_MEMORY_FAILURE=y
+# CONFIG_HWPOISON_INJECT is not set
+# CONFIG_TRANSPARENT_HUGEPAGE is not set
+CONFIG_CROSS_MEMORY_ATTACH=y
+# CONFIG_CLEANCACHE is not set
+# CONFIG_FRONTSWAP is not set
+CONFIG_X86_CHECK_BIOS_CORRUPTION=y
+CONFIG_X86_BOOTPARAM_MEMORY_CORRUPTION_CHECK=y
+CONFIG_X86_RESERVE_LOW=64
+CONFIG_MTRR=y
+CONFIG_MTRR_SANITIZER=y
+CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT=0
+CONFIG_MTRR_SANITIZER_SPARE_REG_NR_DEFAULT=1
+CONFIG_X86_PAT=y
+CONFIG_ARCH_USES_PG_UNCACHED=y
+CONFIG_ARCH_RANDOM=y
+CONFIG_X86_SMAP=y
+CONFIG_EFI=y
+# CONFIG_EFI_STUB is not set
+CONFIG_SECCOMP=y
+CONFIG_CC_STACKPROTECTOR=y
+CONFIG_HZ_100=y
+# CONFIG_HZ_250 is not set
+# CONFIG_HZ_300 is not set
+# CONFIG_HZ_1000 is not set
+CONFIG_HZ=100
+CONFIG_SCHED_HRTICK=y
+CONFIG_KEXEC=y
+CONFIG_CRASH_DUMP=y
+CONFIG_KEXEC_JUMP=y
+CONFIG_PHYSICAL_START=0x1000000
+CONFIG_RELOCATABLE=y
+CONFIG_PHYSICAL_ALIGN=0x1000000
+CONFIG_HOTPLUG_CPU=y
+# CONFIG_BOOTPARAM_HOTPLUG_CPU0 is not set
+# CONFIG_DEBUG_HOTPLUG_CPU0 is not set
+# CONFIG_COMPAT_VDSO is not set
+# CONFIG_CMDLINE_BOOL is not set
+CONFIG_ARCH_ENABLE_MEMORY_HOTPLUG=y
+CONFIG_USE_PERCPU_NUMA_NODE_ID=y
+
+#
+# Power management and ACPI options
+#
+CONFIG_ARCH_HIBERNATION_HEADER=y
+CONFIG_SUSPEND=y
+CONFIG_SUSPEND_FREEZER=y
+CONFIG_HIBERNATE_CALLBACKS=y
+CONFIG_HIBERNATION=y
+CONFIG_PM_STD_PARTITION=""
+CONFIG_PM_SLEEP=y
+CONFIG_PM_SLEEP_SMP=y
+# CONFIG_PM_AUTOSLEEP is not set
+# CONFIG_PM_WAKELOCKS is not set
+CONFIG_PM_RUNTIME=y
+CONFIG_PM=y
+# CONFIG_PM_DEBUG is not set
+CONFIG_ACPI=y
+CONFIG_ACPI_SLEEP=y
+CONFIG_ACPI_PROCFS=y
+CONFIG_ACPI_PROCFS_POWER=y
+# CONFIG_ACPI_EC_DEBUGFS is not set
+CONFIG_ACPI_PROC_EVENT=y
+CONFIG_ACPI_AC=y
+CONFIG_ACPI_BATTERY=y
+CONFIG_ACPI_BUTTON=y
+CONFIG_ACPI_VIDEO=y
+CONFIG_ACPI_FAN=y
+CONFIG_ACPI_DOCK=y
+CONFIG_ACPI_I2C=y
+CONFIG_ACPI_PROCESSOR=y
+CONFIG_ACPI_HOTPLUG_CPU=y
+# CONFIG_ACPI_PROCESSOR_AGGREGATOR is not set
+CONFIG_ACPI_THERMAL=y
+CONFIG_ACPI_NUMA=y
+CONFIG_ACPI_CUSTOM_DSDT_FILE=""
+# CONFIG_ACPI_CUSTOM_DSDT is not set
+# CONFIG_ACPI_INITRD_TABLE_OVERRIDE is not set
+CONFIG_ACPI_BLACKLIST_YEAR=0
+# CONFIG_ACPI_DEBUG is not set
+CONFIG_ACPI_PCI_SLOT=y
+CONFIG_X86_PM_TIMER=y
+CONFIG_ACPI_CONTAINER=y
+CONFIG_ACPI_SBS=y
+# CONFIG_ACPI_HED is not set
+# CONFIG_ACPI_CUSTOM_METHOD is not set
+# CONFIG_ACPI_BGRT is not set
+CONFIG_ACPI_APEI=y
+# CONFIG_ACPI_APEI_GHES is not set
+# CONFIG_ACPI_APEI_PCIEAER is not set
+# CONFIG_ACPI_APEI_MEMORY_FAILURE is not set
+# CONFIG_ACPI_APEI_EINJ is not set
+# CONFIG_ACPI_APEI_ERST_DEBUG is not set
+CONFIG_SFI=y
+
+#
+# CPU Frequency scaling
+#
+CONFIG_CPU_FREQ=y
+CONFIG_CPU_FREQ_TABLE=y
+CONFIG_CPU_FREQ_GOV_COMMON=y
+CONFIG_CPU_FREQ_STAT=y
+CONFIG_CPU_FREQ_STAT_DETAILS=y
+CONFIG_CPU_FREQ_DEFAULT_GOV_PERFORMANCE=y
+# CONFIG_CPU_FREQ_DEFAULT_GOV_POWERSAVE is not set
+# CONFIG_CPU_FREQ_DEFAULT_GOV_USERSPACE is not set
+# CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND is not set
+# CONFIG_CPU_FREQ_DEFAULT_GOV_CONSERVATIVE is not set
+CONFIG_CPU_FREQ_GOV_PERFORMANCE=y
+CONFIG_CPU_FREQ_GOV_POWERSAVE=y
+CONFIG_CPU_FREQ_GOV_USERSPACE=y
+CONFIG_CPU_FREQ_GOV_ONDEMAND=y
+CONFIG_CPU_FREQ_GOV_CONSERVATIVE=y
+
+#
+# x86 CPU frequency scaling drivers
+#
+# CONFIG_X86_INTEL_PSTATE is not set
+# CONFIG_X86_PCC_CPUFREQ is not set
+CONFIG_X86_ACPI_CPUFREQ=y
+CONFIG_X86_ACPI_CPUFREQ_CPB=y
+CONFIG_X86_POWERNOW_K8=y
+# CONFIG_X86_AMD_FREQ_SENSITIVITY is not set
+CONFIG_X86_SPEEDSTEP_CENTRINO=y
+# CONFIG_X86_P4_CLOCKMOD is not set
+
+#
+# shared options
+#
+# CONFIG_X86_SPEEDSTEP_LIB is not set
+CONFIG_CPU_IDLE=y
+# CONFIG_CPU_IDLE_MULTIPLE_DRIVERS is not set
+CONFIG_CPU_IDLE_GOV_LADDER=y
+CONFIG_CPU_IDLE_GOV_MENU=y
+# CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
+CONFIG_INTEL_IDLE=y
+
+#
+# Memory power savings
+#
+# CONFIG_I7300_IDLE is not set
+
+#
+# Bus options (PCI etc.)
+#
+CONFIG_PCI=y
+CONFIG_PCI_DIRECT=y
+CONFIG_PCI_MMCONFIG=y
+CONFIG_PCI_DOMAINS=y
+# CONFIG_PCI_CNB20LE_QUIRK is not set
+CONFIG_PCIEPORTBUS=y
+CONFIG_HOTPLUG_PCI_PCIE=y
+CONFIG_PCIEAER=y
+# CONFIG_PCIE_ECRC is not set
+# CONFIG_PCIEAER_INJECT is not set
+CONFIG_PCIEASPM=y
+# CONFIG_PCIEASPM_DEBUG is not set
+CONFIG_PCIEASPM_DEFAULT=y
+# CONFIG_PCIEASPM_POWERSAVE is not set
+# CONFIG_PCIEASPM_PERFORMANCE is not set
+CONFIG_PCIE_PME=y
+CONFIG_ARCH_SUPPORTS_MSI=y
+CONFIG_PCI_MSI=y
+# CONFIG_PCI_DEBUG is not set
+# CONFIG_PCI_REALLOC_ENABLE_AUTO is not set
+# CONFIG_PCI_STUB is not set
+CONFIG_HT_IRQ=y
+CONFIG_PCI_ATS=y
+# CONFIG_PCI_IOV is not set
+CONFIG_PCI_PRI=y
+CONFIG_PCI_PASID=y
+CONFIG_PCI_IOAPIC=y
+CONFIG_PCI_LABEL=y
+# CONFIG_ISA_DMA_API is not set
+CONFIG_AMD_NB=y
+# CONFIG_PCCARD is not set
+CONFIG_HOTPLUG_PCI=y
+# CONFIG_HOTPLUG_PCI_ACPI is not set
+CONFIG_HOTPLUG_PCI_CPCI=y
+# CONFIG_HOTPLUG_PCI_CPCI_ZT5550 is not set
+# CONFIG_HOTPLUG_PCI_CPCI_GENERIC is not set
+# CONFIG_HOTPLUG_PCI_SHPC is not set
+# CONFIG_RAPIDIO is not set
+
+#
+# Executable file formats / Emulations
+#
+CONFIG_BINFMT_ELF=y
+CONFIG_COMPAT_BINFMT_ELF=y
+CONFIG_ARCH_BINFMT_ELF_RANDOMIZE_PIE=y
+CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS=y
+CONFIG_BINFMT_SCRIPT=y
+# CONFIG_HAVE_AOUT is not set
+CONFIG_BINFMT_MISC=y
+CONFIG_COREDUMP=y
+CONFIG_IA32_EMULATION=y
+# CONFIG_IA32_AOUT is not set
+# CONFIG_X86_X32 is not set
+CONFIG_COMPAT=y
+CONFIG_COMPAT_FOR_U64_ALIGNMENT=y
+CONFIG_SYSVIPC_COMPAT=y
+CONFIG_KEYS_COMPAT=y
+CONFIG_HAVE_TEXT_POKE_SMP=y
+CONFIG_X86_DEV_DMA_OPS=y
+CONFIG_NET=y
+
+#
+# Networking options
+#
+CONFIG_PACKET=y
+# CONFIG_PACKET_DIAG is not set
+CONFIG_UNIX=y
+# CONFIG_UNIX_DIAG is not set
+# CONFIG_XFRM_USER is not set
+# CONFIG_NET_KEY is not set
+CONFIG_INET=y
+CONFIG_IP_MULTICAST=y
+CONFIG_IP_ADVANCED_ROUTER=y
+# CONFIG_IP_FIB_TRIE_STATS is not set
+CONFIG_IP_MULTIPLE_TABLES=y
+CONFIG_IP_ROUTE_MULTIPATH=y
+CONFIG_IP_ROUTE_VERBOSE=y
+CONFIG_IP_PNP=y
+CONFIG_IP_PNP_DHCP=y
+CONFIG_IP_PNP_BOOTP=y
+CONFIG_IP_PNP_RARP=y
+# CONFIG_NET_IPIP is not set
+# CONFIG_NET_IPGRE_DEMUX is not set
+# CONFIG_NET_IP_TUNNEL is not set
+CONFIG_IP_MROUTE=y
+# CONFIG_IP_MROUTE_MULTIPLE_TABLES is not set
+CONFIG_IP_PIMSM_V1=y
+CONFIG_IP_PIMSM_V2=y
+# CONFIG_ARPD is not set
+CONFIG_SYN_COOKIES=y
+# CONFIG_INET_AH is not set
+# CONFIG_INET_ESP is not set
+# CONFIG_INET_IPCOMP is not set
+# CONFIG_INET_XFRM_TUNNEL is not set
+# CONFIG_INET_TUNNEL is not set
+# CONFIG_INET_XFRM_MODE_TRANSPORT is not set
+# CONFIG_INET_XFRM_MODE_TUNNEL is not set
+# CONFIG_INET_XFRM_MODE_BEET is not set
+CONFIG_INET_LRO=y
+# CONFIG_INET_DIAG is not set
+CONFIG_TCP_CONG_ADVANCED=y
+# CONFIG_TCP_CONG_BIC is not set
+CONFIG_TCP_CONG_CUBIC=y
+# CONFIG_TCP_CONG_WESTWOOD is not set
+# CONFIG_TCP_CONG_HTCP is not set
+# CONFIG_TCP_CONG_HSTCP is not set
+# CONFIG_TCP_CONG_HYBLA is not set
+# CONFIG_TCP_CONG_VEGAS is not set
+# CONFIG_TCP_CONG_SCALABLE is not set
+# CONFIG_TCP_CONG_LP is not set
+# CONFIG_TCP_CONG_VENO is not set
+# CONFIG_TCP_CONG_YEAH is not set
+# CONFIG_TCP_CONG_ILLINOIS is not set
+CONFIG_DEFAULT_CUBIC=y
+# CONFIG_DEFAULT_RENO is not set
+CONFIG_DEFAULT_TCP_CONG="cubic"
+CONFIG_TCP_MD5SIG=y
+# CONFIG_IPV6 is not set
+CONFIG_NETLABEL=y
+CONFIG_NETWORK_SECMARK=y
+# CONFIG_NETWORK_PHY_TIMESTAMPING is not set
+CONFIG_NETFILTER=y
+# CONFIG_NETFILTER_DEBUG is not set
+# CONFIG_NETFILTER_ADVANCED is not set
+
+#
+# Core Netfilter Configuration
+#
+CONFIG_NETFILTER_NETLINK=y
+CONFIG_NETFILTER_NETLINK_LOG=y
+# CONFIG_NF_CONNTRACK is not set
+CONFIG_NETFILTER_XTABLES=y
+
+#
+# Xtables combined modules
+#
+# CONFIG_NETFILTER_XT_MARK is not set
+
+#
+# Xtables targets
+#
+CONFIG_NETFILTER_XT_TARGET_LOG=m
+CONFIG_NETFILTER_XT_TARGET_NFLOG=y
+CONFIG_NETFILTER_XT_TARGET_SECMARK=y
+CONFIG_NETFILTER_XT_TARGET_TCPMSS=y
+
+#
+# Xtables matches
+#
+# CONFIG_IP_SET is not set
+# CONFIG_IP_VS is not set
+
+#
+# IP: Netfilter Configuration
+#
+# CONFIG_NF_DEFRAG_IPV4 is not set
+CONFIG_IP_NF_IPTABLES=y
+CONFIG_IP_NF_FILTER=y
+CONFIG_IP_NF_TARGET_REJECT=y
+CONFIG_IP_NF_TARGET_ULOG=y
+CONFIG_IP_NF_MANGLE=y
+# CONFIG_IP_NF_RAW is not set
+# CONFIG_IP_DCCP is not set
+# CONFIG_IP_SCTP is not set
+# CONFIG_RDS is not set
+# CONFIG_TIPC is not set
+# CONFIG_ATM is not set
+# CONFIG_L2TP is not set
+# CONFIG_BRIDGE is not set
+CONFIG_HAVE_NET_DSA=y
+# CONFIG_VLAN_8021Q is not set
+# CONFIG_DECNET is not set
+# CONFIG_LLC2 is not set
+# CONFIG_IPX is not set
+# CONFIG_ATALK is not set
+# CONFIG_X25 is not set
+# CONFIG_LAPB is not set
+# CONFIG_PHONET is not set
+# CONFIG_IEEE802154 is not set
+CONFIG_NET_SCHED=y
+
+#
+# Queueing/Scheduling
+#
+# CONFIG_NET_SCH_CBQ is not set
+# CONFIG_NET_SCH_HTB is not set
+# CONFIG_NET_SCH_HFSC is not set
+# CONFIG_NET_SCH_PRIO is not set
+# CONFIG_NET_SCH_MULTIQ is not set
+# CONFIG_NET_SCH_RED is not set
+# CONFIG_NET_SCH_SFB is not set
+# CONFIG_NET_SCH_SFQ is not set
+# CONFIG_NET_SCH_TEQL is not set
+# CONFIG_NET_SCH_TBF is not set
+# CONFIG_NET_SCH_GRED is not set
+# CONFIG_NET_SCH_DSMARK is not set
+# CONFIG_NET_SCH_NETEM is not set
+# CONFIG_NET_SCH_DRR is not set
+# CONFIG_NET_SCH_MQPRIO is not set
+# CONFIG_NET_SCH_CHOKE is not set
+# CONFIG_NET_SCH_QFQ is not set
+# CONFIG_NET_SCH_CODEL is not set
+# CONFIG_NET_SCH_FQ_CODEL is not set
+# CONFIG_NET_SCH_INGRESS is not set
+# CONFIG_NET_SCH_PLUG is not set
+
+#
+# Classification
+#
+CONFIG_NET_CLS=y
+# CONFIG_NET_CLS_BASIC is not set
+# CONFIG_NET_CLS_TCINDEX is not set
+# CONFIG_NET_CLS_ROUTE4 is not set
+# CONFIG_NET_CLS_FW is not set
+# CONFIG_NET_CLS_U32 is not set
+# CONFIG_NET_CLS_RSVP is not set
+# CONFIG_NET_CLS_RSVP6 is not set
+# CONFIG_NET_CLS_FLOW is not set
+CONFIG_NET_CLS_CGROUP=y
+CONFIG_NET_EMATCH=y
+CONFIG_NET_EMATCH_STACK=32
+# CONFIG_NET_EMATCH_CMP is not set
+# CONFIG_NET_EMATCH_NBYTE is not set
+# CONFIG_NET_EMATCH_U32 is not set
+# CONFIG_NET_EMATCH_META is not set
+# CONFIG_NET_EMATCH_TEXT is not set
+CONFIG_NET_CLS_ACT=y
+# CONFIG_NET_ACT_POLICE is not set
+# CONFIG_NET_ACT_GACT is not set
+# CONFIG_NET_ACT_MIRRED is not set
+# CONFIG_NET_ACT_IPT is not set
+# CONFIG_NET_ACT_NAT is not set
+# CONFIG_NET_ACT_PEDIT is not set
+# CONFIG_NET_ACT_SIMP is not set
+# CONFIG_NET_ACT_SKBEDIT is not set
+# CONFIG_NET_ACT_CSUM is not set
+CONFIG_NET_SCH_FIFO=y
+# CONFIG_DCB is not set
+CONFIG_DNS_RESOLVER=y
+# CONFIG_BATMAN_ADV is not set
+# CONFIG_OPENVSWITCH is not set
+# CONFIG_VSOCKETS is not set
+# CONFIG_NETLINK_MMAP is not set
+# CONFIG_NETLINK_DIAG is not set
+CONFIG_RPS=y
+CONFIG_RFS_ACCEL=y
+CONFIG_XPS=y
+# CONFIG_NETPRIO_CGROUP is not set
+CONFIG_BQL=y
+# CONFIG_BPF_JIT is not set
+
+#
+# Network testing
+#
+# CONFIG_NET_PKTGEN is not set
+# CONFIG_NET_TCPPROBE is not set
+# CONFIG_NET_DROP_MONITOR is not set
+CONFIG_HAMRADIO=y
+
+#
+# Packet Radio protocols
+#
+# CONFIG_AX25 is not set
+# CONFIG_CAN is not set
+# CONFIG_IRDA is not set
+# CONFIG_BT is not set
+# CONFIG_AF_RXRPC is not set
+CONFIG_FIB_RULES=y
+CONFIG_WIRELESS=y
+# CONFIG_CFG80211 is not set
+# CONFIG_LIB80211 is not set
+
+#
+# CFG80211 needs to be enabled for MAC80211
+#
+# CONFIG_WIMAX is not set
+CONFIG_RFKILL=y
+CONFIG_RFKILL_INPUT=y
+# CONFIG_NET_9P is not set
+# CONFIG_CAIF is not set
+# CONFIG_CEPH_LIB is not set
+# CONFIG_NFC is not set
+CONFIG_HAVE_BPF_JIT=y
+
+#
+# Device Drivers
+#
+
+#
+# Generic Driver Options
+#
+CONFIG_UEVENT_HELPER_PATH="/sbin/hotplug"
+# CONFIG_DEVTMPFS is not set
+# CONFIG_STANDALONE is not set
+CONFIG_PREVENT_FIRMWARE_BUILD=y
+CONFIG_FW_LOADER=y
+CONFIG_FIRMWARE_IN_KERNEL=y
+CONFIG_EXTRA_FIRMWARE=""
+CONFIG_FW_LOADER_USER_HELPER=y
+# CONFIG_DEBUG_DRIVER is not set
+# CONFIG_DEBUG_DEVRES is not set
+# CONFIG_SYS_HYPERVISOR is not set
+# CONFIG_GENERIC_CPU_DEVICES is not set
+CONFIG_DMA_SHARED_BUFFER=y
+
+#
+# Bus devices
+#
+CONFIG_CONNECTOR=y
+CONFIG_PROC_EVENTS=y
+# CONFIG_MTD is not set
+# CONFIG_PARPORT is not set
+CONFIG_PNP=y
+# CONFIG_PNP_DEBUG_MESSAGES is not set
+
+#
+# Protocols
+#
+CONFIG_PNPACPI=y
+CONFIG_BLK_DEV=y
+# CONFIG_BLK_DEV_PCIESSD_MTIP32XX is not set
+# CONFIG_BLK_CPQ_DA is not set
+# CONFIG_BLK_CPQ_CISS_DA is not set
+# CONFIG_BLK_DEV_DAC960 is not set
+# CONFIG_BLK_DEV_UMEM is not set
+# CONFIG_BLK_DEV_COW_COMMON is not set
+CONFIG_BLK_DEV_LOOP=y
+CONFIG_BLK_DEV_LOOP_MIN_COUNT=8
+# CONFIG_BLK_DEV_CRYPTOLOOP is not set
+# CONFIG_BLK_DEV_DRBD is not set
+# CONFIG_BLK_DEV_NBD is not set
+# CONFIG_BLK_DEV_NVME is not set
+# CONFIG_BLK_DEV_SX8 is not set
+CONFIG_BLK_DEV_RAM=y
+CONFIG_BLK_DEV_RAM_COUNT=16
+CONFIG_BLK_DEV_RAM_SIZE=65536
+# CONFIG_BLK_DEV_XIP is not set
+# CONFIG_CDROM_PKTCDVD is not set
+# CONFIG_ATA_OVER_ETH is not set
+# CONFIG_BLK_DEV_HD is not set
+# CONFIG_BLK_DEV_RBD is not set
+# CONFIG_BLK_DEV_RSXX is not set
+
+#
+# Misc devices
+#
+# CONFIG_SENSORS_LIS3LV02D is not set
+# CONFIG_AD525X_DPOT is not set
+# CONFIG_DUMMY_IRQ is not set
+# CONFIG_IBM_ASM is not set
+# CONFIG_PHANTOM is not set
+# CONFIG_INTEL_MID_PTI is not set
+# CONFIG_SGI_IOC4 is not set
+# CONFIG_TIFM_CORE is not set
+# CONFIG_ICS932S401 is not set
+# CONFIG_ATMEL_SSC is not set
+# CONFIG_ENCLOSURE_SERVICES is not set
+# CONFIG_HP_ILO is not set
+# CONFIG_APDS9802ALS is not set
+# CONFIG_ISL29003 is not set
+# CONFIG_ISL29020 is not set
+# CONFIG_SENSORS_TSL2550 is not set
+# CONFIG_SENSORS_BH1780 is not set
+# CONFIG_SENSORS_BH1770 is not set
+# CONFIG_SENSORS_APDS990X is not set
+# CONFIG_HMC6352 is not set
+# CONFIG_DS1682 is not set
+# CONFIG_BMP085_I2C is not set
+# CONFIG_PCH_PHUB is not set
+# CONFIG_USB_SWITCH_FSA9480 is not set
+# CONFIG_SRAM is not set
+# CONFIG_C2PORT is not set
+
+#
+# EEPROM support
+#
+# CONFIG_EEPROM_AT24 is not set
+# CONFIG_EEPROM_LEGACY is not set
+# CONFIG_EEPROM_MAX6875 is not set
+# CONFIG_EEPROM_93CX6 is not set
+# CONFIG_CB710_CORE is not set
+
+#
+# Texas Instruments shared transport line discipline
+#
+# CONFIG_SENSORS_LIS3_I2C is not set
+
+#
+# Altera FPGA firmware download module
+#
+# CONFIG_ALTERA_STAPL is not set
+# CONFIG_VMWARE_VMCI is not set
+CONFIG_HAVE_IDE=y
+# CONFIG_IDE is not set
+
+#
+# SCSI device support
+#
+CONFIG_SCSI_MOD=y
+# CONFIG_RAID_ATTRS is not set
+CONFIG_SCSI=y
+CONFIG_SCSI_DMA=y
+# CONFIG_SCSI_TGT is not set
+# CONFIG_SCSI_NETLINK is not set
+CONFIG_SCSI_PROC_FS=y
+
+#
+# SCSI support type (disk, tape, CD-ROM)
+#
+CONFIG_BLK_DEV_SD=y
+# CONFIG_CHR_DEV_ST is not set
+# CONFIG_CHR_DEV_OSST is not set
+CONFIG_BLK_DEV_SR=y
+# CONFIG_BLK_DEV_SR_VENDOR is not set
+CONFIG_CHR_DEV_SG=y
+# CONFIG_CHR_DEV_SCH is not set
+# CONFIG_SCSI_MULTI_LUN is not set
+CONFIG_SCSI_CONSTANTS=y
+CONFIG_SCSI_LOGGING=y
+# CONFIG_SCSI_SCAN_ASYNC is not set
+
+#
+# SCSI Transports
+#
+# CONFIG_SCSI_SPI_ATTRS is not set
+# CONFIG_SCSI_FC_ATTRS is not set
+# CONFIG_SCSI_ISCSI_ATTRS is not set
+CONFIG_SCSI_SAS_ATTRS=y
+CONFIG_SCSI_SAS_LIBSAS=y
+CONFIG_SCSI_SAS_ATA=y
+CONFIG_SCSI_SAS_HOST_SMP=y
+# CONFIG_SCSI_SRP_ATTRS is not set
+CONFIG_SCSI_LOWLEVEL=y
+# CONFIG_ISCSI_TCP is not set
+# CONFIG_ISCSI_BOOT_SYSFS is not set
+# CONFIG_SCSI_CXGB3_ISCSI is not set
+# CONFIG_SCSI_CXGB4_ISCSI is not set
+# CONFIG_SCSI_BNX2_ISCSI is not set
+# CONFIG_SCSI_BNX2X_FCOE is not set
+# CONFIG_BE2ISCSI is not set
+# CONFIG_BLK_DEV_3W_XXXX_RAID is not set
+# CONFIG_SCSI_HPSA is not set
+# CONFIG_SCSI_3W_9XXX is not set
+# CONFIG_SCSI_3W_SAS is not set
+# CONFIG_SCSI_ACARD is not set
+# CONFIG_SCSI_AACRAID is not set
+# CONFIG_SCSI_AIC7XXX is not set
+# CONFIG_SCSI_AIC7XXX_OLD is not set
+# CONFIG_SCSI_AIC79XX is not set
+# CONFIG_SCSI_AIC94XX is not set
+# CONFIG_SCSI_MVSAS is not set
+# CONFIG_SCSI_MVUMI is not set
+# CONFIG_SCSI_DPT_I2O is not set
+# CONFIG_SCSI_ADVANSYS is not set
+# CONFIG_SCSI_ARCMSR is not set
+# CONFIG_MEGARAID_NEWGEN is not set
+# CONFIG_MEGARAID_LEGACY is not set
+# CONFIG_MEGARAID_SAS is not set
+# CONFIG_SCSI_MPT2SAS is not set
+# CONFIG_SCSI_MPT3SAS is not set
+# CONFIG_SCSI_UFSHCD is not set
+# CONFIG_SCSI_HPTIOP is not set
+# CONFIG_VMWARE_PVSCSI is not set
+# CONFIG_LIBFC is not set
+# CONFIG_LIBFCOE is not set
+# CONFIG_FCOE is not set
+# CONFIG_FCOE_FNIC is not set
+# CONFIG_SCSI_DMX3191D is not set
+# CONFIG_SCSI_FUTURE_DOMAIN is not set
+# CONFIG_SCSI_ISCI is not set
+# CONFIG_SCSI_IPS is not set
+# CONFIG_SCSI_INITIO is not set
+# CONFIG_SCSI_INIA100 is not set
+# CONFIG_SCSI_STEX is not set
+# CONFIG_SCSI_SYM53C8XX_2 is not set
+# CONFIG_SCSI_IPR is not set
+# CONFIG_SCSI_QLOGIC_1280 is not set
+# CONFIG_SCSI_QLA_FC is not set
+# CONFIG_SCSI_QLA_ISCSI is not set
+# CONFIG_SCSI_LPFC is not set
+# CONFIG_SCSI_DC395x is not set
+# CONFIG_SCSI_DC390T is not set
+# CONFIG_SCSI_DEBUG is not set
+# CONFIG_SCSI_PMCRAID is not set
+# CONFIG_SCSI_PM8001 is not set
+# CONFIG_SCSI_SRP is not set
+# CONFIG_SCSI_BFA_FC is not set
+# CONFIG_SCSI_CHELSIO_FCOE is not set
+# CONFIG_SCSI_DH is not set
+# CONFIG_SCSI_OSD_INITIATOR is not set
+CONFIG_ATA=y
+# CONFIG_ATA_NONSTANDARD is not set
+CONFIG_ATA_VERBOSE_ERROR=y
+CONFIG_ATA_ACPI=y
+# CONFIG_SATA_ZPODD is not set
+CONFIG_SATA_PMP=y
+
+#
+# Controllers with non-SFF native interface
+#
+CONFIG_SATA_AHCI=y
+# CONFIG_SATA_AHCI_PLATFORM is not set
+# CONFIG_SATA_INIC162X is not set
+# CONFIG_SATA_ACARD_AHCI is not set
+# CONFIG_SATA_SIL24 is not set
+CONFIG_ATA_SFF=y
+
+#
+# SFF controllers with custom DMA interface
+#
+# CONFIG_PDC_ADMA is not set
+# CONFIG_SATA_QSTOR is not set
+# CONFIG_SATA_SX4 is not set
+CONFIG_ATA_BMDMA=y
+
+#
+# SATA SFF controllers with BMDMA
+#
+CONFIG_ATA_PIIX=y
+# CONFIG_SATA_HIGHBANK is not set
+CONFIG_SATA_MV=y
+# CONFIG_SATA_NV is not set
+# CONFIG_SATA_PROMISE is not set
+# CONFIG_SATA_SIL is not set
+# CONFIG_SATA_SIS is not set
+# CONFIG_SATA_SVW is not set
+# CONFIG_SATA_ULI is not set
+# CONFIG_SATA_VIA is not set
+# CONFIG_SATA_VITESSE is not set
+
+#
+# PATA SFF controllers with BMDMA
+#
+# CONFIG_PATA_ALI is not set
+# CONFIG_PATA_AMD is not set
+# CONFIG_PATA_ARTOP is not set
+# CONFIG_PATA_ATIIXP is not set
+# CONFIG_PATA_ATP867X is not set
+# CONFIG_PATA_CMD64X is not set
+# CONFIG_PATA_CS5520 is not set
+# CONFIG_PATA_CS5530 is not set
+# CONFIG_PATA_CS5536 is not set
+# CONFIG_PATA_CYPRESS is not set
+# CONFIG_PATA_EFAR is not set
+# CONFIG_PATA_HPT366 is not set
+# CONFIG_PATA_HPT37X is not set
+# CONFIG_PATA_HPT3X2N is not set
+# CONFIG_PATA_HPT3X3 is not set
+# CONFIG_PATA_IT8213 is not set
+# CONFIG_PATA_IT821X is not set
+# CONFIG_PATA_JMICRON is not set
+# CONFIG_PATA_MARVELL is not set
+# CONFIG_PATA_NETCELL is not set
+# CONFIG_PATA_NINJA32 is not set
+# CONFIG_PATA_NS87415 is not set
+# CONFIG_PATA_OLDPIIX is not set
+# CONFIG_PATA_OPTIDMA is not set
+# CONFIG_PATA_PDC2027X is not set
+# CONFIG_PATA_PDC_OLD is not set
+# CONFIG_PATA_RADISYS is not set
+# CONFIG_PATA_RDC is not set
+# CONFIG_PATA_SC1200 is not set
+CONFIG_PATA_SCH=y
+# CONFIG_PATA_SERVERWORKS is not set
+# CONFIG_PATA_SIL680 is not set
+# CONFIG_PATA_SIS is not set
+# CONFIG_PATA_TOSHIBA is not set
+# CONFIG_PATA_TRIFLEX is not set
+# CONFIG_PATA_VIA is not set
+# CONFIG_PATA_WINBOND is not set
+
+#
+# PIO-only SFF controllers
+#
+# CONFIG_PATA_CMD640_PCI is not set
+# CONFIG_PATA_MPIIX is not set
+# CONFIG_PATA_NS87410 is not set
+# CONFIG_PATA_OPTI is not set
+# CONFIG_PATA_PLATFORM is not set
+# CONFIG_PATA_RZ1000 is not set
+
+#
+# Generic fallback / legacy drivers
+#
+# CONFIG_PATA_ACPI is not set
+# CONFIG_ATA_GENERIC is not set
+# CONFIG_PATA_LEGACY is not set
+CONFIG_MD=y
+CONFIG_BLK_DEV_MD=y
+CONFIG_MD_AUTODETECT=y
+# CONFIG_MD_LINEAR is not set
+CONFIG_MD_RAID0=y
+CONFIG_MD_RAID1=y
+# CONFIG_MD_RAID10 is not set
+CONFIG_MD_RAID456=y
+# CONFIG_MD_MULTIPATH is not set
+# CONFIG_MD_FAULTY is not set
+# CONFIG_BCACHE is not set
+CONFIG_BLK_DEV_DM=y
+# CONFIG_DM_DEBUG is not set
+CONFIG_DM_CRYPT=y
+# CONFIG_DM_SNAPSHOT is not set
+# CONFIG_DM_THIN_PROVISIONING is not set
+# CONFIG_DM_CACHE is not set
+CONFIG_DM_MIRROR=y
+# CONFIG_DM_RAID is not set
+# CONFIG_DM_LOG_USERSPACE is not set
+CONFIG_DM_ZERO=y
+# CONFIG_DM_MULTIPATH is not set
+# CONFIG_DM_DELAY is not set
+# CONFIG_DM_UEVENT is not set
+# CONFIG_DM_FLAKEY is not set
+# CONFIG_DM_VERITY is not set
+# CONFIG_TARGET_CORE is not set
+# CONFIG_FUSION is not set
+
+#
+# IEEE 1394 (FireWire) support
+#
+# CONFIG_FIREWIRE is not set
+# CONFIG_FIREWIRE_NOSY is not set
+# CONFIG_I2O is not set
+# CONFIG_MACINTOSH_DRIVERS is not set
+CONFIG_NETDEVICES=y
+CONFIG_NET_CORE=y
+CONFIG_BONDING=m
+# CONFIG_DUMMY is not set
+# CONFIG_EQUALIZER is not set
+# CONFIG_NET_FC is not set
+# CONFIG_MII is not set
+# CONFIG_IFB is not set
+# CONFIG_NET_TEAM is not set
+# CONFIG_MACVLAN is not set
+# CONFIG_VXLAN is not set
+# CONFIG_NETCONSOLE is not set
+# CONFIG_NETPOLL is not set
+# CONFIG_NET_POLL_CONTROLLER is not set
+# CONFIG_TUN is not set
+# CONFIG_VETH is not set
+# CONFIG_ARCNET is not set
+
+#
+# CAIF transport drivers
+#
+
+#
+# Distributed Switch Architecture drivers
+#
+# CONFIG_NET_DSA_MV88E6XXX is not set
+# CONFIG_NET_DSA_MV88E6060 is not set
+# CONFIG_NET_DSA_MV88E6XXX_NEED_PPU is not set
+# CONFIG_NET_DSA_MV88E6131 is not set
+# CONFIG_NET_DSA_MV88E6123_61_65 is not set
+CONFIG_ETHERNET=y
+CONFIG_NET_VENDOR_3COM=y
+# CONFIG_VORTEX is not set
+# CONFIG_TYPHOON is not set
+CONFIG_NET_VENDOR_ADAPTEC=y
+# CONFIG_ADAPTEC_STARFIRE is not set
+CONFIG_NET_VENDOR_ALTEON=y
+# CONFIG_ACENIC is not set
+CONFIG_NET_VENDOR_AMD=y
+# CONFIG_AMD8111_ETH is not set
+# CONFIG_PCNET32 is not set
+CONFIG_NET_VENDOR_ATHEROS=y
+# CONFIG_ATL2 is not set
+# CONFIG_ATL1 is not set
+# CONFIG_ATL1E is not set
+# CONFIG_ATL1C is not set
+# CONFIG_ALX is not set
+CONFIG_NET_CADENCE=y
+# CONFIG_ARM_AT91_ETHER is not set
+# CONFIG_MACB is not set
+CONFIG_NET_VENDOR_BROADCOM=y
+# CONFIG_B44 is not set
+# CONFIG_BNX2 is not set
+# CONFIG_CNIC is not set
+# CONFIG_TIGON3 is not set
+# CONFIG_BNX2X is not set
+CONFIG_NET_VENDOR_BROCADE=y
+# CONFIG_BNA is not set
+# CONFIG_NET_CALXEDA_XGMAC is not set
+CONFIG_NET_VENDOR_CHELSIO=y
+# CONFIG_CHELSIO_T1 is not set
+# CONFIG_CHELSIO_T3 is not set
+# CONFIG_CHELSIO_T4 is not set
+# CONFIG_CHELSIO_T4VF is not set
+CONFIG_NET_VENDOR_CISCO=y
+# CONFIG_ENIC is not set
+# CONFIG_DNET is not set
+CONFIG_NET_VENDOR_DEC=y
+# CONFIG_NET_TULIP is not set
+CONFIG_NET_VENDOR_DLINK=y
+# CONFIG_DL2K is not set
+# CONFIG_SUNDANCE is not set
+CONFIG_NET_VENDOR_EMULEX=y
+# CONFIG_BE2NET is not set
+CONFIG_NET_VENDOR_EXAR=y
+# CONFIG_S2IO is not set
+# CONFIG_VXGE is not set
+CONFIG_NET_VENDOR_HP=y
+# CONFIG_HP100 is not set
+CONFIG_NET_VENDOR_INTEL=y
+# CONFIG_E100 is not set
+CONFIG_E1000=y
+CONFIG_E1000E=m
+CONFIG_IGB=y
+CONFIG_IGB_HWMON=y
+# CONFIG_IGBVF is not set
+# CONFIG_IXGB is not set
+# CONFIG_IXGBE is not set
+# CONFIG_IXGBEVF is not set
+CONFIG_NET_VENDOR_I825XX=y
+# CONFIG_IP1000 is not set
+# CONFIG_JME is not set
+CONFIG_NET_VENDOR_MARVELL=y
+# CONFIG_MVMDIO is not set
+# CONFIG_SKGE is not set
+# CONFIG_SKY2 is not set
+CONFIG_NET_VENDOR_MELLANOX=y
+# CONFIG_MLX4_EN is not set
+# CONFIG_MLX4_CORE is not set
+CONFIG_NET_VENDOR_MICREL=y
+# CONFIG_KS8851_MLL is not set
+# CONFIG_KSZ884X_PCI is not set
+CONFIG_NET_VENDOR_MYRI=y
+# CONFIG_MYRI10GE is not set
+# CONFIG_FEALNX is not set
+CONFIG_NET_VENDOR_NATSEMI=y
+# CONFIG_NATSEMI is not set
+# CONFIG_NS83820 is not set
+CONFIG_NET_VENDOR_8390=y
+# CONFIG_NE2K_PCI is not set
+CONFIG_NET_VENDOR_NVIDIA=y
+# CONFIG_FORCEDETH is not set
+CONFIG_NET_VENDOR_OKI=y
+# CONFIG_PCH_GBE is not set
+# CONFIG_ETHOC is not set
+CONFIG_NET_PACKET_ENGINE=y
+# CONFIG_HAMACHI is not set
+# CONFIG_YELLOWFIN is not set
+CONFIG_NET_VENDOR_QLOGIC=y
+# CONFIG_QLA3XXX is not set
+# CONFIG_QLCNIC is not set
+# CONFIG_QLGE is not set
+# CONFIG_NETXEN_NIC is not set
+CONFIG_NET_VENDOR_REALTEK=y
+# CONFIG_8139CP is not set
+# CONFIG_8139TOO is not set
+# CONFIG_R8169 is not set
+CONFIG_NET_VENDOR_RDC=y
+# CONFIG_R6040 is not set
+CONFIG_NET_VENDOR_SEEQ=y
+CONFIG_NET_VENDOR_SILAN=y
+# CONFIG_SC92031 is not set
+CONFIG_NET_VENDOR_SIS=y
+# CONFIG_SIS900 is not set
+# CONFIG_SIS190 is not set
+# CONFIG_SFC is not set
+CONFIG_NET_VENDOR_SMSC=y
+# CONFIG_EPIC100 is not set
+# CONFIG_SMSC9420 is not set
+CONFIG_NET_VENDOR_STMICRO=y
+# CONFIG_STMMAC_ETH is not set
+CONFIG_NET_VENDOR_SUN=y
+# CONFIG_HAPPYMEAL is not set
+# CONFIG_SUNGEM is not set
+# CONFIG_CASSINI is not set
+# CONFIG_NIU is not set
+CONFIG_NET_VENDOR_TEHUTI=y
+# CONFIG_TEHUTI is not set
+CONFIG_NET_VENDOR_TI=y
+# CONFIG_TLAN is not set
+CONFIG_NET_VENDOR_VIA=y
+# CONFIG_VIA_RHINE is not set
+# CONFIG_VIA_VELOCITY is not set
+CONFIG_NET_VENDOR_WIZNET=y
+# CONFIG_WIZNET_W5100 is not set
+# CONFIG_WIZNET_W5300 is not set
+# CONFIG_FDDI is not set
+# CONFIG_HIPPI is not set
+# CONFIG_NET_SB1000 is not set
+CONFIG_PHYLIB=y
+
+#
+# MII PHY device drivers
+#
+# CONFIG_AT803X_PHY is not set
+# CONFIG_AMD_PHY is not set
+CONFIG_MARVELL_PHY=y
+CONFIG_DAVICOM_PHY=y
+CONFIG_QSEMI_PHY=y
+CONFIG_LXT_PHY=y
+CONFIG_CICADA_PHY=y
+CONFIG_VITESSE_PHY=y
+CONFIG_SMSC_PHY=y
+CONFIG_BROADCOM_PHY=y
+# CONFIG_BCM87XX_PHY is not set
+CONFIG_ICPLUS_PHY=y
+CONFIG_REALTEK_PHY=y
+CONFIG_NATIONAL_PHY=y
+CONFIG_STE10XP=y
+CONFIG_LSI_ET1011C_PHY=y
+# CONFIG_MICREL_PHY is not set
+CONFIG_FIXED_PHY=y
+CONFIG_MDIO_BITBANG=y
+# CONFIG_PPP is not set
+# CONFIG_SLIP is not set
+
+#
+# USB Network Adapters
+#
+# CONFIG_USB_CATC is not set
+# CONFIG_USB_KAWETH is not set
+# CONFIG_USB_PEGASUS is not set
+# CONFIG_USB_RTL8150 is not set
+# CONFIG_USB_RTL8152 is not set
+# CONFIG_USB_USBNET is not set
+# CONFIG_USB_HSO is not set
+# CONFIG_USB_IPHETH is not set
+# CONFIG_WLAN is not set
+
+#
+# Enable WiMAX (Networking options) to see the WiMAX drivers
+#
+# CONFIG_WAN is not set
+# CONFIG_VMXNET3 is not set
+# CONFIG_ISDN is not set
+
+#
+# Input device support
+#
+CONFIG_INPUT=y
+# CONFIG_INPUT_FF_MEMLESS is not set
+# CONFIG_INPUT_POLLDEV is not set
+# CONFIG_INPUT_SPARSEKMAP is not set
+# CONFIG_INPUT_MATRIXKMAP is not set
+
+#
+# Userland interfaces
+#
+CONFIG_INPUT_MOUSEDEV=y
+CONFIG_INPUT_MOUSEDEV_PSAUX=y
+CONFIG_INPUT_MOUSEDEV_SCREEN_X=1024
+CONFIG_INPUT_MOUSEDEV_SCREEN_Y=768
+# CONFIG_INPUT_JOYDEV is not set
+CONFIG_INPUT_EVDEV=y
+# CONFIG_INPUT_EVBUG is not set
+
+#
+# Input Device Drivers
+#
+CONFIG_INPUT_KEYBOARD=y
+# CONFIG_KEYBOARD_ADP5588 is not set
+# CONFIG_KEYBOARD_ADP5589 is not set
+CONFIG_KEYBOARD_ATKBD=y
+# CONFIG_KEYBOARD_QT1070 is not set
+# CONFIG_KEYBOARD_QT2160 is not set
+# CONFIG_KEYBOARD_LKKBD is not set
+# CONFIG_KEYBOARD_TCA6416 is not set
+# CONFIG_KEYBOARD_TCA8418 is not set
+# CONFIG_KEYBOARD_LM8333 is not set
+# CONFIG_KEYBOARD_MAX7359 is not set
+# CONFIG_KEYBOARD_MCS is not set
+# CONFIG_KEYBOARD_MPR121 is not set
+# CONFIG_KEYBOARD_NEWTON is not set
+# CONFIG_KEYBOARD_OPENCORES is not set
+# CONFIG_KEYBOARD_STOWAWAY is not set
+# CONFIG_KEYBOARD_SUNKBD is not set
+# CONFIG_KEYBOARD_XTKBD is not set
+CONFIG_INPUT_MOUSE=y
+CONFIG_MOUSE_PS2=y
+CONFIG_MOUSE_PS2_ALPS=y
+CONFIG_MOUSE_PS2_LOGIPS2PP=y
+CONFIG_MOUSE_PS2_SYNAPTICS=y
+CONFIG_MOUSE_PS2_CYPRESS=y
+CONFIG_MOUSE_PS2_LIFEBOOK=y
+CONFIG_MOUSE_PS2_TRACKPOINT=y
+CONFIG_MOUSE_PS2_ELANTECH=y
+CONFIG_MOUSE_PS2_SENTELIC=y
+# CONFIG_MOUSE_PS2_TOUCHKIT is not set
+# CONFIG_MOUSE_SERIAL is not set
+# CONFIG_MOUSE_APPLETOUCH is not set
+# CONFIG_MOUSE_BCM5974 is not set
+# CONFIG_MOUSE_CYAPA is not set
+# CONFIG_MOUSE_VSXXXAA is not set
+# CONFIG_MOUSE_SYNAPTICS_I2C is not set
+# CONFIG_MOUSE_SYNAPTICS_USB is not set
+CONFIG_INPUT_JOYSTICK=y
+# CONFIG_JOYSTICK_ANALOG is not set
+# CONFIG_JOYSTICK_A3D is not set
+# CONFIG_JOYSTICK_ADI is not set
+# CONFIG_JOYSTICK_COBRA is not set
+# CONFIG_JOYSTICK_GF2K is not set
+# CONFIG_JOYSTICK_GRIP is not set
+# CONFIG_JOYSTICK_GRIP_MP is not set
+# CONFIG_JOYSTICK_GUILLEMOT is not set
+# CONFIG_JOYSTICK_INTERACT is not set
+# CONFIG_JOYSTICK_SIDEWINDER is not set
+# CONFIG_JOYSTICK_TMDC is not set
+# CONFIG_JOYSTICK_IFORCE is not set
+# CONFIG_JOYSTICK_WARRIOR is not set
+# CONFIG_JOYSTICK_MAGELLAN is not set
+# CONFIG_JOYSTICK_SPACEORB is not set
+# CONFIG_JOYSTICK_SPACEBALL is not set
+# CONFIG_JOYSTICK_STINGER is not set
+# CONFIG_JOYSTICK_TWIDJOY is not set
+# CONFIG_JOYSTICK_ZHENHUA is not set
+# CONFIG_JOYSTICK_AS5011 is not set
+# CONFIG_JOYSTICK_JOYDUMP is not set
+# CONFIG_JOYSTICK_XPAD is not set
+CONFIG_INPUT_TABLET=y
+# CONFIG_TABLET_USB_ACECAD is not set
+# CONFIG_TABLET_USB_AIPTEK is not set
+# CONFIG_TABLET_USB_GTCO is not set
+# CONFIG_TABLET_USB_HANWANG is not set
+# CONFIG_TABLET_USB_KBTAB is not set
+# CONFIG_TABLET_USB_WACOM is not set
+CONFIG_INPUT_TOUCHSCREEN=y
+# CONFIG_TOUCHSCREEN_AD7879 is not set
+# CONFIG_TOUCHSCREEN_ATMEL_MXT is not set
+# CONFIG_TOUCHSCREEN_BU21013 is not set
+# CONFIG_TOUCHSCREEN_CYTTSP_CORE is not set
+# CONFIG_TOUCHSCREEN_DYNAPRO is not set
+# CONFIG_TOUCHSCREEN_HAMPSHIRE is not set
+# CONFIG_TOUCHSCREEN_EETI is not set
+# CONFIG_TOUCHSCREEN_FUJITSU is not set
+# CONFIG_TOUCHSCREEN_ILI210X is not set
+# CONFIG_TOUCHSCREEN_GUNZE is not set
+# CONFIG_TOUCHSCREEN_ELO is not set
+# CONFIG_TOUCHSCREEN_WACOM_W8001 is not set
+# CONFIG_TOUCHSCREEN_WACOM_I2C is not set
+# CONFIG_TOUCHSCREEN_MAX11801 is not set
+# CONFIG_TOUCHSCREEN_MCS5000 is not set
+# CONFIG_TOUCHSCREEN_MMS114 is not set
+# CONFIG_TOUCHSCREEN_MTOUCH is not set
+# CONFIG_TOUCHSCREEN_INEXIO is not set
+# CONFIG_TOUCHSCREEN_MK712 is not set
+# CONFIG_TOUCHSCREEN_PENMOUNT is not set
+# CONFIG_TOUCHSCREEN_EDT_FT5X06 is not set
+# CONFIG_TOUCHSCREEN_TOUCHRIGHT is not set
+# CONFIG_TOUCHSCREEN_TOUCHWIN is not set
+# CONFIG_TOUCHSCREEN_PIXCIR is not set
+# CONFIG_TOUCHSCREEN_USB_COMPOSITE is not set
+# CONFIG_TOUCHSCREEN_TOUCHIT213 is not set
+# CONFIG_TOUCHSCREEN_TSC_SERIO is not set
+# CONFIG_TOUCHSCREEN_TSC2007 is not set
+# CONFIG_TOUCHSCREEN_ST1232 is not set
+# CONFIG_TOUCHSCREEN_TPS6507X is not set
+CONFIG_INPUT_MISC=y
+# CONFIG_INPUT_AD714X is not set
+# CONFIG_INPUT_BMA150 is not set
+# CONFIG_INPUT_PCSPKR is not set
+# CONFIG_INPUT_MMA8450 is not set
+# CONFIG_INPUT_MPU3050 is not set
+# CONFIG_INPUT_ATLAS_BTNS is not set
+# CONFIG_INPUT_ATI_REMOTE2 is not set
+# CONFIG_INPUT_KEYSPAN_REMOTE is not set
+# CONFIG_INPUT_KXTJ9 is not set
+# CONFIG_INPUT_POWERMATE is not set
+# CONFIG_INPUT_YEALINK is not set
+# CONFIG_INPUT_CM109 is not set
+CONFIG_INPUT_UINPUT=y
+# CONFIG_INPUT_PCF8574 is not set
+# CONFIG_INPUT_ADXL34X is not set
+# CONFIG_INPUT_CMA3000 is not set
+
+#
+# Hardware I/O ports
+#
+CONFIG_SERIO=y
+CONFIG_SERIO_I8042=y
+CONFIG_SERIO_SERPORT=y
+# CONFIG_SERIO_CT82C710 is not set
+# CONFIG_SERIO_PCIPS2 is not set
+CONFIG_SERIO_LIBPS2=y
+# CONFIG_SERIO_RAW is not set
+# CONFIG_SERIO_ALTERA_PS2 is not set
+# CONFIG_SERIO_PS2MULT is not set
+# CONFIG_SERIO_ARC_PS2 is not set
+# CONFIG_GAMEPORT is not set
+
+#
+# Character devices
+#
+CONFIG_TTY=y
+CONFIG_VT=y
+CONFIG_CONSOLE_TRANSLATIONS=y
+CONFIG_VT_CONSOLE=y
+CONFIG_VT_CONSOLE_SLEEP=y
+CONFIG_HW_CONSOLE=y
+CONFIG_VT_HW_CONSOLE_BINDING=y
+CONFIG_UNIX98_PTYS=y
+CONFIG_DEVPTS_MULTIPLE_INSTANCES=y
+CONFIG_LEGACY_PTYS=y
+CONFIG_LEGACY_PTY_COUNT=0
+CONFIG_SERIAL_NONSTANDARD=y
+# CONFIG_ROCKETPORT is not set
+# CONFIG_CYCLADES is not set
+# CONFIG_MOXA_INTELLIO is not set
+# CONFIG_MOXA_SMARTIO is not set
+# CONFIG_SYNCLINKMP is not set
+# CONFIG_SYNCLINK_GT is not set
+# CONFIG_NOZOMI is not set
+# CONFIG_ISI is not set
+# CONFIG_N_HDLC is not set
+# CONFIG_N_GSM is not set
+# CONFIG_TRACE_SINK is not set
+# CONFIG_DEVKMEM is not set
+CONFIG_STALDRV=y
+
+#
+# Serial drivers
+#
+CONFIG_SERIAL_8250=y
+CONFIG_SERIAL_8250_DEPRECATED_OPTIONS=y
+CONFIG_SERIAL_8250_PNP=y
+CONFIG_SERIAL_8250_CONSOLE=y
+CONFIG_FIX_EARLYCON_MEM=y
+CONFIG_SERIAL_8250_PCI=y
+CONFIG_SERIAL_8250_NR_UARTS=48
+CONFIG_SERIAL_8250_RUNTIME_UARTS=32
+CONFIG_SERIAL_8250_EXTENDED=y
+CONFIG_SERIAL_8250_MANY_PORTS=y
+CONFIG_SERIAL_8250_SHARE_IRQ=y
+# CONFIG_SERIAL_8250_DETECT_IRQ is not set
+CONFIG_SERIAL_8250_RSA=y
+# CONFIG_SERIAL_8250_DW is not set
+
+#
+# Non-8250 serial port support
+#
+# CONFIG_SERIAL_MFD_HSU is not set
+CONFIG_SERIAL_CORE=y
+CONFIG_SERIAL_CORE_CONSOLE=y
+# CONFIG_SERIAL_JSM is not set
+# CONFIG_SERIAL_SCCNXP is not set
+# CONFIG_SERIAL_TIMBERDALE is not set
+# CONFIG_SERIAL_ALTERA_JTAGUART is not set
+# CONFIG_SERIAL_ALTERA_UART is not set
+# CONFIG_SERIAL_PCH_UART is not set
+# CONFIG_SERIAL_ARC is not set
+# CONFIG_SERIAL_RP2 is not set
+CONFIG_TTY_PRINTK=y
+# CONFIG_IPMI_HANDLER is not set
+CONFIG_HW_RANDOM=y
+# CONFIG_HW_RANDOM_TIMERIOMEM is not set
+CONFIG_HW_RANDOM_INTEL=y
+CONFIG_HW_RANDOM_AMD=y
+CONFIG_HW_RANDOM_VIA=y
+# CONFIG_NVRAM is not set
+# CONFIG_R3964 is not set
+# CONFIG_APPLICOM is not set
+# CONFIG_MWAVE is not set
+# CONFIG_RAW_DRIVER is not set
+CONFIG_HPET=y
+CONFIG_HPET_MMAP=y
+# CONFIG_HANGCHECK_TIMER is not set
+# CONFIG_TCG_TPM is not set
+# CONFIG_TELCLOCK is not set
+CONFIG_DEVPORT=y
+CONFIG_I2C=y
+CONFIG_I2C_BOARDINFO=y
+CONFIG_I2C_COMPAT=y
+CONFIG_I2C_CHARDEV=y
+CONFIG_I2C_MUX=y
+
+#
+# Multiplexer I2C Chip support
+#
+CONFIG_I2C_MUX_PCA9541=y
+CONFIG_I2C_MUX_PCA954x=y
+CONFIG_I2C_HELPER_AUTO=y
+CONFIG_I2C_SMBUS=y
+CONFIG_I2C_ALGOBIT=y
+CONFIG_I2C_ALGOPCA=y
+
+#
+# I2C Hardware Bus support
+#
+
+#
+# PC SMBus host controller drivers
+#
+CONFIG_I2C_ALI1535=y
+CONFIG_I2C_ALI1563=y
+CONFIG_I2C_ALI15X3=y
+CONFIG_I2C_AMD756=y
+CONFIG_I2C_AMD756_S4882=y
+CONFIG_I2C_AMD8111=y
+CONFIG_I2C_I801=y
+CONFIG_I2C_ISCH=y
+# CONFIG_I2C_ISMT is not set
+CONFIG_I2C_PIIX4=y
+CONFIG_I2C_NFORCE2=y
+CONFIG_I2C_NFORCE2_S4985=y
+CONFIG_I2C_SIS5595=y
+CONFIG_I2C_SIS630=y
+CONFIG_I2C_SIS96X=y
+CONFIG_I2C_VIA=y
+CONFIG_I2C_VIAPRO=y
+
+#
+# ACPI drivers
+#
+CONFIG_I2C_SCMI=y
+
+#
+# I2C system bus drivers (mostly embedded / system-on-chip)
+#
+# CONFIG_I2C_DESIGNWARE_PCI is not set
+CONFIG_I2C_EG20T=y
+CONFIG_I2C_INTEL_MID=y
+CONFIG_I2C_OCORES=y
+CONFIG_I2C_PCA_PLATFORM=y
+# CONFIG_I2C_PXA_PCI is not set
+CONFIG_I2C_SIMTEC=y
+CONFIG_I2C_XILINX=y
+
+#
+# External I2C/SMBus adapter drivers
+#
+CONFIG_I2C_DIOLAN_U2C=m
+CONFIG_I2C_PARPORT_LIGHT=y
+CONFIG_I2C_TAOS_EVM=y
+CONFIG_I2C_TINY_USB=m
+
+#
+# Other I2C/SMBus bus drivers
+#
+# CONFIG_I2C_STUB is not set
+CONFIG_I2C_DEBUG_CORE=y
+CONFIG_I2C_DEBUG_ALGO=y
+CONFIG_I2C_DEBUG_BUS=y
+# CONFIG_SPI is not set
+
+#
+# Qualcomm MSM SSBI bus support
+#
+# CONFIG_SSBI is not set
+# CONFIG_HSI is not set
+
+#
+# PPS support
+#
+CONFIG_PPS=y
+# CONFIG_PPS_DEBUG is not set
+
+#
+# PPS clients support
+#
+# CONFIG_PPS_CLIENT_KTIMER is not set
+# CONFIG_PPS_CLIENT_LDISC is not set
+# CONFIG_PPS_CLIENT_GPIO is not set
+
+#
+# PPS generators support
+#
+
+#
+# PTP clock support
+#
+CONFIG_PTP_1588_CLOCK=y
+
+#
+# Enable PHYLIB and NETWORK_PHY_TIMESTAMPING to see the additional clocks.
+#
+# CONFIG_PTP_1588_CLOCK_PCH is not set
+CONFIG_ARCH_WANT_OPTIONAL_GPIOLIB=y
+CONFIG_GPIO_DEVRES=y
+# CONFIG_GPIOLIB is not set
+# CONFIG_W1 is not set
+CONFIG_POWER_SUPPLY=y
+# CONFIG_POWER_SUPPLY_DEBUG is not set
+# CONFIG_PDA_POWER is not set
+# CONFIG_TEST_POWER is not set
+# CONFIG_BATTERY_DS2780 is not set
+# CONFIG_BATTERY_DS2781 is not set
+# CONFIG_BATTERY_DS2782 is not set
+# CONFIG_BATTERY_SBS is not set
+# CONFIG_BATTERY_BQ27x00 is not set
+# CONFIG_BATTERY_MAX17040 is not set
+# CONFIG_BATTERY_MAX17042 is not set
+# CONFIG_CHARGER_MAX8903 is not set
+# CONFIG_CHARGER_LP8727 is not set
+# CONFIG_CHARGER_BQ2415X is not set
+# CONFIG_CHARGER_SMB347 is not set
+# CONFIG_BATTERY_GOLDFISH is not set
+# CONFIG_POWER_RESET is not set
+# CONFIG_POWER_AVS is not set
+CONFIG_HWMON=y
+# CONFIG_HWMON_VID is not set
+# CONFIG_HWMON_DEBUG_CHIP is not set
+
+#
+# Native drivers
+#
+# CONFIG_SENSORS_ABITUGURU is not set
+# CONFIG_SENSORS_ABITUGURU3 is not set
+# CONFIG_SENSORS_AD7414 is not set
+# CONFIG_SENSORS_AD7418 is not set
+# CONFIG_SENSORS_ADM1021 is not set
+# CONFIG_SENSORS_ADM1025 is not set
+# CONFIG_SENSORS_ADM1026 is not set
+# CONFIG_SENSORS_ADM1029 is not set
+# CONFIG_SENSORS_ADM1031 is not set
+# CONFIG_SENSORS_ADM9240 is not set
+# CONFIG_SENSORS_ADT7410 is not set
+# CONFIG_SENSORS_ADT7411 is not set
+# CONFIG_SENSORS_ADT7462 is not set
+# CONFIG_SENSORS_ADT7470 is not set
+# CONFIG_SENSORS_ADT7475 is not set
+# CONFIG_SENSORS_ASC7621 is not set
+# CONFIG_SENSORS_K8TEMP is not set
+# CONFIG_SENSORS_K10TEMP is not set
+# CONFIG_SENSORS_FAM15H_POWER is not set
+# CONFIG_SENSORS_ASB100 is not set
+# CONFIG_SENSORS_ATXP1 is not set
+# CONFIG_SENSORS_DS620 is not set
+# CONFIG_SENSORS_DS1621 is not set
+# CONFIG_SENSORS_I5K_AMB is not set
+# CONFIG_SENSORS_F71805F is not set
+# CONFIG_SENSORS_F71882FG is not set
+# CONFIG_SENSORS_F75375S is not set
+# CONFIG_SENSORS_FSCHMD is not set
+# CONFIG_SENSORS_G760A is not set
+# CONFIG_SENSORS_GL518SM is not set
+# CONFIG_SENSORS_GL520SM is not set
+# CONFIG_SENSORS_HIH6130 is not set
+# CONFIG_SENSORS_CORETEMP is not set
+# CONFIG_SENSORS_IT87 is not set
+# CONFIG_SENSORS_JC42 is not set
+# CONFIG_SENSORS_LINEAGE is not set
+# CONFIG_SENSORS_LM63 is not set
+# CONFIG_SENSORS_LM73 is not set
+# CONFIG_SENSORS_LM75 is not set
+# CONFIG_SENSORS_LM77 is not set
+# CONFIG_SENSORS_LM78 is not set
+# CONFIG_SENSORS_LM80 is not set
+# CONFIG_SENSORS_LM83 is not set
+# CONFIG_SENSORS_LM85 is not set
+# CONFIG_SENSORS_LM87 is not set
+# CONFIG_SENSORS_LM90 is not set
+# CONFIG_SENSORS_LM92 is not set
+# CONFIG_SENSORS_LM93 is not set
+# CONFIG_SENSORS_LTC4151 is not set
+# CONFIG_SENSORS_LTC4215 is not set
+# CONFIG_SENSORS_LTC4245 is not set
+# CONFIG_SENSORS_LTC4261 is not set
+# CONFIG_SENSORS_LM95234 is not set
+# CONFIG_SENSORS_LM95241 is not set
+# CONFIG_SENSORS_LM95245 is not set
+# CONFIG_SENSORS_MAX16065 is not set
+# CONFIG_SENSORS_MAX1619 is not set
+# CONFIG_SENSORS_MAX1668 is not set
+# CONFIG_SENSORS_MAX197 is not set
+# CONFIG_SENSORS_MAX6639 is not set
+# CONFIG_SENSORS_MAX6642 is not set
+# CONFIG_SENSORS_MAX6650 is not set
+# CONFIG_SENSORS_MAX6697 is not set
+# CONFIG_SENSORS_MCP3021 is not set
+# CONFIG_SENSORS_NCT6775 is not set
+# CONFIG_SENSORS_NTC_THERMISTOR is not set
+# CONFIG_SENSORS_PC87360 is not set
+# CONFIG_SENSORS_PC87427 is not set
+# CONFIG_SENSORS_PCF8591 is not set
+# CONFIG_PMBUS is not set
+# CONFIG_SENSORS_SHT21 is not set
+# CONFIG_SENSORS_SIS5595 is not set
+# CONFIG_SENSORS_SMM665 is not set
+# CONFIG_SENSORS_DME1737 is not set
+# CONFIG_SENSORS_EMC1403 is not set
+# CONFIG_SENSORS_EMC2103 is not set
+# CONFIG_SENSORS_EMC6W201 is not set
+# CONFIG_SENSORS_SMSC47M1 is not set
+# CONFIG_SENSORS_SMSC47M192 is not set
+# CONFIG_SENSORS_SMSC47B397 is not set
+# CONFIG_SENSORS_SCH56XX_COMMON is not set
+# CONFIG_SENSORS_ADS1015 is not set
+# CONFIG_SENSORS_ADS7828 is not set
+# CONFIG_SENSORS_AMC6821 is not set
+# CONFIG_SENSORS_INA209 is not set
+# CONFIG_SENSORS_INA2XX is not set
+# CONFIG_SENSORS_THMC50 is not set
+# CONFIG_SENSORS_TMP102 is not set
+# CONFIG_SENSORS_TMP401 is not set
+# CONFIG_SENSORS_TMP421 is not set
+# CONFIG_SENSORS_VIA_CPUTEMP is not set
+# CONFIG_SENSORS_VIA686A is not set
+# CONFIG_SENSORS_VT1211 is not set
+# CONFIG_SENSORS_VT8231 is not set
+# CONFIG_SENSORS_W83781D is not set
+# CONFIG_SENSORS_W83791D is not set
+# CONFIG_SENSORS_W83792D is not set
+# CONFIG_SENSORS_W83793 is not set
+# CONFIG_SENSORS_W83795 is not set
+# CONFIG_SENSORS_W83L785TS is not set
+# CONFIG_SENSORS_W83L786NG is not set
+# CONFIG_SENSORS_W83627HF is not set
+# CONFIG_SENSORS_W83627EHF is not set
+# CONFIG_SENSORS_APPLESMC is not set
+
+#
+# ACPI drivers
+#
+# CONFIG_SENSORS_ACPI_POWER is not set
+# CONFIG_SENSORS_ATK0110 is not set
+CONFIG_THERMAL=y
+CONFIG_THERMAL_HWMON=y
+CONFIG_THERMAL_DEFAULT_GOV_STEP_WISE=y
+# CONFIG_THERMAL_DEFAULT_GOV_FAIR_SHARE is not set
+# CONFIG_THERMAL_DEFAULT_GOV_USER_SPACE is not set
+# CONFIG_THERMAL_GOV_FAIR_SHARE is not set
+CONFIG_THERMAL_GOV_STEP_WISE=y
+# CONFIG_THERMAL_GOV_USER_SPACE is not set
+# CONFIG_CPU_THERMAL is not set
+# CONFIG_THERMAL_EMULATION is not set
+# CONFIG_INTEL_POWERCLAMP is not set
+# CONFIG_WATCHDOG is not set
+CONFIG_SSB_POSSIBLE=y
+
+#
+# Sonics Silicon Backplane
+#
+# CONFIG_SSB is not set
+CONFIG_BCMA_POSSIBLE=y
+
+#
+# Broadcom specific AMBA
+#
+# CONFIG_BCMA is not set
+
+#
+# Multifunction device drivers
+#
+CONFIG_MFD_CORE=y
+# CONFIG_MFD_CS5535 is not set
+# CONFIG_MFD_AS3711 is not set
+# CONFIG_PMIC_ADP5520 is not set
+# CONFIG_MFD_CROS_EC is not set
+# CONFIG_PMIC_DA903X is not set
+# CONFIG_MFD_DA9052_I2C is not set
+# CONFIG_MFD_DA9055 is not set
+# CONFIG_MFD_MC13XXX_I2C is not set
+# CONFIG_HTC_PASIC3 is not set
+# CONFIG_LPC_ICH is not set
+CONFIG_LPC_SCH=y
+# CONFIG_MFD_JANZ_CMODIO is not set
+# CONFIG_MFD_88PM800 is not set
+# CONFIG_MFD_88PM805 is not set
+# CONFIG_MFD_88PM860X is not set
+# CONFIG_MFD_MAX77686 is not set
+# CONFIG_MFD_MAX77693 is not set
+# CONFIG_MFD_MAX8907 is not set
+# CONFIG_MFD_MAX8925 is not set
+# CONFIG_MFD_MAX8997 is not set
+# CONFIG_MFD_MAX8998 is not set
+# CONFIG_MFD_VIPERBOARD is not set
+# CONFIG_MFD_RETU is not set
+# CONFIG_MFD_PCF50633 is not set
+# CONFIG_MFD_RDC321X is not set
+# CONFIG_MFD_RTSX_PCI is not set
+# CONFIG_MFD_RC5T583 is not set
+# CONFIG_MFD_SEC_CORE is not set
+# CONFIG_MFD_SI476X_CORE is not set
+# CONFIG_MFD_SM501 is not set
+# CONFIG_MFD_SMSC is not set
+# CONFIG_ABX500_CORE is not set
+# CONFIG_MFD_STMPE is not set
+# CONFIG_MFD_SYSCON is not set
+# CONFIG_MFD_TI_AM335X_TSCADC is not set
+# CONFIG_MFD_LP8788 is not set
+# CONFIG_MFD_PALMAS is not set
+# CONFIG_TPS6105X is not set
+# CONFIG_TPS6507X is not set
+# CONFIG_MFD_TPS65090 is not set
+# CONFIG_MFD_TPS65217 is not set
+# CONFIG_MFD_TPS6586X is not set
+# CONFIG_MFD_TPS80031 is not set
+# CONFIG_TWL4030_CORE is not set
+# CONFIG_TWL6040_CORE is not set
+# CONFIG_MFD_WL1273_CORE is not set
+# CONFIG_MFD_LM3533 is not set
+# CONFIG_MFD_TC3589X is not set
+# CONFIG_MFD_TMIO is not set
+# CONFIG_MFD_VX855 is not set
+# CONFIG_MFD_ARIZONA_I2C is not set
+# CONFIG_MFD_WM8400 is not set
+# CONFIG_MFD_WM831X_I2C is not set
+# CONFIG_MFD_WM8350_I2C is not set
+# CONFIG_MFD_WM8994 is not set
+# CONFIG_REGULATOR is not set
+# CONFIG_MEDIA_SUPPORT is not set
+
+#
+# Graphics support
+#
+CONFIG_AGP=y
+CONFIG_AGP_AMD64=y
+CONFIG_AGP_INTEL=y
+# CONFIG_AGP_SIS is not set
+CONFIG_AGP_VIA=y
+CONFIG_VGA_ARB=y
+CONFIG_VGA_ARB_MAX_GPUS=16
+CONFIG_VGA_SWITCHEROO=y
+CONFIG_DRM=y
+CONFIG_DRM_KMS_HELPER=y
+# CONFIG_DRM_LOAD_EDID_FIRMWARE is not set
+
+#
+# I2C encoder or helper chips
+#
+# CONFIG_DRM_I2C_CH7006 is not set
+# CONFIG_DRM_I2C_SIL164 is not set
+# CONFIG_DRM_I2C_NXP_TDA998X is not set
+# CONFIG_DRM_TDFX is not set
+# CONFIG_DRM_R128 is not set
+# CONFIG_DRM_RADEON is not set
+# CONFIG_DRM_NOUVEAU is not set
+# CONFIG_DRM_I810 is not set
+CONFIG_DRM_I915=y
+# CONFIG_DRM_I915_KMS is not set
+# CONFIG_DRM_MGA is not set
+# CONFIG_DRM_SIS is not set
+# CONFIG_DRM_VIA is not set
+# CONFIG_DRM_SAVAGE is not set
+# CONFIG_DRM_VMWGFX is not set
+# CONFIG_DRM_GMA500 is not set
+# CONFIG_DRM_UDL is not set
+# CONFIG_DRM_AST is not set
+# CONFIG_DRM_MGAG200 is not set
+# CONFIG_DRM_CIRRUS_QEMU is not set
+# CONFIG_DRM_QXL is not set
+# CONFIG_VGASTATE is not set
+CONFIG_VIDEO_OUTPUT_CONTROL=y
+CONFIG_HDMI=y
+CONFIG_FB=y
+CONFIG_FIRMWARE_EDID=y
+# CONFIG_FB_DDC is not set
+# CONFIG_FB_BOOT_VESA_SUPPORT is not set
+CONFIG_FB_CFB_FILLRECT=y
+CONFIG_FB_CFB_COPYAREA=y
+CONFIG_FB_CFB_IMAGEBLIT=y
+# CONFIG_FB_CFB_REV_PIXELS_IN_BYTE is not set
+# CONFIG_FB_SYS_FILLRECT is not set
+# CONFIG_FB_SYS_COPYAREA is not set
+# CONFIG_FB_SYS_IMAGEBLIT is not set
+# CONFIG_FB_FOREIGN_ENDIAN is not set
+# CONFIG_FB_SYS_FOPS is not set
+# CONFIG_FB_SVGALIB is not set
+# CONFIG_FB_MACMODES is not set
+# CONFIG_FB_BACKLIGHT is not set
+CONFIG_FB_MODE_HELPERS=y
+CONFIG_FB_TILEBLITTING=y
+
+#
+# Frame buffer hardware drivers
+#
+# CONFIG_FB_CIRRUS is not set
+# CONFIG_FB_PM2 is not set
+# CONFIG_FB_CYBER2000 is not set
+# CONFIG_FB_ARC is not set
+CONFIG_FB_ASILIANT=y
+CONFIG_FB_IMSTT=y
+# CONFIG_FB_VGA16 is not set
+# CONFIG_FB_UVESA is not set
+# CONFIG_FB_VESA is not set
+CONFIG_FB_EFI=y
+# CONFIG_FB_N411 is not set
+# CONFIG_FB_HGA is not set
+# CONFIG_FB_S1D13XXX is not set
+# CONFIG_FB_NVIDIA is not set
+# CONFIG_FB_RIVA is not set
+# CONFIG_FB_I740 is not set
+# CONFIG_FB_LE80578 is not set
+# CONFIG_FB_MATROX is not set
+# CONFIG_FB_RADEON is not set
+# CONFIG_FB_ATY128 is not set
+# CONFIG_FB_ATY is not set
+# CONFIG_FB_S3 is not set
+# CONFIG_FB_SAVAGE is not set
+# CONFIG_FB_SIS is not set
+# CONFIG_FB_VIA is not set
+# CONFIG_FB_NEOMAGIC is not set
+# CONFIG_FB_KYRO is not set
+# CONFIG_FB_3DFX is not set
+# CONFIG_FB_VOODOO1 is not set
+# CONFIG_FB_VT8623 is not set
+# CONFIG_FB_TRIDENT is not set
+# CONFIG_FB_ARK is not set
+# CONFIG_FB_PM3 is not set
+# CONFIG_FB_CARMINE is not set
+CONFIG_FB_GEODE=y
+# CONFIG_FB_GEODE_LX is not set
+# CONFIG_FB_GEODE_GX is not set
+# CONFIG_FB_GEODE_GX1 is not set
+# CONFIG_FB_TMIO is not set
+# CONFIG_FB_SMSCUFX is not set
+# CONFIG_FB_UDL is not set
+# CONFIG_FB_GOLDFISH is not set
+# CONFIG_FB_VIRTUAL is not set
+# CONFIG_FB_METRONOME is not set
+# CONFIG_FB_MB862XX is not set
+# CONFIG_FB_BROADSHEET is not set
+# CONFIG_FB_AUO_K190X is not set
+# CONFIG_EXYNOS_VIDEO is not set
+CONFIG_BACKLIGHT_LCD_SUPPORT=y
+CONFIG_LCD_CLASS_DEVICE=m
+# CONFIG_LCD_PLATFORM is not set
+CONFIG_BACKLIGHT_CLASS_DEVICE=y
+CONFIG_BACKLIGHT_GENERIC=y
+# CONFIG_BACKLIGHT_APPLE is not set
+# CONFIG_BACKLIGHT_SAHARA is not set
+# CONFIG_BACKLIGHT_ADP8860 is not set
+# CONFIG_BACKLIGHT_ADP8870 is not set
+# CONFIG_BACKLIGHT_LM3630 is not set
+# CONFIG_BACKLIGHT_LM3639 is not set
+# CONFIG_BACKLIGHT_LP855X is not set
+
+#
+# Console display driver support
+#
+CONFIG_VGA_CONSOLE=y
+# CONFIG_VGACON_SOFT_SCROLLBACK is not set
+CONFIG_DUMMY_CONSOLE=y
+CONFIG_FRAMEBUFFER_CONSOLE=y
+CONFIG_FRAMEBUFFER_CONSOLE_DETECT_PRIMARY=y
+# CONFIG_FRAMEBUFFER_CONSOLE_ROTATION is not set
+# CONFIG_FONTS is not set
+CONFIG_FONT_8x8=y
+CONFIG_FONT_8x16=y
+# CONFIG_LOGO is not set
+# CONFIG_SOUND is not set
+
+#
+# HID support
+#
+CONFIG_HID=y
+# CONFIG_HID_BATTERY_STRENGTH is not set
+CONFIG_HIDRAW=y
+# CONFIG_UHID is not set
+CONFIG_HID_GENERIC=y
+
+#
+# Special HID drivers
+#
+# CONFIG_HID_A4TECH is not set
+# CONFIG_HID_ACRUX is not set
+# CONFIG_HID_APPLE is not set
+# CONFIG_HID_APPLEIR is not set
+# CONFIG_HID_AUREAL is not set
+# CONFIG_HID_BELKIN is not set
+# CONFIG_HID_CHERRY is not set
+# CONFIG_HID_CHICONY is not set
+# CONFIG_HID_CYPRESS is not set
+# CONFIG_HID_DRAGONRISE is not set
+# CONFIG_HID_EMS_FF is not set
+# CONFIG_HID_ELECOM is not set
+# CONFIG_HID_EZKEY is not set
+# CONFIG_HID_HOLTEK is not set
+# CONFIG_HID_KEYTOUCH is not set
+# CONFIG_HID_KYE is not set
+# CONFIG_HID_UCLOGIC is not set
+# CONFIG_HID_WALTOP is not set
+# CONFIG_HID_GYRATION is not set
+# CONFIG_HID_ICADE is not set
+# CONFIG_HID_TWINHAN is not set
+# CONFIG_HID_KENSINGTON is not set
+# CONFIG_HID_LCPOWER is not set
+# CONFIG_HID_LENOVO_TPKBD is not set
+# CONFIG_HID_LOGITECH is not set
+# CONFIG_HID_MAGICMOUSE is not set
+# CONFIG_HID_MICROSOFT is not set
+# CONFIG_HID_MONTEREY is not set
+# CONFIG_HID_MULTITOUCH is not set
+# CONFIG_HID_NTRIG is not set
+# CONFIG_HID_ORTEK is not set
+# CONFIG_HID_PANTHERLORD is not set
+# CONFIG_HID_PETALYNX is not set
+# CONFIG_HID_PICOLCD is not set
+# CONFIG_HID_PRIMAX is not set
+# CONFIG_HID_PS3REMOTE is not set
+# CONFIG_HID_ROCCAT is not set
+# CONFIG_HID_SAITEK is not set
+# CONFIG_HID_SAMSUNG is not set
+# CONFIG_HID_SONY is not set
+# CONFIG_HID_SPEEDLINK is not set
+# CONFIG_HID_STEELSERIES is not set
+# CONFIG_HID_SUNPLUS is not set
+# CONFIG_HID_GREENASIA is not set
+# CONFIG_HID_SMARTJOYPLUS is not set
+# CONFIG_HID_TIVO is not set
+# CONFIG_HID_TOPSEED is not set
+# CONFIG_HID_THRUSTMASTER is not set
+# CONFIG_HID_ZEROPLUS is not set
+# CONFIG_HID_ZYDACRON is not set
+# CONFIG_HID_SENSOR_HUB is not set
+
+#
+# USB HID support
+#
+CONFIG_USB_HID=m
+CONFIG_HID_PID=y
+CONFIG_USB_HIDDEV=y
+
+#
+# USB HID Boot Protocol drivers
+#
+# CONFIG_USB_KBD is not set
+# CONFIG_USB_MOUSE is not set
+
+#
+# I2C HID support
+#
+# CONFIG_I2C_HID is not set
+CONFIG_USB_ARCH_HAS_OHCI=y
+CONFIG_USB_ARCH_HAS_EHCI=y
+CONFIG_USB_ARCH_HAS_XHCI=y
+CONFIG_USB_SUPPORT=y
+CONFIG_USB_COMMON=m
+CONFIG_USB_ARCH_HAS_HCD=y
+CONFIG_USB=m
+# CONFIG_USB_DEBUG is not set
+CONFIG_USB_ANNOUNCE_NEW_DEVICES=y
+
+#
+# Miscellaneous USB options
+#
+CONFIG_USB_DEFAULT_PERSIST=y
+# CONFIG_USB_DYNAMIC_MINORS is not set
+# CONFIG_USB_OTG is not set
+# CONFIG_USB_OTG_WHITELIST is not set
+# CONFIG_USB_OTG_BLACKLIST_HUB is not set
+# CONFIG_USB_MON is not set
+# CONFIG_USB_WUSB_CBAF is not set
+
+#
+# USB Host Controller Drivers
+#
+# CONFIG_USB_C67X00_HCD is not set
+CONFIG_USB_XHCI_HCD=m
+# CONFIG_USB_XHCI_HCD_DEBUGGING is not set
+CONFIG_USB_EHCI_HCD=m
+# CONFIG_USB_EHCI_ROOT_HUB_TT is not set
+# CONFIG_USB_EHCI_TT_NEWSCHED is not set
+CONFIG_USB_EHCI_PCI=m
+# CONFIG_USB_EHCI_HCD_PLATFORM is not set
+# CONFIG_USB_OXU210HP_HCD is not set
+# CONFIG_USB_ISP116X_HCD is not set
+# CONFIG_USB_ISP1760_HCD is not set
+# CONFIG_USB_ISP1362_HCD is not set
+CONFIG_USB_OHCI_HCD=m
+# CONFIG_USB_OHCI_HCD_PLATFORM is not set
+# CONFIG_USB_OHCI_BIG_ENDIAN_DESC is not set
+# CONFIG_USB_OHCI_BIG_ENDIAN_MMIO is not set
+CONFIG_USB_OHCI_LITTLE_ENDIAN=y
+CONFIG_USB_UHCI_HCD=m
+# CONFIG_USB_SL811_HCD is not set
+# CONFIG_USB_R8A66597_HCD is not set
+
+#
+# USB Device Class drivers
+#
+# CONFIG_USB_ACM is not set
+CONFIG_USB_PRINTER=m
+# CONFIG_USB_WDM is not set
+# CONFIG_USB_TMC is not set
+
+#
+# NOTE: USB_STORAGE depends on SCSI but BLK_DEV_SD may
+#
+
+#
+# also be needed; see USB_STORAGE Help for more info
+#
+CONFIG_USB_STORAGE=m
+# CONFIG_USB_STORAGE_DEBUG is not set
+# CONFIG_USB_STORAGE_REALTEK is not set
+# CONFIG_USB_STORAGE_DATAFAB is not set
+# CONFIG_USB_STORAGE_FREECOM is not set
+# CONFIG_USB_STORAGE_ISD200 is not set
+# CONFIG_USB_STORAGE_USBAT is not set
+# CONFIG_USB_STORAGE_SDDR09 is not set
+# CONFIG_USB_STORAGE_SDDR55 is not set
+# CONFIG_USB_STORAGE_JUMPSHOT is not set
+# CONFIG_USB_STORAGE_ALAUDA is not set
+# CONFIG_USB_STORAGE_ONETOUCH is not set
+# CONFIG_USB_STORAGE_KARMA is not set
+# CONFIG_USB_STORAGE_CYPRESS_ATACB is not set
+# CONFIG_USB_STORAGE_ENE_UB6250 is not set
+
+#
+# USB Imaging devices
+#
+# CONFIG_USB_MDC800 is not set
+# CONFIG_USB_MICROTEK is not set
+# CONFIG_USB_DWC3 is not set
+# CONFIG_USB_CHIPIDEA is not set
+
+#
+# USB port drivers
+#
+# CONFIG_USB_SERIAL is not set
+
+#
+# USB Miscellaneous drivers
+#
+# CONFIG_USB_EMI62 is not set
+# CONFIG_USB_EMI26 is not set
+# CONFIG_USB_ADUTUX is not set
+# CONFIG_USB_SEVSEG is not set
+# CONFIG_USB_RIO500 is not set
+# CONFIG_USB_LEGOTOWER is not set
+# CONFIG_USB_LCD is not set
+# CONFIG_USB_LED is not set
+# CONFIG_USB_CYPRESS_CY7C63 is not set
+# CONFIG_USB_CYTHERM is not set
+# CONFIG_USB_IDMOUSE is not set
+# CONFIG_USB_FTDI_ELAN is not set
+# CONFIG_USB_APPLEDISPLAY is not set
+# CONFIG_USB_SISUSBVGA is not set
+# CONFIG_USB_LD is not set
+# CONFIG_USB_TRANCEVIBRATOR is not set
+# CONFIG_USB_IOWARRIOR is not set
+# CONFIG_USB_TEST is not set
+# CONFIG_USB_ISIGHTFW is not set
+# CONFIG_USB_YUREX is not set
+# CONFIG_USB_EZUSB_FX2 is not set
+# CONFIG_USB_HSIC_USB3503 is not set
+# CONFIG_USB_PHY is not set
+# CONFIG_USB_GADGET is not set
+# CONFIG_UWB is not set
+# CONFIG_MMC is not set
+# CONFIG_MEMSTICK is not set
+# CONFIG_NEW_LEDS is not set
+# CONFIG_ACCESSIBILITY is not set
+# CONFIG_INFINIBAND is not set
+# CONFIG_EDAC is not set
+CONFIG_RTC_LIB=y
+CONFIG_RTC_CLASS=y
+CONFIG_RTC_HCTOSYS=y
+CONFIG_RTC_SYSTOHC=y
+CONFIG_RTC_HCTOSYS_DEVICE="rtc0"
+# CONFIG_RTC_DEBUG is not set
+
+#
+# RTC interfaces
+#
+CONFIG_RTC_INTF_SYSFS=y
+CONFIG_RTC_INTF_PROC=y
+CONFIG_RTC_INTF_DEV=y
+# CONFIG_RTC_INTF_DEV_UIE_EMUL is not set
+# CONFIG_RTC_DRV_TEST is not set
+
+#
+# I2C RTC drivers
+#
+# CONFIG_RTC_DRV_DS1307 is not set
+# CONFIG_RTC_DRV_DS1374 is not set
+# CONFIG_RTC_DRV_DS1672 is not set
+# CONFIG_RTC_DRV_DS3232 is not set
+# CONFIG_RTC_DRV_MAX6900 is not set
+# CONFIG_RTC_DRV_RS5C372 is not set
+# CONFIG_RTC_DRV_ISL1208 is not set
+# CONFIG_RTC_DRV_ISL12022 is not set
+# CONFIG_RTC_DRV_X1205 is not set
+# CONFIG_RTC_DRV_PCF8523 is not set
+# CONFIG_RTC_DRV_PCF8563 is not set
+# CONFIG_RTC_DRV_PCF8583 is not set
+# CONFIG_RTC_DRV_M41T80 is not set
+# CONFIG_RTC_DRV_BQ32K is not set
+# CONFIG_RTC_DRV_S35390A is not set
+# CONFIG_RTC_DRV_FM3130 is not set
+# CONFIG_RTC_DRV_RX8581 is not set
+# CONFIG_RTC_DRV_RX8025 is not set
+# CONFIG_RTC_DRV_EM3027 is not set
+# CONFIG_RTC_DRV_RV3029C2 is not set
+
+#
+# SPI RTC drivers
+#
+
+#
+# Platform RTC drivers
+#
+CONFIG_RTC_DRV_CMOS=y
+# CONFIG_RTC_DRV_DS1286 is not set
+# CONFIG_RTC_DRV_DS1511 is not set
+# CONFIG_RTC_DRV_DS1553 is not set
+# CONFIG_RTC_DRV_DS1742 is not set
+# CONFIG_RTC_DRV_STK17TA8 is not set
+# CONFIG_RTC_DRV_M48T86 is not set
+# CONFIG_RTC_DRV_M48T35 is not set
+# CONFIG_RTC_DRV_M48T59 is not set
+# CONFIG_RTC_DRV_MSM6242 is not set
+# CONFIG_RTC_DRV_BQ4802 is not set
+# CONFIG_RTC_DRV_RP5C01 is not set
+# CONFIG_RTC_DRV_V3020 is not set
+# CONFIG_RTC_DRV_DS2404 is not set
+
+#
+# on-CPU RTC drivers
+#
+
+#
+# HID Sensor RTC drivers
+#
+# CONFIG_RTC_DRV_HID_SENSOR_TIME is not set
+# CONFIG_DMADEVICES is not set
+# CONFIG_AUXDISPLAY is not set
+# CONFIG_UIO is not set
+# CONFIG_VFIO is not set
+# CONFIG_VIRT_DRIVERS is not set
+
+#
+# Virtio drivers
+#
+# CONFIG_VIRTIO_PCI is not set
+# CONFIG_VIRTIO_MMIO is not set
+
+#
+# Microsoft Hyper-V guest support
+#
+# CONFIG_STAGING is not set
+# CONFIG_X86_PLATFORM_DEVICES is not set
+
+#
+# Hardware Spinlock drivers
+#
+CONFIG_CLKEVT_I8253=y
+CONFIG_I8253_LOCK=y
+CONFIG_CLKBLD_I8253=y
+# CONFIG_MAILBOX is not set
+CONFIG_IOMMU_API=y
+CONFIG_IOMMU_SUPPORT=y
+CONFIG_AMD_IOMMU=y
+CONFIG_AMD_IOMMU_STATS=y
+# CONFIG_AMD_IOMMU_V2 is not set
+# CONFIG_INTEL_IOMMU is not set
+# CONFIG_IRQ_REMAP is not set
+
+#
+# Remoteproc drivers
+#
+# CONFIG_STE_MODEM_RPROC is not set
+
+#
+# Rpmsg drivers
+#
+# CONFIG_PM_DEVFREQ is not set
+# CONFIG_EXTCON is not set
+# CONFIG_MEMORY is not set
+# CONFIG_IIO is not set
+# CONFIG_NTB is not set
+# CONFIG_VME_BUS is not set
+# CONFIG_PWM is not set
+# CONFIG_IPACK_BUS is not set
+# CONFIG_RESET_CONTROLLER is not set
+
+#
+# Firmware Drivers
+#
+CONFIG_EDD=y
+CONFIG_EDD_OFF=y
+CONFIG_FIRMWARE_MEMMAP=y
+# CONFIG_DELL_RBU is not set
+# CONFIG_DCDBAS is not set
+CONFIG_DMIID=y
+# CONFIG_DMI_SYSFS is not set
+CONFIG_ISCSI_IBFT_FIND=y
+# CONFIG_ISCSI_IBFT is not set
+# CONFIG_GOOGLE_FIRMWARE is not set
+
+#
+# EFI (Extensible Firmware Interface) Support
+#
+CONFIG_EFI_VARS=y
+CONFIG_EFI_VARS_PSTORE=y
+# CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE is not set
+
+#
+# File systems
+#
+CONFIG_DCACHE_WORD_ACCESS=y
+CONFIG_EXT2_FS=y
+CONFIG_EXT2_FS_XATTR=y
+CONFIG_EXT2_FS_POSIX_ACL=y
+CONFIG_EXT2_FS_SECURITY=y
+# CONFIG_EXT2_FS_XIP is not set
+CONFIG_EXT3_FS=y
+CONFIG_EXT3_DEFAULTS_TO_ORDERED=y
+CONFIG_EXT3_FS_XATTR=y
+CONFIG_EXT3_FS_POSIX_ACL=y
+CONFIG_EXT3_FS_SECURITY=y
+CONFIG_EXT4_FS=y
+CONFIG_EXT4_FS_POSIX_ACL=y
+CONFIG_EXT4_FS_SECURITY=y
+# CONFIG_EXT4_DEBUG is not set
+CONFIG_JBD=y
+# CONFIG_JBD_DEBUG is not set
+CONFIG_JBD2=y
+# CONFIG_JBD2_DEBUG is not set
+CONFIG_FS_MBCACHE=y
+# CONFIG_REISERFS_FS is not set
+# CONFIG_JFS_FS is not set
+CONFIG_XFS_FS=y
+CONFIG_XFS_QUOTA=y
+CONFIG_XFS_POSIX_ACL=y
+# CONFIG_XFS_RT is not set
+# CONFIG_XFS_WARN is not set
+# CONFIG_XFS_DEBUG is not set
+# CONFIG_GFS2_FS is not set
+# CONFIG_BTRFS_FS is not set
+# CONFIG_NILFS2_FS is not set
+CONFIG_FS_POSIX_ACL=y
+CONFIG_EXPORTFS=y
+CONFIG_FILE_LOCKING=y
+CONFIG_FSNOTIFY=y
+CONFIG_DNOTIFY=y
+CONFIG_INOTIFY_USER=y
+CONFIG_FANOTIFY=y
+CONFIG_FANOTIFY_ACCESS_PERMISSIONS=y
+CONFIG_QUOTA=y
+CONFIG_QUOTA_NETLINK_INTERFACE=y
+# CONFIG_PRINT_QUOTA_WARNING is not set
+# CONFIG_QUOTA_DEBUG is not set
+# CONFIG_QFMT_V1 is not set
+# CONFIG_QFMT_V2 is not set
+CONFIG_QUOTACTL=y
+CONFIG_QUOTACTL_COMPAT=y
+CONFIG_AUTOFS4_FS=y
+CONFIG_FUSE_FS=y
+# CONFIG_CUSE is not set
+CONFIG_GENERIC_ACL=y
+
+#
+# Caches
+#
+# CONFIG_FSCACHE is not set
+
+#
+# CD-ROM/DVD Filesystems
+#
+CONFIG_ISO9660_FS=y
+CONFIG_JOLIET=y
+CONFIG_ZISOFS=y
+# CONFIG_UDF_FS is not set
+
+#
+# DOS/FAT/NT Filesystems
+#
+CONFIG_FAT_FS=y
+CONFIG_MSDOS_FS=y
+CONFIG_VFAT_FS=y
+CONFIG_FAT_DEFAULT_CODEPAGE=437
+CONFIG_FAT_DEFAULT_IOCHARSET="iso8859-1"
+CONFIG_NTFS_FS=y
+# CONFIG_NTFS_DEBUG is not set
+CONFIG_NTFS_RW=y
+
+#
+# Pseudo filesystems
+#
+CONFIG_PROC_FS=y
+CONFIG_PROC_KCORE=y
+CONFIG_PROC_VMCORE=y
+CONFIG_PROC_SYSCTL=y
+CONFIG_PROC_PAGE_MONITOR=y
+CONFIG_SYSFS=y
+CONFIG_TMPFS=y
+CONFIG_TMPFS_POSIX_ACL=y
+CONFIG_TMPFS_XATTR=y
+CONFIG_HUGETLBFS=y
+CONFIG_HUGETLB_PAGE=y
+# CONFIG_CONFIGFS_FS is not set
+CONFIG_MISC_FILESYSTEMS=y
+# CONFIG_ADFS_FS is not set
+# CONFIG_AFFS_FS is not set
+# CONFIG_ECRYPT_FS is not set
+# CONFIG_HFS_FS is not set
+# CONFIG_HFSPLUS_FS is not set
+# CONFIG_BEFS_FS is not set
+# CONFIG_BFS_FS is not set
+# CONFIG_EFS_FS is not set
+# CONFIG_LOGFS is not set
+# CONFIG_CRAMFS is not set
+# CONFIG_SQUASHFS is not set
+# CONFIG_VXFS_FS is not set
+# CONFIG_MINIX_FS is not set
+# CONFIG_OMFS_FS is not set
+# CONFIG_HPFS_FS is not set
+# CONFIG_QNX4FS_FS is not set
+# CONFIG_QNX6FS_FS is not set
+# CONFIG_ROMFS_FS is not set
+CONFIG_PSTORE=y
+# CONFIG_PSTORE_CONSOLE is not set
+# CONFIG_PSTORE_FTRACE is not set
+# CONFIG_PSTORE_RAM is not set
+# CONFIG_SYSV_FS is not set
+# CONFIG_UFS_FS is not set
+# CONFIG_F2FS_FS is not set
+# CONFIG_EFIVAR_FS is not set
+CONFIG_NETWORK_FILESYSTEMS=y
+CONFIG_NFS_FS=y
+CONFIG_NFS_V2=y
+CONFIG_NFS_V3=y
+CONFIG_NFS_V3_ACL=y
+CONFIG_NFS_V4=y
+# CONFIG_NFS_SWAP is not set
+# CONFIG_NFS_V4_1 is not set
+CONFIG_ROOT_NFS=y
+# CONFIG_NFS_USE_LEGACY_DNS is not set
+CONFIG_NFS_USE_KERNEL_DNS=y
+CONFIG_NFSD=y
+CONFIG_NFSD_V3=y
+# CONFIG_NFSD_V3_ACL is not set
+# CONFIG_NFSD_V4 is not set
+CONFIG_LOCKD=y
+CONFIG_LOCKD_V4=y
+CONFIG_NFS_ACL_SUPPORT=y
+CONFIG_NFS_COMMON=y
+CONFIG_SUNRPC=y
+CONFIG_SUNRPC_GSS=y
+# CONFIG_SUNRPC_DEBUG is not set
+# CONFIG_CEPH_FS is not set
+# CONFIG_CIFS is not set
+# CONFIG_NCP_FS is not set
+# CONFIG_CODA_FS is not set
+# CONFIG_AFS_FS is not set
+CONFIG_NLS=y
+CONFIG_NLS_DEFAULT="utf8"
+CONFIG_NLS_CODEPAGE_437=y
+CONFIG_NLS_CODEPAGE_737=m
+CONFIG_NLS_CODEPAGE_775=m
+CONFIG_NLS_CODEPAGE_850=m
+CONFIG_NLS_CODEPAGE_852=m
+CONFIG_NLS_CODEPAGE_855=m
+CONFIG_NLS_CODEPAGE_857=m
+CONFIG_NLS_CODEPAGE_860=m
+CONFIG_NLS_CODEPAGE_861=m
+CONFIG_NLS_CODEPAGE_862=m
+CONFIG_NLS_CODEPAGE_863=m
+CONFIG_NLS_CODEPAGE_864=m
+CONFIG_NLS_CODEPAGE_865=m
+CONFIG_NLS_CODEPAGE_866=m
+CONFIG_NLS_CODEPAGE_869=m
+CONFIG_NLS_CODEPAGE_936=m
+CONFIG_NLS_CODEPAGE_950=m
+CONFIG_NLS_CODEPAGE_932=y
+CONFIG_NLS_CODEPAGE_949=m
+CONFIG_NLS_CODEPAGE_874=m
+CONFIG_NLS_ISO8859_8=m
+CONFIG_NLS_CODEPAGE_1250=m
+CONFIG_NLS_CODEPAGE_1251=m
+CONFIG_NLS_ASCII=m
+CONFIG_NLS_ISO8859_1=m
+CONFIG_NLS_ISO8859_2=m
+CONFIG_NLS_ISO8859_3=m
+CONFIG_NLS_ISO8859_4=m
+CONFIG_NLS_ISO8859_5=m
+CONFIG_NLS_ISO8859_6=m
+CONFIG_NLS_ISO8859_7=m
+CONFIG_NLS_ISO8859_9=m
+CONFIG_NLS_ISO8859_13=m
+CONFIG_NLS_ISO8859_14=m
+CONFIG_NLS_ISO8859_15=m
+CONFIG_NLS_KOI8_R=m
+CONFIG_NLS_KOI8_U=m
+# CONFIG_NLS_MAC_ROMAN is not set
+# CONFIG_NLS_MAC_CELTIC is not set
+# CONFIG_NLS_MAC_CENTEURO is not set
+# CONFIG_NLS_MAC_CROATIAN is not set
+# CONFIG_NLS_MAC_CYRILLIC is not set
+# CONFIG_NLS_MAC_GAELIC is not set
+# CONFIG_NLS_MAC_GREEK is not set
+# CONFIG_NLS_MAC_ICELAND is not set
+# CONFIG_NLS_MAC_INUIT is not set
+# CONFIG_NLS_MAC_ROMANIAN is not set
+# CONFIG_NLS_MAC_TURKISH is not set
+CONFIG_NLS_UTF8=m
+
+#
+# Kernel hacking
+#
+CONFIG_TRACE_IRQFLAGS_SUPPORT=y
+CONFIG_PRINTK_TIME=y
+CONFIG_DEFAULT_MESSAGE_LOGLEVEL=4
+# CONFIG_ENABLE_WARN_DEPRECATED is not set
+# CONFIG_ENABLE_MUST_CHECK is not set
+CONFIG_FRAME_WARN=1024
+CONFIG_MAGIC_SYSRQ=y
+# CONFIG_STRIP_ASM_SYMS is not set
+# CONFIG_READABLE_ASM is not set
+CONFIG_UNUSED_SYMBOLS=y
+CONFIG_DEBUG_FS=y
+# CONFIG_HEADERS_CHECK is not set
+# CONFIG_DEBUG_SECTION_MISMATCH is not set
+CONFIG_DEBUG_KERNEL=y
+# CONFIG_DEBUG_SHIRQ is not set
+# CONFIG_LOCKUP_DETECTOR is not set
+# CONFIG_PANIC_ON_OOPS is not set
+CONFIG_PANIC_ON_OOPS_VALUE=0
+# CONFIG_DETECT_HUNG_TASK is not set
+CONFIG_SCHED_DEBUG=y
+# CONFIG_SCHEDSTATS is not set
+# CONFIG_TIMER_STATS is not set
+# CONFIG_DEBUG_OBJECTS is not set
+# CONFIG_SLUB_STATS is not set
+CONFIG_HAVE_DEBUG_KMEMLEAK=y
+# CONFIG_DEBUG_KMEMLEAK is not set
+# CONFIG_DEBUG_RT_MUTEXES is not set
+# CONFIG_RT_MUTEX_TESTER is not set
+# CONFIG_DEBUG_SPINLOCK is not set
+# CONFIG_DEBUG_MUTEXES is not set
+# CONFIG_DEBUG_LOCK_ALLOC is not set
+# CONFIG_PROVE_LOCKING is not set
+# CONFIG_LOCK_STAT is not set
+# CONFIG_DEBUG_ATOMIC_SLEEP is not set
+# CONFIG_DEBUG_LOCKING_API_SELFTESTS is not set
+CONFIG_STACKTRACE=y
+# CONFIG_DEBUG_STACK_USAGE is not set
+# CONFIG_DEBUG_KOBJECT is not set
+CONFIG_DEBUG_BUGVERBOSE=y
+# CONFIG_DEBUG_INFO is not set
+# CONFIG_DEBUG_VM is not set
+# CONFIG_DEBUG_VIRTUAL is not set
+# CONFIG_DEBUG_WRITECOUNT is not set
+# CONFIG_DEBUG_MEMORY_INIT is not set
+# CONFIG_DEBUG_LIST is not set
+# CONFIG_TEST_LIST_SORT is not set
+# CONFIG_DEBUG_SG is not set
+# CONFIG_DEBUG_NOTIFIERS is not set
+# CONFIG_DEBUG_CREDENTIALS is not set
+CONFIG_ARCH_WANT_FRAME_POINTERS=y
+CONFIG_FRAME_POINTER=y
+# CONFIG_BOOT_PRINTK_DELAY is not set
+
+#
+# RCU Debugging
+#
+# CONFIG_SPARSE_RCU_POINTER is not set
+# CONFIG_RCU_TORTURE_TEST is not set
+CONFIG_RCU_CPU_STALL_TIMEOUT=21
+# CONFIG_RCU_CPU_STALL_INFO is not set
+# CONFIG_RCU_TRACE is not set
+# CONFIG_KPROBES_SANITY_TEST is not set
+# CONFIG_BACKTRACE_SELF_TEST is not set
+# CONFIG_DEBUG_BLOCK_EXT_DEVT is not set
+# CONFIG_DEBUG_FORCE_WEAK_PER_CPU is not set
+# CONFIG_DEBUG_PER_CPU_MAPS is not set
+# CONFIG_LKDTM is not set
+# CONFIG_NOTIFIER_ERROR_INJECTION is not set
+# CONFIG_FAULT_INJECTION is not set
+# CONFIG_LATENCYTOP is not set
+CONFIG_ARCH_HAS_DEBUG_STRICT_USER_COPY_CHECKS=y
+# CONFIG_DEBUG_STRICT_USER_COPY_CHECKS is not set
+# CONFIG_DEBUG_PAGEALLOC is not set
+CONFIG_USER_STACKTRACE_SUPPORT=y
+CONFIG_NOP_TRACER=y
+CONFIG_HAVE_FUNCTION_TRACER=y
+CONFIG_HAVE_FUNCTION_GRAPH_TRACER=y
+CONFIG_HAVE_FUNCTION_GRAPH_FP_TEST=y
+CONFIG_HAVE_FUNCTION_TRACE_MCOUNT_TEST=y
+CONFIG_HAVE_DYNAMIC_FTRACE=y
+CONFIG_HAVE_DYNAMIC_FTRACE_WITH_REGS=y
+CONFIG_HAVE_FTRACE_MCOUNT_RECORD=y
+CONFIG_HAVE_SYSCALL_TRACEPOINTS=y
+CONFIG_HAVE_FENTRY=y
+CONFIG_HAVE_C_RECORDMCOUNT=y
+CONFIG_TRACER_MAX_TRACE=y
+CONFIG_TRACE_CLOCK=y
+CONFIG_RING_BUFFER=y
+CONFIG_EVENT_TRACING=y
+CONFIG_CONTEXT_SWITCH_TRACER=y
+CONFIG_TRACING=y
+CONFIG_GENERIC_TRACER=y
+CONFIG_TRACING_SUPPORT=y
+CONFIG_FTRACE=y
+CONFIG_FUNCTION_TRACER=y
+CONFIG_FUNCTION_GRAPH_TRACER=y
+# CONFIG_IRQSOFF_TRACER is not set
+CONFIG_SCHED_TRACER=y
+CONFIG_FTRACE_SYSCALLS=y
+CONFIG_TRACER_SNAPSHOT=y
+# CONFIG_TRACER_SNAPSHOT_PER_CPU_SWAP is not set
+CONFIG_BRANCH_PROFILE_NONE=y
+# CONFIG_PROFILE_ANNOTATED_BRANCHES is not set
+# CONFIG_PROFILE_ALL_BRANCHES is not set
+CONFIG_STACK_TRACER=y
+CONFIG_BLK_DEV_IO_TRACE=y
+CONFIG_KPROBE_EVENT=y
+# CONFIG_UPROBE_EVENT is not set
+CONFIG_PROBE_EVENTS=y
+CONFIG_DYNAMIC_FTRACE=y
+CONFIG_DYNAMIC_FTRACE_WITH_REGS=y
+CONFIG_FUNCTION_PROFILER=y
+CONFIG_FTRACE_MCOUNT_RECORD=y
+# CONFIG_FTRACE_STARTUP_TEST is not set
+CONFIG_MMIOTRACE=y
+# CONFIG_MMIOTRACE_TEST is not set
+# CONFIG_RING_BUFFER_BENCHMARK is not set
+# CONFIG_RING_BUFFER_STARTUP_TEST is not set
+# CONFIG_RBTREE_TEST is not set
+# CONFIG_INTERVAL_TREE_TEST is not set
+# CONFIG_PROVIDE_OHCI1394_DMA_INIT is not set
+# CONFIG_DYNAMIC_DEBUG is not set
+# CONFIG_DMA_API_DEBUG is not set
+# CONFIG_ATOMIC64_SELFTEST is not set
+# CONFIG_ASYNC_RAID6_TEST is not set
+# CONFIG_SAMPLES is not set
+CONFIG_HAVE_ARCH_KGDB=y
+# CONFIG_KGDB is not set
+CONFIG_HAVE_ARCH_KMEMCHECK=y
+# CONFIG_TEST_STRING_HELPERS is not set
+# CONFIG_TEST_KSTRTOX is not set
+CONFIG_STRICT_DEVMEM=y
+# CONFIG_X86_VERBOSE_BOOTUP is not set
+CONFIG_EARLY_PRINTK=y
+# CONFIG_EARLY_PRINTK_DBGP is not set
+# CONFIG_DEBUG_STACKOVERFLOW is not set
+# CONFIG_X86_PTDUMP is not set
+CONFIG_DEBUG_RODATA=y
+CONFIG_DEBUG_RODATA_TEST=y
+# CONFIG_DEBUG_SET_MODULE_RONX is not set
+# CONFIG_DEBUG_NX_TEST is not set
+# CONFIG_DEBUG_TLBFLUSH is not set
+# CONFIG_IOMMU_DEBUG is not set
+# CONFIG_IOMMU_STRESS is not set
+CONFIG_HAVE_MMIOTRACE_SUPPORT=y
+# CONFIG_X86_DECODER_SELFTEST is not set
+CONFIG_IO_DELAY_TYPE_0X80=0
+CONFIG_IO_DELAY_TYPE_0XED=1
+CONFIG_IO_DELAY_TYPE_UDELAY=2
+CONFIG_IO_DELAY_TYPE_NONE=3
+# CONFIG_IO_DELAY_0X80 is not set
+CONFIG_IO_DELAY_0XED=y
+# CONFIG_IO_DELAY_UDELAY is not set
+# CONFIG_IO_DELAY_NONE is not set
+CONFIG_DEFAULT_IO_DELAY_TYPE=1
+# CONFIG_DEBUG_BOOT_PARAMS is not set
+# CONFIG_CPA_DEBUG is not set
+CONFIG_OPTIMIZE_INLINING=y
+# CONFIG_DEBUG_NMI_SELFTEST is not set
+
+#
+# Security options
+#
+CONFIG_KEYS=y
+# CONFIG_ENCRYPTED_KEYS is not set
+# CONFIG_KEYS_DEBUG_PROC_KEYS is not set
+# CONFIG_SECURITY_DMESG_RESTRICT is not set
+CONFIG_SECURITY=y
+# CONFIG_SECURITYFS is not set
+CONFIG_SECURITY_NETWORK=y
+# CONFIG_SECURITY_PATH is not set
+# CONFIG_SECURITY_SELINUX is not set
+# CONFIG_SECURITY_SMACK is not set
+# CONFIG_SECURITY_TOMOYO is not set
+# CONFIG_SECURITY_APPARMOR is not set
+# CONFIG_SECURITY_YAMA is not set
+# CONFIG_IMA is not set
+# CONFIG_EVM is not set
+CONFIG_DEFAULT_SECURITY_DAC=y
+CONFIG_DEFAULT_SECURITY=""
+CONFIG_XOR_BLOCKS=y
+CONFIG_ASYNC_CORE=y
+CONFIG_ASYNC_MEMCPY=y
+CONFIG_ASYNC_XOR=y
+CONFIG_ASYNC_PQ=y
+CONFIG_ASYNC_RAID6_RECOV=y
+CONFIG_CRYPTO=y
+
+#
+# Crypto core or helper
+#
+CONFIG_CRYPTO_ALGAPI=y
+CONFIG_CRYPTO_ALGAPI2=y
+CONFIG_CRYPTO_AEAD=y
+CONFIG_CRYPTO_AEAD2=y
+CONFIG_CRYPTO_BLKCIPHER=y
+CONFIG_CRYPTO_BLKCIPHER2=y
+CONFIG_CRYPTO_HASH=y
+CONFIG_CRYPTO_HASH2=y
+CONFIG_CRYPTO_RNG2=y
+CONFIG_CRYPTO_PCOMP2=y
+CONFIG_CRYPTO_MANAGER=y
+CONFIG_CRYPTO_MANAGER2=y
+# CONFIG_CRYPTO_USER is not set
+CONFIG_CRYPTO_MANAGER_DISABLE_TESTS=y
+# CONFIG_CRYPTO_GF128MUL is not set
+# CONFIG_CRYPTO_NULL is not set
+# CONFIG_CRYPTO_PCRYPT is not set
+CONFIG_CRYPTO_WORKQUEUE=y
+# CONFIG_CRYPTO_CRYPTD is not set
+CONFIG_CRYPTO_AUTHENC=y
+# CONFIG_CRYPTO_TEST is not set
+
+#
+# Authenticated Encryption with Associated Data
+#
+# CONFIG_CRYPTO_CCM is not set
+# CONFIG_CRYPTO_GCM is not set
+# CONFIG_CRYPTO_SEQIV is not set
+
+#
+# Block modes
+#
+CONFIG_CRYPTO_CBC=y
+# CONFIG_CRYPTO_CTR is not set
+# CONFIG_CRYPTO_CTS is not set
+CONFIG_CRYPTO_ECB=y
+# CONFIG_CRYPTO_LRW is not set
+# CONFIG_CRYPTO_PCBC is not set
+# CONFIG_CRYPTO_XTS is not set
+
+#
+# Hash modes
+#
+# CONFIG_CRYPTO_CMAC is not set
+CONFIG_CRYPTO_HMAC=y
+# CONFIG_CRYPTO_XCBC is not set
+# CONFIG_CRYPTO_VMAC is not set
+
+#
+# Digest
+#
+CONFIG_CRYPTO_CRC32C=y
+# CONFIG_CRYPTO_CRC32C_INTEL is not set
+# CONFIG_CRYPTO_CRC32 is not set
+# CONFIG_CRYPTO_CRC32_PCLMUL is not set
+# CONFIG_CRYPTO_GHASH is not set
+# CONFIG_CRYPTO_MD4 is not set
+CONFIG_CRYPTO_MD5=y
+# CONFIG_CRYPTO_MICHAEL_MIC is not set
+# CONFIG_CRYPTO_RMD128 is not set
+# CONFIG_CRYPTO_RMD160 is not set
+# CONFIG_CRYPTO_RMD256 is not set
+# CONFIG_CRYPTO_RMD320 is not set
+CONFIG_CRYPTO_SHA1=y
+# CONFIG_CRYPTO_SHA1_SSSE3 is not set
+# CONFIG_CRYPTO_SHA256_SSSE3 is not set
+# CONFIG_CRYPTO_SHA512_SSSE3 is not set
+# CONFIG_CRYPTO_SHA256 is not set
+# CONFIG_CRYPTO_SHA512 is not set
+# CONFIG_CRYPTO_TGR192 is not set
+# CONFIG_CRYPTO_WP512 is not set
+# CONFIG_CRYPTO_GHASH_CLMUL_NI_INTEL is not set
+
+#
+# Ciphers
+#
+CONFIG_CRYPTO_AES=y
+# CONFIG_CRYPTO_AES_X86_64 is not set
+# CONFIG_CRYPTO_AES_NI_INTEL is not set
+# CONFIG_CRYPTO_ANUBIS is not set
+CONFIG_CRYPTO_ARC4=y
+# CONFIG_CRYPTO_BLOWFISH is not set
+# CONFIG_CRYPTO_BLOWFISH_X86_64 is not set
+# CONFIG_CRYPTO_CAMELLIA is not set
+# CONFIG_CRYPTO_CAMELLIA_X86_64 is not set
+# CONFIG_CRYPTO_CAMELLIA_AESNI_AVX_X86_64 is not set
+# CONFIG_CRYPTO_CAMELLIA_AESNI_AVX2_X86_64 is not set
+# CONFIG_CRYPTO_CAST5 is not set
+# CONFIG_CRYPTO_CAST5_AVX_X86_64 is not set
+# CONFIG_CRYPTO_CAST6 is not set
+# CONFIG_CRYPTO_CAST6_AVX_X86_64 is not set
+# CONFIG_CRYPTO_DES is not set
+# CONFIG_CRYPTO_FCRYPT is not set
+# CONFIG_CRYPTO_KHAZAD is not set
+# CONFIG_CRYPTO_SALSA20 is not set
+# CONFIG_CRYPTO_SALSA20_X86_64 is not set
+# CONFIG_CRYPTO_SEED is not set
+# CONFIG_CRYPTO_SERPENT is not set
+# CONFIG_CRYPTO_SERPENT_SSE2_X86_64 is not set
+# CONFIG_CRYPTO_SERPENT_AVX_X86_64 is not set
+# CONFIG_CRYPTO_SERPENT_AVX2_X86_64 is not set
+# CONFIG_CRYPTO_TEA is not set
+# CONFIG_CRYPTO_TWOFISH is not set
+# CONFIG_CRYPTO_TWOFISH_X86_64 is not set
+# CONFIG_CRYPTO_TWOFISH_X86_64_3WAY is not set
+# CONFIG_CRYPTO_TWOFISH_AVX_X86_64 is not set
+
+#
+# Compression
+#
+# CONFIG_CRYPTO_DEFLATE is not set
+# CONFIG_CRYPTO_ZLIB is not set
+# CONFIG_CRYPTO_LZO is not set
+
+#
+# Random Number Generation
+#
+# CONFIG_CRYPTO_ANSI_CPRNG is not set
+# CONFIG_CRYPTO_USER_API_HASH is not set
+# CONFIG_CRYPTO_USER_API_SKCIPHER is not set
+# CONFIG_CRYPTO_HW is not set
+# CONFIG_ASYMMETRIC_KEY_TYPE is not set
+CONFIG_HAVE_KVM=y
+# CONFIG_VIRTUALIZATION is not set
+CONFIG_BINARY_PRINTF=y
+
+#
+# Library routines
+#
+CONFIG_RAID6_PQ=y
+CONFIG_BITREVERSE=y
+CONFIG_GENERIC_STRNCPY_FROM_USER=y
+CONFIG_GENERIC_STRNLEN_USER=y
+CONFIG_GENERIC_FIND_FIRST_BIT=y
+CONFIG_GENERIC_PCI_IOMAP=y
+CONFIG_GENERIC_IOMAP=y
+CONFIG_GENERIC_IO=y
+# CONFIG_CRC_CCITT is not set
+CONFIG_CRC16=y
+CONFIG_CRC_T10DIF=y
+# CONFIG_CRC_ITU_T is not set
+CONFIG_CRC32=y
+# CONFIG_CRC32_SELFTEST is not set
+CONFIG_CRC32_SLICEBY8=y
+# CONFIG_CRC32_SLICEBY4 is not set
+# CONFIG_CRC32_SARWATE is not set
+# CONFIG_CRC32_BIT is not set
+CONFIG_CRC7=y
+CONFIG_LIBCRC32C=y
+# CONFIG_CRC8 is not set
+CONFIG_ZLIB_INFLATE=y
+CONFIG_LZO_COMPRESS=y
+CONFIG_LZO_DECOMPRESS=y
+CONFIG_XZ_DEC=y
+# CONFIG_XZ_DEC_X86 is not set
+# CONFIG_XZ_DEC_POWERPC is not set
+# CONFIG_XZ_DEC_IA64 is not set
+# CONFIG_XZ_DEC_ARM is not set
+# CONFIG_XZ_DEC_ARMTHUMB is not set
+# CONFIG_XZ_DEC_SPARC is not set
+# CONFIG_XZ_DEC_BCJ is not set
+# CONFIG_XZ_DEC_TEST is not set
+CONFIG_DECOMPRESS_GZIP=y
+CONFIG_DECOMPRESS_BZIP2=y
+CONFIG_DECOMPRESS_LZMA=y
+CONFIG_DECOMPRESS_XZ=y
+CONFIG_DECOMPRESS_LZO=y
+CONFIG_HAS_IOMEM=y
+CONFIG_HAS_IOPORT=y
+CONFIG_HAS_DMA=y
+CONFIG_CHECK_SIGNATURE=y
+CONFIG_CPU_RMAP=y
+CONFIG_DQL=y
+CONFIG_NLATTR=y
+CONFIG_ARCH_HAS_ATOMIC64_DEC_IF_POSITIVE=y
+# CONFIG_AVERAGE is not set
+# CONFIG_CORDIC is not set
+# CONFIG_DDR is not set
+CONFIG_OID_REGISTRY=y
+CONFIG_UCS2_STRING=y
+
+#
+# BUFFALO Features
+#
+CONFIG_BUFFALO_PLATFORM=y
+CONFIG_BUFFALO_USE_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_DEGRADE_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT=y
+# CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT is not set
+CONFIG_BUFFALO_ERRCNT=y
+CONFIG_BUFFALO_USE_UPS=y
+# CONFIG_BUFFALO_SUPPORT_UPS_RECOVER is not set
+CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN=y
+# CONFIG_BUFFALO_UBOOT_PARAMS is not set
+CONFIG_BUFFALO_IOERRS=y
+# CONFIG_BUFFALO_SKIP_RESYNC is not set
+# CONFIG_BUFFALO_IGNORE_LUN is not set
+# CONFIG_BUFFALO_SCSI_GUID is not set
+# CONFIG_BUFFALO_EXT23_EXTENSION is not set
+# CONFIG_BUFFALO_SUPPORT_WOL is not set
+# CONFIG_BUFFALO_MATSU_PLATFORM is not set
+# CONFIG_BUFFALO_KIRI_PLATFORM is not set
+CONFIG_BUFFALO_USI_PLATFORM=y
diff --git a/buffalo/arch/x86/configs/buffalo_ts6000_defconfig b/buffalo/arch/x86/configs/buffalo_ts6000_defconfig
new file mode 100644
index 00000000..d5565dd
--- /dev/null
+++ b/buffalo/arch/x86/configs/buffalo_ts6000_defconfig
@@ -0,0 +1,1488 @@
+CONFIG_CC_STACKPROTECTOR_REGULAR=y
+# CONFIG_CC_STACKPROTECTOR_STRONG is not set
+CONFIG_FHANDLE=y
+CONFIG_NO_HZ_IDLE=y
+# CONFIG_NO_HZ_FULL is not set
+CONFIG_TICK_CPU_ACCOUNTING=y
+# CONFIG_VIRT_CPU_ACCOUNTING_GEN is not set
+# CONFIG_IRQ_TIME_ACCOUNTING is not set
+# CONFIG_RCU_USER_QS is not set
+# CONFIG_RCU_NOCB_CPU is not set
+CONFIG_IKCONFIG=y
+CONFIG_IKCONFIG_PROC=y
+# CONFIG_NUMA_BALANCING is not set
+# CONFIG_MEMCG is not set
+# CONFIG_CGROUP_HUGETLB is not set
+# CONFIG_CGROUP_PERF is not set
+# CONFIG_CFS_BANDWIDTH is not set
+# CONFIG_CHECKPOINT_RESTORE is not set
+# CONFIG_KALLSYMS_ALL is not set
+# CONFIG_SLUB_DEBUG is not set
+# CONFIG_OPROFILE is not set
+# CONFIG_MODULE_SIG is not set
+# CONFIG_BLK_DEV_BSGLIB is not set
+# CONFIG_ACORN_PARTITION is not set
+# CONFIG_OSF_PARTITION is not set
+# CONFIG_AMIGA_PARTITION is not set
+# CONFIG_ATARI_PARTITION is not set
+CONFIG_LDM_PARTITION=y
+# CONFIG_SGI_PARTITION is not set
+# CONFIG_ULTRIX_PARTITION is not set
+# CONFIG_SUN_PARTITION is not set
+# CONFIG_KARMA_PARTITION is not set
+# CONFIG_SYSV68_PARTITION is not set
+# CONFIG_DEFAULT_DEADLINE is not set
+CONFIG_DEFAULT_CFQ=y
+CONFIG_DEFAULT_IOSCHED="cfq"
+# CONFIG_X86_INTEL_LPSS is not set
+# CONFIG_HYPERVISOR_GUEST is not set
+# CONFIG_MEMTEST is not set
+# CONFIG_X86_MCE_INJECT is not set
+# CONFIG_I8K is not set
+# CONFIG_MICROCODE is not set
+# CONFIG_X86_MSR is not set
+# CONFIG_X86_CPUID is not set
+# CONFIG_MOVABLE_NODE is not set
+# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
+# CONFIG_MEMORY_HOTPLUG is not set
+# CONFIG_HWPOISON_INJECT is not set
+# CONFIG_TRANSPARENT_HUGEPAGE is not set
+# CONFIG_CLEANCACHE is not set
+# CONFIG_FRONTSWAP is not set
+CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT=0
+# CONFIG_EFI_STUB is not set
+CONFIG_HZ_100=y
+# CONFIG_HZ_250 is not set
+CONFIG_HZ=100
+CONFIG_ACPI_PROCFS=y
+CONFIG_ACPI_PROCFS_POWER=y
+# CONFIG_ACPI_EC_DEBUGFS is not set
+CONFIG_ACPI_VIDEO=y
+# CONFIG_ACPI_PROCESSOR_AGGREGATOR is not set
+CONFIG_ACPI_SBS=y
+# CONFIG_ACPI_HED is not set
+# CONFIG_ACPI_BGRT is not set
+# CONFIG_ACPI_APEI_GHES is not set
+# CONFIG_ACPI_APEI_PCIEAER is not set
+# CONFIG_ACPI_APEI_MEMORY_FAILURE is not set
+# CONFIG_ACPI_APEI_EINJ is not set
+# CONFIG_X86_INTEL_PSTATE is not set
+# CONFIG_X86_PCC_CPUFREQ is not set
+# CONFIG_X86_AMD_FREQ_SENSITIVITY is not set
+# CONFIG_X86_P4_CLOCKMOD is not set
+# CONFIG_X86_SPEEDSTEP_LIB is not set
+# CONFIG_CPU_IDLE_MULTIPLE_DRIVERS is not set
+# CONFIG_I7300_IDLE is not set
+# CONFIG_PCI_REALLOC_ENABLE_AUTO is not set
+# CONFIG_PCI_STUB is not set
+CONFIG_PCI_IOV=y
+# CONFIG_ISA_DMA_API is not set
+# CONFIG_PCCARD is not set
+# CONFIG_HOTPLUG_PCI_ACPI is not set
+# CONFIG_HOTPLUG_PCI_CPCI_ZT5550 is not set
+# CONFIG_HOTPLUG_PCI_CPCI_GENERIC is not set
+# CONFIG_HOTPLUG_PCI_SHPC is not set
+# CONFIG_RAPIDIO is not set
+CONFIG_BINFMT_MISC=y
+# CONFIG_X86_X32 is not set
+# CONFIG_XFRM_USER is not set
+# CONFIG_NET_KEY is not set
+# CONFIG_IP_FIB_TRIE_STATS is not set
+CONFIG_IP_PNP=y
+CONFIG_IP_PNP_DHCP=y
+CONFIG_IP_PNP_BOOTP=y
+CONFIG_IP_PNP_RARP=y
+# CONFIG_NET_IPIP is not set
+# CONFIG_NET_IPGRE_DEMUX is not set
+# CONFIG_NET_IP_TUNNEL is not set
+# CONFIG_INET_AH is not set
+# CONFIG_INET_ESP is not set
+# CONFIG_INET_IPCOMP is not set
+# CONFIG_INET_XFRM_TUNNEL is not set
+# CONFIG_INET_TUNNEL is not set
+# CONFIG_INET_XFRM_MODE_TRANSPORT is not set
+# CONFIG_INET_XFRM_MODE_TUNNEL is not set
+# CONFIG_INET_XFRM_MODE_BEET is not set
+# CONFIG_INET_DIAG is not set
+# CONFIG_TCP_CONG_BIC is not set
+# CONFIG_TCP_CONG_WESTWOOD is not set
+# CONFIG_TCP_CONG_HTCP is not set
+# CONFIG_TCP_CONG_HSTCP is not set
+# CONFIG_TCP_CONG_HYBLA is not set
+# CONFIG_TCP_CONG_VEGAS is not set
+# CONFIG_TCP_CONG_SCALABLE is not set
+# CONFIG_TCP_CONG_LP is not set
+# CONFIG_TCP_CONG_VENO is not set
+# CONFIG_TCP_CONG_YEAH is not set
+# CONFIG_TCP_CONG_ILLINOIS is not set
+# CONFIG_IPV6 is not set
+CONFIG_NETFILTER=y
+CONFIG_NF_CONNTRACK=m
+CONFIG_NF_CONNTRACK_EVENTS=y
+CONFIG_NF_CONNTRACK_FTP=m
+CONFIG_NF_CONNTRACK_SIP=m
+CONFIG_NF_CT_NETLINK=m
+CONFIG_NF_CT_NETLINK_TIMEOUT=m
+CONFIG_NF_CONNTRACK_IPV4=m
+CONFIG_NF_NAT_IPV4=m
+CONFIG_NF_NAT_AMANDA=m
+CONFIG_NF_NAT_TFTP=m
+CONFIG_NF_NAT_MASQUERADE_IPV4=m
+CONFIG_IP_NF_IPTABLES=m
+CONFIG_IP_NF_FILTER=m
+CONFIG_NETFILTER_ADVANCED=y
+CONFIG_NETFILTER_NETLINK=y
+CONFIG_NETFILTER_NETLINK_LOG=y
+CONFIG_NETFILTER_XTABLES=y
+# CONFIG_NETFILTER_XT_MARK is not set
+CONFIG_NETFILTER_XT_TARGET_NFLOG=y
+CONFIG_NETFILTER_XT_TARGET_SECMARK=y
+CONFIG_NETFILTER_XT_TARGET_TCPMSS=y
+# CONFIG_IP_SET is not set
+# CONFIG_IP_VS is not set
+# CONFIG_NF_DEFRAG_IPV4 is not set
+CONFIG_IP_NF_TARGET_REJECT=y
+CONFIG_IP_NF_TARGET_ULOG=y
+CONFIG_IP_NF_MANGLE=y
+# CONFIG_IP_NF_RAW is not set
+# CONFIG_IP_DCCP is not set
+# CONFIG_IP_SCTP is not set
+# CONFIG_RDS is not set
+# CONFIG_TIPC is not set
+# CONFIG_ATM is not set
+# CONFIG_L2TP is not set
+# CONFIG_BRIDGE is not set
+CONFIG_VLAN_8021Q=m
+# CONFIG_DECNET is not set
+# CONFIG_LLC2 is not set
+# CONFIG_IPX is not set
+# CONFIG_ATALK is not set
+# CONFIG_X25 is not set
+# CONFIG_LAPB is not set
+# CONFIG_PHONET is not set
+# CONFIG_IEEE802154 is not set
+# CONFIG_NET_SCH_CBQ is not set
+# CONFIG_NET_SCH_HTB is not set
+# CONFIG_NET_SCH_HFSC is not set
+# CONFIG_NET_SCH_PRIO is not set
+# CONFIG_NET_SCH_MULTIQ is not set
+# CONFIG_NET_SCH_RED is not set
+# CONFIG_NET_SCH_SFB is not set
+# CONFIG_NET_SCH_SFQ is not set
+# CONFIG_NET_SCH_TEQL is not set
+# CONFIG_NET_SCH_TBF is not set
+# CONFIG_NET_SCH_GRED is not set
+# CONFIG_NET_SCH_DSMARK is not set
+# CONFIG_NET_SCH_NETEM is not set
+# CONFIG_NET_SCH_DRR is not set
+# CONFIG_NET_SCH_MQPRIO is not set
+# CONFIG_NET_SCH_CHOKE is not set
+# CONFIG_NET_SCH_QFQ is not set
+# CONFIG_NET_SCH_CODEL is not set
+# CONFIG_NET_SCH_FQ_CODEL is not set
+# CONFIG_NET_SCH_INGRESS is not set
+# CONFIG_NET_SCH_PLUG is not set
+# CONFIG_NET_CLS_BASIC is not set
+# CONFIG_NET_CLS_TCINDEX is not set
+# CONFIG_NET_CLS_ROUTE4 is not set
+# CONFIG_NET_CLS_FW is not set
+# CONFIG_NET_CLS_U32 is not set
+# CONFIG_NET_CLS_RSVP is not set
+# CONFIG_NET_CLS_RSVP6 is not set
+# CONFIG_NET_CLS_FLOW is not set
+CONFIG_NET_CLS_CGROUP=y
+# CONFIG_NET_EMATCH_CMP is not set
+# CONFIG_NET_EMATCH_NBYTE is not set
+# CONFIG_NET_EMATCH_U32 is not set
+# CONFIG_NET_EMATCH_META is not set
+# CONFIG_NET_EMATCH_TEXT is not set
+# CONFIG_NET_ACT_POLICE is not set
+# CONFIG_NET_ACT_GACT is not set
+# CONFIG_NET_ACT_MIRRED is not set
+# CONFIG_NET_ACT_IPT is not set
+# CONFIG_NET_ACT_NAT is not set
+# CONFIG_NET_ACT_PEDIT is not set
+# CONFIG_NET_ACT_SIMP is not set
+# CONFIG_NET_ACT_SKBEDIT is not set
+# CONFIG_NET_ACT_CSUM is not set
+# CONFIG_DCB is not set
+# CONFIG_BATMAN_ADV is not set
+# CONFIG_OPENVSWITCH is not set
+# CONFIG_VSOCKETS is not set
+# CONFIG_NETLINK_MMAP is not set
+# CONFIG_NETLINK_DIAG is not set
+# CONFIG_NETPRIO_CGROUP is not set
+# CONFIG_BPF_JIT is not set
+CONFIG_NET_PKTGEN=y
+# CONFIG_NET_TCPPROBE is not set
+# CONFIG_AX25 is not set
+# CONFIG_CAN is not set
+# CONFIG_IRDA is not set
+# CONFIG_BT is not set
+# CONFIG_AF_RXRPC is not set
+# CONFIG_CFG80211 is not set
+# CONFIG_LIB80211 is not set
+# CONFIG_WIMAX is not set
+# CONFIG_NET_9P is not set
+# CONFIG_CAIF is not set
+# CONFIG_CEPH_LIB is not set
+# CONFIG_NFC is not set
+CONFIG_UEVENT_HELPER_PATH="/sbin/hotplug"
+CONFIG_DEVTMPFS=y
+# CONFIG_SYS_HYPERVISOR is not set
+# CONFIG_MTD is not set
+# CONFIG_PARPORT is not set
+# CONFIG_BLK_DEV_PCIESSD_MTIP32XX is not set
+# CONFIG_BLK_CPQ_DA is not set
+# CONFIG_BLK_CPQ_CISS_DA is not set
+# CONFIG_BLK_DEV_DAC960 is not set
+# CONFIG_BLK_DEV_UMEM is not set
+# CONFIG_BLK_DEV_CRYPTOLOOP is not set
+# CONFIG_BLK_DEV_DRBD is not set
+# CONFIG_BLK_DEV_NBD is not set
+CONFIG_BLK_DEV_NVME=y
+CONFIG_BLK_DEV_RAM=y
+CONFIG_BLK_DEV_RAM_COUNT=8
+CONFIG_BLK_DEV_RAM_SIZE=131072
+# CONFIG_BLK_DEV_SX8 is not set
+# CONFIG_CDROM_PKTCDVD is not set
+# CONFIG_ATA_OVER_ETH is not set
+# CONFIG_BLK_DEV_RBD is not set
+# CONFIG_BLK_DEV_RSXX is not set
+# CONFIG_SENSORS_LIS3LV02D is not set
+# CONFIG_AD525X_DPOT is not set
+# CONFIG_DUMMY_IRQ is not set
+# CONFIG_IBM_ASM is not set
+# CONFIG_PHANTOM is not set
+# CONFIG_INTEL_MID_PTI is not set
+# CONFIG_SGI_IOC4 is not set
+# CONFIG_TIFM_CORE is not set
+# CONFIG_ICS932S401 is not set
+# CONFIG_ATMEL_SSC is not set
+# CONFIG_ENCLOSURE_SERVICES is not set
+# CONFIG_HP_ILO is not set
+# CONFIG_APDS9802ALS is not set
+# CONFIG_ISL29003 is not set
+# CONFIG_ISL29020 is not set
+# CONFIG_SENSORS_TSL2550 is not set
+# CONFIG_SENSORS_BH1780 is not set
+# CONFIG_SENSORS_BH1770 is not set
+# CONFIG_SENSORS_APDS990X is not set
+# CONFIG_HMC6352 is not set
+# CONFIG_DS1682 is not set
+# CONFIG_BMP085_I2C is not set
+# CONFIG_PCH_PHUB is not set
+# CONFIG_USB_SWITCH_FSA9480 is not set
+# CONFIG_SRAM is not set
+# CONFIG_C2PORT is not set
+# CONFIG_EEPROM_AT24 is not set
+# CONFIG_EEPROM_LEGACY is not set
+# CONFIG_EEPROM_MAX6875 is not set
+# CONFIG_EEPROM_93CX6 is not set
+# CONFIG_CB710_CORE is not set
+# CONFIG_SENSORS_LIS3_I2C is not set
+# CONFIG_ALTERA_STAPL is not set
+# CONFIG_VMWARE_VMCI is not set
+CONFIG_RAID_ATTRS=y
+# CONFIG_SCSI_TGT is not set
+# CONFIG_SCSI_NETLINK is not set
+# CONFIG_CHR_DEV_ST is not set
+# CONFIG_CHR_DEV_OSST is not set
+# CONFIG_CHR_DEV_SCH is not set
+# CONFIG_SCSI_MULTI_LUN is not set
+# CONFIG_SCSI_SCAN_ASYNC is not set
+# CONFIG_SCSI_SPI_ATTRS is not set
+# CONFIG_SCSI_FC_ATTRS is not set
+# CONFIG_SCSI_ISCSI_ATTRS is not set
+CONFIG_SCSI_SAS_ATTRS=y
+CONFIG_SCSI_SAS_LIBSAS=y
+# CONFIG_SCSI_SRP_ATTRS is not set
+CONFIG_ISCSI_TCP=m
+# CONFIG_ISCSI_BOOT_SYSFS is not set
+# CONFIG_SCSI_CXGB3_ISCSI is not set
+# CONFIG_SCSI_CXGB4_ISCSI is not set
+# CONFIG_SCSI_BNX2_ISCSI is not set
+# CONFIG_SCSI_BNX2X_FCOE is not set
+# CONFIG_BE2ISCSI is not set
+# CONFIG_BLK_DEV_3W_XXXX_RAID is not set
+# CONFIG_SCSI_HPSA is not set
+# CONFIG_SCSI_3W_9XXX is not set
+# CONFIG_SCSI_3W_SAS is not set
+# CONFIG_SCSI_ACARD is not set
+# CONFIG_SCSI_AACRAID is not set
+# CONFIG_SCSI_AIC7XXX is not set
+# CONFIG_SCSI_AIC79XX is not set
+# CONFIG_SCSI_AIC94XX is not set
+# CONFIG_SCSI_MVSAS is not set
+# CONFIG_SCSI_MVUMI is not set
+# CONFIG_SCSI_DPT_I2O is not set
+# CONFIG_SCSI_ADVANSYS is not set
+# CONFIG_SCSI_ARCMSR is not set
+# CONFIG_MEGARAID_NEWGEN is not set
+# CONFIG_MEGARAID_LEGACY is not set
+# CONFIG_MEGARAID_SAS is not set
+# CONFIG_SCSI_MPT2SAS is not set
+CONFIG_SCSI_MPT3SAS=y
+# CONFIG_SCSI_UFSHCD is not set
+# CONFIG_SCSI_HPTIOP is not set
+# CONFIG_VMWARE_PVSCSI is not set
+# CONFIG_LIBFC is not set
+# CONFIG_LIBFCOE is not set
+# CONFIG_FCOE is not set
+# CONFIG_FCOE_FNIC is not set
+# CONFIG_SCSI_DMX3191D is not set
+# CONFIG_SCSI_FUTURE_DOMAIN is not set
+# CONFIG_SCSI_ISCI is not set
+# CONFIG_SCSI_IPS is not set
+# CONFIG_SCSI_INITIO is not set
+# CONFIG_SCSI_INIA100 is not set
+# CONFIG_SCSI_STEX is not set
+# CONFIG_SCSI_SYM53C8XX_2 is not set
+# CONFIG_SCSI_IPR is not set
+# CONFIG_SCSI_QLOGIC_1280 is not set
+# CONFIG_SCSI_QLA_FC is not set
+# CONFIG_SCSI_QLA_ISCSI is not set
+# CONFIG_SCSI_LPFC is not set
+# CONFIG_SCSI_DC395x is not set
+# CONFIG_SCSI_DC390T is not set
+# CONFIG_SCSI_DEBUG is not set
+# CONFIG_SCSI_PMCRAID is not set
+# CONFIG_SCSI_PM8001 is not set
+# CONFIG_SCSI_SRP is not set
+# CONFIG_SCSI_BFA_FC is not set
+# CONFIG_SCSI_CHELSIO_FCOE is not set
+# CONFIG_SCSI_DH is not set
+# CONFIG_SCSI_OSD_INITIATOR is not set
+# CONFIG_SATA_ZPODD is not set
+# CONFIG_SATA_PMP is not set
+CONFIG_SATA_AHCI=y
+# CONFIG_SATA_AHCI_PLATFORM is not set
+# CONFIG_SATA_INIC162X is not set
+# CONFIG_SATA_ACARD_AHCI is not set
+CONFIG_SATA_SIL24=y
+# CONFIG_PDC_ADMA is not set
+# CONFIG_SATA_QSTOR is not set
+# CONFIG_SATA_SX4 is not set
+CONFIG_SATA_MV=y
+# CONFIG_SATA_NV is not set
+# CONFIG_SATA_PROMISE is not set
+# CONFIG_SATA_SIL is not set
+# CONFIG_SATA_SIS is not set
+# CONFIG_SATA_SVW is not set
+# CONFIG_SATA_ULI is not set
+# CONFIG_SATA_VIA is not set
+# CONFIG_SATA_VITESSE is not set
+# CONFIG_PATA_ALI is not set
+# CONFIG_PATA_AMD is not set
+# CONFIG_PATA_ARTOP is not set
+# CONFIG_PATA_ATIIXP is not set
+# CONFIG_PATA_ATP867X is not set
+# CONFIG_PATA_CMD64X is not set
+# CONFIG_PATA_CS5520 is not set
+# CONFIG_PATA_CS5530 is not set
+# CONFIG_PATA_CS5536 is not set
+# CONFIG_PATA_CYPRESS is not set
+# CONFIG_PATA_EFAR is not set
+# CONFIG_PATA_HPT366 is not set
+# CONFIG_PATA_HPT37X is not set
+# CONFIG_PATA_HPT3X2N is not set
+# CONFIG_PATA_HPT3X3 is not set
+# CONFIG_PATA_IT8213 is not set
+# CONFIG_PATA_IT821X is not set
+# CONFIG_PATA_JMICRON is not set
+# CONFIG_PATA_MARVELL is not set
+# CONFIG_PATA_NETCELL is not set
+# CONFIG_PATA_NINJA32 is not set
+# CONFIG_PATA_NS87415 is not set
+# CONFIG_PATA_OLDPIIX is not set
+# CONFIG_PATA_OPTIDMA is not set
+# CONFIG_PATA_PDC2027X is not set
+# CONFIG_PATA_PDC_OLD is not set
+# CONFIG_PATA_RADISYS is not set
+# CONFIG_PATA_RDC is not set
+# CONFIG_PATA_SC1200 is not set
+CONFIG_PATA_SCH=y
+# CONFIG_PATA_SERVERWORKS is not set
+# CONFIG_PATA_SIL680 is not set
+# CONFIG_PATA_SIS is not set
+# CONFIG_PATA_TOSHIBA is not set
+# CONFIG_PATA_TRIFLEX is not set
+# CONFIG_PATA_VIA is not set
+# CONFIG_PATA_WINBOND is not set
+# CONFIG_PATA_CMD640_PCI is not set
+# CONFIG_PATA_MPIIX is not set
+# CONFIG_PATA_NS87410 is not set
+# CONFIG_PATA_OPTI is not set
+# CONFIG_PATA_PLATFORM is not set
+# CONFIG_PATA_RZ1000 is not set
+# CONFIG_PATA_ACPI is not set
+# CONFIG_ATA_GENERIC is not set
+# CONFIG_PATA_LEGACY is not set
+# CONFIG_MD_LINEAR is not set
+CONFIG_MD_RAID0=y
+CONFIG_MD_RAID1=y
+CONFIG_MD_RAID10=y
+CONFIG_MD_RAID456=y
+# CONFIG_MD_MULTIPATH is not set
+# CONFIG_MD_FAULTY is not set
+# CONFIG_BCACHE is not set
+CONFIG_DM_MQ_DEFAULT=y
+CONFIG_DM_CRYPT=y
+# CONFIG_DM_SNAPSHOT is not set
+# CONFIG_DM_THIN_PROVISIONING is not set
+# CONFIG_DM_CACHE is not set
+CONFIG_DM_MIRROR=y
+CONFIG_DM_RAID=y
+# CONFIG_DM_LOG_USERSPACE is not set
+CONFIG_DM_ZERO=y
+CONFIG_DM_MULTIPATH=y
+# CONFIG_DM_DELAY is not set
+CONFIG_DM_UEVENT=y
+# CONFIG_DM_FLAKEY is not set
+# CONFIG_DM_VERITY is not set
+CONFIG_TARGET_CORE=m
+CONFIG_ISCSI_TARGET=m
+# CONFIG_FUSION is not set
+# CONFIG_FIREWIRE is not set
+# CONFIG_FIREWIRE_NOSY is not set
+# CONFIG_I2O is not set
+# CONFIG_MACINTOSH_DRIVERS is not set
+# CONFIG_DUMMY is not set
+# CONFIG_EQUALIZER is not set
+# CONFIG_NET_FC is not set
+# CONFIG_MII is not set
+# CONFIG_IFB is not set
+# CONFIG_MACVLAN is not set
+# CONFIG_VXLAN is not set
+# CONFIG_NETCONSOLE is not set
+# CONFIG_NETPOLL is not set
+# CONFIG_NET_POLL_CONTROLLER is not set
+# CONFIG_TUN is not set
+# CONFIG_VETH is not set
+# CONFIG_ARCNET is not set
+# CONFIG_NET_DSA_MV88E6XXX is not set
+# CONFIG_NET_DSA_MV88E6060 is not set
+# CONFIG_NET_DSA_MV88E6XXX_NEED_PPU is not set
+# CONFIG_NET_DSA_MV88E6131 is not set
+# CONFIG_NET_DSA_MV88E6123_61_65 is not set
+# CONFIG_VORTEX is not set
+# CONFIG_TYPHOON is not set
+# CONFIG_ADAPTEC_STARFIRE is not set
+# CONFIG_ACENIC is not set
+# CONFIG_AMD8111_ETH is not set
+# CONFIG_PCNET32 is not set
+CONFIG_AQTION=y
+# CONFIG_ATL2 is not set
+# CONFIG_ATL1 is not set
+# CONFIG_ATL1E is not set
+# CONFIG_ATL1C is not set
+# CONFIG_ALX is not set
+# CONFIG_ARM_AT91_ETHER is not set
+# CONFIG_MACB is not set
+# CONFIG_B44 is not set
+# CONFIG_BNX2 is not set
+# CONFIG_CNIC is not set
+# CONFIG_TIGON3 is not set
+# CONFIG_BNX2X is not set
+# CONFIG_BNA is not set
+# CONFIG_NET_CALXEDA_XGMAC is not set
+# CONFIG_CHELSIO_T1 is not set
+# CONFIG_CHELSIO_T3 is not set
+# CONFIG_CHELSIO_T4 is not set
+# CONFIG_CHELSIO_T4VF is not set
+# CONFIG_ENIC is not set
+# CONFIG_DNET is not set
+# CONFIG_NET_TULIP is not set
+# CONFIG_DL2K is not set
+# CONFIG_SUNDANCE is not set
+# CONFIG_BE2NET is not set
+# CONFIG_S2IO is not set
+# CONFIG_VXGE is not set
+# CONFIG_HP100 is not set
+# CONFIG_E100 is not set
+CONFIG_E1000=y
+CONFIG_IGB=y
+# CONFIG_IGBVF is not set
+# CONFIG_IXGB is not set
+CONFIG_IXGBE=y
+# CONFIG_IXGBEVF is not set
+# CONFIG_IP1000 is not set
+# CONFIG_JME is not set
+# CONFIG_MVMDIO is not set
+# CONFIG_SKGE is not set
+# CONFIG_SKY2 is not set
+# CONFIG_MLX4_EN is not set
+# CONFIG_MLX4_CORE is not set
+# CONFIG_KS8851_MLL is not set
+# CONFIG_KSZ884X_PCI is not set
+# CONFIG_MYRI10GE is not set
+# CONFIG_FEALNX is not set
+# CONFIG_NATSEMI is not set
+# CONFIG_NS83820 is not set
+# CONFIG_NE2K_PCI is not set
+# CONFIG_FORCEDETH is not set
+# CONFIG_PCH_GBE is not set
+# CONFIG_ETHOC is not set
+# CONFIG_HAMACHI is not set
+# CONFIG_YELLOWFIN is not set
+# CONFIG_QLA3XXX is not set
+# CONFIG_QLCNIC is not set
+# CONFIG_QLGE is not set
+# CONFIG_NETXEN_NIC is not set
+# CONFIG_8139CP is not set
+# CONFIG_8139TOO is not set
+# CONFIG_R8169 is not set
+# CONFIG_R6040 is not set
+# CONFIG_SC92031 is not set
+# CONFIG_SIS900 is not set
+# CONFIG_SIS190 is not set
+# CONFIG_SFC is not set
+# CONFIG_EPIC100 is not set
+# CONFIG_SMSC9420 is not set
+# CONFIG_STMMAC_ETH is not set
+# CONFIG_HAPPYMEAL is not set
+# CONFIG_SUNGEM is not set
+# CONFIG_CASSINI is not set
+# CONFIG_NIU is not set
+# CONFIG_TEHUTI is not set
+# CONFIG_TLAN is not set
+# CONFIG_VIA_RHINE is not set
+# CONFIG_VIA_VELOCITY is not set
+# CONFIG_WIZNET_W5100 is not set
+# CONFIG_WIZNET_W5300 is not set
+# CONFIG_FDDI is not set
+# CONFIG_NET_SB1000 is not set
+CONFIG_AT803X_PHY=y
+# CONFIG_AMD_PHY is not set
+# CONFIG_BCM87XX_PHY is not set
+# CONFIG_MICREL_PHY is not set
+# CONFIG_PPP is not set
+# CONFIG_SLIP is not set
+# CONFIG_USB_CATC is not set
+# CONFIG_USB_KAWETH is not set
+# CONFIG_USB_PEGASUS is not set
+# CONFIG_USB_RTL8150 is not set
+# CONFIG_USB_RTL8152 is not set
+# CONFIG_USB_USBNET is not set
+# CONFIG_USB_HSO is not set
+# CONFIG_USB_IPHETH is not set
+# CONFIG_WLAN is not set
+# CONFIG_WAN is not set
+# CONFIG_VMXNET3 is not set
+# CONFIG_ISDN is not set
+# CONFIG_INPUT_FF_MEMLESS is not set
+# CONFIG_INPUT_POLLDEV is not set
+# CONFIG_INPUT_SPARSEKMAP is not set
+# CONFIG_INPUT_MATRIXKMAP is not set
+# CONFIG_INPUT_JOYDEV is not set
+# CONFIG_INPUT_EVBUG is not set
+# CONFIG_KEYBOARD_ADP5588 is not set
+# CONFIG_KEYBOARD_ADP5589 is not set
+# CONFIG_KEYBOARD_QT1070 is not set
+# CONFIG_KEYBOARD_QT2160 is not set
+# CONFIG_KEYBOARD_LKKBD is not set
+# CONFIG_KEYBOARD_TCA6416 is not set
+# CONFIG_KEYBOARD_TCA8418 is not set
+# CONFIG_KEYBOARD_LM8333 is not set
+# CONFIG_KEYBOARD_MAX7359 is not set
+# CONFIG_KEYBOARD_MCS is not set
+# CONFIG_KEYBOARD_MPR121 is not set
+# CONFIG_KEYBOARD_NEWTON is not set
+# CONFIG_KEYBOARD_OPENCORES is not set
+# CONFIG_KEYBOARD_STOWAWAY is not set
+# CONFIG_KEYBOARD_SUNKBD is not set
+# CONFIG_KEYBOARD_XTKBD is not set
+CONFIG_MOUSE_PS2=y
+# CONFIG_MOUSE_PS2_TOUCHKIT is not set
+# CONFIG_MOUSE_SERIAL is not set
+# CONFIG_MOUSE_APPLETOUCH is not set
+# CONFIG_MOUSE_BCM5974 is not set
+# CONFIG_MOUSE_CYAPA is not set
+# CONFIG_MOUSE_VSXXXAA is not set
+# CONFIG_MOUSE_SYNAPTICS_I2C is not set
+# CONFIG_MOUSE_SYNAPTICS_USB is not set
+# CONFIG_JOYSTICK_ANALOG is not set
+# CONFIG_JOYSTICK_A3D is not set
+# CONFIG_JOYSTICK_ADI is not set
+# CONFIG_JOYSTICK_COBRA is not set
+# CONFIG_JOYSTICK_GF2K is not set
+# CONFIG_JOYSTICK_GRIP is not set
+# CONFIG_JOYSTICK_GRIP_MP is not set
+# CONFIG_JOYSTICK_GUILLEMOT is not set
+# CONFIG_JOYSTICK_INTERACT is not set
+# CONFIG_JOYSTICK_SIDEWINDER is not set
+# CONFIG_JOYSTICK_TMDC is not set
+# CONFIG_JOYSTICK_IFORCE is not set
+# CONFIG_JOYSTICK_WARRIOR is not set
+# CONFIG_JOYSTICK_MAGELLAN is not set
+# CONFIG_JOYSTICK_SPACEORB is not set
+# CONFIG_JOYSTICK_SPACEBALL is not set
+# CONFIG_JOYSTICK_STINGER is not set
+# CONFIG_JOYSTICK_TWIDJOY is not set
+# CONFIG_JOYSTICK_ZHENHUA is not set
+# CONFIG_JOYSTICK_AS5011 is not set
+# CONFIG_JOYSTICK_JOYDUMP is not set
+# CONFIG_JOYSTICK_XPAD is not set
+# CONFIG_TABLET_USB_ACECAD is not set
+# CONFIG_TABLET_USB_AIPTEK is not set
+# CONFIG_TABLET_USB_GTCO is not set
+# CONFIG_TABLET_USB_HANWANG is not set
+# CONFIG_TABLET_USB_KBTAB is not set
+# CONFIG_TABLET_USB_WACOM is not set
+# CONFIG_TOUCHSCREEN_AD7879 is not set
+# CONFIG_TOUCHSCREEN_ATMEL_MXT is not set
+# CONFIG_TOUCHSCREEN_BU21013 is not set
+# CONFIG_TOUCHSCREEN_CYTTSP_CORE is not set
+# CONFIG_TOUCHSCREEN_DYNAPRO is not set
+# CONFIG_TOUCHSCREEN_HAMPSHIRE is not set
+# CONFIG_TOUCHSCREEN_EETI is not set
+# CONFIG_TOUCHSCREEN_FUJITSU is not set
+# CONFIG_TOUCHSCREEN_ILI210X is not set
+# CONFIG_TOUCHSCREEN_GUNZE is not set
+# CONFIG_TOUCHSCREEN_ELO is not set
+# CONFIG_TOUCHSCREEN_WACOM_W8001 is not set
+# CONFIG_TOUCHSCREEN_WACOM_I2C is not set
+# CONFIG_TOUCHSCREEN_MAX11801 is not set
+# CONFIG_TOUCHSCREEN_MCS5000 is not set
+# CONFIG_TOUCHSCREEN_MMS114 is not set
+# CONFIG_TOUCHSCREEN_MTOUCH is not set
+# CONFIG_TOUCHSCREEN_INEXIO is not set
+# CONFIG_TOUCHSCREEN_MK712 is not set
+# CONFIG_TOUCHSCREEN_PENMOUNT is not set
+# CONFIG_TOUCHSCREEN_EDT_FT5X06 is not set
+# CONFIG_TOUCHSCREEN_TOUCHRIGHT is not set
+# CONFIG_TOUCHSCREEN_TOUCHWIN is not set
+# CONFIG_TOUCHSCREEN_PIXCIR is not set
+# CONFIG_TOUCHSCREEN_USB_COMPOSITE is not set
+# CONFIG_TOUCHSCREEN_TOUCHIT213 is not set
+# CONFIG_TOUCHSCREEN_TSC_SERIO is not set
+# CONFIG_TOUCHSCREEN_TSC2007 is not set
+# CONFIG_TOUCHSCREEN_ST1232 is not set
+# CONFIG_TOUCHSCREEN_TPS6507X is not set
+# CONFIG_INPUT_AD714X is not set
+# CONFIG_INPUT_BMA150 is not set
+# CONFIG_INPUT_PCSPKR is not set
+# CONFIG_INPUT_MMA8450 is not set
+# CONFIG_INPUT_MPU3050 is not set
+# CONFIG_INPUT_ATLAS_BTNS is not set
+# CONFIG_INPUT_ATI_REMOTE2 is not set
+# CONFIG_INPUT_KEYSPAN_REMOTE is not set
+# CONFIG_INPUT_KXTJ9 is not set
+# CONFIG_INPUT_POWERMATE is not set
+# CONFIG_INPUT_YEALINK is not set
+# CONFIG_INPUT_CM109 is not set
+# CONFIG_INPUT_PCF8574 is not set
+# CONFIG_INPUT_ADXL34X is not set
+# CONFIG_INPUT_CMA3000 is not set
+# CONFIG_SERIO_SERPORT is not set
+# CONFIG_SERIO_CT82C710 is not set
+# CONFIG_SERIO_PCIPS2 is not set
+# CONFIG_SERIO_RAW is not set
+# CONFIG_SERIO_ALTERA_PS2 is not set
+# CONFIG_SERIO_PS2MULT is not set
+# CONFIG_SERIO_ARC_PS2 is not set
+# CONFIG_GAMEPORT is not set
+CONFIG_LEGACY_PTY_COUNT=16
+# CONFIG_ROCKETPORT is not set
+# CONFIG_CYCLADES is not set
+# CONFIG_MOXA_INTELLIO is not set
+# CONFIG_MOXA_SMARTIO is not set
+# CONFIG_SYNCLINKMP is not set
+# CONFIG_SYNCLINK_GT is not set
+# CONFIG_NOZOMI is not set
+# CONFIG_ISI is not set
+# CONFIG_N_HDLC is not set
+# CONFIG_TRACE_SINK is not set
+CONFIG_SERIAL_8250_DEPRECATED_OPTIONS=y
+CONFIG_SERIAL_8250_RUNTIME_UARTS=4
+CONFIG_SERIAL_8250_DW=y
+# CONFIG_SERIAL_8250_FINTEK is not set
+# CONFIG_SERIAL_MFD_HSU is not set
+# CONFIG_SERIAL_JSM is not set
+# CONFIG_SERIAL_SCCNXP is not set
+# CONFIG_SERIAL_TIMBERDALE is not set
+# CONFIG_SERIAL_ALTERA_JTAGUART is not set
+# CONFIG_SERIAL_ALTERA_UART is not set
+# CONFIG_SERIAL_PCH_UART is not set
+# CONFIG_SERIAL_ARC is not set
+# CONFIG_SERIAL_RP2 is not set
+# CONFIG_IPMI_HANDLER is not set
+# CONFIG_HW_RANDOM_TIMERIOMEM is not set
+CONFIG_HW_RANDOM_INTEL=y
+CONFIG_HW_RANDOM_AMD=y
+CONFIG_HW_RANDOM_VIA=y
+# CONFIG_NVRAM is not set
+# CONFIG_R3964 is not set
+# CONFIG_APPLICOM is not set
+# CONFIG_MWAVE is not set
+# CONFIG_RAW_DRIVER is not set
+# CONFIG_HANGCHECK_TIMER is not set
+# CONFIG_TCG_TPM is not set
+# CONFIG_TELCLOCK is not set
+CONFIG_I2C_CHARDEV=y
+CONFIG_I2C_MUX=y
+CONFIG_I2C_MUX_PCA9541=y
+CONFIG_I2C_MUX_PCA954x=y
+# CONFIG_I2C_HELPER_AUTO is not set
+CONFIG_I2C_SMBUS=y
+CONFIG_I2C_ALGOBIT=y
+CONFIG_I2C_ALGOPCA=y
+CONFIG_I2C_ALI1535=y
+CONFIG_I2C_ALI1563=y
+CONFIG_I2C_ALI15X3=y
+CONFIG_I2C_AMD756=y
+CONFIG_I2C_AMD756_S4882=y
+CONFIG_I2C_AMD8111=y
+CONFIG_I2C_I801=y
+CONFIG_I2C_ISCH=y
+# CONFIG_I2C_ISMT is not set
+CONFIG_I2C_PIIX4=y
+CONFIG_I2C_NFORCE2=y
+CONFIG_I2C_NFORCE2_S4985=y
+CONFIG_I2C_SIS5595=y
+CONFIG_I2C_SIS630=y
+CONFIG_I2C_SIS96X=y
+CONFIG_I2C_VIA=y
+CONFIG_I2C_VIAPRO=y
+CONFIG_I2C_SCMI=y
+# CONFIG_I2C_DESIGNWARE_PCI is not set
+CONFIG_I2C_EG20T=y
+CONFIG_I2C_INTEL_MID=y
+CONFIG_I2C_OCORES=y
+CONFIG_I2C_PCA_PLATFORM=y
+CONFIG_I2C_SIMTEC=y
+CONFIG_I2C_XILINX=y
+CONFIG_I2C_PARPORT_LIGHT=y
+CONFIG_I2C_TAOS_EVM=y
+# CONFIG_I2C_STUB is not set
+CONFIG_I2C_DEBUG_CORE=y
+CONFIG_I2C_DEBUG_ALGO=y
+CONFIG_I2C_DEBUG_BUS=y
+# CONFIG_SPI is not set
+# CONFIG_SSBI is not set
+# CONFIG_HSI is not set
+CONFIG_PPS=y
+# CONFIG_PPS_CLIENT_LDISC is not set
+# CONFIG_PPS_CLIENT_GPIO is not set
+CONFIG_PTP_1588_CLOCK=y
+# CONFIG_PTP_1588_CLOCK_PCH is not set
+CONFIG_PINCTRL_DENVERTON=y
+CONFIG_GPIOLIB=y
+CONFIG_GPIO_IT87=y
+# CONFIG_W1 is not set
+# CONFIG_PDA_POWER is not set
+# CONFIG_TEST_POWER is not set
+# CONFIG_BATTERY_DS2780 is not set
+# CONFIG_BATTERY_DS2781 is not set
+# CONFIG_BATTERY_DS2782 is not set
+# CONFIG_BATTERY_SBS is not set
+# CONFIG_BATTERY_BQ27x00 is not set
+# CONFIG_BATTERY_MAX17040 is not set
+# CONFIG_BATTERY_MAX17042 is not set
+# CONFIG_CHARGER_MAX8903 is not set
+# CONFIG_CHARGER_LP8727 is not set
+# CONFIG_CHARGER_BQ2415X is not set
+# CONFIG_CHARGER_SMB347 is not set
+# CONFIG_BATTERY_GOLDFISH is not set
+CONFIG_POWER_SUPPLY=y
+CONFIG_POWER_RESET=y
+# CONFIG_POWER_AVS is not set
+CONFIG_HWMON_VID=y
+# CONFIG_SENSORS_ABITUGURU is not set
+# CONFIG_SENSORS_ABITUGURU3 is not set
+# CONFIG_SENSORS_AD7414 is not set
+# CONFIG_SENSORS_AD7418 is not set
+# CONFIG_SENSORS_ADM1021 is not set
+# CONFIG_SENSORS_ADM1025 is not set
+# CONFIG_SENSORS_ADM1026 is not set
+# CONFIG_SENSORS_ADM1029 is not set
+# CONFIG_SENSORS_ADM1031 is not set
+# CONFIG_SENSORS_ADM9240 is not set
+# CONFIG_SENSORS_ADT7410 is not set
+# CONFIG_SENSORS_ADT7411 is not set
+# CONFIG_SENSORS_ADT7462 is not set
+# CONFIG_SENSORS_ADT7470 is not set
+# CONFIG_SENSORS_ADT7475 is not set
+# CONFIG_SENSORS_ASC7621 is not set
+# CONFIG_SENSORS_K8TEMP is not set
+# CONFIG_SENSORS_K10TEMP is not set
+# CONFIG_SENSORS_FAM15H_POWER is not set
+# CONFIG_SENSORS_ASB100 is not set
+# CONFIG_SENSORS_ATXP1 is not set
+# CONFIG_SENSORS_DS620 is not set
+# CONFIG_SENSORS_DS1621 is not set
+# CONFIG_SENSORS_I5K_AMB is not set
+# CONFIG_SENSORS_F71805F is not set
+# CONFIG_SENSORS_F71882FG is not set
+# CONFIG_SENSORS_F75375S is not set
+# CONFIG_SENSORS_FSCHMD is not set
+# CONFIG_SENSORS_G760A is not set
+# CONFIG_SENSORS_GL518SM is not set
+# CONFIG_SENSORS_GL520SM is not set
+# CONFIG_SENSORS_HIH6130 is not set
+# CONFIG_SENSORS_CORETEMP is not set
+CONFIG_SENSORS_IT87=y
+# CONFIG_SENSORS_JC42 is not set
+# CONFIG_SENSORS_LINEAGE is not set
+# CONFIG_SENSORS_LM63 is not set
+# CONFIG_SENSORS_LM73 is not set
+# CONFIG_SENSORS_LM75 is not set
+# CONFIG_SENSORS_LM77 is not set
+# CONFIG_SENSORS_LM78 is not set
+# CONFIG_SENSORS_LM80 is not set
+# CONFIG_SENSORS_LM83 is not set
+# CONFIG_SENSORS_LM85 is not set
+# CONFIG_SENSORS_LM87 is not set
+# CONFIG_SENSORS_LM90 is not set
+# CONFIG_SENSORS_LM92 is not set
+# CONFIG_SENSORS_LM93 is not set
+# CONFIG_SENSORS_LTC4151 is not set
+# CONFIG_SENSORS_LTC4215 is not set
+# CONFIG_SENSORS_LTC4245 is not set
+# CONFIG_SENSORS_LTC4261 is not set
+# CONFIG_SENSORS_LM95234 is not set
+# CONFIG_SENSORS_LM95241 is not set
+# CONFIG_SENSORS_LM95245 is not set
+# CONFIG_SENSORS_MAX16065 is not set
+# CONFIG_SENSORS_MAX1619 is not set
+# CONFIG_SENSORS_MAX1668 is not set
+# CONFIG_SENSORS_MAX197 is not set
+# CONFIG_SENSORS_MAX6639 is not set
+# CONFIG_SENSORS_MAX6642 is not set
+# CONFIG_SENSORS_MAX6650 is not set
+# CONFIG_SENSORS_MAX6697 is not set
+# CONFIG_SENSORS_MCP3021 is not set
+# CONFIG_SENSORS_NCT6775 is not set
+# CONFIG_SENSORS_NTC_THERMISTOR is not set
+# CONFIG_SENSORS_PC87360 is not set
+# CONFIG_SENSORS_PC87427 is not set
+# CONFIG_SENSORS_PCF8591 is not set
+# CONFIG_PMBUS is not set
+# CONFIG_SENSORS_SHT21 is not set
+# CONFIG_SENSORS_SIS5595 is not set
+# CONFIG_SENSORS_SMM665 is not set
+# CONFIG_SENSORS_DME1737 is not set
+# CONFIG_SENSORS_EMC1403 is not set
+# CONFIG_SENSORS_EMC2103 is not set
+# CONFIG_SENSORS_EMC6W201 is not set
+# CONFIG_SENSORS_SMSC47M1 is not set
+# CONFIG_SENSORS_SMSC47M192 is not set
+# CONFIG_SENSORS_SMSC47B397 is not set
+# CONFIG_SENSORS_SCH56XX_COMMON is not set
+# CONFIG_SENSORS_ADS1015 is not set
+# CONFIG_SENSORS_ADS7828 is not set
+# CONFIG_SENSORS_AMC6821 is not set
+# CONFIG_SENSORS_INA209 is not set
+# CONFIG_SENSORS_INA2XX is not set
+# CONFIG_SENSORS_THMC50 is not set
+# CONFIG_SENSORS_TMP102 is not set
+# CONFIG_SENSORS_TMP401 is not set
+# CONFIG_SENSORS_TMP421 is not set
+# CONFIG_SENSORS_VIA_CPUTEMP is not set
+# CONFIG_SENSORS_VIA686A is not set
+# CONFIG_SENSORS_VT1211 is not set
+# CONFIG_SENSORS_VT8231 is not set
+# CONFIG_SENSORS_W83781D is not set
+# CONFIG_SENSORS_W83791D is not set
+# CONFIG_SENSORS_W83792D is not set
+# CONFIG_SENSORS_W83793 is not set
+# CONFIG_SENSORS_W83795 is not set
+# CONFIG_SENSORS_W83L785TS is not set
+# CONFIG_SENSORS_W83L786NG is not set
+# CONFIG_SENSORS_W83627HF is not set
+# CONFIG_SENSORS_W83627EHF is not set
+# CONFIG_SENSORS_APPLESMC is not set
+# CONFIG_SENSORS_ACPI_POWER is not set
+# CONFIG_SENSORS_ATK0110 is not set
+# CONFIG_THERMAL_GOV_FAIR_SHARE is not set
+# CONFIG_THERMAL_GOV_USER_SPACE is not set
+# CONFIG_CPU_THERMAL is not set
+# CONFIG_THERMAL_EMULATION is not set
+# CONFIG_INTEL_POWERCLAMP is not set
+CONFIG_WATCHDOG=y
+# CONFIG_SSB is not set
+# CONFIG_BCMA is not set
+# CONFIG_MFD_CS5535 is not set
+# CONFIG_MFD_AS3711 is not set
+# CONFIG_PMIC_ADP5520 is not set
+# CONFIG_MFD_CROS_EC is not set
+# CONFIG_PMIC_DA903X is not set
+# CONFIG_MFD_DA9052_I2C is not set
+# CONFIG_MFD_DA9055 is not set
+# CONFIG_MFD_MC13XXX_I2C is not set
+# CONFIG_HTC_PASIC3 is not set
+CONFIG_LPC_ICH=m
+CONFIG_LPC_SCH=y
+# CONFIG_MFD_JANZ_CMODIO is not set
+# CONFIG_MFD_88PM800 is not set
+# CONFIG_MFD_88PM805 is not set
+# CONFIG_MFD_88PM860X is not set
+# CONFIG_MFD_MAX77686 is not set
+# CONFIG_MFD_MAX77693 is not set
+# CONFIG_MFD_MAX8907 is not set
+# CONFIG_MFD_MAX8925 is not set
+# CONFIG_MFD_MAX8997 is not set
+# CONFIG_MFD_MAX8998 is not set
+# CONFIG_MFD_VIPERBOARD is not set
+# CONFIG_MFD_RETU is not set
+# CONFIG_MFD_PCF50633 is not set
+# CONFIG_MFD_RDC321X is not set
+# CONFIG_MFD_RTSX_PCI is not set
+# CONFIG_MFD_RC5T583 is not set
+# CONFIG_MFD_SEC_CORE is not set
+# CONFIG_MFD_SI476X_CORE is not set
+# CONFIG_MFD_SM501 is not set
+# CONFIG_MFD_SMSC is not set
+# CONFIG_ABX500_CORE is not set
+# CONFIG_MFD_STMPE is not set
+# CONFIG_MFD_SYSCON is not set
+# CONFIG_MFD_TI_AM335X_TSCADC is not set
+# CONFIG_MFD_LP8788 is not set
+# CONFIG_MFD_PALMAS is not set
+# CONFIG_TPS6105X is not set
+# CONFIG_TPS6507X is not set
+# CONFIG_MFD_TPS65090 is not set
+# CONFIG_MFD_TPS65217 is not set
+# CONFIG_MFD_TPS6586X is not set
+# CONFIG_MFD_TPS80031 is not set
+# CONFIG_TWL6040_CORE is not set
+# CONFIG_MFD_WL1273_CORE is not set
+# CONFIG_MFD_LM3533 is not set
+# CONFIG_MFD_TC3589X is not set
+# CONFIG_MFD_VX855 is not set
+# CONFIG_MFD_ARIZONA_I2C is not set
+# CONFIG_MFD_WM8400 is not set
+# CONFIG_MFD_WM831X_I2C is not set
+# CONFIG_MFD_WM8350_I2C is not set
+# CONFIG_MFD_WM8994 is not set
+# CONFIG_REGULATOR is not set
+# CONFIG_MEDIA_SUPPORT is not set
+# CONFIG_AGP_SIS is not set
+CONFIG_DRM=y
+CONFIG_DRM_KMS_HELPER=y
+# CONFIG_DRM_LOAD_EDID_FIRMWARE is not set
+# CONFIG_DRM_I2C_CH7006 is not set
+# CONFIG_DRM_I2C_SIL164 is not set
+# CONFIG_DRM_I2C_NXP_TDA998X is not set
+# CONFIG_DRM_TDFX is not set
+# CONFIG_DRM_R128 is not set
+# CONFIG_DRM_RADEON is not set
+# CONFIG_DRM_NOUVEAU is not set
+# CONFIG_DRM_I810 is not set
+CONFIG_DRM_I915=y
+CONFIG_DRM_I915_PRELIMINARY_HW_SUPPORT=y
+# CONFIG_DRM_I915_KMS is not set
+# CONFIG_DRM_MGA is not set
+# CONFIG_DRM_SIS is not set
+# CONFIG_DRM_VIA is not set
+# CONFIG_DRM_SAVAGE is not set
+# CONFIG_DRM_VMWGFX is not set
+# CONFIG_DRM_GMA500 is not set
+# CONFIG_DRM_UDL is not set
+# CONFIG_DRM_AST is not set
+# CONFIG_DRM_CIRRUS_QEMU is not set
+# CONFIG_DRM_QXL is not set
+# CONFIG_VGASTATE is not set
+CONFIG_VIDEO_OUTPUT_CONTROL=y
+# CONFIG_FB_DDC is not set
+# CONFIG_FB_SYS_FILLRECT is not set
+# CONFIG_FB_SYS_COPYAREA is not set
+# CONFIG_FB_SYS_IMAGEBLIT is not set
+# CONFIG_FB_SYS_FOPS is not set
+# CONFIG_FB_SVGALIB is not set
+# CONFIG_FB_BACKLIGHT is not set
+# CONFIG_FB_CIRRUS is not set
+# CONFIG_FB_PM2 is not set
+# CONFIG_FB_CYBER2000 is not set
+# CONFIG_FB_ARC is not set
+# CONFIG_FB_VGA16 is not set
+# CONFIG_FB_UVESA is not set
+# CONFIG_FB_N411 is not set
+# CONFIG_FB_HGA is not set
+# CONFIG_FB_S1D13XXX is not set
+# CONFIG_FB_NVIDIA is not set
+# CONFIG_FB_RIVA is not set
+# CONFIG_FB_I740 is not set
+# CONFIG_FB_LE80578 is not set
+# CONFIG_FB_MATROX is not set
+# CONFIG_FB_RADEON is not set
+# CONFIG_FB_ATY128 is not set
+# CONFIG_FB_ATY is not set
+# CONFIG_FB_S3 is not set
+# CONFIG_FB_SAVAGE is not set
+# CONFIG_FB_SIS is not set
+# CONFIG_FB_VIA is not set
+# CONFIG_FB_NEOMAGIC is not set
+# CONFIG_FB_KYRO is not set
+# CONFIG_FB_3DFX is not set
+# CONFIG_FB_VOODOO1 is not set
+# CONFIG_FB_VT8623 is not set
+# CONFIG_FB_TRIDENT is not set
+# CONFIG_FB_ARK is not set
+# CONFIG_FB_PM3 is not set
+# CONFIG_FB_CARMINE is not set
+# CONFIG_FB_GEODE_LX is not set
+# CONFIG_FB_GEODE_GX is not set
+# CONFIG_FB_GEODE_GX1 is not set
+# CONFIG_FB_TMIO is not set
+# CONFIG_FB_SMSCUFX is not set
+# CONFIG_FB_UDL is not set
+# CONFIG_FB_GOLDFISH is not set
+# CONFIG_FB_METRONOME is not set
+# CONFIG_FB_MB862XX is not set
+# CONFIG_FB_BROADSHEET is not set
+# CONFIG_FB_AUO_K190X is not set
+# CONFIG_EXYNOS_VIDEO is not set
+# CONFIG_LCD_PLATFORM is not set
+CONFIG_BACKLIGHT_GENERIC=y
+# CONFIG_BACKLIGHT_APPLE is not set
+# CONFIG_BACKLIGHT_SAHARA is not set
+# CONFIG_BACKLIGHT_ADP8860 is not set
+# CONFIG_BACKLIGHT_ADP8870 is not set
+# CONFIG_BACKLIGHT_LM3630 is not set
+# CONFIG_BACKLIGHT_LM3639 is not set
+# CONFIG_BACKLIGHT_LP855X is not set
+# CONFIG_SOUND is not set
+CONFIG_HID=y
+# CONFIG_HID_BATTERY_STRENGTH is not set
+# CONFIG_UHID is not set
+CONFIG_HID_GENERIC=y
+# CONFIG_HID_A4TECH is not set
+# CONFIG_HID_ACRUX is not set
+# CONFIG_HID_APPLE is not set
+# CONFIG_HID_APPLEIR is not set
+# CONFIG_HID_AUREAL is not set
+# CONFIG_HID_BELKIN is not set
+# CONFIG_HID_CHERRY is not set
+# CONFIG_HID_CHICONY is not set
+# CONFIG_HID_CYPRESS is not set
+# CONFIG_HID_DRAGONRISE is not set
+# CONFIG_HID_EMS_FF is not set
+# CONFIG_HID_ELECOM is not set
+# CONFIG_HID_EZKEY is not set
+# CONFIG_HID_HOLTEK is not set
+# CONFIG_HID_KEYTOUCH is not set
+# CONFIG_HID_KYE is not set
+# CONFIG_HID_UCLOGIC is not set
+# CONFIG_HID_WALTOP is not set
+# CONFIG_HID_GYRATION is not set
+# CONFIG_HID_ICADE is not set
+# CONFIG_HID_TWINHAN is not set
+# CONFIG_HID_KENSINGTON is not set
+# CONFIG_HID_LCPOWER is not set
+# CONFIG_HID_LENOVO_TPKBD is not set
+# CONFIG_HID_LOGITECH is not set
+# CONFIG_HID_MAGICMOUSE is not set
+# CONFIG_HID_MICROSOFT is not set
+# CONFIG_HID_MONTEREY is not set
+# CONFIG_HID_MULTITOUCH is not set
+# CONFIG_HID_NTRIG is not set
+# CONFIG_HID_ORTEK is not set
+# CONFIG_HID_PANTHERLORD is not set
+# CONFIG_HID_PETALYNX is not set
+# CONFIG_HID_PICOLCD is not set
+# CONFIG_HID_PRIMAX is not set
+# CONFIG_HID_PS3REMOTE is not set
+# CONFIG_HID_ROCCAT is not set
+# CONFIG_HID_SAITEK is not set
+# CONFIG_HID_SAMSUNG is not set
+# CONFIG_HID_SONY is not set
+# CONFIG_HID_SPEEDLINK is not set
+# CONFIG_HID_STEELSERIES is not set
+# CONFIG_HID_SUNPLUS is not set
+# CONFIG_HID_GREENASIA is not set
+# CONFIG_HID_SMARTJOYPLUS is not set
+# CONFIG_HID_TIVO is not set
+# CONFIG_HID_TOPSEED is not set
+# CONFIG_HID_THRUSTMASTER is not set
+# CONFIG_HID_ZEROPLUS is not set
+# CONFIG_HID_ZYDACRON is not set
+# CONFIG_HID_SENSOR_HUB is not set
+# CONFIG_USB_KBD is not set
+# CONFIG_USB_MOUSE is not set
+# CONFIG_I2C_HID is not set
+CONFIG_USB_COMMON=m
+CONFIG_USB=m
+# CONFIG_USB_DYNAMIC_MINORS is not set
+# CONFIG_USB_OTG is not set
+# CONFIG_USB_MON is not set
+# CONFIG_USB_WUSB_CBAF is not set
+# CONFIG_USB_C67X00_HCD is not set
+CONFIG_USB_XHCI_HCD=m
+CONFIG_USB_EHCI_HCD=m
+# CONFIG_USB_EHCI_ROOT_HUB_TT is not set
+# CONFIG_USB_EHCI_TT_NEWSCHED is not set
+CONFIG_USB_EHCI_PCI=m
+CONFIG_USB_EHCI_HCD_PLATFORM=y
+# CONFIG_USB_OXU210HP_HCD is not set
+# CONFIG_USB_ISP116X_HCD is not set
+# CONFIG_USB_ISP1760_HCD is not set
+# CONFIG_USB_ISP1362_HCD is not set
+CONFIG_USB_OHCI_HCD=m
+# CONFIG_USB_OHCI_HCD_PLATFORM is not set
+CONFIG_USB_UHCI_HCD=m
+# CONFIG_USB_SL811_HCD is not set
+# CONFIG_USB_R8A66597_HCD is not set
+# CONFIG_USB_ACM is not set
+# CONFIG_USB_WDM is not set
+# CONFIG_USB_TMC is not set
+# CONFIG_USB_STORAGE_REALTEK is not set
+# CONFIG_USB_STORAGE_DATAFAB is not set
+# CONFIG_USB_STORAGE_FREECOM is not set
+# CONFIG_USB_STORAGE_ISD200 is not set
+# CONFIG_USB_STORAGE_USBAT is not set
+# CONFIG_USB_STORAGE_SDDR09 is not set
+# CONFIG_USB_STORAGE_SDDR55 is not set
+# CONFIG_USB_STORAGE_JUMPSHOT is not set
+# CONFIG_USB_STORAGE_ALAUDA is not set
+# CONFIG_USB_STORAGE_ONETOUCH is not set
+# CONFIG_USB_STORAGE_KARMA is not set
+# CONFIG_USB_STORAGE_CYPRESS_ATACB is not set
+# CONFIG_USB_STORAGE_ENE_UB6250 is not set
+# CONFIG_USB_MDC800 is not set
+# CONFIG_USB_MICROTEK is not set
+# CONFIG_USB_DWC3 is not set
+# CONFIG_USB_CHIPIDEA is not set
+CONFIG_USB_SERIAL=m
+CONFIG_USB_SERIAL_PL2303=m
+# CONFIG_USB_EMI62 is not set
+# CONFIG_USB_EMI26 is not set
+# CONFIG_USB_ADUTUX is not set
+# CONFIG_USB_SEVSEG is not set
+# CONFIG_USB_RIO500 is not set
+# CONFIG_USB_LEGOTOWER is not set
+# CONFIG_USB_LCD is not set
+# CONFIG_USB_LED is not set
+# CONFIG_USB_CYPRESS_CY7C63 is not set
+# CONFIG_USB_CYTHERM is not set
+# CONFIG_USB_IDMOUSE is not set
+# CONFIG_USB_FTDI_ELAN is not set
+# CONFIG_USB_APPLEDISPLAY is not set
+# CONFIG_USB_SISUSBVGA is not set
+# CONFIG_USB_LD is not set
+# CONFIG_USB_TRANCEVIBRATOR is not set
+# CONFIG_USB_IOWARRIOR is not set
+# CONFIG_USB_TEST is not set
+# CONFIG_USB_ISIGHTFW is not set
+# CONFIG_USB_YUREX is not set
+# CONFIG_USB_EZUSB_FX2 is not set
+# CONFIG_USB_HSIC_USB3503 is not set
+# CONFIG_USB_PHY is not set
+# CONFIG_USB_GADGET is not set
+# CONFIG_UWB is not set
+# CONFIG_MMC is not set
+# CONFIG_MEMSTICK is not set
+# CONFIG_NEW_LEDS is not set
+# CONFIG_INFINIBAND is not set
+CONFIG_EDAC=y
+CONFIG_EDAC_MM_EDAC=y
+# CONFIG_RTC_DRV_DS1307 is not set
+# CONFIG_RTC_DRV_DS1374 is not set
+# CONFIG_RTC_DRV_DS1672 is not set
+# CONFIG_RTC_DRV_DS3232 is not set
+# CONFIG_RTC_DRV_MAX6900 is not set
+# CONFIG_RTC_DRV_RS5C372 is not set
+# CONFIG_RTC_DRV_ISL1208 is not set
+# CONFIG_RTC_DRV_ISL12022 is not set
+# CONFIG_RTC_DRV_X1205 is not set
+# CONFIG_RTC_DRV_PCF8523 is not set
+# CONFIG_RTC_DRV_PCF8563 is not set
+# CONFIG_RTC_DRV_PCF8583 is not set
+# CONFIG_RTC_DRV_M41T80 is not set
+# CONFIG_RTC_DRV_BQ32K is not set
+# CONFIG_RTC_DRV_S35390A is not set
+# CONFIG_RTC_DRV_FM3130 is not set
+# CONFIG_RTC_DRV_RX8581 is not set
+# CONFIG_RTC_DRV_RX8025 is not set
+# CONFIG_RTC_DRV_EM3027 is not set
+# CONFIG_RTC_DRV_RV3029C2 is not set
+# CONFIG_RTC_DRV_DS1286 is not set
+# CONFIG_RTC_DRV_DS1511 is not set
+# CONFIG_RTC_DRV_DS1553 is not set
+# CONFIG_RTC_DRV_DS1742 is not set
+# CONFIG_RTC_DRV_STK17TA8 is not set
+# CONFIG_RTC_DRV_M48T86 is not set
+# CONFIG_RTC_DRV_M48T35 is not set
+# CONFIG_RTC_DRV_M48T59 is not set
+# CONFIG_RTC_DRV_MSM6242 is not set
+# CONFIG_RTC_DRV_BQ4802 is not set
+# CONFIG_RTC_DRV_RP5C01 is not set
+# CONFIG_RTC_DRV_V3020 is not set
+# CONFIG_RTC_DRV_DS2404 is not set
+# CONFIG_RTC_DRV_HID_SENSOR_TIME is not set
+# CONFIG_DMADEVICES is not set
+# CONFIG_AUXDISPLAY is not set
+CONFIG_UIO=y
+# CONFIG_VFIO is not set
+# CONFIG_VIRT_DRIVERS is not set
+# CONFIG_VIRTIO_PCI is not set
+# CONFIG_VIRTIO_MMIO is not set
+# CONFIG_STAGING is not set
+# CONFIG_X86_PLATFORM_DEVICES is not set
+# CONFIG_MAILBOX is not set
+# CONFIG_AMD_IOMMU_V2 is not set
+# CONFIG_INTEL_IOMMU is not set
+CONFIG_IRQ_REMAP=y
+# CONFIG_STE_MODEM_RPROC is not set
+# CONFIG_PM_DEVFREQ is not set
+# CONFIG_EXTCON is not set
+CONFIG_MEMORY=y
+# CONFIG_IIO is not set
+# CONFIG_NTB is not set
+# CONFIG_VME_BUS is not set
+# CONFIG_PWM is not set
+# CONFIG_IPACK_BUS is not set
+# CONFIG_RESET_CONTROLLER is not set
+# CONFIG_DELL_RBU is not set
+# CONFIG_DCDBAS is not set
+# CONFIG_DMI_SYSFS is not set
+# CONFIG_ISCSI_IBFT is not set
+CONFIG_EFI_VARS_PSTORE=y
+# CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE is not set
+# CONFIG_REISERFS_FS is not set
+# CONFIG_JFS_FS is not set
+CONFIG_XFS_FS=y
+# CONFIG_XFS_RT is not set
+# CONFIG_GFS2_FS is not set
+CONFIG_BTRFS_FS=y
+# CONFIG_NILFS2_FS is not set
+# CONFIG_QFMT_V1 is not set
+# CONFIG_QFMT_V2 is not set
+CONFIG_AUTOFS4_FS=y
+# CONFIG_CUSE is not set
+# CONFIG_FSCACHE is not set
+CONFIG_ISO9660_FS=y
+# CONFIG_UDF_FS is not set
+CONFIG_MSDOS_FS=y
+CONFIG_NTFS_FS=y
+CONFIG_NTFS_RW=y
+CONFIG_CONFIGFS_FS=y
+# CONFIG_ADFS_FS is not set
+# CONFIG_AFFS_FS is not set
+CONFIG_ECRYPT_FS=y
+# CONFIG_HFS_FS is not set
+# CONFIG_BEFS_FS is not set
+# CONFIG_BFS_FS is not set
+# CONFIG_EFS_FS is not set
+CONFIG_CRAMFS=y
+CONFIG_SQUASHFS=y
+CONFIG_SQUASHFS_ZLIB=y
+CONFIG_SQUASHFS_LZO=y
+CONFIG_SQUASHFS_XZ=y
+CONFIG_SQUASHFS_4K_DEVBLK_SIZE=y
+CONFIG_SQUASHFS_EMBEDDED=y
+CONFIG_SQUASHFS_FRAGMENT_CACHE_SIZE=3
+# CONFIG_VXFS_FS is not set
+CONFIG_MINIX_FS=y
+# CONFIG_OMFS_FS is not set
+# CONFIG_HPFS_FS is not set
+# CONFIG_QNX4FS_FS is not set
+# CONFIG_QNX6FS_FS is not set
+CONFIG_ROMFS_FS=y
+# CONFIG_PSTORE_RAM is not set
+# CONFIG_SYSV_FS is not set
+# CONFIG_UFS_FS is not set
+# CONFIG_F2FS_FS is not set
+# CONFIG_EFIVAR_FS is not set
+CONFIG_NFS_FS=y
+CONFIG_NFS_V2=y
+CONFIG_NFS_V3=y
+CONFIG_NFS_V4=y
+# CONFIG_NFS_SWAP is not set
+# CONFIG_NFS_V4_1 is not set
+CONFIG_ROOT_NFS=y
+CONFIG_NFSD=y
+# CONFIG_NFSD_V3_ACL is not set
+# CONFIG_NFSD_V4 is not set
+CONFIG_LOCKD=y
+CONFIG_NFS_ACL_SUPPORT=y
+CONFIG_SUNRPC=y
+CONFIG_SUNRPC_GSS=y
+# CONFIG_SUNRPC_DEBUG is not set
+# CONFIG_CEPH_FS is not set
+CONFIG_CIFS=y
+# CONFIG_NCP_FS is not set
+# CONFIG_CODA_FS is not set
+# CONFIG_AFS_FS is not set
+CONFIG_NLS_CODEPAGE_437=y
+CONFIG_NLS_CODEPAGE_932=y
+# CONFIG_NLS_MAC_ROMAN is not set
+# CONFIG_NLS_MAC_CELTIC is not set
+# CONFIG_NLS_MAC_CENTEURO is not set
+# CONFIG_NLS_MAC_CROATIAN is not set
+# CONFIG_NLS_MAC_CYRILLIC is not set
+# CONFIG_NLS_MAC_GAELIC is not set
+# CONFIG_NLS_MAC_GREEK is not set
+# CONFIG_NLS_MAC_ICELAND is not set
+# CONFIG_NLS_MAC_INUIT is not set
+# CONFIG_NLS_MAC_ROMANIAN is not set
+# CONFIG_NLS_MAC_TURKISH is not set
+CONFIG_MESSAGE_LOGLEVEL_DEFAULT=7
+# CONFIG_LOCKUP_DETECTOR is not set
+# CONFIG_DETECT_HUNG_TASK is not set
+# CONFIG_SCHEDSTATS is not set
+# CONFIG_TIMER_STATS is not set
+CONFIG_DEBUG_BUGVERBOSE=y
+CONFIG_DEBUG_INFO=y
+# CONFIG_BOOT_PRINTK_DELAY is not set
+CONFIG_RCU_CPU_STALL_TIMEOUT=21
+# CONFIG_NOTIFIER_ERROR_INJECTION is not set
+# CONFIG_LATENCYTOP is not set
+# CONFIG_UPROBE_EVENT is not set
+# CONFIG_RBTREE_TEST is not set
+# CONFIG_INTERVAL_TREE_TEST is not set
+# CONFIG_ASYNC_RAID6_TEST is not set
+# CONFIG_KGDB is not set
+# CONFIG_TEST_STRING_HELPERS is not set
+# CONFIG_TEST_KSTRTOX is not set
+# CONFIG_EARLY_PRINTK_DBGP is not set
+CONFIG_DEBUG_RODATA_TEST=y
+# CONFIG_DEBUG_SET_MODULE_RONX is not set
+# CONFIG_ENCRYPTED_KEYS is not set
+# CONFIG_SECURITYFS is not set
+# CONFIG_SECURITY_PATH is not set
+# CONFIG_SECURITY_SELINUX is not set
+# CONFIG_SECURITY_SMACK is not set
+# CONFIG_SECURITY_TOMOYO is not set
+# CONFIG_SECURITY_APPARMOR is not set
+# CONFIG_SECURITY_YAMA is not set
+# CONFIG_EVM is not set
+CONFIG_DEFAULT_SECURITY_DAC=y
+CONFIG_DEFAULT_SECURITY=""
+CONFIG_XOR_BLOCKS=y
+CONFIG_ASYNC_CORE=y
+CONFIG_ASYNC_MEMCPY=y
+CONFIG_ASYNC_XOR=y
+CONFIG_ASYNC_PQ=y
+CONFIG_ASYNC_RAID6_RECOV=y
+CONFIG_CRYPTO_AEAD=y
+# CONFIG_CRYPTO_USER is not set
+# CONFIG_CRYPTO_GF128MUL is not set
+# CONFIG_CRYPTO_NULL is not set
+# CONFIG_CRYPTO_PCRYPT is not set
+# CONFIG_CRYPTO_CRYPTD is not set
+CONFIG_CRYPTO_AUTHENC=y
+# CONFIG_CRYPTO_TEST is not set
+# CONFIG_CRYPTO_CCM is not set
+# CONFIG_CRYPTO_GCM is not set
+# CONFIG_CRYPTO_SEQIV is not set
+# CONFIG_CRYPTO_CTR is not set
+# CONFIG_CRYPTO_CTS is not set
+# CONFIG_CRYPTO_LRW is not set
+# CONFIG_CRYPTO_PCBC is not set
+# CONFIG_CRYPTO_XTS is not set
+CONFIG_CRYPTO_CMAC=y
+# CONFIG_CRYPTO_XCBC is not set
+# CONFIG_CRYPTO_VMAC is not set
+# CONFIG_CRYPTO_CRC32C_INTEL is not set
+# CONFIG_CRYPTO_CRC32 is not set
+# CONFIG_CRYPTO_CRC32_PCLMUL is not set
+# CONFIG_CRYPTO_GHASH is not set
+CONFIG_CRYPTO_MD4=y
+# CONFIG_CRYPTO_MICHAEL_MIC is not set
+# CONFIG_CRYPTO_RMD128 is not set
+# CONFIG_CRYPTO_RMD160 is not set
+# CONFIG_CRYPTO_RMD256 is not set
+# CONFIG_CRYPTO_RMD320 is not set
+# CONFIG_CRYPTO_SHA1_SSSE3 is not set
+# CONFIG_CRYPTO_SHA256_SSSE3 is not set
+# CONFIG_CRYPTO_SHA512_SSSE3 is not set
+# CONFIG_CRYPTO_SHA256 is not set
+# CONFIG_CRYPTO_SHA512 is not set
+# CONFIG_CRYPTO_TGR192 is not set
+# CONFIG_CRYPTO_WP512 is not set
+# CONFIG_CRYPTO_GHASH_CLMUL_NI_INTEL is not set
+# CONFIG_CRYPTO_AES_X86_64 is not set
+# CONFIG_CRYPTO_AES_NI_INTEL is not set
+# CONFIG_CRYPTO_ANUBIS is not set
+CONFIG_CRYPTO_ARC4=y
+# CONFIG_CRYPTO_BLOWFISH is not set
+# CONFIG_CRYPTO_BLOWFISH_X86_64 is not set
+# CONFIG_CRYPTO_CAMELLIA is not set
+# CONFIG_CRYPTO_CAMELLIA_X86_64 is not set
+# CONFIG_CRYPTO_CAMELLIA_AESNI_AVX_X86_64 is not set
+# CONFIG_CRYPTO_CAMELLIA_AESNI_AVX2_X86_64 is not set
+# CONFIG_CRYPTO_CAST5 is not set
+# CONFIG_CRYPTO_CAST5_AVX_X86_64 is not set
+# CONFIG_CRYPTO_CAST6 is not set
+# CONFIG_CRYPTO_CAST6_AVX_X86_64 is not set
+# CONFIG_CRYPTO_DES is not set
+# CONFIG_CRYPTO_FCRYPT is not set
+# CONFIG_CRYPTO_KHAZAD is not set
+# CONFIG_CRYPTO_SALSA20 is not set
+# CONFIG_CRYPTO_SALSA20_X86_64 is not set
+# CONFIG_CRYPTO_SEED is not set
+# CONFIG_CRYPTO_SERPENT is not set
+# CONFIG_CRYPTO_SERPENT_SSE2_X86_64 is not set
+# CONFIG_CRYPTO_SERPENT_AVX_X86_64 is not set
+# CONFIG_CRYPTO_SERPENT_AVX2_X86_64 is not set
+# CONFIG_CRYPTO_TEA is not set
+# CONFIG_CRYPTO_TWOFISH is not set
+# CONFIG_CRYPTO_TWOFISH_X86_64 is not set
+# CONFIG_CRYPTO_TWOFISH_X86_64_3WAY is not set
+# CONFIG_CRYPTO_TWOFISH_AVX_X86_64 is not set
+# CONFIG_CRYPTO_DEFLATE is not set
+# CONFIG_CRYPTO_ZLIB is not set
+# CONFIG_CRYPTO_LZO is not set
+# CONFIG_CRYPTO_ANSI_CPRNG is not set
+# CONFIG_CRYPTO_USER_API_HASH is not set
+# CONFIG_CRYPTO_USER_API_SKCIPHER is not set
+# CONFIG_CRYPTO_HW is not set
+# CONFIG_ASYMMETRIC_KEY_TYPE is not set
+# CONFIG_VIRTUALIZATION is not set
+CONFIG_RAID6_PQ=y
+# CONFIG_CRC_CCITT is not set
+# CONFIG_CRC_ITU_T is not set
+CONFIG_CRC7=y
+CONFIG_LIBCRC32C=y
+# CONFIG_CRC8 is not set
+# CONFIG_XZ_DEC_X86 is not set
+# CONFIG_XZ_DEC_POWERPC is not set
+# CONFIG_XZ_DEC_IA64 is not set
+# CONFIG_XZ_DEC_ARM is not set
+# CONFIG_XZ_DEC_ARMTHUMB is not set
+# CONFIG_XZ_DEC_SPARC is not set
+# CONFIG_XZ_DEC_BCJ is not set
+# CONFIG_XZ_DEC_TEST is not set
+# CONFIG_AVERAGE is not set
+# CONFIG_CORDIC is not set
+# CONFIG_DDR is not set
+CONFIG_TS6000=y
+CONFIG_TS6000_CMOS_DRIVER=y
+#
+# BUFFALO Features
+#
+CONFIG_BUFFALO_PLATFORM=y
+CONFIG_BUFFALO_USE_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_DEGRADE_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT=y
+CONFIG_BUFFALO_ERRCNT=y
+CONFIG_BUFFALO_USE_UPS=y
+CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN=y
+# CONFIG_BUFFALO_SUPPORT_UPS_RECOVER is not set
+# CONFIG_BUFFALO_UBOOT_PARAMS is not set
+CONFIG_BUFFALO_IOERRS=y
+CONFIG_BUFFALO_SKIP_RESYNC=y
+CONFIG_BUFFALO_IGNORE_LUN=y
+CONFIG_BUFFALO_SCSI_GUID=y
+# CONFIG_BUFFALO_EXT23_EXTENSION is not set
+# CONFIG_BUFFALO_SUPPORT_WOL is not set
+CONFIG_BUFFALO_SUPPORT_BOARD_INFO=y
+# CONFIG_BUFFALO_USE_MICON is not set
+# CONFIG_BUFFALO_MICON_V3 is not set
+# CONFIG_BUFFALO_MICON_V3_DEVTTY is not set
+# CONFIG_BUFFALO_MICON_REBOOT is not set
+# CONFIG_BUFFALO_MATSU_PLATFORM is not set
+# CONFIG_BUFFALO_KIRI_PLATFORM is not set
+# CONFIG_BUFFALO_USI_PLATFORM is not set
+CONFIG_BUFFALO_DISCONIRQ=y
+
+CONFIG_BUFFALO_BTRFS_DROP_UNNECESSARY_QRECORD=y
+CONFIG_BUFFALO_BTRFS_DISABLE_QGROUP_EXCLUSIVE_SIZE=y
+CONFIG_BUFFALO_BTRFS_QRECORD_THRESHOLD=y
+CONFIG_BUFFALO_BTRFS_REMOVE_UNUSED_QGROUP=y
+CONFIG_BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD=y
+
+CONFIG_ISCSI_CHAP_BASE64_SUPPORT=y
\ No newline at end of file
diff --git a/buffalo/arch/x86/plat-usi/Makefile b/buffalo/arch/x86/plat-usi/Makefile
new file mode 100644
index 00000000..27b1907
--- /dev/null
+++ b/buffalo/arch/x86/plat-usi/Makefile
@@ -0,0 +1,32 @@
+
+# To build modules outside of the kernel tree, we run "make"
+# in the kernel source tree; the Makefile these then includes this
+# Makefile once again.
+# This conditional selects whether we are being included from the
+# kernel Makefile or not.
+ifeq ($(KERNELRELEASE),)
+
+    # Assume the source tree is where the running kernel was built
+    # You should set KERNELDIR in the environment if it's elsewhere
+    KERNELDIR ?= /lib/modules/$(shell uname -r)/build
+    # The current directory is passed to sub-makes as argument
+    PWD := $(shell pwd)
+
+modules:
+	$(MAKE) -C $(KERNELDIR) M=$(PWD) modules
+
+modules_install:
+	$(MAKE) -C $(KERNELDIR) M=$(PWD) modules_install
+
+clean:
+	rm -rf *.o *~ core .depend .*.cmd *.ko *.mod.c .tmp_versions Module.symvers modules.order
+
+.PHONY: modules modules_install clean
+
+else
+	# called from kernel build system: just declare what our modules are
+	obj-$(CONFIG_BUFFALO_USI_PLATFORM) += sugi_platform.o
+
+endif
+
+
diff --git a/buffalo/arch/x86/plat-usi/sugi_platform.c b/buffalo/arch/x86/plat-usi/sugi_platform.c
new file mode 100644
index 00000000..1bac6a3
--- /dev/null
+++ b/buffalo/arch/x86/plat-usi/sugi_platform.c
@@ -0,0 +1,1989 @@
+/*	Sugi Platform Driver - V1.2
+ *
+ * 	Author: Gary Chen
+ *	Date  : 2012/07/11
+ */
+
+
+#include <linux/version.h>
+#include <linux/seq_file.h>
+#include <linux/slab.h>
+#include <asm/io.h>
+#include <asm/msr.h>
+#include <asm/errno.h>
+#include <linux/fs.h>
+#include <linux/irq.h>
+#include <linux/pci.h>
+#include <linux/cdev.h>
+#include <linux/init.h>
+#include <linux/poll.h>
+#include <linux/delay.h>
+#include <linux/device.h>
+#include <linux/sched.h>
+#include <linux/module.h>
+#include <linux/string.h>
+#include <linux/kernel.h>
+#include <linux/proc_fs.h>
+#include <linux/interrupt.h>
+#include "sugi_platform.h"
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 1
+ * Description: Global variabls and strctures
+ * ---------------------------------------------------------------------------------------------- */
+
+/* Define for procfs directory and file */
+#if defined(CONFIG_BUFFALO_PLATFORM)
+#include <buffalo/kernevnt.h>
+#endif
+
+
+
+/* **************** Button Driver **************** */
+
+/* declare for file and directory of procfs */
+static struct proc_dir_entry *buffalo_dir;
+static struct proc_dir_entry *gpio_dir;
+static struct proc_dir_entry *switch_dir;
+static struct proc_dir_entry *switch_file[MAX_SUPPORTED_BUTTONS];
+
+/* GPIO set3 base addr */
+static unsigned int it87_gpioset3_base_addr;
+
+/* declare timer function */
+static struct timer_list btn_timer;
+
+/* button information strcture */
+static struct button_info_st button_info[] = {
+	{"func", IT87_DEB0},
+	{"display", IT87_DEB1}
+};
+
+/* ************** Fan Control Driver ************* */
+
+/* class and device nodes */
+struct class *sugi_cls;
+struct device *fan_dev;
+dev_t sugit_fan = MKDEV(sugi_fan_major, sugi_fan_minor);
+
+/* IT8721 EC base address */
+unsigned int EC_BASE_ADDR;
+unsigned int IT87_EC_ADDR_REG;
+unsigned int IT87_EC_DATA_REG;
+
+/* core temp used */
+unsigned int tjmax[2] = {100,100};
+unsigned int eax;
+unsigned int edx;
+
+/* fan, temp information strcture */
+struct fan_info_st fan_info[] =
+{
+	{IT87_EC_FAN_TACO1, IT87_EC_FAN_TACO1_EXT, IT87_EC_FAN_SMART_PWM1, IT87_EC_FAN_PWM1, 0x1},
+	{IT87_EC_FAN_TACO2, IT87_EC_FAN_TACO2_EXT, IT87_EC_FAN_SMART_PWM2, IT87_EC_FAN_PWM2, 0x2},
+};
+
+/* 4 steps of speed */
+static unsigned char fan_stop_speed = 0;
+static unsigned char fan_slow_speed = 150;
+static unsigned char fan_fast_speed = 200;
+static unsigned char fan_full_speed = 255;
+
+/* threshold & flag */
+static unsigned int fan_threshold = 100;
+static unsigned int flag_show_speed_by_string = 1;
+
+/* ************** HDD Control Driver ************* */
+
+/* pci device */
+struct pci_dev *pdev = NULL;
+
+/* declare for file and directory of procfs */
+static struct proc_dir_entry *hotplug_dir;
+static struct proc_dir_entry *power_control_dir;
+static struct proc_dir_entry *hotplug_sata_file[MAX_SUPPORTED_DISKS];
+static struct proc_dir_entry *power_control_hdd_file[MAX_SUPPORTED_DISKS];
+
+/* GPIO base address */
+unsigned int ich10r_gpio_base_addr;
+
+/* polling timer */
+struct timer_list sata_hotplug_polling_timer;
+
+/* hotplug status information strcture */
+struct sata_hotplug_data_st sata_hotplug_data[MAX_SUPPORTED_DISKS];
+
+/* HDD information strcture */
+static struct sugi_hdd_info_st sugi_hdd_info[] = {
+	{GP_LVL,	HDD0_PRESENT_BIT,	GP_LVL,		HDD0_POWER_BIT,	HDD0_POWER_MASK},
+	{GP_LVL,	HDD1_PRESENT_BIT,	GP_LVL,		HDD1_POWER_BIT,	HDD1_POWER_MASK},
+	{GP_LVL,	HDD2_PRESENT_BIT,	GP_LVL,		HDD2_POWER_BIT,	HDD2_POWER_MASK},
+	{GP_LVL,	HDD3_PRESENT_BIT,	GP_LVL,		HDD3_POWER_BIT,	HDD3_POWER_MASK},
+	{GP_LVL,	HDD4_PRESENT_BIT,	GP_LVL2,	HDD4_POWER_BIT,	HDD4_POWER_MASK},
+	{GP_LVL,	HDD5_PRESENT_BIT,	GP_LVL2,	HDD5_POWER_BIT,	HDD5_POWER_MASK},
+	{GP_LVL,	HDD6_PRESENT_BIT,	GP_LVL2,	HDD6_POWER_BIT,	HDD6_POWER_MASK},
+	{GP_LVL,	HDD7_PRESENT_BIT,	GP_LVL2,	HDD7_POWER_BIT,	HDD7_POWER_MASK},
+};
+
+/* ***************** CMOS Driver ***************** */
+/* device nodes */
+struct device *cmos_dev;
+dev_t sugit_cmos = MKDEV(sugi_cmos_major, sugi_cmos_minor);
+
+unsigned int ich10r_pm_base_addr;
+unsigned short afterg3_en;
+
+/* Device ID offset */
+unsigned char device_id_offset[32] = {0x46, 0x47, 0x48, 0x49, 0x4a, 0x4b, 0x4c, 0x4d,
+																0x4e, 0x4f, 0x50, 0x51, 0x52, 0x53, 0x54, 0x55,
+																0x56, 0x57, 0x59, 0x5a, 0x5b, 0x5c, 0x5d, 0x5e,
+																0x5f, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x6b, 0x6c};
+
+/* checksum offset */
+unsigned char checksum_offset[4] = {0x79, 0x7a, 0x7b, 0x7c};
+
+/* ASCII string to integer */																
+struct strtoint_st strtoint_info[] = {
+	{0x30, 0x0}, {0x31, 0x1}, {0x32, 0x2}, {0x33, 0x3},
+	{0x34, 0x4}, {0x35, 0x5}, {0x36, 0x6}, {0x37, 0x7},
+	{0x38, 0x8}, {0x39, 0x9}, {0x61, 0xa}, {0x62, 0xb},
+	{0x63, 0xc}, {0x64, 0xd}, {0x65, 0xe}, {0x66, 0xf},
+	{0x41, 0xa}, {0x42, 0xb}, {0x43, 0xc}, {0x44, 0xd},
+	{0x45, 0xe}, {0x46, 0xf},
+};
+
+static unsigned int bios_ver;
+
+/* *************** Boaed ID Driver *************** */
+
+struct device *boardid_dev;
+dev_t sugit_boardid = MKDEV(sugi_boardid_major, sugi_boardid_minor);
+unsigned int boardid_num;
+
+/* ************* protocol for IT8721 ************* */
+void EnterMBPnP(void)
+{
+	outb(0x87, CONFIG_ADDR_PORT);
+	outb(0x01, CONFIG_ADDR_PORT);
+	outb(0x55, CONFIG_ADDR_PORT);
+	outb(0x55, CONFIG_ADDR_PORT);
+}
+void ExitMBPnP(void)
+{
+	outb(0x02, CONFIG_ADDR_PORT);
+	outb(0x02, CONFIG_DATA_PORT);
+}
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2-1
+ * Description: Implement functions of button driver
+ * ---------------------------------------------------------------------------------------------- */
+
+/* ************** implement function ************* */
+
+/* ----------- get GPIO status ----------- */
+static int it87_gpio_getsts(int pin)
+{
+	int	off;
+	if(pin == BTN_DISP){
+		off = IT87_GP35_BIT5;	//pin number of DISP button
+	}else{
+		off = IT87_GP34_BIT4;	//pin number of FUNC button
+	}		
+
+	return inb(it87_gpioset3_base_addr) & off;
+}
+
+/* ------------- button timer ------------ */	
+static void timer_function(unsigned long data)
+{
+	int	pin_sts;
+
+	pin_sts=it87_gpio_getsts(data);
+	
+	if(pin_sts){
+	//Clear de-bounce ping SMI status
+		EnterMBPnP();
+		outb(IT87_REG_SMI_STS2, CONFIG_ADDR_PORT);
+		outb(IT87_DEB0DEB1 | IT87_SMI_STS2_PBD, CONFIG_DATA_PORT);		
+		ExitMBPnP();
+	//Delete timer
+		del_timer(&btn_timer);
+	}
+	else
+		mod_timer(&btn_timer, jiffies + TIMER_DELAY);
+}
+
+/* ---------- get button status ---------- */
+static void *
+sugi_button_status_seq_start(struct seq_file *s, loff_t *pos)
+{
+	return *pos < 1 ? SEQ_START_TOKEN : NULL;
+}
+
+static void *
+sugi_button_status_seq_next(struct seq_file *s, void *v, loff_t *pos)
+{
+	++ *pos;
+	return NULL;
+}
+
+static void
+sugi_button_status_seq_stop(struct seq_file *s, void *v)
+{
+}
+
+static int
+sugi_button_status_seq_show(struct seq_file *m, void *v)
+{
+	struct button_info_st *button_info = (struct button_info_st *)m->private;
+	unsigned char smi_sts;
+
+	EnterMBPnP();
+
+	//Get SMI status of two de-bounce pin
+	outb(IT87_REG_SMI_STS2, CONFIG_ADDR_PORT);
+	smi_sts = inb(CONFIG_DATA_PORT);
+	smi_sts &= IT87_SMI_DEB_MASK;
+
+	ExitMBPnP();
+
+	//Check which button was pressed
+	if ((smi_sts & button_info->reg_stat))
+		seq_printf(m, "on\n");
+	else
+		seq_printf(m, "off\n");
+
+	return 0;
+}
+
+static const
+struct seq_operations sugi_button_status_seq_ops = {
+	.start	= sugi_button_status_seq_start,
+	.next	= sugi_button_status_seq_next,
+	.stop	= sugi_button_status_seq_stop,
+	.show	= sugi_button_status_seq_show,
+};
+
+static int
+sugi_button_status_open(struct inode *inode, struct file *file)
+{
+	int ret;
+	struct seq_file *m;
+	struct button_info_st *button_info = (struct button_info_st *)PDE_DATA(inode);
+
+	ret = seq_open_private(file, &sugi_button_status_seq_ops,
+			       sizeof(button_info));
+	if (ret) {
+		return ret;
+	}
+	m = file->private_data;
+	m->private = button_info;
+	return 0;
+}
+
+static const
+struct file_operations sugi_button_status_file_ops = {
+	.open		= sugi_button_status_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+/* ----------- interrupt handler ---------- */
+static irqreturn_t sugi_interrupt(int irq, void *dev_id)
+{
+	int	pin=0;
+	unsigned char smi_sts;
+	
+#ifdef CONFIG_BUFFALO_PLATFORM
+	char msg[32];
+	memset(msg, 0, sizeof(msg));
+#endif
+	
+	/* get SMI status of two de-bounce pin */
+	EnterMBPnP();	
+	
+	outb(IT87_REG_SMI_STS2, CONFIG_ADDR_PORT);
+	smi_sts = inb(CONFIG_DATA_PORT);
+	
+	ExitMBPnP();
+	
+	/* check if the interrupt source is PBD's IRQ */
+	if(smi_sts & IT87_SMI_STS2_PBD)
+	{
+		smi_sts &= IT87_SMI_DEB_MASK;
+		
+		/* check which button was pressed */
+		if(smi_sts == IT87_DEB0){
+			#ifdef CONFIG_BUFFALO_PLATFORM
+				sprintf(msg, "micon_interrupts");
+			#else
+				printk("EVENT IS OCCURRED\n");
+			#endif
+			pin = BTN_FUNC;
+		}
+		else if(smi_sts == IT87_DEB1){
+			#ifdef CONFIG_BUFFALO_PLATFORM
+				sprintf(msg, "micon_interrupts");
+			#else
+				printk("EVENT IS OCCURRED\n");
+			#endif
+			pin = BTN_DISP;
+		}
+		
+		/* setup timer for checking button GPIO status */
+ 		init_timer(&btn_timer);
+		btn_timer.expires = jiffies + TIMER_DELAY;
+		btn_timer.data = pin;
+		btn_timer.function = timer_function;
+		add_timer(&btn_timer);
+		
+		#ifdef CONFIG_BUFFALO_PLATFORM
+			if(msg[0] != '\0')
+				buffalo_kernevnt_queuein(msg);
+		#endif
+	}
+	return IRQ_HANDLED;
+}
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2-2
+ * Description: Implement functions of fan control driver
+ * ---------------------------------------------------------------------------------------------- */
+
+/* ************* implement functions ************* */
+
+/* ----------- get temperature ---------- */
+unsigned int get_temp(unsigned char temp_num)
+{
+	unsigned int	ret = 0;
+	
+	if(temp_num==2){
+		outb(IT87_EC_TMPIN3, IT87_EC_ADDR_REG);
+		ret = inb(IT87_EC_DATA_REG);
+		return ret;
+	}
+	
+	rdmsr_on_cpu(temp_num, MSR_IA32_THERM_STATUS, &eax, &edx);
+	ret = tjmax[temp_num] - ((eax >> 16)&0x7f);
+	
+	return ret;
+}
+
+/* ---------- get rotation speed --------- */
+unsigned int get_fan_rpm(unsigned char fan_num)
+{
+	unsigned int	read_value;
+	unsigned int	read_value_ext;
+	unsigned int	ret = 0;
+	
+	outb(fan_info[fan_num].reg, IT87_EC_ADDR_REG);
+	read_value = inb(IT87_EC_DATA_REG);
+	outb(fan_info[fan_num].reg_ext, IT87_EC_ADDR_REG);
+	read_value_ext = inb(IT87_EC_DATA_REG);
+	ret = 1350000/(read_value_ext*256+read_value)/2;
+
+	if(ret < fan_threshold)
+		ret = 0;
+	
+	return ret;
+}
+
+/* -------------- get speed -------------- */
+unsigned int get_fan_speed(unsigned char fan_num)
+{
+	unsigned int	read_value;
+
+		
+	outb(IT87_EC_FAN_MAIN_CTL, IT87_EC_ADDR_REG);
+	read_value = inb(IT87_EC_DATA_REG);
+	read_value |= fan_info[fan_num].offset;
+	outb(read_value, IT87_EC_DATA_REG);
+
+	outb(fan_info[fan_num].reg_smart_pwm, IT87_EC_ADDR_REG);
+	read_value = inb(IT87_EC_DATA_REG);
+
+	return read_value;
+}
+
+/* -------------- set speed -------------- */
+unsigned int set_fan_speed(unsigned char fan_num, unsigned char set_val)
+{
+	unsigned int	write_data;
+	unsigned char	read_value;
+
+	/*if(fan_info[fan_num].reg_smart_pwm == 0 ||
+		fan_info[fan_num].reg_pwm == 0)
+	{
+		return -EINVAL;
+	}*/
+
+	outb(IT87_EC_FAN_MAIN_CTL, IT87_EC_ADDR_REG);
+	read_value = inb(IT87_EC_DATA_REG);
+	read_value |= fan_info[fan_num].offset;
+	outb(read_value, IT87_EC_DATA_REG);
+
+	write_data = set_val;
+	outb(fan_info[fan_num].reg_smart_pwm, IT87_EC_ADDR_REG);
+	outb(write_data, IT87_EC_DATA_REG);
+
+	outb(fan_info[fan_num].reg_pwm, IT87_EC_ADDR_REG);
+	read_value = inb(IT87_EC_DATA_REG);
+	read_value &= 0x7F;
+	outb(read_value, IT87_EC_DATA_REG);
+
+	return 0;
+}
+
+/* --------- convert string to ul -------- */
+static unsigned long fan_speed_str_to_ul(char *buf)
+{
+	int len = 0;
+	
+	while(buf[len])
+		len++;
+	
+	if((len == 5) && (strncmp(buf, "stop", strlen("stop")) == 0))
+		return fan_stop_speed;
+	else if((len == 5) && (strncmp(buf, "slow", strlen("slow")) == 0))
+		return fan_slow_speed;
+	else if((len == 5) && (strncmp(buf, "fast", strlen("fast")) == 0))
+		return fan_fast_speed;
+	else if((len == 5) && (strncmp(buf, "full", strlen("full")) == 0))
+		return fan_full_speed;
+
+	return simple_strtoul(buf, NULL, 10);
+}
+
+/* --------- convert ul to string -------- */
+static unsigned long fan_speed_ul_to_str(char *buf, size_t len, unsigned long speed)
+{
+	if(speed <= fan_stop_speed)
+		snprintf(buf, len, "stop");
+	else if(speed > fan_stop_speed && speed <= fan_slow_speed)
+		snprintf(buf, len, "slow");
+	else if(speed > fan_slow_speed && speed <= fan_fast_speed)
+		snprintf(buf, len, "fast");
+	else if(speed > fan_fast_speed)
+		snprintf(buf, len, "full");
+	else
+		snprintf(buf, len, "Unknown");
+		
+	return 0;
+}
+
+/* ************** device attributes ************** */
+
+/* -------- temperature attributes ------- */
+static ssize_t show_temp1(struct device *dev, struct device_attribute *attr, char *buf)
+
+{
+	return sprintf(buf, "%d\n", get_temp(0));
+}
+
+static ssize_t show_temp2(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", get_temp(1));
+}
+
+static ssize_t show_temp3(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", get_temp(2));
+}
+
+DEVICE_ATTR(temp1, 0444, show_temp1, NULL);
+DEVICE_ATTR(temp2, 0444, show_temp2, NULL);
+DEVICE_ATTR(temp3, 0444, show_temp3, NULL);
+
+/* ------ rotation speed attributes ------ */
+static ssize_t show_fan1_rpm(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", get_fan_rpm(0));
+}
+
+static ssize_t show_fan2_rpm(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", get_fan_rpm(1));
+}
+
+DEVICE_ATTR(fan1_rpm, 0444, show_fan1_rpm, NULL);
+DEVICE_ATTR(fan2_rpm, 0444, show_fan2_rpm, NULL);
+
+/* fan3_rpm and fan4_rpm nodes are added to fit Buffalo's requirement. */
+DEVICE_ATTR(fan3_rpm, 0444, show_fan1_rpm, NULL);
+DEVICE_ATTR(fan4_rpm, 0444, show_fan2_rpm, NULL);
+
+/* ----------- speed attributes ---------- */
+static ssize_t show_fan1_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	if(flag_show_speed_by_string == 1)
+	{
+		char szSpeed[32];
+		fan_speed_ul_to_str(szSpeed, sizeof(szSpeed), get_fan_speed(0));
+		return sprintf(buf, "%s\n", szSpeed);
+	}
+	else
+		return sprintf(buf, "%d\n", get_fan_speed(0));
+}
+static ssize_t store_fan1_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long write_val = fan_speed_str_to_ul((char*) buf );
+	if(write_val > 0xff)
+		return -EINVAL;
+
+	set_fan_speed(0, (unsigned char)(write_val & 0xff));
+
+	return count;
+}
+
+static ssize_t show_fan2_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	if(flag_show_speed_by_string == 1)
+	{
+		char szSpeed[32];
+		fan_speed_ul_to_str(szSpeed, sizeof(szSpeed), get_fan_speed(1));
+		return sprintf(buf, "%s\n", szSpeed);
+	}
+	else
+		return sprintf(buf, "%d\n", get_fan_speed(1));
+}
+static ssize_t store_fan2_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long write_val = fan_speed_str_to_ul((char*) buf );
+	if(write_val > 0xff)
+		return -EINVAL;
+
+	set_fan_speed(1, (unsigned char)(write_val & 0xff));
+	return count;
+}
+
+static ssize_t show_fan3_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	unsigned int temp;
+	if(flag_show_speed_by_string == 1)
+	{
+		char szSpeed[32];
+		fan_speed_ul_to_str(szSpeed, sizeof(szSpeed), get_fan_speed(0));
+		/* get_fan_speed(1) is used to set fan4 as software control mode */
+		temp = get_fan_speed(1);
+		return sprintf(buf, "%s\n", szSpeed);
+	}
+	else{
+		/* get_fan_speed(1) is used to set fan4 as software control mode */
+		temp = get_fan_speed(1);
+		return sprintf(buf, "%d\n", get_fan_speed(0));
+	}
+}
+static ssize_t store_fan3_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long write_val = fan_speed_str_to_ul((char*) buf );
+	if(write_val > 0xff)
+		return -EINVAL;
+	
+	set_fan_speed(0, (unsigned char)(write_val & 0xff));
+	set_fan_speed(1, (unsigned char)(write_val & 0xff));
+	return count;
+}
+
+DEVICE_ATTR(fan1_speed, 0644, show_fan1_speed, store_fan1_speed);
+DEVICE_ATTR(fan2_speed, 0644, show_fan2_speed, store_fan2_speed);
+
+/* fan3_speed and fan4_speed are added to fit Buffalo's requirement,
+   and their behavior are same to Matsu. */
+DEVICE_ATTR(fan3_speed, 0644, show_fan3_speed, store_fan3_speed);
+DEVICE_ATTR(fan4_speed, 0644, show_fan2_speed, store_fan2_speed);
+
+/* ---------- 4 steps attributes --------- */
+static ssize_t show_fan_stop_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", fan_stop_speed);
+}
+static ssize_t store_fan_stop_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long tmp_speed = simple_strtoul(buf, NULL, 10);
+	if(tmp_speed > 0xFF)
+		return -EINVAL;
+
+	fan_stop_speed = tmp_speed;
+	return count;
+}
+
+static ssize_t show_fan_slow_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", fan_slow_speed);
+}
+static ssize_t store_fan_slow_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long tmp_speed = simple_strtoul(buf, NULL, 10);
+	if(tmp_speed > 0xFF)
+		return -EINVAL;
+
+	fan_slow_speed = tmp_speed;
+	return count;
+}
+
+static ssize_t show_fan_fast_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", fan_fast_speed);
+}
+static ssize_t store_fan_fast_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long tmp_speed = simple_strtoul(buf, NULL, 10);
+	if(tmp_speed > 0xFF)
+		return -EINVAL;
+
+	fan_fast_speed = tmp_speed;
+	return count;
+}
+
+static ssize_t show_fan_full_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", fan_full_speed);
+}
+static ssize_t store_fan_full_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long tmp_speed = simple_strtoul(buf, NULL, 10);
+	if(tmp_speed > 0xFF)
+		return -EINVAL;
+
+	fan_full_speed = tmp_speed;
+	return count;
+}
+
+DEVICE_ATTR(fan_stop_speed, 0644, show_fan_stop_speed, store_fan_stop_speed);
+DEVICE_ATTR(fan_slow_speed, 0644, show_fan_slow_speed, store_fan_slow_speed);
+DEVICE_ATTR(fan_fast_speed, 0644, show_fan_fast_speed, store_fan_fast_speed);
+DEVICE_ATTR(fan_full_speed, 0644, show_fan_full_speed, store_fan_full_speed);
+
+/* --------- read mode attribute --------- */
+static ssize_t show_show_speed_by_string(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", flag_show_speed_by_string);
+}
+static ssize_t store_show_speed_by_string(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long value = simple_strtoul(buf, NULL, 10);
+	
+	if(value != 0 && value != 1)
+		return -EINVAL;
+
+	flag_show_speed_by_string = value;
+
+	return count;
+}
+DEVICE_ATTR(show_speed_by_string, 0644, show_show_speed_by_string, store_show_speed_by_string);
+
+/* --------- threshold attribute --------- */
+static ssize_t show_fan_threshold(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", fan_threshold);
+}
+static ssize_t store_fan_threshold(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long tmp_threshold = simple_strtoul(buf, NULL, 10);
+	fan_threshold = tmp_threshold;
+	return count;
+}
+DEVICE_ATTR(fan_threshold, 0644, show_fan_threshold, store_fan_threshold);
+
+/* ------- device number attribute ------- */
+static ssize_t show_sugi_fan_dev(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", sugi_fan_major);
+}
+DEVICE_ATTR(sugi_fan_dev, 0444, show_sugi_fan_dev, NULL);
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2-3
+ * Description: Implement functions of HDD control driver
+ * ---------------------------------------------------------------------------------------------- */
+static void *
+sugi_hotplug_status_seq_start(struct seq_file *s, loff_t *pos)
+{
+	return *pos < 1 ? SEQ_START_TOKEN : NULL;
+}
+
+static void *
+sugi_hotplug_status_seq_next(struct seq_file *s, void *v, loff_t *pos)
+{
+	++ *pos;
+	return NULL;
+}
+
+static void
+sugi_hotplug_status_seq_stop(struct seq_file *s, void *v)
+{
+}
+
+static int
+sugi_hotplug_status_seq_show(struct seq_file *m, void *v)
+{
+	struct sugi_hdd_info_st *hdd_info = (struct sugi_hdd_info_st *)m->private;
+
+	if (inl(ich10r_gpio_base_addr + hdd_info->HDD_GPIO_PRESENT_REG) & hdd_info->HDD_PRESENT_BIT)
+		seq_printf(m, "unplugged\n");
+	else
+		seq_printf(m, "plugged\n");
+
+	return 0;
+}
+
+static const
+struct seq_operations sugi_hotplug_status_seq_ops = {
+	.start	= sugi_hotplug_status_seq_start,
+	.next	= sugi_hotplug_status_seq_next,
+	.stop	= sugi_hotplug_status_seq_stop,
+	.show	= sugi_hotplug_status_seq_show,
+};
+
+static int
+sugi_hotplug_status_open(struct inode *inode, struct file *file)
+{
+	int ret;
+	struct seq_file *m;
+	struct sugi_hdd_info_st *hdd_info = (struct sugi_hdd_info_st *)PDE_DATA(inode);
+
+	ret = seq_open_private(file, &sugi_hotplug_status_seq_ops,
+			       sizeof(hdd_info));
+	if (ret) {
+		return ret;
+	}
+	m = file->private_data;
+	m->private = hdd_info;
+	return 0;
+}
+
+static const
+struct file_operations sugi_hotplug_status_file_ops = {
+	.open		= sugi_hotplug_status_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static void *
+sugi_power_control_seq_start(struct seq_file *s, loff_t *pos)
+{
+	return *pos < 1 ? SEQ_START_TOKEN : NULL;
+}
+
+static void *
+sugi_power_control_seq_next(struct seq_file *s, void *v, loff_t *pos)
+{
+	++ *pos;
+	return NULL;
+}
+
+static void
+sugi_power_control_seq_stop(struct seq_file *s, void *v)
+{
+}
+
+static int
+sugi_power_control_seq_show(struct seq_file *m, void *v)
+{
+	struct sugi_hdd_info_st *hdd_info = (struct sugi_hdd_info_st *)m->private;
+
+	if (inl(ich10r_gpio_base_addr + hdd_info->HDD_GPIO_POWER_REG) & hdd_info->HDD_POWER_BIT)
+		seq_printf(m, "on\n");
+	else
+		seq_printf(m, "off\n");
+
+	return 0;
+}
+
+static const
+struct seq_operations sugi_power_control_seq_ops = {
+	.start	= sugi_power_control_seq_start,
+	.next	= sugi_power_control_seq_next,
+	.stop	= sugi_power_control_seq_stop,
+	.show	= sugi_power_control_seq_show,
+};
+
+static int
+sugi_power_control_open(struct inode *inode, struct file *file)
+{
+	int ret;
+	struct seq_file *m;
+	struct sugi_hdd_info *hdd_info = (struct sugi_hdd_info *)PDE_DATA(inode);
+
+	ret = seq_open_private(file, &sugi_power_control_seq_ops,
+			       sizeof(hdd_info));
+	if (ret) {
+		
+		return ret;
+	}
+	m = file->private_data;
+	m->private = hdd_info;
+	return 0;
+}
+
+static ssize_t
+sugi_power_control_write(struct file *file, const char __user *buffer,
+			 size_t count, loff_t *ppos)
+{
+	int tmpgpioval;
+	struct sugi_hdd_info_st *hdd_info = (struct sugi_hdd_info_st *)PDE_DATA(file_inode(file));
+	char *kbuf;
+
+	kbuf = kmalloc(count + 1, GFP_KERNEL);
+	if (kbuf == NULL) {
+		return -ENOMEM;
+	}
+
+	if (copy_from_user(kbuf, buffer, count)) {
+		count = -EFAULT;
+		goto out;
+	}
+
+	kbuf[count] = '\0';
+
+	tmpgpioval = inl(ich10r_gpio_base_addr + hdd_info->HDD_GPIO_POWER_REG);
+
+	if (strncmp(kbuf, "off", strlen("off")) == 0) {
+		if (tmpgpioval & hdd_info->HDD_POWER_BIT) {
+			tmpgpioval &= hdd_info->HDD_POWER_MASK;
+			outl(tmpgpioval, ich10r_gpio_base_addr + hdd_info->HDD_GPIO_POWER_REG);
+			return count;
+		}
+	}
+	
+	if(strncmp(kbuf, "on", strlen("on")) == 0){
+		if (!(tmpgpioval & hdd_info->HDD_POWER_BIT)){
+			tmpgpioval |= hdd_info->HDD_POWER_BIT;
+			outl(tmpgpioval, ich10r_gpio_base_addr + hdd_info->HDD_GPIO_POWER_REG);
+			return count;
+		}
+	}
+out:
+	kfree(kbuf);
+	return count;
+}
+
+static const
+struct file_operations sugi_power_control_file_ops = {
+	.open		= sugi_power_control_open,
+	.read		= seq_read,
+	.write		= sugi_power_control_write,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+/* ----------- polling function ---------- */
+
+static void SataHotplugPollingUpdatePinstat(void)
+{
+	unsigned int i = 0;
+	
+	for(i = 0; i < MAX_SUPPORTED_DISKS; i++)
+	{
+		sata_hotplug_data[i].presentpinstat = (inl(ich10r_gpio_base_addr + sugi_hdd_info[i].HDD_GPIO_PRESENT_REG) & sugi_hdd_info[i].HDD_PRESENT_BIT)? SATA_STAT_UNPLUGGED:SATA_STAT_PLUGGED;
+	}
+}
+
+static void SataHotplugPolling(unsigned long data)
+{
+	unsigned int i = 0;
+	char buf[32];
+
+	SataHotplugPollingUpdatePinstat();
+	for(i = 0; i < MAX_SUPPORTED_DISKS; i++)
+	{
+		if(sata_hotplug_data[i].prevplugstat == sata_hotplug_data[i].presentpinstat)
+		{
+			sata_hotplug_data[i].loops = SATA_POL_LOOPS;
+			continue;
+		}
+		--sata_hotplug_data[i].loops;
+
+		if(sata_hotplug_data[i].loops == 0)
+		{
+			if(sata_hotplug_data[i].presentpinstat == SATA_STAT_PLUGGED)
+				sprintf(buf, PLUGGED_EVENT_MSG, i);
+			else
+				sprintf(buf, UNPLUGGED_EVENT_MSG, i);
+
+			#ifdef CONFIG_BUFFALO_PLATFORM
+				buffalo_kernevnt_queuein(buf);
+			#else
+				printk("EVENT IS OCCURRED\n");
+			#endif
+			
+			sata_hotplug_data[i].loops = SATA_POL_LOOPS;
+			sata_hotplug_data[i].prevplugstat = sata_hotplug_data[i].presentpinstat;
+		}
+	}
+	sata_hotplug_polling_timer.expires += SATA_POL_INTERVAL;
+	add_timer(&sata_hotplug_polling_timer);
+}
+
+static unsigned long SataHotplugPollingStart(void)
+{
+	unsigned int i = 0;
+	for(i = 0; i < MAX_SUPPORTED_DISKS; i++)
+	{
+		sata_hotplug_data[i].prevplugstat = SATA_STAT_UNKNOWN;
+		sata_hotplug_data[i].loops = SATA_POL_LOOPS;
+	}
+
+        init_timer(&sata_hotplug_polling_timer);
+        sata_hotplug_polling_timer.expires = jiffies + SATA_POL_INTERVAL;
+        sata_hotplug_polling_timer.function = SataHotplugPolling;
+        add_timer(&sata_hotplug_polling_timer);
+
+        return 0;
+}
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2-4
+ * Description: Implement functions of CMOS driver
+ * ---------------------------------------------------------------------------------------------- */
+static unsigned char checksum_caculation(unsigned char wol, unsigned char acp, unsigned char lan)
+{
+	return (CMOS_CHANGE_CHECKSUM - wol - (acp << 1) - (lan * 6));
+}
+static int smi_write(void)
+{
+	int smi_count = 0;
+	int read_count = 0;
+	
+	for(smi_count = 0; smi_count < 3; smi_count++){
+		outb(SW_SMI_WRITE, SW_SMI_OFFSET);
+		for(read_count = 0; read_count < 10; read_count++){
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			/* return error code of write "pass" or "fail" */
+			if(inb(CMOS_DATA_PORT) == 0x40 || inb(CMOS_DATA_PORT) == 0xEF || inb(CMOS_DATA_PORT) == 0xFF)
+				return inb(CMOS_DATA_PORT);
+			mdelay(100);
+		}
+	}
+	/* return 0 after sending SMI 3 times and waiting for 0.5s delay 10 times  */
+	return 0;
+}
+
+static int smi_read(void)
+{
+	int smi_count = 0;
+	int read_count = 0;
+	
+	/* clear 73h to 0 */
+	outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+	while(inb(CMOS_DATA_PORT))
+		outb(0x00, CMOS_DATA_PORT);
+	
+	for(smi_count = 0; smi_count < 3; smi_count++){
+		outb(SW_SMI_READ, SW_SMI_OFFSET);
+		for(read_count = 0; read_count < 10; read_count++){
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			/* return error code of read "pass" or "fail" */
+			if(inb(CMOS_DATA_PORT) == 0x40 || inb(CMOS_DATA_PORT) == 0xEF)
+				return inb(CMOS_DATA_PORT);
+			mdelay(100);
+		}
+	}
+	/* return 0 after sending SMI 3 times and waiting for 0.5s delay 10 times  */
+	return 0;
+}
+
+/* -------- wake on LAN attribute -------- */
+static ssize_t show_wol_setting(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	int ret;
+	
+	if(bios_ver >= 209){
+		ret = smi_read();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0xEF:
+				printk("NVRAM_READ_FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0x40:
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+		}
+	}
+	
+	outb(WOL_OFFSET, CMOS_INDEX_PORT);
+	ret = inb(CMOS_DATA_PORT);
+	
+	if(ret == 0){
+		return sprintf(buf, "off\n");
+	}
+	else if(ret == 1){
+		return sprintf(buf, "on\n");
+	}
+	return sprintf(buf, "UNKNOWN\n");
+}
+static ssize_t store_wol_setting(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	int ret;
+	int len = 0;
+	unsigned char wol_setting_value = 0;
+	unsigned char power_setting_value = 0;
+	unsigned char lanboot_setting_value = 0;
+	unsigned char checksum_caculated = 0;
+	
+	while(buf[len])
+		len++;
+	
+	if((len != 3) && (len != 4)){
+		printk("WRONG_STRING\n");
+		return count;
+	}
+	
+	if(bios_ver >= 209){
+		ret = smi_read();
+
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				return count;
+			case 0xEF:
+				printk("NVRAM_READ_FAIL\n");
+				return count;
+			case 0x40:
+				outb(LANBOOT_OFFSET, CMOS_INDEX_PORT);
+				lanboot_setting_value = inb(CMOS_DATA_PORT);
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				return count;
+		}
+	}
+	
+	outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+	power_setting_value = inb(CMOS_DATA_PORT);
+		
+	if((len == 3) && (strncmp(buf, "on", strlen("on")) == 0)){
+		outb(WOL_OFFSET, CMOS_INDEX_PORT);
+		outb(WOL_ENABLE, CMOS_DATA_PORT);
+		
+		wol_setting_value = inb(CMOS_DATA_PORT);
+		if(wol_setting_value == WOL_ENABLE){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+	
+	if((len == 4) && (strncmp(buf, "off", strlen("off")) == 0)){
+		outb(WOL_OFFSET, CMOS_INDEX_PORT);
+		outb(WOL_DISABLE, CMOS_DATA_PORT);
+		
+		wol_setting_value = inb(CMOS_DATA_PORT);
+		if(wol_setting_value == WOL_DISABLE){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+
+	if(bios_ver >=209){
+		ret = smi_write();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				break;
+			case 0xEF:
+				printk("NVRAM_CMOS_COMPARE_FAIL\n");
+				break;
+			case 0xFF:
+				printk("NVRAM_WRITE_FAIL\n");
+				break;
+			case 0x40:
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				break;
+		}
+	}
+
+	return count;
+}
+
+DEVICE_ATTR(wol_setting, 0644, show_wol_setting, store_wol_setting);
+
+/* ------- AC power loss attribute ------- */
+static ssize_t show_power_setting(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	int ret;
+	
+	if(bios_ver >= 209){
+		ret = smi_read();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0xEF:
+				printk("NVRAM_READ_FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0x40:
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+		}
+	}
+	
+	outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+	ret = inb(CMOS_DATA_PORT);
+	
+	if(ret==0){
+		return sprintf(buf, "off\n");
+	}
+	else if(ret==1){
+		return sprintf(buf, "on\n");
+	}
+	else if(ret==2){
+		return sprintf(buf, "last state\n");
+	}
+	return sprintf(buf, "UNKNOWN\n");
+}
+static ssize_t store_power_setting(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	int ret;
+	int len = 0;
+	unsigned char wol_setting_value = 0;
+	unsigned char power_setting_value = 0;
+	unsigned char lanboot_setting_value = 0;
+	unsigned char checksum_caculated = 0;
+	
+	while(buf[len])
+		len++;
+		
+//	if((len != 3) || (len != 4) || (len != 5)){
+//		printk("WRONG_STRING [%d]\n", len);
+//		return count;
+//	}
+		
+	if(bios_ver >= 209){
+		ret = smi_read();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				return count;
+			case 0xEF:
+				printk("NVRAM_READ_FAIL\n");
+				return count;
+			case 0x40:
+				outb(LANBOOT_OFFSET, CMOS_INDEX_PORT);
+				lanboot_setting_value = inb(CMOS_DATA_PORT);
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				return count;
+		}
+	}
+	
+	outb(WOL_OFFSET, CMOS_INDEX_PORT);
+	wol_setting_value = inb(CMOS_DATA_PORT);
+	
+//	if((len == 3) && (strncmp(buf, "on", strlen("on")) == 0)){
+	if(strncmp(buf, "on", strlen("on")) == 0){
+		outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+		outb(AC_POWER_LOSS_POWER_ON, CMOS_DATA_PORT);
+		
+		if(bios_ver < 209){
+			ret = pci_read_config_word(pdev, GEN_PMCON_3, &afterg3_en);
+		afterg3_en &=(~0x0001);
+			ret = pci_write_config_word(pdev, GEN_PMCON_3, afterg3_en);
+		}
+		
+		power_setting_value = inb(CMOS_DATA_PORT);
+		if(power_setting_value == AC_POWER_LOSS_POWER_ON){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+	
+//	if((len == 4) && (strncmp(buf, "off", strlen("off")) == 0)){
+	if(strncmp(buf, "off", strlen("off")) == 0){
+		outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+		outb(AC_POWER_LOSS_POWER_OFF, CMOS_DATA_PORT);
+		
+		if(bios_ver < 209){
+			ret = pci_read_config_word(pdev, GEN_PMCON_3, &afterg3_en);
+		afterg3_en |= 0x0001;
+			ret = pci_write_config_word(pdev, GEN_PMCON_3, afterg3_en);
+		}
+		
+		power_setting_value = inb(CMOS_DATA_PORT);
+		if(power_setting_value == AC_POWER_LOSS_POWER_OFF){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+
+//	if((len == 5) && (strncmp(buf, "last", strlen("last")) == 0)){
+	if(strncmp(buf, "last", strlen("last")) == 0){
+		outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+		outb(AC_POWER_LOSS_LAST_STATE, CMOS_DATA_PORT);
+		
+		if(bios_ver){
+			ret = pci_read_config_word(pdev, GEN_PMCON_3, &afterg3_en);
+		afterg3_en &= 0xFFFE;
+			ret = pci_write_config_word(pdev, GEN_PMCON_3, afterg3_en);
+		}
+		
+		power_setting_value = inb(CMOS_DATA_PORT);
+		if(power_setting_value == AC_POWER_LOSS_LAST_STATE){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+
+	if(bios_ver >=209){
+		ret = smi_write();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				break;
+			case 0xEF:
+				printk("NVRAM_CMOS_COMPARE_FAIL\n");
+				break;
+			case 0xFF:
+				printk("NVRAM_WRITE_FAIL\n");
+				break;
+			case 0x40:
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				break;
+		}
+	}
+
+	return count;
+}
+
+DEVICE_ATTR(power_setting, 0644, show_power_setting, store_power_setting);
+
+/* -------- Gbe LAN boot attribute ------- */
+static ssize_t show_lanboot_setting(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	int ret;
+	
+	if(bios_ver >= 209){
+		ret = smi_read();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0xEF:
+				printk("NVRAM_READ_FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0x40:
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+		}
+	}
+	
+	outb(LANBOOT_OFFSET, CMOS_INDEX_PORT);
+	ret = inb(CMOS_DATA_PORT);
+	
+	if(ret==0){
+		return sprintf(buf, "off\n");
+	}
+	else if(ret==1){
+		return sprintf(buf, "on\n");
+	}
+
+	return sprintf(buf, "UNKNOWN\n");
+}
+static ssize_t store_lanboot_setting(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	int ret;
+	int len = 0;
+	unsigned char wol_setting_value = 0;
+	unsigned char power_setting_value = 0;
+	unsigned char lanboot_setting_value = 0;
+	unsigned char checksum_caculated = 0;
+	
+	while(buf[len])
+		len++;
+	
+	if((len != 3) && (len != 4)){
+		printk("WRONG_STRING\n");
+		return count;
+	}
+	
+	ret = smi_read();
+		
+	switch(ret){
+		case 0: 
+			printk("BIOS_NO_RESPONSE\n");
+			return count;
+		case 0xEF:
+			printk("NVRAM_READ_FAIL\n");
+			return count;
+		case 0x40:
+			break;
+		default:
+			printk("UNKNOWN FAIL\n");
+			return count;
+	}
+	
+	outb(WOL_OFFSET, CMOS_INDEX_PORT);
+	wol_setting_value = inb(CMOS_DATA_PORT);
+	outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+	power_setting_value = inb(CMOS_DATA_PORT);
+		
+	if((len == 3) && (strncmp(buf, "on", strlen("on")) == 0)){
+		outb(LANBOOT_OFFSET, CMOS_INDEX_PORT);
+		outb(LANBOOT_ENABLE, CMOS_DATA_PORT);
+		
+		lanboot_setting_value = inb(CMOS_DATA_PORT);
+		if(lanboot_setting_value == LANBOOT_ENABLE){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+	
+	if((len == 4) && (strncmp(buf, "off", strlen("off")) == 0)){
+		outb(LANBOOT_OFFSET, CMOS_INDEX_PORT);
+		outb(LANBOOT_DISABLE, CMOS_DATA_PORT);
+		
+		lanboot_setting_value = inb(CMOS_DATA_PORT);
+		if(lanboot_setting_value == LANBOOT_DISABLE){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+
+	ret = smi_write();
+		
+	switch(ret){
+		case 0: 
+			printk("BIOS_NO_RESPONSE\n");
+			break;
+		case 0xEF:
+			printk("NVRAM_CMOS_COMPARE_FAIL\n");
+			break;
+		case 0xFF:
+			printk("NVRAM_WRITE_FAIL\n");
+			break;
+		case 0x40:
+			break;
+		default:
+			printk("UNKNOWN FAIL\n");
+			break;
+	}
+
+	return count;
+}
+
+DEVICE_ATTR(lanboot_setting, 0644, show_lanboot_setting, store_lanboot_setting);
+
+/* ------- device number attribute ------- */
+static ssize_t show_sugi_cmos_dev(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", sugi_cmos_major);
+}
+DEVICE_ATTR(sugi_cmos_dev, 0444, show_sugi_cmos_dev, NULL);
+
+/* ----------- PID attribute ------------ */
+static ssize_t show_device_id(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	int i=0;
+	char rv[32]; 
+	
+	for(i=0; i<=31; i++){
+		outb(device_id_offset[i], CMOS_INDEX_PORT);
+		rv[i] = inb(CMOS_DATA_PORT);
+	}
+	
+	return sprintf(buf, "%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c\n",
+	rv[0], rv[1], rv[2], rv[3], rv[4], rv[5], rv[6], rv[7], 
+	rv[8], rv[9], rv[10], rv[11], rv[12], rv[13], rv[14], rv[15],
+	rv[16], rv[17], rv[18], rv[19], rv[20], rv[21], rv[22], rv[23], 
+	rv[24], rv[25], rv[26], rv[27], rv[28], rv[29], rv[30], rv[31]);
+}
+
+static ssize_t store_device_id(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	int i;
+	int len = 0;
+	
+	while(buf[len])
+		len++;
+	
+	if(len != 33){
+		printk("WRONG_STRING\n");
+		return count;
+	}
+	
+	if(len == 33){
+		for(i = 0; i <= 31; i++){
+			if((buf[i] < 32) || (buf[i] > 126)){
+				printk("WRONG_STRING\n");
+				return count;
+			}
+		}
+	
+		for(i = 0; i <= 31; i++){
+			outb(device_id_offset[i], CMOS_INDEX_PORT);
+			outb(buf[i], CMOS_DATA_PORT);
+		}
+	}
+	
+	return count;
+}
+
+DEVICE_ATTR(device_id, 0644, show_device_id, store_device_id);
+
+/* --------- checksum attribute ---------- */
+static ssize_t show_checksum(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	int i;
+	unsigned int rv = 0;
+	
+	for(i=0; i<=3; i++) {
+		outb(checksum_offset[i], CMOS_INDEX_PORT);
+		rv |= inb(CMOS_DATA_PORT) << 8*(3-i);
+	}
+	
+	return sprintf(buf, "%08x\n", rv);
+}
+
+static ssize_t store_checksum(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	int i, j, tmp, len=0;
+	unsigned char checksum_orig[8];
+	unsigned char success_flag = 0;
+	
+	while(buf[len])
+		len++;
+	
+	if(len != 9){
+		printk("WRONG_STRING\n");
+		return count;
+	}
+	
+	else if(len == 9){
+		for(i=0; i<=7; i++) {
+			for(j=0; j<=21; j++) {
+				if(buf[i] == strtoint_info[j].strg){
+					checksum_orig[i] = strtoint_info[j].inte;
+					success_flag = 1;
+				}
+				else if (j == 21 && success_flag == 0){
+					printk("WRONG_STRING\n");
+					return count;
+				}
+			}
+			success_flag = 0;
+		}
+	
+		for(i=0; i<=3; i++) {
+			tmp = (checksum_orig[2*i] << 4) + checksum_orig[2*i+1];
+			outb(checksum_offset[i], CMOS_INDEX_PORT);
+			outb(tmp, CMOS_DATA_PORT);
+		}
+	}
+	
+	return count;
+}
+
+DEVICE_ATTR(checksum, 0644, show_checksum, store_checksum);
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2-5
+ * Description: Implement functions of board ID driver
+ * ---------------------------------------------------------------------------------------------- */
+
+/* ---------- board ID attribute --------- */
+static ssize_t show_board_id(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	if(boardid_num==0)
+		return sprintf(buf,"2HDD\n");
+	else if(boardid_num==1)
+		return sprintf(buf,"4HDD\n");
+	else if(boardid_num==2)
+		return sprintf(buf,"6HDD\n");
+	else if(boardid_num==3)
+		return sprintf(buf,"8HDD\n");
+	else if(boardid_num==4)
+		return sprintf(buf,"1U\n");
+	
+	return sprintf(buf, "Unknown\n");
+}
+
+DEVICE_ATTR(board_id, 0444, show_board_id, NULL);
+
+/* ------- device number attribute ------- */
+static ssize_t show_sugi_boardid_dev(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", sugi_boardid_major);
+}
+
+DEVICE_ATTR(sugi_boardid_dev, 0444, show_sugi_boardid_dev, NULL);
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 3
+ * Description: Chipsets and file system sheeting
+ * ---------------------------------------------------------------------------------------------- */
+
+/* ------- proc file system setting ------ */
+static int init_proc_files(void)
+{
+	int i = 0;
+	char buf[32];
+	
+	/* create /proc/buffalo */
+#ifdef CONFIG_BUFFALO_PLATFORM
+	extern struct proc_dir_entry *get_proc_buffalo(void);
+	buffalo_dir = get_proc_buffalo();
+#else	/* CONFIG_BUFFALO_PLATFORM */
+	buffalo_dir = proc_mkdir(BUFFALO_DIR, NULL);
+#endif	/* CONFIG_BUFFALO_PLATFORM */
+	
+	/* create /proc/buffalo/gpio */
+	gpio_dir = proc_mkdir(GPIO_DIR, NULL);
+	
+	
+	/* button driver */
+	/* create /proc/buffalo/gpio/switch */
+	switch_dir = proc_mkdir(SWITCH_DIR, NULL);
+	
+	/* create /proc/buffalo/gpio/switch/func(display) */
+	for(i = 0; i < MAX_SUPPORTED_BUTTONS; i++){
+		switch_file[i] =
+			proc_create_data(button_info[i].name,
+					 S_IRUGO,
+					 switch_dir,
+					 &sugi_button_status_file_ops,
+					 &button_info[i]);
+	}
+
+	/* HDD control driver */
+	/* create /proc/buffalo/gpio/hotplug */
+	hotplug_dir = proc_mkdir(HOTPLUG_DIR, NULL);
+	
+	/* create /proc/buffalo/gpio/hotplug/sata# */
+	for(i = 0; i < MAX_SUPPORTED_DISKS; i++){
+		sprintf(buf, "sata%d", i);
+		hotplug_sata_file[i] =
+			proc_create_data(buf, S_IRUGO,
+					 hotplug_dir,
+					 &sugi_hotplug_status_file_ops,
+					 &sugi_hdd_info[i]);
+	}
+
+	/* create /proc/buffalo/gpio/power_control */
+	power_control_dir = proc_mkdir(POWER_CONTROL_DIR, NULL);
+
+	/* create /proc/buffalo/gpio/power_control/hdd# */
+	for(i = 0; i < MAX_SUPPORTED_DISKS; i++){
+		sprintf(buf, "hdd%d", i);
+		power_control_hdd_file[i] =
+			proc_create_data(buf, S_IRUGO | S_IWUSR,
+					 power_control_dir,
+					 &sugi_power_control_file_ops,
+					 &sugi_hdd_info[i]);
+	}	
+
+	return 0;
+}
+
+
+/* ---------- sysfs file system ---------- */
+static int init_sysfs_files(void)
+{
+	int rv;
+	
+	if(sugi_cls)
+		return -EINVAL;
+
+	/* create /sys/class/sugi */
+	sugi_cls = class_create(THIS_MODULE, "sugi");
+
+
+	/* fan control driver */
+	/* create /sys/class/sugi/fan */
+	fan_dev = device_create(sugi_cls, NULL, sugit_fan, NULL, "fan");
+	
+	/* create /sys/class/sugi/fan/temp# */
+	rv = device_create_file(fan_dev, &dev_attr_temp1);
+	rv = device_create_file(fan_dev, &dev_attr_temp2);
+	rv = device_create_file(fan_dev, &dev_attr_temp3);
+	
+	/* create /sys/class/sugi/fan/fan#_rpm */
+	rv = device_create_file(fan_dev, &dev_attr_fan1_rpm);
+	rv = device_create_file(fan_dev, &dev_attr_fan2_rpm);
+	rv = device_create_file(fan_dev, &dev_attr_fan3_rpm);
+	rv = device_create_file(fan_dev, &dev_attr_fan4_rpm);
+	
+	/* create /sys/class/sugi/fan/fan#_speed */
+	rv = device_create_file(fan_dev, &dev_attr_fan1_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan2_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan3_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan4_speed);
+    
+	/* create /sys/class/sugi/fan/fan_pattern_speed */
+	rv = device_create_file(fan_dev, &dev_attr_fan_stop_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan_slow_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan_fast_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan_full_speed);
+    
+	/* create /sys/class/sugi/fan/show_speed_by string */
+	rv = device_create_file(fan_dev, &dev_attr_show_speed_by_string);
+    
+	/* create /sys/class/sugi/fan/fan_threshold */
+	rv = device_create_file(fan_dev, &dev_attr_fan_threshold);
+    
+	/* create /sys/class/sugi/fan/sugi_fan_dev */
+	rv = device_create_file(fan_dev, &dev_attr_sugi_fan_dev);
+	
+	
+	/* CMOS driver */
+	/* create /sys/class/sugi/cmos */
+	cmos_dev = device_create(sugi_cls, NULL, sugit_cmos, NULL, "cmos");
+	
+	/* create /sys/class/sugi/cmos/wol_setting */
+	rv = device_create_file(cmos_dev, &dev_attr_wol_setting);
+		
+	/* create /sys/class/sugi/cmos/power_setting */
+	rv = device_create_file(cmos_dev, &dev_attr_power_setting);
+		
+	/* create /sys/class/sugi/cmos/sugi_cmos_dev */
+	rv = device_create_file(cmos_dev, &dev_attr_sugi_cmos_dev);
+	
+		/* create /sys/class/sugi/cmos/pid */
+	rv = device_create_file(cmos_dev, &dev_attr_device_id);
+	
+	/* create /sys/class/sugi/cmos/checksum */
+	rv = device_create_file(cmos_dev, &dev_attr_checksum);
+  
+	/* create /sys/class/sugi/cmos/lanboot_setting */
+	/* this node and the related funciton will be 
+	   created if the BIOS version is newer than V209*/
+	if(bios_ver >= 209)
+		rv = device_create_file(cmos_dev, &dev_attr_lanboot_setting);
+  
+	
+	/* board ID driver */
+	/* create /sys/class/sugi/board */
+	boardid_dev = device_create(sugi_cls, NULL, sugit_boardid, NULL, "board");
+	
+	/* create /sys/class/sugi/board/board_id */
+	rv = device_create_file(boardid_dev, &dev_attr_board_id);
+		
+	/* create /sys/class/sugi/board/sugi_boardid_dev */
+	rv = device_create_file(boardid_dev, &dev_attr_sugi_boardid_dev);
+	
+	return 0;
+}
+
+/* ---------- BIOS version check --------- */
+static int bios_version_check(void)
+{
+	int i;
+	unsigned char* smbios_sm = NULL;
+	unsigned char* smbios_dmi = NULL;
+	unsigned char* smbios_eps = NULL;
+	unsigned char* smbios_base = NULL;
+	unsigned char* smbios_ver = NULL;
+	unsigned int smbios_base_addr = 0;
+
+	for(i = 0; i <= 0xFFF0; i += 0x01){
+		smbios_sm = ioremap(0x000F0000 + i, 4);
+		if(strncmp(smbios_sm, "_SM_", strlen("_SM_")) == 0){
+			smbios_dmi = ioremap(0x000F0000 + i + 0x10, 4);
+			if(strncmp(smbios_dmi, "_DMI_", strlen("_DMI_"))== 0){
+				smbios_eps = ioremap(0x000F0000 + i + 0x18, 4);
+				smbios_base_addr = ioread32(smbios_eps);
+				break;
+			}
+		}
+	}
+	
+	for(i = 0; i <= 0xFF; i += 0x01){
+		smbios_base = ioremap(smbios_base_addr + i, 1);
+		if(ioread8(smbios_base) == 0x33){
+			if(strncmp(smbios_base, "31SUG", strlen("31SUG")) == 0){
+				smbios_ver = ioremap(smbios_base_addr + i + 0x05, 1);
+				bios_ver = simple_strtoul(smbios_ver, NULL, 10);
+				iounmap(smbios_sm);
+				iounmap(smbios_dmi);
+				iounmap(smbios_eps);
+				iounmap(smbios_base);
+				iounmap(smbios_ver);
+				printk("BIOS VERSION : V%d\n",bios_ver);
+				return 0;
+			}
+		}
+	}
+
+	return 1;
+}
+/* ------------ IT8721 setting ----------- */
+	
+	/* button driver */
+void SetBTNMBPnP(void)
+{
+	unsigned int base_msb;
+	unsigned int base_lsb;
+	
+	/* select LDN 07h */	
+	outb(IT87_LDN_ADDR, CONFIG_ADDR_PORT);
+	outb(IT87_GPIO_LDN, CONFIG_DATA_PORT);
+	
+	/* find GPIO set3 base addr */
+	outb(IT87_SIMPLE_IO_BASE_MSB, CONFIG_ADDR_PORT);
+	base_msb = inb(CONFIG_DATA_PORT);
+	outb(IT87_SIMPLE_IO_BASE_LSB, CONFIG_ADDR_PORT);
+	base_lsb = inb(CONFIG_DATA_PORT);
+	it87_gpioset3_base_addr = (base_msb*256 + base_lsb) + GPIO_SET3_OFFSET;
+	
+	/* enable to generate SMI of PBD's IRQ */
+	outb(IT87_REG_SMI_CTL2, CONFIG_ADDR_PORT);
+	outb(inb(CONFIG_DATA_PORT)|0x01, CONFIG_DATA_PORT);
+	
+	/* set GPIO34/35 as de-bounce GPIO */
+	outb(IT87_REG_PNL_DBOUNCE0, CONFIG_ADDR_PORT);
+	outb(IT87_GP34_LOC | IT87_IRQEN, CONFIG_DATA_PORT);
+	
+	outb(IT87_REG_PNL_DBOUNCE1, CONFIG_ADDR_PORT);
+	outb(IT87_GP35_LOC, CONFIG_DATA_PORT);
+	
+	outb(IT87_REG_PNL_IRQ_SEL, CONFIG_ADDR_PORT);
+	outb(IT87_PNL_IRQ3, CONFIG_DATA_PORT);
+	}
+	
+/* fan control driver */
+void SetFANMBPnP(void)
+{
+	unsigned short BASE_ADDR_EXT;
+	unsigned short BASE_ADDR;
+
+	outb(IT87_LDN_ADDR, CONFIG_ADDR_PORT);
+	outb(IT87_EC_LDN, CONFIG_DATA_PORT);
+	outb(0x60,CONFIG_ADDR_PORT);
+	BASE_ADDR_EXT = inb(CONFIG_DATA_PORT)*256;
+	outb(0x61,CONFIG_ADDR_PORT);
+	BASE_ADDR = inb(CONFIG_DATA_PORT);
+  EC_BASE_ADDR = BASE_ADDR_EXT+BASE_ADDR;
+  IT87_EC_ADDR_REG = EC_BASE_ADDR+0x05;
+  IT87_EC_DATA_REG = EC_BASE_ADDR+0x06;
+}
+
+/* ------------ ich10r setting ----------- */
+static int ich10r_setting(void)
+{
+	int ret;
+	
+	pdev = pci_get_device(INTEL_ICH10R_VID, INTEL_ICH10R_DID, NULL);
+	if(!pdev)
+		return -ENODEV;
+	
+	ret = pci_read_config_dword(pdev, GPIOBASE, &ich10r_gpio_base_addr);
+	if(ret)
+		return -EINVAL;
+		
+	ret = pci_read_config_dword(pdev, PMBASE, &ich10r_pm_base_addr);
+	if(ret)
+		return -EINVAL;
+		
+	ich10r_gpio_base_addr &= 0x0000FF80;
+	
+	ich10r_pm_base_addr &= 0x0000FF80;
+	
+	/* Board ID driver */
+	/* set GPIO pin 29, 30 ,31 as GPIO function */
+	outl((inl(ich10r_gpio_base_addr+GP_USE_SEL)|0xE0000000), ich10r_gpio_base_addr+GP_USE_SEL);
+	
+	/* set GPIO pin 29, 30 ,31 as input */
+	outl((inl(ich10r_gpio_base_addr+GP_IO_SEL)|0xE0000000), ich10r_gpio_base_addr+GP_IO_SEL);
+	
+	/* get board ID relative GPIO pins status */
+	boardid_num = (inl(ich10r_gpio_base_addr+GP_LVL)&BOARD_ID_MASK) >> BOARD_ID_OFFSET;
+	
+	/* HDD control driver */
+	/* set relative GPIO pins as GPIO function */
+	outl((inl(ich10r_gpio_base_addr+GP_USE_SEL)|0x0002A6FD), ich10r_gpio_base_addr+GP_USE_SEL);
+	outl((inl(ich10r_gpio_base_addr+GP_USE_SEL2)|0x01000007), ich10r_gpio_base_addr+GP_USE_SEL2);
+	
+	/* set hotplug relative GPIO pins as input */
+	outl((inl(ich10r_gpio_base_addr+GP_IO_SEL)|0x0000A63C), ich10r_gpio_base_addr+GP_IO_SEL);
+	
+	/* set power control relative GPIO pins as outout */
+	outl((inl(ich10r_gpio_base_addr+GP_IO_SEL)&0xFFFDFF3D), ich10r_gpio_base_addr+GP_IO_SEL);
+	outl((inl(ich10r_gpio_base_addr+GP_IO_SEL2)&0xFEFFFFF8), ich10r_gpio_base_addr+GP_IO_SEL2);
+	
+	return 0;
+}
+
+/* ------------ initialization ----------- */
+static int __init sugi_platform_init(void)
+{  	
+	int ret;
+	
+	/* request IRQ3 */
+	ret = request_irq(3, sugi_interrupt, IRQF_SHARED, DRVNAME, sugi_interrupt);
+	if (ret) {
+		printk("%s: REQUEST IRQ3 FAIL\n", __FUNCTION__);
+		free_irq(3, 0);
+		return -EBUSY;
+	}
+	
+	/* chipsets initilization */
+	/* ICH10R */
+	ret = ich10r_setting();
+	if (ret) {
+		printk("%s: ICH10R INITIALIZE FAIL\n", __FUNCTION__);
+		return -ENODEV;
+	}
+	/* IT8721 */	
+	EnterMBPnP();
+	SetFANMBPnP();
+	//ExitMBPnP();
+	
+	//EnterMBPnP();
+	SetBTNMBPnP();
+	ExitMBPnP();
+	
+	/* register device to system */	
+	ret = register_chrdev_region(sugit_fan, sugi_dev_count, DRVNAME);
+	ret = register_chrdev_region(sugit_cmos, sugi_dev_count, DRVNAME);
+	ret = register_chrdev_region(sugit_boardid, sugi_dev_count, DRVNAME);
+	
+	/* check BIOS verion */
+	ret = bios_version_check();
+	if (ret) {
+		printk("%s: BIOS VERSION CHECK FAIL\n", __FUNCTION__);
+		return -EINVAL;
+	}
+	
+	/* create sysfs file system */
+	ret = init_sysfs_files();
+	if (ret) {
+		printk("%s: SYSFS INITALIZE FAIL\n", __FUNCTION__);
+		return -ENOMEM;
+	}
+		
+	/* create proc file system */
+	ret = init_proc_files();
+	if (ret) {
+		printk("%s: PROCFS INITALIZE FAIL\n", __FUNCTION__);
+		return -ENOMEM;
+	}
+	
+	SataHotplugPollingStart();
+	
+	printk("SUGI_PLATFORM MODULE HAS BEEN INITIALIZED\n");
+	
+	return 0;
+}
+
+/* ----------------- exit ---------------- */
+static void __exit sugi_platform_exit(void)
+{
+	int i = 0;
+	char buf[32];
+	
+	/* delete hotplug polling timer */
+	del_timer(&sata_hotplug_polling_timer);
+	
+	/* disable and release IRQ3 */
+	disable_irq(3);
+	free_irq(3, sugi_interrupt);
+	
+	/* remove proc file system nodes */
+	for(i = 0; i < MAX_SUPPORTED_BUTTONS; i++){
+		remove_proc_entry(button_info[i].name, switch_dir);
+	}
+	
+	for (i = 0; i < MAX_SUPPORTED_DISKS; i++){
+		sprintf(buf, "hdd%d", i);
+		remove_proc_entry(buf, power_control_dir);
+	}
+	
+	for (i = 0; i < MAX_SUPPORTED_DISKS; i++){
+		sprintf(buf, "sata%d", i);
+		remove_proc_entry(buf, hotplug_dir);
+	}
+	
+	remove_proc_entry(SWITCH_DIR, NULL);
+	remove_proc_entry(HOTPLUG_DIR, NULL);
+	remove_proc_entry(POWER_CONTROL_DIR, NULL);
+	remove_proc_entry(GPIO_DIR, NULL);
+	remove_proc_entry(BUFFALO_DIR, NULL);
+	
+	/* remove sysfs file system */
+	device_remove_file(fan_dev, &dev_attr_temp1);
+	device_remove_file(fan_dev, &dev_attr_temp2);
+	device_remove_file(fan_dev, &dev_attr_temp3);
+	device_remove_file(fan_dev, &dev_attr_fan1_rpm);
+	device_remove_file(fan_dev, &dev_attr_fan2_rpm);
+	device_remove_file(fan_dev, &dev_attr_fan1_speed);
+	device_remove_file(fan_dev, &dev_attr_fan2_speed);
+	device_remove_file(fan_dev, &dev_attr_fan_stop_speed);
+	device_remove_file(fan_dev, &dev_attr_fan_slow_speed);
+	device_remove_file(fan_dev, &dev_attr_fan_fast_speed);
+	device_remove_file(fan_dev, &dev_attr_fan_full_speed);
+	device_remove_file(fan_dev, &dev_attr_sugi_fan_dev);
+	device_remove_file(fan_dev, &dev_attr_fan_threshold);
+	device_remove_file(fan_dev, &dev_attr_show_speed_by_string);
+	
+	device_remove_file(cmos_dev, &dev_attr_wol_setting);
+	device_remove_file(cmos_dev, &dev_attr_power_setting);
+	device_remove_file(cmos_dev, &dev_attr_sugi_cmos_dev);
+	device_remove_file(cmos_dev, &dev_attr_device_id);
+	device_remove_file(cmos_dev, &dev_attr_checksum);
+	
+	if(bios_ver >= 209)
+		device_remove_file(cmos_dev, &dev_attr_lanboot_setting);
+	
+	device_remove_file(boardid_dev, &dev_attr_sugi_boardid_dev);
+	device_remove_file(boardid_dev, &dev_attr_board_id);
+	
+	device_destroy(sugi_cls, sugit_fan);
+	device_destroy(sugi_cls, sugit_cmos);
+	device_destroy(sugi_cls, sugit_boardid);
+	
+	class_destroy(sugi_cls);
+	
+	unregister_chrdev_region(sugit_fan, sugi_dev_count);
+	unregister_chrdev_region(sugit_cmos, sugi_dev_count);
+	unregister_chrdev_region(sugit_boardid, sugi_dev_count);
+  
+	printk("SUGI_PLATFORM MODULE HAS BEEN REMOVED\n");
+}
+
+module_init(sugi_platform_init);
+module_exit(sugi_platform_exit);
+MODULE_LICENSE("GPL");
diff --git a/buffalo/arch/x86/plat-usi/sugi_platform.h b/buffalo/arch/x86/plat-usi/sugi_platform.h
new file mode 100644
index 00000000..f4662fc
--- /dev/null
+++ b/buffalo/arch/x86/plat-usi/sugi_platform.h
@@ -0,0 +1,308 @@
+#if !defined __SUGI_PLATFORM_H__
+#define __SUGI_PLATFORM_H__
+
+/* common section */
+#define sugi_fan_major						125
+#define sugi_fan_minor						0
+#define sugi_cmos_major						124
+#define sugi_cmos_minor						0
+#define sugi_boardid_major				123
+#define sugi_boardid_minor				0
+#define sugi_dev_count        		1
+#define DRVNAME								"sugi_platform"
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 1
+ * Description: Definition of IT8721 registers
+ * ---------------------------------------------------------------------------------------------- */
+ 
+/* ----------- Common Sections ----------- */
+ 
+/* IT8721 config section */
+#define CONFIG_ADDR_PORT	       	0x2E
+#define CONFIG_DATA_PORT	       	0x2F
+#define IT87_LDN_ADDR		       		0x07
+ 
+/* ------------ Button Driver ------------ */
+
+/* IT8721 logic device number */
+#define	IT87_GPIO_LDN							0x07
+ 
+/* panel button de-bounce mapping */
+#define IT87_REG_PNL_DBOUNCE0			0xE0
+#define IT87_REG_PNL_DBOUNCE1			0xE1
+#define IT87_GP34_LOC							0x1C
+#define IT87_GP35_LOC							0x1D
+#define	IT87_IRQEN								0x40
+
+/* panel button de-bounce interrupt level select */
+#define IT87_REG_PNL_IRQ_SEL			0x70
+#define IT87_PNL_IRQ3							0x03	
+
+/* SMI control register, bit0 is used to enable PBD's IRQ */
+#define IT87_REG_SMI_CTL2 				0xF1
+#define SMI_CTL2_EN_PBD						0x01
+
+/* SMI status register2, bit7-6 is used to detect panel button de-bounce */
+#define IT87_REG_SMI_STS2					0xF3
+#define IT87_SMI_DEB_MASK					0xC0
+
+/* SMI status register2, bit0 is PBD's IRQ */
+#define IT87_SMI_STS2_PBD					0x01
+
+/* Simple I/O base addr */
+#define IT87_SIMPLE_IO_BASE_MSB		0x62
+#define IT87_SIMPLE_IO_BASE_LSB		0x63
+#define GPIO_SET3_OFFSET					0x2
+
+
+/* ---------- Fan Control Driver --------- */
+
+/* IT8721 logic device number */
+#define	IT87_EC_LDN								0x04
+
+/* IT8721 main fan control registers */
+#define IT87_EC_FAN_MAIN_CTL	   	0x13
+#define IT87_EC_FAN_CTL		       	0x14
+
+/* IT8721 fan tachometer registers */
+#define IT87_EC_FAN_TACO1	       	0x0D // FAN1
+#define IT87_EC_FAN_TACO2	       	0x0E // FAN2
+
+#define IT87_EC_FAN_TACO1_EXT	   	0x18
+#define IT87_EC_FAN_TACO2_EXT	   	0x19
+
+/* select PWM control mode  */
+#define IT87_EC_FAN_PWM1					0x15
+#define IT87_EC_FAN_PWM2					0x16
+
+/* set the PWM value */
+#define IT87_EC_FAN_SMART_PWM1		0x63
+#define IT87_EC_FAN_SMART_PWM2		0x6B
+
+/* IT8721 temprature registers */
+#define IT87_EC_TMPIN3						0x2B // SYSTIN(TMPIN3@schematic)
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2
+ * Description: Definition of ICH10R registers
+ * ---------------------------------------------------------------------------------------------- */ 
+ 
+/* ----------- Common Sections ----------- */
+
+/* vendor and device ID for Intel ICH10R */
+#define INTEL_ICH10R_VID					0x8086
+#define INTEL_ICH10R_DID					0x3A16
+#define GPIOBASE									0x48
+#define PMBASE										0x40
+
+/* GPIO register*/
+#define GP_USE_SEL								0x00
+#define GP_USE_SEL2								0x30
+#define GP_IO_SEL									0x04
+#define GP_IO_SEL2								0x34
+#define GP_LVL										0x0C
+#define GP_LVL2										0x38
+
+/* Power management register */
+#define PMBASE										0x40
+#define PM1_STS										0x00
+#define PM1_EN										0x02
+#define GEN_PMCON_3								0xA4
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 3
+ * Description: Path of proc file system
+ * ---------------------------------------------------------------------------------------------- */
+ 
+/* ----------- Common Sections ----------- */
+#define BUFFALO_DIR								"buffalo"
+#define GPIO_DIR									"buffalo/gpio" 
+ 
+/* ------------ Button Driver ------------ */
+#define SWITCH_DIR								"buffalo/gpio/switch"
+#define MAX_SUPPORTED_BUTTONS 		2
+
+/* ---------- HDD Control Driver --------- */
+#define HOTPLUG_DIR								"buffalo/gpio/hotplug"
+#define POWER_CONTROL_DIR					"buffalo/gpio/power_control"
+#define MAX_SUPPORTED_DISKS				8
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 4
+ * Description: Definitions of individual drivers
+ * ---------------------------------------------------------------------------------------------- */
+ 
+/* ------------ Button Driver ------------ */
+
+/* period of timer */      
+#define TIMER_DELAY								(HZ/500)
+
+/* Buttons section */
+#define BTN_FUNC	    	   				0
+#define BTN_DISP	 	  		 				1
+
+/* select SMI status bit7-6 */
+#define IT87_DEB0									0x40	
+#define IT87_DEB1									0x80	
+#define IT87_DEB0DEB1							0xC0
+
+/* bit5-4 in GPIO set3 */
+#define IT87_GP34_BIT4						0x10
+#define IT87_GP35_BIT5						0x20
+
+/* button information structure */
+struct button_info_st
+{
+	char name[32];
+	unsigned char reg_stat;
+};
+
+/* ---------- Fan Control Driver --------- */
+
+/* fan control information */
+struct fan_info_st{
+	unsigned char reg;
+	unsigned char reg_ext;
+	unsigned char reg_smart_pwm;
+	unsigned char reg_pwm;
+	unsigned char offset;
+};
+
+/* ---------- HDD Control Driver --------- */
+
+/*
+    hotplug     |	power control
+----------------------------------
+sata0 -> GPIO2	|	hdd0 -> GPIO17
+sata1 -> GPIO3	|	hdd1 -> GPIO1
+sata2 -> GPIO4	|	hdd2 -> GPIO6
+sata3 -> GPIO5	|	hdd3 -> GPIO7
+sata4 -> GPIO15	|	hdd4 -> GPIO56
+sata5 -> GPIO9	|	hdd5 -> GPIO32
+sata6 -> GPIO13	|	hdd6 -> GPIO33
+sata7 -> GPIO10	|	hdd7 -> GPIO34
+
+*/
+
+/* GPIO pin definition */
+#define HDD0_PRESENT_BIT					0x00000004	/* GPIO2 */
+#define HDD1_PRESENT_BIT					0x00000008	/* GPIO3 */
+#define HDD2_PRESENT_BIT					0x00000010	/* GPIO4 */
+#define HDD3_PRESENT_BIT					0x00000020	/* GPIO5 */
+#define HDD4_PRESENT_BIT					0x00008000	/* GPIO15*/
+#define HDD5_PRESENT_BIT					0x00000200	/* GPIO9 */
+#define HDD6_PRESENT_BIT					0x00002000	/* GPIO13*/
+#define HDD7_PRESENT_BIT					0x00000400	/* GPIO10*/
+
+#define HDD0_POWER_BIT						0x00020000	/*GPIO17*/
+#define HDD1_POWER_BIT						0x00000002	/*GPIO1*/
+#define HDD2_POWER_BIT						0x00000040	/*GPIO6*/
+#define HDD3_POWER_BIT						0x00000080	/*GPIO7*/
+#define HDD4_POWER_BIT						0x01000000	/*GPIO56*/
+#define HDD5_POWER_BIT						0x00000001	/*GPIO32*/
+#define HDD6_POWER_BIT						0x00000002	/*GPIO33*/
+#define HDD7_POWER_BIT						0x00000004	/*GPIO34*/
+
+#define HDD0_POWER_MASK						0xFFFDFFFF
+#define HDD1_POWER_MASK						0xFFFFFFFD
+#define HDD2_POWER_MASK						0xFFFFFFBF
+#define HDD3_POWER_MASK						0xFFFFFF7F
+#define HDD4_POWER_MASK						0xFEFFFFFF
+#define HDD5_POWER_MASK						0xFFFFFFFE
+#define HDD6_POWER_MASK						0xFFFFFFFD
+#define HDD7_POWER_MASK						0xFFFFFFFB
+
+
+/* HDD information structure */
+struct sugi_hdd_info_st {
+	uint32_t HDD_GPIO_PRESENT_REG;
+	uint32_t HDD_PRESENT_BIT;
+	uint32_t HDD_GPIO_POWER_REG;
+	uint32_t HDD_POWER_BIT;
+	uint32_t HDD_POWER_MASK;
+};
+
+/* definitions of status */
+#define PLUGGED_EVENT_MSG       	"SATA %d plugged"
+#define UNPLUGGED_EVENT_MSG     	"SATA %d unplugged"
+
+/* polling timer */
+#define SATA_POL_INTERVAL       	HZ/100
+#define SATA_POL_LOOPS          	10
+
+/* hotplug ststus strcture */
+typedef enum _sata_plug_state {
+	SATA_STAT_UNKNOWN,
+	SATA_STAT_PLUGGED,
+	SATA_STAT_UNPLUGGED,
+}SATA_PLUG_STATE;
+
+/* hotplug information strcture */
+struct sata_hotplug_data_st {
+	SATA_PLUG_STATE presentpinstat;
+	SATA_PLUG_STATE prevplugstat;
+	unsigned int loops;
+};
+
+/* ------------- CMOS Driver ------------- */
+
+/* IO index */
+#define	CMOS_INDEX_PORT						0x70
+#define	CMOS_DATA_PORT						0x71
+
+/* wake on LAN setting */
+#define WOL_OFFSET								0x70
+#define WOL_DISABLE								0x00
+#define WOL_ENABLE								0x01
+
+/* AC power loss setting */
+#define	AC_POWER_LOSS_OFFSET			0x71
+#define AC_POWER_LOSS_POWER_OFF 	0x00
+#define AC_POWER_LOSS_POWER_ON  	0x01
+#define AC_POWER_LOSS_LAST_STATE	0x02
+
+/* Gbe LAN boot setting */
+#define LANBOOT_OFFSET						0x75
+#define LANBOOT_DISABLE						0x00
+#define LANBOOT_ENABLE						0x01
+
+/* CMOS setting */
+#define CMOS_CHECKSUM_OFFSET			0x73
+#define CMOS_CHANGE_CHECKSUM			0xBF
+
+
+/* ASCII string strcture */
+struct strtoint_st {
+	unsigned char strg;
+	unsigned char inte;
+};
+
+/* SW SMI setting and return code */
+#define SW_SMI_OFFSET							0xB2
+#define SW_SMI_READ								0x76
+#define SW_SMI_WRITE							0x77 
+
+/* ----------- Board ID Driver ----------- */
+ 
+/*
+     SKU   | GPIO31   GPIO30   GPIO29 
+ ----------|-------- -------- --------
+  2HDD box |   0        0        0    
+  4HDD box |   0        0        1    
+  6HDD box |   0        1        0    
+  8HDD box |   0        1        1    
+  1U       |   1        0        0    
+*/
+
+#define GPIO29										0x20000000
+#define GPIO30										0x40000000
+#define GPIO31										0x80000000
+#define BOARD_ID_MASK							(GPIO29 | GPIO30 | GPIO31)
+#define BOARD_ID_OFFSET						29
+
+
+#endif
\ No newline at end of file
diff --git a/buffalo/drivers/Makefile b/buffalo/drivers/Makefile
new file mode 100644
index 00000000..b21427e
--- /dev/null
+++ b/buffalo/drivers/Makefile
@@ -0,0 +1,20 @@
+obj-$(CONFIG_BUFFALO_PLATFORM)		+= proc_entry.o
+obj-$(CONFIG_BUFFALO_PLATFORM)		+= buffalocore.o
+obj-$(CONFIG_BUFFALO_PLATFORM)		+= kernevntProc.o
+obj-$(CONFIG_BUFFALO_PLATFORM)		+= kernevnt.o
+
+obj-$(CONFIG_BUFFALO_MICON_V3)		+= micon_v3.o
+
+obj-$(CONFIG_BUFFALO_USE_UPS)		+= upsdrv.o rtc_nvram.o
+
+
+
+buffalo/drivers/buffalocore.o: buffalo/include/generated/builddate.h
+
+       chk_builddate.h = :
+ quiet_chk_builddate.h = echo '  CHK     $@'
+silent_chk_builddate.h = :
+buffalo/include/generated/builddate.h: FORCE
+	$(Q)mkdir -p buffalo/include/generated
+	@$($(quiet)chk_builddate.h)
+	$(Q)$(CONFIG_SHELL) $(srctree)/buffalo/scripts/mkbuilddate_h $@
diff --git a/buffalo/drivers/buffalocore.c b/buffalo/drivers/buffalocore.c
new file mode 100644
index 00000000..bb91fa4
--- /dev/null
+++ b/buffalo/drivers/buffalocore.c
@@ -0,0 +1,547 @@
+/*
+ *  Driver routines for BUFFALO Platform
+ *
+ *  Copyright (C)  BUFFALO INC.
+ *
+ *  This software may be used and distributed according to the terms of
+ *  the GNU General Public License (GPL), incorporated herein by reference.
+ *  Drivers based on or derived from this code fall under the GPL and must
+ *  retain the authorship, copyright and license notice.  This file is not
+ *  a complete program and may only be used when the entire operating
+ *  system is licensed under the GPL.
+ *
+ */
+
+#include <linux/version.h>
+#include <linux/kernel.h>
+#include <linux/slab.h>
+#include <linux/seq_file.h>
+#include <linux/ctype.h>
+#include <linux/string.h>
+#include <linux/module.h>
+#include <linux/proc_fs.h>
+#include <linux/init.h>
+#include <linux/device.h>
+#include <asm/uaccess.h>
+#include <linux/fs.h>
+
+#include "buffalocore.h"
+#include "kernevntProc.h"
+#include "buffalo/kernevnt.h"
+#include "proc_entry.h"
+#include "builddate.h"
+
+
+#define BUFCORE_VERSION "0.20"
+
+/* Module parameters */
+MODULE_AUTHOR("BUFFALO");
+MODULE_DESCRIPTION("Buffalo Platform Linux Driver");
+MODULE_LICENSE("GPL");
+MODULE_VERSION(BUFCORE_VERSION);
+
+//#define DEBUG
+#ifdef DEBUG
+#define FUNCTRACE(x)	x
+#else
+#define FUNCTRACE(x)	/* none */
+#endif
+
+void *
+buffalo_generic_seq_start(struct seq_file *m, loff_t *pos)
+{
+	return *pos < 1 ? SEQ_START_TOKEN : NULL;
+}
+
+void *
+buffalo_generic_seq_next(struct seq_file *m, void *v, loff_t *pos)
+{
+	++ *pos;
+	return NULL;
+}
+
+void
+buffalo_generic_seq_stop(struct seq_file *m, void *v)
+{
+}
+
+
+/*
+ *	/proc/buffalo/booting
+ */
+int buffalo_booting = 1;
+
+static int
+buffalo_booting_show(struct seq_file *m, void *v)
+{
+	seq_printf(m, "%d\n", buffalo_booting);
+	return 0;
+}
+
+static const struct seq_operations buffalo_booting_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_booting_show,
+};
+
+static int
+buffalo_booting_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_booting_op);
+}
+
+static ssize_t
+buffalo_booting_write(struct file *file, const char __user *buffer,
+		      size_t count, loff_t *ppos)
+{
+	char *kbuf;
+
+	kbuf = kmalloc(count + 1, GFP_KERNEL);
+	if (kbuf == NULL) {
+		return -ENOMEM;
+	}
+
+	if (copy_from_user(kbuf, buffer, count)) {
+		count = -EFAULT;
+		goto out;
+	}
+
+	if (kbuf[count - 1] == '\n') {
+		kbuf[count - 1] = '\0';
+	}
+	else {
+		kbuf[count] = '\0';
+	}
+
+	if (strncmp(kbuf, "0", 1) == 0) {
+		buffalo_booting = 0;
+	}
+	else if (strncmp(kbuf, "1", 1) == 0) {
+		buffalo_booting = 1;
+	}
+	else {
+		printk("unknown value for booting(%s)\n", kbuf);
+		count = -EINVAL;
+	}
+out:
+	kfree(kbuf);
+
+	return count;
+}
+
+static struct file_operations buffalo_booting_fops = {
+	.open		= buffalo_booting_open,
+	.read		= seq_read,
+	.write		= buffalo_booting_write,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static struct proc_entry_data buffalo_booting_entry =
+{
+	.path		= "booting",
+	.mode		= S_IRUGO|S_IWUSR,
+	.proc_fops	= &buffalo_booting_fops,
+	.data		= NULL,
+};
+
+
+/*
+ *	/proc/buffalo/cpu_status
+ */
+unsigned int bfMagicKey = MagicKeyHwPoff;
+
+static unsigned int
+bfGetMagicKey(void)
+{
+	return bfMagicKey;
+}
+
+/*
+ * define as 'weak',
+ * you can define architecture-depend bfSetMagicKey_arch()
+ */
+void (*bfSetMagicKey_arch)(unsigned int key) __attribute__((weak)) = NULL;
+
+static void
+bfSetMagicKey(unsigned int key)
+{ 
+	bfMagicKey = key;
+	if (bfSetMagicKey_arch != NULL) {
+		bfSetMagicKey_arch(key);
+	}
+}
+
+static struct buffalo_cpu_status_defs buffalo_cpu_status[] = {
+	{ MagicKeyNormalState,		"normal_state" },
+	{ MagicKeyReboot,		"reboot" },
+	{ MagicKeyWOLReadyState,	"WOLReady" },
+	{ MagicKeySwPoff,		"swpoff" },
+
+	{ MagicKeyTerminator,		NULL },
+};
+
+/*
+ * define as 'weak',
+ * you can define architecture-depend buffalo_cpu_status_arch
+ */
+struct buffalo_cpu_status_defs *buffalo_cpu_status_arch __attribute__((weak)) = NULL;
+
+
+static char *
+buffalo_find_cpu_status_str(unsigned int key,
+			    struct buffalo_cpu_status_defs *defs,
+			    struct buffalo_cpu_status_defs *defs_arch)
+{
+	int i;
+
+	for (i = 0; defs[i].stat != MagicKeyTerminator; i ++) {
+		if (defs[i].stat == key) {
+			return defs[i].str;
+		}
+	}
+
+	if (defs_arch != NULL) {
+		for (i = 0; defs_arch[i].stat != MagicKeyTerminator; i ++) {
+			if (defs_arch[i].stat == key) {
+				return defs_arch[i].str;
+			}
+		}
+	}
+
+	return NULL;
+}
+
+static unsigned int
+buffalo_find_cpu_status_id(char *stat_str,
+			   struct buffalo_cpu_status_defs *defs,
+			   struct buffalo_cpu_status_defs *defs_arch)
+{
+	int i;
+
+	for (i = 0; defs[i].stat != MagicKeyTerminator; i ++) {
+		if (strcmp(defs[i].str, stat_str) == 0) {
+			return defs[i].stat;
+		}
+	}
+
+	if (defs_arch != NULL) {
+		for (i = 0; defs_arch[i].stat != MagicKeyTerminator; i ++) {
+			if (strcmp(defs_arch[i].str, stat_str) == 0) {
+				return defs_arch[i].stat;
+			}
+		}
+	}
+
+	return MagicKeyTerminator;
+}
+
+static int
+buffalo_cpu_status_show(struct seq_file *m, void *v)
+{
+	unsigned int CpuStatus = bfGetMagicKey();
+	char *stat_str;
+
+	stat_str = buffalo_find_cpu_status_str(CpuStatus,
+					       buffalo_cpu_status,
+					       buffalo_cpu_status_arch);
+	if (stat_str != NULL) {
+		seq_printf(m, "%s\n", stat_str);
+	}
+	else {
+		seq_printf(m, "Unknown(CpuStatus=%u)\n", CpuStatus);
+	}
+
+	return 0;
+}
+
+static const struct seq_operations buffalo_cpu_status_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_cpu_status_show,
+};
+
+static int
+buffalo_cpu_status_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_cpu_status_op);
+}
+
+static ssize_t
+buffalo_cpu_status_write(struct file *file, const char __user *buffer,
+			 size_t count, loff_t *ppos)
+{
+	char *kbuf;
+	unsigned int CpuStatus;
+
+	kbuf = kmalloc(count + 1, GFP_KERNEL);
+	if (kbuf == NULL) {
+		return -ENOMEM;
+	}
+
+	if (copy_from_user(kbuf, buffer, count)) {
+		count = -EFAULT;
+		goto out;
+	}
+
+	if (kbuf[count - 1] == '\n') {
+		kbuf[count -1] = '\0';
+	}
+	else {
+		kbuf[count] = '\0';
+	}
+
+	CpuStatus = buffalo_find_cpu_status_id(kbuf,
+					       buffalo_cpu_status,
+					       buffalo_cpu_status_arch);
+
+	if (CpuStatus != MagicKeyTerminator) {
+		bfSetMagicKey(CpuStatus);
+	}
+	else{
+		printk("unknown cpu_status(%s)\n", kbuf);
+		count = -EINVAL;
+	}
+out:
+	kfree(kbuf);
+
+	return count;
+}
+
+static struct file_operations buffalo_cpu_status_fops = {
+	.open		= buffalo_cpu_status_open,
+	.read		= seq_read,
+	.write		= buffalo_cpu_status_write,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static struct proc_entry_data buffalo_cpu_status_entry =
+{
+	.path		= "cpu_status",
+	.mode		= S_IRUGO|S_IWUSR,
+	.proc_fops	= &buffalo_cpu_status_fops,
+	.data		= NULL,
+};
+
+
+
+/*
+ *	/proc/buffalo/firmware
+ */
+char buffalo_bootver[32] = { 0 };
+char buffalo_series_name[32] = { 0 };
+char buffalo_product_name[32] = { 0 };
+char buffalo_product_id[32] = { 0 };
+
+struct {
+	char *key;
+	char *value;
+	char *default_val;
+} cmdline_opts[] = {
+	{ "BOOTVER=",		buffalo_bootver,	"Unknown" },
+	{ "SERIES=",		buffalo_series_name,	"Unknown" },
+	{ "PRODUCTNAME=",	buffalo_product_name,	"Unknown" },
+	{ "PRODUCTID=",		buffalo_product_id,	"0x00000000" },
+};
+
+static int
+buffalo_firmware_show(struct seq_file *m, void *v)
+{
+	int i;
+
+	for (i = 0; i < ARRAY_SIZE(cmdline_opts); i ++) {
+		char *p, *pe;
+
+		if (!isalpha(cmdline_opts[i].value[0])) {
+			memset(cmdline_opts[i].value, 0,
+			       sizeof(cmdline_opts[i].value));
+			p = strstr(saved_command_line, cmdline_opts[i].key);
+			if (p != NULL) {
+				p += strlen(cmdline_opts[i].key);
+				pe = strstr(p, " ");
+
+				if ((pe != NULL) &&
+				    ((pe - p) < sizeof(cmdline_opts[i].value))){
+					strncpy(cmdline_opts[i].value,
+						p, pe - p);
+				}
+				else {
+					strncpy(cmdline_opts[i].value,
+						p, sizeof(cmdline_opts[i].value));
+				}
+			}
+			else {
+				sprintf(cmdline_opts[i].value, "%s",
+					cmdline_opts[i].default_val);
+			}
+		}
+	}
+
+	seq_printf(m, "SERIES=%s\n", buffalo_series_name);
+	seq_printf(m, "PRODUCTNAME=%s\n", buffalo_product_name);
+	seq_printf(m, "VERSION=%s\n", BUFCORE_VERSION);
+	seq_printf(m, "SUBVERSION=FLASH 0.00\n");
+	seq_printf(m, "PRODUCTID=%s\n", buffalo_product_id);
+	seq_printf(m, "BUILDDATE=%s %s\n",
+		   BUFFALO_BUILD_DATE, BUFFALO_BUILD_TIME);
+	seq_printf(m, "BOOTVER=%s\n", buffalo_bootver);
+
+	return 0;
+}
+
+static const struct seq_operations buffalo_firmware_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_firmware_show,
+};
+
+static int
+buffalo_firmware_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_firmware_op);
+}
+
+static struct file_operations buffalo_firmware_fops = {
+	.open		= buffalo_firmware_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static struct proc_entry_data buffalo_firmware_entry =
+{
+	.path		= "firmware",
+	.mode		= S_IRUGO,
+	.proc_fops	= &buffalo_firmware_fops,
+	.data		= NULL,
+};
+
+
+/*
+ *	/proc/buffalo/micon
+ */
+#if defined(CONFIG_BUFFALO_USE_MICON) && !defined(CONFIG_BUFFALO_MICON_V3)
+static int
+buffalo_micon_show(struct seq_file *m, void *v)
+{
+	seq_printf(m, "on\n");
+	return 0;
+}
+
+static const struct seq_operations buffalo_micon_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_micon_show,
+};
+
+static int
+buffalo_micon_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_micon_op);
+}
+
+static struct file_operations buffalo_micon_fops = {
+	.open		= buffalo_micon_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static struct proc_entry_data buffalo_micon_entry =
+{
+	.path		= "micon",
+	.mode		= S_IRUGO,
+	.proc_fops	= &buffalo_micon_fops,
+	.data		= NULL,
+};
+
+
+/*
+ * /proc/buffalo/miconint_en
+ */
+static int
+buffalo_miconint_en_show(struct seq_file *m, void *v)
+{
+	seq_printf(m, "MiconAct\n");
+	return 0;
+}
+
+static const struct seq_operations buffalo_miconint_en_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_miconint_en_show,
+};
+
+static int
+buffalo_miconint_en_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_miconint_en_op);
+}
+
+static struct file_operations buffalo_miconint_en_fops = {
+	.open		= buffalo_miconint_en_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static struct proc_entry_data buffalo_micon_entry =
+{
+	.path		= "miconint_en",
+	.mode		= S_IRUGO0,
+	.proc_fops	= &buffalo_miconint_en_fops,
+	.data		= NULL,
+};
+#endif	/* CONFIG_BUFFALO_USE_MICON && !CONFIG_BUFFALO_MICON_V3 */
+
+static struct proc_entry_data *ped_list[] = {
+	&buffalo_booting_entry,
+	&buffalo_cpu_status_entry,
+	&buffalo_firmware_entry,
+#if defined(CONFIG_BUFFALO_USE_MICON) && !defined(CONFIG_BUFFALO_MICON_V3)
+	&buffalo_micon_entry,
+	&buffalo_miconint_en_entry,
+#endif	/* CONFIG_BUFFALO_USE_MICON && !CONFIG_BUFFALO_MICON_V3 */
+	NULL,
+};
+
+//----------------------------------------------------------------------
+int __init
+buffaloDriver_init (void)
+{
+	int i;
+
+        FUNCTRACE(printk(">%s\n",__FUNCTION__));
+
+	for (i = 0; ped_list[i]; i ++) {
+		make_proc_entry(ped_list[i]);
+	}
+
+	return 0;
+}
+
+//----------------------------------------------------------------------
+void
+buffaloDriver_exit(void)
+{
+	int i;
+	struct proc_dir_entry *buffalo;
+
+	FUNCTRACE(printk(">%s\n",__FUNCTION__));
+
+	buffalo = get_proc_buffalo();
+	for (i = 0; ped_list[i]; i++) {
+		remove_proc_entry(ped_list[i]->path, buffalo);
+	}
+
+	remove_proc_entry ("buffalo", 0);
+}
+
+module_init(buffaloDriver_init);
+module_exit(buffaloDriver_exit);
diff --git a/buffalo/drivers/buffalocore.h b/buffalo/drivers/buffalocore.h
new file mode 100644
index 00000000..880c6cf
--- /dev/null
+++ b/buffalo/drivers/buffalocore.h
@@ -0,0 +1,27 @@
+#if !defined(_BUFFALOCORE_H_)
+#define _BUFFALOCORE_H_
+
+#ifdef CONFIG_X86
+#else // CONFIG_X86
+#if defined(CONFIG_ARCH_FEROCEON_MV78XX0)
+#include "boardEnv/buffalo/buffalo78100BoardEnv.h"
+#include "boardEnv/mvBoardEnvSpec.h"
+#endif
+
+#endif // CONFIG_X86
+
+#if defined(CONFIG_ARCH_FEROCEON_KW) || defined(CONFIG_ARCH_ARMADA370) || defined(CONFIG_ARCH_ARMADA_XP)
+
+#include "boardEnv/mvBoardEnvLib.h"
+
+struct bf_proc_entry_tab {
+  const char *name;
+  int isDirectory;
+  read_proc_t *read_proc;
+  write_proc_t *write_proc;
+  void *data;
+  MV_BOARD_GPP_CLASS class;
+};
+#endif
+
+#endif
diff --git a/buffalo/drivers/kernevnt.c b/buffalo/drivers/kernevnt.c
new file mode 100644
index 00000000..710029c
--- /dev/null
+++ b/buffalo/drivers/kernevnt.c
@@ -0,0 +1,359 @@
+/*
+ *  LinkStation/TeraStation Kernel Event Driver
+ *
+ *  Copyright (C)  BUFFALO INC.
+ *
+ *  This software may be used and distributed according to the terms of
+ *  the GNU General Public License (GPL), incorporated herein by reference.
+ *  Drivers based on or derived from this code fall under the GPL and must
+ *  retain the authorship, copyright and license notice.  This file is not
+ *  a complete program and may only be used when the entire operating
+ *  system is licensed under the GPL.
+ *
+ */
+#include <linux/version.h>
+#include <linux/sched.h>
+#include <linux/module.h>
+#include <linux/kernel.h>
+#include <linux/delay.h>
+#include <linux/errno.h>
+#include <linux/init.h>
+#include <linux/fs.h>
+#include <linux/miscdevice.h>
+#ifdef CONFIG_PHYLIB
+#include <linux/netdevice.h>
+#include <linux/phy.h>
+#endif /*CONFIG_PHYLIB*/
+#include <asm/string.h>
+#include <asm/io.h>
+#include <asm/uaccess.h>
+#include <asm/serial.h>
+#include "buffalo/kernevnt.h"
+#include "kernevntProc.h"
+
+#define bzero(p,sz) memset(p,0,sz)
+
+//#define DEBUG
+//#define FUNCMSG
+
+#ifdef DEBUG
+#define TRACE(x)	x
+#else
+#define TRACE(x)	/* none */
+#endif
+
+#ifdef FUNCMSG
+#define FUNC_MSG(x)	x
+#else	/* FUNCMSG */
+#define FUNC_MSG(x)	/* none */
+#endif	/* FUNCMSG */
+
+static DEFINE_SPINLOCK(BuffaloMicon_event_lock);
+
+wait_queue_head_t buffalo_kernevnt_WaitQueue;
+static int initialized=0;
+static struct tag_MiconDevice {
+	struct {
+		char cmd[MAX_CMDLEN+1];
+	} cmdqueue[MAX_QUELEN];
+	int rindex,windex;
+} MiconDevice;
+
+//--------------------------------------------------------------
+void
+buffalo_kernevnt_queuein(const char *cmd)
+{
+	if (!initialized){
+		return;
+	}
+	printk(KERN_DEBUG "kernevnt: %s\n", cmd);
+	if (MiconDevice.cmdqueue[MiconDevice.windex].cmd[0] == 0) {
+		unsigned long flags;
+		spin_lock_irqsave(&BuffaloMicon_event_lock, flags);
+
+		strncpy(MiconDevice.cmdqueue[MiconDevice.windex].cmd,
+			cmd, MAX_CMDLEN - 1);
+		MiconDevice.windex ++;
+		if (MiconDevice.windex == ARRAY_SIZE(MiconDevice.cmdqueue)) {
+			MiconDevice.windex = 0;
+		}
+
+		spin_unlock_irqrestore(&BuffaloMicon_event_lock, flags);
+
+		TRACE(printk("queue in : r=%d w=%d [%s]\n",
+			     MiconDevice.rindex, MiconDevice.windex, cmd));
+	}
+	else {
+		TRACE(printk("queue full [%s]\n",cmd));
+	}
+	wake_up_interruptible(&buffalo_kernevnt_WaitQueue);
+}
+
+//--------------------------------------------------------------
+int
+buffalo_kernevnt_queueout(unsigned char *cmd, int *len)
+{
+	if (!initialized){
+		return -1;
+	}
+	if (MiconDevice.cmdqueue[MiconDevice.rindex].cmd[0] != 0){
+		int index;
+		index = MiconDevice.rindex;
+
+		TRACE(printk("queue out : r=%d w=%d [%s]\n",
+			     MiconDevice.rindex, MiconDevice.windex,
+			     MiconDevice.cmdqueue[index].cmd));
+
+		spin_lock_irq(&BuffaloMicon_event_lock);
+		
+		if (MiconDevice.cmdqueue[index].cmd[0] != 0) {
+			strncpy(cmd, MiconDevice.cmdqueue[index].cmd,
+				MAX_CMDLEN);
+			*len = strlen(cmd) + 1;  // for NULL terminate.
+			MiconDevice.cmdqueue[index].cmd[0] = 0;
+		}
+		MiconDevice.rindex ++;
+		if (MiconDevice.rindex == ARRAY_SIZE(MiconDevice.cmdqueue)) {
+			MiconDevice.rindex = 0;
+		}
+
+		spin_unlock_irq (&BuffaloMicon_event_lock);
+
+		return index;
+	}
+	else{
+		TRACE(printk("queue none\n"));
+	}
+	return -1;
+}
+
+#ifdef CONFIG_MD
+//--------------------------------------------------------------
+void
+kernevnt_RaidRecovery(int devno, int on, int isRecovery, int major, int minor)
+{
+	static int opencnt = 0;
+	char buff[64];
+
+	FUNC_MSG(printk(">%s:md%d on=%d cnt=%d isRecovery=%d %d %d\n",
+			__FUNCTION__, devno, on, opencnt, isRecovery,
+			major, minor));
+	
+	if (on) {
+		opencnt ++;
+	}
+	else {
+		opencnt --;
+	}
+	
+	if (isRecovery) {
+		sprintf(buff,"raidrecovery %d %d %d %d %d %d",
+			devno, on, opencnt, isRecovery, major, minor);
+	}
+	else{
+		sprintf(buff,"raidresync %d %d %d %d",
+			devno, on, opencnt, isRecovery);
+	}
+	buffalo_kernevnt_queuein(buff);
+}
+//--------------------------------------------------------------
+void
+kernevnt_RaidScan(int devno, int on)
+{
+	static int opencnt = 0;
+	char buff[64];
+
+	FUNC_MSG(printk(">%s:md%d on=%d cnt=%d\n",
+			__FUNCTION__, devno, on, opencnt));
+
+	if (on) {
+		opencnt ++;
+	}
+	else {
+		opencnt --;
+	}
+
+	sprintf(buff, "raidscan %d %d %d", devno, on, opencnt);
+	buffalo_kernevnt_queuein(buff);
+}
+//--------------------------------------------------------------
+void
+kernevnt_RaidDegraded(int devno, int major, int minor)
+{
+	char buff[64];
+
+	FUNC_MSG(printk(">%s:md%d %d %d\n",
+			__FUNCTION__, devno, major, minor));
+
+	sprintf(buff,"raiddegraded %d %d %d", devno, major, minor);
+	buffalo_kernevnt_queuein(buff);
+}
+//--------------------------------------------------------------
+void
+kernevnt_RaidReshape(int devno, int on)
+{
+	static int opencnt = 0;
+	char buff[64];
+
+	if (on) {
+		opencnt++;
+	}
+	else {
+		opencnt--;
+	}
+
+	sprintf(buff, "raidreshape %d %d %d", devno, on, opencnt);
+	buffalo_kernevnt_queuein(buff);
+}
+
+#endif /* CONFIG_MD */
+
+//--------------------------------------------------------------
+void
+kernevnt_FlashUpdate(int on)
+{
+	char msg[32];
+
+	FUNC_MSG(printk(">%s (%d)\n", __FUNCTION__, on));
+
+	sprintf(msg, "flashupdate %d", on);
+	buffalo_kernevnt_queuein(msg);
+}
+
+//--------------------------------------------------------------
+#ifdef CONFIG_PHYLIB
+void
+kernevnt_LanAct_phydev(void *data)
+{
+	struct phy_device *phydev = data;
+	struct net_device *netdev;
+	char msg[128];
+
+	BUG_ON(!phydev);
+	netdev = phydev->attached_dev;
+	BUG_ON(!netdev);
+	sprintf(msg, "lanact %d %s %s",
+	    phydev->link ? phydev->speed : 0,
+	    phydev->duplex ? "full" : "half",
+	    netdev->name);
+	buffalo_kernevnt_queuein(msg);
+}
+void (*kernevnt_LanAct_arch)(void *data) = kernevnt_LanAct_phydev;
+#else /*CONFIG_PHYLIB*/
+void (*kernevnt_LanAct_arch)(void *data) = NULL;
+#endif /*CONFIG_PHYLIB*/
+void
+kernevnt_LanAct(void *data)
+{
+	if (kernevnt_LanAct_arch != NULL) {
+		kernevnt_LanAct_arch(data);
+	}
+}
+void
+kernevnt_LanAct_params(char *name, int speed, int duplex)
+{
+	char msg[128];
+
+	sprintf(msg, "lanact %d %s %s",
+	    speed,
+	    duplex ? "full" : "half",
+	    name);
+	buffalo_kernevnt_queuein(msg);
+}
+
+void
+kernevnt_SwitchHubAct(const char *msg)
+{
+	buffalo_kernevnt_queuein(msg);
+}
+
+//--------------------------------------------------------------
+void
+kernevnt_IOErr(const char *kdevname, const char *dir, unsigned long long sector, unsigned int errcnt)
+{
+	char msg[64];
+
+	FUNC_MSG(printk(">%s(%s): I/O error, dev %s, sector %llu\n",
+			__FUNCTION__,kdevname, dir,
+			(unsigned long long)sector, errcnt));
+
+	sprintf(msg,"ioerr %s %s %llu %u",kdevname, dir,
+		(unsigned long long)sector, errcnt);
+	buffalo_kernevnt_queuein(msg);
+}
+
+//--------------------------------------------------------------
+void
+kernevnt_DriveDead(const char *drvname)
+{
+	char msg[64];
+
+	FUNC_MSG(printk(">%s: drive %s is dead.\n",__FUNCTION__,drvname));
+
+	sprintf(msg,"drivedead %s",drvname);
+	buffalo_kernevnt_queuein(msg);
+}
+
+//--------------------------------------------------------------
+void
+kernevnt_I2cErr(void)
+{
+	printk(">%s\n",__FUNCTION__);
+	buffalo_kernevnt_queuein("i2c_error");
+}
+
+//--------------------------------------------------------------
+void
+kernevnt_MiconInt(void)
+{
+	FUNC_MSG(printk(">%s\n",__FUNCTION__));
+
+	buffalo_kernevnt_queuein("micon_interrupts");
+}
+
+//--------------------------------------------------------------
+void
+kernevnt_EnetOverload(const char *name)
+{
+	char msg[64];
+
+	FUNC_MSG(printk(">%s\n",__FUNCTION__));
+
+	sprintf(msg,"enetover %s",name);
+	buffalo_kernevnt_queuein(msg);
+}
+
+//--------------------------------------------------------------
+/*
+ * Initialize driver.
+ */
+int __init
+BuffaloMicon_init (void)
+{
+	TRACE(printk(">%s\n",__FUNCTION__));
+	printk("MICON ctrl (C) BUFFALO INC. V.1.00 installed.\n"); 
+	
+	// Initialize Local valiables
+	bzero(&MiconDevice, sizeof(MiconDevice));
+	init_waitqueue_head(&buffalo_kernevnt_WaitQueue);
+	initialized=1;
+	return 0;
+}
+
+//--------------------------------------------------------------
+void
+BuffaloMicon_exit(void)
+{
+	TRACE(printk(">%s\n",__FUNCTION__));
+	printk("MICON ctrl removed.\n");
+	initialized=0;
+
+}
+
+EXPORT_SYMBOL(buffalo_kernevnt_queuein);
+EXPORT_SYMBOL(buffalo_kernevnt_queueout);
+EXPORT_SYMBOL(buffalo_kernevnt_WaitQueue);
+
+module_init(BuffaloMicon_init);
+module_exit(BuffaloMicon_exit);
+MODULE_LICENSE("GPL");
diff --git a/buffalo/drivers/kernevntProc.c b/buffalo/drivers/kernevntProc.c
new file mode 100644
index 00000000..ec833ff
--- /dev/null
+++ b/buffalo/drivers/kernevntProc.c
@@ -0,0 +1,130 @@
+/*
+ *  LinkStation/TeraStation Kernel Event Proc Driver
+ *
+ *  Copyright (C)  BUFFALO INC.
+ *
+ *  This software may be used and distributed according to the terms of
+ *  the GNU General Public License (GPL), incorporated herein by reference.
+ *  Drivers based on or derived from this code fall under the GPL and must
+ *  retain the authorship, copyright and license notice.  This file is not
+ *  a complete program and may only be used when the entire operating
+ *  system is licensed under the GPL.
+ *
+ */
+#include <linux/version.h>
+#include <linux/sched.h>
+#include <linux/seq_file.h>
+#include <linux/module.h>
+#include <linux/kernel.h>
+#include <linux/delay.h>
+#include <linux/errno.h>
+#include <linux/init.h>
+#include <linux/fs.h>
+#include <linux/proc_fs.h>
+#include <linux/string.h>
+#include <linux/uaccess.h>
+
+#include "buffalocore.h"
+#include "kernevntProc.h"
+#include "proc_entry.h"
+
+#define bzero(p,sz) memset(p,0,sz)
+
+//#define DEBUG
+
+#ifdef DEBUG
+ #define TRACE(x) x
+#else
+ #define TRACE(x)
+#endif
+
+extern void buffalo_kernevnt_queuein(const char *cmd);
+extern int buffalo_kernevnt_queueout(unsigned char *cmd, int *len);
+extern wait_queue_head_t  buffalo_kernevnt_WaitQueue;
+
+
+// event notice from kernel
+static int
+BuffaloKernevnt_show(struct seq_file *m, void *v)
+{
+	int len = 0;
+	char retbuff[MAX_CMDLEN + 1 + 2];
+
+	if (wait_event_interruptible(buffalo_kernevnt_WaitQueue,
+		buffalo_kernevnt_queueout(retbuff, &len) >= 0) != 0) {
+		return -EIO;	/* XXX : reasonable ? */
+	}
+	
+	seq_printf(m, "%s", retbuff);
+	return 0;
+}
+
+extern void *buffalo_generic_seq_start(struct seq_file *m, loff_t *pos);
+extern void *buffalo_generic_seq_next(struct seq_file *m, void *v, loff_t *pos);
+extern void buffalo_generic_seq_stop(struct seq_file *m, void *v);
+
+static const struct seq_operations buffalo_kernevnt_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= BuffaloKernevnt_show,
+};
+
+static int
+BuffaloKernevnt_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_kernevnt_op);
+}
+static ssize_t
+BuffaloKernevnt_write(struct file *file, const char __user *buf, size_t count, loff_t *ppos)
+{
+	char kbuf[MAX_CMDLEN + 1 + 2];
+
+	if (count >= sizeof(kbuf)) {
+		count = sizeof(kbuf) - 1;
+	}
+	if (copy_from_user(kbuf, buf, count)) {
+		return -EFAULT;
+	}
+	kbuf[count] = 0;
+	buffalo_kernevnt_queuein(kbuf);
+	*ppos += count;
+	return count;
+}
+
+static struct file_operations kernevnt_fops = {
+	.open		= BuffaloKernevnt_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+	.write		= BuffaloKernevnt_write,
+};
+
+
+/*
+ * Initialize driver.
+ */
+int
+BuffaloKernevnt_init (void)
+{
+	TRACE(printk(">%s\n",__FUNCTION__));
+	printk("Kernel event proc (C) BUFFALO INC. V.1.00 installed.\n"); 
+
+	proc_create("kernevnt", S_IRUGO|S_IWUSR, get_proc_buffalo(), &kernevnt_fops);
+	
+	return 0;
+}
+
+void
+BuffaloKernevnt_exit(void)
+{
+	TRACE(printk(">%s\n",__FUNCTION__));
+	remove_proc_entry("kernevnt", get_proc_buffalo());
+	printk("Kernel event proc removed.\n");
+}
+
+
+module_init(BuffaloKernevnt_init);
+module_exit(BuffaloKernevnt_exit);
+
+MODULE_LICENSE("GPL");
diff --git a/buffalo/drivers/kernevntProc.h b/buffalo/drivers/kernevntProc.h
new file mode 100644
index 00000000..75570e1
--- /dev/null
+++ b/buffalo/drivers/kernevntProc.h
@@ -0,0 +1,11 @@
+#ifndef _KERNEVNTPROC_H_
+#define _KERNEVNTPROC_H_
+
+#define MAX_CMDLEN  32
+#define MAX_QUELEN  32
+
+int BuffaloKernevnt_init (void);
+void BuffaloKernevnt_exit(void);
+
+#endif
+
diff --git a/buffalo/drivers/micon_v3.c b/buffalo/drivers/micon_v3.c
new file mode 100644
index 00000000..3fcbc1d
--- /dev/null
+++ b/buffalo/drivers/micon_v3.c
@@ -0,0 +1,328 @@
+/*
+ *
+ */
+
+#include <linux/kernel.h>
+#include <linux/slab.h>
+#include <linux/tty.h>
+#include <linux/uaccess.h>
+#include <linux/syscalls.h>
+#include <linux/delay.h>
+#include <buffalo/micon_v3.h>
+
+
+#ifdef CONFIG_BUFFALO_MICON_V3_DEVTTY
+#define MICON_DEV		CONFIG_BUFFALO_MICON_V3_DEVTTY
+#else	/* CONFIG_BUFFALO_MICON_V3_DEVTTY */
+#warning "CONFIG_BUFFALO_MICON_V3_DEVTTY is not defined, use /dev/ttyS1"
+#define MICON_DEV		"/dev/ttyS1"
+#endif	/* CONFIG_BUFFALO_MICON_V3_DEVTTY */
+#define MICON_BAUD		115200
+#define MICON_BAUD_SYM		B115200
+
+#define MICON_INIT_MARK		0x1b	/* (ESC) */
+#define MICON_DELIMITER		0x0d	/* "\r" */
+
+#define MICON_CMD_POW_OFF	"POW_OFF"
+#define MICON_CMD_REBOOT	"REBOOT"
+
+#define MICON_RSP_ACK		"OK"
+#define MICON_RSP_NACK		"NG"
+
+#define MICON_RSP_MAX		256	/* XXX: reasonable ? */
+#define MICON_RETRY_MAX		3
+
+
+#define DEBUG
+#ifdef DEBUG
+#define TRACE(arg)	arg
+#else	/* DEBUG */
+#define TRACE(arg)	/* none */
+#endif	/* DEBUG */
+
+
+static int
+micon_v3_serial_io(char *indata, int inlen, char *outdata, int outlen)
+{
+	int fd;
+	int sys_val = 0;
+	struct termios termios;
+	struct termios termios_save;
+	char *cmdbuf = NULL;
+	int cmdbuflen;
+	char rspbuf[MICON_RSP_MAX];
+	int rsplen;
+	mm_segment_t oldfs;
+	int try;
+	int i;
+
+	oldfs = get_fs();
+	set_fs(KERNEL_DS);
+
+	fd = sys_open(MICON_DEV, O_RDWR | O_NDELAY, 0);
+	if (fd < 0) {
+		printk(KERN_ERR "Micon device(%s): open failed.(%d)\n",
+		       MICON_DEV, fd);
+		set_fs(oldfs);
+		return fd;
+	}
+
+	sys_val = sys_ioctl(fd, TCGETS, (long)&termios_save);
+	if (sys_val < 0) {
+		printk(KERN_ERR "Micon device(%s): ioctl(TCGETS) failed.(%d)\n",
+		       MICON_DEV, sys_val);
+		sys_close(fd);
+		set_fs(oldfs);
+		return sys_val;
+	}
+
+	memset(&termios, 0, sizeof(termios));
+	termios.c_cflag = MICON_BAUD_SYM | CS8 | CLOCAL | CREAD;
+	termios.c_iflag = IGNPAR;
+	sys_val = sys_ioctl(fd, TCSETS, (unsigned long)&termios);
+	if (sys_val < 0) {
+		printk(KERN_ERR "Micon device(%s): ioctl(TCSETS) failed.(%d)\n",
+		       MICON_DEV, sys_val);
+		goto out;
+	}
+
+	/* read all data before real I/O */
+	while (1) {
+		sys_val = sys_read(fd, rspbuf, sizeof(rspbuf));
+		if (sys_val == 0) {
+			TRACE(printk(KERN_DEBUG "Micon buffer cleared.\n"));
+			break;
+		}
+		else if (sys_val < 0) {
+			printk(KERN_ERR "Micon buffer clear failed.\n");
+			goto out;
+		}
+	}
+
+	cmdbuflen = 1;	/* at least 1 byte */
+	if (inlen > cmdbuflen) {
+		cmdbuflen = inlen;
+	}
+	cmdbuflen ++;	/* for string terminator '\0' */
+	cmdbuf = kmalloc(cmdbuflen, GFP_KERNEL);
+	if (cmdbuf == NULL) {
+		printk(KERN_ERR "Micon I/O buffer allocation failed.\n");
+		return -ENOMEM;
+	}
+
+	for (try = 0; try < MICON_RETRY_MAX; try ++) {
+		/* initialize */
+		memset(cmdbuf, 0, cmdbuflen);
+		snprintf(cmdbuf, cmdbuflen, "%c", MICON_INIT_MARK);
+		sys_val = sys_write(fd, cmdbuf, strlen(cmdbuf));
+		TRACE(printk(KERN_DEBUG "CPU->MICON: INIT\n"));
+		if (sys_val < 0) {
+			printk(KERN_ERR "Micon device(%s): write(init) failed.\n",
+			       MICON_DEV);
+			continue;
+		}
+		else if (sys_val != strlen(cmdbuf)) {
+			printk(KERN_ERR "Micon device(%s): write(init) failed."
+			       " expect %d bytes, but %d bytes was written\n",
+			       MICON_DEV, strlen(cmdbuf), sys_val);
+			continue;
+		}
+		msleep_interruptible(10);	/* 10ms */
+		sys_val = sys_read(fd, rspbuf, sizeof(rspbuf));
+
+		/* send command */
+		memset(cmdbuf, 0, cmdbuflen);
+		snprintf(cmdbuf, cmdbuflen, "%s", indata);
+		sys_val = sys_write(fd, cmdbuf, strlen(cmdbuf));
+		/*
+		 * XXX:
+		 *	it might need sys_write() loop in strictly sense,
+		 *	but this driver doesn't care
+		 *	because command is enough short.
+		 */
+		if (sys_val < 0) {
+			printk(KERN_ERR "Micon device(%s): write(%s) failed.(%d)\n",
+			       MICON_DEV, cmdbuf, sys_val);
+			continue;
+		}
+		else if (sys_val != strlen(cmdbuf)) {
+			printk(KERN_ERR "Micon device(%s): write(%s) failed."
+			       "expect %d bytes, but %d bytes was written\n",
+			       MICON_DEV, cmdbuf, strlen(cmdbuf), sys_val);
+			continue;
+		}
+		TRACE(printk(KERN_DEBUG "CPU->MICON: send [%s]\n", cmdbuf));
+
+		/* check echo-back */
+		rsplen = 0;
+		memset(rspbuf, 0, sizeof(rspbuf));
+		for (i = 0; i < 10/*???*/; i++) {
+			if (rsplen >= sizeof(rspbuf)) {
+				break;
+			}
+			sys_val = sys_read(fd, rspbuf + rsplen,
+					   sizeof(rspbuf) - rsplen);
+			if (sys_val == 0) {
+				break;
+			}
+			else if (sys_val < 0) {
+				if (sys_val == -EAGAIN) {
+					msleep_interruptible(1000);/* XXX */
+					continue;
+				}
+				printk(KERN_ERR "Micon device(%s): read() failed.(%d)\n",
+				       MICON_DEV, sys_val);
+				continue;
+			}
+			else {
+				rsplen += sys_val;
+			}
+			if (rsplen == strlen(cmdbuf)) {
+				break;
+			}
+			msleep_interruptible(10);
+		}
+		TRACE(printk(KERN_DEBUG
+			     "MICON->CPU: echo-back [%s], ", rspbuf));
+		if (strncmp(rspbuf, cmdbuf, rsplen) == 0) {
+			TRACE(printk(KERN_DEBUG "OK"));
+			break;
+		}
+		else {
+			TRACE(printk(KERN_DEBUG "NG"));
+		}
+	}
+	if (try >= MICON_RETRY_MAX) {
+		printk(KERN_ERR
+		       "Micon device(%s): give up to write, can't get echo-back\n",
+		       MICON_DEV);
+		goto out;
+	}
+
+	/* send delimiter */
+	memset(cmdbuf, 0, cmdbuflen);
+	snprintf(cmdbuf, cmdbuflen, "%c", MICON_DELIMITER);
+	sys_val = sys_write(fd, cmdbuf, strlen(cmdbuf));
+	if (sys_val < 0) {
+		printk(KERN_ERR
+		       "Micon device(%s): write(delimiter) failed. (%d)\n",
+		       MICON_DEV, sys_val);
+		goto out;
+	}
+	msleep_interruptible(10);
+	sys_val = sys_read(fd, rspbuf, strlen(cmdbuf));
+	if (sys_val < 0) {
+		printk(KERN_ERR
+		       "Micon device(%s): write(delimiter) failed. (%d)\n",
+		       MICON_DEV, sys_val);
+		goto out;
+	}
+	TRACE(printk(KERN_DEBUG "CPU->MICON: send delimiter\n"));
+
+	/* read response */
+	rsplen = 0;
+	memset(rspbuf, 0, sizeof(rspbuf));
+	for (i = 0; i < 10/*XXX*/; i ++) {
+		int j;
+
+		if (rsplen >= sizeof(rspbuf)) {
+			break;
+		}
+		sys_val = sys_read(fd, rspbuf + rsplen,
+				   sizeof(rspbuf) - rsplen);
+		if (sys_val == 0) {
+			break;
+		}
+		else if (sys_val < 0) {
+			if (sys_val == -EAGAIN) {
+				msleep_interruptible(10);/* XXX */
+				continue;
+			}
+			printk(KERN_ERR "Micon device(%s): read() failed.(%d)\n",
+			       MICON_DEV, sys_val);
+			continue;
+		}
+		else {
+			rsplen += sys_val;
+			for (j = 0; j < rsplen; j ++) {
+				if (rspbuf[j] == '\n') {
+					break;
+				}
+			}
+			if (rspbuf[j] == '\n') {
+				break;
+			}
+		}
+		msleep_interruptible(10);
+	}
+	TRACE(printk(KERN_DEBUG "MICON->CPU: [%s]\n", rspbuf));
+	memcpy(outdata, rspbuf, (sys_val > outlen) ? outlen : sys_val);
+
+out:
+	if (cmdbuf != NULL) {
+		kfree(cmdbuf);
+	}
+	sys_ioctl(fd, TCSETS, (long)&termios_save);
+	sys_close(fd);
+	set_fs(oldfs);
+	return sys_val;
+}
+
+
+static int
+micon_v3_send_simple_command(char *cmd, int cmdlen)
+/* expect "OK" or "NG" */
+{
+	char rspbuf[MICON_RSP_MAX];
+	int micon_ret;
+
+	memset(rspbuf, 0, sizeof(rspbuf));
+	micon_ret = micon_v3_serial_io(cmd, cmdlen, rspbuf, sizeof(rspbuf));
+	if (micon_ret < 0) {
+		return micon_ret;
+	}
+
+	if (strncmp(rspbuf, MICON_RSP_ACK, strlen(MICON_RSP_ACK)) == 0) {
+		TRACE(printk(KERN_DEBUG "Micon ACK(OK) is found\n"));
+	}
+	else if (strncmp(rspbuf, MICON_RSP_NACK, strlen(MICON_RSP_NACK)) == 0) {
+		printk(KERN_ERR "Micon NACK(NG) is found\n");
+		/* XXX: need retry ??? */
+		return -1;
+	}
+	else {
+		printk(KERN_ERR "Micon unexpected response[%s]\n", rspbuf);
+		/* XXX: need retry ??? */
+		return -1;
+	}
+
+	return 0;
+}
+
+void
+miconCntl_PowerOff(void)
+{
+	int rsp;
+
+	rsp = micon_v3_send_simple_command(MICON_CMD_POW_OFF,
+					   strlen(MICON_CMD_POW_OFF));
+	if (rsp != 0) {
+		printk(KERN_ERR "%s() failed\n", __FUNCTION__);
+	}
+
+	return;
+}
+
+void
+miconCntl_Reboot(void)
+{
+	int rsp;
+
+	rsp = micon_v3_send_simple_command(MICON_CMD_REBOOT,
+					   strlen(MICON_CMD_REBOOT));
+	if (rsp != 0) {
+		printk(KERN_ERR "%s() failed\n", __FUNCTION__);
+	}
+
+	return;
+}
diff --git a/buffalo/drivers/proc_entry.c b/buffalo/drivers/proc_entry.c
new file mode 100644
index 00000000..0ad7b2d
--- /dev/null
+++ b/buffalo/drivers/proc_entry.c
@@ -0,0 +1,38 @@
+#include <linux/string.h>
+#include "proc_entry.h"
+
+
+static struct proc_dir_entry *proc_buffalo = NULL;
+
+struct proc_dir_entry *
+get_proc_buffalo(void)
+{
+	if (proc_buffalo == NULL)
+		proc_buffalo = proc_mkdir("buffalo", NULL);
+
+	return proc_buffalo;
+}
+
+void
+make_proc_entry(struct proc_entry_data *entry)
+{
+	struct proc_dir_entry *proc_buffalo;
+	struct proc_dir_entry *pde;
+
+	proc_buffalo = get_proc_buffalo();
+	if (proc_buffalo == NULL) {
+		/* XXX */
+	}
+
+	pde = proc_create_data(entry->path, entry->mode,
+			       proc_buffalo, entry->proc_fops, entry->data);
+	if (pde == NULL) {
+		/* XXX */
+	}
+}
+
+void
+delete_proc_entry(char *path)
+{
+	remove_proc_entry(path, NULL);
+}
diff --git a/buffalo/drivers/proc_entry.h b/buffalo/drivers/proc_entry.h
new file mode 100644
index 00000000..ff4fa53e
--- /dev/null
+++ b/buffalo/drivers/proc_entry.h
@@ -0,0 +1,20 @@
+#ifndef _BUFFALO_PROC_ENTRY_H_
+#define _BUFFALO_PROC_ENTRY_H_
+
+#include <linux/version.h>
+#include <linux/proc_fs.h>
+
+
+struct proc_entry_data {
+	char			path[64];
+	umode_t			mode;
+	struct file_operations	*proc_fops;
+	void			*data;
+};
+
+struct proc_dir_entry* get_proc_buffalo(void);
+void make_proc_entry(struct proc_entry_data *entry);
+void delete_proc_entry(char *path);
+
+
+#endif	/* _BUFFALO_PROC_ENTRY_H_ */
diff --git a/buffalo/drivers/rtc_nvram.c b/buffalo/drivers/rtc_nvram.c
new file mode 100644
index 00000000..35ba102
--- /dev/null
+++ b/buffalo/drivers/rtc_nvram.c
@@ -0,0 +1,29 @@
+/*
+ *
+ */
+#include "rtc_nvram.h"
+
+void
+BuffaloRtc_UPSRecoverInit(void)
+{
+	/* XXX: TODO */
+}
+
+extern void
+BuffaloRtc_UPSRecoverEnable(int8_t TargetType)
+{
+	/* XXX: TODO */
+}
+
+extern void
+BuffaloRtc_UPSRecoverDisable(void)
+{
+	/* XXX: TODO */
+}
+
+extern int
+BuffaloRtc_UPSRecoverReadStatus(void)
+{
+	/* XXX: TODO */
+	return 0;
+}
diff --git a/buffalo/drivers/rtc_nvram.h b/buffalo/drivers/rtc_nvram.h
new file mode 100644
index 00000000..8715909
--- /dev/null
+++ b/buffalo/drivers/rtc_nvram.h
@@ -0,0 +1,16 @@
+#ifndef _RTC_NVRAM_H_
+#define _RTC_NVRAM_H_
+
+#include <linux/types.h>
+
+#define RECOVER_TARGET_UPS_APC  1
+#define RECOVER_TARGET_UPS_OMR  2
+#define RECOVER_TARGET_UPS_USB  3
+#define RECOVER_TARGET_UPS_ALL  4
+
+extern void BuffaloRtc_UPSRecoverInit(void);
+extern void BuffaloRtc_UPSRecoverEnable(int8_t TargetType);
+extern void BuffaloRtc_UPSRecoverDisable(void);
+extern int BuffaloRtc_UPSRecoverReadStatus(void);
+
+#endif	/* _RTC_NVRAM_H_ */
diff --git a/buffalo/drivers/upsdrv.c b/buffalo/drivers/upsdrv.c
new file mode 100644
index 00000000..ff76f7b
--- /dev/null
+++ b/buffalo/drivers/upsdrv.c
@@ -0,0 +1,301 @@
+/*
+ *  LinkStation/TeraStation UPS port Driver
+ *
+ *  Copyright (C)  BUFFALO INC.
+ *
+ *  This software may be used and distributed according to the terms of
+ *  the GNU General Public License (GPL), incorporated herein by reference.
+ *  Drivers based on or derived from this code fall under the GPL and must
+ *  retain the authorship, copyright and license notice.  This file is not
+ *  a complete program and may only be used when the entire operating
+ *  system is licensed under the GPL.
+ *
+ */
+#include <linux/version.h>
+#include <linux/module.h>
+#include <linux/kernel.h>
+#include <linux/proc_fs.h>
+
+#include <linux/delay.h>
+#include <linux/seq_file.h>
+#include <linux/slab.h>
+
+#include <linux/serial_reg.h>
+#include <linux/serial_core.h>
+#include <linux/serial_reg.h>
+#include "buffalocore.h"
+#include "rtc_nvram.h"
+
+
+extern void *buffalo_generic_seq_start(struct seq_file *m, loff_t *pos);
+extern void *buffalo_generic_seq_next(struct seq_file *m, void *v, loff_t *pos);
+extern void buffalo_generic_seq_stop(struct seq_file *m, void *v);
+
+
+#define bzero(p,sz) memset(p,0,sz)
+
+//#define DEBUG_UPS
+
+/* Function prototypes */
+
+
+/* variables */
+static struct proc_dir_entry *proc_buffalo_ups;
+
+
+#ifdef CONFIG_BUFFALO_SUPPORT_UPS_RECOVER
+//--------------------------------------------------------------
+static void
+BuffaloUpsRecoverInit(void)
+{
+	BuffaloRtc_UPSRecoverInit();
+	printk("BUFFALO UPS Recover Function Initialized.\n");
+
+}
+
+//--------------------------------------------------------------
+static struct {
+	int	mode;
+	char	*w_str;
+	char	*r_str;
+} buffalo_ups_mode_defs[] = {
+	{ 0,	/* default */		"off",		"off"		},
+	{ RECOVER_TARGET_UPS_ALL,	"on",		"on"		},
+};
+
+static int
+buffalo_ups_recover_show(struct seq_file *m, void *v)
+{
+	int i;
+	int stat = BuffaloRtc_UPSRecoverReadStatus();
+	int found = 0;	/* default */
+
+	for (i = 1; i < ARRAY_SIZE(buffalo_ups_mode_defs); i ++) {
+		if (buffalo_ups_mode_defs[i].mode == stat) {
+			found = i;
+			break;
+		}
+	}
+
+	seq_printf(m, "%s\n", buffalo_ups_mode_defs[found].r_str);
+
+	return 0;
+}
+
+static const
+struct seq_operations buffalo_ups_recover_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_ups_recover_show,
+};
+
+static int
+buffalo_ups_recover_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_ups_recover_op);
+}
+
+static int
+buffalo_ups_recover_write(struct file *file, const char __user *buffer,
+			  size_t count, loff_t *ppos)
+{
+	int8_t OnTarget = -1;
+	char *kbuf;
+	int i;
+
+	kbuf = kmalloc(count + 1, GFP_KERNEL);
+	if (kbuf == NULL) {
+		return -ENOMEM;
+	}
+
+	if (copy_from_user(kbuf, buffer, count)) {
+		count = -EFAULT;
+		goto out;
+	}
+
+	kbuf[count] = 0;
+
+	for (i = 0; i < ARRAY_SIZE(buffalo_ups_mode_defs); i ++) {
+		if (strncmp(kbuf, buffalo_ups_mode_defs[i].w_str,
+			    strlen(buffalo_ups_mode_defs[i].w_str)) == 0) {
+			OnTarget = buffalo_ups_mode_defs[i].mode;
+			break;
+		}
+	}
+
+	if (OnTarget > 0) {
+		BuffaloRtc_UPSRecoverEnable(OnTarget);
+	}
+	else if (OnTarget == 0) {
+		BuffaloRtc_UPSRecoverDisable();
+	}
+
+out:
+	kfree(kbuf);
+	return count;
+}
+
+static
+struct file_operations buffalo_ups_recover_fops = {
+	.open		= buffalo_ups_recover_open,
+	.read		= seq_read,
+	.write		= buffalo_ups_recover_write,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+#endif /* CONFIG_BUFFALO_SUPPORT_UPS_RECOVER */
+
+
+#ifdef CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN
+static unsigned int OmronShutdownEnable = 0;
+
+static int
+buffalo_ups_omron_shutdown_enable_show(struct seq_file *m, void *v)
+{
+	if (OmronShutdownEnable) {
+		seq_printf(m, "on\n");
+	}
+	else {
+		seq_printf(m, "off\n");
+	}
+	return 0;
+}
+
+static const
+struct seq_operations buffalo_ups_omron_shutdown_enable_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_ups_omron_shutdown_enable_show,
+};
+
+static int
+buffalo_ups_omron_shutdown_enable_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_ups_omron_shutdown_enable_op);
+}
+
+static ssize_t
+buffalo_ups_omron_shutdown_enable_write(struct file *file,
+					const char __user *buffer,
+					size_t count, loff_t *ppos)
+{
+	char *kbuf;
+
+	kbuf = kmalloc(count + 1, GFP_KERNEL);
+	if (kbuf == NULL) {
+		return -ENOMEM;
+	}
+
+	if (copy_from_user(&kbuf, buffer, count)) {
+		count = -EFAULT;
+		goto out;
+	}
+
+	kbuf[count] = '\0';
+
+	if (strncmp(kbuf, "on", 2) == 0) {
+		OmronShutdownEnable = 1;
+	}
+	else if (strncmp(kbuf, "off", 3) == 0) {
+		OmronShutdownEnable = 0;
+	}
+
+out:
+	kfree(kbuf);
+	return count;
+}
+
+static
+struct file_operations buffalo_ups_omron_shutdown_enable_fops = {
+	.open		= buffalo_ups_omron_shutdown_enable_open,
+	.read		= seq_read,
+	.write		= buffalo_ups_omron_shutdown_enable_write,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+void
+BuffaloUps_ShutdownUps(void)
+{
+	int timeout = 15;
+	int i = 0;
+
+	if (OmronShutdownEnable == 1) {
+#if 0	/* XXX: TODO */
+		/*
+		 * sireal driver is refactored in newer kernel,
+		 * we can't access uart_ports[] structure.
+		 * need to re-implement mctrl setting procedure.
+		 */
+		unsigned int mctrl = uart_ports[UPSPORT]->ops->get_mctrl(uart_ports[UPSPORT]);
+		printk("Shuttting down OMRON ups ... \n");
+
+#if defined(CONFIG_ARCH_FEROCEON_KW) || defined(CONFIG_ARCH_FEROCEON_MV78XX0)
+		mctrl &= ~TIOCM_DTR;	// ARMの場合は、TIOCM_DTRが論理反転していたため。
+#else //ARMADA_XPは設定側で反転
+		mctrl |= TIOCM_DTR;
+#endif
+		uart_ports[UPSPORT]->ops->set_mctrl(uart_ports[UPSPORT], mctrl);
+#endif	/* XXX */
+		while (timeout) {
+			for (i = 0; i < 1000; i++) {
+				udelay(1000);
+			}
+			timeout--;
+		}
+		if(timeout == 0)
+			printk("Failed?\n");
+	}
+}
+#endif	/* CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN */
+
+//--------------------------------------------------------------
+/*
+ * Initialize driver.
+ */
+int __init
+BuffaloUpsdrv_init (void)
+{
+	printk("UPSDRV (C) BUFFALO INC. V.1.10 installed.\n"); 
+	
+	proc_buffalo_ups = proc_mkdir("buffalo/ups", 0);
+
+#ifdef CONFIG_BUFFALO_SUPPORT_UPS_RECOVER
+	BuffaloUpsRecoverInit();
+	proc_create("ups_recover", S_IRUGO|S_IWUSR, proc_buffalo_ups,
+		    &buffalo_ups_recover_fops);
+#endif	/* CONFIG_BUFFALO_SUPPORT_UPS_RECOVER */
+
+#ifdef CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN
+	proc_create("omron_shutdown_enable", S_IRUGO|S_IWUSR, proc_buffalo_ups,
+		    &buffalo_ups_omron_shutdown_enable_fops);
+	printk("  OMRON contact type ups shutdown support enabled!\n");
+#endif	/* CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN */
+
+	return 0;
+}
+
+//--------------------------------------------------------------
+void
+BuffaloUpsdrv_exit(void)
+{
+	printk("UPSDRV removed.");
+
+#ifdef CONFIG_BUFFALO_SUPPORT_UPS_RECOVER
+	remove_proc_entry("ups_recover", proc_buffalo_ups);
+	proc_buffalo_ups = NULL;
+#endif	/* CONFIG_BUFFALO_SUPPORT_UPS_RECOVER */
+
+#ifdef CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN
+	remove_proc_entry("omron_shutdown_enable", proc_buffalo_ups);
+#endif	/* CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN */
+
+	proc_buffalo_ups = NULL;
+	remove_proc_entry("buffalo/ups", 0);
+}
+
+module_init(BuffaloUpsdrv_init);
+module_exit(BuffaloUpsdrv_exit);
+MODULE_LICENSE("GPL");
diff --git a/buffalo/include/buffalo/kernevnt.h b/buffalo/include/buffalo/kernevnt.h
new file mode 100644
index 00000000..547e4a8
--- /dev/null
+++ b/buffalo/include/buffalo/kernevnt.h
@@ -0,0 +1,75 @@
+#ifndef _KERNEVNT_H_
+#define _KERNEVNT_H_
+
+// variable definition.
+#define POWER_STATUS_REBOOTING                  1
+#define POWER_STATUS_REBOOTING_UBOOT_PASSED     2
+#define POWER_STATUS_NORMAL_STATE               3
+#define POWER_STATUS_HW_POWER_OFF               4
+#define POWER_STATUS_SW_POWER_OFF               5
+#define POWER_STATUS_SW_POFF_UBOOT_PASSED       6
+#define POWER_STATUS_FWUPDATING                 7
+#define POWER_STATUS_REBOOT_REACHED_HALT        8
+#define	POWER_STATUS_SW_POFF_REACHED_HALT       9
+#define POWER_STATUS_UPS_SHUTDOWN		10
+#define POWER_STATUS_UPS_SHUTDOWN_REACHED_HALT	11
+#define POWER_STATUS_WOL_READY_STATE		12
+#define POWER_STATUS_WOL_READY_UBOOT_PASSED	13
+
+// difinition for MagicKey.
+// DEF4CPU = (CONFIG_ARCH_FEROCEON_MV78XX0, CONFIG_ARCH_ARMADA_XP, other)
+
+#if defined(CONFIG_ARCH_FEROCEON_MV78XX0)
+#define DEF4CPU(x,y,z)  x
+#elif defined(CONFIG_ARCH_ARMADA_XP)
+#define DEF4CPU(x,y,z)  y
+#else
+#define DEF4CPU(x,y,z)  z
+#endif
+
+#define MagicKeyReboot                  0x18
+#define MagicKeyRebootUbootPassed       0x3a
+#define MagicKeyNormalState             0x71
+#define MagicKeyHwPoff                  0x43
+#define MagicKeySwPoff                  DEF4CPU(0x02,	0x41,	0x02)
+#define MagicKeySWPoffUbootPassed       0x5c
+#define MagicKeyFWUpdating              0x6f
+#define MagicKeyRebootReachedHalt       0x2b
+#define MagicKeySWPoffReachedHalt       0x7a
+#define MagicKeyUpsShutdown             DEF4CPU(0x45,   0x21,   0x21)
+#define MagicKeyUpsShutdownReachedHalt  DEF4CPU(0x16,   0x32,   0x32)
+#define MagicKeyWOLReadyState           DEF4CPU(0x75,   0x02,   0x75)
+#define MagicKeyWOLReadyUbootPasswd	0x70
+
+#define MagicKeyTerminator		0x00	/* use as terminator in defs,
+						 * it must not conflict
+						 * with meaningful values
+						 */
+
+/* routines are in buffalo/drivers/kernevnt.c */
+void kernevnt_LanAct(void *data);
+void kernevnt_LanAct_params(char *name, int speed, int duplex);
+void kernevnt_SwitchHubAct(const char *msg);
+#ifdef CONFIG_MD
+void kernevnt_RaidRecovery(int devno,int on, int isRecovery, int major, int minor);
+void kernevnt_RaidScan(int devno, int on);
+void kernevnt_RaidDegraded(int devno, int major, int minor);
+void kernevnt_RaidReshape(int devno, int on);
+#endif
+
+struct buffalo_cpu_status_defs {
+	unsigned int stat;
+	char *str;
+};
+
+void kernevnt_IOErr(const char *kdevname, const char *dir, unsigned long long sector, unsigned int errcnt);
+void kernevnt_FlashUpdate(int on);
+void kernevnt_DriveDead(const char *drvname);
+void kernevnt_I2cErr(void);
+void kernevnt_MiconInt(void);
+void kernevnt_EnetOverload(const char *name);
+void buffalo_kernevnt_queuein(const char *cmd);
+
+extern void (*kernevnt_LanAct_arch)(void *data);
+
+#endif
diff --git a/buffalo/include/buffalo/micon_v3.h b/buffalo/include/buffalo/micon_v3.h
new file mode 100644
index 00000000..90f3b2e
--- /dev/null
+++ b/buffalo/include/buffalo/micon_v3.h
@@ -0,0 +1,11 @@
+/*
+ *
+ */
+
+#ifndef __BUFFALO_MICON_V3_H__
+#define __BUFFALO_MICON_V3_H__
+
+extern void miconCntl_PowerOff(void);
+extern void miconCntl_Reboot(void);
+
+#endif	/* __BUFFALO_MICON_V3_H__ */
diff --git a/buffalo/scripts/debianize.sh b/buffalo/scripts/debianize.sh
new file mode 100644
index 00000000..9ada7ba
--- /dev/null
+++ b/buffalo/scripts/debianize.sh
@@ -0,0 +1,325 @@
+#!/bin/bash
+#
+export LANGUAGE=C
+export LC_ALL=C
+
+# force fixup kernel build user/host, default:"root@buffalo.jp"
+#
+: ${KBUILD_BUILD_USER:="root"}
+: ${KBUILD_BUILD_HOST:="buffalo.jp"}
+export KBUILD_BUILD_USER KBUILD_BUILD_HOST
+
+# kernel version dependent settings:
+#
+: ${KERNELVERSION:="4.4.115"}
+: ${UBUNTUCORE_NAME:="v${KERNELVERSION}"}
+: ${UBUNTUCORE_URL:="http://kernel.ubuntu.com/~kernel-ppa/mainline/${UBUNTUCORE_NAME}"}
+:
+UBUNTU_PATCHES='
+	0001-base-packaging.patch
+	0005-debian-changelog.patch
+	0006-configs-based-on-Ubuntu-4.4.0-113.136.patch
+'
+#	0002-UBUNTU-SAUCE-add-vmlinux.strip-to-BOOT_TARGETS1-on-p.patch
+#	0003-UBUNTU-SAUCE-tools-hv-lsvmbus-add-manual-page.patch
+#	0004-UBUNTU-SAUCE-no-up-disable-pie-when-gcc-has-it-enabl.patch
+: ${UBUNTU_PATCHDIR:="buffalo/ubuntu/"}
+
+# target architecutre/machine dependent settings:
+#
+: ${ARCH:="x86"}
+: ${SRCARCH:="amd64"}
+: ${MACHINE:="buffalo_ts6000"}
+: ${DTSNAMES:=""}
+: ${FLAVOUR:="generic"}
+: ${FLAVOUR_SUPPORTED:="Generic"}
+: ${GCCNAME:="gcc-4.8"}
+: ${DEFCONFIG:="buffalo/arch/${ARCH}/configs/${MACHINE}_defconfig"}
+: ${PACKAGE_ARCHIVE:="kernel_amd64_with_buffalo"}
+: ${KERNEL_DTSDIR:=""}
+: ${EXTRA_DTSDIR:=""}
+: ${UIMAGE_NAME:=""}
+: ${LOAD_ADDRESS:=""}
+: ${ENTRY_ADDRESS:=""}
+
+# mkimage command path.
+#
+: ${MKIMAGE:=dummy}
+
+
+
+fetch_ubuntu_patch () {
+	curl --fail -OL ${UBUNTUCORE_URL}/$1 >/dev/null 2>&1 && return 0
+	cp "${UBUNTU_PATCHDIR}"$1 . >/dev/null 2>&1 && return 0
+	echo "failed to fetch Ubuntu patch" >&2
+	exit 1
+}
+
+apply_ubuntu_patch () {
+	rm -rf debian debian.master
+	for file in ${UBUNTU_PATCHES}; do
+		[ -f ${file} ] || fetch_ubuntu_patch $file
+		patch -p1 < $file || exit 1
+	done
+	chmod +x debian/rules
+	chmod -R u+x debian/scripts/*
+	fakeroot debian/rules clean
+}
+
+fixup_kernel_flavour () {
+	# create debian.master/control.d/vars.${FLAVOUR}
+	#
+	sed -e "s/^arch=.*/arch=\"${SRCARCH}\"/" \
+	    -e "s/^supported=.*/supported=\"${FLAVOUR_SUPPORTED}\"/" \
+	    debian.master/control.d/vars.$1 \
+	    > debian.master/control.d/vars.$2
+
+	# create debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+	#
+	cp debian.master/config/${SRCARCH}/config.flavour.$1 \
+	   debian.master/config/${SRCARCH}/config.flavour.$2
+
+	fakeroot debian/rules clean
+}
+
+fixup_buffalo_configs () {
+	[ -d debian.master ] || apply_ubuntu_patch
+
+	# create new flavour based on 'generic', if needed.
+	#
+	[ -f debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR} ] \
+	    || fixup_kernel_flavour generic ${FLAVOUR}
+
+	# merge machine dependent configs to flavour, except for
+	# CONFIG_LOCALVERSION setting.
+	#
+	egrep -v '^CONFIG_LOCALVERSION' ${DEFCONFIG} \
+	    >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR} \
+	    || exit 1
+
+	fixup_ubuntu_configs || exit 1
+	fixup_${SRCARCH}_configs || true
+
+	for name in ${DTSNAMES}; do
+	    dts="$(basename $name .dts).dts"
+	    if [ -f "${EXTRA_DTSDIR}${dts}" ]; then
+		rm -f "${KERNEL_DTSDIR}${dts}"
+		cat "${EXTRA_DTSDIR}${dts}" > "${KERNEL_DTSDIR}${dts}" \
+		|| exit 1
+	    fi
+	done
+}
+
+# fixup configes drived from UBUNTU.
+#
+fixup_ubuntu_configs () {
+	# Subject: UBUNTU: [Config] CONFIG_ANDROID=n
+	# Author: Tim Gardner <tim.gardner@canonical.com>
+	# Date: 2013-10-07 13:54:56 (GMT)
+	# commit: b50a787fbcd6f42e9c552b201e58953049ac4428
+	# BugLink: http://bugs.launchpad.net/bugs/1235161
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+# CONFIG_ANDROID is not set
+EOF
+}
+
+fixup_amd64_configs () {
+	# To disable asking configs in 'make menuconfig', append default
+	# value to undefined configs.
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+# CONFIG_GPIO_BT8XX is not set
+# CONFIG_RTC_DRV_RX8010 is not set
+# CONFIG_I2C_ALGOPCF is not set
+# CONFIG_EXT2_FS_XATTR is not set
+EOF
+
+	# for Low Level Debugging:
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+CONFIG_DEBUG_LL=y
+CONFIG_EARLY_PRINTK=y
+CONFIG_DEBUG_ALPINE_UART0=y
+# CONFIG_DEBUG_ICEDCC is not set
+# CONFIG_DEBUG_SEMIHOSTING is not set
+# CONFIG_DEBUG_LL_UART_8250 is not set
+# CONFIG_DEBUG_LL_UART_PL01X is not set
+CONFIG_DEBUG_UART_PHYS=0xfd883000
+CONFIG_DEBUG_UART_VIRT=0xfd883000
+CONFIG_DEBUG_UART_8250_SHIFT=2
+CONFIG_DEBUG_UART_8250_WORD=y
+# CONFIG_DEBUG_UART_8250_FLOW_CONTROL is not set
+EOF
+
+	# To fixup user/kernel vm-page split layout configuration
+	# from 1/3 split (ubuntu original) to 2/2 split.
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+# CONFIG_VMSPLIT_3G is not set
+CONFIG_VMSPLIT_2G=y
+# CONFIG_VMSPLIT_1G is not set
+EOF
+}
+
+fixup_armhf_configs () {
+	# To disable asking configs in 'make menuconfig', append default
+	# value to undefined configs.
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+# CONFIG_ARM_PAGE_SIZE_64KB is not set
+CONFIG_ARM_PAGE_SIZE_32KB=y
+# CONFIG_ARM_PAGE_SIZE_4KB is not set
+# CONFIG_FUNC_REORDER is not set
+CONFIG_MTD_CFI_NOSWAP=y
+# CONFIG_MTD_CFI_BE_BYTE_SWAP is not set
+# CONFIG_MTD_CFI_LE_BYTE_SWAP is not set
+# CONFIG_MTD_CFI_GEOMETRY is not set
+# CONFIG_MTD_OTP is not set
+CONFIG_AL_ETH_ALLOC_FRAG=y
+# CONFIG_AL_ETH_ALLOC_PAGE is not set
+# CONFIG_AL_ETH_ALLOC_SKB is not set
+# CONFIG_AL_TRACE is not set
+# CONFIG_I2C_ALGOPCF is not set
+# CONFIG_GPIO_AL_SGPO is not set
+# CONFIG_AL_TDM_TEST_MODULE is not set
+# CONFIG_EXT2_FS_XATTR is not set
+CONFIG_EXT3_DEFAULTS_TO_ORDERED=y
+CONFIG_EXT3_FS_XATTR=y
+# CONFIG_EXT3_FS_POSIX_ACL is not set
+# CONFIG_EXT3_FS_SECURITY is not set
+# CONFIG_JBD_DEBUG is not set
+# CONFIG_DEBUG_SLAB is not set
+# CONFIG_CRYPTO_FIPS is not set
+EOF
+	# disable non-Alpine ARM platforms:
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+# CONFIG_ARCH_VIRT is not set
+# CONFIG_ARCH_MVEBU is not set
+# CONFIG_ARCH_AXXIA is not set
+# CONFIG_ARCH_BERLIN is not set
+# CONFIG_ARCH_HIGHBANK is not set
+# CONFIG_ARCH_HISI is not set
+# CONFIG_ARCH_MESON is not set
+# CONFIG_ARCH_MXC is not set
+# CONFIG_ARCH_MEDIATEK is not set
+# CONFIG_ARCH_OMAP3 is not set
+# CONFIG_ARCH_OMAP4 is not set
+# CONFIG_SOC_AM33XX is not set
+# CONFIG_SOC_DRA7XX is not set
+# CONFIG_ARCH_QCOM is not set
+# CONFIG_ARCH_EXYNOS is not set
+# CONFIG_ARCH_SHMOBILE_MULTI is not set
+# CONFIG_ARCH_TEGRA is not set
+# CONFIG_ARCH_VEXPRESS is not set
+# CONFIG_ARM_THUMBEE is not set
+# CONFIG_ARM_ERRATA_720789 is not set
+# CONFIG_ARM_ERRATA_798181 is not set
+EOF
+
+	# Avoiding compile failure with Ubuntu core configurations,
+	# * CONFIG_DRM:
+	#	compile failure in "drivers/gpu/drm".
+	# * CONFIG_F2FS_FS
+	#	ERROR: "__aeabi_uldivmod" undefined! in modules.
+	# * CONFIG_FB
+	#	ERROR: "__aeabi_uldivmod" undefined! in modules.
+	# * CONFIG_STAGING
+	#	ERROR: "__aeabi_uldivmod" undefined! in modules.
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+# CONFIG_DRM is not set
+# CONFIG_F2FS_FS is not set
+# CONFIG_FB is not set
+# CONFIG_STAGING is not set
+EOF
+
+	# for Low Level Debugging:
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+CONFIG_DEBUG_LL=y
+CONFIG_EARLY_PRINTK=y
+CONFIG_DEBUG_ALPINE_UART0=y
+# CONFIG_DEBUG_ICEDCC is not set
+# CONFIG_DEBUG_SEMIHOSTING is not set
+# CONFIG_DEBUG_LL_UART_8250 is not set
+# CONFIG_DEBUG_LL_UART_PL01X is not set
+CONFIG_DEBUG_UART_PHYS=0xfd883000
+CONFIG_DEBUG_UART_VIRT=0xfd883000
+CONFIG_DEBUG_UART_8250_SHIFT=2
+CONFIG_DEBUG_UART_8250_WORD=y
+# CONFIG_DEBUG_UART_8250_FLOW_CONTROL is not set
+EOF
+
+	# To fixup user/kernel vm-page split layout configuration
+	# from 1/3 split (ubuntu original) to 2/2 split.
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+# CONFIG_VMSPLIT_3G is not set
+CONFIG_VMSPLIT_2G=y
+# CONFIG_VMSPLIT_1G is not set
+EOF
+}
+
+
+fixup_buffalo_rules () {
+	[ -d debian.master ] || apply_ubuntu_patch
+
+	sed -e "/^flavours/s/=.*/= ${FLAVOUR}/" \
+	    -e "/^gcc/s/=.*/= ${GCCNAME}/" \
+	    -i debian.master/rules.d/${SRCARCH}.mk
+	if ! egrep -q "^gcc\s+=.*" debian.master/rules.d/${SRCARCH}.mk; then
+		echo "gcc		= ${GCCNAME}" >> debian.master/rules.d/${SRCARCH}.mk
+	fi
+	for name in ${DTSNAMES}; do
+		dts="$(basename $name .dts)"
+		/bin/echo -e "dtb_files_${FLAVOUR}\t+= ${dts}.dtb" \
+		>> debian.master/rules.d/${SRCARCH}.mk
+	done
+}
+
+build_buffalo_packages () {
+	fakeroot debian/rules do_tools=0 no_dumpfile=1 binary-headers
+	fakeroot debian/rules clean
+	dpkg-architecture -a${SRCARCH} -c debian/rules \
+		do_extras_package=false do_tools=0 no_dumpfile=1 build-arch
+	dpkg-architecture -a${SRCARCH} -c fakeroot debian/rules \
+		do_extras_package=false do_tools=0 no_dumpfile=1 binary-debs
+}
+
+build_uimage_packeges () {
+	# ensure mkimage command was installed.
+	[ -x ${MKIMAGE} ] || return 1;
+
+	tmpdir="debian/tmpwork$$"
+	trap 'rm -rf ${tmpdir}' EXIT TERM HUP INT QUIT
+	for pkg in $(echo ../linux-image-*.deb); do
+		[ -f "$pkg" ] || continue
+		name=$(basename ${pkg} .deb)
+		image=linux-kernel-${name##linux-image-}.img
+		mkdir -p ${tmpdir}
+		dpkg -x ${pkg} ${tmpdir}
+		for file in $(echo ${tmpdir}/boot/vmlinu*); do
+			[ -f "$file" ] || continue
+			${MKIMAGE} -A ${ARCH} -O linux -T kernel -C none \
+			    -a ${LOAD_ADDRESS} -e ${ENTRY_ADDRESS} \
+			    -n ${UIMAGE_NAME} \
+			    -d ${file} ../${image}
+		done
+		rm -rf ${tmpdir}
+	done
+	rm -rf ${tmpdir}
+	trap '' EXIT TERM HUP INT QUIT
+}
+
+fixup_buffalo_configs
+fixup_buffalo_rules
+build_buffalo_packages
+build_uimage_packeges
+
+if [ -x ${MKIMAGE} ]; then
+	( cd ..; tar cvf ${PACKAGE_ARCHIVE}.tar linux-*.deb linux-*.img )
+else
+	( cd ..; tar cvf ${PACKAGE_ARCHIVE}.tar linux-*.deb )
+fi
diff --git a/buffalo/scripts/mkbuilddate_h b/buffalo/scripts/mkbuilddate_h
new file mode 100644
index 00000000..c046309
--- /dev/null
+++ b/buffalo/scripts/mkbuilddate_h
@@ -0,0 +1,21 @@
+#!/bin/sh
+
+TARGET=$1
+
+vecho() { [ "${quiet}" = "silent_" ] || echo "$@" ; }
+
+# Do not expand names
+set -f
+
+# Fix the language to get consistent output
+LC_ALL=C
+export LC_ALL
+
+vecho "  UPD     $TARGET"
+
+( echo /\* This file is auto generated \*/
+
+  date "+#define BUFFALO_BUILD_DATE \"%Y/%m/%d\"%n#define BUFFALO_BUILD_TIME \"%T\""
+
+) > $TARGET
+
diff --git a/buffalo/ubuntu/0001-base-packaging.patch b/buffalo/ubuntu/0001-base-packaging.patch
new file mode 100644
index 00000000..2a7f978c
--- /dev/null
+++ b/buffalo/ubuntu/0001-base-packaging.patch
@@ -0,0 +1,343349 @@
+From 540877d0784ad4539ed47e5b455f1d304bf0ab30 Mon Sep 17 00:00:00 2001
+From: Kernel Builder <kernel@gloin.kernel>
+Date: Sat, 3 Feb 2018 12:31:04 -0500
+Subject: [PATCH 1/6] base packaging
+
+---
+ debian.master/NOTES                                |     4 +
+ debian.master/abi/4.4.0-111.134/abiname            |     1 +
+ debian.master/abi/4.4.0-111.134/amd64/generic      | 18909 ++++++++++++++
+ .../abi/4.4.0-111.134/amd64/generic.compiler       |     1 +
+ .../abi/4.4.0-111.134/amd64/generic.modules        |  4620 ++++
+ debian.master/abi/4.4.0-111.134/amd64/lowlatency   | 18897 ++++++++++++++
+ .../abi/4.4.0-111.134/amd64/lowlatency.compiler    |     1 +
+ .../abi/4.4.0-111.134/amd64/lowlatency.modules     |  4616 ++++
+ debian.master/abi/4.4.0-111.134/arm64/generic      | 17653 +++++++++++++
+ .../abi/4.4.0-111.134/arm64/generic.compiler       |     1 +
+ .../abi/4.4.0-111.134/arm64/generic.modules        |  4393 ++++
+ debian.master/abi/4.4.0-111.134/armhf/generic      | 17621 +++++++++++++
+ debian.master/abi/4.4.0-111.134/armhf/generic-lpae | 17641 +++++++++++++
+ .../abi/4.4.0-111.134/armhf/generic-lpae.compiler  |     1 +
+ .../abi/4.4.0-111.134/armhf/generic-lpae.modules   |  4539 ++++
+ .../abi/4.4.0-111.134/armhf/generic.compiler       |     1 +
+ .../abi/4.4.0-111.134/armhf/generic.modules        |  4631 ++++
+ debian.master/abi/4.4.0-111.134/fwinfo             |   998 +
+ debian.master/abi/4.4.0-111.134/i386/generic       | 18869 ++++++++++++++
+ .../abi/4.4.0-111.134/i386/generic.compiler        |     1 +
+ .../abi/4.4.0-111.134/i386/generic.modules         |  4757 ++++
+ debian.master/abi/4.4.0-111.134/i386/lowlatency    | 18882 ++++++++++++++
+ .../abi/4.4.0-111.134/i386/lowlatency.compiler     |     1 +
+ .../abi/4.4.0-111.134/i386/lowlatency.modules      |  4756 ++++
+ .../abi/4.4.0-111.134/powerpc/powerpc-e500mc       | 17307 +++++++++++++
+ .../4.4.0-111.134/powerpc/powerpc-e500mc.compiler  |     1 +
+ .../4.4.0-111.134/powerpc/powerpc-e500mc.modules   |  4333 ++++
+ .../abi/4.4.0-111.134/powerpc/powerpc-smp          | 17117 +++++++++++++
+ .../abi/4.4.0-111.134/powerpc/powerpc-smp.compiler |     1 +
+ .../abi/4.4.0-111.134/powerpc/powerpc-smp.modules  |  4318 ++++
+ .../abi/4.4.0-111.134/powerpc/powerpc64-emb        | 17241 +++++++++++++
+ .../4.4.0-111.134/powerpc/powerpc64-emb.compiler   |     1 +
+ .../4.4.0-111.134/powerpc/powerpc64-emb.modules    |  4309 ++++
+ .../abi/4.4.0-111.134/powerpc/powerpc64-smp        | 17815 +++++++++++++
+ .../4.4.0-111.134/powerpc/powerpc64-smp.compiler   |     1 +
+ .../4.4.0-111.134/powerpc/powerpc64-smp.modules    |  4368 ++++
+ debian.master/abi/4.4.0-111.134/ppc64el/generic    | 17418 +++++++++++++
+ .../abi/4.4.0-111.134/ppc64el/generic.compiler     |     1 +
+ .../abi/4.4.0-111.134/ppc64el/generic.modules      |  4256 ++++
+ debian.master/abi/4.4.0-111.134/s390x/generic      |  9001 +++++++
+ .../abi/4.4.0-111.134/s390x/generic.compiler       |     1 +
+ .../abi/4.4.0-111.134/s390x/generic.modules        |   846 +
+ debian.master/abi/perm-blacklist                   |     0
+ debian.master/changelog                            | 25085 +++++++++++++++++++
+ debian.master/changelog.historical                 |  4171 +++
+ debian.master/config/amd64/config.common.amd64     |   476 +
+ debian.master/config/amd64/config.flavour.generic  |    10 +
+ .../config/amd64/config.flavour.lowlatency         |    10 +
+ debian.master/config/annotations                   | 10303 ++++++++
+ debian.master/config/arm64/config.common.arm64     |   476 +
+ debian.master/config/arm64/config.flavour.generic  |     3 +
+ debian.master/config/armhf/config.common.armhf     |   461 +
+ debian.master/config/armhf/config.flavour.generic  |    25 +
+ .../config/armhf/config.flavour.generic-lpae       |    25 +
+ debian.master/config/config.common.ports           |     3 +
+ debian.master/config/config.common.ubuntu          |  9121 +++++++
+ debian.master/config/i386/config.common.i386       |   473 +
+ debian.master/config/i386/config.flavour.generic   |     9 +
+ .../config/i386/config.flavour.lowlatency          |     9 +
+ debian.master/config/powerpc/config.common.powerpc |   469 +
+ .../config/powerpc/config.flavour.powerpc-e500mc   |    59 +
+ .../config/powerpc/config.flavour.powerpc-smp      |    60 +
+ .../config/powerpc/config.flavour.powerpc64-emb    |    63 +
+ .../config/powerpc/config.flavour.powerpc64-smp    |    63 +
+ debian.master/config/ppc64el/config.common.ppc64el |   520 +
+ .../config/ppc64el/config.flavour.generic          |     3 +
+ debian.master/config/s390x/config.common.s390x     |   389 +
+ debian.master/config/s390x/config.flavour.generic  |     3 +
+ debian.master/config/x32/config.common.x32         |     1 +
+ debian.master/config/x32/config.flavour.generic    |     1 +
+ debian.master/control.d/flavour-control.stub       |   134 +
+ debian.master/control.d/generic.inclusion-list     |   237 +
+ debian.master/control.d/vars.generic               |     6 +
+ debian.master/control.d/vars.generic-lpae          |     6 +
+ debian.master/control.d/vars.lowlatency            |     6 +
+ debian.master/control.d/vars.powerpc-e500mc        |     6 +
+ debian.master/control.d/vars.powerpc-smp           |     6 +
+ debian.master/control.d/vars.powerpc64-emb         |     6 +
+ debian.master/control.d/vars.powerpc64-smp         |     6 +
+ debian.master/control.stub.in                      |   179 +
+ debian.master/copyright                            |    60 +
+ debian.master/d-i/exclude-firmware.armhf-generic   |     2 +
+ .../d-i/exclude-firmware.armhf-generic-lpae        |     2 +
+ debian.master/d-i/exclude-modules.amd64-virtual    |    14 +
+ debian.master/d-i/exclude-modules.arm64-generic    |     9 +
+ debian.master/d-i/exclude-modules.armhf-generic    |    10 +
+ .../d-i/exclude-modules.armhf-generic-lpae         |    10 +
+ debian.master/d-i/exclude-modules.i386-virtual     |    14 +
+ debian.master/d-i/exclude-modules.powerpc          |     7 +
+ debian.master/d-i/exclude-modules.ppc64el-generic  |    11 +
+ debian.master/d-i/exclude-modules.s390x            |    20 +
+ debian.master/d-i/firmware/README.txt              |     4 +
+ debian.master/d-i/firmware/nic-modules             |    14 +
+ debian.master/d-i/firmware/scsi-modules            |     3 +
+ debian.master/d-i/kernel-versions.in               |    19 +
+ debian.master/d-i/modules-powerpc/block-modules    |    31 +
+ debian.master/d-i/modules-powerpc/message-modules  |     7 +
+ debian.master/d-i/modules-powerpc/nic-modules      |   152 +
+ debian.master/d-i/modules-powerpc/scsi-modules     |   118 +
+ .../d-i/modules-powerpc/storage-core-modules       |    13 +
+ debian.master/d-i/modules-s390x/dasd-extra-modules |     1 +
+ debian.master/d-i/modules-s390x/dasd-modules       |     3 +
+ debian.master/d-i/modules/block-modules            |    42 +
+ debian.master/d-i/modules/crypto-modules           |    70 +
+ debian.master/d-i/modules/fat-modules              |     7 +
+ debian.master/d-i/modules/fb-modules               |     3 +
+ debian.master/d-i/modules/firewire-core-modules    |     4 +
+ debian.master/d-i/modules/floppy-modules           |     1 +
+ debian.master/d-i/modules/fs-core-modules          |     5 +
+ debian.master/d-i/modules/fs-secondary-modules     |     5 +
+ debian.master/d-i/modules/input-modules            |    71 +
+ debian.master/d-i/modules/ipmi-modules             |     5 +
+ debian.master/d-i/modules/irda-modules             |    30 +
+ debian.master/d-i/modules/kernel-image             |    30 +
+ debian.master/d-i/modules/md-modules               |    16 +
+ debian.master/d-i/modules/message-modules          |     9 +
+ debian.master/d-i/modules/mouse-modules            |     2 +
+ debian.master/d-i/modules/multipath-modules        |     4 +
+ debian.master/d-i/modules/nfs-modules              |     6 +
+ debian.master/d-i/modules/nic-modules              |   196 +
+ debian.master/d-i/modules/nic-pcmcia-modules       |    19 +
+ debian.master/d-i/modules/nic-shared-modules       |    26 +
+ debian.master/d-i/modules/nic-usb-modules          |    32 +
+ debian.master/d-i/modules/parport-modules          |     2 +
+ debian.master/d-i/modules/pata-modules             |    47 +
+ debian.master/d-i/modules/pcmcia-modules           |     8 +
+ debian.master/d-i/modules/pcmcia-storage-modules   |     6 +
+ debian.master/d-i/modules/plip-modules             |     1 +
+ debian.master/d-i/modules/ppp-modules              |     6 +
+ debian.master/d-i/modules/sata-modules             |    18 +
+ debian.master/d-i/modules/scsi-modules             |   131 +
+ debian.master/d-i/modules/serial-modules           |     4 +
+ debian.master/d-i/modules/speakup-modules          |    16 +
+ debian.master/d-i/modules/storage-core-modules     |    10 +
+ debian.master/d-i/modules/usb-modules              |    14 +
+ debian.master/d-i/modules/virtio-modules           |    11 +
+ debian.master/d-i/modules/vlan-modules             |     3 +
+ debian.master/d-i/package-list                     |   207 +
+ debian.master/etc/getabis                          |    20 +
+ debian.master/etc/kernelconfig                     |     7 +
+ debian.master/info/OVERRIDES                       |   153 +
+ debian.master/info/REBASE                          |    47 +
+ debian.master/info/RECONCILE                       |   506 +
+ debian.master/modprobe.d/common.conf               |     3 +
+ debian.master/reconstruct                          |     2 +
+ debian.master/rules.d/amd64.mk                     |    20 +
+ debian.master/rules.d/arm64.mk                     |    19 +
+ debian.master/rules.d/armhf.mk                     |    17 +
+ debian.master/rules.d/i386.mk                      |    17 +
+ debian.master/rules.d/powerpc.mk                   |    39 +
+ debian.master/rules.d/ppc64el.mk                   |    19 +
+ debian.master/rules.d/s390x.mk                     |    19 +
+ debian.master/rules.d/x32.mk                       |    14 +
+ debian/cloud-tools/hv_get_dhcp_info                |    55 +
+ debian/cloud-tools/hv_get_dns_info                 |    13 +
+ debian/cloud-tools/hv_set_ifconfig                 |   288 +
+ debian/commit-templates/bumpabi                    |     3 +
+ debian/commit-templates/config-updates             |    15 +
+ debian/commit-templates/external-driver            |    20 +
+ debian/commit-templates/missing-modules            |     3 +
+ debian/commit-templates/newrelease                 |     3 +
+ debian/commit-templates/sauce-patch                |    40 +
+ debian/commit-templates/upstream-patch             |    27 +
+ debian/compat                                      |     1 +
+ debian/control-scripts/extra-post                  |    14 +
+ debian/control-scripts/headers-postinst            |   126 +
+ debian/control-scripts/postinst                    |  1137 +
+ debian/control-scripts/postrm                      |   363 +
+ debian/control-scripts/preinst                     |   317 +
+ debian/control-scripts/prerm                       |   313 +
+ debian/debian.env                                  |     1 +
+ debian/docs/README.inclusion-list                  |    51 +
+ debian/gbp.conf                                    |     2 +
+ ...inux-cloud-tools-common.hv-fcopy-daemon.service |    12 +
+ ...inux-cloud-tools-common.hv-fcopy-daemon.upstart |    22 +
+ .../linux-cloud-tools-common.hv-kvp-daemon.service |    12 +
+ .../linux-cloud-tools-common.hv-kvp-daemon.upstart |    22 +
+ .../linux-cloud-tools-common.hv-vss-daemon.service |    12 +
+ .../linux-cloud-tools-common.hv-vss-daemon.upstart |    22 +
+ debian/rules                                       |   291 +
+ debian/rules.d/0-common-vars.mk                    |   247 +
+ debian/rules.d/1-maintainer.mk                     |   135 +
+ debian/rules.d/2-binary-arch.mk                    |   734 +
+ debian/rules.d/3-binary-indep.mk                   |   185 +
+ debian/rules.d/4-checks.mk                         |    27 +
+ debian/rules.d/5-udebs.mk                          |    74 +
+ debian/scripts/abi-check                           |     2 +
+ debian/scripts/config-check                        |     2 +
+ debian/scripts/control-create                      |    25 +
+ debian/scripts/link-headers                        |    42 +
+ debian/scripts/misc/find-obsolete-firmware         |    91 +
+ debian/scripts/misc/fw-to-ihex.sh                  |    18 +
+ debian/scripts/misc/gen-auto-reconstruct           |    72 +
+ debian/scripts/misc/get-firmware                   |    62 +
+ debian/scripts/misc/getabis                        |   137 +
+ debian/scripts/misc/git-ubuntu-log                 |   139 +
+ debian/scripts/misc/insert-changes.pl              |    36 +
+ debian/scripts/misc/insert-mainline-changes        |    42 +
+ debian/scripts/misc/insert-ubuntu-changes          |    80 +
+ debian/scripts/misc/kernelconfig                   |   172 +
+ debian/scripts/misc/retag                          |    34 +
+ debian/scripts/misc/splitconfig.pl                 |   107 +
+ debian/scripts/misc/update-aufs.sh                 |    50 +
+ debian/scripts/misc/update-zfs.sh                  |    33 +
+ debian/scripts/module-check                        |     2 +
+ debian/scripts/module-inclusion                    |   104 +
+ debian/scripts/sub-flavour                         |    69 +
+ debian/snapcraft.mk                                |    11 +
+ debian/source/format                               |     1 +
+ debian/source/options                              |    14 +
+ debian/stamps/keep-dir                             |     1 +
+ debian/tests-build/README                          |    21 +
+ debian/tests-build/check-aliases                   |    24 +
+ debian/tests/control                               |     7 +
+ debian/tests/rebuild                               |    20 +
+ debian/tests/ubuntu-regression-suite               |    19 +
+ debian/tools/generic                               |    60 +
+ debian/zfs-modules.ignore                          |     8 +
+ 218 files changed, 341597 insertions(+)
+ create mode 100644 debian.master/NOTES
+ create mode 100644 debian.master/abi/4.4.0-111.134/abiname
+ create mode 100644 debian.master/abi/4.4.0-111.134/amd64/generic
+ create mode 100644 debian.master/abi/4.4.0-111.134/amd64/generic.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/amd64/generic.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/amd64/lowlatency
+ create mode 100644 debian.master/abi/4.4.0-111.134/amd64/lowlatency.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/amd64/lowlatency.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/arm64/generic
+ create mode 100644 debian.master/abi/4.4.0-111.134/arm64/generic.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/arm64/generic.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/armhf/generic
+ create mode 100644 debian.master/abi/4.4.0-111.134/armhf/generic-lpae
+ create mode 100644 debian.master/abi/4.4.0-111.134/armhf/generic-lpae.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/armhf/generic-lpae.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/armhf/generic.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/armhf/generic.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/fwinfo
+ create mode 100644 debian.master/abi/4.4.0-111.134/i386/generic
+ create mode 100644 debian.master/abi/4.4.0-111.134/i386/generic.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/i386/generic.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/i386/lowlatency
+ create mode 100644 debian.master/abi/4.4.0-111.134/i386/lowlatency.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/i386/lowlatency.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/ppc64el/generic
+ create mode 100644 debian.master/abi/4.4.0-111.134/ppc64el/generic.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/ppc64el/generic.modules
+ create mode 100644 debian.master/abi/4.4.0-111.134/s390x/generic
+ create mode 100644 debian.master/abi/4.4.0-111.134/s390x/generic.compiler
+ create mode 100644 debian.master/abi/4.4.0-111.134/s390x/generic.modules
+ create mode 100644 debian.master/abi/perm-blacklist
+ create mode 100644 debian.master/changelog
+ create mode 100644 debian.master/changelog.historical
+ create mode 100644 debian.master/config/amd64/config.common.amd64
+ create mode 100644 debian.master/config/amd64/config.flavour.generic
+ create mode 100644 debian.master/config/amd64/config.flavour.lowlatency
+ create mode 100644 debian.master/config/annotations
+ create mode 100644 debian.master/config/arm64/config.common.arm64
+ create mode 100644 debian.master/config/arm64/config.flavour.generic
+ create mode 100644 debian.master/config/armhf/config.common.armhf
+ create mode 100644 debian.master/config/armhf/config.flavour.generic
+ create mode 100644 debian.master/config/armhf/config.flavour.generic-lpae
+ create mode 100644 debian.master/config/config.common.ports
+ create mode 100644 debian.master/config/config.common.ubuntu
+ create mode 100644 debian.master/config/i386/config.common.i386
+ create mode 100644 debian.master/config/i386/config.flavour.generic
+ create mode 100644 debian.master/config/i386/config.flavour.lowlatency
+ create mode 100644 debian.master/config/powerpc/config.common.powerpc
+ create mode 100644 debian.master/config/powerpc/config.flavour.powerpc-e500mc
+ create mode 100644 debian.master/config/powerpc/config.flavour.powerpc-smp
+ create mode 100644 debian.master/config/powerpc/config.flavour.powerpc64-emb
+ create mode 100644 debian.master/config/powerpc/config.flavour.powerpc64-smp
+ create mode 100644 debian.master/config/ppc64el/config.common.ppc64el
+ create mode 100644 debian.master/config/ppc64el/config.flavour.generic
+ create mode 100644 debian.master/config/s390x/config.common.s390x
+ create mode 100644 debian.master/config/s390x/config.flavour.generic
+ create mode 100644 debian.master/config/x32/config.common.x32
+ create mode 100644 debian.master/config/x32/config.flavour.generic
+ create mode 100644 debian.master/control.d/flavour-control.stub
+ create mode 100644 debian.master/control.d/generic.inclusion-list
+ create mode 100644 debian.master/control.d/vars.generic
+ create mode 100644 debian.master/control.d/vars.generic-lpae
+ create mode 100644 debian.master/control.d/vars.lowlatency
+ create mode 100644 debian.master/control.d/vars.powerpc-e500mc
+ create mode 100644 debian.master/control.d/vars.powerpc-smp
+ create mode 100644 debian.master/control.d/vars.powerpc64-emb
+ create mode 100644 debian.master/control.d/vars.powerpc64-smp
+ create mode 100644 debian.master/control.stub.in
+ create mode 100644 debian.master/copyright
+ create mode 100644 debian.master/d-i/exclude-firmware.armhf-generic
+ create mode 100644 debian.master/d-i/exclude-firmware.armhf-generic-lpae
+ create mode 100644 debian.master/d-i/exclude-modules.amd64-virtual
+ create mode 100644 debian.master/d-i/exclude-modules.arm64-generic
+ create mode 100644 debian.master/d-i/exclude-modules.armhf-generic
+ create mode 100644 debian.master/d-i/exclude-modules.armhf-generic-lpae
+ create mode 100644 debian.master/d-i/exclude-modules.i386-virtual
+ create mode 100644 debian.master/d-i/exclude-modules.powerpc
+ create mode 100644 debian.master/d-i/exclude-modules.ppc64el-generic
+ create mode 100644 debian.master/d-i/exclude-modules.s390x
+ create mode 100644 debian.master/d-i/firmware/README.txt
+ create mode 100644 debian.master/d-i/firmware/nic-modules
+ create mode 100644 debian.master/d-i/firmware/scsi-modules
+ create mode 100644 debian.master/d-i/kernel-versions.in
+ create mode 100644 debian.master/d-i/modules-powerpc/block-modules
+ create mode 100644 debian.master/d-i/modules-powerpc/message-modules
+ create mode 100644 debian.master/d-i/modules-powerpc/nic-modules
+ create mode 100644 debian.master/d-i/modules-powerpc/scsi-modules
+ create mode 100644 debian.master/d-i/modules-powerpc/storage-core-modules
+ create mode 100644 debian.master/d-i/modules-s390x/dasd-extra-modules
+ create mode 100644 debian.master/d-i/modules-s390x/dasd-modules
+ create mode 100644 debian.master/d-i/modules/block-modules
+ create mode 100644 debian.master/d-i/modules/crypto-modules
+ create mode 100644 debian.master/d-i/modules/fat-modules
+ create mode 100644 debian.master/d-i/modules/fb-modules
+ create mode 100644 debian.master/d-i/modules/firewire-core-modules
+ create mode 100644 debian.master/d-i/modules/floppy-modules
+ create mode 100644 debian.master/d-i/modules/fs-core-modules
+ create mode 100644 debian.master/d-i/modules/fs-secondary-modules
+ create mode 100644 debian.master/d-i/modules/input-modules
+ create mode 100644 debian.master/d-i/modules/ipmi-modules
+ create mode 100644 debian.master/d-i/modules/irda-modules
+ create mode 100644 debian.master/d-i/modules/kernel-image
+ create mode 100644 debian.master/d-i/modules/md-modules
+ create mode 100644 debian.master/d-i/modules/message-modules
+ create mode 100644 debian.master/d-i/modules/mouse-modules
+ create mode 100644 debian.master/d-i/modules/multipath-modules
+ create mode 100644 debian.master/d-i/modules/nfs-modules
+ create mode 100644 debian.master/d-i/modules/nic-modules
+ create mode 100644 debian.master/d-i/modules/nic-pcmcia-modules
+ create mode 100644 debian.master/d-i/modules/nic-shared-modules
+ create mode 100644 debian.master/d-i/modules/nic-usb-modules
+ create mode 100644 debian.master/d-i/modules/parport-modules
+ create mode 100644 debian.master/d-i/modules/pata-modules
+ create mode 100644 debian.master/d-i/modules/pcmcia-modules
+ create mode 100644 debian.master/d-i/modules/pcmcia-storage-modules
+ create mode 100644 debian.master/d-i/modules/plip-modules
+ create mode 100644 debian.master/d-i/modules/ppp-modules
+ create mode 100644 debian.master/d-i/modules/sata-modules
+ create mode 100644 debian.master/d-i/modules/scsi-modules
+ create mode 100644 debian.master/d-i/modules/serial-modules
+ create mode 100644 debian.master/d-i/modules/speakup-modules
+ create mode 100644 debian.master/d-i/modules/storage-core-modules
+ create mode 100644 debian.master/d-i/modules/usb-modules
+ create mode 100644 debian.master/d-i/modules/virtio-modules
+ create mode 100644 debian.master/d-i/modules/vlan-modules
+ create mode 100644 debian.master/d-i/package-list
+ create mode 100644 debian.master/etc/getabis
+ create mode 100644 debian.master/etc/kernelconfig
+ create mode 100644 debian.master/info/OVERRIDES
+ create mode 100644 debian.master/info/REBASE
+ create mode 100644 debian.master/info/RECONCILE
+ create mode 100644 debian.master/modprobe.d/common.conf
+ create mode 100755 debian.master/reconstruct
+ create mode 100644 debian.master/rules.d/amd64.mk
+ create mode 100644 debian.master/rules.d/arm64.mk
+ create mode 100644 debian.master/rules.d/armhf.mk
+ create mode 100644 debian.master/rules.d/i386.mk
+ create mode 100644 debian.master/rules.d/powerpc.mk
+ create mode 100644 debian.master/rules.d/ppc64el.mk
+ create mode 100644 debian.master/rules.d/s390x.mk
+ create mode 100644 debian.master/rules.d/x32.mk
+ create mode 100755 debian/cloud-tools/hv_get_dhcp_info
+ create mode 100755 debian/cloud-tools/hv_get_dns_info
+ create mode 100755 debian/cloud-tools/hv_set_ifconfig
+ create mode 100644 debian/commit-templates/bumpabi
+ create mode 100644 debian/commit-templates/config-updates
+ create mode 100644 debian/commit-templates/external-driver
+ create mode 100644 debian/commit-templates/missing-modules
+ create mode 100644 debian/commit-templates/newrelease
+ create mode 100644 debian/commit-templates/sauce-patch
+ create mode 100644 debian/commit-templates/upstream-patch
+ create mode 100644 debian/compat
+ create mode 100644 debian/control-scripts/extra-post
+ create mode 100644 debian/control-scripts/headers-postinst
+ create mode 100644 debian/control-scripts/postinst
+ create mode 100644 debian/control-scripts/postrm
+ create mode 100644 debian/control-scripts/preinst
+ create mode 100644 debian/control-scripts/prerm
+ create mode 100644 debian/debian.env
+ create mode 100644 debian/docs/README.inclusion-list
+ create mode 100644 debian/gbp.conf
+ create mode 100644 debian/linux-cloud-tools-common.hv-fcopy-daemon.service
+ create mode 100644 debian/linux-cloud-tools-common.hv-fcopy-daemon.upstart
+ create mode 100644 debian/linux-cloud-tools-common.hv-kvp-daemon.service
+ create mode 100644 debian/linux-cloud-tools-common.hv-kvp-daemon.upstart
+ create mode 100644 debian/linux-cloud-tools-common.hv-vss-daemon.service
+ create mode 100644 debian/linux-cloud-tools-common.hv-vss-daemon.upstart
+ create mode 100755 debian/rules
+ create mode 100644 debian/rules.d/0-common-vars.mk
+ create mode 100644 debian/rules.d/1-maintainer.mk
+ create mode 100644 debian/rules.d/2-binary-arch.mk
+ create mode 100644 debian/rules.d/3-binary-indep.mk
+ create mode 100644 debian/rules.d/4-checks.mk
+ create mode 100644 debian/rules.d/5-udebs.mk
+ create mode 100755 debian/scripts/abi-check
+ create mode 100755 debian/scripts/config-check
+ create mode 100755 debian/scripts/control-create
+ create mode 100755 debian/scripts/link-headers
+ create mode 100755 debian/scripts/misc/find-obsolete-firmware
+ create mode 100755 debian/scripts/misc/fw-to-ihex.sh
+ create mode 100755 debian/scripts/misc/gen-auto-reconstruct
+ create mode 100755 debian/scripts/misc/get-firmware
+ create mode 100755 debian/scripts/misc/getabis
+ create mode 100755 debian/scripts/misc/git-ubuntu-log
+ create mode 100755 debian/scripts/misc/insert-changes.pl
+ create mode 100755 debian/scripts/misc/insert-mainline-changes
+ create mode 100755 debian/scripts/misc/insert-ubuntu-changes
+ create mode 100755 debian/scripts/misc/kernelconfig
+ create mode 100755 debian/scripts/misc/retag
+ create mode 100755 debian/scripts/misc/splitconfig.pl
+ create mode 100755 debian/scripts/misc/update-aufs.sh
+ create mode 100755 debian/scripts/misc/update-zfs.sh
+ create mode 100755 debian/scripts/module-check
+ create mode 100755 debian/scripts/module-inclusion
+ create mode 100644 debian/scripts/sub-flavour
+ create mode 100644 debian/snapcraft.mk
+ create mode 100644 debian/source/format
+ create mode 100644 debian/source/options
+ create mode 100644 debian/stamps/keep-dir
+ create mode 100644 debian/tests-build/README
+ create mode 100755 debian/tests-build/check-aliases
+ create mode 100644 debian/tests/control
+ create mode 100644 debian/tests/rebuild
+ create mode 100755 debian/tests/ubuntu-regression-suite
+ create mode 100644 debian/tools/generic
+ create mode 100644 debian/zfs-modules.ignore
+
+diff --git a/debian.master/NOTES b/debian.master/NOTES
+new file mode 100644
+index 0000000..f65ae4a
+--- /dev/null
++++ b/debian.master/NOTES
+@@ -0,0 +1,4 @@
++eSCO patch removed. Replaced upstream with a disable_esco module parm.
++airprime: Module gone, use option driver instead
++AppArmor: Patch is all there and ported. Ooops when enabled, so default
++	off (still can be enabled apparmor=1)
+diff --git a/debian.master/abi/4.4.0-111.134/abiname b/debian.master/abi/4.4.0-111.134/abiname
+new file mode 100644
+index 0000000..58c9bdf
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/abiname
+@@ -0,0 +1 @@
++111
+diff --git a/debian.master/abi/4.4.0-111.134/amd64/generic b/debian.master/abi/4.4.0-111.134/amd64/generic
+new file mode 100644
+index 0000000..1fae5ff
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/amd64/generic
+@@ -0,0 +1,18909 @@
++EXPORT_SYMBOL arch/x86/kvm/kvm 0x9f5cdf09	kvm_cpu_has_pending_timer
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0x73892a61	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/acpi/nfit 0xa7e9a159	to_nfit_uuid
++EXPORT_SYMBOL drivers/acpi/video 0x6de7f7ff	acpi_video_get_backlight_type
++EXPORT_SYMBOL drivers/acpi/video 0x7a45377b	acpi_video_unregister
++EXPORT_SYMBOL drivers/acpi/video 0x841b6bf1	acpi_video_get_edid
++EXPORT_SYMBOL drivers/acpi/video 0x8826c13b	acpi_video_register
++EXPORT_SYMBOL drivers/acpi/video 0xe92ca535	acpi_video_set_dmi_backlight_type
++EXPORT_SYMBOL drivers/atm/suni 0x315f82b7	suni_init
++EXPORT_SYMBOL drivers/atm/uPD98402 0xdfd2cc1e	uPD98402_init
++EXPORT_SYMBOL drivers/bcma/bcma 0xa35eb9a0	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/bcma/bcma 0xd4cfd049	bcma_core_irq
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x101d0a54	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x39c242ad	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0x3aed4348	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x4267110a	pi_register_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0x646e4efd	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0x6b0349b7	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0x7e12e53d	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x7ef7fbc8	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x97ad7040	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0xa7e63e7b	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0xb21ba07d	pi_unregister_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0xcb845d38	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xd8a6ad45	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xf4c1a7de	pi_read_regr
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0x10eec917	btbcm_patchram
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x3f61b6d3	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8caa3c42	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xab8ede5c	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xc9c73ce2	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xce9a124d	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/nvram 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x17ff2c1d	__nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x2adec1e0	__nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x7da28f12	nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL drivers/char/nvram 0xa8813189	__nvram_write_byte
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x585a85ca	st33zp24_probe
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x64f09e1c	st33zp24_remove
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x88467d83	st33zp24_pm_resume
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xaa792e79	st33zp24_pm_suspend
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x1206690b	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x43cd74fb	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x881156e6	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x0a015800	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x6109c91f	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x8c81a6bd	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xc51c659a	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xc8c491a3	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xe2af5d34	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/edac/edac_core 0xc506b6bd	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04d0f641	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0f7d6af8	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x1704bbc8	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x25e694df	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2ea504e4	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x36f92e50	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3ead6280	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x43b5b822	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4b277058	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4f79cae2	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x605680cc	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x60ef8c0e	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x645b715f	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x66c76c92	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x688d1056	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x71c78c4d	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x75b8dcb9	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x83019afa	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8d018229	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x921b2410	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9a540094	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9abf52d4	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa304ff3a	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xbb08b491	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd25bd20b	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xe17ff243	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xec95e8a5	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xfb96bfd3	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xfd6ca1b9	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firmware/dcdbas 0xa75079d6	dcdbas_smi_request
++EXPORT_SYMBOL drivers/fmc/fmc 0x0f1d76fe	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x17432df4	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x18367e17	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x2a256ea8	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0x3491a125	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0x5fc1d447	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0x63e9b49e	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x716ba0b2	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x827ae2e3	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xb1c7cbce	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xce0761d8	fmc_driver_register
++EXPORT_SYMBOL drivers/gpu/drm/amd/amdkfd/amdkfd 0x4d5896ef	kgd2kfd_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x002f897c	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x03c3a772	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x043a80c7	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x046e83d4	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06760165	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06dde2a1	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06f6bc53	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06fd3113	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x070d0dbb	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x07a77897	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x08b74c8e	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x08c36289	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a8d9a2f	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0b9b9b56	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ca56ec9	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0cfa60d4	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0e7fc82f	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f7f4748	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11910c5d	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13aaffae	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14457c92	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a67600	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x163e1d57	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x183498e1	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a19525e	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1b11f24b	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1bd886c3	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c603e5c	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dae2244	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1e7677f3	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1ef45d90	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x208c26ab	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20da9720	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x217e7f43	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x219b24c5	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22590103	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x233493e4	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x246d704c	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x24feffa1	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x25de693f	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x26a2be84	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x26d3c16e	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x27d266bc	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x28c56fd5	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x28f3c3a0	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29d8adb7	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2a47b4a5	drm_agp_bind_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c0f503b	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2cc0172f	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ea04ccf	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2fa3f095	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x304256fb	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x309f8807	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x325baa4e	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x32b07edd	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x330a0a7f	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x334986e1	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x340e14f4	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x341c02a7	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3423dad9	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x34eeea90	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3946facf	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3960bdc7	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x39f5febd	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3bb8eb24	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d53f631	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x40a003fe	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x42920fff	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4343fa22	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43989ce9	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4491f02e	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x44b6320c	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x45166da4	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x45c28f11	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x463c3b9e	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x463d58a8	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x470074bd	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4716042a	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4810d659	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x483ff6c2	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x483ff8b3	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c0066e9	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c0ecf66	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4cfe28e0	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d815906	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50882f01	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5150d146	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x517c290e	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5231c0e0	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54181b2d	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5529ee5e	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x556a5778	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x55f18d27	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x565fc2c8	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5680b098	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x569039a5	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x56b6c52b	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x58304318	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x583bc69a	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x591a2af4	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a58bec1	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a73d001	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5ad27f06	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5bb80e2a	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d7318dc	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e1b91d0	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e68c8cc	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5eae3a90	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5fdb6109	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x605c2ebe	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6351ba67	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x63bf9307	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x63d8cf07	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x63d93030	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x64391ffa	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x64896e4d	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x676d304a	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67f3a970	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68e80296	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6a64d8ea	drm_agp_unbind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6be7df7d	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6bebff37	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6cb05fe6	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6d68fdc7	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6eb7d90e	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f3a8938	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f979bde	drm_compat_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f9fe4d1	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6fa2854e	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70cddf71	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x71d45caa	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74c32e81	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x75b34268	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x75d8905c	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x76758778	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x77243a02	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x780eb3cc	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b221788	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7cd8358e	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7f61dfd7	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7fde318d	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x818475bd	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82707f02	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8357cd64	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x84660d04	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x851dc8fa	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x853fdd9b	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8543959c	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8552eae9	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x86998a40	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x87f13461	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8819b0c8	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8860a7d3	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x88934a53	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x88f87120	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a1a884f	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8aab3e00	drm_agp_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8acc0668	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ae83ac6	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8b5cecac	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c9f6cda	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8cbec006	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d166c6f	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de0bafb	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e0c2b1f	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x925ede4f	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x957e84a3	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9778e965	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97b45e59	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97f1c830	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x981ff7c7	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9898e95b	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x998a488b	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x99e053f9	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9e85f4fc	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9e86cd72	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ea9dc6b	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ef1774a	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f2c3af1	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0689805	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa07dc441	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa07e3457	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa17a194b	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1944811	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa27e9705	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa3443b53	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa34c5c0a	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa38d37f7	drm_agp_bind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4f3972c	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa5174fc6	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa6066c1e	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa690bfe7	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa7410bc2	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa7958b19	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaa2b7546	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaa64cb6f	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaa7be498	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaac552eb	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xabac5a91	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xabb18126	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xabb79121	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xac2c20d0	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xacca57a7	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xacca796d	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xadf6c58d	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae5b2d6b	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb17a078f	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb29d527d	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb2a1dbf5	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb2ded4af	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb34de41f	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3dbf5ad	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb4c6eca0	drm_agp_acquire
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5540008	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb565ff34	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb6826955	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb6f916c3	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb7517346	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb77aa809	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb781a3b6	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb94a8cc2	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb9fc37fc	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xba0cef54	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xba46f120	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbae70f47	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbcd4d9b7	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe3d6712	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbed115fa	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbf198898	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc0f6064d	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc1681d53	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc29e6a85	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc5d71fab	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc7064817	drm_legacy_addbufs_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc96cee8a	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca571f42	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca64cb05	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb952c54	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd74574a	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcda6a288	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcfb2ef62	drm_agp_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd272d488	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd341141e	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd5222e40	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xda436f18	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdb657eb9	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbe9929e	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc591de2	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdcecd867	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd924b42	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdfe0c71e	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe02fa92d	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe0f4f973	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe1dc6c58	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe32e5714	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe3405f70	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe38edbf5	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe39da800	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe46f39e6	drm_agp_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe522d4ba	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6e03f1a	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7cb79bf	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe8f19058	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe92dc1d2	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe98ed86c	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeaa8d3ee	drm_agp_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb731606	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xecda3170	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed498ad7	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed94bb87	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed9c46d2	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xee5457e5	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0080509	drm_agp_info
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1e359a8	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf25db327	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf785b93b	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf81e44ba	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf83f8250	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfa54dad8	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb325563	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb7cc4c5	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbf34871	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc172c64	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc5ce81e	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfed4f569	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x030a4b31	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x04ac4792	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x08d5b93b	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x099d299c	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x09c3cfd5	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0a603e1b	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0ae6e65a	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0ccae59a	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0e6c2f39	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f9cf57d	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1038c0d2	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x11c62e1e	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1356b416	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x188b087f	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x19391172	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1b48ab50	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1b8b55a1	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2035a04f	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2045f1b7	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2311a4aa	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2cfc55c2	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2fafdee3	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x30ea12a4	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3263d966	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x347f235d	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x37a37316	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3aaa5bb9	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3b9f7e2a	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3db4e630	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3dee4692	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3e8ac584	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3eadb18f	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4096d3c1	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x410782d8	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x43bd6b33	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x468e3523	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x483874ac	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x492bc1fc	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4cf4c901	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5079705d	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x55d302c3	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x570b3558	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x579ac602	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5d678e8d	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x615b3d52	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x63991dea	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x641b44b1	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x65448619	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x66dc9f0c	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6aec610a	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6edbc0be	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6fce07c6	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x70b6f982	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7286fca1	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x72a06379	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7438037a	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7447a8a1	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x76ecb2bd	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x79036df0	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x79359497	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7998114e	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7a1a507a	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7d04452a	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7e081db1	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x818cad8d	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84db501d	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x888f307f	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x88b7486a	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x89f1a3e5	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9242e2e0	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x933c44db	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x955d1d44	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x971eaa3e	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9b099164	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9b93a5c9	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9d57fb8a	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9eb56f41	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa18d0173	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa3788c42	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa50044ef	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa640c135	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa67088ff	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa9109ec0	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa9b84983	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xabd809fc	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaedb642d	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaf499d26	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaf586861	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xafd0671c	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb20ec94c	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb32d0095	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb4edfbbe	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb71c861d	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb7709417	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb82ff82b	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb951c7cb	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb9635dbb	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbc61da5b	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc18877c4	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc670d1fe	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc7464025	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc9080ff6	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcb1bfdb1	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xce9a25c9	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcea45690	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd05c6f37	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd382c968	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd53c4789	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd54a8ebe	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd8244039	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdb251590	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdb74f61a	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdbe01ae6	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdc10a9e3	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdcdc70fd	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xde4c61ac	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdfdb86ef	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe005d3b7	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe1b887f2	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe346b88b	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe3837c1b	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe64848ff	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe6ab3564	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe7d2f465	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeb28eee3	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xec0b980f	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeca9a91a	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xed62547c	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeeafb430	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xef558871	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf1c3da8a	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf2290882	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf373798d	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf393d8d8	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf58a868c	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf89dfc5d	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfc571d6b	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfd16bad4	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfe11afc5	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfe8aec67	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfebe2485	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xffa498f4	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x04ab444e	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x05e60c83	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x06354968	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0bab7f47	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0f84c60a	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1225f046	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x167f0d6b	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1940e4cd	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1b9fc1de	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1c9c7282	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2033a8c0	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x22d8d168	ttm_agp_tt_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x22ec80fe	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x24765c33	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x29c136ee	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x29d8129b	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2c172f18	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2c22c4b2	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x35818e93	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x35a4fcc0	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3c6cca6e	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4122e708	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4899b9a9	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4ad6e181	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4dc4f019	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4e8dd264	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x55440b7f	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x564e1aee	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5978f20d	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6052860c	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6c8dc6bf	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6db6c3bd	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6e875de9	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x79855254	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8188c129	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x83643253	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x836d8fd0	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x85d3c277	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x88e3bb57	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x915f38d9	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x93e52482	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x946d9ea3	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x95b117a7	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9ab7e956	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9d0f18ee	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9fa9ffa6	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa1437865	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa489b7c7	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa555af0a	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa6eb35ec	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbb5e7a98	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc4d4618d	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc8aa1885	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcbb62902	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf49f835	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd40851f4	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd5167af7	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd56aebaf	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xeb4c2e6c	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xed5b3eca	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf00695cf	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf40edaaf	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf45fefe3	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf5ee18bc	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf63eb728	ttm_agp_tt_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfb146efd	ttm_agp_tt_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfc0c5178	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfcc2d35d	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfd14eb4f	ttm_prime_object_init
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0x140bc083	vmbus_sendpacket_ctl
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0x4c6ee679	vmbus_sendpacket
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0x81612ee5	vmbus_recvpacket
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0e2a6864	sch56xx_read_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0f5877d4	sch56xx_read_virtual_reg16
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x33c2040d	sch56xx_watchdog_register
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x34257f35	sch56xx_watchdog_unregister
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xe5022f95	sch56xx_read_virtual_reg12
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xed1d2a08	sch56xx_write_virtual_reg
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x05fffa79	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x779885ae	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xfaaaeaa2	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x030399d1	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x40128409	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0x9ac65b39	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x0a643e16	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x17f6ebb7	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x2236b189	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x27958174	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x2c7bf506	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x30ebf62f	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x373378c7	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x4c9a6d11	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x4fad65b6	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x72737b9b	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x86e43b72	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xb327a66a	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xb5a466e3	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xe9c625d7	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xee235821	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xfb049b4d	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0xa038f55d	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0xce5a1a8b	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x2fbe0a10	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x7397fae8	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x40176a0e	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x5a69f59e	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x78d4aa8b	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xed02bb57	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x266be5b6	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x4125e3c6	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xa04b0f22	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc7dd36fb	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xd8f3bb0c	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xe7152334	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x5b070896	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x780833da	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xde7f0810	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xe7c51f7d	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x17b0dced	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x1d077b4e	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x1f2647aa	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x2d858448	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x370784c2	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x6896ea5f	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc07b42ad	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc71b5c80	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xfb425ecb	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x309266f9	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x4d12a23a	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x7bd758cd	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x845f454c	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xf7fa0d5e	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x60232ffd	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x8b044e9b	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xe16c7a46	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x09084eaa	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x0d48a676	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x14de658b	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x1ff80aac	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x205a173e	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x388c52da	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x70b66f62	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x78919e33	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb223de64	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc0e654dc	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc4a612ba	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc551ae96	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xcd601005	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd2218664	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xdb3c85a9	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xe8dfe3cb	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf3921143	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x9d1b262f	st_sensors_match_acpi_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xaf5ba78c	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0x9e2011f7	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x7404a808	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x866374de	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0xf37a6cc2	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x52d08d9a	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x78ad8f0e	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/industrialio 0x14d4d299	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x1deabe99	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio 0x20608172	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x21df1062	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x3cd6c23a	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0x4c4cf210	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0x6cc485e0	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0x9d5c563a	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x9f77cb7b	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0xb4117b1b	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0xb417bd7f	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xc2d40d3c	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0xc8d5b86d	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0xc990f815	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xd67db27e	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0xde54f89f	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xfb5e0c41	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x3b635648	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x73f6b978	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x97e6029d	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x9bc03d54	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0xbdd85dfb	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x8db92854	st_press_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0xb7ab23f2	st_press_common_remove
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1edc4064	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x70828554	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x76fa6d16	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x9d9cabc5	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xd85225a2	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xfd999941	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x034d874a	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x0558911e	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x16541be5	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1ab1d6f1	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x26eb1816	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x2fa91234	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x422fd70b	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x4de0fbc1	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x5af18656	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x744e9b00	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x980ad1cd	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x98b3d7fc	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa4eec8c7	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa6086779	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa723ec4b	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xc155d728	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd0ec98c3	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd17234a3	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x00476345	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0589f87d	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x07940f4f	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x093608d7	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0b37ec34	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x139d9eb3	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x14989e2f	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x15036971	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x21f0abcd	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x22f3cf93	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2337b074	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x25dc7241	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2947999d	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x29f3530d	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2c4392a6	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2dbd23ff	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x30b25707	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x31dcc1e2	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x354ceb1d	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x49546393	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4bb68ed6	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4e9f5927	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4f61e7a7	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x53457448	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x55aa70d3	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5b3e57fa	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5d5e59f5	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5ead4dba	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x61f55400	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x631e8073	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x64ac5623	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x651ef289	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x67da499a	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x68113273	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6cbbe6e8	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6cec5d05	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6dc3a4ce	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6e189438	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7227ac53	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x75430c27	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x77086b64	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7792e6ae	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x78034364	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x798c5ae9	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7abe7174	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ace6409	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x84e97334	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8822e73b	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x92e2f4f2	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9327eb63	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9591d5d9	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x95d20871	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9c27cf1f	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9da75712	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa0a8c3a3	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa152861f	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa432baf6	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa4512ce9	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa540ca15	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa916b280	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaeb8ccb1	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaf754df4	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb51d7b35	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb9beac82	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xba49f422	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc4058703	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc4b1e15f	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc782a82d	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc97b9bdb	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc9e85d26	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcc1ece04	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcd413e30	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcf8f55b8	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd3e7b0d5	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd74e77e5	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd808155e	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdfc6ebcc	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe33bc024	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe7ebcd6e	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xea669687	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xea66a784	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xeb07b2bf	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfb3faa48	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc59e272	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfcc652f2	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x07eaa171	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x0ce17af5	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x17b608eb	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x18bcbb6e	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x21f6d071	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x257860a9	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x286de3c7	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x37462a7a	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x8b5a88ea	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xa2d6c82e	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xa61baaa7	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xaf0dbe5f	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xe0a86a9e	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x01c69b73	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x05f51c4a	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x09bbf38c	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x0e70c182	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x287d1e73	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x32274d83	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x42e5eeca	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x92fe9b13	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x957e9f7e	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xa0232f44	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf334af3d	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x2dadd7fa	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xb1fc9988	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x1281f501	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x19bfa864	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x60ababf4	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x8004b16d	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x937ace73	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9e1105d1	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xa6eae885	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb13463af	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb7b84727	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xc2b6202f	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd38018b6	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd475391c	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd4b61a41	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xefef3378	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf6d21431	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x09ceca21	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x0d2c7356	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x150db943	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x20e890e0	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x24fca91a	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x286b2018	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x2ccd03ef	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3d87fc5e	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3e888316	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x461d80cd	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5ade6098	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5e39edaa	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x77afd474	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x8ba2cdce	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa6f423d7	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa99e7001	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xba638f52	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xbd8b477e	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xbdd835ac	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xcc850e29	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xdd6d1b83	rdma_resolve_route
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x10c67ae7	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x21e3ce73	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x30ccb029	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x5b4e5a12	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xc31aa36e	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xd6aca6cd	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xe23f3fd8	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xe32845f2	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xef7b9584	gameport_start_polling
++EXPORT_SYMBOL drivers/input/input-polldev 0x31c24ee0	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x42d3c26b	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x928faeb3	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xb4642c5a	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xeb866ac1	input_register_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0xefbdd52e	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x4f9bccb9	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xaa846a5c	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xf5d8a2be	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xb0bc60f6	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x11e785fb	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x34eb19eb	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x4b23a3d9	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x6881e19f	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x794bfa0e	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x7c8eadc3	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x6dfc4788	ad7879_probe
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xcfcd7b95	ad7879_pm_ops
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x0728730e	amd_iommu_init_device
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x742b0129	amd_iommu_set_invalid_ppr_cb
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x9687f347	amd_iommu_set_invalidate_ctx_cb
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0xab8cfc9f	amd_iommu_free_device
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0xdb014730	amd_iommu_bind_pasid
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0xfc8281da	amd_iommu_unbind_pasid
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x020cd237	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x121606af	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x30433736	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x329f2918	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x61d144fe	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6fe04e60	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7292ab34	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x72a25a72	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7fdea068	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xd8663c87	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xd8982f54	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xed82f735	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xfd552f7a	capi_message2str
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x0c48b074	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x30fd8a82	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x48311bf8	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x5da31433	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x690134d8	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x6cc7f2cd	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x75ccb8df	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x7cfcb840	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9507a6d0	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xa23f5e85	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xabd1ef35	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xb31c884c	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xb8db960d	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xbafb312b	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xedf6d0ed	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x22e8be66	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x3c742a92	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x42cc297b	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x7ec53226	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xb012dbde	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xca3c09a5	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xe07f3e18	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xeb80b53b	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xed1d9148	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0x29562993	b1pcmcia_delcard
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xaec3240e	b1pcmcia_addcard_m1
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xea620116	b1pcmcia_addcard_m2
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xf14bf8b1	b1pcmcia_addcard_b1
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x3f94c34d	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x41fe14a1	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x5aaed705	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x6e79e20d	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0xc6874659	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0xe538cc8a	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x039ad31b	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x0b874902	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x19c03119	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x49fcb253	isac_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x6ec2e7cd	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xff446cd3	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x8844ff2e	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xa483fb61	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xb324d00e	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x0b869c74	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x0efd6b84	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x17f628a5	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x19f47331	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1a2095ba	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1bbf3c7d	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1dc71fdf	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2c61c9f2	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x31532c33	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x326c2709	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6d4f79d5	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x709d1a2a	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7629a835	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7b95f5b2	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa4a5fe86	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa8bad672	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xae1a1919	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xcced6b4c	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xceca9e84	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd382fd98	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd7c19d6d	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe2865a98	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf743c839	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x0824bc14	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x1f529ce8	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x440b4830	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x44a37d62	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x4528bcfd	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x5b59b856	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7daccb73	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7f2a56c0	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x8833b0e8	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x8f8fc624	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xa0b4b1b8	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xa3c5c702	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xa5df0d33	closure_put
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca5df778	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xce47a6d9	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd2813054	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd97c32a1	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xdf892351	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xec6f33d0	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/dm-bufio 0x268682d2	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-log 0x47a2656c	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0x69a45e26	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0xbca9f5ed	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0xea10c345	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x553a4d3e	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x6b8ae9bc	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x9b4ee5f5	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xd73a0d8d	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xed1c020a	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xf4cad9a5	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/raid456 0x733247bf	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x0df92a91	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x1316acae	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x3946668e	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x47cedcfa	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x7e7cd239	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x807915b0	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x89655650	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x9c85a5b9	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xabb81ee2	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xbea183fa	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xd77dfcf7	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xdd9653f1	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xf931d903	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x07c52782	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1c04e906	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x7221e6ca	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xffedf63e	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0x667e8c2f	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x16d9bbd3	tveeprom_read
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x2890a967	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x08c0ecf2	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0d3c856a	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x12f5425e	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x14fdf0ee	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1c053a2e	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1cd2401a	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2739cfba	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2d836ce7	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x303b2662	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3405dbfc	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4cf3b0d9	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4ec6c199	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x577d2144	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6560e532	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x67256b08	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x69481245	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x70d370f4	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a854d9	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7c8740ba	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8bcbbafd	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8bf46765	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8e8a637a	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa582ddd4	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa992e4af	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa9c9c39f	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xacc510c8	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb0ca2500	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb671ff24	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc1be5844	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc2dfe52e	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc7a3740a	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc9af1a47	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xcb77c98d	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd8988b7b	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xeaf47cb5	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf1d78344	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf5bd7142	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfff5fd61	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0xdbce7d8d	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0x1d4bae05	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0xc9e9f4cc	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x551928aa	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x7a2d6982	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x9271d32c	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xa0433d85	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xa125b91e	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xc8050842	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xd424182d	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xde1523ed	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xfbfc5669	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0xaddbde90	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0xd40e00be	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0xf20d3b60	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0xc05accfc	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0x3d94f7bc	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x2e932a13	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0xeccbeace	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0x81c89dac	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0xf8e9a043	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x5449e53e	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0xac9ed56b	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0xa4b628b3	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x6f2fc435	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x7d7df72d	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x973e9d99	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x0a847a6c	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x57cb6549	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x9adb6b14	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xa0fb29b1	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xca1c48a4	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x0905215b	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x2f31ddfe	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x39afb215	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x536dcb9f	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5d9a3c35	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x63094238	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x6e045f58	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x748d3cb8	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x8a10a58b	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x9cdd0658	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xa5cece70	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xa98905dd	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xc4f98ff9	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xdebf1169	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf316c0ec	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0x4b89478c	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x00d5809f	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x320ba869	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x38b877a4	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x8ff28fe7	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xe0f2cc88	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xe1d1cf3b	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x36296e7a	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x6425ebc0	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x91c95c0d	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xc3328597	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x382b207b	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x57c18a04	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x30606734	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x7b14074d	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x977659ac	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xab49eedd	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xc54315f9	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0x446e5ea2	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0xf8e14c3c	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0x72a1895b	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0xbf74968b	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0x2c3f48d5	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0x6d391224	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0x25d9877c	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x6d2a0014	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x0ecc7ed4	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0x58e384ab	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0x9027612d	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0x474bb698	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0x504f3677	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0xc0f63998	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0x6f586b18	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0x77881a87	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x42b5c836	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0x55b82efe	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0x64605f10	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x807bf4d6	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0xbc204e02	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0x850a3c77	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x160233da	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x49f70a6d	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0xcaeb67d6	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0x0987ff0c	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x7626133a	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0x1a36f3ab	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0xc94dfcc2	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0x84c34e7e	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0xaae0a0d4	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0x3f1dbe4b	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0x9ce42ac9	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x63a2339f	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x8f1a4f6b	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x4f0a1592	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x8844101c	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0xea6b2a2c	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0xe383140d	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x7f0dae23	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0x396c088f	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0x6ad9ca4e	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0x18a2ff7e	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x48077170	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0x7a6e2430	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0xc339499f	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0xc6098a5e	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x7acd5b40	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x69341fb4	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x6a6d27ae	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0xd54220f3	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x27da7512	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x532c00b1	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0xd333e552	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0xd5f40bc8	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0xe08b4051	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0xf6d2c6ab	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x843c244c	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0xb0298c24	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0xc9abdc0b	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x018d6852	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x9fb73b3c	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0x4f6366ac	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0x3e03aede	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0x715add18	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0x83cdecb1	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0x21440b93	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x77dfd3cd	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0x366033ff	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0x9ed6bf0a	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0xba397edd	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x04817d0a	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x1f539527	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x73cd5987	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x9097f5d9	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xb768d195	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xc5bb16cf	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xf7c9bc11	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x717010df	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xb4322e8e	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xe3777d56	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xe41670ff	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x1188dfd6	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xba9b854a	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbba5cf77	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x3384156c	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x33f308ee	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x3e7ecfd4	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x51ba8acb	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x6640aa2d	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x714b2508	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x830084b9	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x98f80877	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xfca4eaa2	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0xe7335532	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x046994f6	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x22c82d7d	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xa55d3393	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xaa30977b	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xe8861c0a	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x0c36e553	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x301b3e67	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x4d8cd7e6	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x4eb4b1f2	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x91970961	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xba648fed	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xbcbc2b68	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xe7f47347	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x19084cbf	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x7e32b8bf	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x14265ef6	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x748ac9e5	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x85d8ff49	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xb26e908e	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x548d3cff	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x940e6e25	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xa5bd0977	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xc50e830b	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xe1a26df2	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xe2500d8a	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xe6ed28cd	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0b5be4e1	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x1b767031	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x1cd5568c	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x25866a27	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x39b64163	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x47b087b5	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4f9088ab	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x50cb49a8	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x5e1e3d78	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x71e9a24b	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7c7e0eeb	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x88195e91	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xaf03b166	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc0d47ce5	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc78d277c	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xccba5a93	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe3f0149f	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xec30783a	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf2e2fb0a	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf8856373	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x0351b07d	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x10260bec	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x3aae0926	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x6942d2b8	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x6f804688	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x7c334ad3	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x86451dd3	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x994bf411	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa52b9de8	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa5732489	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xb3a19443	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xd4bc653e	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xd4e7e6e8	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xe818746a	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xee110299	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xf0bedab2	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xf838a413	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x29080802	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x2f995d45	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x31ab9c1b	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x4cbfbef0	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x5839b6cc	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x5938356b	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x6ea090a2	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x9288ab2f	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa0e4be65	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xeafd4cdc	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xef948845	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xfe0e263a	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x25c54706	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x2346d1c8	videocodec_unregister
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x66d30627	videocodec_detach
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0xbb1baafc	videocodec_register
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0xf75dce9c	videocodec_attach
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x23196f2e	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x40067efc	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x50fc382c	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x898bcb93	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x9f6fa904	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xa328b7d8	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xed3676a0	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x0845f9eb	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x2f1864fe	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x3069de4d	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x3b6e4c8d	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xadf811fb	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xd36b0a69	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xfa41584c	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x018718ae	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x189be094	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x4bc67282	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x9959fa9d	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xa3e98a21	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xb155c29b	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xd13ad941	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xe41b2344	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x3d942386	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xc537f9b8	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0x1dd1d31a	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0x99612c15	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x51f30450	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xa50015fe	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xb834a061	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/max2165 0x83152b18	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0x8860b0cc	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0xa43026d6	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0x9c7891f3	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0xc768f15b	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0x415c30f3	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0xbec7f271	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0xc2091828	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x2c2d1658	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0xb3a01145	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0x20a2cac5	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xc855bac4	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xe603dbb9	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x2a169825	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x2a759898	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x500000d8	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x6c2d0101	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xa0752816	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xac99dd5d	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xbab15bc5	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xc96a4d8a	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xf0cb00c4	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x06c7ad44	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x735c98aa	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x763ae30c	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x769d2283	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x9c4b37e2	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xdce47f15	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xfcf34b93	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x295a4c1d	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x0377cb89	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x3a75efef	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x40b01e3d	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x5fd6071d	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x614123fb	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x74ecb73f	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x8a6729df	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x9804f98a	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x9fe34623	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xaebef93d	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xf446f7ae	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x2cb84661	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xa1958414	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x047ab291	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x09fa073c	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x18fe27d4	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x2603aab8	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x4fc43596	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x529a6cc2	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x71c30e80	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xe5ce6de2	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xededd131	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x17b56772	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x6a614e31	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x710fc003	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x90a9450b	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x960d8b84	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xa8611e27	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xad54ee70	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xfcbec9e5	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xb4039cc4	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xe5d0bbc3	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xf67741cf	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x566728d0	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x7da0291a	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x2ff8ba8d	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xa1c60549	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xed637ba0	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x11a325c3	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x961fe466	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xa5515a83	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xab5dfe07	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xabba257b	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xd4200117	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x005a69ed	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x83115e54	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x3f00f73e	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x510ff514	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x60acd49f	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x6c1c675c	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x91609b73	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xf8bc38f0	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0xaa31277f	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x03b20e91	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x05104a91	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x06c7dbfa	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x07e2488c	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x09e7012d	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0bf721a0	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x11bd5b5c	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1c1cf2d9	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x28daa37a	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3460b893	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x35423395	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x38f38e87	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3c0f8da4	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45ad1ef8	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x46d3f4ea	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x48581651	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x489daed2	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b9ca023	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4c230a2d	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4fa2d7ed	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x61c15f69	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x649aa3fa	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x668e5008	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6ae9ca28	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6d72c772	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6f23ec5d	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6fd86f24	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x71cf5d61	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x73f90157	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x74294f56	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x75738f83	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7575acca	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x77deb2ab	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a5ec39c	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x83b5c284	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8798d7fc	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8861a6ca	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8b4e5143	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8b6857b1	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8dd20a13	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x93b8c4bd	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x97382116	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x977c4810	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x983f66f4	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x99900f1c	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x99d35023	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9ea7d291	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa0ad9642	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xadac5693	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xae6ba219	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb00cea15	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb5c5c399	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbaf9871b	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc496a837	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc6143239	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc7adb6ee	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xca68b182	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcd7167a7	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcfcb2fe2	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdd900651	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe16eac52	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeb2461c1	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xee3a78b9	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xef32d304	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf00bd689	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf6e28373	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf7cc6cdf	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xff77a091	video_unregister_device
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x0d5c824d	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x15e7bddb	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d1fcabf	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x64f56710	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6b59d0d8	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x862fc3e7	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x9251ae3d	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa66ad9ca	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xaaf3670f	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xbd0bc0c4	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xcfbb692b	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xd8085878	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xdc07e67e	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x08b7b9b6	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x08f16213	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x0fd4d507	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x133dd807	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x147fb6d2	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x217b66df	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x21e38c33	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2c935d87	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2fa0aa9c	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3b4a9983	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3b8fb1ac	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x409eb581	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x47fb1a20	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6dacb440	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6ed59d79	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6f986ea1	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x84b35d1d	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x84d55f72	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8756417a	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8910103c	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8a648ada	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x996b1561	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x9b8698c0	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xacd2ebf3	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb2fea11c	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd20b6302	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe02af561	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf0274cfb	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xfaf8c7f0	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x040348f2	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x260102eb	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x35cbd929	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x36346388	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x36a59ba8	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x3a9c97b6	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x473c39d2	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x580dcf66	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x6d379535	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7ee9673b	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x83ac723d	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xa079d3a9	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb4cc11d8	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb8316aa8	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc075bcec	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc1aee7e6	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc568209f	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xca48176c	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xcbbb9dad	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xcf74eec2	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd29e22b9	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd3758711	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xdc90de4a	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe06df9e7	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xfaca692f	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xfd146cf9	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xfeca3640	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x74508695	cros_ec_suspend
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xb89251f2	cros_ec_resume
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xb97e2230	cros_ec_register
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xf376ce36	cros_ec_remove
++EXPORT_SYMBOL drivers/mfd/dln2 0xd05d98bf	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0xf12f3e9d	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0xfc61b5d3	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xb74273cd	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xd9ab9232	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x0fbc1392	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x26ecca58	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x2ab02f5f	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x306a1977	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x560c69e4	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xb5ead0ec	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xb9b98eb3	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xc9120204	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xdead27cd	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf51339d1	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xfbf5c8a5	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x27c4cd31	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x8b94360a	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x2fbdef2b	wm1811_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x7d71acbd	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x82e5569f	wm8994_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xb0dfed06	wm8958_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xb52c7a44	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xce4da626	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x13090222	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0x0a496c44	c2port_device_register
++EXPORT_SYMBOL drivers/misc/c2port/core 0x30249205	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/ioc4 0xe3c1bdac	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xf52e7864	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/mei/mei 0x5eddbbc9	__tracepoint_mei_reg_read
++EXPORT_SYMBOL drivers/misc/mei/mei 0xdd1b8214	__tracepoint_mei_reg_write
++EXPORT_SYMBOL drivers/misc/tifm_core 0x35272a2e	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x38b4922b	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x3f77ca8f	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x627eadd8	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0xa8c2ec46	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0xac889e31	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xb639d902	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xc0e390f5	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xc27d1025	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xcf4c6b01	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xe291baa3	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xf6844b71	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0xfce0411a	tifm_add_adapter
++EXPORT_SYMBOL drivers/mmc/card/mmc_block 0x2313d7e0	mmc_cleanup_queue
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x228ed68a	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x4406d39c	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x6f10f53a	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xc997cc9b	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xce3ecc9f	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xdb87daf0	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xdcc07f6a	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x0b94a01b	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x27eda614	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x5824e7b3	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xd0617ac2	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0xcf40b4ee	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0xee59efe0	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0xd0244026	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x15c39273	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/mtd 0xa5119260	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x14b5cd7e	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x37b08685	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x070152e0	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x1c41c5d6	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x557afbc8	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8a9b37d7	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xc2520c6f	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xcc099dcf	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x2c99b97d	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xb2f70374	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xee4f0e81	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x7092526f	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xc2d0e7ba	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x29740c3d	onenand_default_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x7a25fe5e	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xbe261fd9	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xd2627178	onenand_addr
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x0cceb7c4	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x1db5c089	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x3ed18f57	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x4f7915b2	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x8e1cf6b5	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xbed501a1	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xed01f5ef	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xf9cb3ff7	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xfbbc9ed9	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xfbee8a7d	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x447da3c8	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xf56f5878	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xf987d3b5	com20020_found
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x3e6d7b2d	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x4c5be829	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x81c6fb96	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x8d1e4f52	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x9d255c5c	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xa383a804	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xaf5dadb7	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xca699f97	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xca9061d2	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xd69cb6b1	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0x2e93ccb3	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0xa047438d	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x0d8be5fd	bgx_lmac_rx_tx_enable
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x285bde59	bgx_get_rx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x42264715	bgx_get_lmac_count
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x6dc1648d	bgx_get_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc397f585	bgx_lmac_internal_loopback
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc82be691	bgx_get_map
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xe48ca42a	bgx_get_tx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf101d1b2	bgx_get_lmac_link_state
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf9508980	bgx_set_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x190a29cc	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x27f53fee	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x3e8045ae	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x45dd7939	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x484b79db	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x582ad6f0	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x5ca10516	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x7a1071b9	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x80e1b4aa	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x8ae4be30	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x92e9f2f7	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xa90f04fb	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xc370f0d4	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xc7b36980	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd93eb89a	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xdef6cef6	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x13c70f61	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x21f2cf9a	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3273364c	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x35d51ca9	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4070e237	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x40a1b8be	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4c8d7411	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50a30000	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x57707dfc	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x5991bf8c	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6d64795a	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x70ec8029	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7153a84d	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x822b3de5	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8be50142	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9e08269b	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa4bb946e	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xaed9933b	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb7aba21c	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xbb485cc2	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc446804d	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc58d2556	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xcfd84c21	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xdb6e26a6	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe040c701	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe3cc0de5	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe56135f1	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xeaab4214	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xebcc087b	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xedad6185	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xef29e5ab	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xfdef5342	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xfdfb585c	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xfe333f6e	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x2351f800	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x56e01ac6	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x5f927497	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x61fa727d	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x90fa1692	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xd0b06fae	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x02df08b9	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x75e7470b	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0a9c1d2c	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x18410e84	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x19cac4be	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2c6c991f	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3113fb3a	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x36a63f84	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x487151a0	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4ae06267	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4b18c028	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4cd6274c	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x544bd120	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5dbc9982	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x64097389	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6c35142d	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6d26ca71	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6d5c91e6	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6f8cf8be	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7454d83f	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x78315111	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x79631422	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7b25b17e	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x850a63aa	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x913bd898	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x95faad6a	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9ee8bcf5	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9f23cb42	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb16cbed5	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb53263a3	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb75b88d2	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbbffff11	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbef96d43	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc8016f7e	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcffbad70	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd1b6fc1b	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd1ef3044	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe110945a	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe21d599c	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xec33729a	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x04af2850	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x077ffe6e	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0beb1d8c	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x287aa4fd	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x298c44e4	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x346b1d83	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x373873e0	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3851e1d4	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3f76e8c2	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x48f7074c	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4bcf9316	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5c87c186	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6088598c	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6163a27b	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x686c88ec	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x73639d5f	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x791be54f	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x80eaa91d	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x846633d8	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8a865d5e	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9643a051	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9b714979	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa3a108ed	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa481be12	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa8261824	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa9aa93e6	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbdb5cedb	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbe31a468	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc184eb3f	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc34e5bf2	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd86c968f	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd923e6b5	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xda85ab5c	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe4012a04	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6e842d1	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xeec0b5d8	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf37a24d1	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf7df4b45	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x0b2f66fd	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x2d07a992	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x39a7d6d9	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x422ddb2c	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x72831829	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80205bcf	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x9669e9bf	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xcf30418a	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x655d32f3	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x07bcb275	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x9e03fa05	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xbdaca126	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xdb6ee6eb	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xf29faa05	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x330a3cf7	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x488d51a6	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x4c0974c5	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x9b6f518c	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xacd63abe	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xbecea234	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xc38383ec	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xd2ab345f	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xe4833a00	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xec72795e	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x120fb501	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0x4151cc02	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0x6276769d	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0x8ead6df4	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0x9a903495	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0xc741894b	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0xd80ddc70	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0xfc178949	mii_link_ok
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x87e372a5	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xbdc6b6c2	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0x62968f3e	cavium_mdiobus_read
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0xa2c763f7	cavium_mdiobus_write
++EXPORT_SYMBOL drivers/net/phy/mdio-octeon 0x8a1d5c26	octeon_mdiobus_force_mod_depencency
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x2471b9a7	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x6f67c811	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xa5fa2818	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/vitesse 0x027a9618	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x0f90965e	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x50c7e573	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xd86ef864	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/sungem_phy 0x18e2d918	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x09a40efb	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/team/team 0x3eb09843	team_options_register
++EXPORT_SYMBOL drivers/net/team/team 0x4125afee	team_mode_register
++EXPORT_SYMBOL drivers/net/team/team 0x54c3bd85	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0x6b096ea9	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0x862966cc	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0x9eb2ca72	team_mode_unregister
++EXPORT_SYMBOL drivers/net/team/team 0xbbad1799	team_options_unregister
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x01429bd8	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x7bc870d5	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x7f046ced	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xfe52e04c	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x04d78cc1	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x09c2e3c7	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x1aa908e0	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x54452677	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x842a8f4f	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x9f5a6488	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb632579c	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xba813608	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xc67ceb24	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xc89c6341	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xf595f571	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0x65085a12	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/airo 0x5c8f5b8c	init_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xcd50531f	reset_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xd79f9ce4	stop_airo_card
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x10d5d03e	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x14ae9b3f	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4da00d30	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x607712c3	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x6b8cc5bd	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x9acaa33d	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb3bb3801	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb9b24c03	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xd36f9d45	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xda443bf6	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xeebfbb0d	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xf4861b1b	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x2534dd99	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x292e9988	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x694f015d	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x705b899c	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x9e3d8bba	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x9f4c5866	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xa00c83a0	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xa9d1c1b5	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc1061a7d	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc56b128a	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc83f79b5	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xcce43c71	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xd2997b6e	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xd8270662	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xec2c8194	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x160adfdb	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x184e074b	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x34162e5f	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x41a8b970	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x43d13790	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x5424eb72	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x94143075	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xbe7400df	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc98873e4	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xccc93e41	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xffe5d06f	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x069fa112	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x169100f0	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1dcd2648	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2b203cad	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x382605f7	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x39bbee5d	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x39e4a60e	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x527890d8	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x541b555c	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x56574730	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x5cad00ea	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x710726dd	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7d374b2e	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x81fb72e7	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x8a5e30d7	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x92a38ace	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9ac62245	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9cf10301	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xc37fb198	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd043b022	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe2892542	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe685e2db	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xeadb76e9	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x020e3396	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x05980fc3	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x07145f78	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x09875187	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0e727401	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x150e2955	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x18a39412	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x26985f2c	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2ce9449c	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2dc6efb4	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2f8510f2	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x30d0054f	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x31e7a839	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x339daf37	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x34830c74	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x36100d83	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x362185ee	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3bfa593e	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3d70a4a1	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x40728236	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x41177ecf	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x41e3e445	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x436faa16	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4fc4d1c8	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x50770dd2	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5383fdeb	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x587af694	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5888fab0	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x58920c12	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x58ab6433	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x59f906dd	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5f3d47c5	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6278d177	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x65af55d7	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6ae1d455	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6f100633	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x70d330f4	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x70fe7a38	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x71c8e4e6	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x775eaf6f	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x79e06df6	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7ae6aa64	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7beefc76	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7d044a12	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x804b33c9	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x81db16ea	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x81eee77a	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x83cd9f5a	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x86eac350	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x89606ec4	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8c248c79	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8fa55db3	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8ff5bdc2	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9586e043	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x967b4ffa	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x984d400e	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x98620681	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x99f5f36a	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9a6d43cb	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9a8e05b9	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9ab07aab	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9ddd261a	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9f0069bc	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9f116297	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa15b3485	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa1cd53c2	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa23f6c05	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa2c36686	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa513de98	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa5e0354e	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa7d96e72	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa9722a91	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xab43968d	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xae63438a	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaf6bf0ff	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaf97077d	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xafe686a0	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb06114a9	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb2544090	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb57c693d	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbbdcba68	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbbe437ab	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc190f2a1	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc2219734	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc8c85c91	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc908a489	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcd34825d	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd1083c44	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd1f59cf4	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd2b0906c	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd4386a6d	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd6f303bc	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd7ef3818	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdf0a281d	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe0b54664	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe43a8a68	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe5a9c3f6	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xea6909f4	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xee6c2d9c	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf0103207	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf240bfbc	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf3ee78d7	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfd7dc929	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfdc4aea6	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xff5fb69b	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x462146b6	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xa1659ce5	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xbb359826	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x044aa83a	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x0da7a2ca	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3e8f8dd9	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x4b20720c	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x6367f329	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x6fcc7148	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x757fca3b	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x8cc6751d	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x8cf0ab19	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x977f81eb	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xb6bba6fc	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xba33bf78	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xde54c086	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x08dc3538	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0fb62790	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x150ee004	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1723ac32	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x229beaf3	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x25b739b9	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x275b5cda	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x2a1e12ff	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x30bb90f0	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x36708de6	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x3d3bec45	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x428e1a3d	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x5d92384e	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x667e5793	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x75ccc1c3	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x76292e3a	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x803fadcb	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x80c4fa25	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x85280fac	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x91aa786c	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xac178745	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xac2d2b7d	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xbcc843b1	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc6b590ed	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xcf2ad0a8	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xeacd11ee	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x03def3bd	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x313b2901	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x327a8f34	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x38945e06	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x3ec8b263	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4cc46fcf	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4d2ad8e8	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4e8d1de3	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x58e6eadc	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x61577d75	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x714a636e	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x7817e42e	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x9ecf20c4	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa03169a7	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa1db6d35	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa66b3573	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb710b0df	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xbfa58beb	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf1e6d4db	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xfcf4ea17	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xff2a8bb0	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x03446cd3	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x06d70f52	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0ab5d250	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0ad33945	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0c1f8d2e	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0d5ef4c3	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0fded2a1	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x127e530e	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x132b622b	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x13a86e70	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x14e4b7fd	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1dbbf380	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1df452fe	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x204eee74	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x21eb0b0d	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x221c3e20	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2f179d6b	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x309a359d	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x382cce69	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3c8e25aa	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3eeed93e	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3f850d38	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x42bb44a3	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x46ba49c3	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4ffe5841	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x509146c4	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x516d1ae8	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x51a75805	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x57079395	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5715891c	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5b959348	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6356bb1c	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6b5c32c4	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6fe795b7	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x715fea25	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x71c1c423	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x73b87042	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x73ea6ac6	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x76d56653	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x775678bc	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7952a0da	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7b665ab6	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7dbdf6e9	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7fa0ddac	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x84455c4d	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x86112de9	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x86670a29	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x86faa4a8	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x921dcbad	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x94083984	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9784de0f	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9a59e8cb	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9e7777bb	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9ed9c9f1	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa0ff668a	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa421a994	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa7618dfc	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb0032a06	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb3436dff	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb3d35a35	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb87e1293	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb9e239de	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbbe3e3a1	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbdc9527b	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbe7e8789	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc4ef9d20	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc83bef0b	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc8f5f441	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc9bdce17	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc9cae199	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcd8ae4c6	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xceeb69ba	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcefb2e18	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcf105b00	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd215edad	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd3864d2a	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd547797c	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd6633c4c	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdb1ebb9d	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdd2b41b4	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe08c1f4d	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe18889d0	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe3b6fa2f	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe48116cd	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe563a6bb	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xec394b82	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf2cb3197	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf4a5c038	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf7b7a8e5	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfa89f6e7	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfb7733ef	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfcfacaf5	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfd36944a	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfed55cdd	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfef42857	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xff19c1b0	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xff4940f4	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xff5e5a3d	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x1b06ce78	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x2447a6ab	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x314a20a8	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x5e9c24ff	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x8c8ab242	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x9a1b1df9	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xdced6db1	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x02cf7fcf	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x1a73d9f4	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x1fbd604c	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x3d5134c5	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x4d5b2135	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x52d75d27	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x6a625c82	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x6d0c554b	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa8a1eedd	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xad7bd015	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xafd8f4ea	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xbb026f84	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xc471513b	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xcf7f70c5	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf763f707	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xfdc906a7	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffd08257	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0x8d593a89	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0b922e31	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x14250d32	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x178fa9fd	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1b0a1dd3	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x26334fba	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x29d47c04	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2b9439c5	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2ebefdd4	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2f12410f	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x39f30666	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3d3f2d5e	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3d78691e	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x43241bc7	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x43733944	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x44841059	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4797d2e6	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x51cb15fa	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x52e5d2e0	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5301021c	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x58a5fe66	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5b5bfa23	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5f61d66b	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6e937848	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6f5ead8f	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7bdebef7	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x84025750	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x849511bf	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x91dd1f09	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa6ec7308	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa9e42dba	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xaf41bcac	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb8fc9fdd	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xbaba3611	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xbcd01d24	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xced964be	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdd93b5d7	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdf371eb4	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xee5ba461	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xeee886d7	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf165cc64	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf70fa4fd	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x09ffea9e	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x4a864137	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xcc524d95	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xfe93e6fc	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x05634a7c	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x0a620e8b	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x17aab717	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xd77719f4	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0459d5f0	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x13917a2b	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x170e91c2	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1ad2098b	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1e335cf2	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2004504d	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x21a113df	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3845b71c	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4ed59840	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x53c97a3a	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x58904535	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6113d371	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6301acd8	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x65b47907	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6ccc3bd0	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x7de4d7ad	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x7f149dbc	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x874ac125	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8f42638a	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8fb685a2	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa15ab3c4	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa4aaf047	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd668a9ed	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdd85ea71	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf1835ba7	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf202434e	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf38c88b6	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf9e0326f	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x6a151732	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xb9abc530	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xd7dbdcc3	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xd84e44a6	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x853fc756	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xa976ab50	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xf8baddb1	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x6bca998c	microread_remove
++EXPORT_SYMBOL drivers/nfc/microread/microread 0xa9eb440c	microread_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x1759738f	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x9f11defc	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xe13af357	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x70a1ba1a	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x7e503b29	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x1856dd75	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xb369f9b0	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xe51595dc	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x20d1888e	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x270450b1	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x5d88a499	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x6c66750a	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x7d1344eb	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x86d38660	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x97c4f0ea	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x9d15b7bb	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xc51857c4	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xd6fe5419	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xf6a9b662	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x05f7a021	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x0ff55bea	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x1caa025b	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x319df548	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x4044a03a	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x4f1640f0	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x6123b505	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x723546e4	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x7edbb323	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x912af6d2	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x9eb62070	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xb0ccd21c	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xbad04f6e	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xcab1d3e2	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xd1b183a1	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xdaeb1c2d	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xdeaebdab	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xe0e8aab3	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/ntb/ntb 0x013aa9d5	ntb_link_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x28ad5ee1	__ntb_register_client
++EXPORT_SYMBOL drivers/ntb/ntb 0x340d44a2	ntb_set_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x90646885	ntb_clear_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x91353a8e	ntb_unregister_device
++EXPORT_SYMBOL drivers/ntb/ntb 0x9f4101d0	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xac2986dc	ntb_register_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xecefe114	ntb_db_event
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0xdde394de	nvdimm_namespace_detach_btt
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0xf70f83e9	nvdimm_namespace_attach_btt
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0xadbe335e	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x01a72d25	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x0301a374	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x0e51db8f	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0x10164f93	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport 0x18256b64	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x1f8f1cc2	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0x3fa3505d	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x54f171d5	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x62aaae14	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0x63174987	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0x63ecd552	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x6c56cb7b	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0x709827d8	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0x7d846b48	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x7e63baa7	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0x920b9c9c	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0x967bca51	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0x9d0f30b7	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0xad273b80	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0xb2ef627f	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xb3926367	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0xb86d3f1a	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0xba5f87ad	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0xbe9296a8	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0xc09e58c1	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0xd036d554	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0xda180bfb	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0xdc7a452a	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0xe3152bec	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0xe7b93e8f	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xeb4e1f1d	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0xfc4f56e2	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport_pc 0x60a647d7	parport_pc_probe_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0xf65a7be8	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x050b4629	pcmcia_request_io
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x0b798d80	pcmcia_dev_present
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x2d963c1c	pcmcia_fixup_iowidth
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x4d0de0c7	pcmcia_enable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x4fdde982	pcmcia_unregister_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x5668fc0e	pcmcia_get_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x61ce1e70	pcmcia_loop_config
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x69a099d1	pcmcia_get_mac_from_cis
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x6b106dc0	pcmcia_read_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x742f5665	pcmcia_parse_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x853881ec	pcmcia_disable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x85d23b76	__pcmcia_request_exclusive_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x876c6fbf	pcmcia_loop_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x984b6cdb	pcmcia_request_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x999f6281	pcmcia_fixup_vpp
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x9f8ece53	pcmcia_map_mem_page
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xb8212998	pcmcia_register_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xda0f3a62	pcmcia_request_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xef1ad1bb	pcmcia_release_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xf0e5e243	pcmcia_write_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x212db8d2	pcmcia_socket_list
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x33359016	pcmcia_get_socket_by_nr
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x468b072d	pcmcia_parse_events
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x47cab305	pcmcia_socket_list_rwsem
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x6429ffc7	pcmcia_parse_uevents
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x64c44c09	pcmcia_reset_card
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x75a6fb60	pcmcia_put_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x81d537b7	pcmcia_unregister_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xa058800d	pccard_register_pcmcia
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcf97f3bd	dead_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xde4ad6d9	pcmcia_socket_class
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xde91b0ad	pcmcia_get_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xf78254a7	pcmcia_register_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0x93fd1886	pccard_static_ops
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0xb59601ea	pccard_nonstatic_ops
++EXPORT_SYMBOL drivers/platform/x86/intel_ips 0xf97d7d0e	i915_bpo_enabled
++EXPORT_SYMBOL drivers/platform/x86/intel_punit_ipc 0x3a0b563a	intel_punit_ipc_simple_command
++EXPORT_SYMBOL drivers/platform/x86/sony-laptop 0x5bb1e117	sony_pic_camera_command
++EXPORT_SYMBOL drivers/pps/pps_core 0x19f6c09e	pps_lookup_dev
++EXPORT_SYMBOL drivers/pps/pps_core 0x1b3f158a	pps_unregister_source
++EXPORT_SYMBOL drivers/pps/pps_core 0xc307f600	pps_register_source
++EXPORT_SYMBOL drivers/pps/pps_core 0xd1b9b420	pps_event
++EXPORT_SYMBOL drivers/ptp/ptp 0x151232c5	ptp_clock_event
++EXPORT_SYMBOL drivers/ptp/ptp 0x5e6681c8	ptp_find_pin
++EXPORT_SYMBOL drivers/ptp/ptp 0x80073b66	ptp_clock_register
++EXPORT_SYMBOL drivers/ptp/ptp 0x8fa77f2d	ptp_clock_index
++EXPORT_SYMBOL drivers/ptp/ptp 0xd5698174	ptp_clock_unregister
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x30bc43db	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x3d975320	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x50cfb950	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x53115109	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x57267467	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x77a3d35a	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x938fd89d	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xbff996f3	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xcbf8af76	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xe69af76e	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0x538bf710	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x026825b4	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x9d758a9b	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xae07cc82	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xfabe39ac	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x01a8063a	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x0ddff693	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x3f4bc66f	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x50120119	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x8e5ff614	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x9ab89312	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x9fdd3d17	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xad949815	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xba281b91	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xd0f2fd72	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xe73b25ee	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xfa25e47d	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0294b227	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x07073e45	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x093df805	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x12e4ff96	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x13c074f4	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1870e17a	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x18e7fbe6	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1cef6f9e	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2146aea5	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x21b53309	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x27a8029a	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2d3254d1	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x349e9468	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36239523	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3adee925	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3bcf5157	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x42cc6cd6	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x44fc00ee	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x461a8e1d	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4724e26b	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5236c381	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5303afb0	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5ccc441b	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x64d61f87	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x64eaa80a	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x67c7564a	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x702c3d12	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7eeb3cb9	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7fc068d8	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x87306420	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x892170d2	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8edd2620	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8ef2feb2	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9910ec72	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9da78331	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa9ddb25b	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbf4c89d5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc049a99f	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc1be63cc	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc2d88b6a	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc6b45c40	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xca5cf18e	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xcebab9b8	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd2e3b3e4	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdce9c573	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf43b63a7	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf92353e8	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf9f8977a	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfafb2852	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfba062fc	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x28f5c01f	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x388432af	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8aa95d8d	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xf3795e7d	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x0c110f9d	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0504378c	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1388f248	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1dce5fbe	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x225c5d63	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x228843d4	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x2812aeef	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x2c50ca91	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3052c669	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x325c2729	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3299996a	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x34c591db	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x386a5087	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3a8bc536	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3febab28	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x47a27535	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5c2b0d48	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x65cebae1	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6ec606f7	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7219ea5b	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x772c5c97	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7e2eb5d2	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x87e98b21	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8e904df8	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9372695f	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x95308484	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xab9d9339	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb2cbccac	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb473a13a	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc9101912	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdab048b3	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xde0ef9e4	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe2d2709d	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe43bb283	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe811490d	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe9700a0d	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfd20e20a	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x06a6c9ee	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x23d1941b	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x819010cb	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xbbffdab7	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xbd8cdd49	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xfb830749	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x01ee56f4	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x18a75903	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x1b9611e5	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x3fc88410	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x4eb8889a	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x65286ced	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x7f1656dd	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x8724600e	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xb8669044	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xb8c6425e	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xd0b44bb6	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xfe8a9001	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x1f55cd70	qlogicfas408_ihandl
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3c93d279	qlogicfas408_queuecommand
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3fd8cd71	qlogicfas408_detect
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x7101378d	qlogicfas408_biosparam
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x79a2b570	qlogicfas408_bus_reset
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x7fc17c32	qlogicfas408_abort
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xa614eb41	qlogicfas408_disable_ints
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xe76b3b20	qlogicfas408_get_chip_type
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf23fd8bc	qlogicfas408_info
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf2b95199	qlogicfas408_setup
++EXPORT_SYMBOL drivers/scsi/raid_class 0x1658d595	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/raid_class 0x53af71a9	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0x785d4823	raid_class_release
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x075a99e4	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x266cfd3e	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x67360b60	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x69061f3e	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7022a9e5	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x78875b40	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x88bcb0aa	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x958e572e	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xaaa73b56	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd675d665	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xe52366aa	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xe9268924	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xff6e7a32	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x08339db6	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1559196e	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x25eb1f54	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x28a6688c	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x293c78f0	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x3391f4b8	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x39abee32	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x46a66836	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5107444f	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x599d8cb7	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x62fdc395	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7203728e	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7d0e3d5b	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7d1ecc90	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x883533ec	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x89be810e	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x8a0c8bc5	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9152ab74	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x92bac403	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x93a4cc5c	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xba802c47	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc34e079e	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd8226e0a	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd93480b2	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe0999a85	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe9618fc9	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xea9be036	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf35ad9da	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf9e5b095	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x324b370c	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x4be3525f	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x7b6a7219	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x95ce1480	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xd00105f6	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x441e3c8c	srp_start_tl_fail_timers
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x74ae80b6	srp_rport_put
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xb5090b47	srp_rport_get
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xf3d96d7f	srp_reconnect_rport
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x5445a31c	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x6f5283e8	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x985be339	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xbd1276cb	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xe3974140	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xe88f4dda	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xf6dabccc	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x0c93ea6c	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0x0f4c05f1	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x17ff179c	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0x217c78dc	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x55eba0be	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x5c1235f2	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0x6049b68f	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x67a9835e	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0x6db739db	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0x8a09f531	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0xa7826c4d	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0xaafd7047	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0xb0f01c5b	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xc338baec	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0xc9c9b673	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0xd1ae1ff5	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xe9b25961	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0xf055874b	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0xfa8121ba	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0xfd6f7b52	ssb_dma_translation
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x02d4a052	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0f7b9ccf	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1622cd75	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x17de602d	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1d866825	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1fb289d2	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x398a043b	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x57f41697	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x5a3bc127	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x6c0707c0	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x6fd59c1a	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x713f127e	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x765c7a9f	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x77d6dd52	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x7e0cc54a	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x870eac4d	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x88bd9162	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x90acdd84	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa81b69fa	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xc59d6276	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xc7fb6d0c	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xceeacc4b	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe886b0da	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xfd13ae72	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xa8812f37	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xddcd31df	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x31d5e958	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x41716ff9	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xb676dd06	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xd91929b9	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xf74c94cd	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x339fb6d9	ade7854_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0xf807412f	ade7854_remove
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0xb37ada18	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0x9f196cc7	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0640d050	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x18d3faa0	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x25dea4e4	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2e5c7e3e	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x318b020c	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x34f6144f	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3b6e26ce	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3c8f1b60	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3d79d1a9	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x41088434	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x41d27435	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x430fd365	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4df9d7f4	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x506bb3a8	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5301bfaf	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x56cf386b	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5851e529	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5c6914e0	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6af900a4	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6f0a3c65	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x777da036	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7ee491db	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x87e8587f	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x88f19fb0	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8a304a34	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8a7767cc	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8b0a94cf	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8c186dce	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8db393a0	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8e8bf61b	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9008f375	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x92dd2c4a	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x94c95006	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9a784333	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9e1b345b	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9eae5e4d	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa0fb5ad7	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc0aa5b39	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc11beb73	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc55bbcb4	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc58e3ad0	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcd9eccf2	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd0caf93b	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd639d027	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd7c00727	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe12b31ae	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe8a3c55a	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xeca356e9	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xed559c20	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfb12492e	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x02804a64	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x046c098c	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x04d68624	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0996bc36	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x099c394a	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0f099f61	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x13b0fb5b	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1513bf12	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1d7a7e94	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1db0319b	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1ecf06a1	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2b00c049	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2c831c95	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2d24704e	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x39c23790	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3cb6f094	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x46e71977	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x47202b39	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4a7fd9dd	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4d8da2cf	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4dfc0501	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5d6f0dd6	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x61ea895d	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6ac7bb85	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6d06bd16	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x73c6ccc5	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x746ca686	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x76f878fc	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x79481750	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x80ec64d6	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x85ee9054	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8c4eb823	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8c996f2a	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8e4b3f14	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8e552713	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x913b0a5c	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x93bbae07	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9522b9f7	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9cf65eca	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9dc493c1	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xab453afc	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xadcaf3b3	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb9359e81	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xba9dab90	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbd779044	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc3d80c46	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcc905ffc	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcf15ccfe	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd84a8715	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdef50380	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe4951bf2	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe506f000	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe8c35fea	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xec0fddfc	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xff4a4853	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/unisys/visorbus/visorbus 0x515b800f	visorbus_get_device_by_id
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x06c02d3e	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x120b7831	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x129f0a7e	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4450b163	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x49df144e	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x502cddae	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x55bb9418	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x589c1a1d	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5e878f5c	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x65a66337	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x7932c1e1	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x7e1b99cd	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8491a649	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x9949ec61	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa7791b78	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb5ce0e9f	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb60b5314	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xba94c93d	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xcd0a1413	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd176a41f	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd35e5470	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd3b47d2b	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xdb753246	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe1bf4b0c	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe8fa4118	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe99925d1	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xebf6b3da	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf842d2e7	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x00657bc5	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x018a6fe2	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x06d427a8	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x07754c4c	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x07ae75eb	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0a836a22	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0e23d481	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1526bb54	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1a408ac4	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1dbd836d	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1e0c7cc8	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0x21668e97	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0x24bd4ea8	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2c90803d	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2f48796f	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x30f45f88	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3331ba9a	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x342c080c	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0x34e4010e	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3fb7e64c	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x40fb5a55	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x43553d6d	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x47eab3da	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x48e4d944	transport_init_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4960f0fd	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x49abecf0	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4fc2b322	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5285df96	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5476dbe1	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0x56695346	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x59fca58e	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5a26f9c3	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5a4ce54d	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5f675550	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0x610c5483	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x65eea97e	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6d7f1e18	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6e8aeeb5	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6efb327f	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7210ac60	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x75b9aac9	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x80699a7a	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x83a485ad	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8a1af3e1	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8d2c2016	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9166fc7b	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0x96db3e86	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0x97055c9a	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x97c1e625	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x99aa2fe2	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9d6188f0	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa29ddef1	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa77028e2	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb253c58c	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb76747a3	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb788cdaf	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb8b43087	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbe3a8ed8	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc2627d32	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0xca8d633c	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd839f36d	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd953f597	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0xda3a1678	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe9451905	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0xeb4bd1a9	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0xefa0d983	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0xefe80a91	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf66a0f8b	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfa3e3bea	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x1887763e	acpi_thermal_rel_misc_device_add
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x5007fc2c	acpi_parse_art
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x86c998e6	acpi_thermal_rel_misc_device_remove
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0xdf707fab	acpi_parse_trt
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0x7967e17a	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0x7a3aa5c7	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0x9e6d9864	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x1c3d20c0	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x23d0ad59	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x47cc5318	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x5bbecea3	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x691e8797	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x98e55df4	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xb0eab020	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xc01244a0	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xc6c894d7	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xdb08bd38	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xe54099c1	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xffe0f906	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x99ca4fac	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0xcfd6a15e	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3b304ebb	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3c71c418	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x4311cd91	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x5fedea44	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x97fa07e9	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xde804bb9	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x44fe5fee	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x778f457e	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x8b9d4cbf	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xc65075a4	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x2594a4d2	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ba857a0	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x79010f81	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x93ed8a7a	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xaafb6ae8	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe8bb6861	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe8bd6727	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/core/syscopyarea 0x4c4f5966	sys_copyarea
++EXPORT_SYMBOL drivers/video/fbdev/core/sysfillrect 0xf9b30ccf	sys_fillrect
++EXPORT_SYMBOL drivers/video/fbdev/core/sysimgblt 0x44986dbc	sys_imageblit
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0e8fb484	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0xa358eac0	mac_find_mode
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x604cc71f	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x86d41cec	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x9b6c3ebc	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x8e6cead5	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x92d8cd45	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xaabab231	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xacc057e6	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0xaef712bc	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0xdd38e78a	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x22c182bf	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x2b439674	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x2e2e6f26	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xf0932a8a	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0x1f17eca6	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xd9952f62	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x4e089be6	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xa69afda5	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xbac5c7e0	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xc5a94237	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcc8c01be	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0x296f0c97	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x41315461	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x5aaff41d	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xc98aa4ed	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xe2845823	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x47cfb34c	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x59964d77	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x55d0ceea	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x714b01f7	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/wire 0x1f7410d3	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x2972c17e	w1_register_family
++EXPORT_SYMBOL drivers/w1/wire 0x7560172a	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0x97bdcefb	w1_remove_master_device
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0x04e133fc	iTCO_vendor_check_noreboot_on
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xa78bd894	iTCO_vendor_pre_set_heartbeat
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xb5f20875	iTCO_vendor_pre_keepalive
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xc4f657bf	iTCO_vendor_pre_stop
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xdc6effc9	iTCO_vendor_pre_start
++EXPORT_SYMBOL fs/configfs/configfs 0x0060b3a6	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x0a9548e4	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x1567df3f	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0x18860b43	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x2f394b2c	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0x3cd678b8	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x5b2d7994	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0x70ba3ceb	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0x7ed3e100	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0x805598d9	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xa355c678	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xb7fd018f	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0xd01cbf55	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xd6989fbe	configfs_unregister_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0xe42b19f4	config_group_find_item
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x44dd8038	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x4b0e7cfe	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x4d4f838c	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x7b831320	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0x90ce1252	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xa7259ca0	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0xbe50522b	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0xdcaefe53	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0xe4df6077	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0xfb1ffe7e	ore_truncate
++EXPORT_SYMBOL fs/fscache/fscache 0x0561534e	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x07fd6762	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x100789ab	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x1bb09f26	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x26eb2a86	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x270c7b2c	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x27c838e0	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0x28954659	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0x2b0c4a5a	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0x3054e8a2	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0x32cc2af8	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x3351496e	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x3615090e	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x39beff38	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x3f4e2ec7	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x46e3bb8e	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x4bfc3c53	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x6475f2ae	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x65a456bb	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0x6750697f	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x6d77ad87	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x70f12dc0	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x73723678	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0x743ba2de	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x7612299a	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0x8c03888b	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x9bdf323e	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0xa07fa567	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xa90511c6	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xac9f469a	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xb0500948	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0xb51a85ca	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0xb5c284fc	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0xb5ec55b4	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0xbac6f7f3	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0xc9e3041c	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0xcc181d91	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0xd44f3e68	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0xf2537b91	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xfb831951	__fscache_check_consistency
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x29e8d935	qtree_read_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x738b9fd0	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x7d16f2f5	qtree_write_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xa27e1691	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0xea61ecf0	qtree_delete_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x1a703ba1	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0x6d356209	crc_itu_t
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc7 0x56329ecc	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd09b2cba	crc8
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x0641307b	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0x098d2ed9	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x175924ca	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x2d47ac83	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0x2f3dcecb	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0x4522d82a	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0x4cf5f5a8	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0x5752f31b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0x7257beee	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0x9134feb7	lc_get
++EXPORT_SYMBOL lib/lru_cache 0x94f2dbc7	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0xb672aa97	lc_create
++EXPORT_SYMBOL lib/lru_cache 0xbfbe53d5	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0xc3a98c1d	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcc979a91	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xefec290a	lc_find
++EXPORT_SYMBOL lib/lru_cache 0xfd525ec7	lc_put
++EXPORT_SYMBOL lib/lz4/lz4_compress 0x0c222eb5	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x682a23e0	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x1f817d5b	lowpan_netdev_setup
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x464895cb	lowpan_nhc_del
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xe7e9f87e	lowpan_nhc_add
++EXPORT_SYMBOL net/802/p8022 0x48f9be98	unregister_8022_client
++EXPORT_SYMBOL net/802/p8022 0xe944d237	register_8022_client
++EXPORT_SYMBOL net/802/p8023 0x1507bd68	make_8023_client
++EXPORT_SYMBOL net/802/p8023 0x492430ab	destroy_8023_client
++EXPORT_SYMBOL net/802/psnap 0x22cebab8	unregister_snap_client
++EXPORT_SYMBOL net/802/psnap 0xc027f835	register_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x006cdab7	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0x011cb620	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x1707aa54	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x1ab6d9b5	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x2aff5f27	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0x2ba0eee6	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0x2ce0fd55	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0x32d2f5f7	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x38ad26da	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x394bca22	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0x3aeaa2d6	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x4a5dc459	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x4c168203	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0x534cc3dd	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x54c0198e	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0x570c814c	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x5c908c74	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0x5fe8a423	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0x6774a217	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0x7165495c	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x74a1fae2	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x8b8d9d97	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0x8f76d88d	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x90f66a5c	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x9244fbfb	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x9f6791a6	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0xa91e4a66	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0xab59ddff	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0xac964400	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0xaec3dcff	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0xaf7952d6	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0xc02ce270	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xc357ac34	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0xc3aa5b4c	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xcd7d5caa	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0xcf5353ce	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xdb3bab36	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0xdb684998	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0xe12595bb	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xf0afdcda	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0xf12b79ec	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0xf2462acb	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x1e423269	atrtr_get_dev
++EXPORT_SYMBOL net/appletalk/appletalk 0x23e60a82	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0x791bffcc	aarp_send_ddp
++EXPORT_SYMBOL net/appletalk/appletalk 0xee5143e2	atalk_find_dev_addr
++EXPORT_SYMBOL net/atm/atm 0x0fbf9a22	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0x19bcb006	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x1e3ef96e	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x320bfe6c	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x3272b4b3	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0x340eaba6	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x54e02ec5	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0x6b9d1507	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0x8ddbfc86	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0x99b543dc	atm_charge
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xa6fb0f4c	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xba6abd27	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0xdbf8c265	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xe292d60f	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/ax25/ax25 0x100a2b8a	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x4da5ce36	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0x517eba95	ax25_ip_xmit
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x8662856e	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0x8fdc5f7e	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xcbcc2f57	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xd7351772	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0xd91b3abe	ax25_find_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x02682ef4	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x06d2eb77	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0b5c9bf8	bt_sock_wait_ready
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x134df408	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x15245e70	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x175ed68e	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1b2f3918	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1b374531	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x21566b48	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2e599ebb	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x31c235d2	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x37bf83f8	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4b276917	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x53686278	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x59a7466b	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x69483ab2	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x793e238c	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7a73518a	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7b30a442	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7c57b7b5	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x82e7aeda	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8464af7d	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x85c67c1e	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x94614ca6	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9b943abd	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9d73d1a5	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9f214b82	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa2e7db42	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa4157443	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xaa590995	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xabe0eda1	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0bcf5a8	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbc7242ff	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc4dd58b5	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xca7c288a	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd707254a	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xdba1c99d	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xdef49762	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xeb79c47a	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xefea7460	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xfce841a3	hci_register_cb
++EXPORT_SYMBOL net/bridge/bridge 0x1fef3c31	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x26b8292e	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x82381dd7	ebt_register_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x95d45ab7	ebt_do_table
++EXPORT_SYMBOL net/caif/caif 0x026657c6	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x8fecdac9	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x968b75cd	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xdd8c350f	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0xfddaad98	get_cfcnfg
++EXPORT_SYMBOL net/can/can 0x21e8ac05	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0x45d84cfb	can_proto_register
++EXPORT_SYMBOL net/can/can 0x6748167c	can_rx_register
++EXPORT_SYMBOL net/can/can 0xaf1c6697	can_proto_unregister
++EXPORT_SYMBOL net/can/can 0xbb2e6605	can_ioctl
++EXPORT_SYMBOL net/can/can 0xc1bc5144	can_send
++EXPORT_SYMBOL net/ceph/libceph 0x02c86417	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0x05d67882	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x07bccb5b	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0a0d9d6f	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x136cc6fa	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x1b07d62a	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x1bb1a0c8	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0x201877e4	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x212ab0ac	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x21c60751	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x23015b46	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x23fb3722	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0x24d897df	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x2764198b	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x2873411c	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x2caa7b94	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0x2d57f408	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0x2f4c7866	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0x33f1848e	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x38fcad3f	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x408b9bb0	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x4134a00e	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x419cb09b	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x4410e9fe	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0x445c8e48	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x46854978	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0x48ef7d57	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0x503cef02	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x514178bb	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x53cbf15d	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x53d7a8a1	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0x55623ca6	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x5f693b72	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x6325147f	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x65ee34d6	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0x6a0a2704	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6fabc1c0	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x6fcdafef	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0x70d231b4	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0x7788bd66	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x790d7335	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x79a265d6	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0x7bfb8e6b	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x7d447a15	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0x7dd2fd9d	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0x81f58f73	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0x84dec33e	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0x89212ab2	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0x8b769aac	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0x8c10d350	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0x90996d95	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0x93dbfeb6	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x944393c7	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x9506b25f	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9e848f44	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa776fb30	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0xa9b4246d	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0xaa3ca31d	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb12a64e2	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0xb507076b	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb6a0f5b2	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0xb7504440	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0xb8e28643	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0xb90c6a8b	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xbe87112b	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xc1e0d92f	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0xc3b16285	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc4d8459a	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc890f420	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd3654ddd	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xd7acd83f	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xdeda2e37	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xdfd1a866	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0xe0fd2ea2	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xe35af346	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xe3b042ca	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xe960ebc4	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0xeb966825	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0xf03fba7b	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0xf075b6e7	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0xf17f7f39	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0xf35cb4d9	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xf50f4c44	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0xf7b576a7	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0xf8c0d8e2	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0xf99e6e8b	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xfbf236cb	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xfd1b9234	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x379ab92b	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x8f85c762	dccp_req_err
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x1769766e	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x4171d87c	wpan_phy_find
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x55df503c	wpan_phy_new
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xd0ed9591	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xd1ca94b5	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xeb19c16c	wpan_phy_unregister
++EXPORT_SYMBOL net/ipv4/fou 0x3106aeb4	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0x8f56986b	fou_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xb51dd683	gue_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xd0750778	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x0f52718f	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x2728ac63	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x3242dc0a	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x91a62b9b	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xa548fbc8	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xed88d3d0	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x2e472fc6	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x863070c3	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xd975530f	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x117737d7	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xf6bc974d	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xffa9179d	ipt_do_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0xb64e6bdc	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/tunnel4 0xe145ab0c	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0x7682f596	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x4cbcad07	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x5bcb4c99	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x7c08d804	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xc9647a38	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x4132b18d	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x95d45bf9	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xdcfcb2fe	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x3e0335c2	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/tunnel6 0x8904db1b	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x8073b16b	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0xe33aadaf	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x0213bbd7	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x2a3ba727	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x30ad0f7c	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x5ea5493a	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x620a4898	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x62591a33	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xa7335b12	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xf72bdd21	ircomm_close
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x0963c24b	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0x09939c11	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x0d00cd59	iriap_close
++EXPORT_SYMBOL net/irda/irda 0x11b30524	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0x175a24f7	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x23bbc2ce	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0x24a8a459	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0x2a93a5c8	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0x2b432980	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x30d0fcef	irlap_close
++EXPORT_SYMBOL net/irda/irda 0x3284b1b0	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x3766d836	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x385847aa	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x3f8513f7	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46b00fdf	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x4f7c51b4	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0x523dd613	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0x577cab45	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x601e786a	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x6450c849	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x70a3f20f	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0x71100168	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7d643faa	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x98a8b3b4	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0x9ccbdfca	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0xa023ccb3	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xa13bf60e	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0xac3dc858	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0xaeeff2b5	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xb2559e1b	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0xb392e608	iriap_open
++EXPORT_SYMBOL net/irda/irda 0xb75feb3a	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xd214798a	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0xd6deeaae	irda_setup_dma
++EXPORT_SYMBOL net/irda/irda 0xd973e469	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xdc0196c2	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe1ba6308	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0xe329462a	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0xeaeb168e	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0xeb78333e	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0xec242b93	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xee747751	irlap_open
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x5aca7645	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0x6a45b006	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x1d387131	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0x31d9b4cc	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0x3f4f427d	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0x59ae5809	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0x66c8f45f	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0xbd5d5146	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0xc4dd4e02	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0xf04edc8a	lapb_connect_request
++EXPORT_SYMBOL net/llc/llc 0x04475363	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0x29e63cf8	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x398b6303	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0x401372f1	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x58e52504	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0x9c422412	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0xc3291f81	llc_sap_open
++EXPORT_SYMBOL net/mac80211/mac80211 0x02ca907f	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x02d9c0be	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x0340bab2	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x0b7e1249	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0x0bd609f2	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x0c1d770a	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x0d61561a	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x0ef70671	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0x13418469	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0x192f91f3	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0x197f937b	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x1c5a385d	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x203ce8fd	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0x207ad47e	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac80211/mac80211 0x210349d3	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x21dea6b2	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x27ed2841	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x2d51b6f5	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x2eeac4f0	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x30db55fe	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x3179a296	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0x3468a49e	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0x3c2d5714	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x419c0202	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x44ecb135	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x474f21f1	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0x4a086c5b	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0x4c2b011a	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0x4c53c81c	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x55f97e4f	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x58a1d7ef	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x5dc6a15a	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x603e5c0d	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x61de9768	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0x652527e8	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0x65f12cea	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x67355b7b	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x6982ec35	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x6ca282ff	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x6cc2610a	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x6f18aaf0	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x71a714e1	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x781a95cd	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0x796d3327	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x7a86eb57	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x7cd559a2	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x815e5189	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0x83153d6f	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x85bdb1e2	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x8acfea05	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x8e0d3396	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0x91e974e3	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x92dbcf04	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x95cf611f	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x9965d869	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x9d0fc03f	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xa1ce1962	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xa34e5fa2	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xa38427eb	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xaa2e9fee	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0xaa6dd0e8	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0xaa88f36e	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac80211/mac80211 0xab425556	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0xb4fe5233	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0xb55e9e7a	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0xb854a4e8	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xba4337fd	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0xbce3ea96	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xbe571749	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0xc291b69c	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0xc4e8aa6b	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0xc8eee485	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0xcdd639e7	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xd4fe9c8f	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72d2263	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xd82bee2d	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xddbe3ab9	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xdf796f60	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xe13b8f61	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0xe50b9fce	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xf0fb8e93	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0xf9d8f614	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac802154/mac802154 0x0316882d	ieee802154_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x14344f4c	ieee802154_register_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x61f1bf32	ieee802154_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x6cdbdd9a	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0xa3cfaad9	ieee802154_unregister_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xce1f9cde	ieee802154_alloc_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xe9669353	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0xf279fb1c	ieee802154_xmit_complete
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x0858b102	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x3073f9da	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x856b8546	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x97b663d1	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x9d17c56b	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb3829f84	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb90242fe	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xba7969ab	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xc7e26535	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd462ebfb	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd6c58ab8	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xf1c3be86	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xfa649726	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xfc84f80e	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x03c65b5e	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x29699191	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x29ec4119	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x25f45257	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x3b753b4f	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x6a535819	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/nf_nat 0x79cdacd3	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xc471e360	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0xe11ea506	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/x_tables 0x10908c7e	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x1ea066a3	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x253e8b44	xt_compat_init_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0x31292867	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x31d64108	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xa25fc115	xt_compat_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xaeaf1c68	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xd09649ea	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xd1e8e49e	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xd819a3e5	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xe1804ed1	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xec2eee14	xt_register_match
++EXPORT_SYMBOL net/nfc/hci/hci 0x01787370	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0x08b94748	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x0c53386a	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0x11d1f463	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0x13ac50fa	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x18f45e74	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x192a4e36	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0x20040ebb	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x2b272f46	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0x2f726cad	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x3434c4e4	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x533c5df1	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0x6195ddd3	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0x6d393578	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xaf9d18b5	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xcc141f13	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0xe7cda966	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xf050c260	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xf09c77f7	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0xf339ac1a	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0xf40d746b	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/nci/nci 0x0bbdab04	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0x0d5a36a1	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x23f347a6	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x2dfc10ba	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x2fc0922b	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0x31de50a4	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x39dc6698	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0x4693512d	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0x4b38db4f	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x58835f31	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nci/nci 0x70c6a5dc	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0x77c33be8	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x7e38fb07	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x7fec28b4	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0x863bd352	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x8b9900c5	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nci/nci 0x955a66a2	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0xa78540b6	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0xa8d5a631	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nci/nci 0xadd5135e	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0xaefd7332	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xc5d278e4	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xde3db4d7	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xe47b599c	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0xedd7efec	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0xeffc8a9b	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xf005cf51	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0xf178e74b	nci_free_device
++EXPORT_SYMBOL net/nfc/nfc 0x0886e857	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0x0ead5136	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x33c6971a	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x3513ba8a	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0x3a671d3d	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0x3f328c36	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0x43d70d56	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0x4cc57125	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0x50b8327a	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x5880ad5a	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0x593e8ee6	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0x7839ae13	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0x9ee54be3	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0xaf8d46e4	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0xb2b15f20	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0xb92361b6	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0xc7fe868b	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0xce836107	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0xdb27074a	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0xdd7c9cf7	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0xe8ff519e	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xeded2cff	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0xf44a6507	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc 0xfa7732c1	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc_digital 0x08b142d6	nfc_digital_unregister_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x3e892cf8	nfc_digital_free_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xc241a11d	nfc_digital_allocate_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xf9405e7b	nfc_digital_register_device
++EXPORT_SYMBOL net/phonet/phonet 0x15c394aa	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0x25417a18	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0x260f5fba	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0x3031aeed	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0x4eff4c07	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0x77c88a99	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0xc67540ba	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0xe7838d3e	phonet_proto_register
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x0431af01	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x0b6fff9e	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1ba4d814	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x5238efe7	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x54034039	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x62dc51e4	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x67c0ab91	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x78fee76f	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x7bee50a9	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb088b788	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xcb0be81e	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xda726a9b	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe1df11ad	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf033ee0a	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf4c87f81	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/sctp/sctp 0xb9238945	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x249ee440	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x754c6429	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xbc4080a8	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x95e3abf9	svc_pool_stats_open
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xb5d6beb1	xdr_truncate_encode
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xd1209d2f	xdr_restrict_buflen
++EXPORT_SYMBOL net/wimax/wimax 0x1948cb76	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0x47eeedd3	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x027a10b5	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0ac1b285	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x0f3e1b1b	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x15132275	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x19417522	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x1ba21403	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x1da9852d	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x1daf6642	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x1ecb5bc2	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x21ae7d6c	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x2697119f	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x2a2d2de7	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0x2c81e29a	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x3444cc9b	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0x3af9619d	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0x3be63138	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x41af163b	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x44d2dca6	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0x47c99d90	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x498170a9	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x527417bb	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x56d5fdb6	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0x57eaf886	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0x5b605e96	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x5ebd8e60	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x5f441f61	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x5f62004b	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0x60bd3c15	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x67cfcf51	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x68f01636	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x6f0912d8	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0x70501bbe	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0x70ba8e64	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x70d91e92	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x72ff2dd1	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x734e9564	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x7c624e5b	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1f42d	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x81106860	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x811e2427	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x83e2485a	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x8969fa56	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x8b02456c	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0x8f9a49a3	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x91d7a142	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x9c8efaa5	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x9f78285e	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xa05bd8c0	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa5b21a54	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xa7339db8	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xab8a63a4	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0xad816e47	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xaee421bb	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0xb0b7e6bb	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0xb13cdb5b	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xb83bb952	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xbe0d75e3	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0xc2182102	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0xc51838b9	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0xc5ad1042	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc7f8fddd	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xc9571d7b	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0xc9786cd9	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0xc98f6411	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0xc9a4d992	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xcc4e0f9a	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xd2f2e27c	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xd50b0a22	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xd838fe85	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0xd99434b9	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xda1f796d	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0xdaa07a83	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xdd7e3cf5	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0xe0d7f50a	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0xe2526365	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0xe560f888	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe70d835e	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0xea3b3870	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0xeaa83c60	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xef8cd6e4	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xf04a37fb	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0xf8f0b31f	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xfcce2451	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0xffb285f3	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/lib80211 0x144ebfa8	lib80211_crypt_info_free
++EXPORT_SYMBOL net/wireless/lib80211 0x34e4e04d	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x6c7f68df	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xa86f5b3d	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0xd01b1b6b	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xd41d70d5	lib80211_crypt_info_init
++EXPORT_SYMBOL sound/ac97_bus 0x464f8689	ac97_bus_type
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0xc6249a11	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x28ecae33	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x4dad1853	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6a2895cf	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xdc30e683	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x0bbe1288	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x205395a0	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x614705ff	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x7746bb9b	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x79794472	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x991c0f60	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xef8fa3d2	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xf3f0324e	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xf6fdda44	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0x37db47ed	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x083789e6	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0x1024a8ac	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0x11a37977	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0x12129d96	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0x16ca19e1	snd_jack_new
++EXPORT_SYMBOL sound/core/snd 0x172b2108	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0x18e1683f	snd_dma_program
++EXPORT_SYMBOL sound/core/snd 0x191e88cf	snd_dma_pointer
++EXPORT_SYMBOL sound/core/snd 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL sound/core/snd 0x220f9dbf	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x285a054f	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0x2a977a35	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0x2bb88428	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0x2e0bf201	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0x317545c1	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0x342a2354	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x3eb613b9	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0x4336eb82	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0x4395574c	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0x445aa287	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0x490b7a4f	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x4cbcde0c	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0x573662a7	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0x5c2ce190	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0x5cce0a8a	snd_cards
++EXPORT_SYMBOL sound/core/snd 0x5edc5646	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd 0x6050ae49	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0x669e1e28	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0x6dbdcf2e	snd_jack_add_new_kctl
++EXPORT_SYMBOL sound/core/snd 0x6ee2e42f	snd_ctl_register_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0x70c15ac1	snd_dma_disable
++EXPORT_SYMBOL sound/core/snd 0x76587904	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x85e79203	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0x862eca84	snd_unregister_oss_device
++EXPORT_SYMBOL sound/core/snd 0x87af9dc5	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0x898ef94a	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x9186a0c0	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0x9f85055a	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xa1694441	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0xa4f0b3e9	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0xa72358e7	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0xa7539bbb	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL sound/core/snd 0xa77df7c1	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0xaa02562c	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xc32a5144	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0xc3b6b337	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0xc6402e09	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0xd59f27c0	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0xeba8410e	snd_ctl_unregister_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0xedc902f5	snd_register_oss_device
++EXPORT_SYMBOL sound/core/snd 0xf0813dba	snd_card_new
++EXPORT_SYMBOL sound/core/snd 0xf5522000	snd_register_device
++EXPORT_SYMBOL sound/core/snd 0xfc1d8bc4	snd_device_new
++EXPORT_SYMBOL sound/core/snd 0xfffd89db	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd-hwdep 0x4ced144a	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x0297e85f	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0x035112f3	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x06b310c9	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x09248629	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0x0cfe5f4f	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x0d0e0db5	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0x1467da48	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x160edd03	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0x17a46296	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x2acf0df3	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0x2f040610	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0x2f897364	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0x33b1b6da	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x3b161509	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0x3b4f21a4	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x41f18fae	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x42afbf83	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x4c0d4a4a	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x55d754cd	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0x56e33055	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x5898dcba	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x5929d1d1	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x61979db7	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x69d9f11f	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x7bbe611e	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0x7f7d9a54	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0x834dc955	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x85fa0f9e	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0x8ace9682	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x8c2be957	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x9455099a	snd_pcm_sgbuf_ops_page
++EXPORT_SYMBOL sound/core/snd-pcm 0x957435b1	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0x98035409	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0x9aea8213	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xac22e325	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xb0981b74	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xb69372ae	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xbd7ba76e	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0xc8055964	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0xca34c226	snd_sgbuf_get_chunk_size
++EXPORT_SYMBOL sound/core/snd-pcm 0xcab45699	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0xccc4f9ce	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0xcffb39bc	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0xd46c6c88	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xdcb5c3ee	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xf131660f	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL sound/core/snd-pcm 0xf2a34727	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0xf4354c70	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xf8e3d66c	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0xf9965b7c	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-pcm 0xfd61adc0	snd_pcm_lib_mmap_iomem
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-pcm 0xffb57735	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x12ba29f7	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x1e60dccf	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x36a18bcf	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x3c914b34	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x42030508	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x49776e86	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x56088499	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x70a92d1a	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7c22c798	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x977dab67	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xa215b4ba	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xa4dbccca	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xa9935424	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb512750e	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xcf253066	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd222f21e	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd2f44fe9	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xdf009695	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xeb309c38	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-timer 0x118e5344	snd_timer_stop
++EXPORT_SYMBOL sound/core/snd-timer 0x32aa8e67	snd_timer_global_register
++EXPORT_SYMBOL sound/core/snd-timer 0x3f31280e	snd_timer_close
++EXPORT_SYMBOL sound/core/snd-timer 0x4b8f402a	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0x601e8f3d	snd_timer_start
++EXPORT_SYMBOL sound/core/snd-timer 0x68692372	snd_timer_new
++EXPORT_SYMBOL sound/core/snd-timer 0x6e6cedb8	snd_timer_interrupt
++EXPORT_SYMBOL sound/core/snd-timer 0x724915fb	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0xa59f325c	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0xba80d6da	snd_timer_pause
++EXPORT_SYMBOL sound/core/snd-timer 0xc04926fa	snd_timer_open
++EXPORT_SYMBOL sound/core/snd-timer 0xec525f98	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0xf8546ecb	snd_timer_resolution
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xfc4afa86	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x037a4fbf	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x0731eaae	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x2829a90b	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x48d5554f	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x6293e785	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x757a792a	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xbda00865	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xd3d3c0f0	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xd7dad577	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x04860ae5	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x200445ae	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x20ecc678	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x467e2481	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x59f134c1	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x65ecd7e4	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x74df90ad	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x7515df28	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xce062bf1	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x020ed703	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x0cabaf3a	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x19a0e4e2	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1b96203e	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x292d2dff	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3736f928	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3d94fdb9	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x47ba6046	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x56863c51	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5ed29f3c	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x75bc3e3c	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x76454b57	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x784655df	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7a6bc933	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7dfabb8d	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8e297667	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x99c39643	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9e74eb9c	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa63c665d	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa9264c8b	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xaaea7bce	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xae932164	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xb3a2ece1	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xbf18edfa	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xdab1be6f	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe4f08b7b	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe7f14418	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xed654cc4	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf1d8a3ef	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf3269058	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf59073e1	amdtp_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf9316d65	cmp_connection_establish
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x3ab1baa1	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x708362ea	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x00c4c058	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x0218effb	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x0b4ebe14	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x18180bd0	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x2c059cb1	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x9cd03c4d	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xc20f714b	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xe4e07d32	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x0daccb1d	snd_ak4117_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x406eb46a	snd_ak4117_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x7b9021af	snd_ak4117_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xb6e50dc9	snd_ak4117_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xdbe74b6a	snd_ak4117_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xfadcc40a	snd_ak4117_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x07e3f2be	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x459f4a60	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x88178e82	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xed2dccdc	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x6f7e764e	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x8972782e	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x115b39ea	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x13ef0258	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x72e8f7eb	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x800580d4	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x8b784c07	snd_cs8427_init
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xb775eca1	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x01dffd65	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xc71fbf14	snd_i2c_device_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xd6a73bef	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xdf8d9761	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xe727cc03	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xfc319266	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x00103977	snd_sbmixer_read
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x2cc41d88	snd_sbmixer_add_ctl
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x45b28261	snd_sbmixer_suspend
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x4990dee9	snd_sbdsp_command
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x57428566	snd_sbdsp_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x6517da25	snd_sbmixer_write
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x7918485c	snd_sbdsp_get_byte
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xc5765b51	snd_sbmixer_resume
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xc596b50b	snd_sbmixer_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xc8c99e5f	snd_sbdsp_reset
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x04df590d	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x28ba47e9	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3106a447	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x33b53104	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x51d9aa34	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x543eb3df	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x6262c4c7	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x7a480cdc	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x80d9e00c	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb9bb29a8	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xbfeea60a	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xc3f1b13f	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xe0d146fc	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xec72447e	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xec90b478	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xee7a9fcb	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xfb9574f8	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/asihpi/snd-asihpi 0x94dac707	hpi_send_recv
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x07692b30	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x17fa0f6c	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x210ebcb9	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x230f02d8	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x28b2c49d	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x9bcca925	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xd33c983f	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xe6e2dd4b	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xfc368de4	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x47eb9adc	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x57ebe73f	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xc1c21304	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x11e11c7e	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x1991a5f7	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x3301994d	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x3f363943	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x457cdebe	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x45afef84	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x4af04dbf	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x5203223c	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x62d44476	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x65508561	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x85801122	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb7def749	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb969991f	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc3a4a159	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc3c6228b	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xe101d176	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xe6081dcc	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xe9620522	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xee9b3c6c	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf80dee54	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xfbc8b9c3	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x33c0110d	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x88289475	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x90d4891e	snd_trident_free_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xa2b8248f	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xedf64d6b	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x42c82f7a	tlv320aic23_probe
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0xbe894576	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/intel/common/snd-soc-sst-dsp 0x36d294bb	sst_dma_new
++EXPORT_SYMBOL sound/soc/intel/common/snd-soc-sst-dsp 0xdc045797	sst_dma_free
++EXPORT_SYMBOL sound/soc/snd-soc-core 0x7763e0fa	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL sound/soundcore 0x0c2aa5aa	sound_class
++EXPORT_SYMBOL sound/soundcore 0x3efff1e1	register_sound_special_device
++EXPORT_SYMBOL sound/soundcore 0x77912045	register_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x8e02b660	register_sound_midi
++EXPORT_SYMBOL sound/soundcore 0x98a03595	register_sound_special
++EXPORT_SYMBOL sound/soundcore 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL sound/soundcore 0xa2d36ef5	register_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x2be2de8a	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x7c661e47	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xae742ffd	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xb0912db1	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xc5c0a011	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xfa9f69f6	snd_emux_register
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x4b1521d2	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x7efdf912	snd_util_memhdr_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x9a6380a1	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xba294bfc	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xcb687579	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xd4a87146	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xe1eb6709	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xe20b233d	__snd_util_mem_free
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x187560d0	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL ubuntu/hio/hio 0x14e2b9e3	ssd_get_temperature
++EXPORT_SYMBOL ubuntu/hio/hio 0x36cf031e	ssd_submit_pbio
++EXPORT_SYMBOL ubuntu/hio/hio 0x5622407c	ssd_register_event_notifier
++EXPORT_SYMBOL ubuntu/hio/hio 0x597c4ae7	ssd_unregister_event_notifier
++EXPORT_SYMBOL ubuntu/hio/hio 0x6e1247b6	ssd_get_version
++EXPORT_SYMBOL ubuntu/hio/hio 0x7a9a6c1e	ssd_set_wmode
++EXPORT_SYMBOL ubuntu/hio/hio 0x7cc0f661	ssd_get_pciaddr
++EXPORT_SYMBOL ubuntu/hio/hio 0x991e5618	ssd_get_label
++EXPORT_SYMBOL ubuntu/hio/hio 0xb06b2419	ssd_set_otprotect
++EXPORT_SYMBOL ubuntu/hio/hio 0xdac6c999	ssd_bm_status
++EXPORT_SYMBOL ubuntu/hio/hio 0xeda35a76	ssd_reset
++EXPORT_SYMBOL ubuntu/opennsl/linux-bcm-knet 0x05450fc9	bkn_filter_cb_register
++EXPORT_SYMBOL ubuntu/opennsl/linux-bcm-knet 0x54c30906	bkn_tx_skb_cb_register
++EXPORT_SYMBOL ubuntu/opennsl/linux-bcm-knet 0x7c878071	bkn_tx_skb_cb_unregister
++EXPORT_SYMBOL ubuntu/opennsl/linux-bcm-knet 0x9d1e8257	bkn_filter_cb_unregister
++EXPORT_SYMBOL ubuntu/opennsl/linux-bcm-knet 0x9e25de11	bkn_rx_skb_cb_unregister
++EXPORT_SYMBOL ubuntu/opennsl/linux-bcm-knet 0xaa63bd12	bkn_rx_skb_cb_register
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0x0b5382e1	lkbde_dev_instid_set
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0x0f2744ab	lkbde_dev_instid_get
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0x1a60fb89	lkbde_get_dma_info
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0x1bcd46ff	lkbde_get_hw_dev
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0x29805c13	___strtok
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0x29a863d1	lkbde_get_dev_phys_hi
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0x2ebd13e4	lkbde_irq_mask_get
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0x514ea590	lkbde_get_dev_phys
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0x6409c305	linux_bde_create
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0xb5692429	lkbde_irq_mask_set
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0xb8f8dc3d	lkbde_get_dev_virt
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0xc36868a4	lkbde_get_dev_resource
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0xccfba9a2	lkbde_get_dma_dev
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0xd558f821	kmalloc_giant
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0xd63cc59b	kfree_giant
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0xee9c1bd4	strtok
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0xf0338bb1	linux_bde_destroy
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0xf06cd208	lkbde_dev_state_get
++EXPORT_SYMBOL ubuntu/opennsl/linux-kernel-bde 0xf3ad288d	lkbde_dev_state_set
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x00322056	VBoxGuest_RTMpCpuIdFromSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x01674ab7	VBoxGuest_RTSemMutexRequestNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0429a6f0	VBoxGuest_RTThreadCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x057fd386	VBoxGuest_RTR0MemObjLockKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0731e88d	VBoxGuest_RTAssertMsg2Add
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x079b132d	VBoxGuest_RTMemTmpAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x08ed98db	VBoxGuest_RTMemDupExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x09a88bc3	VBoxGuest_RTTimeExplode
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0a442050	VBoxGuest_RTAssertAreQuiet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0b94344b	VBoxGuest_g_pszRTAssertExpr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0beb235d	VBoxGuest_RTMpIsCpuWorkPending
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0cd1b64d	VBoxGuest_RTMpCurSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0d10d1ca	VBoxGuest_RTTimeNormalize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0f3e114a	VBoxGuest_RTSemSpinMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0f884b3a	VBoxGuest_RTStrToInt64Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x11ced39a	VBoxGuest_RTSemEventWaitEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x11e95d2e	VBoxGuest_RTLogLoggerEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x11f80121	VBoxGuest_RTSemMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x12614b82	VBoxGuest_RTStrToInt8Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x12f430f3	VBoxGuest_RTAssertMsg2AddV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x147206e1	VBoxGuest_RTStrToUInt64
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x151752ec	VBoxGuest_RTHeapSimpleGetFreeSize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1520b2c8	VBoxGuest_RTLogCreateEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x160b14d4	VBoxGuest_RTMpGetPresentSet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1926b25c	VBoxGuest_RTLogRelLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x19790b4c	VBoxGuest_RTLogFlags
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x197acd65	VBoxGuest_RTR0Init
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1a6d7d86	VBoxGuest_RTThreadPreemptIsEnabled
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1ae28abb	VBoxGuest_RTThreadIsSelfAlive
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1c3b0f90	VBoxGuest_RTR0MemObjAddressR3
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1dc5ebbe	VBoxGuest_RTThreadWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1f3e577b	VBoxGuest_RTMemTmpAllocZTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1f70d065	VBoxGuest_RTErrConvertToErrno
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2003169b	VBoxGuest_RTSpinlockAcquire
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x20728ae6	VBoxGuest_RTThreadCreateV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x20d9d625	VBoxGuest_RTTimeToString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x22058511	VBoxGuest_RTSemMutexRequestDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2254228b	VBoxGuest_RTMpGetPresentCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2387f039	VBoxGuest_RTMpIsCpuPresent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x25219f5e	VBoxGuest_RTR0Term
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2580d04c	VBoxGuest_RTSemEventMultiSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2632a013	VBoxGuest_RTLogRelLoggerV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x29708cf0	VBoxGuest_RTR0MemUserCopyTo
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2a2284fb	VBoxGuest_RTAssertMayPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2af3453c	VBoxGuest_RTLogPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2c2b5b46	VBoxGuest_RTTimerGetSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2cfefa48	VBoxGuest_RTLogBackdoorPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2d445217	VBoxGuest_RTStrToInt64Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2d581c06	VBoxGuest_RTMpCurSetIndexAndId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2eca7777	VBoxGuest_RTHeapSimpleAlloc
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2fb7502f	VBoxGuest_RTThreadSetName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x30e40c69	VBoxGuest_RTLogSetDefaultInstanceThread
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3168cadf	VBoxGuest_RTTimeSystemMilliTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x31ac4c5f	VBoxGuest_RTThreadIsInitialized
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x33d7313a	VBoxGuest_RTMpCpuId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x343e3e1b	VBoxGuest_RTLogGetDestinations
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3480f453	VBoxGuest_RTSemMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x358153bb	VBoxGuest_RTStrCopy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x362275e8	VBoxGuest_RTMemContFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x372d5e29	VBoxGuest_RTPowerNotificationDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x376d539c	VBoxGuest_RTThreadGetType
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x381d7c24	VBoxGuest_RTMemAllocVarTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x383a0b9d	VBoxGuest_RTMpPokeCpu
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3a47392e	VBoxGuest_RTErrConvertFromErrno
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3b04381e	VBoxGuest_RTSemEventMultiReset
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3b231c95	VBoxGuest_RTTimeNanoTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3bcf543a	VBoxGuest_RTLogGetDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3d00f113	VBoxGuest_g_u32RTAssertLine
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3de43f66	VBoxGuest_RTSemEventCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3dfc9ab8	VBoxGuest_RTSemMutexIsOwned
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3fbf3c07	VBoxGuest_RTThreadIsInInterrupt
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x40996438	VBoxGuest_RTSemEventMultiWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x42ecc6d1	VBoxGuest_RTThreadPreemptRestore
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x43fdd8d9	VBoxGuest_RTSemFastMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x44cfbc28	VBoxGuest_RTThreadGetNative
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x461fa9fe	VBoxGuest_RTLogRelGetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x46c14223	VBoxGuest_RTLogSetCustomPrefixCallback
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x49f1be17	VBoxGuest_RTThreadFromNative
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x49f4d19c	VBoxGuest_RTLogDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4ba5006e	VBoxGuest_RTLogPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4bbec091	VBoxGuest_RTR0MemObjGetPagePhysAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4c7d8a56	VBoxGuest_RTSemEventMultiCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4cac3157	VBoxGuest_RTLogFormatV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4cecc93d	VBoxGuest_RTR0MemObjEnterPhysTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4cf913a1	VBoxGuest_RTThreadGetName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4ea67110	VBoxGuest_RTStrToInt32
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4f041d39	VBoxGuest_RTMemContAlloc
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4fc8e10c	VBoxGuest_RTMpGetSet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4fe9e5f1	VBoxGuest_RTR0MemObjProtect
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5040043b	VBoxGuest_RTSemEventWaitExDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x508bb2c4	VBoxGuest_RTLogSetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x51ec28bd	VBoxGuest_RTLogGetFlags
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x53265abc	VBoxGuest_RTLogSetBuffering
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5352c915	VBoxGuest_RTSemMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x54098f34	VBoxGuest_RTTimerStop
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x54ddf87c	VBoxGuest_RTThreadPreemptIsPossible
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5595fc22	VBoxGuest_RTSpinlockDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x56596e82	VBoxGuest_RTThreadSelfName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x56c939fe	VBoxGuest_RTAssertMsg1
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5847ae52	VBoxGuest_RTMpGetCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x58d1b65e	VBoxGuest_RTThreadPreemptIsPending
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x598d3622	VBoxGuest_RTAssertMsg2AddWeak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5a97195c	VBoxGuest_RTHeapSimpleRelocate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5aa6ed66	VBoxGuest_RTPowerSignalEvent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5b3a5164	VBoxGuest_RTLogWriteUser
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5cc0b1b2	VBoxGuest_RTProcSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5d3b1bd6	VBoxGuest_RTSemSpinMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5e071eb3	VBoxGuest_RTSemEventMultiDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5e17b70e	VBoxGuest_RTSpinlockRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5e75c570	VBoxGuest_RTStrToUInt16
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5eaea89a	VBoxGuest_RTSemFastMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5ee65bb7	VBoxGuest_RTStrToUInt16Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5ef42fe5	VBoxGuest_RTTimerStart
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5f2f48bb	VBoxGuest_RTLogWriteStdErr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x61143878	VBoxGuestIDCCall
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6173b384	VBoxGuest_RTMpOnPairIsConcurrentExecSupported
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x61770e8c	VBoxGuest_RTStrToUInt32
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x63378722	VBoxGuest_RTLogBackdoorPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x634946f7	VBoxGuest_RTMpIsCpuOnline
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x637a1d69	VBoxGuest_RTLogWriteStdOut
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6381bb97	VBoxGuest_RTStrFormat
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x63b1fde6	VBoxGuest_RTMpCpuIdToSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x63bc10b0	VBoxGuest_RTLogCreateExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x658cd915	VBoxGuest_RTR0MemObjFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x67135d2b	VBoxGuest_RTSemFastMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6862822a	VBoxGuest_RTHeapSimpleSize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x695d63ad	VBoxGuest_RTMpNotificationDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6b01bbf3	VBoxGuest_RTMpOnSpecific
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6b58b79d	VBoxGuest_RTSemSpinMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6b91f1ce	VBoxGuest_RTStrFormatTypeDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6c8460ac	VBoxGuest_RTLogRelGetDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6cec7c3b	VBoxGuest_RTTimerCreateEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6d8e9c87	VBoxGuest_RTTimeNow
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6e8541b7	VBoxGuest_RTAssertMsg2Weak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x704e1f6f	VBoxGuest_RTAssertMsg2AddWeakV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x70867323	VBoxGuest_RTStrToUInt8Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x71060970	VBoxGuest_RTStrToUInt16Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x716e3be3	VBoxGuest_RTMpGetOnlineCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x729cc4ab	VBoxGuest_RTR0MemObjSize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x72ff1bc3	VBoxGuest_RTTimeIsLeapYear
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x730a01b0	VBoxGuest_RTLogRelSetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x74812dde	VBoxGuest_RTStrToInt32Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x759e7492	VBoxGuest_RTSemFastMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x764ecb18	VBoxGuest_RTR0MemObjAllocLowTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x76a3c47b	VBoxGuest_RTMemAllocZVarTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x79d59e24	VBoxGuest_RTSemSpinMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7d0d9dae	VBoxGuest_RTR0MemObjAllocPhysNCTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7d15e878	VBoxGuest_RTMpGetOnlineSet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7dcc30d8	VBoxGuest_RTStrToInt32Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7e29739a	VBoxGuest_RTStrToInt16
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7f0a40ea	VBoxGuest_RTLogComPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7fc5bdcf	VBoxGuest_RTR0MemObjAllocPhysTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8196c4e6	VBoxGuest_RTSemSpinMutexTryRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x82e081bc	VBoxGuest_RTStrFormatTypeSetUser
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x83e78406	VBoxGuest_RTR0MemAreKrnlAndUsrDifferent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x841e42e9	VBoxGuest_RTSemMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8484a0d6	VBoxGuest_RTStrToInt16Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x84e227f6	VBoxGuest_RTThreadIsSelfKnown
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x86120100	VBoxGuest_RTLogDumpPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x867be0d2	VBoxGuest_RTLogDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x868b79a5	VBoxGuest_RTStrPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x879761cf	VBoxGuest_RTR0MemObjAllocPhysExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x87da3860	VBoxGuest_RTAssertSetQuiet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8826d9de	VBoxGuest_RTMpGetMaxCpuId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x883d496c	VBoxGuest_RTMpGetCoreCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x885274fe	VBoxGuest_RTThreadUserWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x89117f68	VBoxGuest_RTMemExecAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8a3c154f	VBoxGuest_RTR0MemObjLockUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8a454b31	VBoxGuest_RTSemEventGetResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8e01e3fd	VBoxGuest_RTStrFormatV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8f1309e3	VBoxGuest_RTAssertMsg2
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x90312938	VBoxGuest_RTStrToUInt64Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x91204a9b	VBoxGuest_RTTimeSpecToString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x916e42f0	VBoxGuest_RTAssertMsg1Weak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9264ffc0	VBoxGuest_RTLogRelPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x926bf9f7	VBoxGuest_RTThreadPreemptDisable
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x92e716ae	VBoxGuest_RTLogGetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x94f7365f	VBoxGuest_RTPowerNotificationRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x95fa480d	VBoxGuest_RTSpinlockCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x961772f3	VBoxGuestIDCOpen
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x967ea4b6	VBoxGuest_RTStrToInt64
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x96893ce3	VBoxGuest_RTR0MemObjAllocPageTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x96f2e65b	VBoxGuest_RTR0MemUserCopyFrom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9796440b	VBoxGuest_RTSemEventWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x97eb2414	VBoxGuest_RTThreadNativeSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9874cd16	VBoxGuest_RTMpIsCpuPossible
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9909ff3d	VBoxGuest_g_pszRTAssertFunction
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9a2ee747	VBoxGuest_RTSemEventDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9bcc539d	VBoxGuest_RTThreadUserReset
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9cd9213f	VBoxGuest_RTR0MemKernelIsValidAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9d6b527c	VBoxGuest_RTThreadWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9dbd63d6	VBoxGuest_RTStrPrintfEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9eaecd9d	VBoxGuest_RTStrPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9f301085	VBoxGuest_RTTimeSpecFromString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9f4f616a	VBoxGuest_RTLogLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9fb0596d	VBoxGuest_RTMemDupTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa168a070	VBoxGuest_RTLogLoggerExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa34eb1b3	VBoxGuest_RTTimeSystemNanoTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa486e710	VBoxGuestIDCClose
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa554bd97	VBoxGuest_RTLogFlushRC
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa5a26703	VBoxGuest_RTMpNotificationRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa696baed	VBoxGuest_RTR0MemObjAddress
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa6a22472	VBoxGuest_RTThreadUserWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa6de1bcd	VBoxGuest_RTTimerChangeInterval
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa86c5a96	VBoxGuest_RTSemEventSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xaba9bc9c	VBoxGuest_RTLogCloneRC
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xac990d74	VBoxGuest_RTTimerCanDoHighResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xacaac41d	VBoxGuest_g_szRTAssertMsg1
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xad4fdf4e	VBoxGuest_RTSemMutexRequestNoResumeDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xad649089	VBoxGuest_RTStrToUInt64Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xae3e0ecd	VBoxGuest_RTLogRelPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xaf6ffbfc	VBoxGuest_RTThreadSleep
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb05840a7	VBoxGuest_RTSemEventMultiWaitExDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb1cc9148	VBoxGuest_RTLogWriteCom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb42ea0e3	VBoxGuest_g_pszRTAssertFile
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb444f4a1	VBoxGuest_RTLogDestinations
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb6941b2e	VBoxGuest_RTStrToUInt8
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb8c6e615	VBoxGuest_RTStrToUInt32Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb8ca8fcb	VBoxGuest_RTMpOnPair
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb8df2b3a	VBoxGuest_RTAssertShouldPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb9b070b7	VBoxGuest_RTAssertMsg2V
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb9d7a27d	VBoxGuest_RTHeapSimpleDump
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbaa97421	VBoxGuest_g_szRTAssertMsg2
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbb1ead73	VBoxGuest_RTR0MemKernelCopyTo
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbba928e6	VBoxGuest_RTHeapSimpleGetHeapSize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbc4d30f6	VBoxGuest_RTR0MemObjAllocContTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbc85935a	VBoxGuest_RTR0MemKernelCopyFrom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbe4e6114	VBoxGuest_RTLogFlushToLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbffedb55	VBoxGuest_RTMemAllocExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc1095c44	VBoxGuest_RTTimeImplode
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc1b3ada4	VBoxGuest_RTAssertMsg2WeakV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc3a1e5de	VBoxGuest_RTLogGetGroupSettings
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc3fee96e	VBoxGuest_RTMemAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc4bd5fd8	VBoxGuest_RTStrPrintfExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc63cc2f0	VBoxGuest_RTR0MemExecDonate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc71362b7	VBoxGuest_RTLogRelSetBuffering
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc8fbf4aa	VBoxGuest_RTHeapSimpleInit
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc91cea98	VBoxGuest_RTStrCopyEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc9a6a8e7	VBoxGuest_RTThreadCreateF
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xcaee97bf	VBoxGuest_RTLogComPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xcb2a6b54	VBoxGuest_RTMemExecFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xceae9d6a	VBoxGuest_RTStrConvertHexBytes
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd14e8ec2	VBoxGuest_RTTimerDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd1f3f0b9	VBoxGuest_RTSemEventWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd2a37e73	VBoxGuest_RTTimerReleaseSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd2d290ab	VBoxGuest_RTStrToUInt8Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd3a125cb	VBoxGuest_RTR0MemObjMapKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd46c35d4	VBoxGuest_RTMpOnAll
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd4b597fc	VBoxGuest_RTStrCopyP
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd5bfc897	VBoxGuest_RTHeapSimpleAllocZ
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd637869e	VBoxGuest_RTMemReallocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd69bc8e4	VBoxGuest_RTR0MemObjReserveUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd706d85c	VBoxGuest_RTTimeFromString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd88c9330	VBoxGuest_RTLogLoggerV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd984a7f4	VBoxGuest_RTStrFormatTypeRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdc700594	VBoxGuest_RTSemEventMultiGetResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xde9ca744	VBoxGuest_RTThreadYield
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdfbc69bb	VBoxGuest_RTThreadPreemptIsPendingTrusty
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe054d759	VBoxGuest_RTMemTmpFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe095cef8	VBoxGuest_RTThreadSetType
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe0dc7391	VBoxGuest_RTThreadIsMain
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe1c6b3d7	VBoxGuest_RTR0MemObjMapKernelExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe2765c54	VBoxGuest_RTR0AssertPanicSystem
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe38d562c	VBoxGuest_RTStrFormatNumber
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe3fd228f	VBoxGuest_RTTimeMilliTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe7e42113	VBoxGuest_RTThreadSleepNoLog
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe88dae73	VBoxGuest_RTMemFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe8fad285	VBoxGuest_RTSemEventMultiWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xea2f2944	VBoxGuest_RTStrToInt8Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xea38e4f7	VBoxGuest_RTLogDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xea71842b	VBoxGuest_RTMpGetPresentCoreCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xebeefa0e	VBoxGuest_RTR0ProcHandleSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xec3cc9a6	VBoxGuest_RTSemEventMultiWaitEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xee774b8e	VBoxGuest_RTLogWriteDebugger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xeea4ee73	VBoxGuest_RTR0MemObjMapUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xef6e1359	VBoxGuest_RTMpOnOthers
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf02f22ab	VBoxGuest_RTMemAllocZTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf0dbb702	VBoxGuest_RTHeapSimpleFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf26294bb	VBoxGuest_RTR0MemObjIsMapping
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf2aa79bb	VBoxGuest_RTThreadUserSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf3943009	VBoxGuest_RTTimerRequestSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf5d89855	VBoxGuest_RTLogGroupSettings
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf69aec24	VBoxGuest_RTStrToInt16Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf7397dd2	VBoxGuest_RTAssertSetMayPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf8113d66	VBoxGuest_RTMpOnAllIsConcurrentSafe
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf956a4e8	VBoxGuest_RTLogFlush
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf958d9cb	VBoxGuest_RTLogCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfa7d95c9	VBoxGuest_RTR0MemUserIsValidAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfb31e12b	VBoxGuest_RTStrToUInt32Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfba93ac9	VBoxGuest_RTR0MemObjReserveKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfbc67e88	VBoxGuest_RTMemFreeEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfe72cef7	VBoxGuest_RTStrToInt8
++EXPORT_SYMBOL vmlinux 0x001243fe	nvdimm_namespace_common_probe
++EXPORT_SYMBOL vmlinux 0x00297107	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0x00315742	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0x0046e701	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x004aa21f	__module_get
++EXPORT_SYMBOL vmlinux 0x0055cbe6	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x005cf447	param_set_ullong
++EXPORT_SYMBOL vmlinux 0x0070cd1f	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x007440c7	nf_register_hook
++EXPORT_SYMBOL vmlinux 0x0078d677	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0x0085e1f1	__do_once_done
++EXPORT_SYMBOL vmlinux 0x00947ed3	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0x00b8c3a7	mempool_alloc
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x0112b0ae	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0x011f0be2	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0x0125b495	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x013c8469	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0x016bba17	x86_hyper_ms_hyperv
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x019b70bc	set_disk_ro
++EXPORT_SYMBOL vmlinux 0x01a7997a	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0x01a856a9	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x01b8ac7c	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x01d633da	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x01d83e02	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x020589b3	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x02131d27	dquot_commit
++EXPORT_SYMBOL vmlinux 0x02337d87	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x02349608	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0x0237b57a	arch_unregister_cpu
++EXPORT_SYMBOL vmlinux 0x024bf827	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x02504539	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02d2497f	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0x02e25038	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x031be92c	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0x0326165b	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0x03288483	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x033345e2	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x035396e0	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x03913774	dquot_resume
++EXPORT_SYMBOL vmlinux 0x03aa2dd2	mdiobus_write
++EXPORT_SYMBOL vmlinux 0x03c6a779	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0x03d9c5b8	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0x03e24c3b	down_write_trylock
++EXPORT_SYMBOL vmlinux 0x03ee5b33	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x0416d6b9	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x0426ba24	idr_for_each
++EXPORT_SYMBOL vmlinux 0x0438b65d	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0x04392a9c	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x045f13cd	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x047129f7	module_refcount
++EXPORT_SYMBOL vmlinux 0x04820a31	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x048a273a	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x04b197f2	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x04b448ed	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0x04c62fd7	__memset
++EXPORT_SYMBOL vmlinux 0x04d8c750	release_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0x04d99b00	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0x04e6b9ce	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04ea5d10	ksize
++EXPORT_SYMBOL vmlinux 0x04f49cb4	pnp_request_card_device
++EXPORT_SYMBOL vmlinux 0x050877b9	dmi_first_match
++EXPORT_SYMBOL vmlinux 0x05190745	get_cached_acl
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x052fc500	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0x05303b87	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0x0542744b	build_skb
++EXPORT_SYMBOL vmlinux 0x055ad4b4	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0x055c8559	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x056530ce	revert_creds
++EXPORT_SYMBOL vmlinux 0x056562f6	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0x0574b9d3	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0x057c4088	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x05868bc0	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x05a1bdf2	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0x05a512db	bdget_disk
++EXPORT_SYMBOL vmlinux 0x05f4f470	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0x06052f8d	__memmove
++EXPORT_SYMBOL vmlinux 0x06073585	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0x0611a26b	inet_getname
++EXPORT_SYMBOL vmlinux 0x0615b2fa	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x061f4039	acpi_get_table_with_size
++EXPORT_SYMBOL vmlinux 0x0623743b	proc_douintvec
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x063ee507	pnp_possible_config
++EXPORT_SYMBOL vmlinux 0x06688789	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x0688bf03	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0x068c7263	ioremap_cache
++EXPORT_SYMBOL vmlinux 0x068c9995	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x06a61158	unregister_nls
++EXPORT_SYMBOL vmlinux 0x06a75635	bdi_destroy
++EXPORT_SYMBOL vmlinux 0x06c0dae5	__kernel_fpu_end
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x06ffde99	kernel_listen
++EXPORT_SYMBOL vmlinux 0x071d1650	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0x0727c4f3	iowrite8
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x0784fa6e	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x07861e48	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x078822e4	gen_pool_create
++EXPORT_SYMBOL vmlinux 0x07893c9c	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x07a4b576	flex_array_free
++EXPORT_SYMBOL vmlinux 0x07a5621f	copy_from_iter
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07a9ef84	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x07c73a38	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07eb3909	__inode_permission
++EXPORT_SYMBOL vmlinux 0x08030785	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0x0812e60e	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x08316b23	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x0855cf60	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0x08603cd0	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0x0897287b	acpi_disable_all_gpes
++EXPORT_SYMBOL vmlinux 0x08975d6e	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x08a97504	compat_sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x08b8ddf1	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0x08cbb38a	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x08d41d3f	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x0915d9f5	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x092a6a69	have_submounts
++EXPORT_SYMBOL vmlinux 0x093e9b0c	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x095a2ff3	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0x0969567c	submit_bh
++EXPORT_SYMBOL vmlinux 0x09696626	acpi_decode_pld_buffer
++EXPORT_SYMBOL vmlinux 0x0975023d	dev_change_flags
++EXPORT_SYMBOL vmlinux 0x0980c14d	iget5_locked
++EXPORT_SYMBOL vmlinux 0x098431ba	acpi_get_current_resources
++EXPORT_SYMBOL vmlinux 0x0985aca1	tso_build_data
++EXPORT_SYMBOL vmlinux 0x098ae045	iunique
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x099c309e	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x09af5196	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0x09b66856	deactivate_super
++EXPORT_SYMBOL vmlinux 0x09b86fb6	generic_fillattr
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09da0d2f	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x09de64df	set_pages_array_wc
++EXPORT_SYMBOL vmlinux 0x09dedfa6	padata_alloc
++EXPORT_SYMBOL vmlinux 0x09e88526	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0x09fe2504	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x0a135b70	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a2b1a38	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0x0a40a6dc	backlight_force_update
++EXPORT_SYMBOL vmlinux 0x0a51fe3c	dquot_operations
++EXPORT_SYMBOL vmlinux 0x0a57863e	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x0a661faa	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0x0a67dd52	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x0a6972e8	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0x0a76b139	file_update_time
++EXPORT_SYMBOL vmlinux 0x0a770832	register_memory_notifier
++EXPORT_SYMBOL vmlinux 0x0a9921b8	cdev_add
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0accd56a	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b122e37	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b284142	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x0b36dcc2	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x0b45ac32	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b7f1fa2	skb_unlink
++EXPORT_SYMBOL vmlinux 0x0b8110ed	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0x0b905c66	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x0b93e4fb	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x0ba0198f	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0x0ba619cc	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0x0bb00c5a	netif_device_attach
++EXPORT_SYMBOL vmlinux 0x0bb8f00d	input_inject_event
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bcdfae1	phy_attach
++EXPORT_SYMBOL vmlinux 0x0bebd2d4	sock_register
++EXPORT_SYMBOL vmlinux 0x0bfa3349	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0x0bfc0ff1	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x0c21d019	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0x0c255c53	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0x0c32ae88	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c4b83c0	__brelse
++EXPORT_SYMBOL vmlinux 0x0c4e6616	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c69c353	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x0c6bdc3f	vme_master_read
++EXPORT_SYMBOL vmlinux 0x0c7013dc	agp_create_memory
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0ca7b7a8	acpi_check_region
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cb24ce7	bio_split
++EXPORT_SYMBOL vmlinux 0x0cdb7d12	__kernel_fpu_begin
++EXPORT_SYMBOL vmlinux 0x0cf14048	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0x0cf4449a	tcp_prot
++EXPORT_SYMBOL vmlinux 0x0d0810b0	bioset_create
++EXPORT_SYMBOL vmlinux 0x0d177aac	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0x0d254767	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0x0d289aaa	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0x0d3dda14	acpi_get_type
++EXPORT_SYMBOL vmlinux 0x0d4a4fc9	set_pages_uc
++EXPORT_SYMBOL vmlinux 0x0d53155f	bh_submit_read
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d6ea39e	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x0d7258f2	param_get_short
++EXPORT_SYMBOL vmlinux 0x0d77cda0	__page_cache_alloc
++EXPORT_SYMBOL vmlinux 0x0d7a9a04	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x0d80efb5	acpi_evaluate_ost
++EXPORT_SYMBOL vmlinux 0x0d9219fe	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0da55903	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x0dbfa4b3	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0x0dc7fce8	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x0dcc4361	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x0dd599df	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x0df57cc5	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x0df64590	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0x0e1738b3	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x0e1fcb68	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0x0e216492	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x0e22094c	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x0e2d7e73	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x0e5f63fb	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e87daf6	seq_release
++EXPORT_SYMBOL vmlinux 0x0e8a3d14	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x0eb22410	inet_sendpage
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0eca8a13	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x0ed8cc7b	acpi_evaluate_object_typed
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f116119	vfs_getattr
++EXPORT_SYMBOL vmlinux 0x0f332839	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x0f386d98	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0x0f434650	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x0f4a8a74	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f62da84	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f8114ec	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x0f87dd27	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x0f8ad1c4	param_get_uint
++EXPORT_SYMBOL vmlinux 0x0f9adb37	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fd00a68	acpi_clear_event
++EXPORT_SYMBOL vmlinux 0x0fe67804	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x0fed6c86	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x0ffc6270	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x1000c0cd	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0x100e00e9	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x1046b38c	tty_do_resize
++EXPORT_SYMBOL vmlinux 0x105b53dd	block_write_full_page
++EXPORT_SYMBOL vmlinux 0x10630953	put_page
++EXPORT_SYMBOL vmlinux 0x1072a394	csum_partial_copy_from_user
++EXPORT_SYMBOL vmlinux 0x107bce56	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x10860bd8	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x10950ee1	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x109c58af	devm_free_irq
++EXPORT_SYMBOL vmlinux 0x10ac0ccd	vga_switcheroo_register_handler
++EXPORT_SYMBOL vmlinux 0x10bee9c5	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0x10d6413c	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x10fa3b3e	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0x1104f63b	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x113580bb	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x118eaf72	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x119aa83f	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11a1a688	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x11b7cd52	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0x11bab38d	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120d67d4	unregister_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x123f82f3	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x1250c7e1	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x125f91a7	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0x1281827a	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0x1287db1d	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0x129e692a	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12dfeb12	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x12f32e1c	compat_tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x1305d532	ucs2_strncmp
++EXPORT_SYMBOL vmlinux 0x130c9455	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x131d86bb	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x1324473c	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0x132606f5	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0x132c7d47	vga_switcheroo_fini_domain_pm_ops
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x13315729	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0x13448e3e	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0x1346987f	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0x134bad44	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0x135e4e93	param_get_ullong
++EXPORT_SYMBOL vmlinux 0x13847644	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0x138bb668	mmc_start_req
++EXPORT_SYMBOL vmlinux 0x13ae01d7	put_filp
++EXPORT_SYMBOL vmlinux 0x13b2bc95	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0x13b402fd	kernel_read
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13e04fbb	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0x13e82a14	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0x13ebd175	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x13ff1b98	pci_iounmap
++EXPORT_SYMBOL vmlinux 0x140bc2ab	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0x14224bea	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0x142e04e4	nd_namespace_blk_validate
++EXPORT_SYMBOL vmlinux 0x14440887	vga_con
++EXPORT_SYMBOL vmlinux 0x144bbb87	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0x14670779	register_shrinker
++EXPORT_SYMBOL vmlinux 0x14670aac	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0x147872db	pci_disable_device
++EXPORT_SYMBOL vmlinux 0x1482978b	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0x14920eaa	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0x149da1fa	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x14da772f	agp_generic_destroy_page
++EXPORT_SYMBOL vmlinux 0x14f0cd9a	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x150389d6	acpi_processor_power_init_bm_check
++EXPORT_SYMBOL vmlinux 0x1514c04c	nf_log_trace
++EXPORT_SYMBOL vmlinux 0x152958c4	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0x154372f7	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x1547bfd6	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x156a8a59	down_trylock
++EXPORT_SYMBOL vmlinux 0x15799c11	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0x15ae3884	skb_pull
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15bc6c81	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x15c302e1	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0x15c93f55	input_release_device
++EXPORT_SYMBOL vmlinux 0x15d768f5	register_gifconf
++EXPORT_SYMBOL vmlinux 0x15d7a0d8	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0x160ea4c8	sfi_disabled
++EXPORT_SYMBOL vmlinux 0x1616cb30	acpi_evaluate_dsm
++EXPORT_SYMBOL vmlinux 0x162e3da5	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0x16305289	warn_slowpath_null
++EXPORT_SYMBOL vmlinux 0x1646c767	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0x164e4072	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x1678c52b	generic_update_time
++EXPORT_SYMBOL vmlinux 0x16790082	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x167c5967	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x167e7f9d	__get_user_1
++EXPORT_SYMBOL vmlinux 0x16855149	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x16978fb6	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0x16b930f0	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0x16dc4d1f	fence_init
++EXPORT_SYMBOL vmlinux 0x16e04302	init_net
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x170c25ee	acpi_get_next_object
++EXPORT_SYMBOL vmlinux 0x1713c6c0	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0x176627f1	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x177f5e62	notify_change
++EXPORT_SYMBOL vmlinux 0x178044b0	proto_register
++EXPORT_SYMBOL vmlinux 0x1783dafd	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x178fc438	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x179122b3	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0x1793f685	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0x179651ac	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17b3ff44	pci_save_state
++EXPORT_SYMBOL vmlinux 0x17b504bb	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0x17b6c18e	send_sig_info
++EXPORT_SYMBOL vmlinux 0x17ccd3b7	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0x17ee365e	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0x17f341a0	i8042_lock_chip
++EXPORT_SYMBOL vmlinux 0x17fc297e	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0x17fee311	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x18091ea0	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0x18272d55	dm_io
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x182c49db	update_devfreq
++EXPORT_SYMBOL vmlinux 0x182d8ebc	set_cached_acl
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x186b0128	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x187f8585	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0x1883b68c	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x188a74e0	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x1896dc50	set_binfmt
++EXPORT_SYMBOL vmlinux 0x1896fe37	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x18a5472e	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0x18b72573	register_kmmio_probe
++EXPORT_SYMBOL vmlinux 0x18ca6192	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0x18cadc0b	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x1916e38c	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x19178ea6	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x194e23f0	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x1954fbe7	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0x19678148	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0x196c3be9	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x1974a575	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x19756c3e	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x198a4385	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19a290ca	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19bef053	vme_register_driver
++EXPORT_SYMBOL vmlinux 0x19eb1ad7	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0x19fee265	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x1a03950b	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0x1a0b6ad9	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x1a41af32	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x1a45cb6c	acpi_disabled
++EXPORT_SYMBOL vmlinux 0x1a617351	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0x1a63af34	vga_switcheroo_process_delayed_switch
++EXPORT_SYMBOL vmlinux 0x1a69e5c0	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x1a7af6ef	blk_get_request
++EXPORT_SYMBOL vmlinux 0x1a8ca55d	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0x1a92eb0a	bio_add_page
++EXPORT_SYMBOL vmlinux 0x1ab66bd2	d_path
++EXPORT_SYMBOL vmlinux 0x1ac5d3cb	strcspn
++EXPORT_SYMBOL vmlinux 0x1ad3e107	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x1ae88b3a	i2c_master_send
++EXPORT_SYMBOL vmlinux 0x1aea9970	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0x1afb1aaa	acpi_mark_gpe_for_wake
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b072548	kill_anon_super
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b570d23	acpi_warning
++EXPORT_SYMBOL vmlinux 0x1b61aac2	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b71669b	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b8b95ad	i8042_unlock_chip
++EXPORT_SYMBOL vmlinux 0x1b9e8888	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bd7ea44	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0x1bd941ca	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x1be1dd26	lg_global_lock
++EXPORT_SYMBOL vmlinux 0x1bef262a	set_pages_x
++EXPORT_SYMBOL vmlinux 0x1bf2aebc	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0x1bfaf517	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x1bfc4391	dev_deactivate
++EXPORT_SYMBOL vmlinux 0x1c0adf19	inode_permission
++EXPORT_SYMBOL vmlinux 0x1c2e85e1	misc_deregister
++EXPORT_SYMBOL vmlinux 0x1c301f33	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0x1c30b100	d_genocide
++EXPORT_SYMBOL vmlinux 0x1c4630b7	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x1c5ff4ae	update_region
++EXPORT_SYMBOL vmlinux 0x1c78e7b4	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x1c8a04b0	acpi_reset
++EXPORT_SYMBOL vmlinux 0x1c9a30a6	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0x1cad915a	dquot_release
++EXPORT_SYMBOL vmlinux 0x1caf0cfd	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0x1cb99042	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x1cbc68a2	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x1cbc9618	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0x1cbcaeb9	inet_offloads
++EXPORT_SYMBOL vmlinux 0x1ceae786	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x1d1056e5	crc32_be
++EXPORT_SYMBOL vmlinux 0x1d169ae7	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x1d1fac20	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x1d23db84	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x1d2dc20b	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0x1d476074	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0x1d4a0e66	module_put
++EXPORT_SYMBOL vmlinux 0x1d56a68e	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0x1d8717c4	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x1d890288	led_set_brightness
++EXPORT_SYMBOL vmlinux 0x1d8e70c2	phy_stop
++EXPORT_SYMBOL vmlinux 0x1db7706b	__copy_user_nocache
++EXPORT_SYMBOL vmlinux 0x1dc1ed61	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1de74f72	acpi_execute_simple_method
++EXPORT_SYMBOL vmlinux 0x1de98fe6	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x1df44acf	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0x1e036c98	acpi_set_gpe
++EXPORT_SYMBOL vmlinux 0x1e047854	warn_slowpath_fmt
++EXPORT_SYMBOL vmlinux 0x1e0c2be4	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x1e0dadb6	dns_query
++EXPORT_SYMBOL vmlinux 0x1e1ee0f2	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e34d222	scsi_init_io
++EXPORT_SYMBOL vmlinux 0x1e58b9e0	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e765a59	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0x1e87a395	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ea5f404	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0x1ea9c10d	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0x1eb922a3	IO_APIC_get_PCI_irq_vector
++EXPORT_SYMBOL vmlinux 0x1edc53c5	param_set_short
++EXPORT_SYMBOL vmlinux 0x1efbf1b4	param_get_charp
++EXPORT_SYMBOL vmlinux 0x1efddf81	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0x1f15073c	blk_finish_request
++EXPORT_SYMBOL vmlinux 0x1f159457	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0x1f2a4e2a	agp_generic_alloc_by_type
++EXPORT_SYMBOL vmlinux 0x1f385737	seq_lseek
++EXPORT_SYMBOL vmlinux 0x1f3b6126	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0x1f6ce67a	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x1f6e4937	register_console
++EXPORT_SYMBOL vmlinux 0x1f756756	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0x1f75f29a	sg_miter_next
++EXPORT_SYMBOL vmlinux 0x1fa698da	finish_open
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fcac1db	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x1fd02dad	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fde0311	skb_push
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x2005e68a	acpi_remove_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x20092385	acpi_enter_sleep_state_s4bios
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x200cf0bc	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0x200d2a2e	netdev_info
++EXPORT_SYMBOL vmlinux 0x200d5dec	dma_ops
++EXPORT_SYMBOL vmlinux 0x201b0ac0	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0x2026e488	key_invalidate
++EXPORT_SYMBOL vmlinux 0x203eeb90	agp_collect_device_status
++EXPORT_SYMBOL vmlinux 0x2044aea7	amd_iommu_pc_get_max_banks
++EXPORT_SYMBOL vmlinux 0x204aa53e	nd_pfn_probe
++EXPORT_SYMBOL vmlinux 0x204b8c16	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x204c371c	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0x206cc6b8	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x20777b0c	nobh_writepage
++EXPORT_SYMBOL vmlinux 0x208739f6	acpi_load_table
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20bcd34c	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0x20c325ab	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20d1e255	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x20eadeb6	ip_compute_csum
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20f53539	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x20f57bdc	vga_tryget
++EXPORT_SYMBOL vmlinux 0x20f58a4a	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0x20fbe8ee	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x211f68f1	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x213034b0	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x21760124	agp_bridge
++EXPORT_SYMBOL vmlinux 0x21779159	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0x217f3a78	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x2189ce75	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x218be917	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0x219b8d00	clear_nlink
++EXPORT_SYMBOL vmlinux 0x21a181d3	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x21a701fe	fence_signal
++EXPORT_SYMBOL vmlinux 0x21ab2243	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x21afe95e	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0x21cc724b	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x21d1c8e4	vga_switcheroo_unregister_client
++EXPORT_SYMBOL vmlinux 0x21dcad02	__alloc_skb
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21e992a5	ida_simple_get
++EXPORT_SYMBOL vmlinux 0x21ee96bd	get_user_pages
++EXPORT_SYMBOL vmlinux 0x2203f316	bmap
++EXPORT_SYMBOL vmlinux 0x2207a57f	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x22113b84	file_open_root
++EXPORT_SYMBOL vmlinux 0x221bccc2	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0x2223316f	blk_peek_request
++EXPORT_SYMBOL vmlinux 0x22260701	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x2229b9d9	param_ops_byte
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x2247419b	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0x224e5692	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x2253d8f0	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x226704a8	compat_ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x22840e74	skb_copy
++EXPORT_SYMBOL vmlinux 0x2287f651	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x229647d6	make_kuid
++EXPORT_SYMBOL vmlinux 0x22968030	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0x2298be58	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22cee791	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0x22d9f40a	acpi_bus_unregister_driver
++EXPORT_SYMBOL vmlinux 0x22e6971c	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0x22e712ff	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x22f33727	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0x22f90d2f	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x22f9916b	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0x2310adcc	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x232af19f	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0x232d18ec	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0x232e4d85	kthread_bind
++EXPORT_SYMBOL vmlinux 0x23325995	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x234202c2	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0x234bd8fd	pnp_activate_dev
++EXPORT_SYMBOL vmlinux 0x2359e2ff	fb_class
++EXPORT_SYMBOL vmlinux 0x235d3640	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0x23690eea	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0x236aae18	inode_init_owner
++EXPORT_SYMBOL vmlinux 0x236ac8a3	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0x2373f491	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x23861461	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0x2386ccb8	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x23955bf3	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0x239ac099	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23a779fd	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0x23a9661a	read_cache_pages
++EXPORT_SYMBOL vmlinux 0x23ae4a92	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23bfa65a	dev_open
++EXPORT_SYMBOL vmlinux 0x23c35c10	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23c9891c	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x23ce0d28	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0x23cf97db	vm_event_states
++EXPORT_SYMBOL vmlinux 0x23ebf91e	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x240227ac	set_posix_acl
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x242a242d	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x24422330	inode_init_once
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x2444759a	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0x24539748	import_iovec
++EXPORT_SYMBOL vmlinux 0x2458703c	md_reload_sb
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x24817579	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x2484adc3	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0x24906767	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x2494fbb9	unload_nls
++EXPORT_SYMBOL vmlinux 0x249b6181	pnp_register_card_driver
++EXPORT_SYMBOL vmlinux 0x24d1a848	down_write
++EXPORT_SYMBOL vmlinux 0x24e85fce	start_tty
++EXPORT_SYMBOL vmlinux 0x24f1281e	make_kgid
++EXPORT_SYMBOL vmlinux 0x24f48310	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x24fdf4d4	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x2537c9ad	vfs_rename
++EXPORT_SYMBOL vmlinux 0x2562dca3	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x256577a8	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x256e4dc7	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x25836ddf	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x25a8cb6d	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0x25c11130	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0x25cd061e	gnttab_alloc_pages
++EXPORT_SYMBOL vmlinux 0x25e8ed29	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x25f1a91a	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x26376157	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x263e6ebd	proc_create_data
++EXPORT_SYMBOL vmlinux 0x26416672	arch_debugfs_dir
++EXPORT_SYMBOL vmlinux 0x264f5ceb	sock_from_file
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x265b76e9	generic_setlease
++EXPORT_SYMBOL vmlinux 0x2661d2b4	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x2665d53a	key_create_or_update
++EXPORT_SYMBOL vmlinux 0x267c2016	cros_ec_check_result
++EXPORT_SYMBOL vmlinux 0x2687c52a	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0x2689968b	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x26948d96	copy_user_enhanced_fast_string
++EXPORT_SYMBOL vmlinux 0x269bb40e	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x26c31cae	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x26cb34a2	mempool_create
++EXPORT_SYMBOL vmlinux 0x26e24021	skb_find_text
++EXPORT_SYMBOL vmlinux 0x26e298e0	unregister_memory_notifier
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26ec8380	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x26fbaf28	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x271cba95	acpi_bus_private_data_handler
++EXPORT_SYMBOL vmlinux 0x27246ac0	set_groups
++EXPORT_SYMBOL vmlinux 0x272a4306	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x27504227	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x2754064a	simple_lookup
++EXPORT_SYMBOL vmlinux 0x2770e4ae	fasync_helper
++EXPORT_SYMBOL vmlinux 0x27734ed9	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0x27769db0	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0x2777e9f7	arp_xmit
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x2786e71a	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0x27882b9b	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0x278eb432	inet_listen
++EXPORT_SYMBOL vmlinux 0x2791a0b8	register_xen_selfballooning
++EXPORT_SYMBOL vmlinux 0x27ae7d0c	ec_transaction
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27c33efe	csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0x27c400b1	cdev_del
++EXPORT_SYMBOL vmlinux 0x27cd90a2	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0x27cfea5a	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x27d62347	block_commit_write
++EXPORT_SYMBOL vmlinux 0x27d8c0bb	pci_select_bars
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x280fe60a	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x28133f43	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0x2815f3b7	skb_store_bits
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x28318305	snprintf
++EXPORT_SYMBOL vmlinux 0x2833fcb7	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x28439d19	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x2848f164	phy_print_status
++EXPORT_SYMBOL vmlinux 0x28490a6e	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x2859d9b5	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0x289be2a3	inet_release
++EXPORT_SYMBOL vmlinux 0x28a2b29f	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28a45741	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0x28abfe6e	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x28b047f3	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0x28d4137d	input_flush_device
++EXPORT_SYMBOL vmlinux 0x28e09af1	iosf_mbi_available
++EXPORT_SYMBOL vmlinux 0x28f12cb3	__scm_send
++EXPORT_SYMBOL vmlinux 0x2908e024	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0x291b290f	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0x294118b2	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x294cf0b2	key_revoke
++EXPORT_SYMBOL vmlinux 0x295158fd	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x29680bff	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0x29b0c263	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0x29b2279e	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x29ff14f0	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x2a15d70e	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0x2a2e2788	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a4d7038	dev_notice
++EXPORT_SYMBOL vmlinux 0x2a565a25	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0x2a5f4882	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x2a6a16ee	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0x2aa1e4de	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x2aad04c6	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2ab69220	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0x2abe2a32	read_cache_page
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2ad9a73d	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x2af15baa	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0x2af7e095	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0x2b05a21b	intel_gtt_get
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b35d701	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0x2b4433df	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0x2b47b9ee	key_unlink
++EXPORT_SYMBOL vmlinux 0x2b4a97c0	devm_clk_put
++EXPORT_SYMBOL vmlinux 0x2b541876	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x2b6bf62a	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0x2b779563	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x2b7f87fc	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0x2b8dd26f	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2ba8e703	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0x2bb55d6e	acpi_remove_notify_handler
++EXPORT_SYMBOL vmlinux 0x2bcce224	textsearch_register
++EXPORT_SYMBOL vmlinux 0x2bfeb410	acpi_get_handle
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c2873cb	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0x2c3bd23f	tty_unlock
++EXPORT_SYMBOL vmlinux 0x2c5d5b64	__sock_create
++EXPORT_SYMBOL vmlinux 0x2c61dea8	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x2ca319a6	wrmsrl_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x2ca3f5b6	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x2cabc6a4	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x2cad8ec8	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0x2cc40ecf	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0x2ccc5367	md_flush_request
++EXPORT_SYMBOL vmlinux 0x2cf73cb7	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x2cf742d9	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0x2cf875ee	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0x2cfb902a	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x2d08f841	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x2d12c8e4	input_reset_device
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d144e21	rdmsrl_on_cpu
++EXPORT_SYMBOL vmlinux 0x2d2bfc01	ht_create_irq
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d5abe64	eth_header_parse
++EXPORT_SYMBOL vmlinux 0x2d70596a	audit_log_start
++EXPORT_SYMBOL vmlinux 0x2d9b4681	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0x2db19f75	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0x2db787c7	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x2dd16564	arch_register_cpu
++EXPORT_SYMBOL vmlinux 0x2dd9a36b	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x2ddc3bb3	vfs_readv
++EXPORT_SYMBOL vmlinux 0x2de3d75e	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x2de7b62d	param_get_bool
++EXPORT_SYMBOL vmlinux 0x2decc278	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0x2dedc4c2	acpi_format_exception
++EXPORT_SYMBOL vmlinux 0x2def7f76	rtc_cmos_write
++EXPORT_SYMBOL vmlinux 0x2dff016b	param_get_string
++EXPORT_SYMBOL vmlinux 0x2e0d2f7f	queue_work_on
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e2b40d2	strncat
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e497440	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x2e4ecc81	path_noexec
++EXPORT_SYMBOL vmlinux 0x2e593a27	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0x2e94ba76	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0x2e9dbdda	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x2ea84ac6	tty_lock
++EXPORT_SYMBOL vmlinux 0x2ebe372d	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0x2eed1cfe	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f0fd3ea	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x2f2880df	iterate_dir
++EXPORT_SYMBOL vmlinux 0x2f384db3	acpi_is_video_device
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2f5573d8	read_code
++EXPORT_SYMBOL vmlinux 0x2f64f89f	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fbd5267	icmpv6_send
++EXPORT_SYMBOL vmlinux 0x2fd051dc	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2ff063b5	acpi_get_name
++EXPORT_SYMBOL vmlinux 0x2ff16a45	d_walk
++EXPORT_SYMBOL vmlinux 0x2ffa3dc0	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0x3000355d	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0x30085292	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0x30226ddf	agp_device_command
++EXPORT_SYMBOL vmlinux 0x3027475e	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x304895bc	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x3050f7dc	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x3058ebf0	param_ops_bint
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30b01053	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x30b04526	ida_init
++EXPORT_SYMBOL vmlinux 0x30c55c94	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0x30ca4ccb	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x30e96c0c	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x30f5da8c	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x30faad02	blk_start_request
++EXPORT_SYMBOL vmlinux 0x3102d680	ps2_end_command
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310f02ec	memremap
++EXPORT_SYMBOL vmlinux 0x312e8a51	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x313d7635	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x31465f96	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x3153d353	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0x316235ff	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x31a9a33f	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x31b31f5c	csum_partial_copy_nocheck
++EXPORT_SYMBOL vmlinux 0x31d33bb4	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x31e648fb	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0x31e76b57	recalibrate_cpu_khz
++EXPORT_SYMBOL vmlinux 0x31ec44a0	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0x31f18486	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0x3202435a	wrmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0x320bd327	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0x321536eb	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0x322070f4	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0x322ffcdb	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x324adee6	tcp_poll
++EXPORT_SYMBOL vmlinux 0x324fcff5	is_nd_btt
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x32568194	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0x326425ca	pci_unmap_biosrom
++EXPORT_SYMBOL vmlinux 0x3266aed9	pci_restore_state
++EXPORT_SYMBOL vmlinux 0x326c03d9	setattr_copy
++EXPORT_SYMBOL vmlinux 0x327cd399	generic_file_open
++EXPORT_SYMBOL vmlinux 0x3293fd5f	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x3297ae80	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x32ca5139	register_md_personality
++EXPORT_SYMBOL vmlinux 0x32ce767f	generic_make_request
++EXPORT_SYMBOL vmlinux 0x32cfe803	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0x32d09891	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x32ddc69b	nd_sb_checksum
++EXPORT_SYMBOL vmlinux 0x32e6f1a0	acpi_video_backlight_string
++EXPORT_SYMBOL vmlinux 0x32ede6b0	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x3315c855	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0x331620fa	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x333cb37c	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x333cf866	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x336ef409	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0x33917b58	input_set_keycode
++EXPORT_SYMBOL vmlinux 0x33956712	arch_dma_alloc_attrs
++EXPORT_SYMBOL vmlinux 0x3399eb6d	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x33a74249	amd_iommu_flush_tlb
++EXPORT_SYMBOL vmlinux 0x33b84f74	copy_page
++EXPORT_SYMBOL vmlinux 0x33c03ac3	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33d61242	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x33dd25c0	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0x33dd420a	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x33ea2057	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x33fb1e0f	netdev_warn
++EXPORT_SYMBOL vmlinux 0x33fc9e62	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x33fcf44a	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0x344298a0	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x3465a5a0	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x347044fe	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0x347f7c03	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x349213ef	cpu_core_map
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34b5e6d8	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x34cb137e	__put_cred
++EXPORT_SYMBOL vmlinux 0x34daad66	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0x34dba3cb	param_set_charp
++EXPORT_SYMBOL vmlinux 0x34ddd4bb	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0x34e71809	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x351c17e6	fget_raw
++EXPORT_SYMBOL vmlinux 0x35366a00	sk_capable
++EXPORT_SYMBOL vmlinux 0x3539f11b	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x353e21e3	acpi_bios_warning
++EXPORT_SYMBOL vmlinux 0x355c85d3	page_put_link
++EXPORT_SYMBOL vmlinux 0x35630259	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x357bf710	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0x358f7ff2	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x35907029	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0x35a42460	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35b705f5	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0x35fc0443	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0x3601be89	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0x360b1afe	probe_irq_mask
++EXPORT_SYMBOL vmlinux 0x3630d162	inet_ioctl
++EXPORT_SYMBOL vmlinux 0x3632ca45	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0x363fc5e7	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0x36406496	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0x368b3baf	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x369e1115	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x36aea309	dst_init
++EXPORT_SYMBOL vmlinux 0x36b002a1	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x36b05f74	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x36b17f7e	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36c0c566	generic_setxattr
++EXPORT_SYMBOL vmlinux 0x3701a196	csum_partial_copy_to_user
++EXPORT_SYMBOL vmlinux 0x370f9850	efi
++EXPORT_SYMBOL vmlinux 0x37136729	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0x3729f6db	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x37504d05	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x3754a16a	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0x3774376c	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x377a4405	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x37800514	empty_aops
++EXPORT_SYMBOL vmlinux 0x379b6bc7	xfrm_input
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37b8b39e	screen_info
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37db8f19	dmi_get_date
++EXPORT_SYMBOL vmlinux 0x37dc30b1	mntput
++EXPORT_SYMBOL vmlinux 0x38099e13	wrmsrl_on_cpu
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x38273d32	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x382a5ddb	acpi_device_hid
++EXPORT_SYMBOL vmlinux 0x383c7a0d	elv_add_request
++EXPORT_SYMBOL vmlinux 0x386f9701	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0x3880435a	tcp_req_err
++EXPORT_SYMBOL vmlinux 0x3884d76c	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x38877d46	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38b4eff8	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0x38bf7f75	netif_napi_add
++EXPORT_SYMBOL vmlinux 0x38c23acd	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x38cbde9d	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x38d69319	ether_setup
++EXPORT_SYMBOL vmlinux 0x38e6b0f0	__dst_free
++EXPORT_SYMBOL vmlinux 0x38e92f50	dump_page
++EXPORT_SYMBOL vmlinux 0x38e9d20b	dm_get_device
++EXPORT_SYMBOL vmlinux 0x38f33bed	dump_fpu
++EXPORT_SYMBOL vmlinux 0x39078b41	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x39081193	__max_logical_packages
++EXPORT_SYMBOL vmlinux 0x390b5752	kset_unregister
++EXPORT_SYMBOL vmlinux 0x3917f8cc	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0x391e526e	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0x392c92ae	dquot_drop
++EXPORT_SYMBOL vmlinux 0x39388109	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x393d4de9	crc32_le
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x394e875a	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0x39525e28	d_tmpfile
++EXPORT_SYMBOL vmlinux 0x3955fcf6	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x395a4fc3	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x395dcd3d	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0x39657e6a	fd_install
++EXPORT_SYMBOL vmlinux 0x397bdd46	param_array_ops
++EXPORT_SYMBOL vmlinux 0x397bfb86	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0x3996e90f	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x399ad043	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0x399d434c	register_key_type
++EXPORT_SYMBOL vmlinux 0x39a055f3	acpi_remove_gpe_handler
++EXPORT_SYMBOL vmlinux 0x39a25f66	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x39aee1fe	vme_irq_free
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39c30879	simple_empty
++EXPORT_SYMBOL vmlinux 0x39dd9223	x86_hyper_vmware
++EXPORT_SYMBOL vmlinux 0x39e42cfc	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x39f1c2f4	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x39f372a9	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0x39f6f0c7	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0x39f74849	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x3a08475f	platform_thermal_notify
++EXPORT_SYMBOL vmlinux 0x3a151cf6	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0x3a32839e	intel_gtt_chipset_flush
++EXPORT_SYMBOL vmlinux 0x3a3bdd3b	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0x3a46f1d0	simple_statfs
++EXPORT_SYMBOL vmlinux 0x3a4af2ee	__vfs_read
++EXPORT_SYMBOL vmlinux 0x3a535272	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0x3a7497e7	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0x3a8967e7	amd_iommu_device_info
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3aab0c1d	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0x3ab8b8dc	udp_add_offload
++EXPORT_SYMBOL vmlinux 0x3ad9fc9d	backlight_device_register
++EXPORT_SYMBOL vmlinux 0x3adcb504	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0x3aef1f2f	compat_ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x3afe96eb	scsi_host_get
++EXPORT_SYMBOL vmlinux 0x3b100f96	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0x3b2fefaf	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0x3b5ad2ef	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0x3b63cf08	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b6f6cd2	udp_table
++EXPORT_SYMBOL vmlinux 0x3b728155	d_move
++EXPORT_SYMBOL vmlinux 0x3b7aa2f4	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0x3b8c2d72	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0x3b8d6dd8	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0x3bb5114a	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x3becef4e	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0x3bf55869	agp_generic_alloc_user
++EXPORT_SYMBOL vmlinux 0x3c1624e1	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c483012	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x3c4c2be4	__ps2_command
++EXPORT_SYMBOL vmlinux 0x3c533ec6	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0x3c54ea20	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0x3c6ec525	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c840957	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0x3c9898f6	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x3c9b5884	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3ce84682	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0x3cfc453c	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0x3d009ca6	setup_new_exec
++EXPORT_SYMBOL vmlinux 0x3d07fd96	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x3d09c5d1	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x3d1391e2	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x3d241127	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0x3d4f3cd3	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x3d544aa5	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0x3d6976bf	module_layout
++EXPORT_SYMBOL vmlinux 0x3d6b3685	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0x3d7a4605	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x3d7c1ed7	msrs_alloc
++EXPORT_SYMBOL vmlinux 0x3d9ee9f0	clear_page
++EXPORT_SYMBOL vmlinux 0x3da171f9	pci_mem_start
++EXPORT_SYMBOL vmlinux 0x3dad4696	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0x3dbf36c9	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3dd6c42e	arp_send
++EXPORT_SYMBOL vmlinux 0x3defa872	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e09054c	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x3e1c77a1	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x3e2ae3a8	acpi_release_global_lock
++EXPORT_SYMBOL vmlinux 0x3e3cff07	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0x3e3d9789	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0x3e462763	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x3e4eac91	i2c_release_client
++EXPORT_SYMBOL vmlinux 0x3e514af9	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0x3e66e114	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0x3e67fc31	pci_iomap
++EXPORT_SYMBOL vmlinux 0x3e759e8b	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0x3e792b61	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0x3e882943	pcibios_align_resource
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x3ebd5523	thaw_super
++EXPORT_SYMBOL vmlinux 0x3eed825c	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x3efed36b	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x3f0546a8	ioread32_rep
++EXPORT_SYMBOL vmlinux 0x3f1188ce	vme_slave_request
++EXPORT_SYMBOL vmlinux 0x3f181bc3	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0x3f20ca97	rtc_lock
++EXPORT_SYMBOL vmlinux 0x3f227692	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x3f3d2fcd	new_inode
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f4761ca	generic_writepages
++EXPORT_SYMBOL vmlinux 0x3f48a0fb	ilookup
++EXPORT_SYMBOL vmlinux 0x3f5dd17a	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x3f5edb99	pci_set_master
++EXPORT_SYMBOL vmlinux 0x3f81746b	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x3f9ebb58	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x3faaf98d	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0x3fc48160	file_path
++EXPORT_SYMBOL vmlinux 0x3fc575c9	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0x3fdc9f10	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0x3fe2ccbe	memweight
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x400e91e9	vfs_create
++EXPORT_SYMBOL vmlinux 0x4023d1d6	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4039918a	clk_register_clkdev
++EXPORT_SYMBOL vmlinux 0x40473b53	is_nd_pfn
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x406011da	udp_prot
++EXPORT_SYMBOL vmlinux 0x406ed060	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x407d1ecd	sk_common_release
++EXPORT_SYMBOL vmlinux 0x408126d4	compat_ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x40960039	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x4097fa45	acpi_read_bit_register
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40ae0f5a	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c6074b	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40c7d843	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x40c89d46	acpi_get_table_by_index
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40d86de6	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0x40e56eba	get_task_io_context
++EXPORT_SYMBOL vmlinux 0x40e56f04	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0x40e6df69	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x40ed9ff0	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0x40f1a2fd	compat_mc_setsockopt
++EXPORT_SYMBOL vmlinux 0x40f34968	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0x40feef64	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0x40ff21d8	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x4121ddcd	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0x41268242	tty_port_close
++EXPORT_SYMBOL vmlinux 0x4134bdb1	nf_afinfo
++EXPORT_SYMBOL vmlinux 0x41437dc2	sock_init_data
++EXPORT_SYMBOL vmlinux 0x41449a21	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0x4144c937	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x414aebf6	serio_close
++EXPORT_SYMBOL vmlinux 0x4150455a	serio_bus
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x4166c892	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x416a302a	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x417d203e	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x41a3fbf1	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x41a99cd5	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0x41baf194	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0x41e3706c	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x4212461a	vme_master_request
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x4234f096	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x42350e8d	ucs2_strlen
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x424c7673	fb_get_mode
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x42595e58	vgacon_text_force
++EXPORT_SYMBOL vmlinux 0x4290d30a	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x429952d8	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x429c0347	gnttab_free_pages
++EXPORT_SYMBOL vmlinux 0x429dc9b0	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0x42a04a14	agp_bind_memory
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42b76351	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0x42b905d1	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x42c8de35	ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x42ef826d	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0x42f98047	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x42ff7709	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x4319fe03	bdgrab
++EXPORT_SYMBOL vmlinux 0x432e1a4b	cros_ec_query_all
++EXPORT_SYMBOL vmlinux 0x43307623	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0x43465cd0	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x4352eb85	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x4365ed9a	vfs_write
++EXPORT_SYMBOL vmlinux 0x436c2179	iowrite32
++EXPORT_SYMBOL vmlinux 0x4381bb34	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x438b35ff	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0x43a56f52	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0x43bc4c2d	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0x43cb9f9b	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x43cfe6cb	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0x43d76cbb	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x43fc9bed	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0x4408a2d1	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x4428e6d5	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0x445f9df8	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0x446052c0	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0x4488ae17	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x4489da02	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0x448e085f	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x448eac3e	kmemdup
++EXPORT_SYMBOL vmlinux 0x449ad0a7	memcmp
++EXPORT_SYMBOL vmlinux 0x449fe84b	acpi_set_firmware_waking_vectors
++EXPORT_SYMBOL vmlinux 0x44a81d5f	acpi_evaluate_object
++EXPORT_SYMBOL vmlinux 0x44aaf30f	tsc_khz
++EXPORT_SYMBOL vmlinux 0x44ae8aff	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44b7a1be	__breadahead
++EXPORT_SYMBOL vmlinux 0x44bedeba	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0x44d09599	clkdev_add
++EXPORT_SYMBOL vmlinux 0x44db0149	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44f989b9	find_get_entry
++EXPORT_SYMBOL vmlinux 0x45081703	ec_get_handle
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x45659747	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45bb63af	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0x45dfe53d	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0x4604a43a	mem_section
++EXPORT_SYMBOL vmlinux 0x4604e28b	vme_bus_type
++EXPORT_SYMBOL vmlinux 0x46102f2d	set_pages_array_wb
++EXPORT_SYMBOL vmlinux 0x461ac773	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x461b9910	amd_northbridges
++EXPORT_SYMBOL vmlinux 0x4620a36a	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0x46224dda	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0x4629334c	__preempt_count
++EXPORT_SYMBOL vmlinux 0x463b6448	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x4667f310	iov_iter_init
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x467df16d	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0x467f2afe	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x4687add0	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x46a007c5	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x46aabbff	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0x46ae2df9	I_BDEV
++EXPORT_SYMBOL vmlinux 0x46c47fb6	__node_distance
++EXPORT_SYMBOL vmlinux 0x46d10a5d	intel_gmch_probe
++EXPORT_SYMBOL vmlinux 0x46e2de9b	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x46e34093	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x4700b235	follow_pfn
++EXPORT_SYMBOL vmlinux 0x470fa622	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0x4712f5cb	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x4714275f	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0x47203d5b	security_path_symlink
++EXPORT_SYMBOL vmlinux 0x4721d5ee	get_super_thawed
++EXPORT_SYMBOL vmlinux 0x472a1779	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x4740b3bc	xen_arch_unregister_cpu
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x475f010b	acpi_purge_cached_objects
++EXPORT_SYMBOL vmlinux 0x4762c336	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x476fc258	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x477e6dcb	amd_iommu_pc_get_set_reg_val
++EXPORT_SYMBOL vmlinux 0x478d10b2	ht_destroy_irq
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x47a1c05f	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0x47d93cae	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x47e87c55	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0x47ec2518	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x4818bebc	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0x48193639	acpi_lid_open
++EXPORT_SYMBOL vmlinux 0x481cb9ab	acpi_enter_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x483842ac	nd_region_release_lane
++EXPORT_SYMBOL vmlinux 0x4841bdee	strnchr
++EXPORT_SYMBOL vmlinux 0x48483878	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0x4852204f	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0x4855b054	register_quota_format
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x48666566	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x487f661f	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0x489741a2	agp_generic_destroy_pages
++EXPORT_SYMBOL vmlinux 0x48b2664e	ip_defrag
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48c70335	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0x48d50e79	amd_iommu_register_ppr_notifier
++EXPORT_SYMBOL vmlinux 0x48df4781	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0x48e9f90a	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x48ef79b9	fb_set_var
++EXPORT_SYMBOL vmlinux 0x49016ace	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x49168fd6	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0x494e3393	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x4951af5a	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x4987c91e	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0x4993f357	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0x49999f01	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x499df539	arp_create
++EXPORT_SYMBOL vmlinux 0x49a14fa6	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x49a9c9f9	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b163b8	acpi_bus_scan
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x49fd2aa5	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0x4a0442a9	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0x4a0805e8	acpi_pm_device_sleep_state
++EXPORT_SYMBOL vmlinux 0x4a28480f	page_readlink
++EXPORT_SYMBOL vmlinux 0x4a49eaae	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x4a5bce10	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0x4a8961f5	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x4a92e3a9	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0x4aa75c27	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0x4ab1a7b3	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0x4ab6d721	pmem_should_map_pages
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4ac99e84	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4adac422	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0x4aefac58	done_path_create
++EXPORT_SYMBOL vmlinux 0x4af44067	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x4af4eb51	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b085dbf	agp3_generic_configure
++EXPORT_SYMBOL vmlinux 0x4b0a21fc	tso_count_descs
++EXPORT_SYMBOL vmlinux 0x4b181a33	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0x4b204ec0	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0x4b371c99	noop_fsync
++EXPORT_SYMBOL vmlinux 0x4b39187b	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x4b3d80c5	get_fs_type
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b667176	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0x4b82224f	fsync_bdev
++EXPORT_SYMBOL vmlinux 0x4b9a6a52	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0x4b9dfb04	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4bc724cf	__scm_destroy
++EXPORT_SYMBOL vmlinux 0x4bcc2c5a	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0x4be93df7	blkdev_put
++EXPORT_SYMBOL vmlinux 0x4bf9cfca	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x4c07a7e0	acpi_processor_unregister_performance
++EXPORT_SYMBOL vmlinux 0x4c0923b5	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0x4c2cdf6d	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c3654bb	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x4c62ff4e	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0x4c673b3d	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x4c6f1806	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0x4c82710c	__skb_checksum
++EXPORT_SYMBOL vmlinux 0x4c878322	iosf_mbi_modify
++EXPORT_SYMBOL vmlinux 0x4c8c5b7a	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0x4c916a19	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x4c9d28b0	phys_base
++EXPORT_SYMBOL vmlinux 0x4c9fc5e2	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0x4ca37b78	mmc_request_done
++EXPORT_SYMBOL vmlinux 0x4ca4326f	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0x4ca5f57f	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x4ca9669f	scnprintf
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4ce666e8	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0x4cf421c9	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0x4cf9b163	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0x4cfc1008	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x4d0b6791	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0x4d54185c	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x4d6f77af	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0x4d909c36	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9a2aa5	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4de22c25	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4df58c83	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0x4e010297	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x4e08ccef	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x4e1ccf42	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e371411	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e74f0af	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0x4ea25709	dql_reset
++EXPORT_SYMBOL vmlinux 0x4ebba2ec	iput
++EXPORT_SYMBOL vmlinux 0x4ebd7a66	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x4ec11f4f	up_read
++EXPORT_SYMBOL vmlinux 0x4ed4094b	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0x4ee312f1	registered_fb
++EXPORT_SYMBOL vmlinux 0x4f16adfc	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f1fbca5	mntget
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f3361ae	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0x4f339be8	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f4729e5	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f4ec745	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x4f556241	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f6b400b	_copy_from_user
++EXPORT_SYMBOL vmlinux 0x4f783f30	acpi_read
++EXPORT_SYMBOL vmlinux 0x4f7a4827	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0x4f84dd8d	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0x4f8b5ddb	_copy_to_user
++EXPORT_SYMBOL vmlinux 0x4f9c0ba5	lookup_one_len
++EXPORT_SYMBOL vmlinux 0x4fa23d8b	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0x4fb6bc6c	elv_rb_del
++EXPORT_SYMBOL vmlinux 0x4fc8baa0	bdput
++EXPORT_SYMBOL vmlinux 0x4fdee897	i8042_command
++EXPORT_SYMBOL vmlinux 0x4ff08ff7	dm_put_device
++EXPORT_SYMBOL vmlinux 0x4ff204ea	init_buffer
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x50505faa	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x50523d34	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0x50529870	acpi_get_gpe_status
++EXPORT_SYMBOL vmlinux 0x505f511d	get_empty_filp
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x506f7a60	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0x509b64ea	acpi_has_method
++EXPORT_SYMBOL vmlinux 0x50a905c3	pci_release_region
++EXPORT_SYMBOL vmlinux 0x50a90e8d	bsearch
++EXPORT_SYMBOL vmlinux 0x50b1badb	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0x50ba769a	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x50c7236f	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0x50cc559d	PDE_DATA
++EXPORT_SYMBOL vmlinux 0x50d68377	arch_phys_wc_del
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x50f45e9d	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0x50fd5f1d	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x51164ad9	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x51272b49	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0x5141d311	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x514b6512	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x51548fe7	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0x5169d6cb	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0x51719973	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x518c7f40	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x519102b6	override_creds
++EXPORT_SYMBOL vmlinux 0x51a28015	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0x51ccd5c8	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x51d11d47	md_write_start
++EXPORT_SYMBOL vmlinux 0x51d12d4e	acpi_pci_disabled
++EXPORT_SYMBOL vmlinux 0x51dd7418	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0x51e2662c	generic_permission
++EXPORT_SYMBOL vmlinux 0x51e4a0af	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0x51f212c3	md_done_sync
++EXPORT_SYMBOL vmlinux 0x51f5f326	seq_path
++EXPORT_SYMBOL vmlinux 0x51ff4805	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x52095e19	acpi_get_data
++EXPORT_SYMBOL vmlinux 0x52130046	acpi_check_address_range
++EXPORT_SYMBOL vmlinux 0x521623af	nd_btt_arena_is_valid
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x523fe0ef	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x52420e92	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0x525e026f	acpi_os_unmap_generic_address
++EXPORT_SYMBOL vmlinux 0x52810970	proc_set_user
++EXPORT_SYMBOL vmlinux 0x52983a4f	vme_master_write
++EXPORT_SYMBOL vmlinux 0x52aa9abd	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0x52ce78fb	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x52d4b490	__nd_iostat_start
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x5319db9f	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x531b604e	__virt_addr_valid
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x5343334a	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x53569707	this_cpu_off
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x536c148e	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x536cc847	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x5377e556	hex2bin
++EXPORT_SYMBOL vmlinux 0x538b32df	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0x539af73c	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x53ac4217	put_cmsg
++EXPORT_SYMBOL vmlinux 0x53e058dc	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x54059a2a	amd_iommu_pc_get_max_counters
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x540b08e4	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0x541d7ee1	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0x541f910a	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x54245b39	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0x5429d9c1	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x54472810	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0x544b0c11	acpi_lid_notifier_register
++EXPORT_SYMBOL vmlinux 0x5464d3f6	acpi_remove_sci_handler
++EXPORT_SYMBOL vmlinux 0x54693173	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54b3fb06	pci_get_device
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54c8d525	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x54dab42e	lock_fb_info
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54f24d1a	fence_default_wait
++EXPORT_SYMBOL vmlinux 0x551b0c42	led_update_brightness
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x551bedc7	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x553a5855	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x555f0791	blk_queue_split
++EXPORT_SYMBOL vmlinux 0x555f6938	lockref_get
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x55a560b5	inet6_getname
++EXPORT_SYMBOL vmlinux 0x55b726bb	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0x55c9bda4	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x55d7fdf9	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0x55dac311	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0x55dfe666	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0x55e1780b	noop_llseek
++EXPORT_SYMBOL vmlinux 0x55e60a36	queued_spin_unlock_wait
++EXPORT_SYMBOL vmlinux 0x55ed7366	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0x55f5019b	__kmalloc_node
++EXPORT_SYMBOL vmlinux 0x5608cff4	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x56115ba3	__blk_end_request
++EXPORT_SYMBOL vmlinux 0x56128a2c	pnp_release_card_device
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x5641419b	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0x5642f21a	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x5648ef18	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0x565e6f26	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0x56829940	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0x56838d14	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0x5687f7b4	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x56947009	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56d476f2	put_tty_driver
++EXPORT_SYMBOL vmlinux 0x57131705	input_register_handler
++EXPORT_SYMBOL vmlinux 0x57220936	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x57769226	agp_generic_enable
++EXPORT_SYMBOL vmlinux 0x5776a61f	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0x577d35f3	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x5792f848	strlcpy
++EXPORT_SYMBOL vmlinux 0x57ae63cf	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x57ba72ab	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0x57cc82c8	neigh_destroy
++EXPORT_SYMBOL vmlinux 0x57d40a30	release_firmware
++EXPORT_SYMBOL vmlinux 0x58154462	path_nosuid
++EXPORT_SYMBOL vmlinux 0x581919e2	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0x581d2519	skb_checksum
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x5820aea8	d_add_ci
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x584738f9	rdmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x584de6aa	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x5857b225	ioread16_rep
++EXPORT_SYMBOL vmlinux 0x58604e4d	alloc_iova_mem
++EXPORT_SYMBOL vmlinux 0x586103be	acpi_setup_gpe_for_wake
++EXPORT_SYMBOL vmlinux 0x586c2034	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0x586d23f6	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x5886b132	phy_driver_register
++EXPORT_SYMBOL vmlinux 0x58a13217	up_write
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58c89557	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0x58d5b18a	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x5900aee1	__getblk_slow
++EXPORT_SYMBOL vmlinux 0x5902d0ad	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x5906b8f6	pci_get_class
++EXPORT_SYMBOL vmlinux 0x590ad503	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0x5925fa53	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0x59396432	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0x5944d015	__cachemode2pte_tbl
++EXPORT_SYMBOL vmlinux 0x59474073	pci_find_bus
++EXPORT_SYMBOL vmlinux 0x59492a23	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x59556904	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0x596905ae	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x596c0e94	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x5973ad63	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0x5979220f	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0x5984d690	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x5995a4ba	dquot_initialize
++EXPORT_SYMBOL vmlinux 0x59a0d1b7	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59bc9609	acpi_write_bit_register
++EXPORT_SYMBOL vmlinux 0x59bf6795	phy_device_register
++EXPORT_SYMBOL vmlinux 0x59c1e31e	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0x59c219e9	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0x59dd665e	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x59e93004	vga_switcheroo_register_audio_client
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a0cbc7f	init_task
++EXPORT_SYMBOL vmlinux 0x5a2f5519	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x5a33e219	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x5a4896a8	__put_user_2
++EXPORT_SYMBOL vmlinux 0x5a592afa	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0x5a82c44a	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x5a83cb83	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x5a921311	strncmp
++EXPORT_SYMBOL vmlinux 0x5a9a0e75	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0x5a9f25e0	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x5aa5245c	arp_tbl
++EXPORT_SYMBOL vmlinux 0x5ac376a5	acpi_install_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x5ad7d0ba	mpage_readpage
++EXPORT_SYMBOL vmlinux 0x5af0cc3d	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5b1843cd	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0x5b29bf3d	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0x5b56860c	vm_munmap
++EXPORT_SYMBOL vmlinux 0x5b65d6ef	km_state_notify
++EXPORT_SYMBOL vmlinux 0x5b6bb50f	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x5b6f37e5	vfs_setpos
++EXPORT_SYMBOL vmlinux 0x5b8560cf	compat_tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x5b9c808a	acpi_get_possible_resources
++EXPORT_SYMBOL vmlinux 0x5ba71a18	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0x5bc10524	printk_emit
++EXPORT_SYMBOL vmlinux 0x5bc22400	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x5bc64c24	input_register_device
++EXPORT_SYMBOL vmlinux 0x5bc8d583	copy_from_user_overflow
++EXPORT_SYMBOL vmlinux 0x5bd23e3e	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x5bee82fc	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0x5bf4cb76	follow_down
++EXPORT_SYMBOL vmlinux 0x5bfeef92	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0x5c0442fd	acpi_gbl_FADT
++EXPORT_SYMBOL vmlinux 0x5c08b1e3	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0x5c0c5411	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0x5c290dfc	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x5c39588e	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x5c41ed7e	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0x5c495d29	request_key_async
++EXPORT_SYMBOL vmlinux 0x5c76ab00	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x5c9808cc	register_netdev
++EXPORT_SYMBOL vmlinux 0x5caaa78b	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0x5cacd573	key_put
++EXPORT_SYMBOL vmlinux 0x5cc6cdbc	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0x5ccb829e	__napi_complete
++EXPORT_SYMBOL vmlinux 0x5ccfd6c9	drop_nlink
++EXPORT_SYMBOL vmlinux 0x5cd58428	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x5cdae16f	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0x5ce44439	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5cf6cd5b	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x5d0161ec	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x5d0cc974	padata_start
++EXPORT_SYMBOL vmlinux 0x5d272fee	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0x5d339b37	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x5d433bc8	ps2_init
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d74dbcf	pnp_range_reserved
++EXPORT_SYMBOL vmlinux 0x5d752c8c	tty_set_operations
++EXPORT_SYMBOL vmlinux 0x5d79e05a	generic_readlink
++EXPORT_SYMBOL vmlinux 0x5d802f6e	wake_up_process
++EXPORT_SYMBOL vmlinux 0x5d8475e0	completion_done
++EXPORT_SYMBOL vmlinux 0x5d89ffbe	netlink_capable
++EXPORT_SYMBOL vmlinux 0x5d8f91f2	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0x5d8f92f4	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x5d98dd91	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x5daf96ee	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0x5dc86a2b	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0x5de50a56	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0x5dee30c0	register_framebuffer
++EXPORT_SYMBOL vmlinux 0x5e0783de	revalidate_disk
++EXPORT_SYMBOL vmlinux 0x5e0d0cf8	kernel_bind
++EXPORT_SYMBOL vmlinux 0x5e13f815	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x5e1f2cef	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x5e266209	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0x5e358e95	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x5e5ea056	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5e9e8017	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0x5ea71c56	free_page_put_link
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ecd74e7	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0x5ecfeec6	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5eeab21e	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x5ef9062c	scsi_execute
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f0a694b	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0x5f21a711	put_io_context
++EXPORT_SYMBOL vmlinux 0x5f45c965	pci_match_id
++EXPORT_SYMBOL vmlinux 0x5f551f92	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0x5f591c0c	devm_memremap
++EXPORT_SYMBOL vmlinux 0x5f5fb85f	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0x5f8da4d8	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0x5f9f5c27	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0x5fa0d3df	copy_to_iter
++EXPORT_SYMBOL vmlinux 0x5fb2e8ef	idr_init
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x600902c6	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x6024c80d	dma_supported
++EXPORT_SYMBOL vmlinux 0x602ed00d	acpi_current_gpe_count
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x604316d8	acpi_finish_gpe
++EXPORT_SYMBOL vmlinux 0x6045e4a8	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x60854036	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x609b149b	security_path_rename
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x609f5b35	ucs2_strnlen
++EXPORT_SYMBOL vmlinux 0x60a11832	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL vmlinux 0x60be0a14	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x60c9e30a	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x6109146e	security_path_mknod
++EXPORT_SYMBOL vmlinux 0x610aaa40	mempool_destroy
++EXPORT_SYMBOL vmlinux 0x610e898f	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x611273ee	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0x6113beb8	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x61194e4c	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x612a9cb6	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0x612bd401	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0x61433e5e	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x614bb773	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x61520529	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0x615dd47b	release_sock
++EXPORT_SYMBOL vmlinux 0x61609996	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0x618911fc	numa_node
++EXPORT_SYMBOL vmlinux 0x6191bf29	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0x619cb7dd	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x61ab0285	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61bb25b1	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x61be14ec	proc_remove
++EXPORT_SYMBOL vmlinux 0x61c44035	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0x61c61141	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0x61d31dd8	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x61db4381	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0x61ef6170	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0x61f38615	blk_register_region
++EXPORT_SYMBOL vmlinux 0x61fb248a	node_states
++EXPORT_SYMBOL vmlinux 0x62049256	acpi_disable
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6226b9fa	machine_to_phys_mapping
++EXPORT_SYMBOL vmlinux 0x6227bb4d	genl_notify
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x6237f6b5	acpi_enable_event
++EXPORT_SYMBOL vmlinux 0x6255eb95	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0x6256308b	set_security_override
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62748e70	acpi_set_current_resources
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x62978012	abort_creds
++EXPORT_SYMBOL vmlinux 0x629ab041	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0x62b2db35	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0x62bfacb8	__get_page_tail
++EXPORT_SYMBOL vmlinux 0x62de553f	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x6317356c	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x632a322e	nd_btt_probe
++EXPORT_SYMBOL vmlinux 0x63352dba	kobject_del
++EXPORT_SYMBOL vmlinux 0x634d43cc	dev_set_group
++EXPORT_SYMBOL vmlinux 0x6351bcd9	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0x6357f3cd	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0x636a5691	acpi_register_ioapic
++EXPORT_SYMBOL vmlinux 0x636b04b8	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0x637fd387	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0x6388591c	down_timeout
++EXPORT_SYMBOL vmlinux 0x6393ada8	netif_rx
++EXPORT_SYMBOL vmlinux 0x63a01291	acpi_leave_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63b9190d	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x63bf104d	scsi_register
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63d57a95	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63fae632	devm_memunmap
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x640665b2	d_invalidate
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x642e3e06	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0x6434e3a1	sk_net_capable
++EXPORT_SYMBOL vmlinux 0x6449fd41	acpi_install_address_space_handler
++EXPORT_SYMBOL vmlinux 0x645a1801	kill_pid
++EXPORT_SYMBOL vmlinux 0x648963ed	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64ab0e98	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x64ac2f01	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x64bbc288	string_unescape
++EXPORT_SYMBOL vmlinux 0x64cf41a0	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0x64d8fd10	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x64eae7ad	set_memory_array_wb
++EXPORT_SYMBOL vmlinux 0x64fa7693	__acpi_handle_debug
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x651b1d9e	kthread_stop
++EXPORT_SYMBOL vmlinux 0x652ce9aa	nla_memcmp
++EXPORT_SYMBOL vmlinux 0x65324be5	sk_alloc
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x655f1ab0	set_memory_array_wc
++EXPORT_SYMBOL vmlinux 0x656c1a0e	string_escape_mem
++EXPORT_SYMBOL vmlinux 0x656c926c	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x6577109c	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0x658ffc03	consume_skb
++EXPORT_SYMBOL vmlinux 0x6598f9d4	simple_dname
++EXPORT_SYMBOL vmlinux 0x659c78eb	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0x65ab76a1	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x65b992ac	xen_alloc_p2m_entry
++EXPORT_SYMBOL vmlinux 0x65c35fc0	__seq_open_private
++EXPORT_SYMBOL vmlinux 0x65c544a3	current_task
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65e0d6d7	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x65eff4cc	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x66132e76	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0x663f7cd0	acpi_install_table_handler
++EXPORT_SYMBOL vmlinux 0x66429016	pci_map_biosrom
++EXPORT_SYMBOL vmlinux 0x6650e004	bio_reset
++EXPORT_SYMBOL vmlinux 0x66552ba7	uart_resume_port
++EXPORT_SYMBOL vmlinux 0x66569a82	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0x666586aa	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x66895057	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0x668bb964	tty_devnum
++EXPORT_SYMBOL vmlinux 0x66907707	install_exec_creds
++EXPORT_SYMBOL vmlinux 0x66945714	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0x66d804b1	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x66dd2a55	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0x66ee7cea	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0x671d5c8a	dev_crit
++EXPORT_SYMBOL vmlinux 0x6729d3df	__get_user_4
++EXPORT_SYMBOL vmlinux 0x6731a37c	serio_reconnect
++EXPORT_SYMBOL vmlinux 0x673f815e	agp_bridges
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x679e3ea8	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b362b5	amd_iommu_domain_enable_v2
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67b933e2	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0x67be9b0c	__vfs_write
++EXPORT_SYMBOL vmlinux 0x67cc428f	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0x67f132f7	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x680ec266	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x6816bc1c	phy_disconnect
++EXPORT_SYMBOL vmlinux 0x682013a8	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0x683c3be9	pci_bus_put
++EXPORT_SYMBOL vmlinux 0x684cd104	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x6867e74c	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0x68746ccd	devm_memremap_pages
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x688fb740	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68a3e99f	framebuffer_release
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68c2fcad	unregister_console
++EXPORT_SYMBOL vmlinux 0x68d8031c	ip6_xmit
++EXPORT_SYMBOL vmlinux 0x68dc800d	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0x68e08c3d	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x6900dedd	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0x691001b5	acpi_evaluate_integer
++EXPORT_SYMBOL vmlinux 0x6920ff27	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0x6943fe20	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x69472e13	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x694e598e	brioctl_set
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x6982a9f2	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x69840daf	elevator_change
++EXPORT_SYMBOL vmlinux 0x6988d0ca	cpu_dr7
++EXPORT_SYMBOL vmlinux 0x69a0ca7d	iowrite16be
++EXPORT_SYMBOL vmlinux 0x69a103c1	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69acdf38	memcpy
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69c5d804	sock_i_uid
++EXPORT_SYMBOL vmlinux 0x69daeabc	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0x69fbc0a2	acpi_get_event_resources
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a16cbbd	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0x6a2fdea9	to_nd_pfn
++EXPORT_SYMBOL vmlinux 0x6a4a09ad	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a5fa363	sigprocmask
++EXPORT_SYMBOL vmlinux 0x6a60277d	acpi_buffer_to_resource
++EXPORT_SYMBOL vmlinux 0x6a6f6265	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a77633d	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0x6a83c544	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0x6a9061a9	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0x6a994775	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0x6a9d2929	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x6aae3863	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0x6aba2836	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6acb973d	iowrite32be
++EXPORT_SYMBOL vmlinux 0x6ad85887	acpi_enable_gpe
++EXPORT_SYMBOL vmlinux 0x6add5c9a	dmi_find_device
++EXPORT_SYMBOL vmlinux 0x6ade8487	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0x6ae60faa	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b0c8f60	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x6b0ce306	km_query
++EXPORT_SYMBOL vmlinux 0x6b19b5a4	elevator_exit
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b208348	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x6b262e17	simple_open
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b33be42	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0x6b50faea	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0x6b54d136	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0x6b59bfeb	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x6b640864	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6b6ccf71	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0x6b74b9be	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0x6b998031	param_get_byte
++EXPORT_SYMBOL vmlinux 0x6bac34ba	dev_uc_init
++EXPORT_SYMBOL vmlinux 0x6bb97a8e	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0x6bc2068f	pnp_stop_dev
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bcf066d	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x6bdb7524	agp_generic_create_gatt_table
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6be46a37	amd_iommu_flush_page
++EXPORT_SYMBOL vmlinux 0x6bf1c17f	pv_lock_ops
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c15e5ea	md_write_end
++EXPORT_SYMBOL vmlinux 0x6c2fa4b1	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0x6c40cccf	uart_match_port
++EXPORT_SYMBOL vmlinux 0x6c40e715	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x6c44bc15	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c63ce18	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x6c643559	keyring_alloc
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c825e1c	kern_path_create
++EXPORT_SYMBOL vmlinux 0x6c8751ad	x86_hyper
++EXPORT_SYMBOL vmlinux 0x6c93767e	__serio_register_port
++EXPORT_SYMBOL vmlinux 0x6caa63ef	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0x6cb54530	d_rehash
++EXPORT_SYMBOL vmlinux 0x6cb5c718	param_get_long
++EXPORT_SYMBOL vmlinux 0x6cc42aee	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0x6cfec72f	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0x6cff1d11	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x6d00cef0	agp_generic_mask_memory
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d1d5d9b	iosf_mbi_write
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d299e57	tcp_close
++EXPORT_SYMBOL vmlinux 0x6d30f8c4	may_umount
++EXPORT_SYMBOL vmlinux 0x6d334118	__get_user_8
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d3a2782	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0x6d4b2065	sock_release
++EXPORT_SYMBOL vmlinux 0x6d4f4973	tcf_register_action
++EXPORT_SYMBOL vmlinux 0x6d549830	redraw_screen
++EXPORT_SYMBOL vmlinux 0x6d5cdac0	pci_release_regions
++EXPORT_SYMBOL vmlinux 0x6d6aa90d	bio_endio
++EXPORT_SYMBOL vmlinux 0x6d94b2b0	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0x6da5789e	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0x6dc0c9dc	down_interruptible
++EXPORT_SYMBOL vmlinux 0x6dc2a1be	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x6dc6dd56	down
++EXPORT_SYMBOL vmlinux 0x6de0ef80	param_set_bool
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6e357b8a	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0x6e363841	vc_cons
++EXPORT_SYMBOL vmlinux 0x6e3deb33	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x6e47a08b	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x6e669232	write_cache_pages
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e7b12f4	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x6e7f0fd2	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x6e80936b	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x6e8c6c87	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x6e9404a6	netif_device_detach
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6e9e55db	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0x6ea2e10b	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x6ea368d2	key_task_permission
++EXPORT_SYMBOL vmlinux 0x6ec5fb9a	__bforget
++EXPORT_SYMBOL vmlinux 0x6ed682b3	input_register_handle
++EXPORT_SYMBOL vmlinux 0x6ee9e843	skb_trim
++EXPORT_SYMBOL vmlinux 0x6eea9103	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x6ef35181	__kernel_write
++EXPORT_SYMBOL vmlinux 0x6ef66e8a	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0x6f1bf786	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x6f1e801b	phy_resume
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f29c8e5	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0x6f2e4f46	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0x6f3784b0	seq_write
++EXPORT_SYMBOL vmlinux 0x6f52efc0	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x6f556bdb	acpi_get_gpe_device
++EXPORT_SYMBOL vmlinux 0x6f6235b7	d_find_alias
++EXPORT_SYMBOL vmlinux 0x6f7e9e66	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6f8c352d	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0x6f9af886	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0x6fb4ccee	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6fd11024	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0x6fd5e7d2	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0x6fdf683a	i8042_install_filter
++EXPORT_SYMBOL vmlinux 0x6feb2039	acpi_write
++EXPORT_SYMBOL vmlinux 0x6feda463	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x6ffed434	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0x7023bea8	unregister_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x7029f11b	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0x702b2690	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x70379ac1	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7054a3e4	request_dma
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x7073c5d7	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x70878115	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x708a79f7	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x708bdcec	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x70a88c9a	dev_load
++EXPORT_SYMBOL vmlinux 0x70c81625	icmp_send
++EXPORT_SYMBOL vmlinux 0x70d12284	keyring_clear
++EXPORT_SYMBOL vmlinux 0x70d16661	security_file_permission
++EXPORT_SYMBOL vmlinux 0x70d8ab82	acpi_acquire_global_lock
++EXPORT_SYMBOL vmlinux 0x70e9f676	param_ops_string
++EXPORT_SYMBOL vmlinux 0x70f605e9	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x7111e4d6	get_agp_version
++EXPORT_SYMBOL vmlinux 0x7125fa5f	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x712c588f	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0x712f27f0	get_disk
++EXPORT_SYMBOL vmlinux 0x715adc77	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x716ecc12	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x717a40bc	cros_ec_prepare_tx
++EXPORT_SYMBOL vmlinux 0x71828a66	proc_dostring
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71adf0e7	mount_bdev
++EXPORT_SYMBOL vmlinux 0x71b1381f	__genl_register_family
++EXPORT_SYMBOL vmlinux 0x71c70e22	i8042_remove_filter
++EXPORT_SYMBOL vmlinux 0x71dbcc2e	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x71ee4762	pid_task
++EXPORT_SYMBOL vmlinux 0x71eeddca	thaw_bdev
++EXPORT_SYMBOL vmlinux 0x71fa9e0e	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0x72220176	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x7223efff	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x72724529	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0x7280af6c	load_nls
++EXPORT_SYMBOL vmlinux 0x72873e81	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0x729b1645	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x72a40973	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x72a98fdb	copy_user_generic_unrolled
++EXPORT_SYMBOL vmlinux 0x72b243d4	free_dma
++EXPORT_SYMBOL vmlinux 0x72b75830	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0x72b938a2	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0x72c24949	dump_trace
++EXPORT_SYMBOL vmlinux 0x72cd94dc	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x72d37aeb	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0x72dd3f48	path_is_under
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x72ee368c	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x73316952	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x734c013f	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0x735a0bd5	native_io_delay
++EXPORT_SYMBOL vmlinux 0x736fc01c	clkdev_drop
++EXPORT_SYMBOL vmlinux 0x738714db	ida_pre_get
++EXPORT_SYMBOL vmlinux 0x7398f74d	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0x73a098e7	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x73ba73e7	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0x73bd54ec	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0x73dd54eb	irq_fpu_usable
++EXPORT_SYMBOL vmlinux 0x740596b4	vme_dma_request
++EXPORT_SYMBOL vmlinux 0x7405a78e	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x740a1b95	reserve_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x741d26b5	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0x745f20a3	idr_is_empty
++EXPORT_SYMBOL vmlinux 0x74662f36	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x746ae1dc	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x74763ee4	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x7478c84e	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x749b370b	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0x74a9ea4b	pnp_device_attach
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74c213b0	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x74c586e7	poll_initwait
++EXPORT_SYMBOL vmlinux 0x74cffdd2	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x750f444c	pnp_register_driver
++EXPORT_SYMBOL vmlinux 0x7525a60d	kobject_init
++EXPORT_SYMBOL vmlinux 0x7532588a	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0x7538b132	agp_off
++EXPORT_SYMBOL vmlinux 0x754d539c	strlen
++EXPORT_SYMBOL vmlinux 0x757fd35d	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0x758908b4	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0x7590f8dc	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x75bc549a	x86_cpu_to_apicid
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75d4388d	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x75f79460	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x75fbdefd	acpi_remove_address_space_handler
++EXPORT_SYMBOL vmlinux 0x75fc8f99	vga_switcheroo_client_fb_set
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x760fbf91	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x7645af6f	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x764cc3a0	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x76532634	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0x765a75c7	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0x765f961b	misc_register
++EXPORT_SYMBOL vmlinux 0x765ff474	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x7676b167	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0x767dd8fd	acpi_get_irq_routing_table
++EXPORT_SYMBOL vmlinux 0x767ddb02	set_memory_wc
++EXPORT_SYMBOL vmlinux 0x767e5358	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0x768d3543	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x76961c24	skb_append
++EXPORT_SYMBOL vmlinux 0x76a06d06	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0x76a46b04	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x76d3923b	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76d99624	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x76dd3eaa	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0x76f4f306	km_is_alive
++EXPORT_SYMBOL vmlinux 0x76fb08a7	amd_iommu_unregister_ppr_notifier
++EXPORT_SYMBOL vmlinux 0x770d8f52	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x77102b42	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x771ae0bb	phy_detach
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x773bc6ea	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0x773c9252	blkdev_get
++EXPORT_SYMBOL vmlinux 0x773fa409	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x77456e0a	acpi_root_dir
++EXPORT_SYMBOL vmlinux 0x77853e4d	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x7785c684	nd_region_to_nstype
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x779afbd0	kill_fasync
++EXPORT_SYMBOL vmlinux 0x77a60ab8	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77d46454	request_firmware
++EXPORT_SYMBOL vmlinux 0x77ee2b78	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x77ef9cb2	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x77f53abc	acpi_get_vendor_resource
++EXPORT_SYMBOL vmlinux 0x77f57034	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x77ff0cc6	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0x780fdfd1	intel_enable_gtt
++EXPORT_SYMBOL vmlinux 0x7822691c	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0x7829c3bd	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0x7839a763	mdiobus_read
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x7846af3e	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x784b498b	kset_register
++EXPORT_SYMBOL vmlinux 0x785c6561	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x78764f4e	pv_irq_ops
++EXPORT_SYMBOL vmlinux 0x78794eaf	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x788d590a	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x789aeec3	genphy_read_status
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x789d81c9	agp_generic_free_by_type
++EXPORT_SYMBOL vmlinux 0x78a2d26b	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x78a324a4	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x78a5ff8a	fence_add_callback
++EXPORT_SYMBOL vmlinux 0x78b4cd20	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0x78bcdc29	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x78be5b63	from_kuid
++EXPORT_SYMBOL vmlinux 0x78db81c4	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78e739aa	up
++EXPORT_SYMBOL vmlinux 0x78ea433a	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0x79068fda	acpi_install_method
++EXPORT_SYMBOL vmlinux 0x791313b1	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x791ed1c9	rename_lock
++EXPORT_SYMBOL vmlinux 0x79237f48	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x793d018c	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0x793f4b8a	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0x79583b63	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0x79635b6a	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0x796783b1	vfs_writef
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x7975e183	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x7981b316	sk_dst_check
++EXPORT_SYMBOL vmlinux 0x7984eefc	key_update
++EXPORT_SYMBOL vmlinux 0x7985d043	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x79976b1d	sock_wfree
++EXPORT_SYMBOL vmlinux 0x799f81b1	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x79a33f85	vme_get_size
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79d7927c	agp_generic_insert_memory
++EXPORT_SYMBOL vmlinux 0x7a0a5c44	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0x7a2af7b4	cpu_number
++EXPORT_SYMBOL vmlinux 0x7a342896	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0x7a371a0c	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x7a3c3ce1	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a5d80a9	skb_put
++EXPORT_SYMBOL vmlinux 0x7a5f740f	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0x7a612de2	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0x7a6cdedc	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7a82cb47	rdmsrl_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x7a8c03f9	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x7a918a9a	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7abe729f	security_path_chmod
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7ad318d1	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x7addda31	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x7aec9089	clear_user
++EXPORT_SYMBOL vmlinux 0x7aee7b4a	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0x7af4b25f	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x7b06a747	__neigh_create
++EXPORT_SYMBOL vmlinux 0x7b0c2cdd	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0x7b0de404	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x7b16235f	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b2aef6c	__krealloc
++EXPORT_SYMBOL vmlinux 0x7b491801	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0x7b4af9dc	seq_read
++EXPORT_SYMBOL vmlinux 0x7b4be739	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0x7b52a859	wrmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x7b68595d	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x7b8c018f	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0x7bad7a1a	acpi_walk_resources
++EXPORT_SYMBOL vmlinux 0x7bcc7c65	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0x7be75ffc	acpi_walk_resource_buffer
++EXPORT_SYMBOL vmlinux 0x7c0b8561	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c27f6cc	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0x7c2d098f	krealloc
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c65b1a3	seq_open_private
++EXPORT_SYMBOL vmlinux 0x7c946aad	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7cac1c7c	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x7cb0e95e	from_kgid
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cc824e6	agp_generic_free_gatt_table
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7ce72776	md_integrity_register
++EXPORT_SYMBOL vmlinux 0x7ce83365	acpi_remove_table_handler
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7cf3dd9b	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0x7d05f0dc	input_event
++EXPORT_SYMBOL vmlinux 0x7d088d32	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x7d0b6c95	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d166ec1	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0x7d24e15a	twl6040_power
++EXPORT_SYMBOL vmlinux 0x7d287136	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x7d326028	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x7d4d2ef8	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x7d5e2795	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d71445d	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x7d7cd46e	lease_modify
++EXPORT_SYMBOL vmlinux 0x7d84977b	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0x7d8ab44b	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0x7d94f746	acpi_os_write_port
++EXPORT_SYMBOL vmlinux 0x7d96cea3	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x7da30008	padata_stop
++EXPORT_SYMBOL vmlinux 0x7daee664	would_dump
++EXPORT_SYMBOL vmlinux 0x7db116e9	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x7db6f01a	netdev_alert
++EXPORT_SYMBOL vmlinux 0x7dbc2e57	mmiotrace_printk
++EXPORT_SYMBOL vmlinux 0x7dc30683	sk_wait_data
++EXPORT_SYMBOL vmlinux 0x7dd554fc	unregister_kmmio_probe
++EXPORT_SYMBOL vmlinux 0x7def3866	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7e0480cf	first_ec
++EXPORT_SYMBOL vmlinux 0x7e0ffdb9	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x7e318aeb	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x7e5c35b1	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x7e7fc3fb	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x7e833a94	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0x7e83cc3c	to_ndd
++EXPORT_SYMBOL vmlinux 0x7e8eb6b9	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x7e9ab0bb	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x7ea39625	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0x7ea8d651	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0x7eb0365f	submit_bio
++EXPORT_SYMBOL vmlinux 0x7eb550b1	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x7eba45a1	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x7ebd4be4	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x7ec38d2d	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f147a49	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x7f1b9d5c	follow_up
++EXPORT_SYMBOL vmlinux 0x7f1c27fe	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f263ed9	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x7f276ea1	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x7f2775bc	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x7f39a5bb	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x7f5ebe60	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0x7f61d7da	xattr_full_name
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f94c3d3	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x7f9a0160	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x7fbd10d2	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x7fdd540f	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fe38f48	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x8028fabb	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x8067a111	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0x8068c15c	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x80791a8c	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0x809388ca	idr_destroy
++EXPORT_SYMBOL vmlinux 0x80a6c6c2	default_llseek
++EXPORT_SYMBOL vmlinux 0x80ae5b99	force_sig
++EXPORT_SYMBOL vmlinux 0x80b248fd	bdget
++EXPORT_SYMBOL vmlinux 0x80b71e9e	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80e6e9dd	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x80eb423b	acpi_get_object_info
++EXPORT_SYMBOL vmlinux 0x80fe7b44	vga_put
++EXPORT_SYMBOL vmlinux 0x810a992f	vga_switcheroo_get_client_state
++EXPORT_SYMBOL vmlinux 0x81144f9d	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x811b6681	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0x813816c3	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0x81472677	acpi_get_table
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x81533963	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x815b806a	agp_generic_remove_memory
++EXPORT_SYMBOL vmlinux 0x815f2897	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x8161b4fd	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0x81641b68	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x819604c9	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x819dcf76	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0x81a12fe4	netif_skb_features
++EXPORT_SYMBOL vmlinux 0x81aec362	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0x81c3077a	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0x81da207f	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81e43d52	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0x81e6b37f	dmi_get_system_info
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x820a4089	seq_release_private
++EXPORT_SYMBOL vmlinux 0x8212721d	xenbus_dev_request_and_reply
++EXPORT_SYMBOL vmlinux 0x8224141b	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x82458f7f	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x824d354c	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82854c7b	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x8293979c	md_register_thread
++EXPORT_SYMBOL vmlinux 0x829534b3	fence_free
++EXPORT_SYMBOL vmlinux 0x829cf250	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82cbeada	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0x82dc9896	seq_dentry
++EXPORT_SYMBOL vmlinux 0x82e151aa	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x82ee1753	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x82f4708b	vga_switcheroo_set_dynamic_switch
++EXPORT_SYMBOL vmlinux 0x82fa1117	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x830e547b	ioremap_prot
++EXPORT_SYMBOL vmlinux 0x83314e49	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0x833c03aa	acpi_enable_all_runtime_gpes
++EXPORT_SYMBOL vmlinux 0x8354a582	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0x83619aac	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0x836fede0	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x8384647a	acpi_map_pxm_to_online_node
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83dbbf7d	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0x84060081	xen_poll_irq_timeout
++EXPORT_SYMBOL vmlinux 0x840cd53e	dev_add_offload
++EXPORT_SYMBOL vmlinux 0x840e6b13	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0x84147abc	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0x8417f512	acpi_update_all_gpes
++EXPORT_SYMBOL vmlinux 0x844c0f31	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0x844e3767	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0x84521c25	amd_iommu_enable_device_erratum
++EXPORT_SYMBOL vmlinux 0x84540921	add_disk
++EXPORT_SYMBOL vmlinux 0x845fce2f	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x8460152e	block_write_end
++EXPORT_SYMBOL vmlinux 0x847764dc	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x84787f5c	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0x8489bc5a	do_SAK
++EXPORT_SYMBOL vmlinux 0x848c55df	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0x84909777	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x84a29dce	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x84acf249	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x84bc0570	genphy_config_init
++EXPORT_SYMBOL vmlinux 0x84bd9351	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x84c74f71	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0x84c9123c	migrate_page
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x8501b98c	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x8507c383	proc_dointvec
++EXPORT_SYMBOL vmlinux 0x85214ab2	vme_irq_request
++EXPORT_SYMBOL vmlinux 0x8526c35a	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x853cb3c7	param_set_uint
++EXPORT_SYMBOL vmlinux 0x8540bb5e	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x854e682b	dst_alloc
++EXPORT_SYMBOL vmlinux 0x855cdab7	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x8567596f	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0x857582f7	acpi_enable_all_wakeup_gpes
++EXPORT_SYMBOL vmlinux 0x857da20e	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x858b3fe3	free_iova_mem
++EXPORT_SYMBOL vmlinux 0x858e6a08	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x85900891	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0x8593884c	cdrom_open
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x8600e131	dump_align
++EXPORT_SYMBOL vmlinux 0x861e22a4	acpi_map_cpu
++EXPORT_SYMBOL vmlinux 0x86304412	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x863662cc	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x863a0d34	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0x86416370	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x86574ca9	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0x865d263c	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0x866251b8	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0x866352ed	vme_slot_num
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x86a214b8	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86a6b430	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0x86d796cf	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x86e34e3c	unregister_key_type
++EXPORT_SYMBOL vmlinux 0x86e49f77	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x870d3c16	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0x87188d13	nf_log_unset
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x8722acb0	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x87487567	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x874f0e72	bio_init
++EXPORT_SYMBOL vmlinux 0x8752dc1a	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x875b0b19	kfree_put_link
++EXPORT_SYMBOL vmlinux 0x8760ee29	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x87612e44	nvdimm_namespace_disk_name
++EXPORT_SYMBOL vmlinux 0x8769e108	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0x876a9aae	__mutex_init
++EXPORT_SYMBOL vmlinux 0x876dafc3	ec_write
++EXPORT_SYMBOL vmlinux 0x8789be64	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x878b75bb	__nd_driver_register
++EXPORT_SYMBOL vmlinux 0x878cd015	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x879f6087	napi_disable
++EXPORT_SYMBOL vmlinux 0x87a16e57	agp_copy_info
++EXPORT_SYMBOL vmlinux 0x87aaddf8	wrmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0x87ac41f6	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0x87b3aeb7	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0x87ba5a3a	amd_iommu_get_v2_domain
++EXPORT_SYMBOL vmlinux 0x87c86926	bdi_init
++EXPORT_SYMBOL vmlinux 0x87e896e2	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0x87ebfd89	free_netdev
++EXPORT_SYMBOL vmlinux 0x87fdb0fb	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0x88068ad7	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0x881acdd5	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x88203616	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x886f204a	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0x887044c7	finish_no_open
++EXPORT_SYMBOL vmlinux 0x887fa47e	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x88816ad9	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x8895192d	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x88d1bb49	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0x89013a20	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0x890f6189	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0x89276022	agp_generic_alloc_pages
++EXPORT_SYMBOL vmlinux 0x892b26a0	set_memory_nx
++EXPORT_SYMBOL vmlinux 0x892de3fb	__nla_put
++EXPORT_SYMBOL vmlinux 0x89347d60	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x89519845	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0x89547fd6	mmc_free_host
++EXPORT_SYMBOL vmlinux 0x896f14d8	vc_resize
++EXPORT_SYMBOL vmlinux 0x89790349	compat_sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89c0a9b0	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0x89c13434	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x89d1502c	component_match_add
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89d591d3	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0x89dc10a7	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0x8a0b12c6	complete_all
++EXPORT_SYMBOL vmlinux 0x8a0b81b6	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a1ba4e6	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0x8a3f5aa1	acpi_processor_preregister_performance
++EXPORT_SYMBOL vmlinux 0x8a43f884	agp3_generic_tlbflush
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a608649	generic_show_options
++EXPORT_SYMBOL vmlinux 0x8a675472	clear_inode
++EXPORT_SYMBOL vmlinux 0x8a6944f9	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x8a6af65c	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x8a6cf45f	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x8a7a9af9	kernel_write
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a80d7a5	acpi_error
++EXPORT_SYMBOL vmlinux 0x8a840b95	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8add66a1	do_truncate
++EXPORT_SYMBOL vmlinux 0x8afc1151	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x8b2f9f47	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b3b3d77	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0x8b3ee291	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x8b41ac04	xen_biovec_phys_mergeable
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b4bbd0a	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x8b4c0387	vga_switcheroo_init_domain_pm_optimus_hdmi_audio
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b8329a6	ilookup5
++EXPORT_SYMBOL vmlinux 0x8b989cf9	acpi_bus_can_wakeup
++EXPORT_SYMBOL vmlinux 0x8ba82b10	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0x8bacd034	scsi_print_result
++EXPORT_SYMBOL vmlinux 0x8bb5fb90	vme_bus_num
++EXPORT_SYMBOL vmlinux 0x8bd696d8	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0x8be76d96	__d_drop
++EXPORT_SYMBOL vmlinux 0x8bf8632e	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0x8c0e2191	compat_sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x8c183cbe	iowrite16
++EXPORT_SYMBOL vmlinux 0x8c2172fe	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0x8c2759b7	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x8c400fec	vga_switcheroo_init_domain_pm_ops
++EXPORT_SYMBOL vmlinux 0x8c5eb0a2	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c6f16c7	no_llseek
++EXPORT_SYMBOL vmlinux 0x8c71c0e1	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0x8c82a186	devm_clk_get
++EXPORT_SYMBOL vmlinux 0x8c86171f	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0x8c8e7739	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0x8cc79cab	iowrite16_rep
++EXPORT_SYMBOL vmlinux 0x8cda8029	xen_clear_irq_pending
++EXPORT_SYMBOL vmlinux 0x8cdaca92	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0x8cf1a339	load_nls_default
++EXPORT_SYMBOL vmlinux 0x8d087929	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x8d1b8aea	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0x8d28298f	netlink_ack
++EXPORT_SYMBOL vmlinux 0x8d295ff4	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x8d38d8ea	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x8d49df51	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d55d4b9	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0x8d5cb48f	follow_down_one
++EXPORT_SYMBOL vmlinux 0x8d6d4696	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0x8d6fcbc2	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d73b92f	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x8d7dd320	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0x8d838d91	ida_remove
++EXPORT_SYMBOL vmlinux 0x8d8b894b	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0x8d8d96c6	acpi_get_sleep_type_data
++EXPORT_SYMBOL vmlinux 0x8d985206	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x8da1a3cb	acpi_remove_interface
++EXPORT_SYMBOL vmlinux 0x8da6135f	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x8daf8c42	dql_init
++EXPORT_SYMBOL vmlinux 0x8deffe68	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x8df465de	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x8df92f66	memchr_inv
++EXPORT_SYMBOL vmlinux 0x8e002cda	acpi_remove_gpe_block
++EXPORT_SYMBOL vmlinux 0x8e16c7ef	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0x8e2d83b6	node_to_cpumask_map
++EXPORT_SYMBOL vmlinux 0x8e352cd7	lock_rename
++EXPORT_SYMBOL vmlinux 0x8e62dee6	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0x8e71758a	phy_find_first
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e9b1d65	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x8eaf2a5f	vga_switcheroo_unregister_handler
++EXPORT_SYMBOL vmlinux 0x8ecc423c	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0x8eeef016	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x8f041d3e	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x8f2703b7	wbinvd_on_all_cpus
++EXPORT_SYMBOL vmlinux 0x8f6ace30	pnp_is_active
++EXPORT_SYMBOL vmlinux 0x8f840b34	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x8f8812cf	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x8f8dd1bd	send_sig
++EXPORT_SYMBOL vmlinux 0x8f9c199c	__get_user_2
++EXPORT_SYMBOL vmlinux 0x8fa8feca	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0x8fcfa011	key_alloc
++EXPORT_SYMBOL vmlinux 0x8fe2c032	mount_nodev
++EXPORT_SYMBOL vmlinux 0x8fe59cef	convert_art_to_tsc
++EXPORT_SYMBOL vmlinux 0x8fee828e	filemap_flush
++EXPORT_SYMBOL vmlinux 0x9008ead7	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x901ba548	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x901eac4b	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x9023a30a	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x90270d85	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x90278ac8	pci_bus_get
++EXPORT_SYMBOL vmlinux 0x9041f1bb	cdev_init
++EXPORT_SYMBOL vmlinux 0x904409c6	acpi_set_firmware_waking_vector
++EXPORT_SYMBOL vmlinux 0x904abd6f	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0x9050ece4	__sb_end_write
++EXPORT_SYMBOL vmlinux 0x905b583a	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x908575fe	queued_write_lock_slowpath
++EXPORT_SYMBOL vmlinux 0x90949ce3	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0x90d03b87	set_device_ro
++EXPORT_SYMBOL vmlinux 0x90d72f8e	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x90ea3dff	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0x90f35bee	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0x910d7b85	devm_request_resource
++EXPORT_SYMBOL vmlinux 0x9113c343	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x91193fb0	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0x911c243d	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x914968f0	posix_test_lock
++EXPORT_SYMBOL vmlinux 0x91607d95	set_memory_wb
++EXPORT_SYMBOL vmlinux 0x9162b4e3	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x91656840	key_link
++EXPORT_SYMBOL vmlinux 0x9166fada	strncpy
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x91772502	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0x91967e8e	xen_selfballoon_init
++EXPORT_SYMBOL vmlinux 0x91ac822f	vscnprintf
++EXPORT_SYMBOL vmlinux 0x91aef84f	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0x91b07fed	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0x91b1e05e	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0x91ce301b	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x91d53d37	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0x91d5ea67	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0x91f4e25a	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x91ffb193	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x9203acf6	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x9213b4b5	console_stop
++EXPORT_SYMBOL vmlinux 0x921abacd	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x922b7a22	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x92314569	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x924cf75f	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x92554b68	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0x92578d40	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0x927f77ce	tty_name
++EXPORT_SYMBOL vmlinux 0x9284951f	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x9287e464	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0x9291cd3b	memdup_user
++EXPORT_SYMBOL vmlinux 0x929cf440	__f_setown
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92ab4f56	phy_device_create
++EXPORT_SYMBOL vmlinux 0x92c0d3f2	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x92f6767f	lg_local_lock
++EXPORT_SYMBOL vmlinux 0x92f8496b	inet_put_port
++EXPORT_SYMBOL vmlinux 0x92f9592c	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x93022ba6	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x93208656	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0x932493a8	iosf_mbi_read
++EXPORT_SYMBOL vmlinux 0x934821fe	nvm_register_target
++EXPORT_SYMBOL vmlinux 0x935b9110	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x935ee833	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0x9362846c	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x938232d5	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0x9383b89e	simple_rename
++EXPORT_SYMBOL vmlinux 0x93a68c23	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93b65bc7	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0x93b7db79	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x93c0f05e	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x93f3e52b	acpi_extract_package
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x93fd7bf3	bio_copy_data
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x94087dfd	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0x9412e10e	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x94178922	dst_discard_out
++EXPORT_SYMBOL vmlinux 0x946c71ad	__inet_hash
++EXPORT_SYMBOL vmlinux 0x948c088d	unlock_page
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94bd4088	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0x94d852d7	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0x94e740e0	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x950f720b	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x952a9d9b	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x95395301	acpi_exception
++EXPORT_SYMBOL vmlinux 0x953c5f2d	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x9540b857	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x955943ff	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0x955bf803	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0x9560ee55	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0x9578db09	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0x95ae1213	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0x95bd6e26	acpi_install_sci_handler
++EXPORT_SYMBOL vmlinux 0x95c98cb3	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0x95dd3410	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0x95e1f4c2	ppp_input
++EXPORT_SYMBOL vmlinux 0x960a8f85	skb_pad
++EXPORT_SYMBOL vmlinux 0x96194880	phy_start
++EXPORT_SYMBOL vmlinux 0x961ff9d1	rwsem_wake
++EXPORT_SYMBOL vmlinux 0x9625c7e6	dqget
++EXPORT_SYMBOL vmlinux 0x9630a7fb	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x96389c0a	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x963a2376	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x9648af43	md_update_sb
++EXPORT_SYMBOL vmlinux 0x965593c6	set_wb_congested
++EXPORT_SYMBOL vmlinux 0x9671cf35	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0x9692f154	set_pages_wb
++EXPORT_SYMBOL vmlinux 0x9699cb3a	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0x96aba385	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x96b29254	strncasecmp
++EXPORT_SYMBOL vmlinux 0x96b4f166	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0x96b7515a	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x96ca12c3	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96d6cf6e	request_key
++EXPORT_SYMBOL vmlinux 0x96ea4642	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x96f3dfa5	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x970e57b1	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x973fa82e	register_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x976e5e7d	use_ibrs
++EXPORT_SYMBOL vmlinux 0x977e9a99	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x97868aef	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x97a57333	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0x97bf320e	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x97c5bd0a	acpi_unload_parent_table
++EXPORT_SYMBOL vmlinux 0x97d72537	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x97de0ddd	acpi_install_gpe_block
++EXPORT_SYMBOL vmlinux 0x97dfc650	write_inode_now
++EXPORT_SYMBOL vmlinux 0x97e4a860	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x97e5b645	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0x97f43f03	wireless_send_event
++EXPORT_SYMBOL vmlinux 0x97faed2b	pnp_unregister_card_driver
++EXPORT_SYMBOL vmlinux 0x9820b644	warn_slowpath_fmt_taint
++EXPORT_SYMBOL vmlinux 0x9829fc11	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0x98482fc9	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0x985fe9ae	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0x98601bc6	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x986da01f	seq_pad
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x9878745c	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x988d0a29	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0x988ed85d	set_memory_x
++EXPORT_SYMBOL vmlinux 0x98b9f739	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x98bcbb39	blk_rq_init
++EXPORT_SYMBOL vmlinux 0x98c68c41	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x98d37bc0	tty_register_device
++EXPORT_SYMBOL vmlinux 0x98de1def	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0x98ecbae2	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x98fb85b5	amd_iommu_domain_set_gcr3
++EXPORT_SYMBOL vmlinux 0x98fbeb27	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0x98ffbdd2	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x990d879b	agp_unbind_memory
++EXPORT_SYMBOL vmlinux 0x99195078	vsnprintf
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x99714dc4	set_anon_super
++EXPORT_SYMBOL vmlinux 0x9976105c	eth_header_cache
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99aa2bb9	alloc_disk
++EXPORT_SYMBOL vmlinux 0x99c5ed14	seq_file_path
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d3a43c	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x99d998f6	dqput
++EXPORT_SYMBOL vmlinux 0x99daa9bf	try_offline_node
++EXPORT_SYMBOL vmlinux 0x99ddf9b1	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0x99ed424b	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x99f068d5	x86_cpu_to_node_map
++EXPORT_SYMBOL vmlinux 0x99f175d8	napi_complete_done
++EXPORT_SYMBOL vmlinux 0x99f3f93e	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x9a091879	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0x9a1019b5	kobject_add
++EXPORT_SYMBOL vmlinux 0x9a1c6d2e	blk_init_queue
++EXPORT_SYMBOL vmlinux 0x9a1d755b	d_splice_alias
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a3d4d7a	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0x9a7992cd	sock_rfree
++EXPORT_SYMBOL vmlinux 0x9a9e301d	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0x9aab0bd7	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0x9ab437f5	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x9ad2d93e	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x9ae5f0cd	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0x9ae6f874	node_data
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9afa039e	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b596272	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba146bf	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bbe88b3	flex_array_put
++EXPORT_SYMBOL vmlinux 0x9bdcb8f7	nvdimm_namespace_capacity
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9c14ff25	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0x9c161158	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x9c3b6ee5	__frontswap_test
++EXPORT_SYMBOL vmlinux 0x9c41624c	compat_ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x9c46685e	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c6a6b64	udplite_prot
++EXPORT_SYMBOL vmlinux 0x9c9075e5	kobject_get
++EXPORT_SYMBOL vmlinux 0x9c9dd1b9	sock_create_kern
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9ccb3589	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0x9ce76489	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d14dae4	vga_switcheroo_register_client
++EXPORT_SYMBOL vmlinux 0x9d2b3a51	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x9d33ef5e	acpi_enable
++EXPORT_SYMBOL vmlinux 0x9d3635fd	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d41c7b0	skb_clone
++EXPORT_SYMBOL vmlinux 0x9d54ed5c	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0x9d5a3eb7	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0x9d5bb6a5	flow_cache_init
++EXPORT_SYMBOL vmlinux 0x9d855e17	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0x9d9c8324	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0x9da05e10	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0x9df5da1f	vme_lm_request
++EXPORT_SYMBOL vmlinux 0x9dfc3e38	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0x9e098e2b	cpu_sibling_map
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e2f8c90	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9e363b6b	acpi_disable_gpe
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e621f47	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0x9e64fbfe	rtc_cmos_read
++EXPORT_SYMBOL vmlinux 0x9e6c5ae1	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e7d6bd0	__udelay
++EXPORT_SYMBOL vmlinux 0x9e85b34e	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0x9e8a0fe2	md_check_recovery
++EXPORT_SYMBOL vmlinux 0x9e97fc66	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9eaf4194	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x9eaf6910	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9ed11456	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x9ef6ad62	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0x9efaed7d	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0x9f41daed	sock_wake_async
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f6a3408	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x9f7c1be8	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9fa70f2f	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x9fabfa78	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0x9fc47ae6	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x9fd7cda1	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa005a51c	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xa00aca2a	dql_completed
++EXPORT_SYMBOL vmlinux 0xa0152de7	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0xa040a612	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa049182f	user_path_create
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa04a345f	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0xa04bf95b	rt6_lookup
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa05d1020	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0xa06ff399	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xa072c55b	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0xa07a37f0	memchr
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa0824497	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa08d385c	block_read_full_page
++EXPORT_SYMBOL vmlinux 0xa08f3a7f	input_allocate_device
++EXPORT_SYMBOL vmlinux 0xa0a43264	sget
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0dbea2d	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0xa0e63942	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0ff74d6	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa1309da6	dup_iter
++EXPORT_SYMBOL vmlinux 0xa135ad7a	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0xa13684bd	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0xa139b8ef	dev_mc_del
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa14b3f5d	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0xa15ac66f	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0xa1622117	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0xa1809250	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0xa180eebf	do_splice_to
++EXPORT_SYMBOL vmlinux 0xa1aba20e	netdev_notice
++EXPORT_SYMBOL vmlinux 0xa1b1c528	__ht_create_irq
++EXPORT_SYMBOL vmlinux 0xa1b59b90	nonseekable_open
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1cb5c3c	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa202a8e5	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa20b0854	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0xa213b814	clk_add_alias
++EXPORT_SYMBOL vmlinux 0xa2263f7a	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0xa246d3dd	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0xa27bc636	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0xa283420e	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa297db40	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0xa2a335bd	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0xa2c32b61	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0xa2facbd4	simple_link
++EXPORT_SYMBOL vmlinux 0xa2fe4c05	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0xa304156b	__block_write_begin
++EXPORT_SYMBOL vmlinux 0xa30dc5dd	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0xa30e18f8	pv_cpu_ops
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa33c5491	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0xa34bf438	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0xa34c7e3e	netlink_unicast
++EXPORT_SYMBOL vmlinux 0xa34fcb2d	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xa350a8f8	set_memory_array_uc
++EXPORT_SYMBOL vmlinux 0xa3687147	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0xa37a816d	inet6_bind
++EXPORT_SYMBOL vmlinux 0xa37e78b6	flex_array_get
++EXPORT_SYMBOL vmlinux 0xa38671b2	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0xa3a12147	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0xa3b75735	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0xa3e0422e	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0xa3e22c89	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0xa3fde6e2	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0xa425e908	set_page_dirty
++EXPORT_SYMBOL vmlinux 0xa438d12e	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0xa438e2a8	neigh_update
++EXPORT_SYMBOL vmlinux 0xa4416412	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0xa4511467	crc16
++EXPORT_SYMBOL vmlinux 0xa469a3cc	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa475c418	d_set_d_op
++EXPORT_SYMBOL vmlinux 0xa484cfd9	nvdimm_bus_lock
++EXPORT_SYMBOL vmlinux 0xa4b94fea	iowrite8_rep
++EXPORT_SYMBOL vmlinux 0xa4d0e9a9	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0xa4d4f0e6	global_cache_flush
++EXPORT_SYMBOL vmlinux 0xa4db8321	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0xa4e0c1e4	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0xa4e15088	d_delete
++EXPORT_SYMBOL vmlinux 0xa4eca6a8	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0xa4f6c63f	agp_find_bridge
++EXPORT_SYMBOL vmlinux 0xa4f6d98e	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xa4f87310	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xa50a80c2	boot_cpu_data
++EXPORT_SYMBOL vmlinux 0xa52e4ca1	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0xa5366824	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0xa53ca5ee	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa5701399	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0xa57114b1	register_cdrom
++EXPORT_SYMBOL vmlinux 0xa5753021	mount_single
++EXPORT_SYMBOL vmlinux 0xa59593dc	udp_ioctl
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa5a51eee	__crc32c_le
++EXPORT_SYMBOL vmlinux 0xa5a98e13	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0xa5ad5a3d	tty_throttle
++EXPORT_SYMBOL vmlinux 0xa5dc40e1	current_fs_time
++EXPORT_SYMBOL vmlinux 0xa5e7f188	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0xa5ec2325	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0xa5f62b93	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0xa5fa236a	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0xa615bdc5	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0xa63322c6	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa6489437	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0xa65d050a	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0xa669e70b	mapping_tagged
++EXPORT_SYMBOL vmlinux 0xa66e718a	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa6ad83e7	security_path_link
++EXPORT_SYMBOL vmlinux 0xa6bbd805	__wake_up
++EXPORT_SYMBOL vmlinux 0xa6bd63ca	acpi_bios_error
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa70fabbe	release_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0xa713acf1	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0xa713f3a6	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0xa7163bb8	lookup_bdev
++EXPORT_SYMBOL vmlinux 0xa71d99dd	km_policy_expired
++EXPORT_SYMBOL vmlinux 0xa72a0f5b	nr_online_nodes
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa748ac3d	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0xa74a6525	padata_free
++EXPORT_SYMBOL vmlinux 0xa74bcd62	rdmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0xa75aa9d0	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0xa763a046	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0xa77df734	path_get
++EXPORT_SYMBOL vmlinux 0xa788f1a0	i8253_lock
++EXPORT_SYMBOL vmlinux 0xa7b21bd5	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0xa7cb4871	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0xa7ccb6f1	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0xa7d7ec65	netdev_crit
++EXPORT_SYMBOL vmlinux 0xa8022b70	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0xa80fca46	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xa81462a0	iterate_fd
++EXPORT_SYMBOL vmlinux 0xa828fa43	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa8638435	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa8a06f88	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0xa8a1719e	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0xa8aa72a8	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0xa8bd66dc	dm_register_target
++EXPORT_SYMBOL vmlinux 0xa8cba40d	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0xa8cbe9f8	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0xa8ccfe55	simple_readpage
++EXPORT_SYMBOL vmlinux 0xa8cfe1f4	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0xa8fe98f2	filp_open
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa90af8f3	x86_dma_fallback_dev
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa916b694	strnlen
++EXPORT_SYMBOL vmlinux 0xa91761f9	elevator_init
++EXPORT_SYMBOL vmlinux 0xa91d90d3	nla_put
++EXPORT_SYMBOL vmlinux 0xa9220a25	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0xa92fc8a8	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0xa9311c3e	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0xa9504bc2	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0xa959aacb	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa982f03d	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xa99b39c2	prandom_bytes
++EXPORT_SYMBOL vmlinux 0xa9a8e17f	arch_phys_wc_add
++EXPORT_SYMBOL vmlinux 0xa9ab1788	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0xa9bd2676	__vmalloc
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xaa0c8612	set_bh_page
++EXPORT_SYMBOL vmlinux 0xaa207881	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0xaa392e83	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0xaa5bd08d	__pv_queued_spin_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaaa306c6	pci_request_region
++EXPORT_SYMBOL vmlinux 0xaaaac71a	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0xaab68850	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0xaac5a89f	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaad9218b	agp_generic_alloc_page
++EXPORT_SYMBOL vmlinux 0xaae8ab0e	acpi_bus_power_manageable
++EXPORT_SYMBOL vmlinux 0xaaeedeeb	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab4cb7c9	pnpacpi_protocol
++EXPORT_SYMBOL vmlinux 0xab4e65e5	ps2_command
++EXPORT_SYMBOL vmlinux 0xab551fad	acpi_get_data_full
++EXPORT_SYMBOL vmlinux 0xab600421	probe_irq_off
++EXPORT_SYMBOL vmlinux 0xab65ed80	set_memory_uc
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab770678	rdmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab7f6697	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xaba3159c	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0xaba5ac08	cros_ec_cmd_xfer_status
++EXPORT_SYMBOL vmlinux 0xabbbb61b	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0xabc3b66b	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0xabc9e148	ata_print_version
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xac09832c	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac1eb1d6	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0xac398912	flex_array_clear
++EXPORT_SYMBOL vmlinux 0xac3d1d56	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0xac48f3b9	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0xac604020	blk_end_request
++EXPORT_SYMBOL vmlinux 0xac6a6408	register_filesystem
++EXPORT_SYMBOL vmlinux 0xaca5727a	agp_put_bridge
++EXPORT_SYMBOL vmlinux 0xaca9bcd2	pnp_disable_dev
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacb99769	ida_destroy
++EXPORT_SYMBOL vmlinux 0xacc76868	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xacf56f49	genphy_update_link
++EXPORT_SYMBOL vmlinux 0xad01744f	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad164875	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xad17fa37	dev_err
++EXPORT_SYMBOL vmlinux 0xad1e91bf	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0xad261d36	tcp_filter
++EXPORT_SYMBOL vmlinux 0xad3c9b62	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0xad698f77	dqstats
++EXPORT_SYMBOL vmlinux 0xad6e1555	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0xad6e4bb6	mempool_free
++EXPORT_SYMBOL vmlinux 0xad73ef4b	vm_mmap
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad8ffc74	soft_cursor
++EXPORT_SYMBOL vmlinux 0xada3412a	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0xadb2a920	address_space_init_once
++EXPORT_SYMBOL vmlinux 0xadb2bef3	acl_by_type
++EXPORT_SYMBOL vmlinux 0xadd6dae6	tty_check_change
++EXPORT_SYMBOL vmlinux 0xadd771b2	security_path_unlink
++EXPORT_SYMBOL vmlinux 0xade21e6f	path_put
++EXPORT_SYMBOL vmlinux 0xade3d4f0	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xae044bc7	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0xae0826e9	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0xae0ba24b	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0xae26de29	set_pages_array_uc
++EXPORT_SYMBOL vmlinux 0xae2867a1	dev_addr_del
++EXPORT_SYMBOL vmlinux 0xae520a16	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0xae6766e6	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0xae71feb4	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0xae732686	freeze_super
++EXPORT_SYMBOL vmlinux 0xae74188c	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0xae90438f	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0xaea140b8	single_release
++EXPORT_SYMBOL vmlinux 0xaea976a8	acpi_check_resource_conflict
++EXPORT_SYMBOL vmlinux 0xaeb0a47b	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0xaeb9f98d	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0xaef5ff2e	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0xaeffd738	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0xaf09dec1	vmap
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf460dba	netdev_features_change
++EXPORT_SYMBOL vmlinux 0xaf5b1085	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0xaf606bd9	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0xaf611eac	amd_nb_misc_ids
++EXPORT_SYMBOL vmlinux 0xaf6ae696	kstrndup
++EXPORT_SYMBOL vmlinux 0xaf6cce6c	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0xafb8c6ff	copy_user_generic_string
++EXPORT_SYMBOL vmlinux 0xafc50476	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0xafd5ff2c	amd_iommu_v2_supported
++EXPORT_SYMBOL vmlinux 0xafe0fd24	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0xaff05472	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0xaffa7830	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0xaffa8ae2	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xb00a4c75	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0xb01244c2	set_blocksize
++EXPORT_SYMBOL vmlinux 0xb0140dfb	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0xb016369e	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xb019eb9b	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0xb01b1db8	intel_gtt_insert_sg_entries
++EXPORT_SYMBOL vmlinux 0xb028d8fd	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0xb051579b	skb_insert
++EXPORT_SYMBOL vmlinux 0xb057ef0b	d_drop
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb09de40c	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0a39f0b	inet_select_addr
++EXPORT_SYMBOL vmlinux 0xb0b34544	netdev_err
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0bd0533	locks_init_lock
++EXPORT_SYMBOL vmlinux 0xb0d12af0	simple_setattr
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0e602eb	memmove
++EXPORT_SYMBOL vmlinux 0xb0e9be2e	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0xb0eb41ff	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0xb0f44b3b	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0xb0f64288	dcb_getapp
++EXPORT_SYMBOL vmlinux 0xb101ea46	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0xb10604db	sync_inode
++EXPORT_SYMBOL vmlinux 0xb113240a	genphy_resume
++EXPORT_SYMBOL vmlinux 0xb121390a	probe_irq_on
++EXPORT_SYMBOL vmlinux 0xb123b82b	datagram_poll
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb152d87d	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb16acd2e	iterate_mounts
++EXPORT_SYMBOL vmlinux 0xb176c05e	acpi_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xb17ec862	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0xb1873bd3	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0xb187b3a8	lg_lock_init
++EXPORT_SYMBOL vmlinux 0xb19e1f56	dcb_setapp
++EXPORT_SYMBOL vmlinux 0xb1a0be2f	pipe_unlock
++EXPORT_SYMBOL vmlinux 0xb1ba6826	dev_activate
++EXPORT_SYMBOL vmlinux 0xb1c1170d	dentry_open
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1cfad22	rdmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xb1d3ed0f	vfs_llseek
++EXPORT_SYMBOL vmlinux 0xb20ecf88	acpi_run_osc
++EXPORT_SYMBOL vmlinux 0xb20f9ca4	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0xb219d56c	wbinvd_on_cpu
++EXPORT_SYMBOL vmlinux 0xb2255e2c	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0xb235c373	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0xb240ac21	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0xb241b093	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0xb24e7b28	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0xb24fbc0e	da903x_query_status
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb269dc76	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0xb274ec72	bio_advance
++EXPORT_SYMBOL vmlinux 0xb27cd284	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2d5a552	complete
++EXPORT_SYMBOL vmlinux 0xb2d966a8	simple_fill_super
++EXPORT_SYMBOL vmlinux 0xb2e3db61	nf_log_set
++EXPORT_SYMBOL vmlinux 0xb2e9bcf7	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0xb2f74fb6	intel_gmch_remove
++EXPORT_SYMBOL vmlinux 0xb2fd5ceb	__put_user_4
++EXPORT_SYMBOL vmlinux 0xb30e206c	__free_pages
++EXPORT_SYMBOL vmlinux 0xb3284531	acpi_dbg_layer
++EXPORT_SYMBOL vmlinux 0xb3332a6f	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0xb334161e	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0xb33e34b0	nvdimm_bus_unlock
++EXPORT_SYMBOL vmlinux 0xb34a7199	inet_add_offload
++EXPORT_SYMBOL vmlinux 0xb352177e	find_first_bit
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb40d2fe3	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0xb40d8a63	stop_tty
++EXPORT_SYMBOL vmlinux 0xb41bab83	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0xb4231b14	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb42e5f78	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xb430b84e	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0xb4328ac4	mutex_lock
++EXPORT_SYMBOL vmlinux 0xb441fdf7	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0xb45abdc3	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0xb464b31f	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb47189b5	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xb4783235	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0xb4a28341	pci_dev_get
++EXPORT_SYMBOL vmlinux 0xb4c80374	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0xb4ceab69	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0xb4d5984b	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0xb4d5b679	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0xb4da68a1	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0xb50c8cb9	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0xb52ee8be	intel_gtt_clear_range
++EXPORT_SYMBOL vmlinux 0xb55027c3	dev_close
++EXPORT_SYMBOL vmlinux 0xb56001cb	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb589afec	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xb59443da	ip_options_compile
++EXPORT_SYMBOL vmlinux 0xb5971222	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0xb597b3f7	fb_pan_display
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5b185b1	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0xb5b41feb	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb5cc8bf1	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0xb5cc9b7e	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0xb5d238a1	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0xb5dbd16a	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0xb5ecf214	tc_classify
++EXPORT_SYMBOL vmlinux 0xb5ef8745	proc_symlink
++EXPORT_SYMBOL vmlinux 0xb5fecb9e	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xb60b2957	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0xb6150a07	param_set_invbool
++EXPORT_SYMBOL vmlinux 0xb615cf1b	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0xb61f7200	kern_path
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb6395a35	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0xb640708c	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0xb65960a9	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0xb66928ea	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0xb674a534	acpi_unmap_cpu
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb681f6ce	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0xb6920562	downgrade_write
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6ae54a8	sync_filesystem
++EXPORT_SYMBOL vmlinux 0xb6b1a614	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0xb6c3f396	generic_write_checks
++EXPORT_SYMBOL vmlinux 0xb700ab7d	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0xb70213fc	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0xb70688b1	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0xb7225ad6	account_page_redirty
++EXPORT_SYMBOL vmlinux 0xb72c5845	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0xb735920f	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb758b225	acpi_disable_event
++EXPORT_SYMBOL vmlinux 0xb75be552	mount_ns
++EXPORT_SYMBOL vmlinux 0xb7681e7c	dev_warn
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb788c428	__register_chrdev
++EXPORT_SYMBOL vmlinux 0xb7a06cba	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7d2a32f	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0xb80d9912	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0xb812fd7f	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xb81afd72	set_create_files_as
++EXPORT_SYMBOL vmlinux 0xb821647c	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0xb827d039	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0xb871dc54	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb87d6019	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0xb8a5bd81	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0xb8a5f8bb	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0xb8b6a76c	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0xb8bf8996	d_instantiate
++EXPORT_SYMBOL vmlinux 0xb8e3aaa6	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0xb8e7ce2c	__put_user_8
++EXPORT_SYMBOL vmlinux 0xb8fdcd10	mempool_resize
++EXPORT_SYMBOL vmlinux 0xb907513f	unpoison_memory
++EXPORT_SYMBOL vmlinux 0xb909e0e6	get_super
++EXPORT_SYMBOL vmlinux 0xb9377a91	input_set_capability
++EXPORT_SYMBOL vmlinux 0xb94a8915	inode_init_always
++EXPORT_SYMBOL vmlinux 0xb95a4f68	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0xb979bdfb	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0xb99ab7ac	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0xb9aef31e	pci_biosrom_size
++EXPORT_SYMBOL vmlinux 0xb9c4db76	agp_generic_type_to_mask_type
++EXPORT_SYMBOL vmlinux 0xb9d4f09e	sync_blockdev
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xb9ff0ac9	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0xba087a71	phy_suspend
++EXPORT_SYMBOL vmlinux 0xba0d7cae	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0xba25df74	sock_no_listen
++EXPORT_SYMBOL vmlinux 0xba2d8594	ec_read
++EXPORT_SYMBOL vmlinux 0xba370af2	seq_escape
++EXPORT_SYMBOL vmlinux 0xba3b31e9	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0xba3b3a86	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba69804a	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0xba69b120	unlock_rename
++EXPORT_SYMBOL vmlinux 0xba8acdbf	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0xbabb7400	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb2ec6cc	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0xbb34134a	iov_shorten
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb4f4766	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb63b023	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0xbb9638b4	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbb9ddbc0	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0xbba70a2d	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xbba9745a	simple_write_end
++EXPORT_SYMBOL vmlinux 0xbbaeb559	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0xbbaf5968	tso_start
++EXPORT_SYMBOL vmlinux 0xbbe4a04b	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0xbbeb1ec6	ioremap_wt
++EXPORT_SYMBOL vmlinux 0xbc03d1cc	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0xbc155aed	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0xbc1974e9	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0xbc1a7c56	param_set_copystring
++EXPORT_SYMBOL vmlinux 0xbc1ea818	touch_atime
++EXPORT_SYMBOL vmlinux 0xbc2031de	acpi_processor_get_bios_limit
++EXPORT_SYMBOL vmlinux 0xbc605c10	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0xbc9db617	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0xbca20545	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0xbca6143b	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0xbcb49d38	bioset_free
++EXPORT_SYMBOL vmlinux 0xbcbd6199	ppp_input_error
++EXPORT_SYMBOL vmlinux 0xbcbd6d3e	vfs_link
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcdc1d91	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0xbcef02ad	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0xbcfc3cd5	tty_kref_put
++EXPORT_SYMBOL vmlinux 0xbd1a7e55	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0xbd26f77e	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0xbd27bd2d	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0xbd462b55	__kfifo_init
++EXPORT_SYMBOL vmlinux 0xbd6cf327	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0xbd6d79f1	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbdaf5b07	acpi_os_read_port
++EXPORT_SYMBOL vmlinux 0xbdc6b187	cpu_tss
++EXPORT_SYMBOL vmlinux 0xbdc99c2f	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0xbde70e44	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0xbdf2533c	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0xbdfb6dbb	__fentry__
++EXPORT_SYMBOL vmlinux 0xbe067e1f	pci_clear_master
++EXPORT_SYMBOL vmlinux 0xbe0ab81e	dev_alert
++EXPORT_SYMBOL vmlinux 0xbe1150a6	register_netdevice
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe3146b6	amd_iommu_domain_direct_map
++EXPORT_SYMBOL vmlinux 0xbe9ca4d8	sock_i_ino
++EXPORT_SYMBOL vmlinux 0xbec30d05	x86_match_cpu
++EXPORT_SYMBOL vmlinux 0xbec3424c	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0xbed1ade8	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0xbee276c6	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0xbeed2e8e	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf1b07ee	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0xbf1cd2a7	alloc_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0xbf439646	__get_user_pages
++EXPORT_SYMBOL vmlinux 0xbf4dca92	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0xbf4f8eab	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0xbf54873e	tty_free_termios
++EXPORT_SYMBOL vmlinux 0xbf6c0682	acpi_bus_get_device
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf829e0b	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0xbf832354	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf98863a	tty_hangup
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfa3e5f4	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0xbfac13ba	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0xbfb0e196	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0xbfb760a9	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0xbfc177bc	iowrite32_rep
++EXPORT_SYMBOL vmlinux 0xbfe1152b	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xc017f56c	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0xc04794e3	inet6_protos
++EXPORT_SYMBOL vmlinux 0xc04a03be	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xc0520b6b	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0xc05e355f	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc07c80f5	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc09c8e35	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0xc0a1407d	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0cd3b13	___ratelimit
++EXPORT_SYMBOL vmlinux 0xc108b7f4	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0xc119b2d4	fget
++EXPORT_SYMBOL vmlinux 0xc1414e3f	file_remove_privs
++EXPORT_SYMBOL vmlinux 0xc15a44c6	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xc1965605	__invalidate_device
++EXPORT_SYMBOL vmlinux 0xc1c9543c	set_trace_device
++EXPORT_SYMBOL vmlinux 0xc1cbbd10	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc1e843d5	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0xc1f0fca6	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0xc208a0b1	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0xc210c982	param_set_ushort
++EXPORT_SYMBOL vmlinux 0xc2120ad9	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0xc2146bde	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0xc21e73a5	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0xc22bb673	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0xc2316fc9	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0xc234c00a	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0xc2424641	agp3_generic_cleanup
++EXPORT_SYMBOL vmlinux 0xc24449d3	sk_free
++EXPORT_SYMBOL vmlinux 0xc26b1766	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0xc288044b	acpi_processor_notify_smm
++EXPORT_SYMBOL vmlinux 0xc29bf967	strspn
++EXPORT_SYMBOL vmlinux 0xc29ef5a5	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0xc2a5d328	phy_device_free
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2af3120	nla_append
++EXPORT_SYMBOL vmlinux 0xc2c28213	fb_find_mode
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc2e58833	unregister_netdev
++EXPORT_SYMBOL vmlinux 0xc2f220b2	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xc310b981	strnstr
++EXPORT_SYMBOL vmlinux 0xc312dfde	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0xc315cbf4	mount_subtree
++EXPORT_SYMBOL vmlinux 0xc3201a46	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0xc32acc76	vfs_writev
++EXPORT_SYMBOL vmlinux 0xc34ba9bf	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0xc350b4eb	wrmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0xc356aa25	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0xc38ddf78	netdev_state_change
++EXPORT_SYMBOL vmlinux 0xc393146e	block_truncate_page
++EXPORT_SYMBOL vmlinux 0xc3966737	is_bad_inode
++EXPORT_SYMBOL vmlinux 0xc3aaf0a9	__put_user_1
++EXPORT_SYMBOL vmlinux 0xc3b0a9f2	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0xc3bf1cf6	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3c7d03e	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0xc3d2c0cd	__register_nls
++EXPORT_SYMBOL vmlinux 0xc3da66d6	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0xc3e05a3c	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0xc3e49e64	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0xc3ed1ebb	param_ops_short
++EXPORT_SYMBOL vmlinux 0xc4025314	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0xc441369a	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0xc4596795	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0xc482c967	proc_set_size
++EXPORT_SYMBOL vmlinux 0xc48307db	lz4_decompress
++EXPORT_SYMBOL vmlinux 0xc4908af0	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0xc4915808	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4b591a9	del_gendisk
++EXPORT_SYMBOL vmlinux 0xc4c0bac2	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0xc4f331c6	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0xc4f7503f	inet_frag_find
++EXPORT_SYMBOL vmlinux 0xc4fdb30b	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0xc5137552	x86_bios_cpu_apicid
++EXPORT_SYMBOL vmlinux 0xc52ec2bf	udp_poll
++EXPORT_SYMBOL vmlinux 0xc5534d64	ioread16
++EXPORT_SYMBOL vmlinux 0xc558530d	profile_pc
++EXPORT_SYMBOL vmlinux 0xc5621972	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0xc5669258	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0xc5718826	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0xc57287f3	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0xc57a2078	acpi_match_device_ids
++EXPORT_SYMBOL vmlinux 0xc5929eb0	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xc59776b8	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc5d0cfc9	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0xc5d9c46c	agp_try_unsupported_boot
++EXPORT_SYMBOL vmlinux 0xc5e222ab	ping_prot
++EXPORT_SYMBOL vmlinux 0xc5f16c03	inet_frags_init
++EXPORT_SYMBOL vmlinux 0xc5f6a5d8	elevator_alloc
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc6150ab6	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc6415013	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0xc65abeb7	agp3_generic_sizes
++EXPORT_SYMBOL vmlinux 0xc666a132	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xc6772da2	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xc6824601	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0xc6975826	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0xc6b368d3	acpi_gpe_count
++EXPORT_SYMBOL vmlinux 0xc6cb465a	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc712502d	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0xc71ed727	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc733a903	use_ibpb
++EXPORT_SYMBOL vmlinux 0xc734381f	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0xc73834b7	dst_destroy
++EXPORT_SYMBOL vmlinux 0xc74d41b0	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0xc75047a3	neigh_for_each
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc7591cf0	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0xc76ab71e	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0xc7717b1d	acpi_processor_register_performance
++EXPORT_SYMBOL vmlinux 0xc7782a17	inet_bind
++EXPORT_SYMBOL vmlinux 0xc77af30f	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0xc7803a62	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc79bb4cb	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7c49ffe	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0xc7d035d0	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0xc7fa4700	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0xc7fcc5bf	acpi_resource_to_address64
++EXPORT_SYMBOL vmlinux 0xc815137c	single_open
++EXPORT_SYMBOL vmlinux 0xc81d643a	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0xc81deaf1	flush_signals
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc83f5cfc	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc85b6841	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xc860e0d3	param_set_int
++EXPORT_SYMBOL vmlinux 0xc862469b	param_set_byte
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc8799f38	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0xc88b2702	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc89acaaf	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0xc89e8a40	nd_region_acquire_lane
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8a9759f	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8cd16a9	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xc8cff934	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0xc8f6d231	tcp_child_process
++EXPORT_SYMBOL vmlinux 0xc90f8832	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc93c5c60	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc96c635d	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0xc978479a	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xc97cc7aa	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0xc98a9367	single_open_size
++EXPORT_SYMBOL vmlinux 0xc9912792	__dax_fault
++EXPORT_SYMBOL vmlinux 0xc995ca54	security_inode_permission
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc99f6aae	dma_spin_lock
++EXPORT_SYMBOL vmlinux 0xc9a4407f	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0xc9b2191e	mmc_erase
++EXPORT_SYMBOL vmlinux 0xc9b24d2a	phy_device_remove
++EXPORT_SYMBOL vmlinux 0xc9d2c62c	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0xc9f3bea1	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0xc9f77f44	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0xc9fb6af2	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0xc9fef317	add_wait_queue
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca1a2783	fput
++EXPORT_SYMBOL vmlinux 0xca2e829b	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0xca4d6313	pci_map_rom
++EXPORT_SYMBOL vmlinux 0xca5ee09a	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0xca763303	inet6_offloads
++EXPORT_SYMBOL vmlinux 0xca832efe	kmalloc_order
++EXPORT_SYMBOL vmlinux 0xca8acc78	acpi_dbg_level
++EXPORT_SYMBOL vmlinux 0xca8d95d4	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0xca900955	fb_is_primary_device
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xcab5b3c1	current_in_userns
++EXPORT_SYMBOL vmlinux 0xcabea97b	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0xcac83b66	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0xcacf29e4	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0xcaee698a	agp_backend_acquire
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcaf5f117	d_obtain_root
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb031945	input_close_device
++EXPORT_SYMBOL vmlinux 0xcb271276	nd_integrity_init
++EXPORT_SYMBOL vmlinux 0xcb4e8bb7	acpi_get_hp_hw_control_from_firmware
++EXPORT_SYMBOL vmlinux 0xcb733bf2	acpi_bus_set_power
++EXPORT_SYMBOL vmlinux 0xcb8a2048	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0xcb8d9322	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0xcb8e1d16	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0xcb936989	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcbae6c7a	acpi_lid_notifier_unregister
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbcf190a	__netif_schedule
++EXPORT_SYMBOL vmlinux 0xcbd6d852	pnp_start_dev
++EXPORT_SYMBOL vmlinux 0xcbec4bdf	param_ops_long
++EXPORT_SYMBOL vmlinux 0xcbf17a89	page_waitqueue
++EXPORT_SYMBOL vmlinux 0xcc0428ed	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0xcc24648d	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc27f909	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xcc2bc20a	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0xcc3a6f88	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0xcc3ae51b	__lock_page
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc546254	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0xcc5680fc	inet6_release
++EXPORT_SYMBOL vmlinux 0xcc580f11	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0xcc6082be	simple_getattr
++EXPORT_SYMBOL vmlinux 0xcc82add3	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xcc838223	__pte2cachemode_tbl
++EXPORT_SYMBOL vmlinux 0xcc8d3f4f	acpi_os_execute
++EXPORT_SYMBOL vmlinux 0xcc9aa2a6	register_sysctl
++EXPORT_SYMBOL vmlinux 0xccb0d76f	amd_iommu_complete_ppr
++EXPORT_SYMBOL vmlinux 0xccbc0084	sg_miter_start
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccdba8d8	open_exec
++EXPORT_SYMBOL vmlinux 0xcceee8d6	pnp_unregister_driver
++EXPORT_SYMBOL vmlinux 0xccfa2bb2	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0xcd20667a	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd3438a5	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0xcd57f7b0	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0xcd58ce84	serio_open
++EXPORT_SYMBOL vmlinux 0xcd828db5	agp_backend_release
++EXPORT_SYMBOL vmlinux 0xcda427d9	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0xcda63344	mpage_writepages
++EXPORT_SYMBOL vmlinux 0xcdabe586	keyring_search
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdc63c35	dquot_get_state
++EXPORT_SYMBOL vmlinux 0xcdca60d3	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0xcdd39abf	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0xce0e2d66	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce2c45cc	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xce4904a4	acpi_leave_sleep_state
++EXPORT_SYMBOL vmlinux 0xce4e47b6	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce652cef	filemap_fault
++EXPORT_SYMBOL vmlinux 0xce7778bd	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0xce7850e1	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0xce84fdee	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0xce9c630a	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xceae504f	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0xcec74ad3	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0xcedbd003	md_error
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcef6e12b	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0xcef8d9c3	invalidate_partition
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf112ff0	mmc_add_host
++EXPORT_SYMBOL vmlinux 0xcf36fe73	proto_unregister
++EXPORT_SYMBOL vmlinux 0xcf484eee	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0xcf4e186e	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0xcf649e4f	release_pages
++EXPORT_SYMBOL vmlinux 0xcf6cfe1f	msrs_free
++EXPORT_SYMBOL vmlinux 0xcf800d9f	blk_start_queue
++EXPORT_SYMBOL vmlinux 0xcf80e0d5	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0xcf9c88c9	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0xcfa1c596	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0xcfb4a296	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0xcfcdbc3a	agp_allocate_memory
++EXPORT_SYMBOL vmlinux 0xcfe46ead	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0xd012f4a4	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0xd026f568	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0xd04668e8	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0xd04df91b	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0xd0537bb5	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0xd0665727	genphy_suspend
++EXPORT_SYMBOL vmlinux 0xd06f2367	neigh_xmit
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd08da6d3	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0xd08f6239	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fef3b2	agp_free_key
++EXPORT_SYMBOL vmlinux 0xd1104291	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0xd136c8e0	key_validate
++EXPORT_SYMBOL vmlinux 0xd13ae4ac	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0xd1577498	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd1652a93	acpi_info
++EXPORT_SYMBOL vmlinux 0xd178ff70	vm_stat
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd1ac1346	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0xd1b30d48	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0xd1cfba77	cdev_alloc
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1f6c5f3	smp_num_siblings
++EXPORT_SYMBOL vmlinux 0xd2064e2f	idr_replace
++EXPORT_SYMBOL vmlinux 0xd20f3020	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xd2286108	get_phy_device
++EXPORT_SYMBOL vmlinux 0xd23b30d5	netlink_set_err
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2546927	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd270943c	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd27cbeb4	netdev_change_features
++EXPORT_SYMBOL vmlinux 0xd27fa985	prepare_binprm
++EXPORT_SYMBOL vmlinux 0xd29b6fda	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xd2b09ce5	__kmalloc
++EXPORT_SYMBOL vmlinux 0xd2b9548c	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0xd2c5ed04	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0xd2d10e7e	dev_mc_add
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2f4ddea	tty_port_open
++EXPORT_SYMBOL vmlinux 0xd2f5d089	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0xd34a17ef	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0xd36b1ad5	bd_set_size
++EXPORT_SYMBOL vmlinux 0xd36d3bb4	scsi_add_device
++EXPORT_SYMBOL vmlinux 0xd36e3d59	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0xd3719d59	paravirt_ticketlocks_enabled
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3f1867b	vfs_symlink
++EXPORT_SYMBOL vmlinux 0xd3f76442	dma_find_channel
++EXPORT_SYMBOL vmlinux 0xd402c1a3	ihold
++EXPORT_SYMBOL vmlinux 0xd448ad7f	__break_lease
++EXPORT_SYMBOL vmlinux 0xd45cc6ca	bin2hex
++EXPORT_SYMBOL vmlinux 0xd4619915	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0xd47a9bc5	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0xd4835ef8	dmi_check_system
++EXPORT_SYMBOL vmlinux 0xd4b42432	audit_log
++EXPORT_SYMBOL vmlinux 0xd4b6d393	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0xd4d392f1	kernel_connect
++EXPORT_SYMBOL vmlinux 0xd4e67b4c	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0xd4f33909	agp_enable
++EXPORT_SYMBOL vmlinux 0xd50fef48	acpi_detach_data
++EXPORT_SYMBOL vmlinux 0xd511bca0	to_nd_btt
++EXPORT_SYMBOL vmlinux 0xd5138f41	vfs_unlink
++EXPORT_SYMBOL vmlinux 0xd530cb5f	sget_userns
++EXPORT_SYMBOL vmlinux 0xd5430173	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd55ebc7e	truncate_setsize
++EXPORT_SYMBOL vmlinux 0xd56a30e0	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0xd586e77b	clk_get
++EXPORT_SYMBOL vmlinux 0xd5877263	i2c_transfer
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd5d51b8d	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0xd5d71373	fb_show_logo
++EXPORT_SYMBOL vmlinux 0xd5f760d8	iget_locked
++EXPORT_SYMBOL vmlinux 0xd60dad12	seq_open
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd626e425	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd6419547	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd6607fd1	sock_create
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd68cad4d	cros_ec_cmd_xfer
++EXPORT_SYMBOL vmlinux 0xd68e177f	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0xd68e1d1b	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0xd68f7305	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0xd6990313	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0xd6b2ed5f	generate_pm_trace
++EXPORT_SYMBOL vmlinux 0xd6b33026	cpu_khz
++EXPORT_SYMBOL vmlinux 0xd6e2893d	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0xd6e707f7	dquot_acquire
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd6f8d60c	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0xd707808a	nvm_register
++EXPORT_SYMBOL vmlinux 0xd730959d	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xd7389705	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0xd75374ad	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd77c2c12	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0xd78e0450	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0xd7b06182	make_kprojid
++EXPORT_SYMBOL vmlinux 0xd7be2995	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0xd7dd777b	reserve_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd7ead6e1	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0xd7fba6d8	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0xd7fdc508	mdiobus_free
++EXPORT_SYMBOL vmlinux 0xd801786d	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0xd8161326	register_qdisc
++EXPORT_SYMBOL vmlinux 0xd81dc270	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0xd83f8169	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0xd861352f	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0xd8738d5d	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0xd87ac9e5	try_module_get
++EXPORT_SYMBOL vmlinux 0xd8854bc6	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd9091363	acpi_install_notify_handler
++EXPORT_SYMBOL vmlinux 0xd90ebf8f	save_mount_options
++EXPORT_SYMBOL vmlinux 0xd912a2c7	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0xd91e001c	read_dev_sector
++EXPORT_SYMBOL vmlinux 0xd91faa21	__kfree_skb
++EXPORT_SYMBOL vmlinux 0xd92e2dca	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0xd940652f	nd_device_register
++EXPORT_SYMBOL vmlinux 0xd94322e7	acpi_evaluate_reference
++EXPORT_SYMBOL vmlinux 0xd945c1f3	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0xd95254ac	igrab
++EXPORT_SYMBOL vmlinux 0xd969b2c7	amd_e400_c1e_detected
++EXPORT_SYMBOL vmlinux 0xd9717d8d	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0xd971c6c4	xen_arch_register_cpu
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd9b07cba	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0xd9c2b771	processors
++EXPORT_SYMBOL vmlinux 0xd9c67fa9	cpu_info
++EXPORT_SYMBOL vmlinux 0xd9d3bcd3	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9f8d7ba	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0xda186067	vm_map_ram
++EXPORT_SYMBOL vmlinux 0xda1a1dc1	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0xda1fb5ad	generic_write_end
++EXPORT_SYMBOL vmlinux 0xda29655a	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0xda3241cc	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0xda35577e	i2c_use_client
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda43fc50	_dev_info
++EXPORT_SYMBOL vmlinux 0xda447f99	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0xda5108e1	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0xda636cc3	compat_nf_getsockopt
++EXPORT_SYMBOL vmlinux 0xda77de13	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda9fc7ae	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0xdab22ac9	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdaea6e0d	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0xdaf1eb29	cont_write_begin
++EXPORT_SYMBOL vmlinux 0xdafdeaab	nvdimm_revalidate_disk
++EXPORT_SYMBOL vmlinux 0xdb043c8a	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0xdb16b170	topology_phys_to_logical_pkg
++EXPORT_SYMBOL vmlinux 0xdb186e97	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0xdb3bcca6	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0xdb50c2dd	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0xdb5bd395	filp_close
++EXPORT_SYMBOL vmlinux 0xdb60abfa	nvm_end_io
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb6dc028	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0xdb7020ba	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0xdb7305a1	__stack_chk_fail
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb854474	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xdb86a079	page_symlink
++EXPORT_SYMBOL vmlinux 0xdb8fc278	pv_mmu_ops
++EXPORT_SYMBOL vmlinux 0xdb9e26ea	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0xdb9f83e1	end_page_writeback
++EXPORT_SYMBOL vmlinux 0xdbc3eea7	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0xdbce16a2	vfs_read
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc1ec55e	cpu_tlbstate
++EXPORT_SYMBOL vmlinux 0xdc293114	tty_write_room
++EXPORT_SYMBOL vmlinux 0xdc309283	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0xdc30f707	pnp_get_resource
++EXPORT_SYMBOL vmlinux 0xdc3c41a8	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xdc3c9fa4	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdc57f532	acpi_install_gpe_handler
++EXPORT_SYMBOL vmlinux 0xdc5f5da8	lockref_put_return
++EXPORT_SYMBOL vmlinux 0xdc75ef59	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xdc8699f8	dquot_enable
++EXPORT_SYMBOL vmlinux 0xdc892f3b	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0xdc9b6823	check_disk_change
++EXPORT_SYMBOL vmlinux 0xdca20af1	dget_parent
++EXPORT_SYMBOL vmlinux 0xdca5c4f8	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdcd4b472	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0xdd2260f4	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0xdd2cb0b2	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0xdd64e639	strscpy
++EXPORT_SYMBOL vmlinux 0xdd9697f5	sock_no_poll
++EXPORT_SYMBOL vmlinux 0xddb583f6	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0xdddb28a2	seq_puts
++EXPORT_SYMBOL vmlinux 0xddef0ae2	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0xde0f1a20	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0xde16dc16	tboot
++EXPORT_SYMBOL vmlinux 0xde17c7b0	kaiser_enabled
++EXPORT_SYMBOL vmlinux 0xde2543f2	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0xde29abac	agp_alloc_page_array
++EXPORT_SYMBOL vmlinux 0xde3c289d	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0xde45bd2f	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0xde6151db	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xde6232ea	skb_make_writable
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde9b17ed	agp3_generic_fetch_size
++EXPORT_SYMBOL vmlinux 0xdec2864a	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0xdedb6611	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0xdedbf17a	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0xdef92c8e	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0xdf0da3cc	acpi_get_devices
++EXPORT_SYMBOL vmlinux 0xdf12a927	acpi_check_dsm
++EXPORT_SYMBOL vmlinux 0xdf1427e5	idr_remove
++EXPORT_SYMBOL vmlinux 0xdf29b0de	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf358b6f	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0xdf35f46b	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0xdf47824c	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0xdf531c1c	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf5b1698	seq_vprintf
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf8c695a	__ndelay
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdf9b2477	dump_skip
++EXPORT_SYMBOL vmlinux 0xdfa252c5	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0xdfb62ac1	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0xdfbc6290	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0xdfc46bbd	blk_make_request
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xdfd3a075	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0xdfe6a6e5	give_up_console
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xdffdaca4	is_nvdimm_bus_locked
++EXPORT_SYMBOL vmlinux 0xe00d3922	inc_nlink
++EXPORT_SYMBOL vmlinux 0xe01b1c37	pipe_lock
++EXPORT_SYMBOL vmlinux 0xe03d175a	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0xe04e00e9	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe0573427	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe08226db	d_lookup
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe090200c	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0xe0ac8bd2	acpi_bus_generate_netlink_event
++EXPORT_SYMBOL vmlinux 0xe0b0cfb7	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0c54972	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0xe0cbc8f7	dev_printk
++EXPORT_SYMBOL vmlinux 0xe0d07318	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0xe0d8f9ae	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0xe0e8983e	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0xe0ea67da	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xe10b6aee	con_is_bound
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe12377ae	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0xe124c087	sock_create_lite
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe13cd8a7	dmi_name_in_vendors
++EXPORT_SYMBOL vmlinux 0xe1505731	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe17bfadd	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0xe18301bc	complete_request_key
++EXPORT_SYMBOL vmlinux 0xe183f867	secpath_dup
++EXPORT_SYMBOL vmlinux 0xe19856f8	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0xe1bb17f1	cdrom_release
++EXPORT_SYMBOL vmlinux 0xe1bde4cc	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0xe1cd5cfb	blk_complete_request
++EXPORT_SYMBOL vmlinux 0xe1ece345	dump_emit
++EXPORT_SYMBOL vmlinux 0xe1f67094	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe20372ae	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0xe226f641	bdevname
++EXPORT_SYMBOL vmlinux 0xe2330722	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe2427f94	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0xe247cf4f	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe259ae9e	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0xe25b045e	scsi_unregister
++EXPORT_SYMBOL vmlinux 0xe27283db	pnp_device_detach
++EXPORT_SYMBOL vmlinux 0xe27d4549	kernel_accept
++EXPORT_SYMBOL vmlinux 0xe298a062	param_ops_uint
++EXPORT_SYMBOL vmlinux 0xe29b04e9	acpi_set_firmware_waking_vector64
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2a27095	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0xe2b46958	amd_iommu_domain_clear_gcr3
++EXPORT_SYMBOL vmlinux 0xe2b4f781	down_read
++EXPORT_SYMBOL vmlinux 0xe2b53897	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xe2c15524	pci_bus_type
++EXPORT_SYMBOL vmlinux 0xe2c75b48	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0xe2cff3c8	eth_header
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2df6648	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0xe2e6e0fb	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe2f81ee5	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0xe308cdbe	__bread_gfp
++EXPORT_SYMBOL vmlinux 0xe317764d	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0xe319eb24	acpi_pci_osc_control_set
++EXPORT_SYMBOL vmlinux 0xe3278ed2	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0xe3399a75	native_queued_spin_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xe35730a9	serio_rescan
++EXPORT_SYMBOL vmlinux 0xe359140c	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0xe37e8c3a	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0xe393da4a	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0xe3965da1	key_type_keyring
++EXPORT_SYMBOL vmlinux 0xe3992461	free_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0xe3a53f4c	sort
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3d03364	netdev_emerg
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe408d98b	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0xe4124a5f	get_io_context
++EXPORT_SYMBOL vmlinux 0xe46688a4	cad_pid
++EXPORT_SYMBOL vmlinux 0xe46fd920	init_special_inode
++EXPORT_SYMBOL vmlinux 0xe47c7cfb	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0xe484e35f	ioread32
++EXPORT_SYMBOL vmlinux 0xe4937091	agp_free_memory
++EXPORT_SYMBOL vmlinux 0xe49b2b0c	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0xe4a4b009	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0xe4ca259a	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0xe4ccdc03	__lock_buffer
++EXPORT_SYMBOL vmlinux 0xe4d140ce	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0xe4d99100	input_unregister_device
++EXPORT_SYMBOL vmlinux 0xe4e0c91a	poll_freewait
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe4eaab2e	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0xe4f83ca0	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0xe50eac1a	vga_client_register
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe524e233	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0xe5284e79	neigh_table_init
++EXPORT_SYMBOL vmlinux 0xe530d757	acpi_clear_gpe
++EXPORT_SYMBOL vmlinux 0xe53e848d	nd_dev_to_uuid
++EXPORT_SYMBOL vmlinux 0xe5404251	dump_truncate
++EXPORT_SYMBOL vmlinux 0xe5438c14	posix_lock_file
++EXPORT_SYMBOL vmlinux 0xe5616ef6	mmc_release_host
++EXPORT_SYMBOL vmlinux 0xe57199ca	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe57d97ff	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0xe5815f8a	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe5958c6b	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0xe5a8f2f3	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5d74faa	phy_connect
++EXPORT_SYMBOL vmlinux 0xe5d8703f	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0xe5eaf807	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe5f408ee	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0xe60f0154	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0xe6162877	down_killable
++EXPORT_SYMBOL vmlinux 0xe61c50fc	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0xe647a6e2	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0xe64d98fe	rdmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0xe65a73d7	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xe66fc1bd	tty_port_put
++EXPORT_SYMBOL vmlinux 0xe675c5b7	mpage_readpages
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe69a9df4	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xe6a1c3d4	netdev_update_features
++EXPORT_SYMBOL vmlinux 0xe6b8cb49	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xe6be97e2	free_task
++EXPORT_SYMBOL vmlinux 0xe6dd21e6	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0xe6f0d56e	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe6fc528b	skb_tx_error
++EXPORT_SYMBOL vmlinux 0xe708c67e	led_blink_set
++EXPORT_SYMBOL vmlinux 0xe716baed	acpi_unregister_ioapic
++EXPORT_SYMBOL vmlinux 0xe74ba8d3	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xe7516813	simple_follow_link
++EXPORT_SYMBOL vmlinux 0xe7629fad	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0xe7690453	blk_put_request
++EXPORT_SYMBOL vmlinux 0xe76b1f30	__frontswap_store
++EXPORT_SYMBOL vmlinux 0xe78e2f9f	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7ad3ecf	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0xe7c0cc5a	kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0xe7c4ab39	simple_unlink
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7d912da	simple_rmdir
++EXPORT_SYMBOL vmlinux 0xe7eec68c	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0xe80cda97	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0xe8122f40	nobh_write_end
++EXPORT_SYMBOL vmlinux 0xe81ef1dd	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe8731918	x86_hyper_xen
++EXPORT_SYMBOL vmlinux 0xe877e13b	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8b85365	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0xe8bd0d36	from_kprojid
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8d3fce5	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0xe8da8288	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0xe8db8dd2	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0xe8ef0ff0	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0xe9015131	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0xe90aa3a4	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe92135af	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0xe94071cb	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0xe951adb9	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe95e00cf	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0xe964194b	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0xe96deaaa	elv_rb_find
++EXPORT_SYMBOL vmlinux 0xe9744cf1	pci_request_regions
++EXPORT_SYMBOL vmlinux 0xe997667b	wrmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xe9a45455	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0xe9ac774c	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0xe9acfac4	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xe9bd7844	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0xe9e068bd	netdev_printk
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xe9f78bab	down_read_trylock
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea0e1f88	n_tty_compat_ioctl_helper
++EXPORT_SYMBOL vmlinux 0xea10048f	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0xea18edeb	do_splice_direct
++EXPORT_SYMBOL vmlinux 0xea2238f6	kmem_cache_alloc_node_trace
++EXPORT_SYMBOL vmlinux 0xea2cd705	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0xea3718a7	bio_put
++EXPORT_SYMBOL vmlinux 0xea37487a	write_one_page
++EXPORT_SYMBOL vmlinux 0xea3f725d	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xea75db93	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0xea7a42f9	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xea7b8a44	acpi_install_interface
++EXPORT_SYMBOL vmlinux 0xea7cf94e	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0xea8bd8da	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0xea8c3f4d	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0xea90bdd3	acpi_attach_data
++EXPORT_SYMBOL vmlinux 0xea946285	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0xea94c50e	ps2_drain
++EXPORT_SYMBOL vmlinux 0xea9f76c8	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0xeaa32eb1	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0xeac73847	irq_regs
++EXPORT_SYMBOL vmlinux 0xeae3dfd6	__const_udelay
++EXPORT_SYMBOL vmlinux 0xeafcc2cf	do_splice_from
++EXPORT_SYMBOL vmlinux 0xeb0acb4f	file_ns_capable
++EXPORT_SYMBOL vmlinux 0xeb1ca0e5	dquot_file_open
++EXPORT_SYMBOL vmlinux 0xeb2191cf	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0xeb22e0c1	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0xeb30b52b	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb44339a	free_pages_exact
++EXPORT_SYMBOL vmlinux 0xeb540d5f	get_acl
++EXPORT_SYMBOL vmlinux 0xeb5a3189	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0xeb6d75b4	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0xeb6e2360	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0xeb7b46f5	f_setown
++EXPORT_SYMBOL vmlinux 0xeb7f22ce	generic_listxattr
++EXPORT_SYMBOL vmlinux 0xeb9f564f	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0xeba1836d	udp_del_offload
++EXPORT_SYMBOL vmlinux 0xebc0f1eb	put_disk
++EXPORT_SYMBOL vmlinux 0xebc94dc5	ata_port_printk
++EXPORT_SYMBOL vmlinux 0xebe687d1	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0xebe8a7ef	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0xebecfa1c	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0xebf540f5	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0xebff5cf5	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0xec0e5069	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0xec1b975b	param_ops_int
++EXPORT_SYMBOL vmlinux 0xec1ce6e8	d_make_root
++EXPORT_SYMBOL vmlinux 0xec1fdfa4	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0xec262607	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec957a5c	find_vma
++EXPORT_SYMBOL vmlinux 0xecab65f0	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0xecac8407	__memcpy
++EXPORT_SYMBOL vmlinux 0xeccd3e0c	acpi_handle_printk
++EXPORT_SYMBOL vmlinux 0xecd92d62	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xece9ce1b	compat_mc_getsockopt
++EXPORT_SYMBOL vmlinux 0xecee92f0	ata_link_printk
++EXPORT_SYMBOL vmlinux 0xecfd68ef	acpi_get_node
++EXPORT_SYMBOL vmlinux 0xed2f5275	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0xed340b5a	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0xed3e5dd2	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed5a604a	drop_super
++EXPORT_SYMBOL vmlinux 0xed730bfc	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0xed74757e	generic_perform_write
++EXPORT_SYMBOL vmlinux 0xed98475d	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedb18ffb	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xedb53c45	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0xedb9903f	param_set_long
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedc78e94	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0xedca0326	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0xedd11647	udp_set_csum
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xedf6ae56	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0xedf7ab08	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0xedfcc439	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0xedffcc28	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0xee0dcd01	param_get_ushort
++EXPORT_SYMBOL vmlinux 0xee141054	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee316def	blk_run_queue
++EXPORT_SYMBOL vmlinux 0xee34d6b5	acpi_bus_register_driver
++EXPORT_SYMBOL vmlinux 0xee3e5e4e	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xee61b390	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0xee7eb9e1	pnp_platform_devices
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xeea3cd7a	nla_reserve
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeeab11f2	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0xeec2c7cf	ucs2_as_utf8
++EXPORT_SYMBOL vmlinux 0xeedd92dc	console_start
++EXPORT_SYMBOL vmlinux 0xeee4c2bd	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0xeee9e30c	irq_to_desc
++EXPORT_SYMBOL vmlinux 0xeeed532a	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xeef427cb	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0xeef9075d	inet_accept
++EXPORT_SYMBOL vmlinux 0xef0be79f	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0xef1263ec	dquot_disable
++EXPORT_SYMBOL vmlinux 0xef34f9da	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0xef43a014	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0xef4a9c6f	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0xef530c46	km_report
++EXPORT_SYMBOL vmlinux 0xef5680a1	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0xef766ec2	scsi_device_get
++EXPORT_SYMBOL vmlinux 0xef9aedfc	boot_option_idle_override
++EXPORT_SYMBOL vmlinux 0xefa05c48	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefda8d99	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefe099c3	acpi_get_event_status
++EXPORT_SYMBOL vmlinux 0xefe0d792	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0xeff809a3	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf03ff904	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0xf0425a0d	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf062576b	ucs2_utf8size
++EXPORT_SYMBOL vmlinux 0xf065f629	ioread16be
++EXPORT_SYMBOL vmlinux 0xf067257c	register_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0xf069ff15	fb_blank
++EXPORT_SYMBOL vmlinux 0xf0815cba	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0xf08242c2	finish_wait
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0a4e773	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0xf0a5ff1f	bio_map_kern
++EXPORT_SYMBOL vmlinux 0xf0a8237a	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xf0adef22	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0xf0ea101f	input_grab_device
++EXPORT_SYMBOL vmlinux 0xf0eaffce	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf0f6b822	inet_del_offload
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf10de535	ioread8
++EXPORT_SYMBOL vmlinux 0xf11543ff	find_first_zero_bit
++EXPORT_SYMBOL vmlinux 0xf116d4b5	copy_in_user
++EXPORT_SYMBOL vmlinux 0xf129a01a	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0xf1333ab0	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0xf1398e2e	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf14fa2a3	__find_get_block
++EXPORT_SYMBOL vmlinux 0xf17b39f3	bdi_register
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf1a0415d	dput
++EXPORT_SYMBOL vmlinux 0xf1a3f3d8	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0xf1b312b4	vga_get
++EXPORT_SYMBOL vmlinux 0xf1b4380c	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0xf1c2044d	set_user_nice
++EXPORT_SYMBOL vmlinux 0xf1c9d085	fs_bio_set
++EXPORT_SYMBOL vmlinux 0xf1ca9d84	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0xf1cfa6f3	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1fdb436	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0xf2048c33	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf212dd05	acpi_bus_get_status
++EXPORT_SYMBOL vmlinux 0xf217726d	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0xf23533aa	block_write_begin
++EXPORT_SYMBOL vmlinux 0xf23a4675	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf2529314	km_state_expired
++EXPORT_SYMBOL vmlinux 0xf28ed6e2	machine_to_phys_nr
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2a2b163	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0xf2ad3c52	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xf2b41efc	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0xf2b7f352	__sb_start_write
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2dda68f	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xf2e01c98	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0xf2e57aab	kdb_current_task
++EXPORT_SYMBOL vmlinux 0xf2feb959	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0xf312cb9d	ucs2_strsize
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf3152403	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf35321cf	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf358794d	nf_reinject
++EXPORT_SYMBOL vmlinux 0xf3817795	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf395d164	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf3986b06	acpi_os_map_generic_address
++EXPORT_SYMBOL vmlinux 0xf3a2be53	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xf3ab56a0	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf3f37c52	vfs_readf
++EXPORT_SYMBOL vmlinux 0xf415231e	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0xf43f6a24	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0xf441ac43	ioread8_rep
++EXPORT_SYMBOL vmlinux 0xf4439009	set_pages_nx
++EXPORT_SYMBOL vmlinux 0xf46426b9	sock_edemux
++EXPORT_SYMBOL vmlinux 0xf4692cdb	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0xf473cf11	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf476082c	input_free_device
++EXPORT_SYMBOL vmlinux 0xf47a269d	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0xf4a05c79	__quota_error
++EXPORT_SYMBOL vmlinux 0xf4a5c213	avail_to_resrv_perfctr_nmi_bit
++EXPORT_SYMBOL vmlinux 0xf4ab0994	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0xf4afb28f	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0xf4b26af5	commit_creds
++EXPORT_SYMBOL vmlinux 0xf4b4ce61	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0xf4b754fd	acpi_resources_are_enforced
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4c8b9e7	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0xf4d3778c	input_open_device
++EXPORT_SYMBOL vmlinux 0xf4d568a2	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0xf4e1442d	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf513fa02	alloc_file
++EXPORT_SYMBOL vmlinux 0xf51ae235	touch_nmi_watchdog
++EXPORT_SYMBOL vmlinux 0xf51bf88b	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xf51c14fe	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0xf536d22e	acpi_set_gpe_wake_mask
++EXPORT_SYMBOL vmlinux 0xf53c4309	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf548abb7	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0xf57b4271	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL vmlinux 0xf5b10e67	acpi_install_global_event_handler
++EXPORT_SYMBOL vmlinux 0xf5c1dc25	set_nlink
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5c3b754	kern_unmount
++EXPORT_SYMBOL vmlinux 0xf5da342b	alloc_pages_current
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf5f3b07a	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0xf60e31c5	security_mmap_file
++EXPORT_SYMBOL vmlinux 0xf6267ba9	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf63fbbab	touch_buffer
++EXPORT_SYMBOL vmlinux 0xf65f1236	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0xf669f4e4	kill_bdev
++EXPORT_SYMBOL vmlinux 0xf66e2c7d	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0xf672d00e	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf67f4dc6	softnet_data
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf68c1b82	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0xf68dbc14	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0xf693a145	irq_stat
++EXPORT_SYMBOL vmlinux 0xf699984e	kobject_put
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf70d18bf	security_path_truncate
++EXPORT_SYMBOL vmlinux 0xf72bf475	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0xf72e1811	param_set_ulong
++EXPORT_SYMBOL vmlinux 0xf73d0785	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf764868a	udplite_table
++EXPORT_SYMBOL vmlinux 0xf77d324b	iget_failed
++EXPORT_SYMBOL vmlinux 0xf783e815	rtnl_notify
++EXPORT_SYMBOL vmlinux 0xf788d318	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0xf79bac2c	compat_sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0xf79e97cd	acpi_get_physical_device_location
++EXPORT_SYMBOL vmlinux 0xf7b2cae3	tty_port_init
++EXPORT_SYMBOL vmlinux 0xf7b778be	dev_uc_del
++EXPORT_SYMBOL vmlinux 0xf7c2269b	nf_log_register
++EXPORT_SYMBOL vmlinux 0xf7d6b7b9	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0xf7e0823a	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0xf7e153b7	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0xf7fb76f1	irq_set_chip
++EXPORT_SYMBOL vmlinux 0xf805b24a	freeze_bdev
++EXPORT_SYMBOL vmlinux 0xf80b4b93	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf812cff6	memscan
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf87e3be0	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0xf88e0ee2	acpi_get_table_header
++EXPORT_SYMBOL vmlinux 0xf8bbe0af	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0xf8c3b1b8	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0xf8d04f09	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0xf8e02a5e	tcp_connect
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf8f777c7	param_set_bint
++EXPORT_SYMBOL vmlinux 0xf90b25de	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xf92f84a5	agp_alloc_bridge
++EXPORT_SYMBOL vmlinux 0xf9304d12	inet_addr_type
++EXPORT_SYMBOL vmlinux 0xf9326899	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0xf93d6c96	tty_mutex
++EXPORT_SYMBOL vmlinux 0xf9881da8	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0xf98af266	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0xf9a3dfbe	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9a4a141	user_revoke
++EXPORT_SYMBOL vmlinux 0xf9b1075f	skb_split
++EXPORT_SYMBOL vmlinux 0xf9bd4ca0	kfree_skb
++EXPORT_SYMBOL vmlinux 0xf9bf144f	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0xf9c0b663	strlcat
++EXPORT_SYMBOL vmlinux 0xf9c714a6	devm_release_resource
++EXPORT_SYMBOL vmlinux 0xfa07e00b	passthru_features_check
++EXPORT_SYMBOL vmlinux 0xfa1cace5	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0xfa268cd2	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0xfa2e1b45	d_alloc
++EXPORT_SYMBOL vmlinux 0xfa345ab5	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0xfa4365f0	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0xfa48c6e9	kill_block_super
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa6328bf	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0xfaadbba7	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfae74c4d	__devm_release_region
++EXPORT_SYMBOL vmlinux 0xfb0443fb	acpi_get_parent
++EXPORT_SYMBOL vmlinux 0xfb099ada	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xfb138a8e	vfs_statfs
++EXPORT_SYMBOL vmlinux 0xfb28de91	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0xfb3f60ef	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0xfb473fb0	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0xfb578fc5	memset
++EXPORT_SYMBOL vmlinux 0xfb691d2f	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb80c7a0	acpi_walk_namespace
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfb959c51	find_lock_entry
++EXPORT_SYMBOL vmlinux 0xfba58595	ns_capable
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbb3ff03	__page_symlink
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbc9f382	scmd_printk
++EXPORT_SYMBOL vmlinux 0xfbd676c6	seq_printf
++EXPORT_SYMBOL vmlinux 0xfbdb0721	nd_iostat_end
++EXPORT_SYMBOL vmlinux 0xfbdeb1fa	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc08b925	pci_pme_active
++EXPORT_SYMBOL vmlinux 0xfc10e845	blk_get_queue
++EXPORT_SYMBOL vmlinux 0xfc13088f	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc3ee5bd	prepare_creds
++EXPORT_SYMBOL vmlinux 0xfc537be4	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0xfc734327	queued_read_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xfc7c05a9	serio_interrupt
++EXPORT_SYMBOL vmlinux 0xfc8210b8	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0xfc872fd1	get_ibs_caps
++EXPORT_SYMBOL vmlinux 0xfc918953	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0xfca0a626	loop_backing_file
++EXPORT_SYMBOL vmlinux 0xfcac0d40	acpi_install_interface_handler
++EXPORT_SYMBOL vmlinux 0xfcb926cd	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xfcbeae14	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcc40602	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0xfccc59bd	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0xfcda24ac	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfcfa722e	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0xfd009954	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0xfd0a3b95	param_get_int
++EXPORT_SYMBOL vmlinux 0xfd48e2ed	free_user_ns
++EXPORT_SYMBOL vmlinux 0xfd576bac	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0xfd635115	get_gendisk
++EXPORT_SYMBOL vmlinux 0xfd85d1bf	sock_efree
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfd9f53bf	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0xfda281e9	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0xfdb9b629	ioread32be
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfdd1943f	phy_init_hw
++EXPORT_SYMBOL vmlinux 0xfde044aa	__check_sticky
++EXPORT_SYMBOL vmlinux 0xfdf2d480	dst_release
++EXPORT_SYMBOL vmlinux 0xfdfb792f	amd_iommu_pc_supported
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfdfd6c90	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0xfe026c36	generic_read_dir
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe033169	dev_emerg
++EXPORT_SYMBOL vmlinux 0xfe047ce6	acpi_enter_sleep_state
++EXPORT_SYMBOL vmlinux 0xfe13c522	acpi_install_gpe_raw_handler
++EXPORT_SYMBOL vmlinux 0xfe17047b	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xfe1f84f3	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0xfe26fc7c	nr_node_ids
++EXPORT_SYMBOL vmlinux 0xfe353f4e	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0xfe5d30e9	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe6d755b	qdisc_reset
++EXPORT_SYMBOL vmlinux 0xfe6f11fa	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe855087	security_path_chown
++EXPORT_SYMBOL vmlinux 0xfe8b388e	compat_nf_setsockopt
++EXPORT_SYMBOL vmlinux 0xfe916dc6	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xfe9230da	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0xfe976ac6	flush_old_exec
++EXPORT_SYMBOL vmlinux 0xfe9ebbbb	acpi_osi_is_win8
++EXPORT_SYMBOL vmlinux 0xfeb9e6a6	nd_device_unregister
++EXPORT_SYMBOL vmlinux 0xfebd4542	bio_chain
++EXPORT_SYMBOL vmlinux 0xfec65de2	nd_pfn_validate
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfeebc7c4	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0xfef2c78f	idr_get_next
++EXPORT_SYMBOL vmlinux 0xff0245c5	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xff028791	seq_putc
++EXPORT_SYMBOL vmlinux 0xff14f09d	kaiser_flush_tlb_on_return_to_user
++EXPORT_SYMBOL vmlinux 0xff16ff4d	lro_flush_all
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff6b0bdf	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff9aa856	acpi_device_set_power
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xff9d85a7	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0xffa355d1	__register_nmi_handler
++EXPORT_SYMBOL vmlinux 0xffa3c891	dquot_destroy
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffd70041	acpi_pm_device_run_wake
++EXPORT_SYMBOL vmlinux 0xffdbb2de	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0xfff7cd57	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xfffbc853	posix_unblock_lock
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-x86_64 0x7060bf0a	crypto_aes_encrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-x86_64 0xe409b491	crypto_aes_decrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x13a65ecf	camellia_ecb_enc_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x17bf48dc	camellia_xts_dec_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x1a08ded1	camellia_xts_enc
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x47129015	camellia_xts_enc_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x7d54edc2	camellia_cbc_dec_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x7e87ef55	camellia_ecb_dec_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x8f185793	camellia_xts_dec
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x9e8086dc	camellia_ctr_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x16061d06	__camellia_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x1636abdf	__camellia_enc_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x1da0e256	camellia_crypt_ctr
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x31bbe42b	camellia_crypt_ctr_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x3e14798e	xts_camellia_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x50dc55b6	__camellia_enc_blk_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x930f687f	camellia_decrypt_cbc_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x9ceb996b	lrw_camellia_exit_tfm
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0xa41a5ad3	camellia_dec_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0xadd83ce5	lrw_camellia_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0xf4521fda	camellia_dec_blk_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x1dd85921	glue_cbc_decrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x61ce5b1f	glue_ecb_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x8f02ac4d	glue_xts_crypt_128bit_one
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xa28ed48e	glue_cbc_encrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xe112890c	glue_xts_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xf3592bcf	glue_ctr_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x016a957f	serpent_xts_enc_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x0c5a8af6	serpent_xts_dec_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x0ff3c26d	serpent_xts_dec
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x606a8162	serpent_cbc_dec_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x79ff0b7a	serpent_ecb_dec_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x7dd29718	lrw_serpent_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x8742ee73	lrw_serpent_exit_tfm
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x9ae34b2f	serpent_xts_enc
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x9e018632	__serpent_crypt_ctr
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x9f99663c	serpent_ctr_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0xa84ea33d	serpent_ecb_enc_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0xb8686195	xts_serpent_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64 0x19dc7881	twofish_dec_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64 0x5e752773	twofish_enc_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x1fd77fb1	twofish_dec_blk_3way
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x277c7851	lrw_twofish_exit_tfm
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x56ed3161	xts_twofish_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x61694b97	twofish_dec_blk_cbc_3way
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x8d75ab44	twofish_enc_blk_ctr
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x8e856922	twofish_enc_blk_ctr_3way
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x9357c7ec	lrw_twofish_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0xf2e80e9c	__twofish_enc_blk_3way
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x00470950	load_pdptrs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x00aaf935	kvm_disable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x01ccd216	__tracepoint_kvm_fast_mmio
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0566339d	kvm_arch_has_noncoherent_dma
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x070f9719	__tracepoint_kvm_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x075c920f	kvm_set_cr3
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x078418c4	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x080be3ad	__tracepoint_kvm_invlpga
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0bc66b11	kvm_mmu_slot_leaf_clear_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0d4adf8b	__tracepoint_kvm_nested_intr_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0df9e61c	kvm_before_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0e48031d	kvm_vcpu_read_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0ebd958b	kvm_vcpu_write_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x13d8cddd	kvm_emulate_halt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x147d01dd	kvm_intr_is_single_vcpu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x14a0e76e	kvm_set_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x15175c5c	kvm_cpu_has_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x17c114b8	kvm_write_guest_virt_system
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1b46b51e	kvm_rdpmc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1d1f56ff	reset_shadow_zero_bits_mask
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x21564cf4	__tracepoint_kvm_nested_intercepts
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2349b3af	kvm_fast_pio_out
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2c78b8d4	__gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2ce7041b	kvm_vcpu_gfn_to_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2d7c0357	kvm_cpu_get_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2f98c12c	kvm_lmsw
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2fb1ac36	kvm_x86_ops
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3063ccd4	kvm_arch_has_assigned_device
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x30a98791	kvm_lapic_set_eoi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3105cccb	vcpu_load
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x317f9e6b	kvm_enable_efer_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x34da1ead	kvm_set_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x36d71e6a	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x37b444ed	reprogram_fixed_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x37c3b0e7	kvm_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x399df21e	kvm_inject_realmode_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3e1f72e0	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3f4fa327	kvm_after_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3f8b7877	kvm_apic_update_irr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3fb11c23	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x435b5e82	kvm_get_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x43f490d4	kvm_vcpu_halt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x44046cb1	__tracepoint_kvm_nested_vmexit_inject
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4632733d	kvm_mmu_unload
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x466d2701	kvm_complete_insn_gp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x46eb1e0f	kvm_mtrr_valid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x48dea41d	kvm_mmu_unprotect_page_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4b3076aa	kvm_flush_remote_tlbs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4c8102e0	kvm_write_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4d42722a	gfn_to_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4d88bce8	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4d9987e7	kvm_write_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4db4ccda	kvm_get_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4f317c61	kvm_get_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x51ad2247	reprogram_gp_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5224407f	kvm_emulate_hypercall
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5335067d	kvm_set_cr8
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5729e540	vcpu_put
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x58c4a709	kvm_mmu_reset_context
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x59c2e938	kvm_vcpu_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5b30dd8f	kvm_requeue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5b7f892e	mark_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6245e9df	kvm_get_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6337c844	kvm_get_linear_rip
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x64020e10	kvm_set_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x66fd1d8a	kvm_vcpu_block
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6a2f9dac	kvm_set_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6a5c6a3c	kvm_set_msi_irq
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6d7721e9	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6f75e3ea	__tracepoint_kvm_write_tsc_offset
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7057fb44	kvm_require_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x709cd8cb	kvm_spurious_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x710cc59c	kvm_vcpu_gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x713fcdcd	kvm_arch_start_assignment
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7170ac29	kvm_queue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x73ae496a	__tracepoint_kvm_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x74532b9c	kvm_mmu_invlpg
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x771f26b5	kvm_emulate_wbinvd
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x78d511ea	kvm_read_l1_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x79261d51	kvm_read_guest_page_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7b77a8e0	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7bdd1815	kvm_queue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7be7fd5e	kvm_get_dirty_log
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7d763de2	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7e8e4d2b	__x86_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7eba610d	cpuid_query_maxphyaddr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7ff1ca84	__tracepoint_kvm_nested_vmrun
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x829f1b09	kvm_mmu_unprotect_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x831327da	kvm_max_guest_tsc_khz
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8515aeaf	kvm_vcpu_gfn_to_hva
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8664ebd8	kvm_find_cpuid_entry
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x891b3c2d	kvm_set_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8ce4f3ab	kvm_enable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8dd2370b	kvm_vcpu_write_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x903a4157	kvm_mmu_clear_dirty_pt_masked
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x90961a81	kvm_io_bus_write
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x916cae29	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x92156b1d	kvm_get_cr8
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x956f0de6	kvm_get_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x96dbe382	kvm_mpx_supported
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x97deb76c	kvm_read_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9a216313	kvm_define_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9cb5f049	kvm_write_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9d5fc537	kvm_vcpu_is_reset_bsp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9ea900cc	handle_mmio_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa0ec3a0a	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa4d57013	__tracepoint_kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa7d47ae6	reprogram_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xac112ead	kvm_task_switch
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xacf7f97c	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaed361f1	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb1cc6be5	__tracepoint_kvm_inj_virq
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb2a32c89	gfn_to_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb326aecf	kvm_read_guest_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb511cf52	kvm_is_linear_rip
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb7086bfc	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb78aa974	kvm_arch_unregister_noncoherent_dma
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb92665bc	kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xba110548	kvm_put_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xba9ed435	kvm_mmu_set_mmio_spte_mask
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbb3a647f	kvm_set_cr0
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbb822089	kvm_inject_pending_timer_irqs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbc9f8e27	gfn_to_hva
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbcdd9ab6	kvm_set_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbec53c32	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc04d0f8c	kvm_vcpu_gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc1adc2cb	__tracepoint_kvm_skinit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc24f6ab0	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc41683d6	kvm_init_shadow_ept_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc56d75ce	__kvm_apic_update_irr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc599bc18	kvm_max_tsc_scaling_ratio
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc5a2dd43	kvm_debugfs_dir
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc6b29a79	kvm_mmu_sync_roots
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc748268d	kvm_require_cpl
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc97be447	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc9a8c9fa	kvm_init_shadow_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcbc63ba9	kvm_vcpu_read_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcec5a907	kvm_mmu_slot_largepage_remove_write_access
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcf0b30d5	__tracepoint_kvm_pml_full
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcf2c0f71	kvm_read_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcf3dd57e	kvm_set_cr4
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcfb381e8	kvm_requeue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0459e67	kvm_has_tsc_control
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0b2727a	kvm_mmu_set_mask_ptes
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd3039d12	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd68239d3	kvm_vcpu_reload_apic_access_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd69da428	kvm_arch_register_noncoherent_dma
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd93bbd46	gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdc2516fe	kvm_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xddb49ce3	kvm_get_dirty_log_protect
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdfa99328	kvm_vcpu_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe02634fd	kvm_inject_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe0a88578	kvm_get_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe0c2ca95	kvm_scale_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe596e5c4	kvm_apic_write_nodecode
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe6122a73	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe7bb0402	kvm_apic_set_eoi_accelerated
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe8bea110	x86_emulate_instruction
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xeacb211a	kvm_emulate_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xeb1bf8cd	kvm_mmu_load
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xeb36d905	kvm_clear_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xee08fdbb	x86_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xee1670ed	kvm_get_cs_db_l_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xee455bd5	kvm_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf1c5a78d	gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf2312a76	__tracepoint_kvm_ple_window
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf2694899	kvm_mtrr_get_guest_memory_type
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf2854343	kvm_vcpu_mark_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf2f286c4	kvm_tsc_scaling_ratio_frac_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf41e94f5	__tracepoint_kvm_pi_irte_update
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf5252e67	kvm_release_page_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf63aee78	kvm_set_xcr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf6e1e2cc	kvm_mmu_slot_set_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf8f4642c	__tracepoint_kvm_nested_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfbd95c91	__tracepoint_kvm_cr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfce66f8a	kvm_valid_efer
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfd4f3b3b	kvm_inject_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xff18e135	kvm_arch_end_assignment
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xffbc83fa	kvm_mmu_page_fault
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x02b0cbfb	ablk_set_key
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x2796ca74	ablk_exit
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x540be3ef	ablk_decrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x85b05ba1	ablk_init_common
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x8d0f0e28	ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x94e8eba2	ablk_init
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xf3d8c0e9	__ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/af_alg 0x0e204d41	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x11badcb8	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0x33398615	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x3bb614e1	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x54ccd55f	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x7940d99b	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0xa523d3e7	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0xaf840c64	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0xece51d9f	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0xfaf10a64	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xfe74e081	af_alg_release
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0xda92b072	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x64039ded	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x7808a3b4	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x630e9e83	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0xb47faafc	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x381a0467	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xad58fd60	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xc2ff8c1e	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xeb6864cb	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x312d0148	async_xor
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x5ba6edaf	async_xor_val
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0xa171fac7	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x6e0f985e	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0xa7c54ced	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x19621dd9	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x65af3ac3	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/cryptd 0x5b4bb7ba	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x772d8135	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x975a49e4	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xadbf7406	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0xc91aadaa	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xdc22c416	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xdf7772de	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0xe0079835	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xe6b5b88c	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0xf0e77a95	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0xc44d5075	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x40013cb2	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x5bbd576c	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x5e46ec5e	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x653ba238	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x6ac3b312	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x8347667c	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x8bcaaec5	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xac3d5595	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xe47fc2df	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x73944ca8	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xb31efc57	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xcbea3473	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xf18c3b31	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0xa69e93ac	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0xc11686b6	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0x46718c92	xts_crypt
++EXPORT_SYMBOL_GPL drivers/acpi/nfit 0xb496c7a3	acpi_nfit_init
++EXPORT_SYMBOL_GPL drivers/acpi/nfit 0xd02b6e4d	acpi_nfit_attribute_groups
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x1c8984c7	acpi_smbus_unregister_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x87bd07bd	acpi_smbus_register_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xb9a141b0	acpi_smbus_read
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xe1372311	acpi_smbus_write
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x06eb56ea	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x14dd2b79	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x226c746c	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x2e164358	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x3e769df2	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x4493ad37	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x84b88a0a	ahci_error_handler
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8785043c	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa9fbfa1b	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xad96eb2d	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xadf74d41	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xaf0d952d	ahci_host_activate
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xb0f5bb7b	ahci_qc_issue
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xb2c8b4e7	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xb5d0dbb2	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc5738653	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe41fd813	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe5917620	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe5bd1a96	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe9acc3c5	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf58830f5	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xfa5544af	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xfe22c2d0	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x004f32e4	ahci_platform_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x50672a66	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x5d953235	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x63de2eaa	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x65ac4e2a	ahci_platform_suspend_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x6e5c4695	ahci_platform_init_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x8b24f98d	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x99eea469	ahci_platform_suspend
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xa2d1aa58	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xaeabc2c6	ahci_platform_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xccc88275	ahci_platform_resume_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xcf7405aa	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xd5a2477e	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0x8b9283cb	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x02ff9464	cfag12864b_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x0ecb2e5d	cfag12864b_disable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x305dc3c6	cfag12864b_isenabled
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x3389f926	cfag12864b_enable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x9522a342	cfag12864b_getrate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0xc48e9d95	cfag12864b_buffer
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x08ab6ae4	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x7c05aad1	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xebf7749e	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xee5fc43b	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1bebf384	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3b9efd3b	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3ebb1788	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x50b71386	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x53ade01b	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x55dd7114	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x60901028	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x69cdad6e	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6c2a2c11	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6f460f14	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x7d628a0f	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x86854d44	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x96895a4d	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xaa3c183a	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb678d582	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb8a3f5f4	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc09e0b23	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc95e194c	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd52bad0d	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd765127b	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd8fdd71e	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe70fde65	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe83fe414	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xeebd7b88	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x15c811f6	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x28f83b1b	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x53e46a9d	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x6efe559a	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x7054d54c	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x8320f5d5	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x0068c774	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x24e0e7a9	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x37b2930b	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x389f6a0d	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x67eb4847	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x778c6441	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x8b88b720	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x8e7b82af	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xa9f47cba	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xe0103fdb	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xf4e09e34	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xfca5fef5	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x112f1a5e	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x2506ba25	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x445a5d80	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x7e465a51	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x865b4a85	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x8f6fbe25	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x9231780c	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x9ad6d3a8	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xa188dc51	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xaf292d47	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xbdd41523	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x45a595e8	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x5e162507	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0x75ae9b13	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0xcbdc19ce	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/cpufreq/speedstep-lib 0x1b1f2bda	speedstep_get_freqs
++EXPORT_SYMBOL_GPL drivers/cpufreq/speedstep-lib 0x2b67f096	speedstep_get_frequency
++EXPORT_SYMBOL_GPL drivers/cpufreq/speedstep-lib 0xd7ab2c0c	speedstep_detect_processor
++EXPORT_SYMBOL_GPL drivers/crypto/ccp/ccp 0x04773b60	ccp_present
++EXPORT_SYMBOL_GPL drivers/crypto/ccp/ccp 0xe1b73272	ccp_enqueue_cmd
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x082008f4	adf_dev_put
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x11b410e1	adf_disable_pf2vf_interrupts
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x1af1ae00	adf_cfg_dev_remove
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x1dd74122	adf_dev_started
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x1e3fd243	adf_dev_in_use
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x25ce9c47	adf_service_unregister
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x2b687087	adf_dev_get
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x404c0ba8	adf_devmgr_rm_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x4c12ea06	adf_response_handler
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x5461f6d5	adf_devmgr_pci_to_accel_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x55d7a3cc	adf_enable_pf2vf_interrupts
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x5d784fa9	adf_dev_shutdown
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x6d18be43	adf_service_register
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x75f0b0bc	adf_init_etr_data
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x80257519	adf_iov_putmsg
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x8df26525	adf_disable_sriov
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x942a8f85	adf_cleanup_etr_data
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x99a161f9	adf_init_admin_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x9c376607	adf_sriov_configure
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x9dcdc0fb	adf_devmgr_add_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x9e12c4ae	adf_devmgr_update_class_index
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xa7dcd479	adf_disable_aer
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xab89ffb0	adf_dev_stop
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xac6fdf4c	adf_devmgr_in_reset
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xae996d7b	adf_send_admin_init
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xb170746f	adf_cfg_add_key_value_param
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc7573772	adf_init_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc7e65655	adf_cfg_section_add
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xcc3b167a	adf_clean_vf_map
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd08a790b	adf_exit_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd137ec96	adf_enable_vf2pf_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd1bb420c	adf_update_ring_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd6118923	adf_exit_admin_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd9abe560	adf_dev_init
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xe0ce4081	adf_dev_start
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xe85c3057	adf_cfg_dev_add
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xe909e49f	adf_enable_aer
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xedafb42b	adf_disable_vf2pf_interrupts
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x01a33ab9	dca_unregister_notify
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x31a2c8df	dca_get_tag
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x35162369	free_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x79170d39	dca_add_requester
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x7b4a0492	dca_remove_requester
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xa84dc501	register_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xac34ecec	dca_register_notify
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xacf920f1	alloc_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xbe2d69ee	unregister_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xe120d815	dca3_get_tag
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x235a7d08	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x550722b8	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xb3b9db29	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xbd9badff	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xdfcb8c20	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x54689c9a	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x71d23ee7	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x841dc3fa	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x0efd4220	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x39bb98a2	vchan_find_desc
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x5969f55f	vchan_init
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xc3df7dd0	vchan_tx_submit
++EXPORT_SYMBOL_GPL drivers/edac/amd64_edac_mod 0xfc72d086	amd64_get_dram_hole_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x057807d7	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x1c8c09c7	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x200b1a51	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2f6c0146	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x39368897	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3ae0bbcf	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x41b794e8	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x478082be	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4aa8c162	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x56d0b9c7	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6745f9e9	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x687cb711	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7599c3aa	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7f787611	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x812b91fa	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x85984c4c	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x9161484d	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x922db0fd	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xad0f4fb9	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xbe3348db	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd3e70df5	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd698e2db	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xdf98f02f	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x14878009	amd_report_gart_errors
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x1d34e996	pp_msgs
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x81d75507	amd_register_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0xb30b7e56	amd_decode_mce
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0xd3cc2686	amd_unregister_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x07262998	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x2067fe47	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x299cad9a	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x2e3b3a34	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x48a5d1b0	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x6a85c0de	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x17cc5ed3	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x2e16ad3f	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x7ec7b75d	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0xe25d224d	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x1c32ad30	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xadcb97e6	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xe9e52e67	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x05876c69	i915_gpu_busy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x08a7896d	i915_gpu_raise
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x402468e9	i915_gpu_lower
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x500858b9	i915_read_mch_val
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0xe7237b0b	i915_gpu_turbo_disable
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x836a969c	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xaa6ff558	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xcb50beaf	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x03c35813	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x04075be3	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0ac4638d	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x1044839d	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x29c5918a	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3e495ed4	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4914fc96	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4a2ec069	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4cc0328e	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4f4dd487	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x581ed124	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5a6bdc47	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x60905e43	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x60a38de6	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x74473ec7	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x88018fa7	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x8890df31	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x8f861ba8	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x950a399c	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbc9c1db7	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc95c47a4	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd76e7dd8	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd86fe546	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd9e55731	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xdadda6e6	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xdd0fb94f	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xdf15a802	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xdf5a2fb3	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe310c53d	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe320e442	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe3ca16da	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe4c523e9	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf1aa5253	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf76998ce	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfba2fb4d	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfc2c5b5a	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x60476113	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x329c5fe9	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x373d97ca	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x485e095c	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x58d9ab3a	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x8c208993	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xf9f85218	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x2a34bf66	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x36fad31e	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x58bdc966	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x60bf40aa	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x86723df4	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x9bef9206	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xc92298b4	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xed1e0edf	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xf87f1312	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x1827c3f2	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x425a24b6	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x4e485989	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x58638d68	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x680ffc29	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x72f29900	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x86f11f42	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x97d93f94	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x9cf5e468	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xbccc1c37	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc423180d	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xd5a8148b	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xd5d1124a	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xdf4375d1	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe0c6a03e	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xeb47e9c1	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xec6d772f	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xfcf8fee9	hsi_event
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x06ab4a34	vmbus_hvsock_device_unregister
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x1a25cd8a	hv_do_hypercall
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x25a0a3d2	vmbus_cpu_number_to_vp_number
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x2764e941	vmbus_sendpacket_pagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x2de6e406	vmbus_set_event
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x311f26f8	vmbus_setevent
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x337a7e1d	__vmbus_driver_register
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x358fafa5	vmbus_prep_negotiate_resp
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x41b4d5fc	vmbus_sendpacket_pagebuffer_ctl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x46a417ca	vmbus_proto_version
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x5cc1a761	vmbus_establish_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x71a41c49	vmbus_are_subchannels_present
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x74bd5324	vmbus_teardown_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x8419e122	vmbus_recvpacket_raw
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x86ff5fa6	hyperv_cs
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x88f7ebfe	vmbus_allocate_mmio
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x9fe04980	vmbus_close
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xa32d7a2c	vmbus_open
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xabffc492	vmbus_get_outgoing_channel
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xb87e1f17	vmbus_set_sc_create_callback
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xc68a30b5	vmbus_sendpacket_mpb_desc
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xd201beee	vmbus_sendpacket_multipagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xd2c559d7	vmbus_set_chn_rescind_callback
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xda40aea3	vmbus_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xdb2f6047	vmbus_free_mmio
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xeadb5fcc	vmbus_send_tl_connect_request
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x2eda5a44	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xe893492f	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xfc7c9086	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x0b1cdadf	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x1d11ca7b	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x20ddbfde	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x2f09b032	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x43a844bf	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x501f24e1	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x6f8ee98c	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x939b4b19	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xac434338	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xb1d56fdc	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xca45bd7a	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xceff98d7	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xd144e856	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xe6bc11e4	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xfe5e515b	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x2692aa0f	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x450820eb	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x5dd17239	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x8a13d3d7	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xab4e31f9	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xd76f9144	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xf9a38f84	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x060f302a	stm_source_write
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x0c197ce3	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x5756d218	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x82b7e234	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xb19c097e	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x4c8deff1	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x5e363ee6	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xa22b5c24	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xd2134f81	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xe7f4348e	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-nforce2 0xb6605a6f	nforce2_smbus
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x771d92e1	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x886255df	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x5250287e	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x75825cdf	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x394c23ad	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x7ff00330	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x8c924715	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x18f18145	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x2b7bc8bb	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x2d9c4e3a	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x3390ed96	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x71b98f97	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x900d0af3	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xbb90d59f	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xc64c07f5	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xd18a3f90	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xd4cbccfe	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x8ff0bd86	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0xdee6236f	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xea5326d6	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xebb48e72	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x3c4663e9	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xc62c8f68	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xefbccc52	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x0334bf10	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x0c52123f	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x3e2972d6	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x4d3f1004	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x501e98ad	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x6512a8f7	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x72118a03	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x9dfab02c	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xae059a71	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xc474f10c	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xca6bce4b	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xf6bb30bc	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0cb1288d	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0fc02137	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x124f1bb3	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x22e27bfa	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2566fc9c	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x286f3dca	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x35c40313	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x49877c35	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5390fa5f	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5eaf363c	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x67ade851	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x750be603	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x75de49fb	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7eabe4ca	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7ed3fb72	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7f4a1868	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x879b8785	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x88ba560e	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x905f06fa	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x93d08a95	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9a1da9de	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc2439784	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc4406bcd	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xcb08485d	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe25a5810	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe738306d	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe765f105	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xeac8cfc0	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xec443136	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xec677a7a	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf5135a2d	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0xc7c84dc2	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x6d486197	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x7f9f0a60	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xa4141aeb	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xb7947dd5	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x3b2bbf55	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x90e8f8e3	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xe743ce66	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x964b3da2	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0xbeff3437	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x26e43182	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x608b552f	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x89a2631a	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xb3ea7a9f	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x030ed630	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x18ecfb97	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x1f65f519	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x27225c4f	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x557ff799	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x643b3398	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x964872ad	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x979bedac	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xb12195a3	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xc692fc47	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xcfa4d6ae	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xd21acbf4	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x04f6a5ae	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x1480b3ad	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x332ab3f1	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x4cbcddd4	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x53d3f353	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x5407221b	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x7e393ab7	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xc00dbbb8	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xc5389e3b	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x0b697396	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x12ed5d99	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x22e6a046	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x291ed516	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x3e3a0245	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x4eee72b2	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x5570dc33	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x5a3422ca	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x66357706	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x6aa10e84	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7a5acd03	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x93bcff1d	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa3151853	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xb5ab2c41	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc9282ff7	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xcd39c062	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xe3cb9f0b	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xe5acf770	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/leds/dell-led 0x86fd1ffb	dell_app_wmi_led_set
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x1aa88520	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x4e6a8222	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x588826c8	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x6b4e6e07	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xbeba5234	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xeccecb16	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x0f8771ce	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x191b3f4a	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x3705a6bb	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x402802f3	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x43919472	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x51b232ac	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x6dfb154c	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xd39b0bab	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xdd620099	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xe2870328	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xfab0e3f7	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x0cc27b4d	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x23004ff2	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x41a9214e	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x4949aa16	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x49df63aa	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x4fb1a66f	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x50d155ba	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x5ff431ab	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x69e8f845	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x81c2063a	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8bf52ac0	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xab8f59f8	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xbd9a5a0f	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xee3cc4d2	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x021811cf	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x0f0677b8	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x10e6a889	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1154f7a1	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x15aa8e40	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x174c2a29	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2205bcf9	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3fc7cb7f	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x469f38de	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4ba51ecf	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5b2a89c7	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5d950f2a	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5e21030c	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5ed04550	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6eef9654	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x74ab7b0f	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x84efb763	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8fe32879	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x91f02667	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x93f7fc02	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa1de5277	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa81bf581	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb7d964de	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbbace2cd	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc6673631	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc8a2f711	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe3de2ba2	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe902838d	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xec919105	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xeea27f46	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfad1ec73	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x09fd3574	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x0bc28390	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x0d22d981	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x224fbffb	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x5d77326b	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6d1358cc	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x93b41a1e	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xbe353c06	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xd6c6f895	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6aba7f5e	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9310ba06	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9c256008	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa1d2413a	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa448e19f	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa47dc687	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xafbda3f3	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xcbb1bae2	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x29582fc8	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x2f7166c0	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x44879f3a	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x56603ab7	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x69bcd51c	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x6db6dc94	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x8c07395e	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x9a433b82	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0xaf13252a	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x013f8e07	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4430764e	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x45ab972a	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x6ec989c3	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x72dd2529	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x80713cbb	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa289db7e	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa68e1f06	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd1bc9451	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfad9d53a	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfc62ef4e	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x17c36f29	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3c7a085c	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42dbdfc3	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x49b35849	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x55b4bd4d	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x827a42f4	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9f624559	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xafeda29f	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd29923fb	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf375d009	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf5455120	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x3116fe7e	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x4099528d	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x717707b3	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xa1b5e5a7	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xa4553417	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xbb1a392b	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xc7a4c7bc	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xcddd3373	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xf9b8d00d	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xfd5324b7	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x321945e3	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x3feb683f	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xb15bf789	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xcfa684e9	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xd9b526b0	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xdc305b09	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xff4bc6fc	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x0868701c	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x248541d8	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x39c9bd73	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x54ada951	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x66b61c03	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x6ec1206b	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7e672107	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x99a81ab3	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xb797a67c	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xba561c57	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc4d9e832	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xdce48c0f	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xdd1d6763	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xdfdb18f6	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xe620c8d8	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xe7e4e59e	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xfaec54e9	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xfe72be24	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0xba2dde3d	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0xf9dfd782	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0xec667786	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x098f63b2	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x3090cb01	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0x39ad4e66	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x40b54bce	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0x40cd1029	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x4694c8b0	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/media 0x5d5de39c	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/media 0x63259c79	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x69de546c	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/media 0x6aa9bbd9	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x7283d986	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x90268671	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x91c7994b	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0x98344344	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x99d79a4f	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0xb54398c9	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0xccdc9532	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/media 0xfcc0aed4	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0x22527eab	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x21454b35	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x357c8e05	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x4021f812	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x5405a2c1	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x67880910	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x6ee93e96	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x7d5f6d37	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x80cd2f4e	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x869b296d	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x91f345e4	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xa355f954	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xad7ff5ad	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xaef867c6	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb45c8d90	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xe31f4223	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xe846ab92	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf291cfb5	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf52b4535	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf77451ae	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x05d7794a	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x20af6576	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x32c72240	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x55dbda5e	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x62f76b27	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x65204b18	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x6bfeec29	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x75206628	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x941a328e	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x9e8247b0	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xbb4ff028	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xcdc08a81	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xd0d18260	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xd92d9942	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe0b670aa	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe2ee2335	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe3f66bbf	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe913d94c	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xff15fac9	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x012354d8	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x3be76877	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x493cac48	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xa6c952e7	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xab1d49b2	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xc133ffeb	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xe71ce81f	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x1a4b9365	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x303b08f6	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x054267fb	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x29a91501	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x37c163e3	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x57b17815	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x5bd7e58f	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x636c2180	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x6a3b1292	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x76c71f94	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x819fac72	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x8ec2e810	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x990cf3af	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa2c3fb00	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa9e2786a	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb99c1e67	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc21de712	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc28901b1	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xd57b73db	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xd81753d6	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xf65b7967	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0x32125fe4	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0x6253a8c1	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0xe064a585	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0x878aff41	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0xe93e31a3	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x2d778774	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x87bb69fd	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xae23e15e	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0xe498e42a	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x19d18124	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x310db14c	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x8cebb4bf	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xd8831b12	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0xf593df78	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x045e7a9e	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x267cd015	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x3d58db83	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x52db7be4	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x57a3fe70	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x58048a88	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6478ccf5	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x66ce4300	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6d7a959a	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x73b0929b	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8d724308	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x9334dfb5	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa85f37e1	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xb9f5e08f	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xcd04474f	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xedce28f4	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xedd015cd	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf04bf7ea	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf2fad670	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf94b0041	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0x55c1bc02	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0xa9f0ef32	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x139dc5fc	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x247d6d7c	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x39bec675	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3d8a6070	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x5336c3d7	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x580c9225	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x64b44509	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x665708cf	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7972c5e0	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x84bb615b	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9f6d62e2	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xa978540f	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xb93b5288	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xca6ac348	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xeed3bbbb	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xf21287b1	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xfb492048	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xfc327c4a	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x22c7f145	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x5bbcd9e6	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x8f48576a	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xf0dc6e51	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x04160110	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x0f8271bb	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x18326c5f	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x2dbc8be1	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xd01775be	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5237a15	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x27e63a1a	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x7912938b	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x0c3cdbe7	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x18611cb2	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x18ab443b	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x3730a5e0	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x39a4ecbc	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x3dd47671	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x4724ec06	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x517d0a74	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x596566c5	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x5ba7b03c	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x5f9aa183	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6a272c00	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6ed25d9b	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x75eb2e0c	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x77e46f36	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7aa21bcf	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7da77f89	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x8784b1d0	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x8fd9cfee	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x96938db4	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9fce5aac	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb10d10ea	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd6ceb998	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xde0e552f	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe511ff53	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe60228fa	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xee7f2e78	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x0d40f7a8	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x18aeac66	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x194481aa	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x26685fd6	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x423d969f	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x44258738	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4962a6ea	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4c923257	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x52b81ffb	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x54471b7e	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x5e48a922	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x607cac3d	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x61a65353	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x682869b7	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x696d072e	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6b516e6a	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x738f1e2f	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x87238159	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa0654c89	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa7bd3868	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xaa69dbc0	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xac181523	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xbe4487c0	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xeba8ac4f	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x553a86d0	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x8a62a6a3	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x91ffa343	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xcf45db64	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xfd422cd5	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x1a51d8bf	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x38702637	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x87fa2526	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x248c587f	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2dba821d	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x54b8385e	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x5571451b	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x5aaf824d	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x5ca2dffd	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x72b0add5	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x831060f7	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8a24e8ac	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x99871c8e	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x99fc0ecd	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xcebd243f	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xdd456ff3	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xddbe7cb6	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe5cc3c5f	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf0988bb1	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf17092e9	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfe9edda0	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x5568098a	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xfe9d2968	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x5ef5eac0	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd4f726cf	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x74de8710	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x079262f5	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0c66cd3b	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x2abdbcb1	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x2f9fedee	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x30c4856f	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3745a003	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x40bc4044	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x48752e52	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x59ed3f10	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5d977f7b	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x6908818c	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x7672c593	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x7a052ea4	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x7d69d36f	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x7f20b928	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x890debe1	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8da450b2	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa91270ca	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xaabc798c	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xabdd4f03	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xad9d6ee2	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xaf31ad79	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb27c438e	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb6fd82f3	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb93ed7ec	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xbe2fbc0e	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc166d5a0	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc9d1f69e	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xce23636c	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xcf67160e	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf2b2a64e	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf67ca0bc	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x72d2523a	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x027abe31	v4l2_compat_ioctl32
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x08e330f6	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0e7acfb6	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x114a1f5a	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x11ea03c5	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x133adfc4	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x19986f4f	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1ef3a428	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2ab9d732	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2fbe2b80	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4e73fa8d	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5833a575	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x61362225	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x6184e475	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x624f7e10	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x6ea25f95	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x74a017c5	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7bfda7d4	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7c8fba0e	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x80d85335	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x82ecd9db	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x882f49c6	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x88d66582	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8c70c76c	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8cdfbe43	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9058c58c	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9a86e92c	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa4567336	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa55c185e	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xaca2544a	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb801d24f	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc6429d8b	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd8bdd6bb	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe56527f2	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe63f3901	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe7366c60	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xef4419bf	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x33583656	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd15859a3	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd30fbec5	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x20b0f6b8	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x2166c271	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x3b482e58	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xc4d83e05	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xcf316779	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xda58d8fd	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xe826396c	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x63752762	intel_lpss_probe
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x75c527ee	intel_lpss_remove
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x8fde8250	intel_lpss_prepare
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0xbda6b4d9	intel_lpss_resume
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0xfea1041c	intel_lpss_suspend
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x05801b76	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x0c4671a2	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x220e8d0b	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x5b613820	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x69fd8105	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xaf1bb1d0	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xafceee75	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xe315ec08	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x2a1bacfd	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xa37b73ab	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xc9b3b20c	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x0fc2a62b	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x36db83a8	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x507c55dc	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xc0c6d550	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xd6dcd9cb	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xe449ab26	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xe9af674a	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x5f4a55d0	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x93c8893f	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xe3c0c790	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x130264bb	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x1bd2724b	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x2c2ddd1b	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x4967cc03	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x5b68396b	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x877f9505	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x0b437431	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x149c698f	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x2acb9ea7	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x54f756d2	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x6255cc8d	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x6993d3be	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x73f83a35	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xab34bbd7	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xb278d3a7	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xc62f284f	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xd5297461	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x8bd158e8	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xdc3138ff	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x59a334f9	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xd5e3fc19	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xee9f94e4	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xf6a10940	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xf9c065af	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x01c86f0f	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0a8dc0bc	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0e56a3af	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x22712ca5	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x2ce00e93	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3a58312d	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3e3bd08c	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x4058e6e0	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x44a7940a	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x5cb7cad4	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x5e7ecf6c	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x75b0f06e	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x7bc31d35	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x97658c7d	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9b4cad29	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa519ec46	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa8a5ecdf	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xbea21cde	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xc05bc17e	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xdc677d93	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe0e00811	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf18c6834	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf428fb00	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xffa80735	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x1dc9a14e	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x1ef6b221	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x2c67d962	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x625a5c6d	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x64599656	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x7c1090a2	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x977438a1	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xa9b4c510	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xb269e6b8	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xb6c4b148	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xe2bea90a	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xe989da76	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xedc13654	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x03453fae	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x06683b07	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0b83f578	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x184a24be	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2606926f	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x26840452	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x26cbfa06	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x297cba73	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3b39cb8f	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3f456da5	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x67ad1f2a	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7934d31b	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7f1296d9	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8db9c2e2	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x92e6433a	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x97dbbb38	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9bc25549	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9c7885cf	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa949376b	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb022edb6	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb5404799	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc146508a	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc58ba5bc	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc7f8da1d	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xcd98e5cd	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xce009eb5	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd0596839	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd4f88aee	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe280fb4e	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xec386d38	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xefd788be	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf46c7532	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xff00da92	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfffd65da	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x300ed43e	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x3f975aac	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x5d1b4c35	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x9d3ae635	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xd228e47a	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x2acbd42e	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x7e23b1ec	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xca22cde0	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xde7828a2	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x09f639ca	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x89ef9685	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x9d0d686f	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xb9951775	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0xe86a6cd1	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x363d50c2	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x8d25014d	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xcae9c39b	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xd58aa980	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x0c0b9fec	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x2d4b9859	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x5fa70e38	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xb528931f	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x1399a1cc	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x35285cac	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x64037f31	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x77d9c0bb	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xc5fd824e	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xc93eeef1	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xf1fd42ba	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xfab2ed4c	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x0477ae66	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x1fb04b7c	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x4ff210db	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xd5e4540b	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xd8fe586f	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xe62bb222	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xe6c0108e	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xf4909bc5	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x05db1d3a	mei_restart
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x0a9408fc	mei_cldev_enabled
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x0f6ab964	mei_hbm_pg_resume
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x186adcb3	mei_irq_read_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x23e05f30	mei_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x28683e05	mei_irq_write_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3000b7f3	mei_cldev_register_event_cb
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x332e67e0	mei_deregister
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x395bedf2	mei_cldev_enable
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3991b6d5	mei_cldev_disable
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3b20d522	mei_cancel_work
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3bc5ab0f	mei_write_is_idle
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3c92459e	mei_cldev_get_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x67e939b0	mei_stop
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x68e7430d	__mei_cldev_driver_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x754f2816	mei_cldev_set_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x7905e092	mei_cldev_uuid
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x7ac23963	mei_cldev_ver
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x91e20713	mei_hbm_pg
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xa4e70fa5	mei_reset
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xa7ab2395	mei_irq_compl_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xadcf4054	mei_device_init
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xbad780ba	mei_start
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xe59bc6eb	mei_cldev_recv
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xe8dd0278	mei_fw_status2str
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xf2062ce6	mei_cldev_driver_unregister
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xfed3d175	mei_cldev_send
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/cosm_bus 0x110353ad	cosm_unregister_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/cosm_bus 0x4ebd3fa2	cosm_unregister_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/cosm_bus 0x612982b5	cosm_register_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/cosm_bus 0x84a24ee4	cosm_find_cdev_by_id
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/cosm_bus 0xbd27c3d3	cosm_register_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/mic_bus 0x3e059d33	mbus_unregister_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/mic_bus 0x477adcc1	mbus_register_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/mic_bus 0xa71f2bac	mbus_register_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/mic_bus 0xfe46efd1	mbus_unregister_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/scif_bus 0x27b8858d	scif_register_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/scif_bus 0x87aac2b2	scif_register_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/scif_bus 0xa61f04d3	scif_unregister_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/scif_bus 0xab9337ed	scif_unregister_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x08df0400	scif_accept
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x0c126e87	scif_vreadfrom
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x1d555617	scif_pin_pages
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x29b9251c	scif_poll
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x2a449095	scif_recv
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x2d1b72f7	scif_listen
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x31f517c5	scif_get_node_ids
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x34de4a0f	scif_fence_mark
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x37aaafea	scif_register
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x3dee0a27	scif_close
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x3fd88411	scif_open
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x506d999e	scif_writeto
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x52add8ad	scif_unpin_pages
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x72571e79	scif_unregister
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x808e83a3	scif_readfrom
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x83036207	scif_fence_wait
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x92477ccc	scif_bind
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xb59c747d	scif_send
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xbc1dd1f8	scif_put_pages
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xc5c49db6	scif_vwriteto
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xc754a79c	scif_register_pinned_pages
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xca8a0881	scif_client_unregister
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xd1beaee4	scif_client_register
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xf32f4912	scif_get_pages
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xf92dbf71	scif_fence_signal
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xff3bb2d3	scif_connect
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x95ea0797	st_register
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xbe92fb75	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x0f6680ea	vmci_qpair_produce_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1152e318	vmci_qpair_get_produce_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x13aa5a5d	vmci_datagram_create_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1872c7af	vmci_qpair_produce_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1a195863	vmci_context_get_priv_flags
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x3ef56cd5	vmci_qpair_alloc
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x46fbf193	vmci_qpair_peekv
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4b630dac	vmci_get_context_id
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4ba5c46b	vmci_qpair_peek
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x50a255c9	vmci_doorbell_create
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x612df9ae	vmci_qpair_detach
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x677c36d0	vmci_is_context_owner
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x69ef87ff	vmci_datagram_destroy_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x6cc1a5f7	vmci_datagram_create_handle_priv
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x722d488a	vmci_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x7d540b50	vmci_qpair_consume_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x81d61eef	vmci_qpair_dequeue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9624c58c	vmci_datagram_send
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9973b9b2	vmci_qpair_consume_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9d16164a	vmci_send_datagram
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xa2ac811a	vmci_qpair_enquev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xccbb53d1	vmci_doorbell_notify
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xcf5ed7ef	vmci_event_subscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xdac94780	vmci_qpair_get_consume_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xdb1b1663	vmci_qpair_dequev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xe67343c1	vmci_qpair_enqueue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xe7e7c107	vmci_doorbell_destroy
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x162caab1	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x1d4b012b	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x291761c4	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x3b5251f7	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x74a867d3	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x92988db0	sdhci_send_command
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x9a0af0ba	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xa47ed5e9	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xc56ed884	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xdb330141	sdhci_reset
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe0b53931	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe45478c8	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xf32785f0	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xf36a4a55	sdhci_set_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x278cec58	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x470a7376	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x50ce5fd8	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x51664891	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x69d77b63	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xa1d63ab5	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xacfd9496	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xc775825e	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xf0efd184	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x529aa98b	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x90ada9f5	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xaf848c1d	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x2b971e77	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x55c555a7	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xd86ed1f1	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0x21d7786e	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x7def63c9	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xa1650d08	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xd2b99433	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x03ad60c1	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x04ff9f9f	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0d99ac09	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1b405465	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1c7657fe	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x24eb36c1	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2559c20a	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2c47b0fb	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2f9b66f4	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x32299fa2	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3f4de0f8	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x49de2317	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x49f62a17	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4c365a0e	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x53a0065b	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5f8a6a3d	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x61024f99	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6fce2a80	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x75e3e771	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x762eec31	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x763d006c	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7bf932fe	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x94797ec0	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x96797f9c	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9adcae9c	mtd_block_isreserved
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9c113f61	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9f0df80c	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa6f78026	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa7c6022b	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa964f57a	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb47aea4a	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb8fae755	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xbea0270a	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc24e96c3	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc39d83b8	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcb3f8a02	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcfcef9a8	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd14015da	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe37b6672	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xeb8a9443	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfd7cb051	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfe642257	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x06da8b95	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x31728d94	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x515da5ba	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x59f10161	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x83d83daf	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x82d8ba6c	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0xd85a789b	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0x6300ae7e	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x15d4679f	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0xcb10f64b	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0xfeac4e67	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x0eb72244	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x17a6df57	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x1e7345fc	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x4587f8aa	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x4d0c5a4d	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x7cb0461e	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8436b704	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x9c9fb696	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xa39db9ef	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xc5de10ce	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xc970851c	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xc97d9478	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe4deb13b	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe7daa38e	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x590982f3	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xebf4160e	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x24a0105d	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x6b9b933d	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x97fb83dc	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xa123b209	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xe6d20024	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xee8626f1	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x0977d576	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x0b322ec3	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x18ed7ac6	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3a6d327f	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x53882c76	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x56b3019b	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x572e84f3	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x59c547cd	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x60644f72	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x712b8d1e	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x7618cb73	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x81b85140	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x89ba19ab	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb0abd05a	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb30c6c12	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xba1411c0	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xbb7534a9	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xbb932270	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x17787c41	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x675e37c5	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xbf050a61	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xd8126f7e	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x1f24a67b	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x33c6fead	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x5dbf0069	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xa1c5130a	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x013ebe92	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x05db2bdc	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x062a5192	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x066a81e6	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0bf8e16d	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0cf6765c	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x10258527	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x10bc821b	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x12f92455	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x13e9e236	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1b13a551	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1b896c51	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1d06aa5d	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x20b8907a	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x21d6cc48	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x22ad30e5	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x275f0bf6	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x27812dc5	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x291d2b59	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2a56f35f	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2c8d67ad	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2ce70f82	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2df92352	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2ecca305	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x35a5c37a	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x39b296b9	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3bf1e90e	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3f91d2c0	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3fa66e09	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x401fdd60	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x466aca18	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x47137003	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x49bf3ceb	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4b999b09	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4cf9ea65	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4fb5b633	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5388660a	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5755ce5a	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x59719c1c	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5b1eee70	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5b78a873	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5d4da985	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5d55b788	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x60d2eee3	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x61690fe3	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x637b8fdd	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x63f68bce	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x64b4bfa2	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6fb64059	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x703724a9	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x743116e6	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7494b469	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7a08897e	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7cf05ad0	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7d0a788b	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7fca41b8	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x823e887c	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x84d2e1bf	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8631308c	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x89dc07bb	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8a8820e4	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8dc7d7d2	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8fe3d0ec	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x92e6b2d5	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x92e71616	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x94286245	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x954c2b30	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x988bdf72	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x995591db	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x99f6b4db	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9a31438a	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9a59d9d6	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9b464e85	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9d7e9cbd	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa256af6f	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa401b83d	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa6a48cc3	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa9abc8dc	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xae10d48e	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaf645bd1	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb0914f3b	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb0c1a8f0	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb23a9865	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb2ac6d34	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb3cd8b6c	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb3ce5158	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb9b5dc6a	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb2e5d34	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbc42e783	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc0c1e49b	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc14b25cc	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc5bc8ce6	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc6300e31	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc9b8547e	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc9e39c06	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcbc3ad54	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd0ceb35e	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd2c36116	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd571a05c	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd6ae80d0	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd945601b	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd9958579	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd9c45164	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xda48148d	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xde23958f	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe26186ee	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe381b801	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe52f3f51	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe5dc9715	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe6b53347	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe900fc48	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe9fd953a	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xec99c990	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xecebdba8	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xecf60a64	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xed4baf98	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf0d8025b	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf2273537	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf3b202d1	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf55ed37f	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf7da039a	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf9c49cfc	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfd5f3964	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfe165508	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x02a9e0e5	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x06a21585	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09543b3d	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0e573e35	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0f28fef1	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x101e28ab	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1143c6ee	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x12c4ee78	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x158c6017	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1fa735f9	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2a20ccc7	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2cc1ab6a	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2d892b2e	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x340e0c4c	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x39a21809	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3b0a54d6	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x400aebfd	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4435ae93	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4c28e368	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5e10c34e	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5f195792	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x63021b77	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x643dd61a	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6642d8f0	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x66fcddb0	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6d19b0ff	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x805b0765	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x852d3d33	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x897fd2be	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x90d9a5d8	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa1d26b74	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb64165bd	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbd97cfdc	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc5103549	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc7c41b95	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcc43788e	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd1c18eae	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd1e63d69	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd5ae579b	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe2071c53	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe53f47ab	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe70c01df	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xede04514	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xee4086ef	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf0c6a048	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf77aaacf	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x5e28947e	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xac144314	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xdc2c8acf	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x4c6345d2	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x90ec8e52	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xa9b67f76	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xd8e192c4	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x13656f89	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x24aa8045	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xe195bac5	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xeb42883c	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x045cbf6e	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x07fab775	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x09a60b26	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x16567e56	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x662c2aa2	cpsw_ale_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x7d04f368	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x857a8763	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x93daf45c	cpsw_ale_stop
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x98a6db9c	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xada6f39f	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xbd37fd11	cpsw_ale_dump
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xc97f9b39	cpsw_ale_start
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xdf7b0237	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xe78605b2	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xfb183cc4	cpsw_ale_add_vlan
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x7f11d472	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/geneve 0xe0ceb962	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x314c60db	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x4893d90a	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xda1a7998	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xdf072582	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0x79630150	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x1c465f89	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x45d6a6f2	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x5e8663d0	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x75e178c6	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xada41e6d	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xae8cf3bb	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xdb263ab1	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xde6f877f	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xe8b339b8	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xed31902e	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x027ca1a9	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x1d964fb8	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x37e7d4e2	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xc4957ece	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x1f879f03	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x458da18b	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x46ec362c	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x6e0efcf0	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xa3a6ed69	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xc3ffe96d	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xd3cb491a	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xd643ba0c	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xfc29eeb7	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x1aa07946	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x25fc1300	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x86834e1c	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x9c0deeca	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xd1fc4837	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xe0bbf6df	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0a5dc59f	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0e7dc05c	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0fa87e02	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x103a7a15	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1fedf201	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x36266e4c	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x39d1e6d1	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3a44af6c	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x465cdac7	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4a33bf19	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4a87f1b2	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4c4ca322	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4cfae407	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4f20643a	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x565dd95c	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x602a5963	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6a246129	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8e0c7b64	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x92d2e74b	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x945a88bf	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x995e105f	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9d0d2459	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9e25926c	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa0c2f02f	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb5ecabd7	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbc1bd716	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd116d933	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd826045d	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd858019e	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xdad0bfcb	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe65b1da2	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf84e5b4e	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x3cc09dd5	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x6b97a2f1	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x08df6349	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1404c4f5	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x186fca6e	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1f831562	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x2b10a6d3	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x34e83e64	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x693a283f	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x6f681efd	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x7569b892	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x9e516212	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb5c71a33	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xcadd4f7f	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xdcd4da49	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf1086a44	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf50e72e8	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xfe96c9f0	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xa4f04b36	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xbebc1ebd	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xed64b883	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xfd4961f6	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0x3fd9b9d9	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x2327381e	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x29fd41f8	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x72eec18d	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xcbe42a2e	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xce6c4429	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0ccbce98	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0e76e67e	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x18377514	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1b074767	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x202a9ac0	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x43f2ba3c	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x512a2413	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x56428b7b	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5719cf84	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5b2bdcec	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5ee5ab54	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x76d20e36	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7a3ec41c	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8bedbbdf	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8e53edad	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9195ff5d	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x97a5b9bc	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9a2df7d6	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa5055f95	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xaa6ce8ff	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb260109f	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb8979af3	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xbefbbec4	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc1273c21	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc4a8fc91	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd49b4b3e	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd676ce68	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd6da7753	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xdcece30e	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf3f98af3	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xfc197511	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x0009561f	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x35c977aa	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x3d335458	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x554f0c7c	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5acd7a2b	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x62cfb63e	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x724f718e	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x7dcd79a7	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x81ebd547	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x9294ccf8	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x980fcb40	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd96dbc16	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xdbcbd6a6	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe9314bce	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xea9ea435	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xeb9ace3d	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x36117724	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x62447420	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x6afcb35e	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x888a7f8c	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x988e4d6b	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x9fd26dcb	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xb27ca797	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xf0206fae	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x205a9ea6	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x27d53021	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2ac8c154	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2ad53cd7	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x37f975a2	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x4eb34949	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x50781d3e	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x60248bfd	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x715cb9e4	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x84c9bba3	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x84ca4128	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x898a03fc	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xbd38f2d9	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc29946e5	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc7b0f20a	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xec949e98	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xee24b9d3	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf4cef922	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xfbc02f1a	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x00a52d07	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x073677c8	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x243bed8f	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x3a9be87a	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x5573fd25	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xabf0fffc	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xb64ae2f6	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xc9321391	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xe66013d0	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0ec8267e	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6559682b	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd7317694	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf178d4c2	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x0dfb5520	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x0fb7ecbe	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x12339576	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1f0f2260	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x200058c7	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x2fb24374	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3f147f5e	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x416490ec	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x4597be64	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x49e91d2b	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x4ba6e630	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x4e2f59b1	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x563511b5	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x732a03d4	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x75c6a017	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7a759ba5	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x8b0433d1	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa47a889c	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa5d1ed2c	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf7344f7	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xb80d5753	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xc0805d9c	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xca9210a8	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xcd91c11d	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd48c0c76	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xdc6add8c	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xfb85966d	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x011061df	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x08fce469	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0d62d0d1	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x132e7fd4	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2ef4ec8b	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x32a60989	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3348551e	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x37ee191a	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x65963750	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6b202899	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6b4de810	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6db00dd5	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xafcdc668	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb44ba6c4	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbb88e6d1	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc2a77c07	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc70cb313	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdbc8d597	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf4b2f230	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf8e3b352	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xfa88b478	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x1d2c36a5	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x1e7f0df9	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x4ea00f4e	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xc09641a9	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0758d0c4	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x07b76928	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x09e98742	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0ce36f31	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x139bc04b	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x339978c9	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x41cdb945	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x44a7c653	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x48fa90c7	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4f57068a	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4fcf021e	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x59c397ef	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6145500e	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6ae73118	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6e7350e7	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6e9aca94	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x737c0eff	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7843c3f9	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x85cdf10a	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x97698457	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x99876a3f	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa0ee9537	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xba061347	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xbd8b4860	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xbdd12040	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc10019e3	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcecf84a4	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd3718b72	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd38976bb	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd591935c	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd94759b6	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xdf8d0c02	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe53805c1	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe601d96a	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe6b33682	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xee0fc43f	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xeeffe6ec	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xefe8f6b8	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x25b751ca	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x29ccbf1b	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2cf21d39	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x30502c36	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x3bfede01	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x41f2df1d	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x70d74eb2	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x7aadaf7f	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x858c6aca	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xb0cad76f	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xb4d305c5	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xb61db2b3	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc3957570	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0446aed2	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x04800f34	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x057eb35d	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0811f043	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0c0de359	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1567519d	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x18b5c303	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1e150f6a	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x22c5bb01	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3114c951	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x34dd184b	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x41537fc2	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x41a1842c	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4fbbe2a1	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x590b0549	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x59343362	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5ad81222	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x68d77cc3	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7db29299	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7e77b3d3	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7f245372	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8c7b2049	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x90029501	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x904813f8	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x904b164f	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x984eea41	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa87d53ba	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xaa6bb93b	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb443482b	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xba74868f	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbe7bdf17	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbf72bb2d	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd135c1c4	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdb7b7b40	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xde29c13c	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdef29462	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe522890d	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe5ede11f	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe62947be	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe77523df	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xec080211	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf006ee58	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf84bf266	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfa84b832	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfcdd8b97	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfdd871ba	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x07238446	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x216c20a8	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x43be7ea3	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x6283aba5	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xd6e994d6	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x1b1ee3b5	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x8df283fb	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xc68a4896	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xd1e90284	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x06c37260	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x10358467	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1eb3c8e9	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1eeb5edb	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x235bed8a	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x3db7678e	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x46494f73	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x5bc3f797	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x5ebce741	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x7df4bf7c	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x897f4b06	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x92eda220	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xbb94757f	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xbeceed88	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xdd10f11f	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xf01405c8	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x360883d7	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x503b834a	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x6c85ffe9	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x03656d44	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0e2da949	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x118cec52	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x16147349	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x18b27987	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1ee30738	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x219560e5	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x274a345f	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x34702d6f	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3880426c	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3aabc252	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3fde67e8	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x48b1cd58	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x49ce152d	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4c35ad16	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x528ce3d6	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53b0dab3	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x546106ac	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x626c4da6	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x63cb25dc	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x69f8bcc2	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6d142030	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6e225cd1	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x73e5c3be	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x775baac9	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7b5650d2	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7e1a047c	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8eedfb0f	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8f557ae1	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9e951004	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa5890eee	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa6c524f2	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xaa2fedd7	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xae9c3544	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb491c43b	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb62486d3	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb805a0fa	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc1797150	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc38e4bdd	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc9078626	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd4355423	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf272f020	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf40494b7	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf8c80da1	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfbf4d2d4	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x22ca38e3	mei_phy_ops
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x521a6b9a	nfc_mei_phy_free
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0xb3a30243	nfc_mei_phy_alloc
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x1e922ff3	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x7c50718c	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xf583b0b3	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xfbb7040c	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x0db48239	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x0df5052c	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x2298b362	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x7d41fcca	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x99b9afa5	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xd925fb42	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xdd242528	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xeec90a9d	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x20c7d459	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x2cc91f85	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x52c611b2	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x0c80bf9d	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x16e16764	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x202d4ed6	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x224f51bf	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x3866e217	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x72a337b5	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x7ba66918	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x93e24e90	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x99f018c4	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xa408fe3c	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc697b0f7	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x1ac2e6ca	intel_pinctrl_remove
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x41e14396	intel_pinctrl_probe
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x51eefe57	intel_pinctrl_resume
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x7708c008	intel_pinctrl_suspend
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0xf7f9dbd8	asus_wmi_register_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0xfe08cb63	asus_wmi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/dell-rbtn 0x51552fca	dell_rbtn_notifier_unregister
++EXPORT_SYMBOL_GPL drivers/platform/x86/dell-rbtn 0xa060fe7d	dell_rbtn_notifier_register
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_ips 0x46809fa9	ips_link_to_i915_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0x56235c72	intel_pmc_ipc_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0x75068282	intel_pmc_ipc_raw_cmd
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0xdea07053	intel_pmc_ipc_simple_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_punit_ipc 0xa6c87106	intel_punit_ipc_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x111aafa7	telemetry_set_trace_verbosity
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x1bbf0813	telemetry_add_events
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x1be25432	telemetry_get_sampling_period
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x4294042b	telemetry_get_eventconfig
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x4cb51f18	telemetry_pltconfig_valid
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x50c1c0a8	telemetry_get_trace_verbosity
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x5847f501	telemetry_clear_pltdata
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x611fd2a7	telemetry_read_eventlog
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x64c6a83e	telemetry_read_events
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x73dcd24f	telemetry_raw_read_events
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x82bb2dbe	telemetry_get_evtname
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0xb78846ce	telemetry_set_sampling_period
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0xbb9a2726	telemetry_reset_events
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0xbf0d3d83	telemetry_set_pltdata
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0xcbdc93cf	telemetry_update_events
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0xe7eb1528	telemetry_raw_read_eventlog
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x232b5238	mxm_wmi_supported
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x61cdf799	mxm_wmi_call_mxds
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0xe26032eb	mxm_wmi_call_mxmx
++EXPORT_SYMBOL_GPL drivers/platform/x86/thinkpad_acpi 0x706cdcef	tpacpi_led_set
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x3ecf6cfc	wmi_install_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x561c634a	wmi_evaluate_method
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x876d29f1	wmi_get_event_data
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xb5a6ebe2	wmi_remove_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xc9d4d6d1	wmi_has_guid
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xda29f8b0	wmi_set_block
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xfb882fb7	wmi_query_block
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xd8c82379	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xe25c93b8	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xf208968e	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0x6365870a	pwm_lpss_byt_info
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xafcf8794	pwm_lpss_bxt_info
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xb563cdb0	pwm_lpss_remove
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xc34d815f	pwm_lpss_bsw_info
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xf3b40a39	pwm_lpss_probe
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x3a573d59	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x86cdd329	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xc37d467f	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x35c4132b	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x4dde3c27	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x80d75c8e	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x8c103174	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xa63fcd1e	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xbbe0e6c6	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0xe50e53b4	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x002167e3	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x16c042e8	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x19919e77	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1aa4e57c	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1ea12345	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2353438d	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x26bcf178	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2dd81f27	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x35b2b499	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x38b9e05e	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3af297c4	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x40e09f62	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x43524617	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x506e3562	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5b34d197	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5c177eea	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5f55b912	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x605e916e	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7814a0d2	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x796683b8	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x83fec4d2	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x857d08e8	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9b4dbbe0	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xaa6ebe3f	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xacaf9c3b	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xacfd0729	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xadf97960	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb1082fe2	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbaa4dfc8	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbe107ac9	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc99203fd	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xca3e1aea	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xcbc481d7	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xcc589d74	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xce713434	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd16d951a	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe324ee7a	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe4d48fe3	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xec67c2c3	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xeca95fd0	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xedce3d22	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xefd89ba8	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf6d0179b	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf77a790e	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfd9fb2e5	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfec290b4	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x00c980d8	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x06750e1c	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x14797d94	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x3a5e15e0	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x48f0b577	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x78fa2ef5	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x7ef8ff8e	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x8a67d367	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x8f9b21bc	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x96705086	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x9c5a6c62	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xca9fc5c9	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xd57b97ec	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf0774e9a	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf2af2aad	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xfd87b00a	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x367f04cc	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x48b447b6	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x48ed768b	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x5416cdd2	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xd6428a05	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xe3b1c24b	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x098ad3db	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0cfbf2d1	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12182fb8	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x21290637	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x22699bfa	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x278c713f	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x28031698	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3458c647	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x36ca3bbf	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3741f13a	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3872f988	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x409a1239	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4cbd6d57	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x50ec3c04	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x542edb26	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x57e2f368	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5edf724d	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5f3771d0	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6142e25d	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x655b64e9	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6e7b9c5a	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7366479f	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x74b3987d	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7a3c9d07	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7ac7710a	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7da2e529	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7e906535	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x82be83bb	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x85e59a9a	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8b686749	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x92b1a2ce	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9c739b3c	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa40f0610	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb022183f	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb2dc6895	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb5ecb109	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbc075ed3	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xce5e33f5	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd4eb4adc	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe0158600	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe8c80f52	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xeb6b0384	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x0018ff2a	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x1596fa91	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x181c502b	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x336fd13d	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x63f6cc30	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x68930b61	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x6c45ebae	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x73d625d4	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x775faaa8	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x7c3a2df7	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x7f2c094a	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x90494d25	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x9e481a09	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xa23631e2	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xaffc70f7	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xceca5fc7	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe5d3f272	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x0273ee5e	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x04f23708	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x050e0057	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1f4df05e	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x20f4610c	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x22c8b421	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2d8640fd	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x32f472e6	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x37422cb3	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x443a6046	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6ab6159e	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x75f66782	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x79a75ef6	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x81356f1e	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8c56bd81	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8f3047fe	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9c663c4a	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa11f0fce	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa82140d4	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xc632a9f3	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xcf8c212f	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xda738f48	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xeecea7c3	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf69df1d5	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x003daaeb	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x04b5f65f	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x06f7fa3f	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0b6dc439	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0b95baeb	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1921fd54	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x20a60fb9	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3e08bf8f	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3ff12c9b	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4276dacd	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4f33a387	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x501b1956	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x50b443cb	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x56d18642	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x670fa63f	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6e8f465e	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x73aebe80	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x769361c1	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7ef6cce7	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x801f8757	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x83040340	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8b753577	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x90130498	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x90db02b6	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9970fad6	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9af96303	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa23b34fd	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa3ee40d5	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa964e8f5	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb1b6ef47	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb38f5810	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb59b9728	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb5f9991c	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbe7e41c9	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc379acbe	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc64ea57f	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc6a59da2	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd1c9f86e	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xdd54434e	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe68b77b8	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x21ef7494	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x44b702de	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x679a89b7	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xf11b7cb5	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xc7e1f04f	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x46c39879	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x4eb527da	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x880293d7	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xa8bde6bc	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xb36d6110	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xb600fb5b	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x2be04b4a	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x3d4635b8	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x40e1bf2b	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x5d4c4067	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x82088565	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xd5202e25	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xd6c9c42c	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x17768567	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x186f6bfe	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x2681c579	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x2f87f7ed	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x3642afdc	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xa466214b	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xdf233303	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x3d4c7bf2	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x4cab8d49	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x55dad84d	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x7800302f	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xf2e864d4	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x2799c82a	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x37aac021	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x7fbe3896	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xf2377b7a	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x06baaecc	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x19aca355	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1c0a67eb	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x396b214d	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x44953490	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x4c34c3c0	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x56245b07	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x5a247d7c	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x7ba79791	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x81aff360	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8788d64b	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x930c2f12	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x9dbd5d06	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xaf0d4c3c	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xb3671444	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xc2626c84	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xcf94feed	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xe99744b3	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0x388e052c	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x05fba4cd	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0aeb1725	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0e183937	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0f6b5fba	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1d4cae64	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1dabce15	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2102150f	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f4f1684	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3094aceb	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3db04b00	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x457ac479	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4d59ae18	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x532b36c6	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x552abc25	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x642bdb72	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6df1b75d	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x79a61cf0	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x7fb0c547	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9609612e	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x98303237	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9af1336c	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9b78ec3f	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa6f72de8	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb0218dbc	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb78f5f93	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb791ce6a	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcc4b4f54	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd06ae41c	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd2a1efa2	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd6bc7c5f	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdcd86c14	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe18e1f36	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe63f38cf	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xea3793da	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf848cb9e	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x0cc42f55	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x251603bd	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x308d95fd	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x373f2fae	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x5c8c9b77	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xa6843eed	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xbe4e3e53	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xf99aef8b	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x191048d1	comedi_pcmcia_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x278cd6d1	comedi_pcmcia_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x27f6f953	comedi_pcmcia_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x6dc9978e	comedi_pcmcia_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xac52e2c1	comedi_pcmcia_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xb7e84e99	comedi_pcmcia_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xd317f4db	comedi_to_pcmcia_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x158da47f	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x67f73567	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x924fd942	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xa000072d	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xe49d4573	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xf3acffaf	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x508295fb	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0xb7d388e8	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0xbae0895a	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0x6ebbc1b9	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x16510501	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x2f2588b9	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x422a054f	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x552404bf	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x670906ca	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x68280a57	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x6e0af0d4	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x6f7e5e0c	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x9f9e8b7f	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xa3102dda	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb1308b1e	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb8cbd872	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xd7415fd4	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x12d888b8	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x54e56aaf	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x7794dc58	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x0d68fcd9	comedi_isadma_poll
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x12fba874	comedi_isadma_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x4a17474e	comedi_isadma_disable_on_sample
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x61f9b59b	comedi_isadma_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x6815a033	comedi_isadma_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa3d01a85	comedi_isadma_program
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa7ebb8a3	comedi_isadma_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x9d2d7ffb	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x277ba529	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x29c7ccb7	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x2c45b66c	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x43ca548f	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x49655853	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5797e25f	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5a040786	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x671c0a4f	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x678364c2	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x7574459f	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x7979f116	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xaad38835	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xb1e6f4c2	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc6a530ff	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd19cb9c8	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd2834d4a	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xde2133e3	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe0a143f4	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe1de43b5	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf11e3529	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf7fb7a78	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x2d4952f5	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x96e8e48e	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x0f44cf69	labpc_drain_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x2ce83aaa	labpc_free_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x4bdf3677	labpc_setup_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xb3e39c96	labpc_init_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xbae9144d	labpc_handle_dma_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x43df697c	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x6aa99d56	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x738f182f	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x8c132732	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xa24b17db	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xe02a9459	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xf1551b59	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xfc5bf2f5	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x06d9b7b6	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x29b7516f	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x6f932d57	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x88bcf173	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x92e06083	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xf664cf3d	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x25a968d8	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x492dd1a6	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x5c4c5a9f	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x6aa8dfd2	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x71671601	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x97dda4a0	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xda41b936	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0x67736947	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x0edfb1cc	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x299f1679	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x4ae7fc45	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x4bd5e61e	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x53c610b1	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x602e185b	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x9b86cc86	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x9f5d11c9	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xab9d7fac	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xb4838799	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xc50639e8	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xd396ad81	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/rdma/ipath/ib_ipath 0x1514b2b2	ipath_debug
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x01f6a04d	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x1a0edd9f	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x2ab8daa7	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x3997a436	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x410b102a	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x503fd4fc	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x5094c4a3	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x6698e0e8	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8ab7113e	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8b3aeb81	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbcd8d392	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xf24271ab	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x0877dd5c	visor_periodic_work_start
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x0ec0434e	visorchannel_zoneid
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x149bde55	visorchannel_clear
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x1582a13b	visorchannel_signalempty
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x2886afa3	visorchannel_debug
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x37626eff	visorchannel_get_clientpartition
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x39fe5de1	visorchannel_signalqueue_max_slots
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x4063ea9d	visorchannel_signalqueue_slots_avail
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x4e4bfbe5	visorchannel_signalremove
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x563d32aa	visorbus_read_channel
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x5e533597	visor_periodic_work_nextperiod
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x60aaf74b	visorchannel_uuid_id
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x610d19dd	visorbus_enable_channel_interrupts
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x6d2236e7	visorbus_clear_channel
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x720775df	visorchannel_set_clientpartition
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x7948d062	visorchannel_get_header
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x7a4ec5c5	visor_periodic_work_stop
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x85b49e2d	visorchannel_get_uuid
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x865e5ab6	visor_periodic_work_destroy
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x96401fe5	visor_periodic_work_create
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xa428b832	visorchannel_create
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xa77f3c8a	visorbus_write_channel
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xac7771ac	visorchannel_signalinsert
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xae9128e9	visorchannel_create_with_lock
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xaeb9627f	visorchipset_register_busdev
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xb21866a9	visorbus_disable_channel_interrupts
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xb4aab617	visorchannel_write
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xca18358d	visorchannel_id
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xcc89f91f	visorchannel_destroy
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xd7edca34	visorbus_register_visor_driver
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xe3b5efe1	visorchannel_get_physaddr
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xebc59b20	visorbus_unregister_visor_driver
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xed313c21	visorchannel_read
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xf990f627	visorchannel_get_nbytes
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xfece836b	visorbus_registerdevnode
++EXPORT_SYMBOL_GPL drivers/thermal/int340x_thermal/int340x_thermal_zone 0x628c48ab	int340x_thermal_zone_add
++EXPORT_SYMBOL_GPL drivers/thermal/int340x_thermal/int340x_thermal_zone 0xe829eae2	int340x_thermal_zone_remove
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x5b471184	intel_soc_dts_iosf_init
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x63edb99f	intel_soc_dts_iosf_interrupt_handler
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x96c831c9	intel_soc_dts_iosf_add_read_only_critical_trip
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0xe691cb08	intel_soc_dts_iosf_exit
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x50292d96	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x664b22b7	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xe780b034	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xbf90c79d	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xbfec053a	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x253d452b	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x4a9c4a4f	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x0539d70f	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x57f1b705	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x84f2d39b	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xb8966d23	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xc5d7a920	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xccaa5650	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x00a60f80	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x21e46079	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x3f73a6eb	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x48a80637	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x6f2ddf0c	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x91007091	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xab14499e	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xb1a029dc	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xb3f1e3a4	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xb6181ed5	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xbcfa3f4a	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd9c8765f	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xe83f4331	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xf528aa88	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xf8f3dca8	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x89ca818c	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xd371dd12	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xeb2dd117	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xf41130d0	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x18b1224e	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x56a4d0d6	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xd667b34c	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x0172237f	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x076de66f	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x08195931	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x0de43e24	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x19b7aa9b	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x28ffc25a	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2b6ad518	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2cad632b	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x3c7598b9	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x471006c4	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x4d7a8daa	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x8407ddd8	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99930a7c	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb3c44db9	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xc898d9c6	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x27bf599d	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x3929a83c	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x39f49d4f	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x5cff0607	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x6535715e	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x6a087ca6	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x7870152e	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x846dbf1b	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xa6f26255	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xad6ee7a5	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xc11251a4	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xcb070d7f	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xd0ad6f0e	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xe178b217	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xf2fefa11	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x02d65867	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x03b1db0e	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x081db4c9	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0c0ebd3f	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x126550b5	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x14899298	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x1904a256	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x29ef52fc	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x35b3e733	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x39ed719b	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4295d5b2	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x459ba287	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x48e41cd9	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x52e776e6	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5bf48a5a	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x68494784	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x719fab7e	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7938f755	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x84cf33df	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa3218b41	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xac191861	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc23f84c1	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc3dcf116	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc8d3b895	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xca267db3	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xce1c96ae	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd28b0148	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2eec10a	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd5868984	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd8d3a27e	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xdf736660	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfc2ae9b2	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x05eafb4a	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x14c7f6d0	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x25113c48	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x3021a9e0	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x41b4d1ad	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x64e3497f	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x79ae69dc	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x82c9e1ad	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x93e793cd	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x9e2926cc	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa4744dba	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa9a36447	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xdaa4b493	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xea172b88	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x72bb7cab	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x9f92167a	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x1bdee7d2	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x1d272c0e	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x4cbeb3c2	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x56382208	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x8af34b75	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xb99771cc	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xcc9f36c6	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xe7959292	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xef1db977	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x7b2a2254	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0x36a4dcb8	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0xe79b8b04	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x04ecc853	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x168944b4	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1fb5c1ee	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x27cf33a8	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2a5e3559	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x30bb6d2e	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x47e87bc3	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4e251a8a	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x67f2feb0	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7352dd4f	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7bcc8fd4	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x803b1b24	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x8e9d0d75	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x93bcfeee	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xa9b1535e	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xadc92af6	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xaefc3232	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc0d22934	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xdf10a3bd	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xeb44f282	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xfe2c3a5f	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x007e2728	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x0904f6e0	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x21496d94	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x236238a9	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x2dafa2d5	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x35d6fd8b	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x38364dae	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x389fb8e0	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x48a7928c	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x53fe35e7	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x54c95ef2	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x59f01d8d	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6567fc5f	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x67179876	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x72ebf468	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8461fd04	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x84864d3d	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8c99512b	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8da47664	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc9725989	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xcced6673	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd4ea878b	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xea7de6f1	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf5a1d544	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x09490a7b	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x1e283a27	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x5d89c9f9	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x7adfa905	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x8eb0bf3a	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x96637fc5	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x9ba95499	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xa184d210	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xa38e2fb5	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xa516758e	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xa9f99d20	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd5d263dc	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x0bd816f0	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x122f15ac	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x17720501	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x31085255	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x6e53f743	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x7026de83	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x85a801b4	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x87ef0cb8	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xa79a5345	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x07d7e3dc	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x1878ad5e	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x1f44a9a7	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x3bc93ff6	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x4091d397	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x553b256b	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x862ed80a	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xa80002a0	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xafc63e39	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb50a982f	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb7a20fdd	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xdcc34c49	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xee3aa672	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfbdd9782	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x01fce8ea	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x1e61d7fd	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x217e82d8	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x180df6b0	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x511dac48	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x8f7cbdcd	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x9e1dbde7	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x9e66ce00	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x9f9574fa	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xa5cbffeb	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xda1581e5	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x067cdc8c	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x06abd058	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x092839a4	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0be1a874	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0d78016e	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0fc02440	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x154e2db6	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x15574bf2	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x176d4619	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1c167fb4	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1f3c00e7	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x28fc242e	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x353741be	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3878c259	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3c88ec4c	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4091de8f	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x47108af7	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x490d248c	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x54c908d2	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x592c39e0	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5c7dcecc	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5d5180ec	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6313baaf	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6a255bd0	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6e5d7fab	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x748cf859	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7619f7a2	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7ae9cbe8	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7beeff23	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x816b9e92	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x868c397c	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x89e44ec9	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8f3079c2	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x939704f0	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa7dd0d19	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xaa049372	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xac97316b	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xcdd156d2	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf2ecbf18	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xfc8f2963	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xff3e3770	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0x0f0749b3	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x07f8d19c	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x1098089d	vfio_external_group_match_file
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x12b3dfbc	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x319609e3	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3567743b	vfio_external_user_iommu_id
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x4586f06f	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x69b438e6	vfio_group_get_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xb3900359	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc1d989c5	vfio_external_check_extension
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc4913442	vfio_group_put_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0x43c5ade0	vfio_virqfd_disable
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0xf6962e93	vfio_virqfd_enable
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0265de87	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1debec77	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x33029292	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3ece6ab3	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x47293371	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4cb96f77	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4f7cc8a6	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x737a34e6	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8157f477	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x84c53843	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8cca519f	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x98ee0a41	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9f432c3e	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa359f34f	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa5bbdc95	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa814317e	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xad1337e8	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xaeb59b4c	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc1280e6d	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc5a6643d	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xcc64d9c1	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xcd530593	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd5600d98	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xde1726d9	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe1b932b4	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe5abc999	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xeb7ee4c7	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xf691d050	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfd08cb71	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfe97695f	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0x2c63e051	apple_bl_register
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0xdab0f892	apple_bl_unregister
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x22be72ba	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x2dcbadb6	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x517512cd	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xa4de5a95	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xaa8632cb	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xdb5c4371	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xf3f33c5d	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x111541de	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x1af01a98	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x56545b41	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x5c54d274	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x6846e93d	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xadf40fb4	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xdb35ad3a	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xe41efd6b	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xee2686f3	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xf7f0d1b6	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0x4472cb61	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0xbf02a4ef	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0xfec0ee69	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0xa3a9088a	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0xdc4e6afc	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/vermilion/vmlfb 0x016e6c20	vmlfb_unregister_subsys
++EXPORT_SYMBOL_GPL drivers/video/fbdev/vermilion/vmlfb 0x90c018c6	vmlfb_register_subsys
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x15446974	viafb_find_i2c_adapter
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x22a7af24	viafb_dma_copy_out_sg
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x292da7a2	viafb_irq_enable
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x30cc9311	viafb_request_dma
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x31469540	viafb_pm_unregister
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x79e6190a	viafb_irq_disable
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xb4f863e6	viafb_pm_register
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xcaefb732	viafb_release_dma
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xfff2dfd2	viafb_gpio_lookup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x00088dd2	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x23d4de74	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x3f177a0a	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xca0f39b5	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xd21ff68a	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xe19956e3	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xea413082	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xf9f5b490	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xfbd41297	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/xen/xen-privcmd 0x37d748b1	xen_privcmd_fops
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x1671caf7	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x607a3870	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x841c8690	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x209e0cf9	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x2eb1f94a	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x76399c04	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x8d509d4e	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x930fad5d	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xba9e173b	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xea48528f	lockd_up
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x00f0a71e	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x05177a84	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x08ac1913	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x08f9c15b	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0920535e	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x097bb08d	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0a033855	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0b575956	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0c2e818f	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0ebd2154	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0fbe84c9	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1013c378	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x10a79376	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x125923a0	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x12e7c379	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x141e3fe2	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x19cc4823	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1a1b13b8	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1c0c7431	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1e107205	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x238d1f8a	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2431f0c9	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26ab6d29	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x29a96cf5	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2ac90f69	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2ad80922	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2e85db80	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2eb51550	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2f2ec84f	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x34946067	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3594850c	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x35f4149f	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x370a62ac	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x388ba15d	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3bc137f3	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3e6dd8ac	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f6b16d4	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x45d5c869	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x475b7ea8	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x490c7345	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4c691576	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4d0e4d3f	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4d1cc548	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4fd03437	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5089ae7f	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x544fd027	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5631ca69	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x58204b26	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5afc11ca	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5e7d6533	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5ec46e91	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x648e1a94	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x66190ae6	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x66341d72	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x676d0bb2	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x679b284f	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6902283e	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6aaf3fea	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6d5d71fa	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6e46dfe0	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6fa1b514	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x70e48fe4	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7372601a	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7793308e	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x77a0e0fd	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x799d9eba	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7c9722ba	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7cdeb2bd	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7d82c62f	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x85b17ad9	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x86c45104	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x871fea63	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x87daa93b	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8a229ec5	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8ae92a04	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8d278734	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8d9e1aea	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8ea562c6	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8fc1139e	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x902ee052	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x92969cbb	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9387e4ea	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9456c218	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x954e7f97	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x992f38fb	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x996b4fdf	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9cf6866a	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9d36588e	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9fa61a0a	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa372957a	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaadde206	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaea173a8	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb40beab5	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb77eead5	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbd33ac68	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbececadb	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbf240e85	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc0080312	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc120a29c	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc235fabd	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc2e117f9	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc8d13d09	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xca5adaa1	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xce85166f	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd0933cfa	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd15aa2ba	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd4806680	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd5140df3	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd81fd314	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd9d26ac3	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe39aecaa	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe5c12ae4	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe630755c	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe9277bcf	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe9a67cca	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xec672515	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xef8b61c4	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf410328f	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf46aee54	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf8119021	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf97e1475	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc7661aa	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfcf119b4	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfe6d623a	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xff5c18cf	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0x393dbf1f	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x03105db7	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0431c72e	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x04409d4b	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0b2eec9c	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0c701c34	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1093b108	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1ac29ac6	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x22fb63bd	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x23928458	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x25b082d8	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2b303724	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2e088d04	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2fcf137d	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x318c70a9	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x31f0e475	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x372882e3	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4786d5e1	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4e3605a6	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5ce538a5	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5e7cb9a7	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5eb7f201	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5f36948b	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6085edbd	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6179a70b	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x62ee8b87	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6ad72985	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7b563516	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7bfa5b65	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7dacbf5c	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x826db747	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x870a7dd4	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8846d9d6	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x89ad9f97	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8b68402a	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9563656c	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x959f201c	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x96b0af04	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9c9f5955	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa6e0663f	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa9e7c327	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xad59343c	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xaedb8127	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb0480ef3	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb32d0a6e	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb5249a98	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb787af19	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xba46c581	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc6513216	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc7b77b1b	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd0b5b7dc	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd898c38d	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xda181497	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xda7036a2	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdbf0af36	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdd7f88fa	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe6d56001	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xecbbd4af	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xeefb9c8c	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf2fa1834	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf32f7f23	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf76c92bb	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfc8be3f4	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x6ee769b3	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xc364ecd1	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xffd73afe	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x21611e4c	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0xef0341d3	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x200dfbe3	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36a28a9e	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x5ea493e7	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x7c1bcba0	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x81a17396	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa0a780b6	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xafb81975	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xb38bfeb8	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf56c2017	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf9715706	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x169afd60	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x43e30571	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x57289aef	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xa16123d2	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xa25f4c13	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xb8046306	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x0dd169c4	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x58d22e3a	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xc7260236	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x43f8a56e	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x5d4e0515	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b9f71fd	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x893f921e	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xc7293205	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x1803a6ed	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x2b30f429	raid6_call
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xe4b051cf	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x0adcb055	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x221df614	base_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x4da25bec	base_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x63f42b6a	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x76203267	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xca3140ce	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfa5eee0a	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfc02472a	base_inv_true_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x4d9cabcc	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0xfd50aeb8	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/802/garp 0x2ff08c54	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0x5a3e07c7	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0x5f052d19	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0xb2bcc32c	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0xcc4defaa	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0xfd04de1a	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x520f3f7e	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x5a19a05e	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0x897523b4	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xc85e2ba6	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xeefd72ec	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0xf09a4125	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/stp 0xed651fb7	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/802/stp 0xef7615af	stp_proto_register
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x012ec818	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x0f1a25cf	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0x4f9bb71b	ax25_register_pid
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x1907eda0	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x75916165	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x7f4c44b9	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x8b3c3784	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x91b8df56	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x976a6c22	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xa3884e13	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xef3e4608	bt_debugfs
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x0fbd0946	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x1fe3f5e2	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x3ba79f04	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x41500615	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x4d46af60	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x92d5ea49	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xe9eafba5	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xf6ea7da4	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x0b57ad36	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x17d4abae	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0243ed7e	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0c1c0654	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0e0e7417	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1c928600	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x20971804	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x233a2500	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x23672cd0	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x24fed8f1	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3490815d	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3cc49947	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4e2d4d99	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6184e3d8	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6b1e4651	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6ec46362	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x83a3c269	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x840f2d94	compat_dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9180bde1	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x940a67c9	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x97658cc0	compat_dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9aca485b	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9c70dc0b	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa025b4af	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa02c934d	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa1589684	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb2497572	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb7b07659	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb87666c5	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xbc655c38	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xbe5c61da	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc28c8e19	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xda3b64d1	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xda4405c2	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe2c93ff3	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xed77252c	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xee23193c	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xee87ad5e	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x4f8af54d	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x5066c6bb	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x8c12cd38	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xad1741fa	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xb025b6c2	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xd4763ee2	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x4d7aef69	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x51939f6e	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x554f9682	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x8e448410	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x938c7b00	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xf19dd4aa	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xf3fc1b1d	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x0b5cbfb5	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x4917354b	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x5af4d98f	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x675640da	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x771d68dd	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x8919e19f	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0x317a2c04	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x06dffd5a	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x2fffb1e7	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x5b1efac0	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x67390583	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x7a93cab3	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x7c873bc6	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xad545ab1	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc8582bfe	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd0c2c637	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd0ea4ad1	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd1d7326b	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd5fbf878	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd9e03d3a	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xe1031c9d	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xfd9d41f7	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0x3485fe19	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0xc55f3aea	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0x0decfab7	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x723bfaea	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xadfe7ab2	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xf92ec55c	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xfb89d214	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xfda0ccae	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x18bd12eb	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x00e6a680	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x6f8a2b2e	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x748507ce	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x8dfc8e04	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xee090aeb	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0x5cbcc3e4	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x42ab1ce0	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x63050157	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xeb1f1dd0	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xf9b5598b	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xfacaca01	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x0036e8b5	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x96818e08	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xde75525b	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xf9167a83	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x107f69b3	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x17ae4861	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x523d40c2	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x5cc81c0a	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x5e1f9f71	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xa42b3070	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xb96ecbd9	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x08fed159	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x25300743	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0x9c6eb897	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x376c1439	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x65322f31	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0x24e598a1	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x43e5048d	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x4c4d807e	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x9c6b5ecb	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xc5042acf	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xee2283cd	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x16142333	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x23beff05	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x42ac6251	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x67851bdd	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xa4de5ebd	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xb5b9388c	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0x41e09ba3	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x08744a87	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x18c652ab	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x1d6f0af6	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x23e29055	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x2a8e1a37	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x3666718b	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x65c90dd1	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x6a67193a	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x797f9b40	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x806a18a1	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x829e129b	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x90e4ca56	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x95e17c64	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xba85c5ca	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xcadf2af6	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd4b70805	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0xd286ca2e	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x0d8f6043	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x11e1f72f	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x1f216d2c	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x52f86a52	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x58a151ae	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x5b36d08e	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x6e427bd1	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x817bd7e7	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x86b1dad7	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x8a760de8	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x98c716a2	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xa4b193ad	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xaa8bdbe4	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xb8a241b6	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xc1a2d804	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xdad73c11	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe05a6187	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe8cc782b	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x8c74bc38	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x923e895f	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xa307e421	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xfa231c1e	mpls_output_possible
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3958305b	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3c0e7ef6	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x5f740e14	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x615af51f	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6a77e3ca	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6f7fda4c	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7786a421	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7881d187	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa020b076	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc89f5f55	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcd2956f4	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd1638705	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf1e5f12b	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf3a99ab2	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf3b4d4ae	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xfc5c87f4	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xfd58cd5f	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x166c1331	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x7433a1f5	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xacb63972	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xe44a9049	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0c0bd125	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x137c6edb	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1497885b	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1e367f73	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1f31fdf4	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x295d1e3a	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x298f530f	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2ac348d9	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2b7d6614	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2cee0203	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2d4df134	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2e8c12f2	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3484f8e7	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3b90328e	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3ca1ade2	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3ef2abf6	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x42cfc811	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4395096a	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x440a12a3	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x446bea64	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4495125a	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x44ff69fa	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x45534b23	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4653e904	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x47704932	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5364aafd	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5a8234ec	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5a84d8f8	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5fff8e74	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x600db1a6	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6025ae3a	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6314f44a	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6459e411	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x666da1ba	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x68b4566e	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6a18dc58	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6d318308	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x73756342	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x741be4b5	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7629b73f	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7a0ec560	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7a0fe489	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7bc4138b	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7c989cfb	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7fc7d18e	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8403147f	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8507bce7	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x85f992ba	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x87df62ad	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8d85ccb6	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8d9b8af2	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ea0df79	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90bf61c2	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x950e7e54	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x951d2fe8	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x96753218	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x97b39f39	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9aa8726d	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9aef4198	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa2d59abb	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa30c5217	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa5012b66	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaab3ea81	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xadf8dad3	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xae600172	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb1bd992c	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbffe235b	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xca44cdc4	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xce0c7cb6	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xceb09022	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd1fac7af	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd2a83a19	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd8289eaf	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe6b3731d	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf04bf0c0	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf186acae	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf8845f60	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf8d9a3cc	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfb00ecf1	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfc3a1e34	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0xb8c6754a	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0x03989441	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x6b2fd39a	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x1924f4e3	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x286cc99a	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x3e59e01c	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x54de0e3f	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x60c92573	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x6ab3b631	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x86f41a41	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xcc3d0fac	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xf1c5fa7c	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xf7580331	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0xdbffcdea	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x40729058	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x5f97c606	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xd0efb406	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xe80a3795	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x9eb8d66f	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xd9eb739d	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x0ef31f73	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x47729e51	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x4e07bda1	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xaf7877a1	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xd5437511	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xdc4ee838	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xedd56362	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0x37442ca5	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0x4ba742d1	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x6ab35cee	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x74f1cb1d	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xa870ffa1	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xd049c1fc	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x08c18545	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x92243535	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x92c41150	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x94bb1628	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xb0b3c610	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xea858da9	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xf8ab9f62	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xf8ece4b3	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xfaadb7df	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x38134e6b	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x69af166d	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x8841d39b	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x9392cb92	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xc84c9809	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x082a8270	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x12048908	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x2c08adde	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x2f6cfe48	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x3f802371	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x447779c0	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x4f224a22	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x593cfba8	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x634bc4a6	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x6bf89820	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xa864fa75	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xb792d9a1	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbccb2f4a	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xd0c27f4a	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xef3ed2d1	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xf130cf96	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xfd0b9f0d	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x216f689c	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x424de106	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x513a8637	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x8b628bfb	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x997c4469	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xa50366d5	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xb8bcc7df	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x046488b9	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x09a653d3	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xba23eb22	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0x7762ed05	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x5e5ceeef	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x6192a1ae	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xb8ca865e	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x10bedcae	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x233c5e03	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x26fbf989	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x361035eb	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x6afad014	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xf66a44d4	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x327b4d2a	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x5b75e6e2	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xe34e409a	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x511a35e7	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe7b94527	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x161d1417	xt_compat_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24f663cc	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x33e595c8	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x44301d6c	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x51611aad	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5f44c5ed	xt_compat_match_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5f82f1f7	xt_compat_flush_offsets
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x691a6d69	xt_compat_calc_jump
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x73cee41e	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x78a43041	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9625fe02	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x99856a8d	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9b215ec9	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xb0176f60	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xb02c5f1f	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xb0a06092	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbeb74a16	xt_compat_target_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc1bcfe2d	xt_compat_match_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd55acfa3	xt_compat_target_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd6ef6014	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd78161d2	xt_compat_match_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe0b4971b	xt_compat_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe357e0fd	xt_compat_target_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xec24fd82	xt_compat_add_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xfb3809c2	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x4c32c169	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xb7459345	xt_rateest_put
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x6af75388	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0xf1a97db3	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0xf63cd4dc	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x299ec646	nci_uart_register
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x84dc0264	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x9a4a65bb	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x14a44208	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x1b6fa268	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x292aacf3	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x4e7aa0d4	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x8b1d8b54	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xad7232f1	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xb6a8748c	ovs_vport_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xe3ed9341	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xf2b90ceb	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x1263ed70	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0x17cac343	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0x274a7376	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x35c106ef	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x5af12fa4	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0x5b8ba62d	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x5f976a97	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x684640c4	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x750fbe82	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x793ded17	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0x7bc62829	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x7c518050	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x8b47e485	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0x8efd3d1d	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0x93ae6ffd	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xa16b9def	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0xb3a5ccd5	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0xb7452602	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0xba5149bd	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xbcedc61f	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xca935705	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0xd990f0f7	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0xde673448	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0xe8dc3744	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0xf7ba349e	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x1d3d7858	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xe5b55823	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x415117dc	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x986d9506	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xd4055792	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x01488262	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x021fa37c	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x02e20cd9	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05b432f8	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05d9ee66	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x060e7b7a	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x064141e4	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x06f93112	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x07dcc2c8	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x07ed6b65	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0904fd10	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0bfa2267	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c8b1608	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0ca367ac	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0e96fb8e	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0ef9fbff	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0fbf2bc0	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x10066c69	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x109d6e28	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x14acd881	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x154077d9	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x15feb477	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x16e40d9b	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x171e31b5	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1ae4c95a	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1afff6ab	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1b04f52e	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1d6eed8b	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1df7cb3b	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1f2a9970	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x225a398c	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x226bc4ec	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x233d2863	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x279a4d5a	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x27c7d1eb	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x284ad0ed	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x29140a9f	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x299dce95	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2ff9f19f	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x30727fdd	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31f64792	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x32a64981	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x354ec999	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x35a2e6d5	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3624b70a	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3bd78f15	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c2e4b21	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c46572e	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c80c20a	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3cae1560	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3d25ba92	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3eac6474	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f8c5c96	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3fb81907	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x41c0819a	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x42d330ff	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x44d45239	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x46dfc2c9	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x46f21cce	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4bd846a6	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4c2519ec	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4c93c8dc	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4ceff076	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4ebbd9e1	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4f3ac16a	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4fb8639d	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4fd34465	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x52acf11a	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x52bd5f00	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5377c0cc	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x55d0bb4b	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x561744c2	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x563591c6	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x585ab2c0	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5a4c70de	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5e90af55	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x61a75840	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x63fea2cd	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x67c32c89	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x69474cf1	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6b2c4d84	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6c5089a6	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6d72196b	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6e3e5f6b	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6fabb2a4	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7208173d	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x724a821e	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x73c838b2	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x74984eef	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x74b2259f	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x75f151eb	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x764d8367	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7726f947	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x773521e7	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7900df9b	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x79f8342c	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7c981f0c	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7cfc478d	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7e541d83	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80646536	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x820a30ff	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x828a83a5	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x84ae7ff8	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x856cf597	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x863aeef7	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x87099d94	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x876db969	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x88857a8a	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x89439d62	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8d048537	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8e381ca3	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8e69a75b	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8fb20614	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x911235e0	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9297adaf	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x94c2fa18	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9507daa4	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9579ff56	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x97454a69	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x97784330	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x983e4d4c	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x999505b6	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9add17fa	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9f56c55a	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa17a9146	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa44bee3a	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa5a4e8b2	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf1109be	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb07d1246	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb241befd	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb2696a20	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb2853966	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb2afce79	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb44a24ae	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb5047f91	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb50b7c7d	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb854bac4	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb886dc8d	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb9adf17d	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb9ff9cb3	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbc3ea613	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbc896f75	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc1253a10	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc14e4004	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc1679080	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc17d0b74	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc1db5e14	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc24a1ebb	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3744075	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc81b6fa1	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc95d9141	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcbba175a	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcbbbb564	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcc2e43e1	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcdd356ad	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd14c8eb9	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd244bf23	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd2d7a1d1	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd382995b	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd39b1075	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd3da2815	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd4af6172	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd56a7bb0	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd648f887	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd6695867	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7085007	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd9874b8e	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd98f2b62	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdb789342	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdd70c9b6	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdffe0102	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe26b875f	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe4070958	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe432e4a9	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe66d5124	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe8b1fb5d	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe8e0f162	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe945ddf4	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeabc5c22	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xebb794ab	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xebb9a842	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xec80f4fa	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xed00af62	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedeb2fec	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef52ba19	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf219f135	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf229274f	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf26dd582	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf510a506	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf551fe09	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf565a937	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf80d4c02	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf8961787	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf93b7f0b	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9e395b7	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa01939c	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa4cef9e	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfc94be87	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfeb14851	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x04b68e8e	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0dbe951a	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x185de7b0	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x3052b7af	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x59d943c8	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x71a5b4f4	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x79346836	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x927410e3	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x9546036e	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x970b77bc	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd44c6b8c	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd68e316b	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xec7001e8	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf4c495d4	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf65bb4d5	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x3204696e	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x4296e5a3	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x53dc0a18	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6655496f	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x66c48996	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6bd87e08	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x70b15ec3	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x80cf9ae6	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xadd5ed6f	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xcd654e06	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xd051b079	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xdcf031de	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xf8f5c919	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x187f32dc	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x28dd12b4	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x42ad6ee0	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x4d467e67	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x5e99f3ea	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x6313c944	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x7e473959	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x8c1a8ad1	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x94810867	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xa2881e8a	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xdd91eec9	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xef5f96aa	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xfbb30704	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x50be518e	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x7c33df84	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x8305bbde	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xedf3b029	ipcomp_destroy
++EXPORT_SYMBOL_GPL sound/ac97_bus 0x306c0332	snd_ac97_reset
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x048e449f	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x4eeea7b4	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/core/snd 0x017aa327	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL sound/core/snd 0x14c4cd44	snd_device_initialize
++EXPORT_SYMBOL_GPL sound/core/snd 0x3c63f1f9	snd_device_disconnect
++EXPORT_SYMBOL_GPL sound/core/snd 0xb96766e5	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd 0xc97fed2d	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd 0xcc11b999	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL sound/core/snd 0xce224f01	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0x29b85a48	snd_compress_new
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0xca6fe9fa	snd_compress_deregister
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0xe9cd752e	snd_compress_register
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x122029b1	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x4330de74	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x8ea09dcf	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x920f35c8	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xbebf9e16	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xe5d5f5ee	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xf1a9a80c	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xf7d17eac	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xfd7dd86b	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x09b5eb9b	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x1655582c	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x2084b4a8	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x529f479e	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x7abb90d5	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x806e526f	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x8ce31df0	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x9585ac5e	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x9e2f7adb	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xc83b03da	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xe4b4a282	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x25e7549b	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x463474e3	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x52259a0b	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x543a748c	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x8dda2f6d	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xa1c8cfbf	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xa4329670	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x08f8bf5a	snd_hdac_ext_bus_link_power_down
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x15697a30	snd_hdac_ext_bus_link_power_down_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x15e2f969	snd_hdac_ext_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x1884a9f7	snd_hdac_ext_stream_spbcap_enable
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x18c053f2	snd_hdac_ext_bus_device_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x297e38eb	snd_hdac_ext_link_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x2a43e33f	snd_hdac_ext_stream_init_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x2d142876	snd_hdac_ext_bus_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x4370d877	snd_hdac_ext_bus_ppcap_int_enable
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x580d65a6	snd_hdac_ext_link_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x5b8e16c1	snd_hdac_stream_free_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x641a0afa	snd_hdac_ext_stop_streams
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x7f7f6f49	snd_hdac_ext_stream_release
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x8ca4c3fd	snd_hdac_ext_link_clear_stream_id
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x90ba9ac3	snd_hda_ext_driver_register
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x90f4cd62	snd_hdac_ext_bus_ppcap_enable
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x9a4e9a7f	snd_hdac_ext_bus_link_power_up
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xb60c539d	snd_hdac_ext_bus_get_link
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xc46f0424	snd_hdac_ext_link_set_stream_id
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xc57aeafa	snd_hdac_ext_bus_device_exit
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xc59edca1	snd_hdac_ext_bus_parse_capabilities
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xcbee7c58	snd_hdac_link_free_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xce3451cb	snd_hdac_ext_link_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd09c3e83	snd_hdac_ext_stream_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd66dbb5a	snd_hdac_ext_stream_get_spbmaxfifo
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd7242760	snd_hdac_ext_bus_device_remove
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd99d8c71	snd_hdac_ext_bus_get_ml_capabilities
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xe3f740cb	snd_hdac_ext_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xebf59208	snd_hdac_ext_stream_set_spib
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xeee03bcd	snd_hdac_ext_stream_decouple
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xf494fb21	snd_hda_ext_driver_unregister
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xf9366fe0	snd_hdac_ext_link_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x03b0a9e4	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0958ea7e	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0abee42b	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0f316892	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0f5aaa06	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1630bac3	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x18c641e4	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x225f374d	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2716de6d	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x27a110ce	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2b4b973e	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2d96c9bb	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x407c4941	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x418d4f12	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x426b495d	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4496ae61	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4a9c90c5	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4c0b1990	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4d6584ea	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4e977c00	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x522fb611	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x549f0111	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x563f98b1	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5ad1bebf	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5fa81f59	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x680d9971	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x685fe664	snd_hdac_i915_init_bpo
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6c850489	snd_hdac_i915_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x73187668	snd_hdac_i915_register_notifier
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x734c43d7	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7911901e	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7aefd3bb	snd_hdac_display_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7b6497a8	snd_hdac_i915_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7cb53bfc	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7cc293e8	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7f4ce0c5	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7f70d80b	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x800ceebc	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x830b5462	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x888f5f04	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x93c59f4c	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x99254714	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9c3a5ab3	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9e3d3583	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9eb3017c	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9f5fde6c	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa552dd26	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa6293f41	snd_hdac_get_display_clk
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa86eb0ca	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa90b9656	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xab79e813	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb55028e2	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbbfaf242	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbd105128	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbeb4618f	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc59b16a7	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc9acc4b8	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcb3ab735	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcc9ebfc1	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcd83c2a7	snd_hdac_set_codec_wakeup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd0051b95	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd28aa73d	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd36b961e	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd64d2280	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd6e91078	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd8852072	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdc4ac173	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xded652a2	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe0859ee8	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe3fc883a	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xea2f88ba	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xea43e73b	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xefbd1b85	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf13e8c1a	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf31b5d04	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf83c2be7	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf8a4f11a	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfb862a15	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x3c74ef25	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x685261b8	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x6f4d727a	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xa317232e	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xab996486	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xc19145be	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0459add8	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0b151638	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0b43f4fe	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0c922a12	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0e1a09e6	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x130a94ce	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x143d46d6	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x16790d27	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x18028436	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1b44b875	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1be2c099	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1d4f85a7	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1fc87c6a	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x20d383d3	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2278b0ca	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x281cc80b	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2b3c7512	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2ca42e34	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2ec29558	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2f93e1d0	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x30265673	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x378c6326	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3c3ec350	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3d7fafe7	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3da6c3aa	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x430c56de	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x46e6d009	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x473eebc5	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4974757a	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x49f5eaa8	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4cdd011d	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4ded93c1	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x50170024	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x520ba60d	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x52565762	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x53d48c12	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x54171865	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x57b22d08	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x59b0a82e	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5ae03984	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x602ba500	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x667f1566	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x697d78ca	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x69980804	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x71994d97	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x770b132e	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7b28876d	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7d203a6e	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7f601431	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x81ef0d72	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8853fb14	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x89f6fad4	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8cb0e33a	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8da0a79d	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x90c1db57	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x944b148e	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9ab42c10	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9aea5b8e	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9bba889d	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9bc579df	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9c2a661f	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9c8e3e7c	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9ea81c1b	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9f1c27e3	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9facbb7c	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa03db17d	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa048bed1	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa38c6941	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa43775ad	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa68d2443	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa865f374	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa8ce6a37	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa94934a4	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa9794187	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa9fe50a4	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xab33134e	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaef81795	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaf4accd4	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaf6ec37f	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaf71d5d7	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb34cc22d	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb42acea6	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb6a0dfb0	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbf3c7f75	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc037819c	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc0957c09	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc125d20e	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc26a88d4	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc3c2ed74	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc42eb444	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc8e7f66b	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc9e8f69b	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcacbb815	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcbcb4f45	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcd310a66	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcf3b5675	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd1057a47	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd2da243a	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd7fe0529	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd91ef58b	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdaf5db05	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xde84f3ed	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe3e80485	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe404f459	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe5f61f22	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe679f048	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe7ba2766	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe7dd94fa	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xea769f3a	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeed7ed6b	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xef558d02	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf020203a	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf1e7ddd4	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf34a1b6f	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf35ba461	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf4423cab	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf6de26cc	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf9910732	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf9bc79ae	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfab5f847	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfcd2cc37	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfd980263	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xffa0d9d1	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xffabdbf2	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x107308d7	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x12b55b8d	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x12c1f916	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x3730aa51	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x3ec87043	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x453b3344	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x463e6dbf	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x4ad58d2b	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x5af23d01	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x7eec99a0	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x81fc34bb	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x9e754550	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xa5901460	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xb3844cb4	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xb5f20a10	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xceeff0bf	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xd0cafc8c	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xd2cb4498	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe43363cd	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe5efe9aa	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe9606edf	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x1978e900	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x5d7451c5	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x381e7d5e	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xcb245058	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x5ceacd3f	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x66ad0191	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xdce2d9ff	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x80e4a80f	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x965df68d	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98090 0x193cc4cb	max98090_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x665b56e1	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x7017e473	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xd2f35e14	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xde5b846d	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x70617a04	rl6231_get_clk_info
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x7f68b24d	rl6231_pll_calc
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x8d7fa148	rl6231_get_pre_div
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0xdba4502f	rl6231_calc_dmic_clk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6347a 0xa7aa810f	rl6347a_hw_write
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6347a 0xade4bf4c	rl6347a_hw_read
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt286 0xa79cac21	rt286_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5640 0x374cb79a	rt5640_dmic_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0x21145389	rt5645_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0x23dabb5b	rt5645_set_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0x823e508b	rt5670_jack_resume
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0xb886595e	rt5670_jack_suspend
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0xc90a3df7	rt5670_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0xd728ebad	rt5670_set_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x89669ca9	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x9131149d	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xa0d183be	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xb6605a1d	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xb69c7777	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0x119e9888	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x1154536c	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x34da9316	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x9766dd13	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xb84b9742	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0xd56231ba	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x0e666090	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x4e8a353f	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x82bca4d4	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x9ecf1047	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0xb4d334fa	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0xf5908fbe	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x847de4f3	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x9d042d08	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/snd-soc-sst-mfld-platform 0x0b38904b	sst_register_dsp
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/snd-soc-sst-mfld-platform 0x95ca54d5	sst_unregister_dsp
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x14444671	intel_sst_pm
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x1513d5c4	sst_context_init
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x24380a35	sst_context_cleanup
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x292f6a2b	sst_configure_runtime_pm
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x74e43b1d	sst_alloc_drv_context
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0xab14edd5	relocate_imr_addr_mrfld
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0x0f749a1a	sst_byt_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0x8918f8cb	sst_byt_dsp_wait_for_ready
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0xc2ea61c2	sst_byt_dsp_suspend_late
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0xd1d7361d	sst_byt_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0xf914b4bc	sst_byt_dsp_boot
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x02046079	sst_memcpy_toio_32
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x07365ff6	sst_block_alloc_scratch
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x10698949	sst_dsp_shim_update_bits64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x179d927b	sst_fw_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x1b5e8b82	sst_shim32_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x1e60dea6	sst_module_runtime_save
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x1fb78beb	sst_dsp_get_offset
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x2ad6e0a1	sst_dsp_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x3414ab6b	sst_dsp_shim_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x35736b99	sst_dsp_dump
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x35f2c6ec	sst_dsp_dma_copyto
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x36ee56ee	sst_dsp_shim_update_bits_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x3791506b	sst_dsp_wake
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4515a885	sst_module_runtime_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x484c13c2	sst_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x49fcb719	sst_memcpy_fromio_32
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4a045773	sst_shim32_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x5444e413	sst_module_runtime_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x55e7e4ec	sst_dsp_shim_read64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x5ae7de6c	sst_dsp_shim_read_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x5ec126bf	sst_module_runtime_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x5f33e38e	sst_fw_reload
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x64ae9b14	sst_block_free_scratch
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x6745c4c8	sst_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x68b4feda	sst_module_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x6afd4b28	sst_dsp_dma_get_channel
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x6d9e57e0	sst_module_runtime_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x6e6d9a33	sst_module_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x70712069	sst_fw_free_all
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x77227d7b	sst_module_runtime_restore
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x83f861f1	sst_dsp_dma_copyfrom
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x88b9b82e	sst_dsp_outbox_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x898266a7	sst_mem_block_register
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x94a08dc4	sst_dsp_shim_write64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x9b111216	sst_dsp_shim_write64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x9bfe2fbb	sst_dsp_shim_write_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x9f7d9c2c	sst_module_get_from_id
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x9f809c04	sst_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xa921765d	sst_dsp_reset
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xaa392dc4	sst_dsp_shim_update_bits_forced_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb41b755a	sst_dsp_inbox_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb4be1f8e	sst_dsp_mailbox_init
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbc9d6fc0	sst_dsp_inbox_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbcd44f6c	sst_mem_block_unregister_all
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbcec5387	sst_shim32_read64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbdeb29ce	sst_dsp_dma_put_channel
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xc96f942e	sst_fw_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xc9f35297	sst_dsp_shim_update_bits64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xcca4862c	sst_dsp_stall
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xd9a2c94c	sst_shim32_write64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xde597d19	sst_dsp_sleep
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xe262edc3	sst_module_runtime_get_from_id
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xe2f6d51d	sst_dsp_ipc_msg_tx
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xe3ae8ca9	sst_fw_unload
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xe94d7981	sst_dsp_boot
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xe984c840	sst_dsp_shim_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xee9ef002	sst_module_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf09066f3	sst_dsp_shim_update_bits_forced
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf1d4981d	sst_dsp_register_poll
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf3520c49	sst_dsp_ipc_msg_rx
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf39d9ef2	sst_dsp_outbox_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf4315c04	sst_dsp_shim_update_bits
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf8fa6e3c	sst_dsp_shim_read64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xfc23356b	sst_module_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x4edf4d0c	sst_ipc_tx_msg_reply_complete
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x5165bc82	sst_ipc_init
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x54a13a81	sst_ipc_tx_message_wait
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x5f96b758	sst_ipc_reply_find_msg
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x83b6b219	sst_ipc_tx_message_nowait
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x948070bd	sst_ipc_fini
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0xc5f43996	sst_ipc_drop_all
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0x3dc813eb	sst_hsw_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0xd1f69f64	sst_hsw_device_set_config
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0xe49ed9c4	sst_hsw_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x0bd61f69	skl_ipc_create_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x107ea843	skl_sst_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x30bfcb55	skl_ipc_init_instance
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x34bdd970	skl_ipc_delete_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x58bec114	skl_ipc_bind_unbind
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x6332ecde	skl_sst_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x876a885f	skl_ipc_restore_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x990e7f19	is_skl_dsp_running
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xa1790e03	skl_ipc_set_pipeline_state
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xab00afea	skl_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xb148beec	skl_dsp_sleep
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xc217e159	skl_ipc_save_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xdc60005d	skl_dsp_wake
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xde3e15d6	skl_ipc_set_dx
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xea2205d0	skl_ipc_set_large_config
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x00377e22	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x004e093f	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0104fca2	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0855caf3	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0a8f0419	snd_soc_tplg_component_remove
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0cfe326d	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0eceb272	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x109978d3	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x141cc719	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x157d25f0	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x174c395f	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x17bad9aa	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x18106679	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1881bb6a	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1a11cad8	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1a2ee81c	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1dc15084	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1f8dfe12	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x232f0e5b	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2369635a	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x23d3ec91	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x23d5d0a1	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2431a0b2	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x26d46e53	snd_soc_component_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x28d564d5	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2cac1ff4	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2cfdaf78	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2d12f022	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3249f834	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x33dc2324	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x38c1ac49	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x396975fb	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3dd1acc0	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3f7c860c	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3ffa3d67	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x413ec4d6	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x42f0f350	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x43e7d06a	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4638d52e	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x47ae5476	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x48129323	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x486ec8dc	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x48842c44	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4aa28721	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4b5fd1b6	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4c148da4	snd_soc_resume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4dd6cf0d	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4faca343	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x57fae621	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x58e8a403	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5abacaca	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5b30ea65	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5e771c70	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5eb9d19b	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x60846260	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6112f668	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x63202373	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x63238bcf	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x63389694	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x672c1ef7	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x676bfbfb	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x67ca971c	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6fff479a	snd_soc_new_compress
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x706cba9d	snd_soc_tplg_component_load
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x71524325	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x71c63b72	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x74190a3f	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x74fd4f6b	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x771173fe	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7726ac48	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7a1b7d51	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7a3d7781	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7f3da87a	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8175b25c	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8409e128	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8547e468	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x85f40e0e	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x87b59d38	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8bd95798	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8de0c4d4	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x90e2132c	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x926bd5bb	snd_soc_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9272eaee	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x929cfc73	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9314f2bc	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x939347f4	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x962f3f4b	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x96ca5dea	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x988f6770	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9939bcf8	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9b5373e7	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9caabc19	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9ccb64c1	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9da474e5	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9fb5dac7	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa064cae5	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa21063b9	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa5f31f4f	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa610e367	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa699cd1b	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa7bf914e	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa95eb8ed	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xacb665d6	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xada41eec	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb2fedca2	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb30c9ac9	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb406815a	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb57091bf	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb9526d5d	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbb8f5cae	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbe0f2bef	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbe68e9c9	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbeb46b73	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc02c1fcb	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc303e53e	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc379e95f	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc4638ada	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc4764559	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc49b8e91	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc4e4039e	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc7128682	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc7666116	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xca754b04	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcba0d3ad	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcda8b04c	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd32d6cd3	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd998ef81	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdd9e4298	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xde1be97c	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe208233c	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe258e94d	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe3e15383	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe5a5f6bf	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe5f26633	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe7d8400b	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xea1fb739	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeaa5cb46	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb390821	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xec70ac82	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xedc3f285	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xee618b43	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf2c0a328	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf4ae43ef	snd_soc_component_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf53053f4	snd_soc_tplg_widget_bind_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf5eec29a	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf6be6e4f	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf7bbfa46	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf87d463f	snd_soc_tplg_widget_remove_all
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfa6931d1	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfb66982a	snd_soc_tplg_widget_remove
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfcf94647	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfdcdeb28	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfe37a7fb	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfe89537e	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x22348497	line6_init_midi
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x24f7b27a	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x27e33183	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x28e56990	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x54dad910	line6_version_request_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x7a1a0b5b	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x7e354ca6	line6_write_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x829c10da	line6_suspend
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xabcd8f0f	line6_send_sysex_message
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xad983ea0	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xb0bd7b9d	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xc087e75c	line6_read_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xd80d5a88	line6_read_serial_number
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xe90fd0c4	line6_pcm_acquire
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xf7a5b1b9	line6_pcm_release
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x08003b2f	i915_bpo_gpu_turbo_disable
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x0d97d346	i915_bpo_gpu_raise
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x358a54ae	i915_bpo_gpu_busy
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x451432c2	i915_bpo_gpu_lower
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x7d4de94c	i915_bpo_read_mch_val
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x035b3a19	rsi_default_ps_params
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x0b8af985	rsi_init_dbgfs
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x1e678bb2	dot11_pkt_type
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x206a2bc3	rsi_deregister_bt
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x3b657e26	rsi_hal_device_init
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x40725363	rsi_send_rx_filter_frame
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x41f45ef5	ven_rsi_mac80211_detach
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x437447f4	rsi_hex_dump
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x45ca198c	ven_rsi_dbg
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x463ef029	rsi_hci_detach
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x563d7f77	rsi_hci_recv_pkt
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x5e0fdf3d	rsi_remove_dbgfs
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x7e8f7d87	rsi_send_rfmode_frame
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x866db18f	ven_rsi_91x_deinit
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x932ca0ef	ven_rsi_91x_init
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x9f2a2788	rsi_hci_attach
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xa94efeea	rsi_config_wowlan
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xd8e77311	ven_rsi_read_pkt
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x3fe35aea	irq_bypass_unregister_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x418873cc	irq_bypass_register_producer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x888c5be5	irq_bypass_register_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0xf6e772c3	irq_bypass_unregister_producer
++EXPORT_SYMBOL_GPL vmlinux 0x0018fe49	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0x0034f3b6	xen_has_pv_nic_devices
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x006c4abf	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x0082878e	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0x0082f454	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x0086e787	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00ce8128	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0x00d4be75	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x00e427b9	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x00ea1b01	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x00f0fa5e	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x00f10363	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x01091c47	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0x0109d998	gdt_page
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x012dc41c	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x013fdb8f	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x0172f2ae	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0x01848a8e	local_apic_timer_c2_ok
++EXPORT_SYMBOL_GPL vmlinux 0x019ad7cd	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x019c868e	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x01bf673a	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0x01c57047	acpi_device_update_power
++EXPORT_SYMBOL_GPL vmlinux 0x01c7fae3	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x02022aa8	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x0203ef05	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x02040675	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0x020f27d8	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x0254dd08	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0x02579e45	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x025f0325	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x026211e2	memory_failure_queue
++EXPORT_SYMBOL_GPL vmlinux 0x0267f213	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x027e2e3f	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0x029084c7	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x029c93c2	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x02b74582	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x02b7f9a4	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x02c4f3e4	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0x02d23a7b	sis_info133_for_sata
++EXPORT_SYMBOL_GPL vmlinux 0x02d818d6	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x032a1855	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x0361ce34	acpi_subsys_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x0365b728	xenbus_watch_path
++EXPORT_SYMBOL_GPL vmlinux 0x0392648d	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03bf7cdb	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x03bfbc98	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x03c22609	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x03c55157	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x03fd01a4	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0x03fdbd1e	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x0402cbbf	preempt_notifier_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0405c0de	dax_truncate_page
++EXPORT_SYMBOL_GPL vmlinux 0x041a9639	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0x042a31a8	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x043b935f	__tracepoint_io_page_fault
++EXPORT_SYMBOL_GPL vmlinux 0x0444a808	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x044c5c8f	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0x044e05d1	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x04607da2	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x0485655f	amd_get_nodes_per_socket
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04a8c179	rio_mport_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x04c1501f	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x04c3f2c1	gnttab_empty_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04caf886	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0x04df8fbc	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0x04e130da	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0x04ecfb5c	set_memory_wt
++EXPORT_SYMBOL_GPL vmlinux 0x051239e9	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x053494cb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0x05388cb2	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x0538c38a	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x054803df	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0x05484689	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x055f2d37	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x0563e4a4	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0x057ffe26	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x0592f041	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x05c4831d	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x05d3c5fd	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x060bdd0e	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0x061e47cf	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x06222a7a	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x0634e614	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x06454971	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x064cdc7b	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x064ce65c	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x0656a0f7	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0x068e148b	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x06a84a67	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x06d549e6	pinctrl_free_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x06de9060	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x07251663	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0x0759e32e	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x0763f8ca	nvdimm_bus_check_dimm_count
++EXPORT_SYMBOL_GPL vmlinux 0x0772ed17	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x077a7b5d	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0x077eedf8	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x0788adfc	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0x0788b634	irqd_cfg
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b28849	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07d67acb	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0x07f4fb9d	xen_swiotlb_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0x0800c365	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0x081106cf	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x0822fb82	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0x08360509	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0853863c	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x085509a0	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x088b98af	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0x088bfa7e	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x089cb5ed	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x08a7592f	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x08aa4010	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0x08bc0870	compat_put_timespec
++EXPORT_SYMBOL_GPL vmlinux 0x08c7e3f5	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x08de3fbd	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0x08e73696	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x08f24a21	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x08fb916f	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x0921d60a	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x094f7083	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x0961aa2a	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x096b2e8b	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x096c0c3b	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x09869d9a	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x098e12ba	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0x0a3dfcd9	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x0a4fde00	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x0a6a09a7	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0x0a77076c	xen_swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0a845c41	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0x0a8d21ae	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0x0a8dc27e	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0x0a93cf6b	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x0a94281c	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x0ac2308e	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x0ac637b3	inet_csk_compat_setsockopt
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b1fbc55	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x0b52e502	apei_resources_add
++EXPORT_SYMBOL_GPL vmlinux 0x0b7e1416	xenbus_unmap_ring_vfree
++EXPORT_SYMBOL_GPL vmlinux 0x0b9e3096	fpu__save
++EXPORT_SYMBOL_GPL vmlinux 0x0b9feb53	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0ba0dcdd	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x0bd726ae	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x0be25a17	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c00ea74	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c186753	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0x0c227a4c	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c71f738	xenbus_dev_changed
++EXPORT_SYMBOL_GPL vmlinux 0x0c805f93	clflush_cache_range
++EXPORT_SYMBOL_GPL vmlinux 0x0c80e3fe	efivar_init
++EXPORT_SYMBOL_GPL vmlinux 0x0c873fd2	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x0c88dabf	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0cd05e81	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x0ce0126a	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x0cef466f	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0x0cfa8ef2	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0d18b892	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x0d327303	rio_release_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x0d42f411	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d51f037	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x0d6a4419	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x0d6aa401	pinctrl_utils_dt_free_map
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0da3016f	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0x0dba3445	rio_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x0dccb01a	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1b38	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0de3b019	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0x0df925f6	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0x0e007edf	xen_evtchn_nr_channels
++EXPORT_SYMBOL_GPL vmlinux 0x0e04dcdf	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x0e13cb4d	apei_resources_release
++EXPORT_SYMBOL_GPL vmlinux 0x0e31cfcc	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0x0e5058b2	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0x0e507884	acpi_dev_pm_attach
++EXPORT_SYMBOL_GPL vmlinux 0x0e5bf407	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0x0e5e07da	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0x0e67fdd4	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0x0e7f4f87	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0x0e9acf27	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x0ea41f64	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x0eb1b216	devm_acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x0eb43a76	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x0ebab034	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x0ec0651b	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x0ec4e33b	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x0ec58c80	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0x0ec69353	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x0ecf823a	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x0ee01453	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x0ef1107e	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x0effc1c3	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0x0f012044	__tracepoint_detach_device_from_domain
++EXPORT_SYMBOL_GPL vmlinux 0x0f170383	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x0f26f8a8	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0f2d7d87	mce_unregister_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0x0f30f035	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0x0f312e86	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x0f316a0d	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f33d080	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x0f35c1b8	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0x0f5c5e9c	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0x0f6ec1f0	acpi_get_pci_dev
++EXPORT_SYMBOL_GPL vmlinux 0x0f739404	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f95da9c	nvdimm_bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0fa138de	xen_hvm_need_lapic
++EXPORT_SYMBOL_GPL vmlinux 0x0fcc1969	copy_from_user_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x0fd161f1	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0x0fe2d570	xenbus_directory
++EXPORT_SYMBOL_GPL vmlinux 0x1001a241	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x101e2399	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x102589df	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x102c0591	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x10574719	put_hwpoison_page
++EXPORT_SYMBOL_GPL vmlinux 0x1059ce4e	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x107dad8e	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0x109a0831	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x109cc1d3	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x10be69b1	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x10e65ae9	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x10f4e491	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x110106c1	cper_severity_to_aer
++EXPORT_SYMBOL_GPL vmlinux 0x1109f09c	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0x110ba97a	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x1111ba85	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0x1126bf34	acpi_create_platform_device
++EXPORT_SYMBOL_GPL vmlinux 0x1150206f	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x1167b282	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x117c7305	hwpoison_filter_dev_major
++EXPORT_SYMBOL_GPL vmlinux 0x117c92f9	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0x1196f921	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x11aa102e	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0x11bd8626	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0x11caddc7	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x11e57569	xen_swiotlb_sync_single_for_device
++EXPORT_SYMBOL_GPL vmlinux 0x12012dd4	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0x120cb535	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x123a67ad	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x123d3c0c	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x123fc0db	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0x12483e58	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x125b6dad	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0x12644708	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x12a9680f	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x12c28cfa	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x12d0f0b5	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x12e6d13a	rio_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x12ea3c14	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x13013945	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x130146fb	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x13053ba4	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0x130a7f6e	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x130bd388	check_tsc_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x130de01d	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0x131a2cb3	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x132ecbc1	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x133fa60e	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x134bff42	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x1361ade1	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x138aff76	gnttab_init
++EXPORT_SYMBOL_GPL vmlinux 0x13936b53	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0x13ad647f	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x13ae73c1	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0x13b89dee	pinctrl_request_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x13cabc43	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0x13ce87e8	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0x13f51fc3	ms_hyperv
++EXPORT_SYMBOL_GPL vmlinux 0x140c987f	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0x142807d2	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0x142f63e4	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x14791e6c	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x149f09ad	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0x15010e1f	arbitrary_virt_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0x15118765	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x15247f12	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x1530e82c	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0x15325776	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0x1534106d	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x153b519a	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x155d7130	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x158a0a3e	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x15b0606e	e820_any_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x15ba3629	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0x15e4b4b8	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x15f1bb18	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x15f93bde	pci_msi_create_irq_domain
++EXPORT_SYMBOL_GPL vmlinux 0x15f9aa1f	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x15fa6915	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x160acef9	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0x162bf367	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x163297ab	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x163690e2	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x164e157a	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x165246d6	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0x169301d2	usb_acpi_set_power_state
++EXPORT_SYMBOL_GPL vmlinux 0x169a6e1a	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x169f2f5b	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x16dd32e2	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x16e215c6	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x1709d3ba	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x171d62c4	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x17340627	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x173b894d	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x17614bf3	apei_resources_sub
++EXPORT_SYMBOL_GPL vmlinux 0x17799660	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x17994d70	memhp_auto_online
++EXPORT_SYMBOL_GPL vmlinux 0x179a5991	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x17a8360c	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0x17af3477	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x17c087b9	usb_acpi_power_manageable
++EXPORT_SYMBOL_GPL vmlinux 0x17dea724	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x17e1a3ac	pinctrl_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x17eb45ce	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x17f3eabd	set_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x1829b9ed	hwpoison_filter_memcg
++EXPORT_SYMBOL_GPL vmlinux 0x1835da8d	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0x1841ff95	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x18582826	amd_pmu_disable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x186c74aa	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x18cabdd3	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x18dcc4a4	gnttab_unmap_refs
++EXPORT_SYMBOL_GPL vmlinux 0x18f5e50e	arch_apei_enable_cmcff
++EXPORT_SYMBOL_GPL vmlinux 0x18f83fab	gnttab_grant_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0x19119803	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x194d812f	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x196614ce	hw_breakpoint_restore
++EXPORT_SYMBOL_GPL vmlinux 0x197c9d16	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0x1987dab4	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19b9e40c	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x19bb8eba	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x19e08e01	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x19e4fede	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x19f9e5b4	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x1a0520ca	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x1a063be6	set_pages_array_wt
++EXPORT_SYMBOL_GPL vmlinux 0x1a0b77f4	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x1a1aad80	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x1a3ab27b	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0x1a42b68e	rio_mport_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x1a4c489d	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x1a4d7cb5	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x1a699bc4	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0x1a6ce4db	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x1a726fe5	pinctrl_select_state
++EXPORT_SYMBOL_GPL vmlinux 0x1a7624a8	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x1a8db718	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x1a8ee9e5	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1a995dc1	rio_mport_get_efb
++EXPORT_SYMBOL_GPL vmlinux 0x1a9cb062	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x1ac0e2b3	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0x1ac1171f	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1ac55dc9	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0x1aca901d	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1aecf1d1	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x1b06f4e0	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0x1b38b3c6	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0x1b5452f9	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0x1b86d36e	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0x1b8822d8	pinctrl_gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x1b93377c	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1bbb9f48	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x1bc5eebe	pinctrl_gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x1bcc31c8	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x1bddfecf	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1c01ad91	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x1c0c2485	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x1c14e3f7	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x1c2f2e33	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c5ff742	clk_get_phase
++EXPORT_SYMBOL_GPL vmlinux 0x1c6417a4	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0x1c650049	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x1c654b23	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x1c6660c7	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0x1c6bde75	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1c73eeb6	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1c899130	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x1c8fe88e	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x1cb7650a	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x1cdb2147	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x1ce26736	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x1cf8602d	clk_debugfs_add_file
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d2e9f19	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0x1d3eacec	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0x1d459685	xstate_size
++EXPORT_SYMBOL_GPL vmlinux 0x1d52c47d	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d652735	__tracepoint_attach_device_to_domain
++EXPORT_SYMBOL_GPL vmlinux 0x1d6996ee	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x1d739e1c	xen_set_callback_via
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1d7cb586	clk_register_fixed_rate_with_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x1d8714f8	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0x1dbd544f	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0x1dc15316	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0x1dc84e93	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0x1dcecf48	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x1def880e	bind_interdomain_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1e000879	hwpoison_filter_enable
++EXPORT_SYMBOL_GPL vmlinux 0x1e0d7a5e	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0x1e44fd8c	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e5f7ec2	rio_request_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0x1e68ce14	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0x1e7042f3	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e8663fd	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1e951548	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1eabc56a	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x1eac4d28	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebac2bd	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ecc368a	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x1ecd18c6	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0x1ecf28c5	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1ed5119d	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x1edc21cb	hwpoison_filter_flags_mask
++EXPORT_SYMBOL_GPL vmlinux 0x1f169100	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x1f186217	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0x1f1988f7	hwpoison_filter_flags_value
++EXPORT_SYMBOL_GPL vmlinux 0x1f372291	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x1f3a7bb5	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1f962d8a	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0x1fac2832	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x1fb29377	clk_hw_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x1fc544d0	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x1fd34b3a	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0x1fe2e475	gpiochip_add_pingroup_range
++EXPORT_SYMBOL_GPL vmlinux 0x1fee7e9e	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x1fef0dcb	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0x200cc695	__free_iova
++EXPORT_SYMBOL_GPL vmlinux 0x203a66c3	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0x203d134a	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0x2076a45a	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x207f2ede	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x209ec764	xen_event_channel_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0x20aa6f51	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x20be22ba	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x20c73524	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x20f752f7	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x20f935a0	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0x2108ed92	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0x2140a0e7	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x214ffaec	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x218d65f9	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0x219c8d60	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x21a563da	clk_get_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21b7e436	__nvdimm_bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x21bfaf13	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0x21c56fec	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0x21c71c62	rio_route_clr_table
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21dcea12	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x22240afd	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x222e4647	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0x223936b7	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0x223ff585	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0x2240b197	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x22530d05	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0x2285510c	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x2299ec81	perf_assign_events
++EXPORT_SYMBOL_GPL vmlinux 0x229edaaa	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0x229fad27	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x22a18df5	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x22b84034	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x22bca852	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0x22d76641	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x22f2b136	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0x2303aa0e	component_add
++EXPORT_SYMBOL_GPL vmlinux 0x2304dea8	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x2315a82c	clk_mux_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x231ca14e	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x233b20f6	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x23620dbb	user_update
++EXPORT_SYMBOL_GPL vmlinux 0x2366a2c0	errata
++EXPORT_SYMBOL_GPL vmlinux 0x237a0d33	xen_swiotlb_dma_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x238245b5	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x2396c7f0	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0x23da0263	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x23dcb506	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x23e31407	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x23fed2b0	rio_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x24011e14	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x240f04a3	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x24491f7d	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2449ac19	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x24565e02	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x247c4f58	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x248affdf	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0x249102be	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24bb05cd	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0x24c7698a	xenbus_write
++EXPORT_SYMBOL_GPL vmlinux 0x24d10995	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x24f45195	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x250bbb45	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x25268c32	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0x252c09be	injectm
++EXPORT_SYMBOL_GPL vmlinux 0x252ef50e	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x25379e73	clk_set_min_rate
++EXPORT_SYMBOL_GPL vmlinux 0x25425917	acpi_gpiochip_free_interrupts
++EXPORT_SYMBOL_GPL vmlinux 0x2545c170	unregister_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x2567768e	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0x256e45af	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x258ad3ef	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x258f7ebb	gpiochip_remove_pin_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x25d3db19	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0x25d700b8	gnttab_foreach_grant_in_range
++EXPORT_SYMBOL_GPL vmlinux 0x25dbf705	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0x25dfef8d	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x25f02c87	xen_p2m_addr
++EXPORT_SYMBOL_GPL vmlinux 0x25f6c56f	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0x25fa0d3b	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x25fa5908	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x26006b48	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x2601de2e	rio_mport_get_physefb
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x2633b731	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2634a3e1	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0x263e4192	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0x2643baef	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0x264ae4c6	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x265b7b15	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x267e9027	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0x26965721	slow_virt_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x269bb076	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x26ad6577	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x26b3c701	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26ce0665	nvdimm_volatile_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x26f382f2	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x274555a9	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0x274cf5e1	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x2768e7f3	dax_clear_blocks
++EXPORT_SYMBOL_GPL vmlinux 0x276aab92	xen_swiotlb_set_dma_mask
++EXPORT_SYMBOL_GPL vmlinux 0x277e49f2	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x278754b0	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0x27884207	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x279cb985	apei_exec_pre_map_gars
++EXPORT_SYMBOL_GPL vmlinux 0x27c0c4be	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27cb1269	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x27dd7abf	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x27f04e6e	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0x27f4a676	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x2800ed09	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0x2800fdb5	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0x28084a7d	reserve_iova
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x28302a80	xenbus_dev_is_online
++EXPORT_SYMBOL_GPL vmlinux 0x283160c4	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x283dc496	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x28794588	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0x28aa4a89	devm_pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0x28b3e928	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0x28bc583f	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x28d26c6d	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0x28ded88f	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0x28e514bf	acpi_dev_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x28e64c64	xen_has_pv_and_legacy_disk_devices
++EXPORT_SYMBOL_GPL vmlinux 0x28e70667	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x2924534b	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x2932427a	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x2933cfb2	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x294bc1a5	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x2950b1bd	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x29653c93	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0x2965a26b	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0x298f98a0	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x299efdb6	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x29a5aba2	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x29aa13df	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0x29b56f81	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x29b7ed42	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x29bfb141	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0x29d11ff4	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x29ea222a	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x29fa16d9	acpi_subsys_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2a5cb540	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0x2a66fbea	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a78570c	hypervisor_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x2aa5cba2	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x2aa79bb6	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x2ab114df	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x2ac9484c	rio_route_get_entry
++EXPORT_SYMBOL_GPL vmlinux 0x2acbc83f	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0x2ad67252	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x2af63321	acpi_dev_resource_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x2b116fc8	__tracepoint_add_device_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x2b1fa505	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b286805	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x2b477aad	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0x2b952517	clk_has_parent
++EXPORT_SYMBOL_GPL vmlinux 0x2bc0c9d0	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2bc730fd	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa985e	nd_cmd_dimm_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2bfc6d79	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0x2c14a782	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x2c1f7908	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c2d3e79	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c331921	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x2c53839e	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x2c58a808	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0x2c6fa0e0	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0x2c7d9c64	xen_store_interface
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c7e5fab	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0x2c8f130e	pinctrl_get_group_pins
++EXPORT_SYMBOL_GPL vmlinux 0x2c9289e2	input_class
++EXPORT_SYMBOL_GPL vmlinux 0x2ca5a9e4	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0x2cb25c43	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x2cc2ec63	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0x2cd0b218	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2cee9968	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x2d0bda44	xen_swiotlb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x2d0c7c2e	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x2d111d22	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0x2d11485c	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x2d16b29e	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d4fe8bf	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d5b0848	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x2d81a003	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x2d94d713	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0x2d9f2ce3	sched_clock_idle_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x2da282da	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x2db35afa	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x2dd05401	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0x2de9696f	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0x2deee045	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x2e0dcb3b	klp_enable_patch
++EXPORT_SYMBOL_GPL vmlinux 0x2e1da9fb	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e2924ed	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x2e2df7f4	irq_remapping_cap
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e3bd528	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0x2e490dc7	rio_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0x2e506e16	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0x2e519600	ata_acpi_gtm_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x2e88780e	pinctrl_dev_get_devname
++EXPORT_SYMBOL_GPL vmlinux 0x2e9c0c03	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0x2e9d2617	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ec53d99	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2ede2bb5	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x2efc1076	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f1aa710	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0x2f212f21	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x2f2a5224	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x2f360412	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f4c1ceb	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x2f64415f	unregister_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f76285d	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x2f7c20a6	nvdimm_blk_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x2fb7bada	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x2fd44e62	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x2fdfbd73	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0x30119c69	xenbus_grant_ring
++EXPORT_SYMBOL_GPL vmlinux 0x30216080	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0x3025619e	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x302e8c61	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x30635782	cpu_has_xfeatures
++EXPORT_SYMBOL_GPL vmlinux 0x30757a2e	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x307fba32	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x3089ce1e	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0x308aedd2	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3094c355	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x30ad187d	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x30ba7a98	acpi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x30c7a595	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30cff1bb	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x30f7fa68	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x30fdab26	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0x310197b5	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0x310560f7	clk_register_gpio_gate
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x31128b8e	hv_remove_kexec_handler
++EXPORT_SYMBOL_GPL vmlinux 0x311c2dee	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0x3120ab27	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x313b5a75	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x314fad93	efivar_entry_set_get_size
++EXPORT_SYMBOL_GPL vmlinux 0x316bdff3	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x31929029	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31cff85d	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x31d1e9ab	xenbus_dev_error
++EXPORT_SYMBOL_GPL vmlinux 0x31e3eb37	rio_request_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x3201bd0e	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0x32114450	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0x3214bc77	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x321bdbb1	compat_get_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x3226249e	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x322a28bf	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x32365cff	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x325e677c	gnttab_grant_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x32690c72	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x3269a6c0	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x326fbfee	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0x327b7488	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x328b8ef9	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0x32963abc	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x32a77bad	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x32bc0fcf	preempt_notifier_dec
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32dde084	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x32e3b076	mxcsr_feature_mask
++EXPORT_SYMBOL_GPL vmlinux 0x32eda4a6	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x331cb115	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x3333b581	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x333927e9	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x333a7831	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0x3359c07c	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x336234a1	xenbus_unmap_ring
++EXPORT_SYMBOL_GPL vmlinux 0x3362b03c	xen_p2m_size
++EXPORT_SYMBOL_GPL vmlinux 0x33655159	xen_pcpu_hotplug_sync
++EXPORT_SYMBOL_GPL vmlinux 0x3368a4dc	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x3378725a	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x33804147	efivar_entry_remove
++EXPORT_SYMBOL_GPL vmlinux 0x3389e4c2	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x339dbbd9	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0x33ab9e1c	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0x33ac6abe	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x33b87dbd	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x33b96e5d	apei_exec_write_register
++EXPORT_SYMBOL_GPL vmlinux 0x33c4eb98	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x33f99f25	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x340eb2b8	xenbus_read_otherend_details
++EXPORT_SYMBOL_GPL vmlinux 0x342dac9a	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0x3443b755	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0x344d0bd6	rio_release_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x34507c22	clear_foreign_p2m_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x3451ce4b	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x346113d1	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x3461a43c	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x34915a4c	pinctrl_pm_select_idle_state
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34a8da5f	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0x34b30ce4	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0x34b482f0	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x34d2b434	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x34e49be3	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0x34edd635	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x3500bdef	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x35026c52	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x35124f07	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x352650ee	gnttab_batch_map
++EXPORT_SYMBOL_GPL vmlinux 0x352b6aac	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x353e93d9	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x3547cbfe	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x354fec56	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x357e2a8c	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x35910f72	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x35a7027c	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0x35b50d2a	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x35bf2acd	nd_fletcher64
++EXPORT_SYMBOL_GPL vmlinux 0x35c2f089	rio_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x35c638d9	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x360cd5ec	pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x366b9703	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0x368f1fea	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x36905d60	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x369c5b0e	clkdev_create
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36a7f5ed	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0x36b1aac9	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x36b5497e	intel_iommu_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x36bda7b0	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x36c1794d	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x3732d909	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x374971fe	xenbus_probe_devices
++EXPORT_SYMBOL_GPL vmlinux 0x37571c6f	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0x3795a8bb	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x37da8929	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x37ff7a43	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0x380798d3	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x38158737	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0x3862cce5	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x386369a9	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0x386997d4	rio_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x38722f80	kernel_fpu_end
++EXPORT_SYMBOL_GPL vmlinux 0x38866889	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x3891e066	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x38c9ce6b	clk_register_gpio_mux
++EXPORT_SYMBOL_GPL vmlinux 0x38e5bc5a	clk_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x38f9df82	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x38fafc5a	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x39104880	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x392fe739	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x394c4d62	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x39512c10	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x39597d25	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x39802b67	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x399ad7a8	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0x39a1a062	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x39f36e96	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0x3a08fb8b	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x3a0c5647	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x3a197f64	xenbus_probe_node
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a290f97	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x3a38dc65	memory_failure
++EXPORT_SYMBOL_GPL vmlinux 0x3a3db234	divider_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x3a420411	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x3a4e054f	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a512a14	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a5c2b18	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0x3a7d80f9	xen_max_p2m_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x3a8b4440	acpi_subsys_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x3a960378	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3aafee4b	klp_disable_patch
++EXPORT_SYMBOL_GPL vmlinux 0x3ab8317d	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0x3ab8a4b9	xen_register_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3ad0e201	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x3b00fb2a	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3b2693bb	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0x3b3991d8	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0x3b458c00	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3b4ba8e3	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0x3b547bc9	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x3b7145bb	apei_exec_read_register_value
++EXPORT_SYMBOL_GPL vmlinux 0x3b7c4779	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x3b92b1eb	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0x3b9718da	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x3b9bfc8b	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x3be86a54	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3beb7ae7	agp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x3c0a43d5	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0x3c112ec6	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x3c2badd6	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3c3f73a8	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0x3c78287f	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x3c7a8d48	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x3c7d4cd3	clk_hw_get_num_parents
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3cb29369	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cef79b6	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0x3d203f7b	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d5d0a15	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x3d5f392d	acpi_os_unmap_memory
++EXPORT_SYMBOL_GPL vmlinux 0x3d6b1d5b	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0x3d7ea99a	gnttab_grant_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x3d863d17	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3da67a23	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x3dae6404	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x3dc795e8	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3df64137	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0x3dfc436e	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x3dfd01b3	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x3e1ef78a	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0x3e2d6df3	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3e3cd018	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x3e5384de	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x3e54b244	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e611fdc	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x3e68bd9e	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x3e6d4fe8	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0x3e6dc296	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e76cd00	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0x3e7d7546	pinctrl_dev_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x3e8bdeb8	iommu_get_domain_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3ea1ebb5	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0x3ea5196d	apei_osc_setup
++EXPORT_SYMBOL_GPL vmlinux 0x3ec1321b	is_dock_device
++EXPORT_SYMBOL_GPL vmlinux 0x3ed554fa	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x3ed589bf	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f04450c	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3f1b5f65	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0x3f229c4c	oops_begin
++EXPORT_SYMBOL_GPL vmlinux 0x3f31c307	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0x3f749f0d	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0x3f84d4c9	gnttab_release_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x3f93f20f	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0x3fa5af9c	nd_cmd_bus_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3faba502	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x3fc74aef	intel_svm_unbind_mm
++EXPORT_SYMBOL_GPL vmlinux 0x4004205e	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4009cb45	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0x400a024b	acpi_scan_lock_release
++EXPORT_SYMBOL_GPL vmlinux 0x4010b80f	pmc_atom_read
++EXPORT_SYMBOL_GPL vmlinux 0x401e84c8	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x40356d20	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x404da1fe	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x40671255	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x406e9373	rio_dma_prep_slave_sg
++EXPORT_SYMBOL_GPL vmlinux 0x4081c31d	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0x408212ba	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40de46cf	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0x40e7ddd5	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0x40ef495f	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x40f73430	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x410691b8	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x4106e96a	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x41114a8e	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0x41177fc0	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0x4125e8ca	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x41765870	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x41835d60	device_create
++EXPORT_SYMBOL_GPL vmlinux 0x418710e7	mce_inject_log
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x4213a51a	efivar_entry_set_safe
++EXPORT_SYMBOL_GPL vmlinux 0x42324d32	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x4255026d	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x42591ba5	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x425e49dd	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x42635d55	pm_suspend_global_flags
++EXPORT_SYMBOL_GPL vmlinux 0x427d5c68	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x427de547	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42a21f5e	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0x42b3e22a	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0x42bb8d80	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x42c0c9b3	efivars_kobject
++EXPORT_SYMBOL_GPL vmlinux 0x42ce92e0	ata_acpi_cbl_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x42de21dd	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x4319b991	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0x431bc4cd	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x43480fa7	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0x43619e1a	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x4378416c	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4383903e	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x438d8df2	iova_cache_get
++EXPORT_SYMBOL_GPL vmlinux 0x4395953e	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x43f81957	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x43fa2970	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x440c777b	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x441fa356	irq_ts_save
++EXPORT_SYMBOL_GPL vmlinux 0x4428f0a2	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x443defee	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x446e3c47	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x449cf6ab	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x44b10ada	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x44b85596	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44d0f90f	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x44d3bcd2	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x44e1e9aa	balloon_stats
++EXPORT_SYMBOL_GPL vmlinux 0x44e96da5	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x450fb522	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x451ac048	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x4527a1e8	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0x4533ec38	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0x4539fe18	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0x4541fe0d	mtrr_state
++EXPORT_SYMBOL_GPL vmlinux 0x45466d86	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x454f1cb4	efi_query_variable_store
++EXPORT_SYMBOL_GPL vmlinux 0x455876e8	pinctrl_dev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x4572c2c4	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x458859b9	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4593ba00	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0x45b7d6a0	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x45bd429d	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45d14bdf	hypercall_page
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x460247e6	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0x460f31aa	rodata_test_data
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x46434934	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x465270ae	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x465e144f	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0x4663d883	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x4678157d	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x46b70eca	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x4743fc1d	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x47447cce	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x47649534	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0x4779f4d2	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x4789d000	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x479e2c6e	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47b8de82	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x47be2669	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x47c4f7fc	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x47d0eea2	acpi_lpat_temp_to_raw
++EXPORT_SYMBOL_GPL vmlinux 0x47de0dc7	clk_unregister_mux
++EXPORT_SYMBOL_GPL vmlinux 0x47e02ebc	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x47e51f94	__efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x47e6a08f	of_css
++EXPORT_SYMBOL_GPL vmlinux 0x47ea5cce	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x47ed5009	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x47fb8a99	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0x4805229c	unregister_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x4811d532	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x4828e77b	acpi_scan_lock_acquire
++EXPORT_SYMBOL_GPL vmlinux 0x4832b211	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x4838cdbc	xenbus_dev_probe
++EXPORT_SYMBOL_GPL vmlinux 0x4842719c	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0x48520747	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0x48682db9	perf_guest_get_msrs
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x4875d18b	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x4897995b	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x489c8742	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0x48b3fd4a	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x4909fc8d	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x490a8df6	x86_platform
++EXPORT_SYMBOL_GPL vmlinux 0x4981be30	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x4984bc4c	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x499034f5	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x49b16057	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0x49b481bd	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0x49e4eb33	pv_info
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4a02ab07	rio_unlock_device
++EXPORT_SYMBOL_GPL vmlinux 0x4a3c3cf9	microcode_sanity_check
++EXPORT_SYMBOL_GPL vmlinux 0x4a3c889d	pinctrl_lookup_state
++EXPORT_SYMBOL_GPL vmlinux 0x4a420d09	acpi_bus_detach_private_data
++EXPORT_SYMBOL_GPL vmlinux 0x4a44b614	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a5b5d6a	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4a90160e	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4abdbae8	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x4ac3e61f	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0x4b06869f	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0x4b211246	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x4b33c81b	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0x4b3965aa	xen_swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x4b7465fb	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0x4b7be658	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x4b8275f2	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4b88a3e0	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x4bb94dee	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0x4beddbe1	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4bf1ed8b	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0x4c0b11cc	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4c231e47	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0x4c2a472b	__static_cpu_has_safe
++EXPORT_SYMBOL_GPL vmlinux 0x4c34c274	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x4c4fa0aa	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c645f9e	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4c78ce4d	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4c917d1f	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x4ce2df70	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0x4cea7f58	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0x4cf4bcda	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d545bc3	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x4d57fc04	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x4d70ff85	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x4d81ca58	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0x4d8577f3	apei_get_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x4da0bf58	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0x4dbee430	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4e042286	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0x4e06e294	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e45d555	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0x4e57723d	apei_read
++EXPORT_SYMBOL_GPL vmlinux 0x4e5f3efa	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4e74e625	gnttab_batch_copy
++EXPORT_SYMBOL_GPL vmlinux 0x4e783c89	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0x4e790907	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x4e804ba9	acpi_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x4e97a832	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0x4ea8074c	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0x4eaf6cfd	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x4eb08374	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x4ebe9cb0	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x4ee58c71	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f05925c	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f3c62eb	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x4f3fef7d	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4f81b531	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x4f93621b	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x4faf8fb3	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x4fb383de	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4ff1e5b3	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4ff5fcaa	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x50098cd4	iommu_capable
++EXPORT_SYMBOL_GPL vmlinux 0x5025a5ac	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x5026585c	xen_irq_from_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x503aa000	clk_hw_get_parent_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x503ebba9	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x50432fdc	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0x50433639	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0x50596d22	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x5062aefc	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x507de8c6	add_memory
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x50920811	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0x50c7a482	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0x50d1f870	pgprot_writecombine
++EXPORT_SYMBOL_GPL vmlinux 0x50db3980	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50e937df	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0x50f0c871	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x511459a7	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x5119ffad	clk_hw_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x512b1d19	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x5133dab9	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x513ccc63	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0x5143f6a3	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x514e9875	divider_get_val
++EXPORT_SYMBOL_GPL vmlinux 0x516992fd	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x517e8239	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x51859c28	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x5187ac4b	xen_store_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x518c217c	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x518c2fc6	hpet_rtc_dropped_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5191bd3c	efivar_work
++EXPORT_SYMBOL_GPL vmlinux 0x519504f0	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x51c96b5f	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x51e26b08	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x5209f4df	acpiphp_register_attention
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x52131d59	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0x522f538b	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x523db296	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0x5272d8bc	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0x52754995	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0x528f8d6b	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x52903271	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x529733f6	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0x529dd3f4	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x52a41251	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x52b3d110	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x52c29e2f	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x52c4c3dc	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x52c4dddc	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0x52cc038f	rio_request_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x52d8c375	clk_register_divider
++EXPORT_SYMBOL_GPL vmlinux 0x52e9538f	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x531caa0d	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x532039af	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x532f49b6	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0x534a16c8	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x53541fa3	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x535b33d2	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x5361e7b1	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x539f13da	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x539f157b	pci_xen_swiotlb_init_late
++EXPORT_SYMBOL_GPL vmlinux 0x53a11be7	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0x53b8ec43	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x53cbddeb	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x53d0af76	nvdimm_bus_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x53da37d7	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x53f35dbe	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0x541231f4	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x54215db5	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0x5431c811	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x545cd49c	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0x545ee955	fpu__activate_curr
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x5460f4df	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x5463d0bb	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x5475fab2	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0x5485dcfa	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54a29dae	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x54ac6a13	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x550ce709	pat_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x55181725	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x554271cc	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0x55526907	xen_features
++EXPORT_SYMBOL_GPL vmlinux 0x556e4390	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x557027f4	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x5588c7e1	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0x558ecb61	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x5593d715	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x55ac152a	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x55b8e2c2	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x55e5218d	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0x55eb90e8	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x55f52127	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x55fc87eb	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0x560abccc	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x56300a79	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x563102b2	acpi_subsys_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x56398615	mark_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x563ae0c2	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x56482bc0	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x5651bb7e	nvdimm_name
++EXPORT_SYMBOL_GPL vmlinux 0x5654f836	erst_get_record_id_next
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x56947347	dmi_walk
++EXPORT_SYMBOL_GPL vmlinux 0x56974180	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x56a7a333	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56d7426b	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56f39d37	rio_dma_prep_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x5705a391	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x57198934	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x5719e669	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x572e2909	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x57530470	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x575c5f94	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0x5779d445	xenbus_exists
++EXPORT_SYMBOL_GPL vmlinux 0x578a30ad	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x57c3e0d2	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0x57e1c003	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0x57ead3f0	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x57f3f81f	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0x57f41f0f	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x57f5274a	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x57f8062c	acpi_dev_resource_io
++EXPORT_SYMBOL_GPL vmlinux 0x58110346	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x5813a189	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0x5835338e	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x585704ab	aer_recover_queue
++EXPORT_SYMBOL_GPL vmlinux 0x587bd46f	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0x589924bb	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58a5e7a8	rio_mport_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x58c9c906	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0x58db9633	agp_remove_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x58f8b910	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x58fe9409	rio_inb_pwrite_handler
++EXPORT_SYMBOL_GPL vmlinux 0x590246fd	find_module
++EXPORT_SYMBOL_GPL vmlinux 0x590d5566	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x59367333	xen_remap_domain_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x59409b4f	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x594a0eba	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x59688cf7	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x59828a5b	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0x59909e73	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0x5995a5a8	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x59aa6dbb	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0x59abe37a	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0x59b0882b	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x59b2adbf	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x59b9f235	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x59bcfda9	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0x59d570e9	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x59db3c98	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x59e0458d	nvdimm_create
++EXPORT_SYMBOL_GPL vmlinux 0x59e17ccc	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x59e36b68	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x5a03c730	__clk_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x5a171008	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x5a2b1b67	gnttab_free_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5a35d82e	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5a4460e3	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x5a50c823	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0x5a73549b	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5ac877e5	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0x5aeec53a	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0x5af03a28	gnttab_claim_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5b13e53b	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0x5b1899f8	free_iova
++EXPORT_SYMBOL_GPL vmlinux 0x5b380c54	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x5b83b36e	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0x5bb4d519	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x5bb73368	pinctrl_remove_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x5bce8ca1	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbee8a	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x5be5a88c	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x5beefea6	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x5c143f02	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x5c27801f	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x5c47fd7b	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c65e6f4	acpi_dev_get_property
++EXPORT_SYMBOL_GPL vmlinux 0x5c66e90c	efivar_run_worker
++EXPORT_SYMBOL_GPL vmlinux 0x5c67cf89	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x5c8d7f62	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cc129cc	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5cd78169	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x5ce56d4a	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0x5ce7bf3b	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0x5ce7eb3f	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x5d0e73c5	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d193502	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0x5d2b968b	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x5d2de0ad	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x5d3537a1	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0x5d366dec	gnttab_cancel_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0x5d42bea7	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0x5d5ca512	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x5d5ef138	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0x5d7fa30f	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x5d8d97f8	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0x5d932c95	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5dbcfa4f	boot_cpu_physical_apicid
++EXPORT_SYMBOL_GPL vmlinux 0x5dc719ac	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0x5dcd7160	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x5dd0f6a7	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0x5dd9f2ac	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x5de25d28	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x5dfdb07d	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x5e0831bc	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0x5e219587	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x5e3c89cc	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e6da803	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x5e70bd6f	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x5e8a02aa	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0x5ea3fbdf	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x5ea8a054	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x5eaab96d	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x5edd8400	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0x5eee2ea5	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x5ef9d207	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x5f12d200	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0x5f226035	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x5f2da8c4	check_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x5f49bc1d	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5f5aa447	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0x5f6d1b1d	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x5f89d96f	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x5faf82d7	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x5fc27be9	acpi_dev_irq_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5fc57d85	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5fd0e4f7	acpi_processor_get_performance_info
++EXPORT_SYMBOL_GPL vmlinux 0x5fdcbd09	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x5fdfa2c1	amd_pmu_enable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x5fe907b7	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x5ff50674	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0x60091316	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x60238be0	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x6051a105	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x605c340f	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x605d0da0	component_del
++EXPORT_SYMBOL_GPL vmlinux 0x607cdbd0	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x60879664	acpi_subsys_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x6087d6dc	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x608a1c68	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0x60930d37	save_mc_for_early
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60aa5cdc	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x60b08606	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0x60cd73ed	pv_apic_ops
++EXPORT_SYMBOL_GPL vmlinux 0x60d50b24	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0x60e1252b	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x61577115	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x615b1616	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0x615b4c40	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0x616877a5	devm_pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0x6172e954	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0x617fb036	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x6188c3da	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0x61a11ddd	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0x61afce04	nd_blk_region_to_dimm
++EXPORT_SYMBOL_GPL vmlinux 0x61cde409	acpi_dev_resource_memory
++EXPORT_SYMBOL_GPL vmlinux 0x61d20a08	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x61d48a1d	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0x620ef2e4	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x6214b16c	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x62237d6b	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0x62283c0b	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x622a2eae	__xenbus_register_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x623803c8	hest_disable
++EXPORT_SYMBOL_GPL vmlinux 0x624b660a	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0x625fcea3	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0x62628ca3	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x627f7085	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0x62a0145d	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0x62a1c981	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x62a34b40	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x62a4ad18	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x62bd5a6d	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x62ef0bf0	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x63150e06	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x6318d75f	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0x6333072c	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x634637c1	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x635b0db9	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0x635ec980	apei_exec_post_unmap_gars
++EXPORT_SYMBOL_GPL vmlinux 0x638fe045	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x63e00b69	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x63e17b86	divider_recalc_rate
++EXPORT_SYMBOL_GPL vmlinux 0x63ea80b3	cper_mem_err_type_str
++EXPORT_SYMBOL_GPL vmlinux 0x63f14ebe	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x63f90b6c	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x63fdb64f	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0x6407b445	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x64081eb3	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x6412dfc8	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0x641d1de9	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0x642aea92	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x64318593	acpi_dev_filter_resource_type
++EXPORT_SYMBOL_GPL vmlinux 0x6431b7cf	nd_region_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x644c7025	to_nvdimm
++EXPORT_SYMBOL_GPL vmlinux 0x6453799f	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x645c838b	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x646b7ea9	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x64749dfc	pinctrl_utils_reserve_map
++EXPORT_SYMBOL_GPL vmlinux 0x647f5865	nd_cmd_in_size
++EXPORT_SYMBOL_GPL vmlinux 0x6498a22b	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0x64a466a2	set_foreign_p2m_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x64a8ae76	acpi_subsys_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x64ac58c2	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x64b6565a	pci_get_hp_params
++EXPORT_SYMBOL_GPL vmlinux 0x64b7069e	apei_mce_report_mem_error
++EXPORT_SYMBOL_GPL vmlinux 0x64b8a2d9	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0x64e80dfb	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x64ee1421	__remove_pages
++EXPORT_SYMBOL_GPL vmlinux 0x6527a231	dbgp_external_startup
++EXPORT_SYMBOL_GPL vmlinux 0x6536953b	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0x655586fa	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0x656ae987	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x658c8186	amd_get_nb_id
++EXPORT_SYMBOL_GPL vmlinux 0x65981bb6	__online_page_free
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65d506a1	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x65ea14f5	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0x65f28a88	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x65f70357	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x6608a3ef	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x660a8606	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x660dee66	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0x660ee6d4	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x665ecab0	pv_time_ops
++EXPORT_SYMBOL_GPL vmlinux 0x666e1ddb	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x6673cf9c	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66fd265e	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6719e366	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x67333136	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6739a503	balloon_set_new_target
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x675ba9cb	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x67968b28	pinctrl_add_gpio_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x67973bd7	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x67b802b6	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x67d5304d	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0x67ea03bf	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0x67ffb3dc	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x683c85ad	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0x68489f99	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x685488ec	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0x685ee377	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x68607302	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x68626879	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0x68646a1c	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0x689267d6	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x68a0ef23	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x68a1ff2c	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0x68b111d1	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0x68cebdd6	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x6919114e	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0x6921aa34	compat_put_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x6959790c	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x695fd06b	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x69bf4027	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x69e536aa	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x69fb594d	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0x69fcef81	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x6a0856e7	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6a08c31c	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x6a10f384	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a592d4e	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6a5ec3e0	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a694462	rio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6a6cafd2	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a936feb	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x6ab1b8bb	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x6ab32054	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0x6abdfa3d	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0x6acad21f	acpi_get_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0x6b0dc565	xen_set_irq_priority
++EXPORT_SYMBOL_GPL vmlinux 0x6b1d7448	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b2ef235	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0x6b51577d	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x6b56da48	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6bcc69b9	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0x6bf1b90d	dmi_memdev_name
++EXPORT_SYMBOL_GPL vmlinux 0x6bf5c4c7	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x6bf7984f	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6c042d59	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c0abea3	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x6c1251fd	apei_exec_read_register
++EXPORT_SYMBOL_GPL vmlinux 0x6c389761	acpi_bus_get_private_data
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c6538df	init_iova_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6c655913	register_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6c65ae60	xenbus_match
++EXPORT_SYMBOL_GPL vmlinux 0x6c79906a	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x6c7db967	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6cdb2005	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x6cfc084c	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0x6d08ddeb	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6d239bef	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d33757a	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0x6d53ef0a	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0x6d6b072f	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0x6d6b8b34	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x6d865e4e	rio_mport_send_doorbell
++EXPORT_SYMBOL_GPL vmlinux 0x6d91a0d0	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0x6d957c51	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0x6d9f3300	xen_find_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x6da4ede7	irq_chip_ack_parent
++EXPORT_SYMBOL_GPL vmlinux 0x6da54fb4	nvdimm_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x6dab70b6	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x6dc5e0b9	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e0eaf85	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x6e0eef46	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x6e17bdda	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x6e18c542	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x6e272f00	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x6e2c2592	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x6e34600d	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x6e393f0b	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x6e3ef4e9	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x6e460138	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x6e58ddf0	gnttab_end_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x6e6a2f35	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e85b00b	local_touch_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6e91340b	acpi_dev_get_resources
++EXPORT_SYMBOL_GPL vmlinux 0x6e938603	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x6ea98361	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x6ebe8259	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0x6ec1b096	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x6ed4d20c	acpiphp_unregister_attention
++EXPORT_SYMBOL_GPL vmlinux 0x6edcd348	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6ef209c8	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x6f02efd9	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f2431ee	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x6f402ba6	acpi_dev_resource_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x6f59ba6c	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x6f5ac2bb	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6f9b4ec4	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x6fa8e34e	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x6fc0fef3	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x6fc89892	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x6fdcf31f	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6feb6001	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x7027c76e	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0x7029c830	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70317e7b	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x7034ed49	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x7057293e	acpi_bus_trim
++EXPORT_SYMBOL_GPL vmlinux 0x705ec281	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x708d8ddf	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x709d8afe	devm_acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x70a789a2	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x70b11f7d	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x70bfcb54	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0x70bfd694	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70ed5bd9	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0x71094bde	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x712159d1	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x7127f94d	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x7132696c	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x71359802	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x715f18b0	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x716d5536	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x71777ac6	xenbus_dev_fatal
++EXPORT_SYMBOL_GPL vmlinux 0x717f1828	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x71913f13	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0x719e17ff	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x71a1bfe8	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x71d78511	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71e7c7a5	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x720040e6	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7206b7b3	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0x72252316	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x7238ab9a	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x7288d311	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x7296383e	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0x72b644a9	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0x72b678d1	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x72c3a397	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x72cf714d	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x72df3043	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x72fe73ef	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x73013896	xenbus_printf
++EXPORT_SYMBOL_GPL vmlinux 0x731dba7a	xen_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0x732260a1	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x73263b64	xenbus_dev_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x7344e08f	shake_page
++EXPORT_SYMBOL_GPL vmlinux 0x73674689	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x7386edf9	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x73a2918a	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73a62718	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x73afb372	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0x73b1720e	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x73bb76dc	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0x73c2554f	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73d93880	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x74027424	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0x743159e0	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x74457e56	apei_resources_fini
++EXPORT_SYMBOL_GPL vmlinux 0x7449d0c5	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x7452adff	user_return_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x7458e4a8	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x747da2d3	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0x747e8a87	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x7481afc6	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x74876d6d	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x748e15cc	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0x74a3843e	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74b9478f	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x74b9f79b	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74c08941	kvm_async_pf_task_wake
++EXPORT_SYMBOL_GPL vmlinux 0x74ca4083	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0x74deb10c	used_vectors
++EXPORT_SYMBOL_GPL vmlinux 0x74e493b7	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x74ee5af3	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x75133f6e	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0x751d12c7	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7521afb6	leave_mm
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x75283d6a	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0x75414fde	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0x754c4ce7	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x757b49d2	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0x75815247	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0x75869e30	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x75a585b9	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75df7479	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0x75fcef9e	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x7641ab4b	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x76437689	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x768fb920	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x76a65d0e	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0x76c18a2f	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x76c6fe89	acpi_dev_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x76d9b876	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0x76da420c	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0x76e57a8e	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0x76ebb258	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0x76f90a97	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0x77027b55	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x7712771a	unbind_from_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x7737ed87	rio_register_scan
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x7757b51a	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x775a6ef5	kvm_read_and_reset_pf_reason
++EXPORT_SYMBOL_GPL vmlinux 0x7761d416	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x777a23e5	nd_device_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x778b675a	pmc_atom_write
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x77affecc	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0x77cc53b6	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0x77d31318	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x77da9931	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x77ddaf3d	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x782adb74	hpet_rtc_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x784973b6	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x784d640e	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x78575bee	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x7874b5ec	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x787c882b	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78b8b793	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x78c2a7b6	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x78cc5bec	hugetlb_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x78d02e2d	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x78d80aca	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0x78f21cf6	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x795c92e3	efivar_entry_size
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x797f5779	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x7985239d	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x798d6459	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x7991fd8d	crash_vmclear_loaded_vmcss
++EXPORT_SYMBOL_GPL vmlinux 0x79bb44f3	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0x79c3cc49	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x79c87977	dax_fault
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x79e69460	intel_iommu_gfx_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x7a01d993	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x7a093833	set_memory_array_wt
++EXPORT_SYMBOL_GPL vmlinux 0x7a164eb8	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x7a20829f	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a319404	clk_register_fixed_rate
++EXPORT_SYMBOL_GPL vmlinux 0x7a43efb5	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x7a5e3a3d	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x7a782de7	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x7a7c6c92	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7ab35493	rio_unregister_scan
++EXPORT_SYMBOL_GPL vmlinux 0x7ac8e5b0	acpi_gsi_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7ace6f69	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0x7ad700c3	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7ad9fafa	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x7af95716	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x7b0c6762	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1a5ccf	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b202401	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x7b307b1f	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0x7b3e0cac	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x7b3f5d2d	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x7b5a7486	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x7b67b19d	xenbus_map_ring_valloc
++EXPORT_SYMBOL_GPL vmlinux 0x7b70ed5c	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x7b7a6424	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b90d1a9	bind_virq_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7c004e17	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x7c13a19d	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x7c1722f6	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0x7c2064c2	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0x7c40de53	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0x7c9a7371	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x7c9ef889	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0x7cab1185	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7cd8c6e5	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cedf677	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7d00c65b	nd_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x7d0456c4	pin_is_valid
++EXPORT_SYMBOL_GPL vmlinux 0x7d0e1d95	hv_setup_crash_handler
++EXPORT_SYMBOL_GPL vmlinux 0x7d36d6a8	clk_register_fractional_divider
++EXPORT_SYMBOL_GPL vmlinux 0x7d467dc7	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x7d4b8958	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d9c2402	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7db32284	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x7dcdc93f	__tracepoint_extlog_mem_event
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7de65a03	acpi_lpat_free_conversion_table
++EXPORT_SYMBOL_GPL vmlinux 0x7e2f9f7f	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x7e412b70	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0x7e63d5f7	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e661239	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7ea1a2bc	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x7ebfbe71	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x7ed700ac	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0x7f13d491	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f29e9ab	__rio_local_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x7f3658e6	fpstate_init
++EXPORT_SYMBOL_GPL vmlinux 0x7f5c4a5f	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x7f739248	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7f85abbb	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0x7f8a9129	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0x7f9f6be8	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x7fa54a50	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0x7fb806c7	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x800ada01	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0x8012553a	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x80156244	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x801656cf	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x801917a4	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0x80261072	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x804c07bb	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x806ba4b3	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x806f5710	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0x80753ea0	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x809529fd	alloc_iova
++EXPORT_SYMBOL_GPL vmlinux 0x80960aa8	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x80c04d98	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0x80c6015b	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80d8d96e	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x80fd4aee	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x81086b5a	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x8119c524	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x812a9be9	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x815084b5	acpi_dev_gpio_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0x8151b1d6	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0x8152e111	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x815588a6	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x81897657	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x81a84515	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x81cd3f33	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x81ee5caa	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0x8224b593	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0x8235f5f6	pinctrl_register
++EXPORT_SYMBOL_GPL vmlinux 0x823c2631	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x823c9e8a	rio_mport_chk_dev_access
++EXPORT_SYMBOL_GPL vmlinux 0x823d5091	efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x825ea7fe	clk_gpio_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8284b859	rio_set_port_lockout
++EXPORT_SYMBOL_GPL vmlinux 0x82991e0d	acpi_match_device
++EXPORT_SYMBOL_GPL vmlinux 0x829e0c3e	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x82b0d1e3	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x82c1da30	__rio_local_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x82c6a57c	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82dbec19	erst_write
++EXPORT_SYMBOL_GPL vmlinux 0x830f24b0	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x836666ce	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0x83746945	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x83764aab	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x83b4d5bf	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x83ba5fbb	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x83cf4dd9	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0x83f21ec6	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0x8409fe09	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x841861f3	acpi_dev_add_driver_gpios
++EXPORT_SYMBOL_GPL vmlinux 0x841da5ed	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x8427a6d3	xen_swiotlb_map_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x8429eed5	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x842cab77	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x84368bed	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x843d70ef	acpi_is_root_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x846e0381	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8487a2b6	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x848f8f50	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x8490d7cc	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0x84a9ca7f	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x84e3b24a	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0x84e7855c	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x84e7a70d	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0x84f98752	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x84fc9e91	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x84fdb0a4	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x8500f247	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0x850283db	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x8506baa8	clk_unregister_gate
++EXPORT_SYMBOL_GPL vmlinux 0x8508891b	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x850df8b9	clk_divider_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x85375c19	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0x853b49b6	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0x854aad8e	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0x855059ae	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0x8559e4fe	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x85613a90	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x85710364	acpi_dma_request_slave_chan_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x859875b7	rio_mport_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x859a6dc3	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x859aea9a	xen_set_domain_pte
++EXPORT_SYMBOL_GPL vmlinux 0x85b82f1e	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0x85ba86aa	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85cb2c45	xen_has_pv_devices
++EXPORT_SYMBOL_GPL vmlinux 0x85d7edfd	hpet_set_periodic_freq
++EXPORT_SYMBOL_GPL vmlinux 0x85ed6390	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x861181c7	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x862f6d76	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x864058ee	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0x864146a6	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x864a2d97	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8654be58	hv_remove_vmbus_irq
++EXPORT_SYMBOL_GPL vmlinux 0x865b7928	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x86623fd7	notify_remote_via_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8666a7c5	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x86819bc6	irq_ts_restore
++EXPORT_SYMBOL_GPL vmlinux 0x8683ea9c	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x86849bf9	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x86a378aa	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0x86a51007	gnttab_end_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x86ae4ed7	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x86bc3f15	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x86d476ca	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x86eb0a3f	pinctrl_pm_select_sleep_state
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f69b90	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x86fefa88	clk_gpio_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8702e548	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x870e16b7	xen_test_irq_shared
++EXPORT_SYMBOL_GPL vmlinux 0x872530d0	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x872a22a4	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0x87323e1b	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x87329ae8	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x87453390	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x876760ec	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x87731651	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0x8780acef	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x87878e45	rio_request_mport_dma
++EXPORT_SYMBOL_GPL vmlinux 0x879b3749	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x879d1b1c	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x87b57ec5	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0x87cedfcd	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0x87d42b63	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x87d7c353	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x87ea0002	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x88136838	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8815270d	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0x883c2740	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x884381c2	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8844d236	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0x88599e55	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x886f4004	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x8873af68	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x887d89e7	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x88841cd9	efivar_entry_set
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88bbcc1a	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x88c14387	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x88c3cae5	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x88f7e69b	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x89056db7	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x891a5a7f	gnttab_max_grant_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x892537e3	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0x8937011f	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0x89382983	nd_mapping_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x89495374	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x8956aeae	apei_exec_ctx_init
++EXPORT_SYMBOL_GPL vmlinux 0x895985ee	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0x895d20b2	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0x897426b0	acpi_node_get_property_reference
++EXPORT_SYMBOL_GPL vmlinux 0x89a25e5a	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x89a70660	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89bd2aea	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x89becd68	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0x89cdb825	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x89d05abc	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x8a02b6c2	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x8a456737	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0x8a4b8066	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x8a559846	gnttab_setup_auto_xlat_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a5b5816	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x8a78989f	irq_from_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x8a7cb9c4	platform_thermal_package_rate_control
++EXPORT_SYMBOL_GPL vmlinux 0x8a7e8dd1	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x8a835788	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8a951089	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8ab630db	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8ac4a86b	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0x8ad191f6	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0x8ad30432	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8ade2c51	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0x8aeb5c8a	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x8b03c71a	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x8b04668e	bind_interdomain_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x8b149c36	clk_is_match
++EXPORT_SYMBOL_GPL vmlinux 0x8b462d3a	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0x8b52e457	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0x8b540f1a	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x8b6ba5dd	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0x8b7861f9	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8b8dd7ac	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x8b9200fd	lookup_address
++EXPORT_SYMBOL_GPL vmlinux 0x8bddd69f	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0x8be7aadc	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8bf7f004	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c06a108	xenbus_transaction_start
++EXPORT_SYMBOL_GPL vmlinux 0x8c11bff3	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0x8c1ee7a0	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8c2c01c9	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x8c40c226	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c9d1661	arch_phys_wc_index
++EXPORT_SYMBOL_GPL vmlinux 0x8c9eabaa	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x8ca2e291	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8caaaa12	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0x8cae54b5	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x8cc830d2	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x8ccd68f4	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8cd9f935	setup_APIC_eilvt
++EXPORT_SYMBOL_GPL vmlinux 0x8cea765f	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x8cefb899	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0x8cf00d6b	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0x8d005769	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x8d0e5a78	nd_cmd_out_size
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d304670	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0x8d389db4	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0x8d398ba2	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8d39eba7	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x8d3b7056	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x8d3e04a6	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0x8d3fedd6	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x8d43b4a3	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0x8d45152c	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0x8d707b57	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x8d71377d	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x8d9fa235	acpi_os_map_iomem
++EXPORT_SYMBOL_GPL vmlinux 0x8db946cf	acpi_driver_match_device
++EXPORT_SYMBOL_GPL vmlinux 0x8e026c90	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x8e198b66	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e4334db	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0x8e51d923	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x8e542fbf	fpu__restore
++EXPORT_SYMBOL_GPL vmlinux 0x8e5ac881	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x8e5f2865	xen_swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x8e79c2b4	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x8e7b4361	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x8e854b7a	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0x8ea147ff	acpi_ec_add_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0x8ea3270d	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0x8eba4f8f	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0x8ec8993f	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8ed08041	pcc_mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x8ed2458d	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0x8ed4282c	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x8edddc3c	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0x8ef6393e	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x8ef67a11	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x8ef89697	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x8efd5376	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f67844e	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f7d90a5	pinctrl_utils_add_config
++EXPORT_SYMBOL_GPL vmlinux 0x8fb41a02	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0x8fb6c1d3	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x8fbbbc95	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x8fd1c2e3	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0x8fee274f	__clk_get_hw
++EXPORT_SYMBOL_GPL vmlinux 0x8ffc523a	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x9009602a	acpi_bus_get_ejd
++EXPORT_SYMBOL_GPL vmlinux 0x901d7c66	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x903bb65b	acpi_dev_resource_ext_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x90525921	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x906e8a9d	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x907feb52	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0x90862d22	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0x909a9d88	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90b7e815	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x90bcdca2	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x90c5c342	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0x90d9829d	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x90dc29df	aout_dump_debugregs
++EXPORT_SYMBOL_GPL vmlinux 0x90de0452	platform_thermal_package_notify
++EXPORT_SYMBOL_GPL vmlinux 0x90e0d5bf	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x911facc5	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9125d4b1	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x912f609d	xen_swiotlb_dma_mapping_error
++EXPORT_SYMBOL_GPL vmlinux 0x91375f21	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x9145eec5	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x91523124	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x915a2994	xenbus_dev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x916dd403	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x91826bf6	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x919ec103	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x91b516fb	xenbus_free_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91d60985	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x91d8108a	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x91f0c992	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0x920cc389	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x921d2f95	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x92341fbc	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x924f7057	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0x9273028d	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x927a26ec	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0x929167a1	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x92a2609b	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x92a7b6b4	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x92b32ba6	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0x92b8118d	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92e03492	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x92ea30c1	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0x92f42253	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x930a7bca	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0x9312d80e	evtchn_put
++EXPORT_SYMBOL_GPL vmlinux 0x9316f3fe	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x9333a104	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x9341be5a	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x935519ce	clk_multiplier_ops
++EXPORT_SYMBOL_GPL vmlinux 0x935bd2a3	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x9361d426	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0x936db988	rio_enable_rx_tx_port
++EXPORT_SYMBOL_GPL vmlinux 0x93731e9f	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x937d3c74	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0x93a82a66	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0x93d4116a	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0x93dc2586	pgprot_writethrough
++EXPORT_SYMBOL_GPL vmlinux 0x93ec847e	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x93f9f3a6	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x942a6c34	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0x9430937a	nd_blk_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x943508e5	acpi_unbind_one
++EXPORT_SYMBOL_GPL vmlinux 0x943fc708	xen_setup_shutdown_event
++EXPORT_SYMBOL_GPL vmlinux 0x9450550e	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x94720414	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x949f7342	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x94c318be	apei_exec_collect_resources
++EXPORT_SYMBOL_GPL vmlinux 0x94c38f90	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0x94ca8260	xenbus_dev_groups
++EXPORT_SYMBOL_GPL vmlinux 0x94dcfab7	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x9519fcb5	rio_register_mport
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x9544f868	__online_page_increment_counters
++EXPORT_SYMBOL_GPL vmlinux 0x9546b5c9	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x9558489f	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x958bd7a8	acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x959056d1	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x95b62f07	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95cba492	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x96436239	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x964add15	xenbus_scanf
++EXPORT_SYMBOL_GPL vmlinux 0x964c6d21	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x964d5c39	acpi_os_map_memory
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9657a6aa	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0x96626387	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x967672f0	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x96776025	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x96897001	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x968e4266	xen_swiotlb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x96ab8751	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0x96e1abc5	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x96e9ac84	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0x96f47e9f	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x96f62c41	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0x9707a7de	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x971baa9d	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x972ba455	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x97359873	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0x9739b45a	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x973ab8ad	cper_estatus_print
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x976be982	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0x976cec43	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0x9786a753	clk_fractional_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x979c0afd	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0x97afcb5c	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0x97be6505	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0x97d6549d	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x98320fa4	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x9839849f	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9855c639	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0x985824e8	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x985a03df	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x985e7495	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9886e421	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x98d60c3e	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0x98d731b0	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x98ed1a64	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x98f9f73d	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x98ff4efb	pinctrl_pm_select_default_state
++EXPORT_SYMBOL_GPL vmlinux 0x99091212	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0x990f75fd	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x991eddea	pinctrl_force_default
++EXPORT_SYMBOL_GPL vmlinux 0x99200c4c	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x99412854	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x99457f76	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x99608282	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x9973add9	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x998d79d6	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x99921495	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0x99a9ff9a	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99bfca9c	pinctrl_utils_add_map_mux
++EXPORT_SYMBOL_GPL vmlinux 0x99cac210	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0x99cf05aa	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a3c21b3	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x9a3d2816	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x9a4be63c	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x9a785c54	rio_mport_class
++EXPORT_SYMBOL_GPL vmlinux 0x9a863668	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9aab1f39	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x9ab04626	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0x9ab14b93	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9ad1b551	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0x9ad65adc	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9afe26dc	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x9b05a955	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0x9b085977	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x9b1599cc	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x9b1d15d7	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9b39ec8a	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x9b6a7412	idle_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x9b7048cb	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0x9b720312	acpi_target_system_state
++EXPORT_SYMBOL_GPL vmlinux 0x9b934050	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x9b9f3648	pcibios_scan_specific_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9ba2bb2b	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x9bbbd141	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0x9bbd182c	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x9bc5ba84	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x9bc66123	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0x9bc9912c	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x9bca03ca	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0x9bd35a61	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x9bd72b78	apei_write
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c09dc5c	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x9c10b6d2	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9c248b07	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0x9c2de449	memory_add_physaddr_to_nid
++EXPORT_SYMBOL_GPL vmlinux 0x9c2e4b66	acpi_unregister_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x9c462261	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0x9c781803	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0x9c7a3fe5	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0x9c90c5a8	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x9c92992c	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x9c96a45b	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0x9cb6b429	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0x9cbab8bb	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cc6f286	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x9cd68e75	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9cda64ab	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x9cdf33d5	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0x9cf6ff04	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x9cfd1dd7	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x9d06688b	register_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x9d1441cb	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x9d193d23	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x9d20a089	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x9d3850e1	gnttab_alloc_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x9d3f4f48	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0x9d5a0739	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0x9d61d6b1	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9ddaedc1	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x9e05499a	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x9e1e9210	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x9e293cbb	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x9e39dd6e	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0x9e3a4b25	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e47c69d	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0x9e53caa5	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x9e71d7e7	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0x9e86a9f6	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0x9e8df904	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0x9ea7e335	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9f353441	nd_numa_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x9f3c1c45	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x9f3dd633	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x9f723c5d	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0x9f92af83	x86_hyper_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x9fbced97	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fde333b	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9ff519b6	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x9fffbcb8	acpi_initialize_hp_context
++EXPORT_SYMBOL_GPL vmlinux 0xa002060a	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0xa0052a01	xenbus_dev_remove
++EXPORT_SYMBOL_GPL vmlinux 0xa0128e88	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xa0143810	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0xa014a6ac	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0xa03d7442	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0xa08792fe	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0xa09a7bc3	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0xa0b8b1eb	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0xa0c082e8	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xa0c64d8a	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0xa0c7d20e	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0xa0e0a473	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xa0f334d1	arch_add_memory
++EXPORT_SYMBOL_GPL vmlinux 0xa0ff01d4	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0xa11216be	xen_store_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0xa11b55b2	xen_start_info
++EXPORT_SYMBOL_GPL vmlinux 0xa1244ec5	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0xa12fef87	gnttab_unmap_refs_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa1498221	__tracepoint_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xa151836e	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0xa156a1f2	erst_get_record_id_end
++EXPORT_SYMBOL_GPL vmlinux 0xa15fa3c2	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0xa16742d3	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xa188048b	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa1ace321	xen_pci_frontend
++EXPORT_SYMBOL_GPL vmlinux 0xa1afeafc	generic_access_phys
++EXPORT_SYMBOL_GPL vmlinux 0xa1b13779	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0xa1b538bb	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0xa1c22190	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0xa1d27207	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xa1e399c9	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0xa1e674c1	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0xa1ed9c8b	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xa1f79553	xen_create_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xa26d0f5e	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa2718017	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa2a1ce03	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0xa2a257e0	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0xa2ac5519	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0xa2b9c993	clk_register_fixed_factor
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2d01710	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0xa30f41d4	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0xa353fffc	xenbus_rm
++EXPORT_SYMBOL_GPL vmlinux 0xa35fe53f	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0xa36f5a2a	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xa3748943	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xa384918b	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa386c029	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3a448ba	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3c3c801	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0xa3e58789	efivar_validate
++EXPORT_SYMBOL_GPL vmlinux 0xa3e76da0	acpi_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa3f6274a	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0xa4116d5d	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xa41cc9e7	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0xa42aee34	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0xa4415fc2	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0xa447465d	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xa452c297	hpet_mask_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa452f2a4	xen_pirq_from_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa466de38	acpi_processor_ffh_cstate_enter
++EXPORT_SYMBOL_GPL vmlinux 0xa46bb061	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa4a1128f	rio_map_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xa4ba24cd	nd_blk_region_set_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0xa4e74982	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xa5109c40	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xa53e5840	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0xa56de7ac	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xa5834428	pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0xa58f6f15	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xa5a1f630	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0xa5ac0ed5	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xa5ae3f4d	acpi_pci_check_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5f90534	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa60a53ef	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0xa616585b	__clk_mux_determine_rate_closest
++EXPORT_SYMBOL_GPL vmlinux 0xa621d04c	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xa623d515	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa62892c6	efivar_sysfs_list
++EXPORT_SYMBOL_GPL vmlinux 0xa63bad57	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0xa660eaa7	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0xa66438e8	erst_read
++EXPORT_SYMBOL_GPL vmlinux 0xa6647139	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa6aacd1a	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa6acf78d	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6ca92f2	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa6d5607d	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa6e6237c	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0xa6ed02fa	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa70ca802	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0xa7119661	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa7315d7d	xenbus_watch_pathfmt
++EXPORT_SYMBOL_GPL vmlinux 0xa743b02a	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0xa74b7cd3	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xa74da95b	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa771d090	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xa7a54417	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xa7b0b2d8	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa7c05aff	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa7d34bfc	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0xa7e713d6	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0xa7fae3cb	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xa7fe5404	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa801b359	efivar_entry_iter_begin
++EXPORT_SYMBOL_GPL vmlinux 0xa81bef70	pinctrl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa8228444	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xa837231b	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa866c149	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0xa86ff83e	dax_do_io
++EXPORT_SYMBOL_GPL vmlinux 0xa8707931	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0xa8771834	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xa8774821	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xa87d1ee1	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0xa880c38c	nd_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0xa89c44a1	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0xa8a9156c	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8e3efde	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0xa9008cba	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa9126bff	hpet_set_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa9143342	find_iova
++EXPORT_SYMBOL_GPL vmlinux 0xa92d6d08	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xa9317db7	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa9674e24	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0xa99f146f	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xa99ff199	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0xa9aa15bf	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0xa9ae8621	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xa9b9cb18	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xaa070b27	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0xaa3518ce	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xaa53d522	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0xaa60429a	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xaa71cf8f	phy_pm_runtime_put
++EXPORT_SYMBOL_GPL vmlinux 0xaa8a73a9	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xaa8bf341	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xaa8f985e	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0xaa99aab7	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0xaa9e4cd7	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0xaaa23d73	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaab24d62	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0xaabb1441	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xaaf44ba3	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0xab01acbe	gnttab_request_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0xab07c28b	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xab161e9b	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xab1a708d	__online_page_set_limits
++EXPORT_SYMBOL_GPL vmlinux 0xab1e0e93	hv_setup_kexec_handler
++EXPORT_SYMBOL_GPL vmlinux 0xab29ad96	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0xab2fecb7	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xab34b564	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0xab387011	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xab567d31	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab86e20c	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0xabbf7416	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabd34543	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xabe0f64b	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0xabe980b9	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xac0e59bd	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0xac27f43b	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0xac76a038	to_nd_blk_region
++EXPORT_SYMBOL_GPL vmlinux 0xac8c3c2d	to_nd_region
++EXPORT_SYMBOL_GPL vmlinux 0xac8f64df	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xac9ce195	kvm_async_pf_task_wait
++EXPORT_SYMBOL_GPL vmlinux 0xaca645de	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0xacae8a02	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0xacafa8e7	vector_used_by_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xaccd6887	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xad15825f	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0xad1b04b9	print_context_stack_bp
++EXPORT_SYMBOL_GPL vmlinux 0xad1b2d62	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0xad1bc423	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0xad541832	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0xad570a4a	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xad70eae7	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0xad7a49f8	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0xad8d8ab0	xen_physdev_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadd9486e	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xae2eef20	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xae323b15	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0xae44bdec	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0xae574393	efivar_entry_add
++EXPORT_SYMBOL_GPL vmlinux 0xae57879c	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xae660fc2	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae6eaf93	hwpoison_filter_dev_minor
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae7c7c5b	dmi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xae7ebc5a	acpi_dev_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xae91f629	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xae960a89	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xaec55ac2	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xaec628d0	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0xaecba6be	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0xaeea8ef2	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0xaeec159a	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0xaef373b5	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0xaf071408	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xaf26c446	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0xaf50345e	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0xaf51e7cd	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xaf6bb4ab	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xaf8574d8	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0xaf9439db	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xaf953fa3	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xafa4ad4e	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0xafaab145	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb0012c5c	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xb00b833e	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xb02ac411	register_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb0661d73	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xb077e70a	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xb08fa0f5	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xb0957646	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0xb0a70f22	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0bce4f0	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xb0c21ccb	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0xb0d1656c	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0xb13844b1	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb145a22b	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0xb15845f1	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xb172ffac	efivars_sysfs_init
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb1a5f2fe	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xb1a8660d	inet_csk_compat_getsockopt
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1b370bd	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0xb1b82e72	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1bedeb7	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1d90832	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1f32450	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0xb2034006	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xb2129d6d	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xb217dd47	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb21bbef9	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb254ea62	rio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb26a1add	elfcorehdr_addr
++EXPORT_SYMBOL_GPL vmlinux 0xb275076b	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb276838d	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0xb285b8f8	xen_in_preemptible_hcall
++EXPORT_SYMBOL_GPL vmlinux 0xb286ecf7	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0xb2c3c7ad	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0xb2c9ff49	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xb2cba732	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb2f0e12c	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xb3253ed9	hpet_rtc_timer_init
++EXPORT_SYMBOL_GPL vmlinux 0xb33b6f0b	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0xb33e4aee	clk_hw_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0xb347bb2c	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0xb35119cd	pcc_mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0xb352939f	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb3642505	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xb3a0f0b8	acpi_bind_one
++EXPORT_SYMBOL_GPL vmlinux 0xb3dc3424	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0xb3f44210	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xb3fedd4e	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb43f0eaf	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xb4548d80	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xb4557e67	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0xb45aab2c	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4e14553	gnttab_query_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea277f	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb5398600	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0xb53d7367	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0xb54c38d6	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xb553c015	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0xb56d463f	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0xb5848bae	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5a145bf	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0xb5c59610	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0xb5da1435	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0xb5de4bc2	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0xb5e73af8	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0xb5f1549e	acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb5f7e464	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0xb60b89ea	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb6143675	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0xb61b2abe	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb6230f1f	gnttab_grant_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb630bce8	nvdimm_pmem_region_create
++EXPORT_SYMBOL_GPL vmlinux 0xb632d90a	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0xb63f50c8	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xb64e9b91	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0xb66421b2	acpi_str_to_uuid
++EXPORT_SYMBOL_GPL vmlinux 0xb66967c4	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0xb66f3adc	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0xb67b63ec	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0xb68c4cbf	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0xb694e039	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0xb695f934	md_run
++EXPORT_SYMBOL_GPL vmlinux 0xb6a6e964	hwpoison_filter
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6b76720	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xb6d8fba6	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xb6e6d99d	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb6e9ca78	efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0xb718f2f9	sfi_table_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb7329c06	clk_set_phase
++EXPORT_SYMBOL_GPL vmlinux 0xb73b740a	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0xb75c5884	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0xb76a166c	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0xb7b7f514	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0xb7b7f920	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0xb7d387a2	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xb7d7c12e	hpet_set_alarm_time
++EXPORT_SYMBOL_GPL vmlinux 0xb7e55c53	xenbus_alloc_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb81aca50	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0xb8353f51	intel_svm_bind_mm
++EXPORT_SYMBOL_GPL vmlinux 0xb844a457	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0xb8546bef	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xb85fc64d	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xb8806322	restore_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb89bd38b	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb8a0328b	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xb8a1c88f	rio_release_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xb8b2b1f7	mce_register_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0xb8b34c4a	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8e50962	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xb8e6c0e0	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xb8f71e6e	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb900c3ee	rio_mport_get_feature
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb931607a	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0xb945ace8	__tracepoint_remove_device_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xb96dcfa4	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0xb98eec9d	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0xb99d5837	xenbus_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9e9d006	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xba00d55d	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0xba00f918	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0xba19754b	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba3dc4ef	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0xba5b6ec9	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0xba7e331e	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xba883f61	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xba94c685	cper_estatus_check
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbaf6d630	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb162e8e	pinctrl_find_gpio_range_from_pin
++EXPORT_SYMBOL_GPL vmlinux 0xbb341dce	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xbb355944	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0xbb390228	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xbb6f025a	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0xbb75912c	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0xbb768919	rio_mport_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xbb7c922a	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xbbb98859	edid_info
++EXPORT_SYMBOL_GPL vmlinux 0xbbc98da9	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xbbd1aef4	acpi_subsys_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xbbd46dde	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbbd4f657	xen_pcpu_id
++EXPORT_SYMBOL_GPL vmlinux 0xbbf7e42a	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0xbc1294ea	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0xbc18e66b	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xbc2c4d4c	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xbc4217d4	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0xbc49db86	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc6cdd81	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0xbc72075b	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xbc7c88cc	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0xbc8f1670	rio_request_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xbc9e510b	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcb838a1	amd_flush_garts
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcd1e92b	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbd02cf00	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0xbd0c1f58	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0xbd22a123	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0xbd280fb4	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0xbd2c272d	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd611e09	acpi_is_pnp_device
++EXPORT_SYMBOL_GPL vmlinux 0xbd671048	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xbd86b127	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xbd8a9571	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xbd9cfddb	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0xbda18748	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbdd5f10f	apei_hest_parse
++EXPORT_SYMBOL_GPL vmlinux 0xbdee8c23	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0xbdfa0a98	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0xbe0500cf	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0xbe153e84	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe31f2f4	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0xbe5d0996	idle_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe781c85	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0xbe80473a	xenbus_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xbe8f4502	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbebcd541	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xbed48142	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbee2ce86	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbeea9a80	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0xbeeee742	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0xbf02d56b	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf088119	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0xbf10959a	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0xbf3ea525	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xbf70c548	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xbf89379d	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0xbf909261	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xbfa12f1f	rio_get_comptag
++EXPORT_SYMBOL_GPL vmlinux 0xbfa877b4	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0xbfaec24e	to_nvdimm_bus
++EXPORT_SYMBOL_GPL vmlinux 0xbfb1be70	hv_setup_vmbus_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfc1a3bb	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0xbfd10bb7	clk_register_mux_table
++EXPORT_SYMBOL_GPL vmlinux 0xbfde06a8	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xbfe80de5	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xbfef7770	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0xbffde8ec	compat_alloc_user_space
++EXPORT_SYMBOL_GPL vmlinux 0xc015a3d1	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xc0250219	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc02e5039	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0xc0317ee7	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xc04b21bd	acpi_os_unmap_iomem
++EXPORT_SYMBOL_GPL vmlinux 0xc04ba76e	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0xc04d6f0a	to_nd_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc0900fcf	acpi_os_get_iomem
++EXPORT_SYMBOL_GPL vmlinux 0xc090dd06	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0xc092f5ca	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xc09b507e	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0d9cfd0	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0eedbb5	register_mce_write_callback
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc101e257	xen_remap_domain_gfn_array
++EXPORT_SYMBOL_GPL vmlinux 0xc10bce31	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0xc1396fdb	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0xc13cc042	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0xc14c2824	xenbus_probe
++EXPORT_SYMBOL_GPL vmlinux 0xc164642e	xenbus_otherend_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc17f45ca	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0xc187696a	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0xc1afd79d	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0xc1e3c1fc	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0xc1f29022	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0xc1fb554f	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xc2007b1a	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xc202f54e	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0xc2105ee9	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc240d17f	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xc246b590	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xc25b8971	hv_remove_crash_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc26351f8	bind_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc2690330	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc287d96a	kvm_set_posted_intr_wakeup_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc2909b76	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xc290ae44	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0xc2a57600	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xc2b6de0c	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0xc2bd2f16	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc2d65f3f	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xc2dbee5c	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0xc2ee89c0	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0xc2fdbae4	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0xc3098b37	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xc3098be6	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0xc30d161d	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc3567ef3	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0xc357923c	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xc35f9499	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0xc3611b97	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc36831d7	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc37f2a3d	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0xc38f36d9	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc39c41ba	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0xc3a04506	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc3c900a0	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xc3cc7467	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc3d2dba6	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xc3f141fe	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0xc403434d	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc40418c5	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc41c932c	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0xc426bded	xen_xlate_remap_gfn_array
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc4301a53	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc447dd93	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xc44898ae	mmput
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc4796bf3	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0xc48182e1	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc48f6d71	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xc4a2f58e	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4d35a59	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xc4d760c7	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc4ded348	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc4e7ac96	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc4f1dc0b	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xc512626a	__supported_pte_mask
++EXPORT_SYMBOL_GPL vmlinux 0xc5397da6	xenbus_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc54bde31	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xc569d8ce	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc589021b	__clk_mux_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0xc589dbd1	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xc59171b4	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0xc5d681f2	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc5ef860f	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc63e7d93	static_key_deferred_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc64aafec	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xc64e0579	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc66019cc	xen_resume_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc6732728	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc68cefc7	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xc68dbe32	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6a4a872	__clk_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc6ab4cde	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xc6bac7ec	put_device
++EXPORT_SYMBOL_GPL vmlinux 0xc6bfce66	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc6da7a0a	__tracepoint_map
++EXPORT_SYMBOL_GPL vmlinux 0xc6de3a94	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0xc7002ac4	evtchn_make_refcounted
++EXPORT_SYMBOL_GPL vmlinux 0xc7061ef3	iova_cache_put
++EXPORT_SYMBOL_GPL vmlinux 0xc7146bfe	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc7566b1b	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0xc75f6d8d	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0xc771b773	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0xc7894993	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7ca51a4	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0xc7cb49f5	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xc7cd6018	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xc7df8bfd	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7e4cb1b	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xc7f174be	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc814fb4e	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0xc81b765d	put_iova_domain
++EXPORT_SYMBOL_GPL vmlinux 0xc845dc99	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0xc856f132	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xc87196ff	rio_local_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc87e487a	sched_clock_idle_sleep_event
++EXPORT_SYMBOL_GPL vmlinux 0xc8874d01	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0xc8931ea1	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8b75b76	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xc8cb97aa	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc8f941a8	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0xc8fd2fc6	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc9420ac2	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0xc950ea92	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc9641b48	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0xc9705eeb	has_newer_microcode
++EXPORT_SYMBOL_GPL vmlinux 0xc98f8bc7	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xc99416ee	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0xc9b74073	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0xc9c3f176	hpet_register_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc9c89bcf	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xca0302db	xenbus_dev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xca092e65	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0xca3b7fd5	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0xca5a79de	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xca7903a1	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca81ea9a	xenbus_transaction_end
++EXPORT_SYMBOL_GPL vmlinux 0xcabbc405	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcae37d01	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xcaf270b4	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb227a00	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xcb45f851	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb496225	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0xcb51b8f7	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0xcb5b116e	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0xcb5d0af3	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0xcb7219a8	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0xcb86998d	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0xcb87014a	ioremap_uc
++EXPORT_SYMBOL_GPL vmlinux 0xcb9749d1	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0xcb986baa	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbe8808d	pinctrl_find_and_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0xcbedba44	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcbf7ddf4	xen_swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0xcc04b356	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xcc05cc48	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0xcc0c1584	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0xcc1633cc	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0xcc265861	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xcc590f40	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0xcc604750	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0xcc7a2922	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcca4d2d8	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xcca6bb78	acpi_dma_request_slave_chan_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xccc24256	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccd6e657	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0xccd859a8	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xcce238b5	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0xcce73109	smp_ops
++EXPORT_SYMBOL_GPL vmlinux 0xccea4e34	perf_get_x86_pmu_capability
++EXPORT_SYMBOL_GPL vmlinux 0xccf7b421	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xcd02f1dc	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xcd161fed	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0xcd192bc8	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0xcd377150	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xcd5d4ef9	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcd9fdd23	dax_pfn_mkwrite
++EXPORT_SYMBOL_GPL vmlinux 0xcda2618e	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdc87274	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcdd990a2	efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0xcddaf9a2	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0xcddb9dc1	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0xcde34ce3	add_memory_resource
++EXPORT_SYMBOL_GPL vmlinux 0xcdf6d3f1	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0xce12d037	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xce151a36	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0xce5829e1	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce714bf6	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0xce79ea2a	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0xce8ab5c3	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xce9ab7d6	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xce9fc779	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0xceaa8fb2	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xceaeb390	acpi_dev_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xceb1f126	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0xceb591a4	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xcebcae34	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0xcec32fa9	__rio_local_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcef1dd0e	perf_check_microcode
++EXPORT_SYMBOL_GPL vmlinux 0xcef274d3	xen_swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xcef7770a	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xcf264fc6	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcfaac056	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfe3bdc6	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xcff48317	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd02331a4	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0xd02d0832	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0xd02dbe53	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xd03b826e	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd0458ccb	xenbus_strstate
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd068342c	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0xd08da653	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd092116c	xen_unmap_domain_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0xd0922552	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd0b12460	__dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0dfad1e	xen_swiotlb_sync_sg_for_device
++EXPORT_SYMBOL_GPL vmlinux 0xd0e61e8c	klp_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0xd0f4dda3	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0xd0f9eea5	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xd108086d	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xd11c855e	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0xd12629c8	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0xd13a2891	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xd13b4b19	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd1403b4d	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0xd1507e59	erst_clear
++EXPORT_SYMBOL_GPL vmlinux 0xd1553b3b	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0xd160a17c	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd17d26b3	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xd1985553	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0xd1ca4984	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xd1d418c2	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0xd1d79882	xen_unregister_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd1f84573	klp_unregister_patch
++EXPORT_SYMBOL_GPL vmlinux 0xd1ff0b5f	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd2400fab	__xenbus_register_backend
++EXPORT_SYMBOL_GPL vmlinux 0xd25205ed	hugetlb_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd258d2c3	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0xd25ea5a4	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xd25ee25a	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xd25fa113	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd2751c03	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0xd2817892	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xd28285ef	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd2c58ab2	apei_exec_noop
++EXPORT_SYMBOL_GPL vmlinux 0xd2d1927b	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2e5cda3	pinctrl_force_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xd2e88de5	clk_register_gate
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd2f01b17	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0xd2fa622b	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0xd30c4a6d	rio_mport_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xd3295ad3	acpi_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0xd37bab0b	__efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3b19bf5	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0xd3bcc7cd	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0xd3d12269	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xd3d8685c	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd404a937	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd40eb9c1	dax_zero_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xd411cef0	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0xd418ea2a	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd426dbc4	erst_get_record_count
++EXPORT_SYMBOL_GPL vmlinux 0xd435c181	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0xd43eced9	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xd4487fd5	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd45ea32f	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0xd4788579	device_del
++EXPORT_SYMBOL_GPL vmlinux 0xd4a347f4	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xd4ba1891	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0xd4bd66a0	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd4c07ee4	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd5030f07	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xd51d4230	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd52a56bc	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xd54d4ae3	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd5659033	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0xd56b5f64	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0xd58318ba	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xd58745bf	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0xd59bc23c	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0xd5bb7f68	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5cc4d70	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd640afef	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xd65fe9d2	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd68e6b3c	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0xd6cde341	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0xd6d9c42e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0xd6e973af	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0xd6ed3a8e	cper_next_record_id
++EXPORT_SYMBOL_GPL vmlinux 0xd6f90089	rio_unmap_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xd6feefa5	agp_num_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd72feba2	xenbus_read_driver_state
++EXPORT_SYMBOL_GPL vmlinux 0xd7399d2a	efivar_entry_iter_end
++EXPORT_SYMBOL_GPL vmlinux 0xd74a41bd	dummy_con
++EXPORT_SYMBOL_GPL vmlinux 0xd74ec514	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd764d265	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd76ae33f	clk_hw_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd78c6bd2	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xd7ceaadf	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7f2f1b7	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0xd7f3c845	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0xd804aaec	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd82922ac	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd878bdfb	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xd87a8ff8	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xd87fa3b6	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd88f409d	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0xd8aec26c	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0xd8b3d780	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xd8b85191	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xd8cf61d7	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xd8eb57c5	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xd9026c42	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd905f38f	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd919672e	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0xd919806a	amd_cache_northbridges
++EXPORT_SYMBOL_GPL vmlinux 0xd91a98ad	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0xd923afae	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0xd9264c4e	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0xd93263ca	rio_dev_get
++EXPORT_SYMBOL_GPL vmlinux 0xd935292f	apic
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94c96a2	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xd94cccdf	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd94de9f9	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0xd94fa823	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0xd962052b	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd9863d69	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0xd986dad1	kernel_fpu_begin
++EXPORT_SYMBOL_GPL vmlinux 0xd9944232	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xd995ec4f	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xd99fd583	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xd9ae8b44	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0xd9b207c9	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xd9c5c6be	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xd9fb9b47	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xda1f18ca	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xda389561	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0xda45124d	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0xda67da43	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0xda8e399a	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xda9c3a79	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0xdaa06dc1	acpi_lpat_raw_to_temp
++EXPORT_SYMBOL_GPL vmlinux 0xdaaaf7c7	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0xdabb7450	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xdad2583a	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaf34969	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdaff9147	get_hwpoison_page
++EXPORT_SYMBOL_GPL vmlinux 0xdb03b778	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0xdb0bf9f5	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb48101d	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0xdb63a944	acpi_lpat_get_conversion_table
++EXPORT_SYMBOL_GPL vmlinux 0xdb69993c	rio_request_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xdb747300	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb916fd0	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0xdb91e05c	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xdbd29a58	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdbfb2109	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xdc14a211	xen_hvm_evtchn_do_upcall
++EXPORT_SYMBOL_GPL vmlinux 0xdc1d0f9f	efivar_entry_find
++EXPORT_SYMBOL_GPL vmlinux 0xdc4d145f	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xdc5b3dfb	user_read
++EXPORT_SYMBOL_GPL vmlinux 0xdc6699cb	acpi_dev_free_resource_list
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9c172d	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdca5a237	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xdcb2d696	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xdcb359e5	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0xdcc0888d	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xdcccfce2	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0xdcfb4a25	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0xdd0eff61	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd20d031	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0xdd227165	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xdd2d0ff2	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd415154	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xdd57e2b5	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0xdd64008d	xenbus_dev_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xdd70cbc9	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0xdd84a310	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xdd96bcfd	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0xdda1dfb5	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xddd7eac3	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xddfd51dc	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xde16f9f0	__rio_local_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xde37be19	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0xde46e353	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xde51f1d8	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0xde647383	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0xde829697	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xde8dd926	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0xde929cff	get_device
++EXPORT_SYMBOL_GPL vmlinux 0xde9bdace	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0xde9e2403	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xdec5e33a	acpi_register_gsi
++EXPORT_SYMBOL_GPL vmlinux 0xdf0a2c38	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf1882af	dbgp_reset_prep
++EXPORT_SYMBOL_GPL vmlinux 0xdf21c8b9	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0xdf36c66a	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0xdf3a2761	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0xdf4a6bd6	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xdf622181	clk_register_divider_table
++EXPORT_SYMBOL_GPL vmlinux 0xdf66ca81	ucode_cpu_info
++EXPORT_SYMBOL_GPL vmlinux 0xdf6b7c61	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0xdf73943a	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xdf73fe2a	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0xdf75282c	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0xdfa6fa56	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xdfaca769	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdfb6b5f0	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xdff11e33	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0xdff6ca0f	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xdffd82a0	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0xe00719af	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe0159c1e	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0xe0289fd0	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xe02b9e90	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe0427277	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0xe04b7dfc	clk_register_mux
++EXPORT_SYMBOL_GPL vmlinux 0xe052aaf6	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0xe05d8f3d	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe089cfcc	agp_memory_reserved
++EXPORT_SYMBOL_GPL vmlinux 0xe0931cd0	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0xe0a988b3	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe0ada9b0	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0xe0addfbb	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0xe0afaf3c	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xe0b1c103	clk_set_max_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe0c71d03	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0xe0c77bb5	mce_notify_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe0c811b0	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xe0ceec30	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0xe0d151fc	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0xe0d4189e	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xe10cd6ad	erst_get_record_id_begin
++EXPORT_SYMBOL_GPL vmlinux 0xe1303c9b	print_context_stack
++EXPORT_SYMBOL_GPL vmlinux 0xe1629a81	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xe16b0d30	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe1b8c279	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe1bd6c99	rio_init_mports
++EXPORT_SYMBOL_GPL vmlinux 0xe1d0e51b	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xe1de0878	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xe1f1f309	x86_vector_domain
++EXPORT_SYMBOL_GPL vmlinux 0xe2311567	rio_lock_device
++EXPORT_SYMBOL_GPL vmlinux 0xe234175c	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe249e2e9	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe28e8d67	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0xe290704d	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe292c6ca	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xe29349dc	copy_reserved_iova
++EXPORT_SYMBOL_GPL vmlinux 0xe295c0ff	is_hpet_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe2bf4344	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe2bf501e	acpi_gpiochip_request_interrupts
++EXPORT_SYMBOL_GPL vmlinux 0xe2c7eb93	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0xe2de5ea6	dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0xe2fad8ff	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe31e729f	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0xe3215942	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0xe34554c3	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0xe34a1c9f	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0xe35d177d	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe35f003e	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xe3692279	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0xe3925249	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe3948ff4	acpi_walk_dep_device_list
++EXPORT_SYMBOL_GPL vmlinux 0xe399413b	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0xe3b97803	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xe3bc7fd4	hpet_unregister_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe3bda663	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe3ffe2cd	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0xe41534ce	bind_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0xe418fde4	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe433c6ac	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xe4635aa1	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe47d9548	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xe48beb97	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe4ad9d1c	register_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xe4adc317	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4db8265	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0xe4e68bc8	apei_map_generic_address
++EXPORT_SYMBOL_GPL vmlinux 0xe50e2398	pinctrl_utils_add_map_configs
++EXPORT_SYMBOL_GPL vmlinux 0xe514d401	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xe519861c	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xe51e1c7e	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0xe5243788	efivars_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe5454a73	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xe545a811	get_xsave_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe5498c5b	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xe5623fe9	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xe5648b55	xenbus_switch_state
++EXPORT_SYMBOL_GPL vmlinux 0xe570e3ce	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58b02fb	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5b8082b	cper_estatus_check_header
++EXPORT_SYMBOL_GPL vmlinux 0xe5fda007	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0xe62a781a	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0xe64ad8ea	unregister_nmi_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe660d527	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0xe6793630	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0xe693ca11	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xe6b6ba7f	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6df60eb	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6ed141e	xenbus_map_ring
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe6f83837	acpi_bus_attach_private_data
++EXPORT_SYMBOL_GPL vmlinux 0xe708c0a9	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0xe7232e0f	user_return_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe734a197	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe768d444	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe7877de4	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xe7bb9f21	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0xe7c1a685	xen_xenbus_fops
++EXPORT_SYMBOL_GPL vmlinux 0xe7cbcfab	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0xe7f40528	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0xe7f5dc26	__add_pages
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe82c0e86	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0xe83f164f	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe87422c7	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0xe87e2d0c	xen_xlate_unmap_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0xe89bd243	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xe8bbe923	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0xe8c62862	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xe8dd237c	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0xe8e9a235	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0xe8f46963	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0xe8fdd326	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0xe937c01b	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe9880b36	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0xe99e462b	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0xe9a62b4a	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe9a818e6	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xe9ab9862	device_move
++EXPORT_SYMBOL_GPL vmlinux 0xe9ce931a	kvm_para_available
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xe9db377a	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0xe9ddc688	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0xe9efdbae	clk_hw_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea147be6	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0xea1b6249	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0xea224e21	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea4662cc	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0xea4ebd64	xenbus_frontend_closed
++EXPORT_SYMBOL_GPL vmlinux 0xea5d2844	clk_hw_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xea628c20	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0xea6399e9	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0xea64c665	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0xea66eaee	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xea99c5e1	nvdimm_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xea9fd51f	rio_get_asm
++EXPORT_SYMBOL_GPL vmlinux 0xeab9e18f	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0xeb14f65f	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0xeb194e2b	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0xeb22caca	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xeb2798f7	xen_destroy_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xeb2eb288	efivar_variable_is_removable
++EXPORT_SYMBOL_GPL vmlinux 0xeb306801	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0xeb370805	__apei_exec_run
++EXPORT_SYMBOL_GPL vmlinux 0xeb3ba46f	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xeb3f148a	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0xeb4428e3	pinconf_generic_dump_config
++EXPORT_SYMBOL_GPL vmlinux 0xeb6f3823	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xeb72e74e	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0xeb76532f	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0xeb7a31bb	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0xeb7c8bd8	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xeb7d183e	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0xeb8274d2	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0xeb833c22	xen_has_pv_disk_devices
++EXPORT_SYMBOL_GPL vmlinux 0xeb844743	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0xeb89c0cf	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xebbe7ac5	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0xebd0b939	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0xebe80421	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0xebea0478	ata_acpi_gtm
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xebf73ce0	device_register
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec4b29ea	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xec519da1	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0xec631f34	remove_memory
++EXPORT_SYMBOL_GPL vmlinux 0xec85e27c	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xecad3b34	do_machine_check
++EXPORT_SYMBOL_GPL vmlinux 0xecba321c	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0xecd6fdfb	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xecdd4821	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0xeced40c5	gnttab_map_refs
++EXPORT_SYMBOL_GPL vmlinux 0xed0a1f4d	efivars_register
++EXPORT_SYMBOL_GPL vmlinux 0xed0ee16c	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0xed0f3204	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xed200276	rio_release_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xed565d63	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xed80784a	acpi_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xed981a16	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xed9ce7ef	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0xedbc6f67	gnttab_end_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xedc4cad1	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0xedcdffd4	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0xee0b47f6	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0xee13102a	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0xee13e697	set_personality_ia32
++EXPORT_SYMBOL_GPL vmlinux 0xee1e680a	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xee2c3d2a	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0xee6615fc	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee765736	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0xee9caf6c	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0xeeb68672	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xeee22cb8	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xeef07ec7	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0xef0be3a3	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xef14de9b	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xef1f6e23	apei_resources_request
++EXPORT_SYMBOL_GPL vmlinux 0xef22da16	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0xef2e02d6	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xef45bca0	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0xef679d1e	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6d007a	sigset_from_compat
++EXPORT_SYMBOL_GPL vmlinux 0xef72653f	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefacb4ec	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0xefc50d37	default_iommu_map_sg
++EXPORT_SYMBOL_GPL vmlinux 0xefd127ff	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0xefd5bd21	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xefe153df	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0xefe80f8b	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0xf00691fc	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0xf0234101	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf04ce61e	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf050197b	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0xf0522199	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf064d467	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf0696401	acpi_pci_detect_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xf0722c3f	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf0787b3e	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xf0865561	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0xf09ccd5f	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xf0ad5c20	pci_msi_set_desc
++EXPORT_SYMBOL_GPL vmlinux 0xf0bf48ca	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4cfa3	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4d251	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0xf0ce9e72	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0xf0f172c5	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf10df554	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0xf14e4d24	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xf14e733b	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0xf15f8543	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0xf16929f6	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0xf16a355e	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf1857c3b	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0xf18c7897	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0xf18d9930	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0xf192b79f	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1b551d9	ibft_addr
++EXPORT_SYMBOL_GPL vmlinux 0xf1c36117	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0xf1ca251e	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf222aa67	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0xf229b2e9	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0xf22ab548	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xf23e8f63	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0xf2411c29	gpiochip_add_pin_range
++EXPORT_SYMBOL_GPL vmlinux 0xf26084bd	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf2630668	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf291252d	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2d4de05	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0xf2e7b795	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0xf2f15fcc	acpi_pci_find_root
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf3086da0	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf3265fff	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0xf32bdc5d	unregister_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf33dc43c	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xf34962f9	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0xf34c7054	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0xf35d7284	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xf3623cfb	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf3894916	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0xf38defcd	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0xf39a301d	acpi_ec_remove_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0xf3ab94b3	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3ba3e56	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3bd273b	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0xf3be69ca	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0xf3d16a69	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0xf3dd3ec1	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf3ebf4eb	arch_apei_report_mem_error
++EXPORT_SYMBOL_GPL vmlinux 0xf3effa9a	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0xf3f06b68	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf3f4cc5e	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf4174b48	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xf445506a	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xf45f84d1	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0xf46ea06b	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xf492d63e	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf49c079c	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xf4cb7b8e	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0xf4cc6600	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0xf4e1387e	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0xf4ea2ce1	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf513e585	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0xf52a8ffa	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xf53435d9	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0xf5379771	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xf5489437	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf5785b42	evtchn_get
++EXPORT_SYMBOL_GPL vmlinux 0xf589ff6c	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0xf5945bac	gnttab_free_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5a8eefc	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf5b9ca54	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0xf5e9f0dd	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0xf5f60965	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0xf6185bb8	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0xf6630358	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xf6713209	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xf6740a1c	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0xf69a0823	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0xf6a9556a	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xf6c58153	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf6c71a25	cper_severity_str
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6ce4173	__efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0xf6d553c1	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0xf6da310d	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf6ecc1d7	gnttab_unmap_refs_async
++EXPORT_SYMBOL_GPL vmlinux 0xf7016530	xenbus_gather
++EXPORT_SYMBOL_GPL vmlinux 0xf72d8e44	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0xf72d9c48	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0xf78c7a39	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0xf7911d4c	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xf7a09b2f	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xf7a2de26	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xf7a585fd	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf7c3f273	xen_resume_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xf7c6365d	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xf7d20c70	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xf7df703c	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xf7dfd765	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xf7f07a0f	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf7f1d2c2	pci_msi_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf8032508	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf8374a0a	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0xf843f322	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xf845b344	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xf84c8d6c	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf8990820	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xf89dd932	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xf8df41dc	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xf8e6b564	hibernation_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8e9459e	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf90da188	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf920c1a5	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf939c937	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0xf9426bd0	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0xf9466a67	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xf94d3b62	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf95b4906	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xf9765833	dmi_match
++EXPORT_SYMBOL_GPL vmlinux 0xf98683f9	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9a55249	rio_route_add_entry
++EXPORT_SYMBOL_GPL vmlinux 0xf9b083fa	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0xf9c338d5	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9d9264e	xen_have_vector_callback
++EXPORT_SYMBOL_GPL vmlinux 0xf9e97f92	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xf9eaf6f8	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xf9f04dac	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xf9f5d2f3	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0xf9fb2f04	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xfa0d3900	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa2c0632	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0xfa35044a	alternatives_patched
++EXPORT_SYMBOL_GPL vmlinux 0xfa901b31	compat_get_timespec
++EXPORT_SYMBOL_GPL vmlinux 0xfa9e33f7	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0xfaa25473	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xfacbe684	__rio_local_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xfad980fe	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0xfadfb9ee	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0xfae6c1fc	xenbus_register_driver_common
++EXPORT_SYMBOL_GPL vmlinux 0xfaf7e751	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xfb0047f6	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0xfb142f55	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0xfb223f45	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfb237cad	acpi_device_modalias
++EXPORT_SYMBOL_GPL vmlinux 0xfb25ce06	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0xfb2cd145	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb383515	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfb64b230	acpi_processor_ffh_cstate_probe
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb7570f8	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xfb77ec2d	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0xfb7ff697	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xfbadbacd	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0xfbb39334	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfbd2b4fc	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0xfbe020f8	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xfbe442b0	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0xfbe92719	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc201b66	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0xfc254d15	gnttab_free_auto_xlat_frames
++EXPORT_SYMBOL_GPL vmlinux 0xfc2c0a48	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0xfc3b4246	acpi_bus_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xfc410567	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xfc4c6263	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0xfc77177b	ata_acpi_stm
++EXPORT_SYMBOL_GPL vmlinux 0xfc92d7ff	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0xfc968c8b	apei_exec_write_register_value
++EXPORT_SYMBOL_GPL vmlinux 0xfcc5bc3a	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0xfcc89d2b	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfcf36802	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0xfd01a657	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfd0a2f43	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0xfd4f1cb9	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xfd51b281	gnttab_end_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0xfd54a887	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0xfd7243c7	erst_disable
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd9437b4	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfe0267ad	__rio_local_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xfe0c0244	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xfe0d7572	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0xfe4684ae	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xfe5218fc	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0xfe6249f1	rio_release_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xfe6bc608	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xfe727411	get_phys_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfe9b6625	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xfea10de5	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0xfeb4b008	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0xfec85113	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0xfecaa4da	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfee02f24	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xfee83cc3	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xfeff5d59	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xff01e48b	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff291ecf	clk_unregister_divider
++EXPORT_SYMBOL_GPL vmlinux 0xff2978c4	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xff2ce747	machine_check_poll
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff5f427c	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff7799f8	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0xff89ba20	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xff903cb4	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0xffa64552	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0xffa7d0be	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffb87dd2	rio_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0xffba4dfb	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xffd387e1	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0xffd6a9ee	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0xffe0c40f	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0xffe3890f	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0xffe5bde3	clockevents_register_device
+diff --git a/debian.master/abi/4.4.0-111.134/amd64/generic.compiler b/debian.master/abi/4.4.0-111.134/amd64/generic.compiler
+new file mode 100644
+index 0000000..d1936f3
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/amd64/generic.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/amd64/generic.modules b/debian.master/abi/4.4.0-111.134/amd64/generic.modules
+new file mode 100644
+index 0000000..5ab41b1
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/amd64/generic.modules
+@@ -0,0 +1,4620 @@
++3c574_cs
++3c589_cs
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_dw
++8250_fintek
++8250_mid
++8255
++8255_pci
++8390
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++BusLogic
++DAC960
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++abituguru
++abituguru3
++ablk_helper
++ac97_bus
++acard-ahci
++acecad
++acenic
++acer-wmi
++acerhdf
++acpi-als
++acpi_extlog
++acpi_ipmi
++acpi_pad
++acpi_power_meter
++acpi_thermal_rel
++acpiphp_ibm
++acquirewdt
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7170
++adv7175
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++advantechwdt
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++aes-x86_64
++aesni-intel
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++ah4
++ah6
++aha152x_cs
++ahci
++ahci_platform
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airo
++airo_cs
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++ali-ircc
++alienware-wmi
++alim1535_wdt
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am53c974
++ambassador
++amc6821
++amd
++amd-rng
++amd5536udc
++amd64_edac_mod
++amd76xrom
++amd8111e
++amd_freq_sensitivity
++amd_iommu_v2
++amdgpu
++amdkfd
++amilo-rfkill
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apanel
++apds9300
++apds9802als
++apds990x
++apds9960
++apple-gmux
++apple_bl
++appledisplay
++applesmc
++appletalk
++appletouch
++applicom
++aquantia
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_ps2
++arc_uart
++arcfb
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3935
++as5011
++asb100
++asc7621
++ascot2e
++asix
++ast
++asus-laptop
++asus-nb-wmi
++asus-wmi
++asus_atk0110
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atlas_btns
++atm
++atmel
++atmel_cs
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp
++atp870u
++atusb
++atxp1
++aty128fb
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avm_cs
++avma1_cs
++avmfritz
++ax25
++ax88179_178a
++axnet_cs
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1pci
++b1pcmcia
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcma
++bcma-hcd
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish-x86_64
++blowfish_common
++blowfish_generic
++bluecard_cs
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpck
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmsmac
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bt3c_cs
++bt819
++bt856
++bt866
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btuart_cs
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c2port-duramar2150
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia-aesni-avx-x86_64
++camellia-aesni-avx2
++camellia-x86_64
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5-avx-x86_64
++cast5_generic
++cast6-avx-x86_64
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_das16_cs
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc10001_adc
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++ccp
++ccp-crypto
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfag12864b
++cfag12864bfb
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20-x86_64
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipreg
++chnl_net
++chromeos_laptop
++chromeos_pstore
++ci_hdrc
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++ck804xrom
++classmate-laptop
++clip
++clk-cdce706
++clk-palmas
++clk-pwm
++clk-s2mps11
++clk-si5351
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cm4000_cs
++cm4040_cs
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmtp
++cnic
++cobalt
++cobra
++coda
++com20020
++com20020-pci
++com20020_cs
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_isadma
++comedi_parport
++comedi_pci
++comedi_pcmcia
++comedi_test
++comedi_usb
++comm
++compal-laptop
++configfs
++contec_pci_dio
++cordic
++core
++coretemp
++cosm_bus
++cosm_client
++cp210x
++cpcihp_generic
++cpcihp_zt5550
++cpia2
++cpsw_ale
++cpu-notifier-error-inject
++cpu5wdt
++cpuid
++cr_bllcd
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc32-pclmul
++crc7
++crc8
++crct10dif-pclmul
++cros_ec
++cros_ec_devs
++cros_ec_i2c
++cros_ec_keyb
++cros_ec_lpc
++cros_ec_spi
++crvml
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++csiostor
++ct82c710
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_cs
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++db9
++dc395x
++dca
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++dcdbas
++ddbridge
++de2104x
++de4x5
++decnet
++deflate
++defxx
++dell-laptop
++dell-led
++dell-rbtn
++dell-smm-hwmon
++dell-smo8800
++dell-wmi
++dell-wmi-aio
++dell_rbu
++denali
++denali_dt
++denali_pci
++des3_ede-x86_64
++des_generic
++designware_i2s
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9601
++dme1737
++dmfe
++dmi-sysfs
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++dp83848
++dp83867
++dpt_i2o
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dtl1_cs
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_wdt
++dwc3
++dwc3-pci
++dwmac-generic
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++e752x_edac
++earth-pt1
++earth-pt3
++eata
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++ec_bhf
++ec_sys
++echainiv
++echo
++edac_core
++edac_mce_amd
++edt-ft5x06
++eeepc-laptop
++eeepc-wmi
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efi-pstore
++efi_test
++efs
++ehset
++einj
++elan_i2c
++elo
++elsa_cs
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++empeg
++ems_pci
++ems_pcmcia
++ems_usb
++emu10k1-gp
++ena
++enc28j60
++enclosure
++encx24j600
++encx24j600-regmap
++ene_ir
++eni
++enic
++epat
++epia
++epic100
++eql
++esas2r
++esb2rom
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++eurotechwdt
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++ezusb
++f2fs
++f71805f
++f71808e_wdt
++f71882fg
++f75375s
++f81232
++fakelb
++fam15h_power
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_sys_fops
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdomain_cs
++fdp
++fdp_i2c
++fealnx
++ff-memless
++fintek-cir
++firedtv
++firestream
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fixed
++fjes
++fl512
++flexfb
++floppy
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fmvj18x_cs
++fnic
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fschmd
++fsl_lpuart
++ft6236
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu-laptop
++fujitsu-tablet
++fujitsu_ts
++g450_pll
++g760a
++g762
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcm
++gdmtty
++gdmulte
++gdmwm
++gdth
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++genwqe_card
++gf128mul
++gf2k
++gfs2
++ghash-clmulni-intel
++ghash-generic
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++glue_helper
++gluebi
++gma500_gfx
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-104-idio-16
++gpio-addr-flash
++gpio-adp5520
++gpio-adp5588
++gpio-amd8111
++gpio-amdpt
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-f7188x
++gpio-fan
++gpio-generic
++gpio-ich
++gpio-ir-recv
++gpio-it87
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-rdc321x
++gpio-regulator
++gpio-sch
++gpio-sch311x
++gpio-tps65912
++gpio-twl4030
++gpio-twl6040
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mouse
++gpio_tilt_polled
++gr_udc
++grace
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++gxt4500
++hackrf
++hamachi
++hampshire
++hangcheck-timer
++hanwang
++hci
++hci_uart
++hci_vhci
++hdaps
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hecubafb
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfi1
++hfs
++hfsplus
++hgafb
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-hyperv
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++hih6130
++hio
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi504_nand
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hopper
++horizon
++horus3a
++hostap
++hostap_cs
++hostap_pci
++hostap_plx
++hp-wireless
++hp-wmi
++hp100
++hp_accel
++hpfs
++hpilo
++hpsa
++hptiop
++hpwdt
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++htc-pasic3
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hv_balloon
++hv_netvsc
++hv_storvsc
++hv_utils
++hv_vmbus
++hwa-hc
++hwa-rc
++hwmon-vid
++hwpoison-inject
++hx8357
++hyperv-keyboard
++hyperv_fb
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd756-s4882
++i2c-amd8111
++i2c-cbus-gpio
++i2c-cros-ec-tunnel
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-emev2
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-ismt
++i2c-kempld
++i2c-matroxfb
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-pinctrl
++i2c-mux-reg
++i2c-nforce2
++i2c-nforce2-s4985
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-piix4
++i2c-robotfuzz-osif
++i2c-scmi
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i3000_edac
++i3200_edac
++i40e
++i40evf
++i5000_edac
++i5100_edac
++i5400_edac
++i5500_temp
++i5k_amb
++i6300esb
++i7300_edac
++i7300_idle
++i740fb
++i7core_edac
++i810
++i82092
++i82975x_edac
++i915
++i915_bpo
++iTCO_vendor_support
++iTCO_wdt
++ib700wdt
++ib_addr
++ib_cm
++ib_core
++ib_ipath
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_qib
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibm_rtl
++ibmaem
++ibmasm
++ibmasr
++ibmpex
++ichxrom
++icp_multi
++icplus
++ics932s401
++ideapad-laptop
++ideapad_slidebar
++idma64
++idmouse
++idt77252
++idt_gen2
++idtcps
++ie31200_edac
++ie6xx_wdt
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imm
++imon
++ims-pcu
++imx074
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int3400_thermal
++int3402_thermal
++int3403_thermal
++int340x_thermal_zone
++int51x1
++intel-hid
++intel-lpss
++intel-lpss-acpi
++intel-lpss-pci
++intel-rng
++intel-rst
++intel-smartconnect
++intel-vbtn
++intel_ips
++intel_menlow
++intel_oaktrail
++intel_pch_thermal
++intel_pmc_ipc
++intel_powerclamp
++intel_punit_ipc
++intel_qat
++intel_quark_i2c_gpio
++intel_rapl
++intel_soc_dts_iosf
++intel_soc_dts_thermal
++intel_telemetry_core
++intel_telemetry_debugfs
++intel_telemetry_pltdrv
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++intelfb
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioatdma
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipwireless
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++irlan
++irnet
++irqbypass
++irtty-sir
++isci
++iscsi_boot_sysfs
++iscsi_ibft
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it87
++it8712f_wdt
++it87_wdt
++it913x
++itd1000
++ite-cir
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++k10temp
++k8temp
++kafs
++kalmia
++kaweth
++kb3886_bl
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks0108
++ks0127
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kvm
++kvm-amd
++kvm-intel
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l440gx
++l4f00242t03
++l64781
++lan78xx
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-adp5520
++leds-bd2802
++leds-blinkm
++leds-clevo-mail
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-pwm
++leds-regulator
++leds-ss4200
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libahci_platform
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_cs
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++linux-bcm-knet
++linux-kernel-bde
++linux-user-bde
++liquidio
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++litelink-sir
++lkkbd
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lmc
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac80211
++mac80211_hwsim
++mac802154
++mac_hid
++macb
++machzwd
++macmodes
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++marvell
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77693
++max77693-haptic
++max77693_charger
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mce-inject
++mce_amd_inj
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++mdc800
++mdio
++mdio-bcm-unimac
++mdio-bitbang
++mdio-cavium
++mdio-gpio
++mdio-octeon
++mdio-thunder
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++mei
++mei-me
++mei-txe
++mei_phy
++memory-notifier-error-inject
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++metro-usb
++metronomefb
++meye
++mf6x4
++mga
++mic_bus
++mic_card
++mic_cosm
++mic_host
++mic_x100_dma
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microread_mei
++microtek
++mii
++minix
++mip6
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmc_block
++mmc_spi
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi-laptop
++msi-wmi
++msi001
++msi2500
++msp3400
++mspro_block
++msr
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtd_dataflash
++mtdblock
++mtdblock_ro
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-sd
++mtouch
++multipath
++multiq3
++musb_hdrc
++mv_u3d_core
++mv_udc
++mvmdio
++mvsas
++mvumi
++mwave
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxc4005
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxm-wmi
++mxser
++mxuport
++myri10ge
++n411
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nci
++nci_spi
++nci_uart
++ncpfs
++nct6683
++nct6775
++nct7802
++nct7904
++nd_blk
++nd_btt
++nd_pmem
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++nettel
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfit
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_daq_700
++ni_daq_dio24
++ni_labpc
++ni_labpc_common
++ni_labpc_cs
++ni_labpc_isadma
++ni_labpc_pci
++ni_mio_cs
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicpf
++nicstar
++nicvf
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nmclan_cs
++nosy
++notifier-error-inject
++nouveau
++nozomi
++ns558
++ns83820
++nsc-ircc
++ntb
++ntb_hw_amd
++ntb_hw_intel
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nuvoton-cir
++nv_tco
++nvidiafb
++nvme
++nvmem_core
++nvram
++nxp-nci
++nxp-nci_i2c
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_xilinx_wdt
++old_belkin-sir
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_cs
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p4-clockmod
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++padlock-aes
++padlock-sha
++palmas-pwrbutton
++palmas-regulator
++panasonic-laptop
++pandora_bl
++panel
++paride
++parkbd
++parport
++parport_ax88796
++parport_cs
++parport_pc
++parport_serial
++pata_acpi
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pcmcia
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sl82c105
++pata_triflex
++pata_via
++pc300too
++pc87360
++pc87413_wdt
++pc87427
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_udc
++pci
++pci-hyperv
++pci-stub
++pci200syn
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmcia
++pcmcia_core
++pcmcia_rsrc
++pcmciamtd
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcnet_cs
++pcrypt
++pcspkr
++pcwd_pci
++pcwd_usb
++pd
++pd6729
++pda_power
++pdc_adma
++peak_pci
++peak_pcmcia
++peak_usb
++pegasus
++penmount
++percpu_test
++pf
++pfuze100-regulator
++pg
++phantom
++phonet
++phram
++phy-bcm-kona-usb2
++phy-exynos-usb2
++phy-gpio-vbus-usb
++phy-isp1301
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-tahvo
++phy-tusb1210
++physmap
++pinctrl-broxton
++pinctrl-intel
++pinctrl-sunrisepoint
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl2303
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8941-wled
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pn533
++pn544
++pn544_i2c
++pn544_mei
++pn_pep
++poly1305-x86_64
++poly1305_generic
++port100
++powermate
++powr1220
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_core
++pps_parport
++pptp
++prism2_usb
++processor_thermal_device
++ps2mult
++psmouse
++psnap
++pt
++ptp
++pulsedlight-lidar-lite-v2
++punit_atom_debug
++pvpanic
++pvrusb2
++pwc
++pwm-beeper
++pwm-lp3943
++pwm-lpss
++pwm-lpss-pci
++pwm-lpss-platform
++pwm-pca9685
++pwm-regulator
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa27x_udc
++qat_dh895xcc
++qat_dh895xccvf
++qcaux
++qcom-spmi-iadc
++qcom-spmi-vadc
++qcom_spmi-regulator
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qlogic_cs
++qlogicfas408
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quatech_daqp_cs
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-bcm2048
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-shark
++radio-si476x
++radio-tea5764
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++ray_cs
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++reed_solomon
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio-scan
++rio500
++rionet
++rivafb
++rj54n1cb0c
++rmd128
++rmd160
++rmd256
++rmd320
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-bq32k
++rtc-bq4802
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-hid-sensor-time
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-msm6242
++rtc-mt6397
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-r9701
++rtc-rc5t583
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-twl
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7110
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7185
++saa7706h
++safe_serial
++salsa20-x86_64
++salsa20_generic
++samsung-keypad
++samsung-laptop
++samsung-q10
++samsung-sxgbe
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_sil
++sata_sil24
++sata_sis
++sata_svw
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sb1000
++sb_edac
++sbc60xxwdt
++sbc_epx_c3
++sbc_fitpc2_wdt
++sbc_gxx
++sbni
++sbp_target
++sbs
++sbs-battery
++sbshc
++sc1200wdt
++sc16is7xx
++sc92031
++sca3000
++scb2_flash
++sch311x_wdt
++sch5627
++sch5636
++sch56xx-common
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scif
++scif_bus
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++sdhci
++sdhci-acpi
++sdhci-pci
++sdhci-pltfm
++sdio_uart
++sdricoh_cs
++sedlbauer_cs
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial2002
++serial_cs
++serio_raw
++sermouse
++serpent-avx-x86_64
++serpent-avx2
++serpent-sse2-x86_64
++serpent_generic
++serport
++ses
++sfc
++sh_veu
++sha1-mb
++sha1-ssse3
++sha256-ssse3
++sha512-ssse3
++shark2
++shpchp
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sir-dev
++sis
++sis-agp
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skd
++skfp
++skge
++skx_edac
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++sl811_cs
++slcan
++slicoss
++slip
++slram
++sm501
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smc91c92_cs
++smipcie
++smm665
++smsc
++smsc-ircc2
++smsc37b787_wdt
++smsc47b397
++smsc47m1
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4117
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als300
++snd-als4000
++snd-asihpi
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt3328
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-compress
++snd-cs4281
++snd-cs46xx
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1938
++snd-es1968
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-ext-core
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel-sst-acpi
++snd-intel-sst-core
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm
++snd-pcm-dmaengine
++snd-pcm-oss
++snd-pcsp
++snd-pcxhr
++snd-pdaudiocf
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-sb-common
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-core
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-dmic
++snd-soc-es8328
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-ssi
++snd-soc-gtm601
++snd-soc-imx-audmux
++snd-soc-max98090
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rl6231
++snd-soc-rl6347a
++snd-soc-rt286
++snd-soc-rt5631
++snd-soc-rt5640
++snd-soc-rt5645
++snd-soc-rt5660
++snd-soc-rt5670
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-skl
++snd-soc-skl-ipc
++snd-soc-skl_rt286
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sst-acpi
++snd-soc-sst-baytrail-pcm
++snd-soc-sst-broadwell
++snd-soc-sst-byt-max98090-mach
++snd-soc-sst-byt-rt5640-mach
++snd-soc-sst-bytcr-rt5640
++snd-soc-sst-bytcr-rt5660
++snd-soc-sst-cht-bsw-max98090_ti
++snd-soc-sst-cht-bsw-rt5645
++snd-soc-sst-cht-bsw-rt5672
++snd-soc-sst-dsp
++snd-soc-sst-haswell
++snd-soc-sst-haswell-pcm
++snd-soc-sst-ipc
++snd-soc-sst-mfld-platform
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-xtfpga-i2s
++snd-sonicvibes
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-us122l
++snd-usb-usx2y
++snd-usb-variax
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-vxpocket
++snd-ymfpci
++snic
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++softdog
++softing
++softing_cs
++solo6x10
++solos-pci
++sony-btf-mpx
++sony-laptop
++soundcore
++sp2
++sp5100_tco
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_dectlk
++speakup_dummy
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++spectrum_cs
++speedfax
++speedstep-lib
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi-lm70llp
++spi-nor
++spi-oc-tiny
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tle62x0
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spl
++splat
++spmi
++sr9700
++sr9800
++ssb
++ssb-hcd
++ssfdc
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++sstfb
++ssu100
++st
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++surfacepro3_button
++svgalib
++sx8
++sx8654
++sx9500
++sym53c500_cs
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink
++synclink_cs
++synclink_gt
++synclinkmp
++syscopyarea
++sysfillrect
++sysimgblt
++sysv
++t1pci
++t5403
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tehuti
++tekram-sir
++teles_cs
++teranetics
++test-hexdump
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tg3
++tgr192
++thinkpad_acpi
++thmc50
++thunder_bgx
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timeriomem-rng
++tipc
++tlan
++tlclk
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmem
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++topstar-laptop
++torture
++toshiba-wmi
++toshiba_acpi
++toshiba_bluetooth
++toshiba_haps
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_atmel
++tpm_crb
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_infineon
++tpm_nsc
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tsi568
++tsi57x
++tsi721_mport
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl-regulator
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish-avx-x86_64
++twofish-x86_64
++twofish-x86_64-3way
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++uPD98402
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udf
++udl
++udlfb
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++usnic_verbs
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vboxguest
++vboxsf
++vboxvideo
++vcan
++vcnl4000
++ven_rsi_91x
++ven_rsi_sdio
++ven_rsi_usb
++ves1820
++ves1x93
++veth
++vfio
++vfio-pci
++vfio_iommu_type1
++vfio_virqfd
++vga16fb
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-camera
++via-cputemp
++via-ircc
++via-rhine
++via-rng
++via-sdmmc
++via-velocity
++via686a
++via_wdt
++viafb
++video
++videobuf-core
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videocodec
++videodev
++vim2m
++viperboard
++viperboard_adc
++virt-dma
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_scsi
++virtual
++visor
++visorbus
++visorhba
++visorinput
++visornic
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_ca91cx42
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmlfb
++vmw_balloon
++vmw_pvscsi
++vmw_vmci
++vmw_vsock_vmci_transport
++vmwgfx
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vpx3220
++vrf
++vringh
++vsock
++vsxxxaa
++vt1211
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83627ehf
++w83627hf
++w83627hf_wdt
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83877f_wdt
++w83977af_ir
++w83977f_wdt
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++wafer5823wdt
++walkera0701
++wanxl
++warrior
++wbsd
++wcn36xx
++wd719x
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++winbond-cir
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wl3501_cs
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wmi
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x38_edac
++x86_pkg_temp_thermal
++x_tables
++xc4000
++xc5000
++xcbc
++xen-blkback
++xen-evtchn
++xen-fbfront
++xen-gntalloc
++xen-gntdev
++xen-kbdfront
++xen-netback
++xen-pciback
++xen-pcifront
++xen-privcmd
++xen-scsiback
++xen-scsifront
++xen-tpmfront
++xen_wdt
++xenfs
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xhci-plat-hcd
++xillybus_core
++xillybus_pcie
++xirc2ps_cs
++xircom_cb
++xor
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yenta_socket
++yurex
++zatm
++zaurus
++zavl
++zcommon
++zd1201
++zd1211rw
++zforce_ts
++zfs
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++znvpair
++zpios
++zr36016
++zr36050
++zr36060
++zr36067
++zr364xx
++zram
++zunicode
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/amd64/lowlatency b/debian.master/abi/4.4.0-111.134/amd64/lowlatency
+new file mode 100644
+index 0000000..a0f4957
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/amd64/lowlatency
+@@ -0,0 +1,18897 @@
++EXPORT_SYMBOL arch/x86/kvm/kvm 0x253dbf8a	kvm_cpu_has_pending_timer
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0x73892a61	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/acpi/nfit 0xa7e9a159	to_nfit_uuid
++EXPORT_SYMBOL drivers/acpi/video 0x6de7f7ff	acpi_video_get_backlight_type
++EXPORT_SYMBOL drivers/acpi/video 0x7a45377b	acpi_video_unregister
++EXPORT_SYMBOL drivers/acpi/video 0x8826c13b	acpi_video_register
++EXPORT_SYMBOL drivers/acpi/video 0xa56e83c7	acpi_video_get_edid
++EXPORT_SYMBOL drivers/acpi/video 0xe92ca535	acpi_video_set_dmi_backlight_type
++EXPORT_SYMBOL drivers/atm/suni 0x5a8ee5d6	suni_init
++EXPORT_SYMBOL drivers/atm/uPD98402 0x3ca73fc7	uPD98402_init
++EXPORT_SYMBOL drivers/bcma/bcma 0xa35eb9a0	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/bcma/bcma 0xd4cfd049	bcma_core_irq
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x254a39c1	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0x403b3a12	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x4267110a	pi_register_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0x445abb00	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x49001b27	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0x4ae081f3	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0x5496c40f	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x55ec42f8	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x5a44b9c4	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0x5bd944c7	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0x5ecb4d0b	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x63a24078	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x662d51bd	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xb21ba07d	pi_unregister_driver
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0x47c06e4a	btbcm_patchram
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x0318c77a	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x13816d72	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4e039e81	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xcc460dfb	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcca77ec	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/nvram 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x17ff2c1d	__nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x2adec1e0	__nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x7da28f12	nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL drivers/char/nvram 0xa8813189	__nvram_write_byte
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x0b2ebd23	st33zp24_pm_suspend
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xae622848	st33zp24_remove
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xc4e3ae29	st33zp24_pm_resume
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xffeb2338	st33zp24_probe
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x2798856e	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x5ab1ede0	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xc01c6763	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x0a015800	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x6109c91f	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x8c81a6bd	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xc51c659a	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xc8c491a3	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xe2af5d34	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/edac/edac_core 0x3ba20b7f	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04d0f641	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0f7d6af8	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x1704bbc8	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x25e694df	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2ea504e4	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x36f92e50	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3ead6280	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x43b5b822	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4b277058	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4f79cae2	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x605680cc	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x60ef8c0e	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x645b715f	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x66c76c92	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x688d1056	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x71c78c4d	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x75b8dcb9	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x83019afa	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8d018229	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x921b2410	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9a540094	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9abf52d4	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa304ff3a	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xbb08b491	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd25bd20b	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xe17ff243	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xec95e8a5	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xfb96bfd3	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xfd6ca1b9	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firmware/dcdbas 0xa75079d6	dcdbas_smi_request
++EXPORT_SYMBOL drivers/fmc/fmc 0x0f1d76fe	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x17432df4	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x18367e17	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x2a256ea8	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0x3491a125	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0x5fc1d447	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0x63e9b49e	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x716ba0b2	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x827ae2e3	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xb1c7cbce	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xce0761d8	fmc_driver_register
++EXPORT_SYMBOL drivers/gpu/drm/amd/amdkfd/amdkfd 0xf71b4088	kgd2kfd_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x00c05a11	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x01ff42ce	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x022b9ae0	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0273729e	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02740511	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02cc2423	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x058d1309	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x05c65552	drm_agp_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0622ba24	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06395a22	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06457fff	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0677584b	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06799fc2	drm_legacy_addbufs_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06f98e84	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0722e09f	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x07825abf	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a2b6497	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a5321fe	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0aa079f4	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0b4b521c	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ba17e5d	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0cfd958e	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0d7e6f42	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0e1fbf05	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f02d4a4	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f0ce6dd	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f7f4748	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x10d19d0e	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13d62de0	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x157038a7	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1581bafd	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x15d83e5d	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x15dc0d4d	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x18b9e9a8	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x19417c02	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194588b5	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1949a36a	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x196906f8	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a0b0c43	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1b4a2ca9	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1ee9c241	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1f58e2b8	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2013e396	drm_agp_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2125cebf	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2163b449	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x21a4b7b1	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x21f40626	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x24f8a100	drm_agp_acquire
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x25c15c8c	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2644e70c	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x277632db	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x27f9fba8	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x281e1d96	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x28c07738	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2a418c87	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2aa50f55	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2bead4e6	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c4847f7	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d23297d	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x31e8ecba	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3204b3bd	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3218e738	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x342b3b4f	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x361b32b2	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x36a3f25d	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x394233bb	drm_agp_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x39db5a22	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3a7ec2a3	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3a951859	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d52f0b8	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d6e8769	drm_agp_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3df78744	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3e05bf1b	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ea3be3a	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x40e1bec3	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x40ef0dcc	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x41c256b0	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x42dfbc55	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x436677fe	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x439c58b9	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43cafe17	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43e92f75	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x447657b3	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x45581f84	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x45959909	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x45b1f2fe	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x46299af5	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4787736d	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48f75e03	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490172f1	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4923ca26	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x49fafc2d	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4bb4891d	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d2359d2	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4e3b8ffe	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4e4374cf	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4f2d3036	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4fbc4507	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x512b089b	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x53796367	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x552ea322	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x56331600	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x586e5d92	drm_agp_info
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59d3b6d4	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a72e8f0	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5b1ac89d	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5b82ad9e	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5c84d6b4	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d663584	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d7318dc	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6020f61b	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x608b0974	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x638d8c4d	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6477d9b4	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x650fbeb8	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x657d2881	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67297c0a	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6789feef	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x694e2868	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6b58e24e	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6de8b10c	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6df51dc2	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6eb6278d	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6eff3f70	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f219021	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7119e39b	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x748ec840	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74bcd755	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x75d3b334	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x76752eae	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x76758778	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x77548619	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x794af188	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x798fd372	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x79cd5cda	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x79d92c7b	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b410983	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7cfbfc16	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7d4cc1e2	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7f3999ae	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x81c07c12	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82e09ece	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8357cd64	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x843ea63e	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x84b20349	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x84e15657	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x85f12c25	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x862d2ee2	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8652d99a	drm_agp_bind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871b8bc6	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x874f9075	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x87eaad5d	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a588d6d	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ade3309	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8b1f571a	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d30a6c0	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d79df85	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de5c57f	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8df94a3f	drm_agp_bind_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e87f2cf	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ebb79d2	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f45f5a9	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f47c46e	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x904f9f2d	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x90fc0957	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x911bb482	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x916443c9	drm_compat_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x925d4d24	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9282e4b5	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x94bc0ca2	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x96a15ff1	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9772c6ac	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97f4be59	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9898e95b	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9938708f	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a45d8c4	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9d3b74c2	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9e78fba8	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9fc589cc	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1365525	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa2875976	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa395878e	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4f15dc9	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa5b3f8e3	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa77f8467	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaa1f98f5	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaae21d25	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xabbb48fb	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xacb5c941	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xacca57a7	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad33f0d7	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad7155c1	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae088517	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaf613444	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaf9a3748	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaffeb2a9	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb210bb9c	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb2462a8d	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb34de41f	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5540008	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5c1aadd	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb637b331	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb7880b3c	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb84c1b19	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb88253b6	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xba9f4ef7	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbdeb32b1	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe409342	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc146757a	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc1523d0b	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2b89ea7	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2dbcf60	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc31ed25b	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc3f3443b	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc514c7a1	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc5ca6367	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc6b48007	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc860c0ac	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc8b952a8	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc94697f5	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc9a466ca	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca16530d	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb79079a	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcbc8e2ba	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcbd55ac4	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcbda0e1e	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcce0e2e9	drm_agp_unbind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd100ecd	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd406db9	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd478c86	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf6eb399	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf940c81	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd1d4ff50	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2942279	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3be6ab4	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd44b234d	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd6d89710	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd734f6cf	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd7af0417	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xda156c9f	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xda3c3bf9	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbea915e	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbf61c39	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc908053	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd1e4aa9	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd773ab4	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xddb86234	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xde334dc0	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe0781161	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe0a4a153	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe3514284	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe3f73a4a	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe522d4ba	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe5b8a75a	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6c42bc4	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6f6994f	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe90a0395	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe9f2de47	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea111c3c	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeba71e59	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xec38c4b8	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeca25a50	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed71d6a9	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed7c4a91	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed992dd6	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef3fb638	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef9c6a2e	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0f1dbba	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf11bb2fc	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf25a07e6	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf47b97da	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf64aa778	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf6f59f8a	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf81e44ba	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9f0d96e	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfa121d3d	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb296380	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb325563	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb49d36b	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbf34871	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd0ebdb5	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd33b607	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfdc4efd7	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff4f70b3	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff74c00a	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x00e6b1f2	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x02c564e3	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x02d8cda5	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x034e3ffe	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x036b847e	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x04f671f1	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x054decfc	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x06315b6d	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x07254c74	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0c1f108a	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x119bb909	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x12b0bec4	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x12caf0dc	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x130b4aa2	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x141d91f3	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163044f6	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x17910222	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x17ce2057	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x190eea8c	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1914ddb7	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1b6596a6	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1dc7727f	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1e66639f	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x213a36bd	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x21a6451e	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x21c4f036	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x237e2d9f	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x24d9a4a3	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x25b78736	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2a889e15	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2aa2550f	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2daec5f4	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2dff8175	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x339d5f37	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x33f9f24c	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3638c2c1	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x374d160c	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x37adfea1	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3b31eb9e	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3b9eea4e	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3d70a865	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3fc70371	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x404f0569	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x44231d9f	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x44e8b5ef	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x455488a7	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x47110d6a	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4e5c849f	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4f138ca3	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x51e31fad	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5320118b	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x55a25a50	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x55e12bdf	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x569988eb	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5873cda9	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5984e235	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5a6e6f6c	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5b631bbe	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5cb4ed87	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5db6ad72	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x602fa8d9	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x61433b12	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x61bad27c	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x633df5d1	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x63c6dbb8	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6458b7a8	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x64798c78	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x67c3b171	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x68f84ea6	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6a305e5c	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6b13fff8	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6ef697fe	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x736fadf3	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x759b15b0	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x75d5f570	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x77e7d6c8	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x78289593	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x78d5ae78	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7a517c40	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7f4827f0	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x80117697	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x810aee01	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x819bcaca	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x81bf9c24	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8a62d2dd	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8aa608f8	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x92e0b9b9	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x937bc17c	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x93ac7fe6	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x94ed6c56	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x95461544	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x962a51a0	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x974eb7cc	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9b0e4556	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9ef8f7f0	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9f7ebda2	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9fd73729	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa1dfd76d	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa599717e	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa64681cf	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8ed1cf8	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaa9d73f2	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaae84839	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaafa6ae1	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab6d38db	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xabd3c4e7	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xae603c6e	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb1927085	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb2e1ee36	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb3d10936	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb3d922ac	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb8443a69	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbcaa3be2	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbf09f2a6	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbf854327	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc0f64690	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc19cfc71	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc85f57cc	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc89bfebd	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xccc7ec7c	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xce9d5e6a	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcf63da9e	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd2850c2a	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd2fee719	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd3e9eecc	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd4489bfa	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd9521509	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdbc6103c	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdc7a506c	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe123189e	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe5f74c65	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe7b31900	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xecedb4fa	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeda2f866	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xee37ee75	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xefda794c	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf0a4b927	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf0e7eadc	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf3421507	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf671a1b9	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfd19b019	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfd4d14bb	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0728fce6	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x09dd6014	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0bab7f47	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x113b333c	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1940e4cd	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1c540c90	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x203c6968	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x22ec80fe	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x24765c33	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2947383a	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x297e8dd9	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b677ad2	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x30648c80	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3082916b	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x316e9f8e	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x356d1b0f	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3e84fdfb	ttm_agp_tt_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4207fd41	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4559f925	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x46fb8572	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x479a4062	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4c322012	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4dbc67c2	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4e8dd264	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4ef50856	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x56447ef3	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x564e1aee	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6052860c	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x623d1fc6	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6366432f	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x68410754	ttm_prime_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6c8dc6bf	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6e875de9	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6ffba21d	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x71760080	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7378a00c	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x762bd848	ttm_agp_tt_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x78a90bef	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7c57012b	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7cdcf184	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x836d8fd0	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8bac541a	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8bafd632	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x946d9ea3	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9dd23bfd	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xab0bdcf5	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xadd015f8	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb579eac1	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xba9d102f	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbaa01a47	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbbb652cf	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc397a11b	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc4d4618d	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc63102fd	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc9834fcf	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce19ea2a	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf49f835	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcfe5f8d1	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd144eac3	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd6610063	ttm_agp_tt_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd779bfab	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd7bd4f0e	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdf55a6ad	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xeb68a735	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf08e0dcf	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf37eda13	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf48188e4	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf7d5dd1f	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfb5dd460	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0xa73e8aab	vmbus_sendpacket
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0xbd9d6482	vmbus_recvpacket
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0xddb277c9	vmbus_sendpacket_ctl
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0e2a6864	sch56xx_read_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0f5877d4	sch56xx_read_virtual_reg16
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x34257f35	sch56xx_watchdog_unregister
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xe5022f95	sch56xx_read_virtual_reg12
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xed1d2a08	sch56xx_write_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xef315a1d	sch56xx_watchdog_register
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x114b42c7	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x3a347fba	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x59e1f217	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x6d15ac21	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0xeed31e6c	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0x32bd8c79	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x1221116b	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x1b610c86	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x1bd95852	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x33e61336	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x4b04aa8e	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x55036f40	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x561dc5c6	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x6aabad00	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x99233583	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xa5aea588	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbca75634	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xcdc24f28	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xcffd9f03	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xd9643787	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xf13b687a	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xf5401961	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x5d413e3c	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0xd6fe207b	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x2fbe0a10	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x7397fae8	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x1b8d92e9	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x29ba4937	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x8879b510	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xfe353a10	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x266be5b6	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x4125e3c6	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xa04b0f22	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc7dd36fb	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xd8f3bb0c	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xe7152334	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x5b070896	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x780833da	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xde7f0810	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xe7c51f7d	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x1f2f0e7e	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x5fd43a99	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x700711bc	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x768388b3	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x7b0404d1	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xa5a443cf	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xa9e6c68f	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xde4c3693	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xec244adb	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x258c08dc	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x4b909089	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x9609d9ad	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x9ff9c218	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xb143e16e	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x60232ffd	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x8b044e9b	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xe16c7a46	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x0ebc3e0d	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x2aa3a7b4	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4828c4bf	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x51571580	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x5dc8a600	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6bdbb2c6	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x7436242d	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x768cf7fd	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x77785c3f	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x7b432026	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x8478cbdb	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x866c0a6e	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x971c84c5	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x9d8ced6e	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xcd713d7a	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf0b05bfb	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf2900ab2	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x885f99fd	st_sensors_match_acpi_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xc5384a69	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0xbf527fe0	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x150e51f5	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0xa8e35a86	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0xf37a6cc2	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x12fce446	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xbaf519c9	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/industrialio 0x025e854a	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0x064e69f4	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0x14d4d299	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x1deabe99	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x308a43bc	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x33698391	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0x3d1e0b15	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0x7b5addf6	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x9d5c563a	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x9f77cb7b	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0xa50aa3c7	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xae802924	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xb4117b1b	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0xc2d40d3c	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0xd67db27e	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0xde54f89f	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xfb5e0c41	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x3b635648	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x73f6b978	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x3c66efaa	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x531e7e5d	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0xbdd85dfb	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x8b18bb97	st_press_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0xd3c1d0c6	st_press_common_probe
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1edc4064	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x81cb1f37	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x8a7f2f7a	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x8f6152f7	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x9d9cabc5	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xa2c039eb	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x07b3cae4	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x17ae73ba	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1e9bf6fd	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x24ec9b77	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x33eabada	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x44c66540	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x5c025ce9	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x7f16e23f	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x8ac7eefd	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xae7896ac	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xb4e9f3d2	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xc0067d67	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xc4731fd7	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xccb3e069	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd69ef88c	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xe4351ebb	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xef7202ec	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xfb410d37	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x004f0006	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x01f7b989	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x05992298	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x05d6b050	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0741840f	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0a89d2a8	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0dbe3a63	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0dc8d01d	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0e066965	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x10a4feea	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x161763e8	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1a958973	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1d5205f1	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x22f3cf93	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2395b86f	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x242fdee9	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2644aa67	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2e1edb59	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2f76215a	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3002165d	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x30ce30e3	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x39020935	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3afa1b3a	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4222b3aa	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x422e4f4e	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x460510ae	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4994a60c	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4b57ce0e	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4b93fbfd	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4faa66fb	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x555c2f05	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5787bb6b	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x59b61f23	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5a28e7a0	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5f526519	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6884c8f9	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6aff8c43	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6dcc101d	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x71f49d96	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x783b4037	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7875dc98	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x80bb5b15	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8251ea94	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8374cf9d	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x86b992d8	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x890042b6	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8bb10036	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8c0583d0	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8d6428e0	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x94f707f9	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x970f0d78	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x99c84863	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9b9df26c	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9ba5d93a	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9c27c071	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9e4eee9f	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa38d1a2d	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa432baf6	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa822196b	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaa2ced41	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaa35bd61	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xac8ea35b	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb6678d23	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93761c9	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbb277c37	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbd7a437a	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc08ff804	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc143b361	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc6772e8c	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc6c5e93e	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc70b8e1b	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xca28ed21	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcb4084a1	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcb68729e	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xce746cb8	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcec18a2a	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd17b4191	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd2a84106	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd775fa0a	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xecf09ca3	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf40fba36	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf5577c47	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf61f1013	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf90637c3	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfb32ea09	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x07eaa171	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x0ce17af5	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x17b608eb	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x18bcbb6e	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x21f6d071	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x257860a9	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x286de3c7	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x37462a7a	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x8b5a88ea	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xa2d6c82e	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xa61baaa7	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xaf0dbe5f	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xe0a86a9e	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x05f51c4a	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x0e401710	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x287d1e73	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x51427021	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x9a65f041	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xa59dff5c	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xb25629e9	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xb67f27a4	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xdba22b82	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf23dfdd7	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xfda7d463	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x0217ca87	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x75578784	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x2e532149	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x3a0e0208	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x4e365787	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5260aee8	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x56f67f78	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5cb8648f	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x69586590	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x7bedf905	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99b5bb69	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xbe5ba0b5	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xbefeb831	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xcb891797	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd0a7d7f3	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xe8b24155	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xfece8aeb	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x0311efc8	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x269ae3ab	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x2f7abeb1	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x32fdd36f	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x35f9d310	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3689d353	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x38ee070a	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3961f687	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x512f8065	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x52b17565	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x55ecee32	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5b323afb	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x6cb40e83	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x6eba0bae	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7b301ea0	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x81f422d8	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x8e340969	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa0c9f9e0	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xbb22ab7e	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xe18e1575	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xe249553c	rdma_create_id
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x300b0a06	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x57ce58a9	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x76827be4	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xb30476e9	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xb4d7d08b	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xb6e63aab	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xbe9d7ed3	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xecf8bd5a	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xf9b89130	gameport_set_phys
++EXPORT_SYMBOL drivers/input/input-polldev 0x31c24ee0	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x42d3c26b	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x928faeb3	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xb4642c5a	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xeb866ac1	input_register_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0xefbdd52e	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x4f9bccb9	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xaa846a5c	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xf5d8a2be	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xb0bc60f6	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x11e785fb	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x34eb19eb	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x4b23a3d9	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x6881e19f	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x794bfa0e	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x7c8eadc3	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x3e0c65d0	ad7879_pm_ops
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x7efc04d0	ad7879_probe
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x2432991d	amd_iommu_init_device
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x7afef95c	amd_iommu_set_invalid_ppr_cb
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x9296bb23	amd_iommu_bind_pasid
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x950173e3	amd_iommu_free_device
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0xf4bba096	amd_iommu_set_invalidate_ctx_cb
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0xf4d856d4	amd_iommu_unbind_pasid
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x63653a15	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6e76c78e	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7292ab34	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x72a25a72	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x744a7cab	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x79ca9ea9	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x822e1ac2	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8c83755e	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8e3e6b79	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xca4c9625	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe71fa3e3	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xf0681caf	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xfd552f7a	capi_message2str
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x05f59c3e	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x08bbaf77	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x262c7ed4	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x36d4f63a	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x3d9fb144	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x49bd73cf	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x62de4a6c	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x8636ad1a	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9f4fb45f	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xa2038988	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xc325b9ca	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xca598386	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xd2dde5a1	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xe189151d	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa6fa20b	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x2c6dbda4	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x2fa0ec09	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x3cdd5556	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x5fd5b638	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x6b72e77d	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x864b0767	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x8859ecc0	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x8c207290	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xead909ab	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0x29562993	b1pcmcia_delcard
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xaec3240e	b1pcmcia_addcard_m1
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xea620116	b1pcmcia_addcard_m2
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xf14bf8b1	b1pcmcia_addcard_b1
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x665e9c71	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x8b2418f8	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x953bee26	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xe6a95cd9	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x0441d3e4	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x4337d002	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x473a0464	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x174a8c56	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x19e4604a	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x4475e642	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xe2c4ea6c	isac_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xec497eae	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x1b0f1cd7	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xd482c8c4	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xff95c68d	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x012100ad	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x02924640	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x355086e4	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3b029653	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3df5aa34	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3ecc9623	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x652a5ca4	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x657f3f33	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x67905925	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6910f021	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x79609402	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x873b9970	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xac611cf2	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb6c31ac8	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb77a21c8	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xbb72a995	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xcb35e5ee	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd46e4738	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xdb54c157	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe2151a88	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe62e3728	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe86ad54b	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xfa183696	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x1f529ce8	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x440b4830	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x44a37d62	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x5b59b856	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x60f0bd65	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7daccb73	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7f2a56c0	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x8833b0e8	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x8f8fc624	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x8f9cb905	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x94126895	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x9aea0422	closure_put
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xa3c5c702	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca5df778	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xce47a6d9	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd2813054	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd97c32a1	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xdf892351	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xec6f33d0	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/dm-bufio 0x268682d2	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-log 0x92c6404a	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0xacc5755a	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0xb733f338	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0xea021a7b	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x25e215aa	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xb8386883	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xbb6663db	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xd2e703eb	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xe36bc328	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xe9d409d8	dm_snap_cow
++EXPORT_SYMBOL drivers/md/raid456 0x6e6667a3	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x0b9463b1	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x32d6ec6b	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x3ea05d74	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x4a967449	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x4ccfd6e9	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x84e357be	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x878bf668	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x992d62c5	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x9bf66f9c	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xb7c1f3b1	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xf658118e	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xf6ea7dbb	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xf9878b93	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x0a0daa1e	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x87897fbc	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xa066b7eb	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xae319202	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0xf8534971	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x38c689cb	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x9e18d38d	tveeprom_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x08c0ecf2	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0d3c856a	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x12f5425e	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x14fdf0ee	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1c053a2e	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3405dbfc	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x37ebb3d0	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3dd7e0af	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x447ac290	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4cf3b0d9	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4ec6c199	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x58e81ea8	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x59d758b0	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6057518b	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6560e532	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x69481245	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x69ec96ba	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x69fb82dd	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x746c98c7	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x808a9064	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x85e876a5	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x87dd6b71	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8bcbbafd	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x96ffa5f0	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xaae396eb	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb0ca2500	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb34d782d	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xbfda6501	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc2dfe52e	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc4e7cfc0	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc7a3740a	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xca7ca95c	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd6d6f856	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd8988b7b	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe1c71dee	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xeaf47cb5	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf1d78344	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfe467947	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0xb19bc23a	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0x3180a36b	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0x608ed33d	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x0474765b	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x2dec9bc1	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x347640eb	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x5f8e7830	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xb02422e6	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xd8b1409c	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xe3b0b270	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xe68f7c2a	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xef138b2f	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0x332ad577	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0x5260c735	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0xcca0ee25	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0xdd4e101f	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0x033922f9	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x361b0a30	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x98b0ad32	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0xaf28c04c	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0x09f9f9e1	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x2a10b2a8	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x5b11f07b	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0xbae130b9	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x655f914d	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x770da255	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x8f1cfbf9	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x0cacc5be	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x3fa1aeb5	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xbf52dc3f	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xcb54396b	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xebf3928c	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x00aa7841	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x00f137c1	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x11f1922a	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x6ab69a04	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x6bff5dab	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7146cb03	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7adf830f	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7ae15f5f	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x80984682	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xa1ee9aee	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xab48461c	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xc1f3160e	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xcb769885	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xdcf44c16	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xea67b589	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0x495336ae	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x00fef423	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x2d902a0e	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x411ab86b	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x550ccb73	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x79f6302f	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x9ebdba83	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x363b1ae9	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x5c9e8687	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x65b23197	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x8f93480a	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xc1668e3f	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x0548a612	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x4bfad68c	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x5987d0eb	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x8091f5a6	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x84e12f86	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xd2c17eba	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0x3c31909e	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0x262d4e77	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0xa7f0beb2	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0x12ae4d52	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0xf8740a28	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0x2093511a	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0x09128a12	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x18dc5502	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0xcd14bb37	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0xbce3afc2	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0x33ebe63d	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0x4a64746b	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0xfe5f708a	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0x044dd949	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0x8eb5f0aa	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0xfc9162c9	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x9e9e46d0	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0x04eada42	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0x1120153d	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x1c8d7e14	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x242eb926	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0x8cd34ab6	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x09c7d943	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x9934226d	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0x14646980	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0xd4a245f2	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0xf0bc45c1	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0x6f76b986	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0xb2df52af	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0x2f58ef3f	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0xcbebf8d9	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0x94861f0a	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0xe9b06a64	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x09f78c28	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0xd3be3a9c	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x03f1f1ff	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x405200d7	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x7f4a3dfb	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0x1d31dd47	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x621972c0	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0x91c1c47f	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0xc27406be	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0xc98698da	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x06fb5931	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0x7ed55d81	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0xf7a9da72	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0x8c959271	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x1126bab1	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0xb411a54a	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0xb7489d50	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0x91edce95	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0xd12d10ec	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x10916ed5	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0xa30d323c	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0x2fc2280c	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0x3e044e07	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0xc1d3fe50	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x80654f2f	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0xb470e747	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0xc4841ef8	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x486fab41	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0xa11aee79	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0x4d887bc1	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0xbd021a07	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0xa40beaf1	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0xcd31c4f0	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0xc7650d24	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0xf1458536	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0xde4e10d6	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0x667daae8	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0xca9a7d23	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x13911351	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x16fc9238	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x4c3cae1f	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x8cde1ff7	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xc0e72ae5	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xd49c198b	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xde9a744b	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xad042d5d	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xb33dff47	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd17b225e	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd8212def	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x04867ad1	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x292f6119	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x4fda2e1a	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x01e44e6f	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x64fbc83e	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x833dd449	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x882387ab	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x9fbe9176	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xc46e6865	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xdf689dab	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xdf861202	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xeaedf210	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0x0cf59497	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x076d9e47	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2b1df380	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x6196e21d	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x791ef10b	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xc6e56980	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x73d78ab3	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x026769b1	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x3f044424	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x448fe8f5	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x4c6987fb	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x91fa511b	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xd2557676	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xd457b13b	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x98f7f601	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xe9c0e193	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xa306e627	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xec810a94	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xfa65e65f	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xff4f5325	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x2d9b3d1a	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x3a4577d9	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x3e99a933	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x87a3fd59	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x95db3046	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xe498689f	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xf9cd9983	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x183ec162	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x24123956	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x25b6c75c	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x29aa6dee	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x33f5ef9f	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x46deeca3	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x54778dbe	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x625e3cb2	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x65ad6bff	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x65fd31f3	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x67707b77	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x751be0cc	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x9423e6cd	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xa2c8523a	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xa96d82ed	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc64f2b21	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xcd860a51	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xdc8a955d	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf70894fb	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xfe5e7fe0	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x29c7ae08	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x40992ffb	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x48d5dd8c	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x540b4256	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x60c8b9fc	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x7637857f	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x85ea3d70	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x940c09a9	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x98859328	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xafe24207	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xbb5f7631	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xbc14cd65	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xd1e6fa48	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xe43bc854	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xfabf411d	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xfc63234a	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xff2d0aaf	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x01adba95	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x151b5571	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1aa54170	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x4d128293	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x63e7762c	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x65b4b03a	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7307a273	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x8c258cea	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa509fd5b	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xba5a185e	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xdf3dd386	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xeeeba60b	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xd7e6747c	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x2346d1c8	videocodec_unregister
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x66d30627	videocodec_detach
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0xbb1baafc	videocodec_register
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0xf75dce9c	videocodec_attach
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x0d52a9d7	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x216df3b8	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x267e272e	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x73a0211d	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x8522b818	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xc5897fe7	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xf6d11695	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x01f76545	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x22ee9ee7	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x289d81f5	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x41b9632d	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x486c0399	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xe51b89a1	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xf20441a1	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x0fdbd063	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x24d02aa0	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x45f0f75d	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x5780ac4e	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xc724ea58	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xd544cb1d	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xd9e06165	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xff8f0272	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x7a685baa	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xb807990c	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0x8122e390	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0xe38d187a	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x4c11c3da	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xedb3535f	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xf9b5c2ea	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/max2165 0xca9104c8	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0xa289010e	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0xe8ef150f	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0xd0a7a22a	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0x2af81c5e	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0x940d071a	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x53571f74	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0x81b4764c	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x77d7683d	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0xef0464b2	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0xab172b26	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x45a865c1	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x80c49a1b	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x0591f80f	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x07ed413e	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x424734ca	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x7708e26f	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x7a35354a	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x84d307ac	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x944a5c20	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x9ed80598	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xf116b517	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x04d49cb6	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x0d08997d	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x5ccd7f71	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xd9272627	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xdf577477	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xe79b12b9	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xf6fa7f52	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xded74c8e	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x0029a6b3	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x1b05d962	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x47aa896c	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x5729ce15	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x5c58a569	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x83809a45	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xba30a9d0	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xccc181af	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xd5209a80	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xe578ad94	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xfe6b7ab4	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x0583ee48	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x8e22ae21	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x09a4ead2	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x5040b903	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x5622301b	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x958ac59c	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xd0781765	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xd4a9418a	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xd93af9c3	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xf9d71ddf	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xfdf77713	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x0f33af09	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x1fb08f1b	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x48decc1e	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x8d2c4dcb	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xa4edf63a	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xae7c5947	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xb4f59077	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xc9770cfe	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x5c76df9c	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xf30035a1	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xf3b7933e	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x0cae3b05	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x27693acf	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x852ee5b7	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xc92ac1d6	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xd6f44ebe	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x37f4e6e7	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x3ae2d458	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x4bac46e3	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x5da5121c	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xae2c82b0	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xe20cc0d5	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x1d3259b5	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x90bee7ee	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x23072925	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x237f7054	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x50ff30b2	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x6a01517b	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xd21dccb4	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xf9d636c9	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0xb94c398b	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x04ee859f	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0a752dc6	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0c2ebee8	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x12ea0bfa	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1428a17d	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b002a0d	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1bd379f8	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1cc04bff	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1ce615d3	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x23249aef	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x24947e82	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x24bfdf61	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x27ceae2c	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2c8899b9	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x33c66bd9	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3676f221	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bf27cc2	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x42449414	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x46eb55d6	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x476bd25e	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4cd9b3a3	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x512226e0	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x59648336	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5f01a00b	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x609bb6dc	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x664904ef	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x66cdaad7	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x67bde0e8	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6859db45	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6f250b4a	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x765e2b81	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7c3d8b00	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7f8c00c0	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x803ae0f2	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8450f404	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x859916ee	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x87a62ee2	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8a911dad	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8bbf020c	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8bd4bcdd	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8c914a1d	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8e5a85ca	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8f4b3e81	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x996c99f5	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x99b56ed4	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa00f3bd8	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa3035e85	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa9e2df63	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xac1d28dc	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xaf13d741	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb618dc2f	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbad035f7	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbde51706	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc33f1ee1	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd61b5553	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdf0a2b67	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe432e416	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe4f55f41	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe628ac1b	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe912b917	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeaebb1e9	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xec95c74f	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xedef177e	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf1c42a69	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf38b49c6	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf430f210	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf4791f0d	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf7230a71	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x0d5c824d	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x15e7bddb	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d1fcabf	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x64f56710	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6b59d0d8	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x862fc3e7	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x9251ae3d	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa66ad9ca	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xaaf3670f	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xbd0bc0c4	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xcfbb692b	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xd8085878	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xdc07e67e	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x0116f3eb	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x13d0d5ed	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x17ec3619	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1d56bafd	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x211f56f9	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x397c93c4	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4a60a9aa	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4c2e48c9	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4c79404c	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x53892c2b	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x5dec3ce1	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x68f055b1	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x698311ce	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x7e772aba	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x84cf189f	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x864bb2ce	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x89919b1a	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8be6261b	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8c187285	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x92cfce34	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xab1c106f	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb1f25e66	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc9712a3f	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc9a9182f	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdcfbc187	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdf440160	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe4683331	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf3b79f68	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xff50efe0	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x079e0831	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0ff52e8c	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x177e9640	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2e1c68fa	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x32d05a53	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x402391d2	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x511add79	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x52f61b32	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x56d35dbc	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x5b725c6f	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7087e56d	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x70ca8802	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7330113c	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x767d4ea6	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7f0ebdb3	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7fba83de	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x831050f6	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x927088e9	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9ce1c437	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb6032d7a	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xbb3d4d1b	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd2cae94e	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe0c14f83	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe12128f0	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xea1277c0	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf62b1ad5	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xfcd92246	mptscsih_abort
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x74508695	cros_ec_suspend
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xb89251f2	cros_ec_resume
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xb97e2230	cros_ec_register
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xf376ce36	cros_ec_remove
++EXPORT_SYMBOL drivers/mfd/dln2 0x4eae9d7d	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/dln2 0x5809efd6	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0xa6369c2f	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xb74273cd	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xd9ab9232	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x0fbc1392	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x26ecca58	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x2ab02f5f	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x306a1977	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x560c69e4	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xb5ead0ec	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xb9b98eb3	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xc9120204	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xdead27cd	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf51339d1	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xfbf5c8a5	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x0787fef2	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x77bec1ee	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x2fbdef2b	wm1811_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x7d71acbd	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x82e5569f	wm8994_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xb0dfed06	wm8958_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xb52c7a44	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xce4da626	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x13090222	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0x2e2c2109	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0x4094dd31	c2port_device_register
++EXPORT_SYMBOL drivers/misc/ioc4 0xe3c1bdac	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xf52e7864	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/mei/mei 0x5eddbbc9	__tracepoint_mei_reg_read
++EXPORT_SYMBOL drivers/misc/mei/mei 0xdd1b8214	__tracepoint_mei_reg_write
++EXPORT_SYMBOL drivers/misc/tifm_core 0x35272a2e	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x38b4922b	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x3f77ca8f	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x627eadd8	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0xa8c2ec46	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0xac889e31	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xb639d902	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xc0e390f5	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xc27d1025	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xcf4c6b01	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xe291baa3	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xf6844b71	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0xfce0411a	tifm_add_adapter
++EXPORT_SYMBOL drivers/mmc/card/mmc_block 0x28b21366	mmc_cleanup_queue
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x40447ee3	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x584a22e5	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x7a11fe77	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xcd378499	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xcf323972	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xd3249e27	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xd940dc13	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x0b94a01b	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x27eda614	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x5824e7b3	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xd0617ac2	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0xdf0ad4e7	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0x16505ca6	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0xd0244026	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x114dc366	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/mtd 0x83218739	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x5f3863f6	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xd3b37346	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x0e9b7379	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x298fae08	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x2f718d94	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x66b9af66	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xe93268c6	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xff2ce258	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x38cfb625	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xde082306	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xfd8a70b3	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x2d2b8978	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xffaa45b1	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x4b509b2e	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xb7757545	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xcab50476	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xdc8a1f38	onenand_default_bbt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x1b007f1f	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x33c4e4a9	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x4552c8b2	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x8eb1c762	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xab5a8d52	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xbde43596	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xcf2e5005	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xd643a746	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xf3fe9b1c	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xfdbd65c6	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x33ea5c3e	com20020_found
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x8ab26171	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xbc676556	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x122e1316	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x45adf62d	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x77d202ca	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x8aea3762	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x9174f2f1	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xb7f1accc	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xd10ff626	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xde9b036a	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xe2291284	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xe41d233b	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0xfac712db	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0xd4304d78	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x0d8be5fd	bgx_lmac_rx_tx_enable
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x285bde59	bgx_get_rx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x42264715	bgx_get_lmac_count
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x6dc1648d	bgx_get_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc397f585	bgx_lmac_internal_loopback
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc82be691	bgx_get_map
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xe48ca42a	bgx_get_tx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf101d1b2	bgx_get_lmac_link_state
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf9508980	bgx_set_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x1110b12d	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x2c8e1b2e	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x486a6f04	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x6348c407	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x641047e1	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x678348bd	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x7e8093a8	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x875be631	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x8beb9132	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x955ef9b5	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xad95903a	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xb4a204a1	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xcc9b0e26	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd11d0a62	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd192ffa7	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xfd3cfb53	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x03caf6ea	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x05e82631	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0822d158	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x09efdd40	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0dfcfe95	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1611f32b	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1a40f324	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3273364c	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x35d51ca9	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x36d2a977	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3d166c32	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x42b65d38	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x564e17cb	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x57707dfc	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x5bb8e80c	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66388b7b	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6d9b2a63	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7c29d91e	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9376847b	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9d78f63e	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xaed9933b	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb0715f6f	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb8903984	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc6033a5f	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc8678561	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd6ccab32	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xdaecb519	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe0884753	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe60701ca	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xec74af65	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xedad6185	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf3e5e595	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xfe333f6e	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xff6074db	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x05745fd9	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x3cec35de	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x40ebf745	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xb4bb075b	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xf21d2d3c	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xf5e4f4a6	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x4a571be9	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xff3341f5	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x02fea453	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0a6cae07	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b559029	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x193487ff	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1a3c50eb	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x20c18e28	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x26eb367f	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x33d3d2a0	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3544b9c1	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x38cd835b	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x39c7edcf	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4ae4bc44	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x537c41d9	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x57d9ef64	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5998d2c6	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5a196711	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x63e515c3	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6832ec34	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6c3ec01b	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7cc6c8ea	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8dfacf77	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8fb20be0	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x974b1e8a	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9f2bdc67	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9f658395	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa642a8da	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa7c3115f	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xadb7dc16	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xae6453bb	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb52ff99f	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbe357e8a	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd07dd050	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd5102a7c	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe5170bc3	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe6f94643	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf4dfca40	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfc095422	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xff8266d9	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x10a8c2d2	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1230ff83	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2db8d08f	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x409f2a36	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4d742747	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4de844ff	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4df6eed0	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5482d56a	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5bf58ec2	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5c3a1a26	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5dd96966	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x680c6599	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6a7ff154	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6cdb98e7	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6e099901	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x717886f9	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x729c3ea3	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x78b6455f	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x861109ae	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x88f5ccb5	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8d8b4582	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9425a0f7	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x967ccf86	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x97a2ee46	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9aa3c8dd	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9c0f1766	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9c10a0e0	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9c10e3f3	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9dfd222a	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa7173c05	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xad44c1c5	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc0aa2810	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc0da66e9	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcda7e3c4	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd04a8b06	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe1b55e56	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfaef3ebc	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfba86fd0	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x037028bb	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x1875feaf	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x2d07a992	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x4b6fa25a	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x64bb6db2	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xb6300fde	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xd45f67ff	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfe193303	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xfa265020	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x0fdbaf62	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x5d0b3609	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xc19d4b96	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xce8d7122	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xe2632151	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x02f6b52f	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x0cad3300	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x2c08e4cb	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x3206141c	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x3747a0cf	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x3fcadd52	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x4f50bcae	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x5c0f62c5	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x5d6fbc09	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xc51656d7	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x107b04aa	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0x4082c2fb	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0x47e9b44f	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0x5390bb23	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0x86a2d5cc	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0xaddab581	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0xd28b931c	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0xf1f3fab7	mii_link_ok
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x6b2caac3	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xbfd1eac1	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0x3e30ff4b	cavium_mdiobus_write
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0xd7c40f61	cavium_mdiobus_read
++EXPORT_SYMBOL drivers/net/phy/mdio-octeon 0x8a1d5c26	octeon_mdiobus_force_mod_depencency
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x0a28978c	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xc9c08f55	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xcd40d3a4	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/vitesse 0x53fb2518	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x2a771182	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x2e4ae6fd	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x722c1f53	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/sungem_phy 0xbafb1c01	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x37c519e9	team_mode_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x4c06c38d	team_options_register
++EXPORT_SYMBOL drivers/net/team/team 0x57a3404f	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0x78933bce	team_mode_register
++EXPORT_SYMBOL drivers/net/team/team 0x7a255e98	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0x89c55791	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0xb12543ab	team_options_unregister
++EXPORT_SYMBOL drivers/net/team/team 0xd3225d36	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x3ad0dc97	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x52c59a3c	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xdf30a084	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xeebc078f	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x18faa8ab	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x485e4f01	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x521ad61e	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x69dc2c3a	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x76bb773f	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xd5b41ccd	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xd843a841	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe191b019	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe62f5a44	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xfb818b3e	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xfbfce0e0	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0xdfb88a93	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/airo 0x272482fe	reset_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0x89c20601	init_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xe882ae8c	stop_airo_card
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x1c773150	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x24a6fee8	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x2b925f5a	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x2ef3e045	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4a470310	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x589110f6	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x5a2e3bc9	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x5bbf4c2f	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x6f33eed8	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x7d5c367b	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x83e2ca57	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x9978490f	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x0dc06dec	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x11041022	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x1dfbc9f7	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x6ad36f2d	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x7b5e0ebe	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x7cba0ba0	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x9190cfd6	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x925a1ece	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xa93b90b4	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xab01bff2	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xab3de418	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xac8abaed	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xb71cb8ba	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc873e37d	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xeb8d7294	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x280784a4	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x329e5e26	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x33e1b361	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x491b41d6	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4decfe00	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7ee29f95	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x8b8e76f9	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x9b2467db	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xb8784704	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc92e66e7	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xd774963b	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x08757352	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x0c572a8a	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x12123b3a	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x17476def	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1bd8a7a4	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d88d8f2	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x30bd74fa	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x393794f4	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x47a22344	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x4ed395a9	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x6004c244	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x64326d81	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7a187507	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x82601b2a	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x89a4a707	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9609c137	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9c0eb62d	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb1433c6d	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xc6280457	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xc70e2ef5	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xc71032b6	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe7dab5b6	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xefbc20f2	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x02f2462a	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x04d7d974	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0680b340	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x080e0cde	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x09dd0836	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0c496870	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0d2a54dc	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0db5e373	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1851c4d5	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1b9e96d2	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1cc720e6	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1e286ff7	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1ef8ea4e	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1f0737f0	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1f427c8a	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x20a24b48	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2279ee8d	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x237bbd93	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x25373b52	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x26d1afb2	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x26dae048	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2d35e9bf	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2ee79d39	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2ee90099	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2fd99c55	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x30099627	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x35ee12cd	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x374becb8	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3cc23a5d	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3ff9ec05	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x415f4425	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x41e6e9dd	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x46a75ca9	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x483fa279	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4c1dbb77	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4ca8ef3d	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x519fdd5b	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x52b76cf8	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x53971b91	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5693167c	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5830af13	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x58b651ef	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5c59b1c0	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x647274e4	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6b6578b8	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7078d6ef	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x727609cc	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x771a1fcc	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x782bc1a4	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x789047e0	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x78f54e2b	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7ae7534e	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x83f82969	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8a1593c3	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8dc7cc3f	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x907760f5	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x91af79c9	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9367b970	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x94006d43	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x94d48b17	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9683d229	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9c22b603	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9d4faa24	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9dc534ec	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9e7e0575	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa1db1ec5	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa2a514fa	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa30f4a03	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa455ce12	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa6036234	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xabcfc8d6	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xae6e5633	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaf3f6870	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb2c781e8	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb8cdfb13	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc0123344	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc21d2342	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc4dfcad2	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc6c18f9d	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcb14bdad	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcb2f2d6e	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcd163e5b	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcd40b95c	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcf7cd521	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd0a12c32	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd5eac5df	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd61fb426	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd66690e6	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd6c2bd4d	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd9b760f6	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd9f65e30	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xda48fb07	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdd2868e0	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe127cfb7	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe164c53e	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xeb747c7e	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xed44e7ff	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xedc52e02	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xeeb54198	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xeec3a482	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf0194cfc	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf22be37b	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf410472c	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf6cc6f6f	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfe1e9235	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x044751ab	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x31df6dd0	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x354e8857	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x038ab1dd	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x0f667bfa	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x391c78ab	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x48a552f8	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x56cdb074	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x6915e814	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x87474bbb	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x8a5963cf	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x8fd15f9e	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xb22e162b	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xcb57b0da	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd76aea40	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xf99455a9	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x11938aad	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1723ac32	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1ac0f037	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1fef7d8d	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x239eca61	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x4505bdb7	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x47240b8c	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x484ed78d	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x499f5331	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x50a5babf	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x545c49f3	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x5c2b3f49	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x6177ebee	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x61fba936	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x66cdb83e	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x69dbc35f	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x899a24ff	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xae2937f0	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb7f1b8b7	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xbed237f5	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xbfcef73e	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xcc988e68	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xce849a34	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd04bb4af	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd30bddfe	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xff56dd20	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x01b8ef3b	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x32efbe0b	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x358f43db	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x3609f6b9	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x409a1d76	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x535f2945	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x6a0b40ef	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x6cd43be4	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x757fbf9d	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x8504a535	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa9e9ae66	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb6a0b46d	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xc4444e73	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd0e414ca	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd2f1f48e	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xdcf32433	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xde7037ab	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xe363e29a	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xe82987f1	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xebe5fc83	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf754a510	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x005a85e2	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x013f677e	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x018f4661	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0543620d	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0a93bc82	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0d8c4f37	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x11c52f2f	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1502a5cc	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x15fb717b	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x18ec7002	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1933f84f	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1ef3405c	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x20e10b9b	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x21547f4b	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2633d51c	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2b3c8d27	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2b46a752	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2c379949	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3243271a	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x36c3ae56	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x407f1bbb	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x40d16bf7	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x43209a92	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x462f7dc4	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4d899a9c	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4e52edc4	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x51ee0495	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x54188a95	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5573d000	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x574aa088	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5c040100	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5d70bf96	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x649bf9b2	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6577ffa9	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x65eeca2a	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x663a1ac0	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x678417e8	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x67ac939a	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x68b85a2a	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x68c3b0af	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x69bcd38c	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6fed38f5	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x74832050	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x74973980	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x768c9941	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x77cdb06a	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x79d671e1	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7bd7cf60	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7fbbbe4a	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8201f6eb	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8262fb9c	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8366a5d6	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x869541a2	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8a582dcd	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8b97fe14	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8d1b797e	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9b266e05	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9b47b2a2	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9bf29743	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9e55ec79	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa04c93ce	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa06861fb	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa58182df	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa7cd2e82	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa83fb1e6	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa9ba45a0	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xaa5ea312	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xaec92927	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb1c1141e	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb200c016	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb2e7c86b	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb50e41f0	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb69526b5	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbcc6e21b	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbd260186	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbe1d8492	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc9ea9652	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcb44eefb	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcd4342f3	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xce56a930	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xce83deaf	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xceeb2b5b	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcf3844fb	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd23a36cd	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd3cc5f08	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd4220f56	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd55e72d2	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd574ca2b	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd6fac3f9	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe0183655	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe0b5fccf	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe8723cf5	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xea3f2149	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xeda89530	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xedeffac9	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf324a743	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf3f0f16c	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf4a92641	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x1b06ce78	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x2447a6ab	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x314a20a8	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x5e9c24ff	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x8c8ab242	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x9a1b1df9	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xdced6db1	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x00bc266c	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x02cf7fcf	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x09af522e	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x6777dc36	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x747537b4	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x91450e3b	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x9c1d3d0d	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa776bf4d	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xc2ac4a7e	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xcdf029f7	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xd3a8db61	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xdd6c1239	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xe3019590	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xed6f033e	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf3fee895	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf49d14a1	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf79d0846	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0x008b9c2b	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0f795e0c	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x11595a4a	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x137b4001	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x177f7f61	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x18c5f96c	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x21fb222b	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x237d4310	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2c047e16	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x41e76efe	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x43c1fa62	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x54133ca1	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x559a9137	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5c29ba06	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5f90c116	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x61cfc6e2	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6ef90295	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7c10f5b4	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7c7ad937	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7eca5d19	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8a5c7106	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x93e2f0d4	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x97393caf	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xae53c5bf	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb196cb15	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb497e7f0	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xbbf456e2	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xbdf0686b	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc7f92b4f	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xcc571d38	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd0cac57a	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd0dd3f58	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd3e0ba47	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd47e2693	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd4b5f5dd	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd797af26	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdcec089d	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdd8efb5d	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe29d75a0	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xeb02dece	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf1a954d5	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf8f0273b	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x23717b6c	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x5abe7a60	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x9535ad7e	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xb83ebf26	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x1176dc62	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x9ee041ea	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xd64e6775	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xe005027c	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0fda996b	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x254d41b1	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x25fa23c9	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x29252d39	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x29dc0d74	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5a15f303	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6381b40a	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x7ddf983a	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x7fad1ce2	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x88ce55cb	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x898ba440	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8c263614	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8fd22b82	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9065ca7e	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9559d411	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x97201501	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x99537b11	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9f7cd381	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9f8c536a	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa4a06f9b	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa7d4ca5f	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xaae07126	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xaeaf12f8	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb531fa53	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb81d3c9a	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc0c1db7a	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc70c552e	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc79fc2d9	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xbe2c8c11	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xc24c8c12	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xe8a4cabc	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xed60cde0	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x0372f8f8	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x2e953bd4	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xe235c6df	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x56a41cd9	microread_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0xf4ab9e25	microread_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x4a6c810b	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xf3718795	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xf7ced4a0	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x96a2c83e	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0xc307e744	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x140de69d	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x89395690	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xe73fefc6	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x4c382b31	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x4c7fd24f	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x523f1229	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x549a868e	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x6b9d1193	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x8e9d7f2f	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x8eeaae1a	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x93a2ad91	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x95710b8a	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xf199b025	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xf92ce329	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x0237bf8b	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x066f330e	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x1a155f8a	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3010dca3	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x367ec622	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x36fc8f8c	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x47a86aa6	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x55560ad2	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x5754fd07	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x6c94b1d9	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x8241cccc	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x9e0e3cc3	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x9ee6e100	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xa19fe724	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xb1f46d2e	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xb2ec27a9	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xc6fd4a29	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xe6ebe063	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/ntb/ntb 0x013aa9d5	ntb_link_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x28ad5ee1	__ntb_register_client
++EXPORT_SYMBOL drivers/ntb/ntb 0x340d44a2	ntb_set_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x90646885	ntb_clear_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x91353a8e	ntb_unregister_device
++EXPORT_SYMBOL drivers/ntb/ntb 0x9f4101d0	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xac2986dc	ntb_register_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xecefe114	ntb_db_event
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x09a1ccfe	nvdimm_namespace_attach_btt
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x356e8fc1	nvdimm_namespace_detach_btt
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0xadbe335e	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x002085ca	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x12968736	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0x13c170df	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0x14346ce6	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0x1fc8bee5	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x249d28c5	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x309bb8b0	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x34bcc10c	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x3dd08c4b	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x444eae00	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x53a79795	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x5ee25c76	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0x640ba6bd	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0x6daa53a5	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0x764af8ec	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0x859888cc	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0x9b2765a0	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0x9d2dab97	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x9e45950f	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0xa14a0054	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0xaf98f993	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xbb9e69e6	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xbf7a287d	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0xc5378bd9	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0xc8ef0e28	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0xd40a1991	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0xe64ef6d9	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport 0xe6f263d9	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0xf0d28374	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0xf582fc38	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0xf8ef0841	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0xfc720d57	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0x9b35d458	parport_pc_probe_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0xdff4a5f8	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x120ffd37	__pcmcia_request_exclusive_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x1a17aa52	pcmcia_register_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x274c8259	pcmcia_fixup_vpp
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x287a92d1	pcmcia_release_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x2b3d5f2c	pcmcia_get_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x40416f37	pcmcia_enable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x4b968569	pcmcia_loop_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x4d3d49ca	pcmcia_fixup_iowidth
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x61170185	pcmcia_request_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x633ee469	pcmcia_request_io
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x6536d157	pcmcia_unregister_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x6c197e33	pcmcia_read_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x70ac52b5	pcmcia_map_mem_page
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x742f5665	pcmcia_parse_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x8c7e75a1	pcmcia_get_mac_from_cis
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xd1255b39	pcmcia_loop_config
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xd384fbd6	pcmcia_disable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xdd1d16a1	pcmcia_dev_present
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xf0a2628c	pcmcia_request_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xfd485988	pcmcia_write_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x212db8d2	pcmcia_socket_list
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x48d3f5e5	pcmcia_parse_uevents
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x590d8796	pcmcia_get_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x6bfbea0b	pcmcia_put_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x9a8ae310	pcmcia_unregister_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x9f245db9	pcmcia_parse_events
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xb884c979	pcmcia_get_socket_by_nr
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xbed4e47b	pccard_register_pcmcia
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xc7270c55	pcmcia_socket_list_rwsem
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcf97f3bd	dead_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xdd646f53	pcmcia_register_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xe8cc121f	pcmcia_socket_class
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xfc9ecf76	pcmcia_reset_card
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0x139960da	pccard_nonstatic_ops
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0x96721afd	pccard_static_ops
++EXPORT_SYMBOL drivers/platform/x86/intel_ips 0xf97d7d0e	i915_bpo_enabled
++EXPORT_SYMBOL drivers/platform/x86/intel_punit_ipc 0x3a0b563a	intel_punit_ipc_simple_command
++EXPORT_SYMBOL drivers/platform/x86/sony-laptop 0x5bb1e117	sony_pic_camera_command
++EXPORT_SYMBOL drivers/pps/pps_core 0x4f7f72b3	pps_lookup_dev
++EXPORT_SYMBOL drivers/pps/pps_core 0x5ca93a15	pps_event
++EXPORT_SYMBOL drivers/pps/pps_core 0x6721a623	pps_register_source
++EXPORT_SYMBOL drivers/pps/pps_core 0xff522617	pps_unregister_source
++EXPORT_SYMBOL drivers/ptp/ptp 0x240f159c	ptp_clock_event
++EXPORT_SYMBOL drivers/ptp/ptp 0x5aa8ed57	ptp_find_pin
++EXPORT_SYMBOL drivers/ptp/ptp 0x75271576	ptp_clock_index
++EXPORT_SYMBOL drivers/ptp/ptp 0x80e80ac3	ptp_clock_unregister
++EXPORT_SYMBOL drivers/ptp/ptp 0xee42fede	ptp_clock_register
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x30bc43db	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x3d975320	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x50cfb950	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x53115109	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x57267467	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x77a3d35a	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x938fd89d	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xbff996f3	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xcbf8af76	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xe69af76e	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0x538bf710	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x278d5af8	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x640edd4f	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xbc8b8259	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xeed73792	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x0273bd4c	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x2278c566	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x31ed1ae3	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x38ed2b4c	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x43329167	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x484785fa	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x5d385839	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xafe9c6f6	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xbdab4319	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xbf97f5e7	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xd6e9a4a6	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xf41a0653	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x04a043a3	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0b1dea47	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0f03813d	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1107deca	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x13c074f4	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x141db087	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x15b19b28	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1d69bd19	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2192ce51	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2615fd6e	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x28a358fe	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2d3254d1	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2d964347	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x359e5307	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x38a3355e	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x391eec83	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x40c0296e	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x42cc6cd6	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x48007465	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4abff7ec	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x50b4de26	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5303afb0	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5677026f	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5ccc441b	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x62dfdde9	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x681975ee	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x69543f64	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6f76ded0	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x70aea72b	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7163c835	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x783a0ad3	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x78d46dcd	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x88e0572e	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9009d988	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9a762ad3	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbf4c89d5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc2963674	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc6b45c40	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc9dcb5ae	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd19c4971	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd73ce7d5	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd837813d	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdb414dc8	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdcfa942f	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdde8a603	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe8533676	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xecb345f0	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xee4f4071	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf56ba323	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfb162d34	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x3542864e	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x3947904f	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x5ec31086	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xe0443a45	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x72bcd1fd	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x02d0c466	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x06bac0e7	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0adf0bfa	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0b36e5c4	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1024abbe	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x105e5ad2	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1d4304f3	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1e086a41	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1f4c9ad9	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x22332afe	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x32b558b0	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3562be1a	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x36dc48fd	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3e3e172c	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x40adc9d5	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x46cb8635	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5ca190b4	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5cfc31e9	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5f37ca1c	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5f3c31df	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7440aa33	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x78513457	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x812d7878	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x81f529f6	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x91ca5fbd	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x999c24b1	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9e115f0b	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa676780f	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc1c66e99	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd92b3fb1	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdbceece1	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe4ff80fe	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe6ffecca	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf0916277	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf55ffbf0	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfae5ccbc	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x2ab9b65b	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5b18f70b	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x6136e5f9	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x931fe52a	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xd40a4ae5	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xf0ea977c	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x1e266bfd	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x4626d3cb	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x55347d8b	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x5f73ef37	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x7cfd3ec9	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x82e15695	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x83157c7c	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x8424e0ac	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x9597197a	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xa9ee2be0	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xc6634648	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xfa805da1	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x1f55cd70	qlogicfas408_ihandl
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3f605821	qlogicfas408_queuecommand
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3fd8cd71	qlogicfas408_detect
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x63464591	qlogicfas408_biosparam
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x77f4260f	qlogicfas408_abort
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xa6796060	qlogicfas408_info
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xa7efaaee	qlogicfas408_disable_ints
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xb41186dc	qlogicfas408_bus_reset
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xe76b3b20	qlogicfas408_get_chip_type
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf2b95199	qlogicfas408_setup
++EXPORT_SYMBOL drivers/scsi/raid_class 0x1d3573ac	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0x53bae440	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/raid_class 0x9f5c463e	raid_class_release
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x24a78071	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x272b9083	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x290cc805	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x29e7d06a	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x308dd8db	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x36abc1f3	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x3a0ec19d	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x566173dd	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7b149abf	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x852c3a77	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x90bb1391	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xc7f8e711	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xfb906b5d	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x04ad6ceb	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x0bd66aef	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1141ec10	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x15c5a54e	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1b326a71	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x25f20207	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2884fab6	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x314799e4	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x352317bb	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x427ba612	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x51c82dc9	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x58522eb9	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5bae4847	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x61a58dc7	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x64012aa7	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6825eb83	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6a260fc1	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6b7f3295	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x81525a67	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x8d7792fa	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa3331d75	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa5764d71	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xadd06b32	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb35026cd	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb8a9be05	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc5b6c31d	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd3b26da1	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd4c5583c	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xfbd4212e	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x03850c7d	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x510e2580	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x9a0bb1aa	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x9cb9686b	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xe2e6a4b3	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x078f29c8	srp_start_tl_fail_timers
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x2fce4e00	srp_rport_put
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x7a8fd5fd	srp_reconnect_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xbadfb431	srp_rport_get
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x09bf7dc6	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x27a3424d	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x39d6546c	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x5462b9d8	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x6199df9f	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x7bf12906	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xaf73180a	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0x068ab77b	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x217c78dc	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x3d0f810d	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0x55eba0be	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x7f33d4cb	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x8a09f531	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0x9bde69c5	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xa7826c4d	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0xaaaed338	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0xabb937f3	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0xac61964a	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0xad176612	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0xaf8933d5	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0xbe210070	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xcf100942	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0xd1ae1ff5	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xe8102695	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0xeb361281	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0xf4dfc2f6	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0xfc7ad91d	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x068cdc48	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x070805aa	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0792fb41	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x097be66a	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x09a0d718	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0eaf2837	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x187c5b07	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x2fdd6765	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x432ce86b	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x44a2f9e1	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x45b9308d	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x598ce08c	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x5db571a1	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x617ad5f9	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x64363b2d	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x7fad5445	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x82bffaf4	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xab536120	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xb4759b0f	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xb47a8d6c	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xc41237e1	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xd6d47afc	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe362c611	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xee664dda	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x07f968b0	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xda171fbc	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x04a43e78	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x41716ff9	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xb676dd06	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xd91929b9	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xf74c94cd	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x339fb6d9	ade7854_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0xf807412f	ade7854_remove
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0x90e84900	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0x7db9ec19	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x032059e5	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1b26a3ad	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x20aab2d6	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x27df9b9c	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x28acecd0	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x28b9212b	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2a37cceb	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2c63123a	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2cd9ec70	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x34634c2c	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3569e33b	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x38ac489e	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3b6ec364	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3d0bfb9c	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4c7c8374	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x50a6ee73	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x56ef275e	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5adadb4f	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5d04ffdd	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5ed459a1	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x66744432	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6e02a66b	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7244788c	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x76d2d5dc	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x79323dde	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7d2caa9a	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8c639f66	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8c8c9e22	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8cb6c44b	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8f75f4ef	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9465652e	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x97730ea7	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9b9861a8	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9edae3d2	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa7fd22e9	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xaf5d9ca7	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb0fe7420	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb2267f36	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb23e80b9	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb3e23c9f	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcc681353	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd53e2a3f	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd555364c	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd7447345	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdfbf99bc	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe7791fe4	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe9f3ca73	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xea997ad4	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xecaadcec	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfe50a7a1	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x08ba397a	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0f099f61	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x112ab000	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x12fbd93b	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x25f9030e	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x26a3da9d	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x27de9c05	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x31ddfc75	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x37a7336f	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3aa3318a	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x428821b6	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x438a8603	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4662c42b	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4c7e0608	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x56ef7111	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5ad073cf	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5ca9ff60	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5eb17c7f	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x60f419a5	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x61ea895d	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x62a52139	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x65fb1261	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6df3a99c	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6eab1dbb	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6eaf0dbf	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x752d2cc7	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x77fb5ad4	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x78b7d0a5	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7c7ae5c1	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7cc287c1	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7e29c9c1	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x86bb8290	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8cec8a01	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8e5bf4de	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x93766e03	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x93a0e3ec	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x93a9fc6e	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x93c1e919	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9428e960	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9cdee311	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa5f59038	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaeccd7c1	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb435f5f9	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc7061ae1	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcbf8b06f	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd67f4e3b	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd6c12417	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdba9911c	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe31e27aa	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe50d417c	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe84a3874	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf506fab0	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf89c06d2	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf978bca1	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfaad661c	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/unisys/visorbus/visorbus 0x83b2e9c2	visorbus_get_device_by_id
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x020d0867	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0ebc9e34	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x113859fa	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x16da5908	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x281e437c	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x376e9cce	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3b6cddc0	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x40331b3d	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x409aeef9	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4d57129b	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5145bbd3	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x576c6a15	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6b913a2b	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8575bc86	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa08931ed	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa0b13887	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa0d0c705	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa1e9e250	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa9d27ad4	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xabf25fea	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc2c40082	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc43e917e	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd2d6522f	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xdeb196ca	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe1b72886	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe1e40285	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xef214569	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf9ecbec4	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x089e86f2	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0ab6c677	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0b21eb0f	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0c35dc17	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0cbd121c	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0cfe50a7	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x12b368a3	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0x12f8ded2	transport_init_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1442f161	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x200ccd9f	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x212975e4	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x212cd002	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2206c2d9	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x22d36dc0	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0x24d281db	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x25c571ba	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0x28261629	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2a6f7164	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2e5ee1ac	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x30b3220e	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x33a4f7b3	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x34a3961d	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0x38ae7087	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3ab2fc05	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3ef536ca	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0x43c8e183	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x49d1d293	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x50c005ea	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5fa90d72	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6062f574	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6147a0a8	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0x67f09102	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0x68a0f3ac	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6cfec785	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6dadb587	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0x70b26d9a	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x70caf728	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7bb7d78e	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x829dd46a	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8445d217	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8846c122	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8ff1803c	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x91e7567f	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9c21ffa7	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9e164029	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa029e5d9	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa71d8c23	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xad8c76e8	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb3d7a88a	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb6ffc24a	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb7508948	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbe517511	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc4e4ed56	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc5940024	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc65d836c	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcd803f56	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd263c46a	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd5f47f42	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd5f86a4f	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd7f3b8f5	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdb4342ca	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xeed9a3e5	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf0a33d2f	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf200024d	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf25ffc16	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf89fdb54	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfea13913	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0xff50753e	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0xff572e75	sbc_dif_verify
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x1887763e	acpi_thermal_rel_misc_device_add
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x5007fc2c	acpi_parse_art
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x86c998e6	acpi_thermal_rel_misc_device_remove
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0xdf707fab	acpi_parse_trt
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0x42e659a9	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0x7a3aa5c7	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0xcb9c0105	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x0b189907	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x15503d76	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x429ac9fe	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x6bb0ca30	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x71d0a750	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x796fcf2d	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x7dbb275a	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x7eca3c76	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x89deac75	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xb459e974	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xcd49b15f	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xda7c669e	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x8c60bf1f	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x9bde8c23	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3b304ebb	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3c71c418	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x4311cd91	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x5fedea44	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x97fa07e9	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xde804bb9	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x5de5a07e	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xccb1fee2	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xe9ee4446	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xef8b97c1	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x0bf231e9	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x159a8c27	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x2dcc1ef0	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ee25313	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8dfceeb5	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xc91630cf	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd49e494e	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/core/syscopyarea 0xd7dc83cd	sys_copyarea
++EXPORT_SYMBOL drivers/video/fbdev/core/sysfillrect 0x1ae1434e	sys_fillrect
++EXPORT_SYMBOL drivers/video/fbdev/core/sysimgblt 0xbbc2debd	sys_imageblit
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xa142f6ee	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0x8725f226	mac_find_mode
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x406179b2	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x5bddf600	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x6f9ab5a7	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x1b752276	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x22dc1d19	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xc2f74afa	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xfb30aa49	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0xffd9aaa0	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0x555301df	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x0f767086	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x0f9eb3c4	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xbd443cd3	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xe0a333fd	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0x44e3237d	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xc402f78f	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x05914d85	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x0d94c616	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x377298f5	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xad65bc7d	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xaf4c733d	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0x212ed6d7	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x41315461	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x5aaff41d	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xc98aa4ed	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xe2845823	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x47cfb34c	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x59964d77	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x55d0ceea	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x714b01f7	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/wire 0x48b12c45	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x4c28198f	w1_register_family
++EXPORT_SYMBOL drivers/w1/wire 0x85a6df39	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xf24a4c6d	w1_unregister_family
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0x04e133fc	iTCO_vendor_check_noreboot_on
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xa78bd894	iTCO_vendor_pre_set_heartbeat
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xb5f20875	iTCO_vendor_pre_keepalive
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xc4f657bf	iTCO_vendor_pre_stop
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xdc6effc9	iTCO_vendor_pre_start
++EXPORT_SYMBOL fs/configfs/configfs 0x0060b3a6	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x0a9548e4	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x1567df3f	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0x18860b43	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x2f394b2c	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0x3cd678b8	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x5b2d7994	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0x70ba3ceb	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0x7ed3e100	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0x805598d9	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xa355c678	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xb7fd018f	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0xd01cbf55	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xd6989fbe	configfs_unregister_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0xe42b19f4	config_group_find_item
++EXPORT_SYMBOL fs/exofs/libore 0x0ed15ed6	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x26752205	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0x27f45dda	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x2a12f83f	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0x3d50a227	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x630ef6f5	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0x88cffe1a	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xb25073d9	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0xbe8da832	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0xc8556fa2	ore_get_io_state
++EXPORT_SYMBOL fs/fscache/fscache 0x0c60ccfd	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x1914d5fe	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0x19386ec8	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x25d71617	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x29fe5eac	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x2b2502ef	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0x31e99eba	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x353cef5a	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x382752f5	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0x3d0d5cbd	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x404f007a	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x427259db	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x49427c09	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x553c2a2c	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x6279516d	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x65f9401f	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x66d50783	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0x6cdcaef9	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0x6e6058a2	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x7d81de10	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x8175841a	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x86f26278	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x883e5bae	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x8a5f8642	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0x9116aad3	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x93e89b5b	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x961bfe2e	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0x97b95c0f	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x9bdf323e	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x9d426074	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0xa1aa74c9	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0xa28e9ceb	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0xab9689fc	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0xb4701121	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xba333866	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0xbd7eaf90	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xc7fda0f2	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xce90312c	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xe483ae6d	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0xf0553ac1	fscache_fsdef_index
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x29e8d935	qtree_read_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x738b9fd0	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x7d16f2f5	qtree_write_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xa27e1691	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0xea61ecf0	qtree_delete_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x1a703ba1	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0x6d356209	crc_itu_t
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc7 0x56329ecc	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd09b2cba	crc8
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x0641307b	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0x098d2ed9	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x175924ca	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x2d47ac83	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0x2f3dcecb	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0x4522d82a	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0x4cf5f5a8	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0x5752f31b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0x7257beee	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0x9134feb7	lc_get
++EXPORT_SYMBOL lib/lru_cache 0x94f2dbc7	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0xb672aa97	lc_create
++EXPORT_SYMBOL lib/lru_cache 0xbfbe53d5	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0xc3a98c1d	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcc979a91	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xefec290a	lc_find
++EXPORT_SYMBOL lib/lru_cache 0xfd525ec7	lc_put
++EXPORT_SYMBOL lib/lz4/lz4_compress 0x0c222eb5	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x682a23e0	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x56193a6d	lowpan_nhc_add
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x69eeae35	lowpan_netdev_setup
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xfb36163c	lowpan_nhc_del
++EXPORT_SYMBOL net/802/p8022 0x46cc3639	register_8022_client
++EXPORT_SYMBOL net/802/p8022 0xc394328a	unregister_8022_client
++EXPORT_SYMBOL net/802/p8023 0x41413278	make_8023_client
++EXPORT_SYMBOL net/802/p8023 0x9b2f8012	destroy_8023_client
++EXPORT_SYMBOL net/802/psnap 0x1829d3ba	unregister_snap_client
++EXPORT_SYMBOL net/802/psnap 0x22d6f6f1	register_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x02790115	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x037d7ac4	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0x10e25895	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0x18f47e80	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x1c8a8705	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x1d3d0762	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0x21988915	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x316961bb	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x34a3ac16	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x36b48b45	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x3aeaa2d6	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x3f0e4478	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x42713bac	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0x42ae3aed	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0x441561b0	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x4ea7af18	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0x505511ce	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x5f84ae80	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x645c6df9	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0x699dd6bd	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0x72c9d59b	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x7fca8cf8	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x83536918	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x8b8d9d97	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0x8c79e8c2	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x8f76d88d	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x90f66a5c	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x91ac5ea2	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0x94c276d2	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0xa8c6f45f	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0xad8b917d	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0xafda1315	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0xb278ecdb	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0xbb6e1d73	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xc907aad5	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xd34ebbd1	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0xd6ae1161	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xee803d0a	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0xf0dbb166	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0xf36d0879	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0xf3b2f0f9	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/9p/9pnet 0xff56addb	p9_client_unlinkat
++EXPORT_SYMBOL net/appletalk/appletalk 0x32c78696	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0x4f987c9b	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0x81abcf18	aarp_send_ddp
++EXPORT_SYMBOL net/appletalk/appletalk 0x835b1e25	atrtr_get_dev
++EXPORT_SYMBOL net/atm/atm 0x2929ce93	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x2f3eda37	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0x2f8bad05	atm_charge
++EXPORT_SYMBOL net/atm/atm 0x3423571f	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x487129f1	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x5bc48d7f	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0x5c797fc8	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x8ddbfc86	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xb02f37c2	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0xc4581c69	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0xf08fa4be	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/atm/atm 0xf559153e	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0xf8d9925d	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0xfdc80bb4	atm_dev_release_vccs
++EXPORT_SYMBOL net/ax25/ax25 0x08c6c756	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0x0c0f30ae	ax25_ip_xmit
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x30aecbde	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x3dca3f77	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x4b863cf5	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x5c392dff	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0x779b2a33	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xbf45f5d3	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0e21b0ed	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x14e51379	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2350d4ba	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x315a6d06	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x31e67092	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3e8a963c	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4064448a	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47eefd85	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4d505f94	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x50ab97b8	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x560694fd	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x59c109f8	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x669b9d73	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x68dd40e7	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6a04c851	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6a4bfdce	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6c63da9d	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x718fe79a	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7725c8eb	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7a943d0b	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7c58e4a7	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x81941935	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x946602a2	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa1941a2d	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xaafea009	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xab30da64	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xaed103a7	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb453d2b6	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb565f51b	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc955a79c	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc9a72dd1	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7e1b2b6	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd8b2e432	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xdbd22ad2	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xde480197	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe0b9c07a	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe44e84bf	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe5d9b5fe	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe7d68075	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf911392c	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xffcdcdec	bt_sock_wait_ready
++EXPORT_SYMBOL net/bridge/bridge 0x2f186828	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x541b7518	ebt_do_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x6b624adc	ebt_register_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xa6723752	ebt_unregister_table
++EXPORT_SYMBOL net/caif/caif 0x0e097c96	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x46db2f40	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x8f97ae7b	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xb22a6cc9	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xebd1df15	get_cfcnfg
++EXPORT_SYMBOL net/can/can 0x18f34c00	can_proto_unregister
++EXPORT_SYMBOL net/can/can 0x5dfa5585	can_ioctl
++EXPORT_SYMBOL net/can/can 0x830c19c5	can_send
++EXPORT_SYMBOL net/can/can 0xb4a9a029	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0xc7c85b16	can_rx_register
++EXPORT_SYMBOL net/can/can 0xee2849a6	can_proto_register
++EXPORT_SYMBOL net/ceph/libceph 0x06763d4c	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0c11b0c5	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0x10372c1a	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0x1309a1b8	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x166eba09	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x17e261f5	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0x18826396	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x1d16a92e	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x21c60751	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x23618143	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0x23c21fde	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0x24d897df	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x2972e9f1	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x2b85d232	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x33324fce	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0x34ff06d5	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0x3639d102	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x38040805	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0x384e3c66	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3b5d328e	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x3f27df16	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x419cb09b	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x496ae417	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0x4aa10165	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x4d4fbe8e	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0x50aaf6ff	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x59327d66	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x5a651f36	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x62111879	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x62451b36	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x635eb17d	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x68b970a5	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0x696e9826	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6c7a66fc	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0x6dbda31f	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x6e3f309e	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x6f38ef8a	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x6f4bf4d0	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x6fcdafef	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0x7285f0c1	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x74bc397a	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0x7e3c98a5	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0x80f89300	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0x85f7eafb	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x886490b3	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x889fe63a	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x897ef3f5	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0x8b34474f	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0x8febe185	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0x9202d09c	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x95775938	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0x9746d9a3	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0x97d442e8	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0x98ef7abe	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x9978be5d	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa03a4416	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0xa397fdd0	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0xa518ea6c	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0xa54d6b8c	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0xa79aa610	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xad20b9f4	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xaff93975	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0xb041d6d7	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0xb40f79f9	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb742eea2	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0xb85172fa	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xc3ce6dec	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc86b9e0e	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0xc8a67a2d	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xc93b6cda	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xd27c7f50	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd7acd83f	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xd9b85986	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0xdf8aff41	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xe0d18569	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xe184fdbb	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xe25aae1e	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xe3b042ca	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xe5f8bbd8	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0xe63fa614	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0xe8b53500	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xea5db2a0	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0xf32882e5	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xf35cb4d9	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xf3a06108	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0xf8722228	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xff2b13f3	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0xffb7931b	ceph_calc_pg_primary
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x0f913de3	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x85b7f0a6	dccp_req_err
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x25993fb3	wpan_phy_find
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x3f90c3d4	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x5fa6407d	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x70023029	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xd844d46e	wpan_phy_new
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xff141e4d	wpan_phy_register
++EXPORT_SYMBOL net/ipv4/fou 0x3106aeb4	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0x61cada3b	gue_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xd0750778	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0xea67ac99	fou_build_header
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x4fdc2b82	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x78284752	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xb63109ae	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xd9549402	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xe0416a7b	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xef4fb7be	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x34bd6525	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x6490f65a	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xa807be81	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x203388a1	ipt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xdd4b26d8	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xe2139583	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x7356ac62	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/tunnel4 0xd1a38c7f	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0xe0a6dd68	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x129ecc52	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x1a846e23	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xc6db4068	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xd9f4b4f3	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xaf0b5efe	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xb12049eb	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xf6418942	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0xda4fcb39	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/tunnel6 0xe2bd4da3	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x5e6a7d6f	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x959165e6	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x523fe467	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x7ae31c56	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x7c7f75c0	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x90bdda9c	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xa04d1f90	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xafe887cc	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xb0e48169	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xc74a51e4	ircomm_connect_request
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x08a32eb8	irlap_close
++EXPORT_SYMBOL net/irda/irda 0x0963c24b	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0x09939c11	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x23bbc2ce	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0x271b30a8	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0x2aa485d4	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x2b432980	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x2d4bc458	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x2da83814	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x385847aa	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x3e601626	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0x3e8da4cd	irlap_open
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46b00fdf	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x499956e2	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0x4aa61b5e	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x553f6446	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0x58943351	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0x61edf197	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6b34be4d	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x70a3f20f	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x77b14a1d	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x87ecb024	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0x8c003ad6	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0x91151f90	iriap_close
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x91eb33af	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x98a8b3b4	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0x9ccbdfca	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0xa1e606a5	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0xac3dc858	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0xaeeff2b5	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xb82cd448	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xba72ef11	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xc12e01e2	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xd41df8d4	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0xd6deeaae	irda_setup_dma
++EXPORT_SYMBOL net/irda/irda 0xd85d972e	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0xd92ca872	iriap_open
++EXPORT_SYMBOL net/irda/irda 0xdc0196c2	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe1ba6308	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0xe329462a	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0xeb78333e	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0xec242b93	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x57545387	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0xe03fd787	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x213a44e4	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0x4eebaa43	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0x7aa9ffcc	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0x7be51ffe	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0xcd5c2fd4	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0xdedb3c12	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0xe5354fea	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0xe775f4da	lapb_setparms
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x3afec058	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0x453096fa	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x5f0a43c4	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0x79bf2b53	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0xc4882921	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0xf7f88357	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0xfb3bffe9	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/mac80211/mac80211 0x0673d165	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x08111529	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x0bd609f2	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x1134840a	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x11440f58	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0x117371b9	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x12de2635	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0x13a54652	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x1720ff12	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x27287d62	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0x2b0761a7	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x2df48fa0	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x3062bb01	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x316988e0	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x31d938a9	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x3224e53b	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x337a20bb	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0x36027608	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0x3781e96f	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x3d34886f	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x3fd2c19d	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0x419c0202	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x4274cc98	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x445bfa80	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x4576d97b	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x4b8d470a	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x4bf9f5e8	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x4c2b011a	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0x4ce4648f	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x53033b33	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x55f97e4f	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x56e31876	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x5b0d559f	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x60b0fa07	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x623c8cb9	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x66b47ee0	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x6fb058aa	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x79657fd5	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0x7a28f21a	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x7b2f47d6	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x8256d6a8	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0x8485fe7d	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0x8b4298fc	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac80211/mac80211 0x902d162f	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x935353e4	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x96faf836	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0x986bdaf8	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x9df8dc29	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac80211/mac80211 0x9fc46bba	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xa489ae32	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xa71bc85a	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0xa8a13bf6	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0xa9fc577a	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0xae3b6389	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0xae5a25f6	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xb35e2995	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xb73daf67	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0xbacfebb3	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xbe306eca	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0xbff11c6b	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0xc2bd4872	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0xc4d8cd05	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xc6db6572	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0xca16e8ed	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0xcce0ff82	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0xd0ff67e9	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0xd1bf7fd1	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0xd2dcd2c3	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xd2e454f1	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0xd4cb3acb	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xdf0d9ec0	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xe0420def	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xe9eece01	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xeaedbb20	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xeeac854d	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xf1cfc142	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0xf1edef54	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0xf493e621	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0xf763e572	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0xf812b004	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xfbe03359	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0xffa4f83c	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac802154/mac802154 0x12fe6e70	ieee802154_xmit_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0x15363b8a	ieee802154_unregister_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x51947538	ieee802154_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xa9c2c7ff	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0xb8601e93	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0xdc068b00	ieee802154_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0xe17e4f23	ieee802154_alloc_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xe331e50d	ieee802154_register_hw
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x053cc5eb	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x08cbab90	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x2c9cdfa3	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x30f71b1b	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x31551408	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x47c447b0	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x517d1773	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x5f597565	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb1ba7a38	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xbf46bded	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xbfc1b69b	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xc0f6344e	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xc85b0beb	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xe4bb9b75	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x4093324c	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x488bba60	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xe5842e8e	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x577471d3	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x5e3f1729	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x77079d54	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0xdb77d9d6	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xe1d4337e	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0xf87a93cb	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/x_tables 0x050dff85	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x253e8b44	xt_compat_init_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0x2fea56b3	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x4bfadf5d	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x5ea4f289	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x65c1a893	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x8f3f40b6	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x9e6f3c1d	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xa25fc115	xt_compat_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xa973c272	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xc5998e8d	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xf11f3743	xt_register_target
++EXPORT_SYMBOL net/nfc/hci/hci 0x039c632a	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x0a63e613	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x178b9d3f	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0x2e4f7a4f	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0x3867d7e9	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x3a8fc3d9	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x58ea3d79	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0x6e6608d8	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/hci/hci 0x6f6f70b0	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x7ef7f2fe	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0x7f18b53d	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0x9dbbeb57	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0xb44ede3f	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0xb905b653	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xbeca23e0	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0xbed6753c	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xd01e2a5f	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0xd0e80c5b	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xd721c29b	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xd917e175	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xeb09648f	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/nci/nci 0x03fc46fb	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x14db07eb	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x21c26cc4	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0x239beb7b	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x355e758e	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0x41bb5674	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0x45ec6bd6	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x45f7718c	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x5f3c339b	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0x61f0a715	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0x62f325ab	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x69148e74	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0x6ce09032	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nci/nci 0x855505cd	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nci/nci 0x94fef26d	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x960fd5e8	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0xa07ca7b2	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xa71e31b0	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0xad8f290c	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xb1d47f39	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xb6697a5b	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0xb7733a40	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xbf261efe	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xc4f600cc	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0xcdc865c2	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xd0d77db3	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xd125c934	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0xe5f34e8c	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nfc 0x0031fa66	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc 0x0fab3f3b	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0x110b769a	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0x13122288	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0x1b5e0515	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0x1f67fb40	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x20b3c9df	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0x2472029f	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0x29ea91db	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0x429acb45	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0x58b6c50d	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x61555740	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x66729efc	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0x6941609b	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0x878f9753	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0x983ec619	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0xa17247e2	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0xb3719bda	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0xd2f95e65	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0xe4b06b8e	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0xe707db16	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0xf192a9eb	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0xf3f1b518	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0xf4cb3074	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc_digital 0x0795fa22	nfc_digital_register_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x351df39b	nfc_digital_free_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x6c62597a	nfc_digital_allocate_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xbbff2e44	nfc_digital_unregister_device
++EXPORT_SYMBOL net/phonet/phonet 0x05c3121a	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0x1104aecd	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0x6908ceae	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0x6ce0f0f3	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0x86346a32	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0x8c968fbe	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0xa7a8a0d5	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0xae6288a2	pn_sock_hash
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x4e559211	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x55c5693f	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x71ce6b54	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x733a0d7b	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x7b47ac38	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8cfa3516	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8e105bbb	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x99b8dce2	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xac718e2c	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xaed4f51b	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xc3f1be37	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe70ea352	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe81b5ef5	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xed5a7574	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xfe5d8d3d	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/sctp/sctp 0xc8fdcc85	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x479540db	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x9a459b36	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xdbedb097	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x6ff474ce	svc_pool_stats_open
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x79a9ac47	xdr_truncate_encode
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x86545f8d	xdr_restrict_buflen
++EXPORT_SYMBOL net/wimax/wimax 0x0119276f	wimax_reset
++EXPORT_SYMBOL net/wimax/wimax 0x61cb4d99	wimax_rfkill
++EXPORT_SYMBOL net/wireless/cfg80211 0x048b4791	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0x092138d5	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0b8ffa01	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x0cb424f1	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x21ae7045	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0x255ac855	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x27d0a1b3	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x2b7e6877	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0x2dfbe311	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x301eeb82	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0x34012cbf	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0x37b7fe23	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x383a315a	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3dacc6dc	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e707998	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0x3ec81d06	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x454e9913	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x46d09925	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x4733f5da	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x49fbb434	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x50e4f23b	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x58959d87	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x5e68c630	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x5eb24611	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x62c337ca	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x6446df7f	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0x6970a43a	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x69eaa7a3	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x6a4373b6	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0x6b2d8025	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x727785ec	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x78e5fff9	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0x7d4a5816	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x85e85cb9	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x8769e97d	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0x887b0eac	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x88db0d1f	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x91d7a142	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x96ad30c3	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x9ade30b9	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0x9b377994	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x9dc0f37f	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0x9e188fca	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x9e7ccb32	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa5ea0bb0	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xa8746d8d	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0xaa478b4e	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xab60082c	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0xadc7ba74	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xadfc4dd3	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xae22de27	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xb16cf0e7	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xb57bdd2d	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xb6422e34	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0xb653db72	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0xb85f5237	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0xba4088df	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xbd5351d3	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0xbe83b7a1	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xbeeac1f1	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xc0f3852d	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xcabb81c9	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0xcb0a6b6f	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0xcc088cee	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xcedf5fea	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0xd3095ff6	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xd4667f24	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xd50b0a22	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xd5823245	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xd8814dce	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xdca564df	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xde700115	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0xdf686755	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xe4f53c1a	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe8f5fdbd	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0xea4b6586	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0xef54c6a4	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0xef9a96c3	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0xefa82c22	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xf0048458	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0xf2143676	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xfadae348	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0xfc77a482	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0xffec4b0d	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/lib80211 0x15537a03	lib80211_crypt_info_free
++EXPORT_SYMBOL net/wireless/lib80211 0x3da92bd1	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x633dc3f7	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x8e120812	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0xc5ccc3af	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0xe67df343	lib80211_register_crypto_ops
++EXPORT_SYMBOL sound/ac97_bus 0x07740cc5	ac97_bus_type
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0xa30bcfed	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x75c1e0c6	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x93bfc8ab	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xd72672f1	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xf5047698	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xf2bef094	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x205395a0	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x614705ff	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x7746bb9b	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x79794472	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x991c0f60	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xef8fa3d2	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xf3f0324e	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xf6fdda44	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0xaec61b98	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x056ea9f0	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0x0621f23a	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0x0827e61b	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0x17550188	snd_card_new
++EXPORT_SYMBOL sound/core/snd 0x185af367	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0x18e1683f	snd_dma_program
++EXPORT_SYMBOL sound/core/snd 0x191e88cf	snd_dma_pointer
++EXPORT_SYMBOL sound/core/snd 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL sound/core/snd 0x1af45826	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0x1d3ad354	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0x1e1cc59b	snd_ctl_register_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0x1fdd3da0	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0x21fa9030	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x2726f2b3	snd_ctl_unregister_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0x32935221	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0x32ae2749	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0x33081368	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0x342a2354	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x34e54284	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0x3897102d	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x3a2e51e6	snd_register_oss_device
++EXPORT_SYMBOL sound/core/snd 0x3ce890a6	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0x3e48823f	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0x409c8418	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0x468d9f46	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x4b3c6cd9	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0x522d0efa	snd_cards
++EXPORT_SYMBOL sound/core/snd 0x52be9500	snd_register_device
++EXPORT_SYMBOL sound/core/snd 0x602a741e	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0x67367a71	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0x6a5c8123	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd 0x70c15ac1	snd_dma_disable
++EXPORT_SYMBOL sound/core/snd 0x71239ae4	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x8261be1a	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0x8dc6546b	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x9242512e	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd 0x95e27e4d	snd_device_new
++EXPORT_SYMBOL sound/core/snd 0x9835798a	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xa6282774	snd_jack_add_new_kctl
++EXPORT_SYMBOL sound/core/snd 0xa84ef6be	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0xacf318cd	snd_unregister_oss_device
++EXPORT_SYMBOL sound/core/snd 0xb08a7b52	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0xb0d9f2c1	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xb313569a	snd_jack_new
++EXPORT_SYMBOL sound/core/snd 0xba1c3baa	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0xc0208076	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0xc5348442	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0xd4b0ff7e	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0xdfecae62	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0xf65a87ad	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0xf6b77a64	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0xf70e920c	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL sound/core/snd 0xfbcb8a0d	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0xfffd89db	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd-hwdep 0xd1f43d77	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x02428dcd	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x035112f3	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x06b310c9	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x0e45d53d	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x148db5d0	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x1ae7e314	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x1dcd1438	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0x25d8159e	snd_pcm_sgbuf_ops_page
++EXPORT_SYMBOL sound/core/snd-pcm 0x2892198d	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0x2c6a0ead	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0x2d6cb0ec	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x37cf4d21	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x39d406fd	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-pcm 0x468fe178	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0x476233ae	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x4d393ef7	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0x4d445d4e	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0x4daa914b	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x542b8861	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0x55d92af9	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL sound/core/snd-pcm 0x5898dcba	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x60425da5	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x60e887fd	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x62cddf5b	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-pcm 0x64f09d12	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x6cca3450	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x713a1fb1	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0x78e3063e	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x80214432	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x832c5265	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0x834dc955	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x849d5630	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0x909280d6	snd_pcm_lib_mmap_iomem
++EXPORT_SYMBOL sound/core/snd-pcm 0x92fc8330	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0x93cd9156	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x966169c7	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x9b0b95dd	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xb284ca43	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0xb44d7d25	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xba72c8c6	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0xbc5d74d4	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0xbdd11579	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0xc96973e7	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0xca34c226	snd_sgbuf_get_chunk_size
++EXPORT_SYMBOL sound/core/snd-pcm 0xcd260252	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xd46c6c88	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xda45ba6a	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xe5b70cf4	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0xeacfc2c1	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0xf9965b7c	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-pcm 0xfcf81733	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0xff2732f9	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x0595732f	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x095cb6c0	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x3c08fe58	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x43f08535	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x4835e107	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x53e3bc54	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x5d1130b7	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x65694238	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x65cac207	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x6ed9428e	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x884b3f8f	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x89250087	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xbde3072e	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xc1874ab2	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xc8e8c5fa	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xcf2acb98	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd0f130bd	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xdaaaa88a	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xf326a0e2	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-timer 0x3309ceb9	snd_timer_start
++EXPORT_SYMBOL sound/core/snd-timer 0x448af078	snd_timer_stop
++EXPORT_SYMBOL sound/core/snd-timer 0x48dd4c98	snd_timer_interrupt
++EXPORT_SYMBOL sound/core/snd-timer 0x6b854631	snd_timer_global_register
++EXPORT_SYMBOL sound/core/snd-timer 0x6d289247	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0x763246d6	snd_timer_new
++EXPORT_SYMBOL sound/core/snd-timer 0x9aa52038	snd_timer_resolution
++EXPORT_SYMBOL sound/core/snd-timer 0xa2f32e41	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0xa5911885	snd_timer_close
++EXPORT_SYMBOL sound/core/snd-timer 0xbfd565bb	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0xd96439e6	snd_timer_open
++EXPORT_SYMBOL sound/core/snd-timer 0xed760e2a	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0xf1cda83a	snd_timer_pause
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xbca43a46	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x06bb53d2	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x18f7b4b6	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x69dd7fa4	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x7eba931e	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x9e21f152	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x9f92d91d	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xa1da723e	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xcef1ede4	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xdaa727ae	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x2aae4322	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x31ce73e5	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x3bd3c184	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x48859687	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x53915249	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x7db44af9	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x96a05d30	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x9f1d9133	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xbc13b33e	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x04c473ae	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x0585872f	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x0d893f7a	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1b96203e	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x280c7f8c	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x31114a3a	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3c2abe84	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4455a6bc	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4e4926f2	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x54812112	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5a3d7d76	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x6316dd1b	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x64605f14	amdtp_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7102ea09	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7172b255	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7713f117	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7785e3f2	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x88b42930	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x905f2256	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x937bdaa1	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x969e0e94	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa63c665d	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xaf50188f	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xb85164e2	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xbcbe6268	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc54706f7	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd61bc739	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xda5e9e20	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xdb410eb3	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe7904fb0	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe8991fbe	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xed1cdec4	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x1fd5323f	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0xfcf62816	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x1917a555	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x25b7afac	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x33323563	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x5a5741c2	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x60950ce2	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x781c21f4	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xd9888769	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xf88725c1	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x0b9cc78e	snd_ak4117_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x7d6d0cfe	snd_ak4117_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x8a62ed54	snd_ak4117_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xa9715356	snd_ak4117_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xbb5c899e	snd_ak4117_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xe3dc659a	snd_ak4117_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x68612885	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x6f763723	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xd94cbc56	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xf210e655	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x2ea38307	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x4ec3122e	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x483c7c1c	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x498a51a5	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x4e075b81	snd_cs8427_init
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x5cd15b79	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x6ca0afb7	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xbdd14df6	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x32c4ba14	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x6397e3cf	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x7b750e5d	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x978e0031	snd_i2c_device_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xbd62f4fb	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xd9065178	snd_i2c_device_free
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x07d1d6c4	snd_sbmixer_suspend
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x265856d6	snd_sbmixer_write
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x2fe74790	snd_sbmixer_add_ctl
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x50da5b15	snd_sbdsp_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x61b3c77f	snd_sbdsp_get_byte
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x79085603	snd_sbmixer_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x802af604	snd_sbmixer_resume
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x86b5c553	snd_sbmixer_read
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xdb36104a	snd_sbdsp_command
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xfdf7af19	snd_sbdsp_reset
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x13db3734	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x17c71503	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x2491b8b9	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x28ddd3fa	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5ae08884	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5b83615d	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x765631f6	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x85b6132d	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x8ab4b381	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xa15a4004	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xad6ef2e7	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xc5cbc14a	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xd299cecd	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xda39db5f	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xda570669	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xe838b1da	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xf488195d	snd_ac97_write
++EXPORT_SYMBOL sound/pci/asihpi/snd-asihpi 0xf1fc1a61	hpi_send_recv
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x1968c142	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x303eaadc	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x31381fa4	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x5c6a53dc	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x7ed6b1c2	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xa45ac73b	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xb7d7447e	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xcb1513f0	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xf2f5b853	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x835b2176	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xae1eca84	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xafee8d64	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x130bab1a	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x26fed330	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x31588699	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x3a179550	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x44887907	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x4befd2bb	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x4de5260d	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x51185ba9	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x5fce1b7f	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x6484668b	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x7892f653	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x802ee865	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x8e17c940	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x95a6f5aa	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa6e7cdc5	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb59eb080	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xcd52a6b8	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xd6acfdfe	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xecd0344c	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf351b5ec	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf83d41b1	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x06ae7d7a	snd_trident_free_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x5943cae1	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x68ecbe74	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xcf46d513	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xed8e1cd7	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x2113e84b	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x64003106	tlv320aic23_probe
++EXPORT_SYMBOL sound/soc/intel/common/snd-soc-sst-dsp 0x582ce052	sst_dma_new
++EXPORT_SYMBOL sound/soc/intel/common/snd-soc-sst-dsp 0xdc045797	sst_dma_free
++EXPORT_SYMBOL sound/soc/snd-soc-core 0xb6d7062e	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL sound/soundcore 0x291bd857	sound_class
++EXPORT_SYMBOL sound/soundcore 0x48b52754	register_sound_midi
++EXPORT_SYMBOL sound/soundcore 0x600a6a6c	register_sound_special
++EXPORT_SYMBOL sound/soundcore 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL sound/soundcore 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xe4a806b5	register_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xf4ca5970	register_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0xf9dffcc2	register_sound_special_device
++EXPORT_SYMBOL sound/soundcore 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x063a3fd7	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x3a6cbd94	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x8194a564	snd_emux_register
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x97d18ce8	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xa873f079	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xce8ac189	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x01ca02d7	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x22511cd2	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x60a52fc8	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x85cc7e76	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xa3728dc0	__snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xcecdf26e	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xe8e20091	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xfb5e8277	snd_util_memhdr_free
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbef93959	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL ubuntu/hio/hio 0x0448b53b	ssd_get_pciaddr
++EXPORT_SYMBOL ubuntu/hio/hio 0x20e876a3	ssd_unregister_event_notifier
++EXPORT_SYMBOL ubuntu/hio/hio 0x21097539	ssd_set_otprotect
++EXPORT_SYMBOL ubuntu/hio/hio 0x26b39671	ssd_get_temperature
++EXPORT_SYMBOL ubuntu/hio/hio 0x295bad6e	ssd_submit_pbio
++EXPORT_SYMBOL ubuntu/hio/hio 0x2a5eb2e2	ssd_reset
++EXPORT_SYMBOL ubuntu/hio/hio 0x4e849fc5	ssd_bm_status
++EXPORT_SYMBOL ubuntu/hio/hio 0x659ccffe	ssd_get_label
++EXPORT_SYMBOL ubuntu/hio/hio 0x66eade8f	ssd_get_version
++EXPORT_SYMBOL ubuntu/hio/hio 0x7edc7e9d	ssd_register_event_notifier
++EXPORT_SYMBOL ubuntu/hio/hio 0xf105b860	ssd_set_wmode
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x00322056	VBoxGuest_RTMpCpuIdFromSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x01674ab7	VBoxGuest_RTSemMutexRequestNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0429a6f0	VBoxGuest_RTThreadCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x057fd386	VBoxGuest_RTR0MemObjLockKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0731e88d	VBoxGuest_RTAssertMsg2Add
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x079b132d	VBoxGuest_RTMemTmpAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x08ed98db	VBoxGuest_RTMemDupExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x09a88bc3	VBoxGuest_RTTimeExplode
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0a442050	VBoxGuest_RTAssertAreQuiet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0b94344b	VBoxGuest_g_pszRTAssertExpr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0beb235d	VBoxGuest_RTMpIsCpuWorkPending
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0cd1b64d	VBoxGuest_RTMpCurSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0d10d1ca	VBoxGuest_RTTimeNormalize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0f3e114a	VBoxGuest_RTSemSpinMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0f884b3a	VBoxGuest_RTStrToInt64Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x11ced39a	VBoxGuest_RTSemEventWaitEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x11e95d2e	VBoxGuest_RTLogLoggerEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x11f80121	VBoxGuest_RTSemMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x12614b82	VBoxGuest_RTStrToInt8Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x12f430f3	VBoxGuest_RTAssertMsg2AddV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x147206e1	VBoxGuest_RTStrToUInt64
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x151752ec	VBoxGuest_RTHeapSimpleGetFreeSize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1520b2c8	VBoxGuest_RTLogCreateEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x160b14d4	VBoxGuest_RTMpGetPresentSet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1926b25c	VBoxGuest_RTLogRelLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x19790b4c	VBoxGuest_RTLogFlags
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x197acd65	VBoxGuest_RTR0Init
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1a6d7d86	VBoxGuest_RTThreadPreemptIsEnabled
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1ae28abb	VBoxGuest_RTThreadIsSelfAlive
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1c3b0f90	VBoxGuest_RTR0MemObjAddressR3
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1dc5ebbe	VBoxGuest_RTThreadWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1f3e577b	VBoxGuest_RTMemTmpAllocZTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1f70d065	VBoxGuest_RTErrConvertToErrno
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2003169b	VBoxGuest_RTSpinlockAcquire
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x20728ae6	VBoxGuest_RTThreadCreateV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x20d9d625	VBoxGuest_RTTimeToString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x22058511	VBoxGuest_RTSemMutexRequestDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2254228b	VBoxGuest_RTMpGetPresentCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2387f039	VBoxGuest_RTMpIsCpuPresent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x25219f5e	VBoxGuest_RTR0Term
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2580d04c	VBoxGuest_RTSemEventMultiSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2632a013	VBoxGuest_RTLogRelLoggerV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x29708cf0	VBoxGuest_RTR0MemUserCopyTo
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2a2284fb	VBoxGuest_RTAssertMayPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2af3453c	VBoxGuest_RTLogPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2c2b5b46	VBoxGuest_RTTimerGetSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2cfefa48	VBoxGuest_RTLogBackdoorPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2d445217	VBoxGuest_RTStrToInt64Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2d581c06	VBoxGuest_RTMpCurSetIndexAndId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2eca7777	VBoxGuest_RTHeapSimpleAlloc
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2fb7502f	VBoxGuest_RTThreadSetName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x30e40c69	VBoxGuest_RTLogSetDefaultInstanceThread
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3168cadf	VBoxGuest_RTTimeSystemMilliTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x31ac4c5f	VBoxGuest_RTThreadIsInitialized
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x33d7313a	VBoxGuest_RTMpCpuId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x343e3e1b	VBoxGuest_RTLogGetDestinations
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3480f453	VBoxGuest_RTSemMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x358153bb	VBoxGuest_RTStrCopy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x362275e8	VBoxGuest_RTMemContFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x372d5e29	VBoxGuest_RTPowerNotificationDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x376d539c	VBoxGuest_RTThreadGetType
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x381d7c24	VBoxGuest_RTMemAllocVarTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x383a0b9d	VBoxGuest_RTMpPokeCpu
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3a47392e	VBoxGuest_RTErrConvertFromErrno
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3b04381e	VBoxGuest_RTSemEventMultiReset
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3b231c95	VBoxGuest_RTTimeNanoTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3bcf543a	VBoxGuest_RTLogGetDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3d00f113	VBoxGuest_g_u32RTAssertLine
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3de43f66	VBoxGuest_RTSemEventCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3dfc9ab8	VBoxGuest_RTSemMutexIsOwned
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3fbf3c07	VBoxGuest_RTThreadIsInInterrupt
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x40996438	VBoxGuest_RTSemEventMultiWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x42ecc6d1	VBoxGuest_RTThreadPreemptRestore
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x43fdd8d9	VBoxGuest_RTSemFastMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x44cfbc28	VBoxGuest_RTThreadGetNative
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x461fa9fe	VBoxGuest_RTLogRelGetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x46c14223	VBoxGuest_RTLogSetCustomPrefixCallback
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x49f1be17	VBoxGuest_RTThreadFromNative
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x49f4d19c	VBoxGuest_RTLogDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4ba5006e	VBoxGuest_RTLogPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4bbec091	VBoxGuest_RTR0MemObjGetPagePhysAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4c7d8a56	VBoxGuest_RTSemEventMultiCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4cac3157	VBoxGuest_RTLogFormatV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4cecc93d	VBoxGuest_RTR0MemObjEnterPhysTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4cf913a1	VBoxGuest_RTThreadGetName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4ea67110	VBoxGuest_RTStrToInt32
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4f041d39	VBoxGuest_RTMemContAlloc
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4fc8e10c	VBoxGuest_RTMpGetSet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4fe9e5f1	VBoxGuest_RTR0MemObjProtect
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5040043b	VBoxGuest_RTSemEventWaitExDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x508bb2c4	VBoxGuest_RTLogSetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x51ec28bd	VBoxGuest_RTLogGetFlags
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x53265abc	VBoxGuest_RTLogSetBuffering
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5352c915	VBoxGuest_RTSemMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x54098f34	VBoxGuest_RTTimerStop
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x54ddf87c	VBoxGuest_RTThreadPreemptIsPossible
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5595fc22	VBoxGuest_RTSpinlockDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x56596e82	VBoxGuest_RTThreadSelfName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x56c939fe	VBoxGuest_RTAssertMsg1
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5847ae52	VBoxGuest_RTMpGetCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x58d1b65e	VBoxGuest_RTThreadPreemptIsPending
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x598d3622	VBoxGuest_RTAssertMsg2AddWeak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5a97195c	VBoxGuest_RTHeapSimpleRelocate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5aa6ed66	VBoxGuest_RTPowerSignalEvent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5b3a5164	VBoxGuest_RTLogWriteUser
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5cc0b1b2	VBoxGuest_RTProcSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5d3b1bd6	VBoxGuest_RTSemSpinMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5e071eb3	VBoxGuest_RTSemEventMultiDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5e17b70e	VBoxGuest_RTSpinlockRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5e75c570	VBoxGuest_RTStrToUInt16
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5eaea89a	VBoxGuest_RTSemFastMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5ee65bb7	VBoxGuest_RTStrToUInt16Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5ef42fe5	VBoxGuest_RTTimerStart
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5f2f48bb	VBoxGuest_RTLogWriteStdErr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x61143878	VBoxGuestIDCCall
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6173b384	VBoxGuest_RTMpOnPairIsConcurrentExecSupported
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x61770e8c	VBoxGuest_RTStrToUInt32
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x63378722	VBoxGuest_RTLogBackdoorPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x634946f7	VBoxGuest_RTMpIsCpuOnline
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x637a1d69	VBoxGuest_RTLogWriteStdOut
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6381bb97	VBoxGuest_RTStrFormat
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x63b1fde6	VBoxGuest_RTMpCpuIdToSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x63bc10b0	VBoxGuest_RTLogCreateExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x658cd915	VBoxGuest_RTR0MemObjFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x67135d2b	VBoxGuest_RTSemFastMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6862822a	VBoxGuest_RTHeapSimpleSize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x695d63ad	VBoxGuest_RTMpNotificationDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6b01bbf3	VBoxGuest_RTMpOnSpecific
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6b58b79d	VBoxGuest_RTSemSpinMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6b91f1ce	VBoxGuest_RTStrFormatTypeDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6c8460ac	VBoxGuest_RTLogRelGetDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6cec7c3b	VBoxGuest_RTTimerCreateEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6d8e9c87	VBoxGuest_RTTimeNow
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6e8541b7	VBoxGuest_RTAssertMsg2Weak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x704e1f6f	VBoxGuest_RTAssertMsg2AddWeakV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x70867323	VBoxGuest_RTStrToUInt8Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x71060970	VBoxGuest_RTStrToUInt16Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x716e3be3	VBoxGuest_RTMpGetOnlineCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x729cc4ab	VBoxGuest_RTR0MemObjSize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x72ff1bc3	VBoxGuest_RTTimeIsLeapYear
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x730a01b0	VBoxGuest_RTLogRelSetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x74812dde	VBoxGuest_RTStrToInt32Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x759e7492	VBoxGuest_RTSemFastMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x764ecb18	VBoxGuest_RTR0MemObjAllocLowTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x76a3c47b	VBoxGuest_RTMemAllocZVarTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x79d59e24	VBoxGuest_RTSemSpinMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7d0d9dae	VBoxGuest_RTR0MemObjAllocPhysNCTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7d15e878	VBoxGuest_RTMpGetOnlineSet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7dcc30d8	VBoxGuest_RTStrToInt32Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7e29739a	VBoxGuest_RTStrToInt16
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7f0a40ea	VBoxGuest_RTLogComPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7fc5bdcf	VBoxGuest_RTR0MemObjAllocPhysTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8196c4e6	VBoxGuest_RTSemSpinMutexTryRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x82e081bc	VBoxGuest_RTStrFormatTypeSetUser
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x83e78406	VBoxGuest_RTR0MemAreKrnlAndUsrDifferent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x841e42e9	VBoxGuest_RTSemMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8484a0d6	VBoxGuest_RTStrToInt16Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x84e227f6	VBoxGuest_RTThreadIsSelfKnown
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x86120100	VBoxGuest_RTLogDumpPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x867be0d2	VBoxGuest_RTLogDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x868b79a5	VBoxGuest_RTStrPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x879761cf	VBoxGuest_RTR0MemObjAllocPhysExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x87da3860	VBoxGuest_RTAssertSetQuiet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8826d9de	VBoxGuest_RTMpGetMaxCpuId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x883d496c	VBoxGuest_RTMpGetCoreCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x885274fe	VBoxGuest_RTThreadUserWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x89117f68	VBoxGuest_RTMemExecAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8a3c154f	VBoxGuest_RTR0MemObjLockUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8a454b31	VBoxGuest_RTSemEventGetResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8e01e3fd	VBoxGuest_RTStrFormatV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8f1309e3	VBoxGuest_RTAssertMsg2
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x90312938	VBoxGuest_RTStrToUInt64Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x91204a9b	VBoxGuest_RTTimeSpecToString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x916e42f0	VBoxGuest_RTAssertMsg1Weak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9264ffc0	VBoxGuest_RTLogRelPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x926bf9f7	VBoxGuest_RTThreadPreemptDisable
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x92e716ae	VBoxGuest_RTLogGetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x94f7365f	VBoxGuest_RTPowerNotificationRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x95fa480d	VBoxGuest_RTSpinlockCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x961772f3	VBoxGuestIDCOpen
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x967ea4b6	VBoxGuest_RTStrToInt64
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x96893ce3	VBoxGuest_RTR0MemObjAllocPageTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x96f2e65b	VBoxGuest_RTR0MemUserCopyFrom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9796440b	VBoxGuest_RTSemEventWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x97eb2414	VBoxGuest_RTThreadNativeSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9874cd16	VBoxGuest_RTMpIsCpuPossible
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9909ff3d	VBoxGuest_g_pszRTAssertFunction
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9a2ee747	VBoxGuest_RTSemEventDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9bcc539d	VBoxGuest_RTThreadUserReset
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9cd9213f	VBoxGuest_RTR0MemKernelIsValidAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9d6b527c	VBoxGuest_RTThreadWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9dbd63d6	VBoxGuest_RTStrPrintfEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9eaecd9d	VBoxGuest_RTStrPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9f301085	VBoxGuest_RTTimeSpecFromString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9f4f616a	VBoxGuest_RTLogLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9fb0596d	VBoxGuest_RTMemDupTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa168a070	VBoxGuest_RTLogLoggerExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa34eb1b3	VBoxGuest_RTTimeSystemNanoTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa486e710	VBoxGuestIDCClose
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa554bd97	VBoxGuest_RTLogFlushRC
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa5a26703	VBoxGuest_RTMpNotificationRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa696baed	VBoxGuest_RTR0MemObjAddress
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa6a22472	VBoxGuest_RTThreadUserWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa6de1bcd	VBoxGuest_RTTimerChangeInterval
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa86c5a96	VBoxGuest_RTSemEventSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xaba9bc9c	VBoxGuest_RTLogCloneRC
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xac990d74	VBoxGuest_RTTimerCanDoHighResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xacaac41d	VBoxGuest_g_szRTAssertMsg1
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xad4fdf4e	VBoxGuest_RTSemMutexRequestNoResumeDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xad649089	VBoxGuest_RTStrToUInt64Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xae3e0ecd	VBoxGuest_RTLogRelPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xaf6ffbfc	VBoxGuest_RTThreadSleep
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb05840a7	VBoxGuest_RTSemEventMultiWaitExDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb1cc9148	VBoxGuest_RTLogWriteCom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb42ea0e3	VBoxGuest_g_pszRTAssertFile
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb444f4a1	VBoxGuest_RTLogDestinations
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb6941b2e	VBoxGuest_RTStrToUInt8
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb8c6e615	VBoxGuest_RTStrToUInt32Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb8ca8fcb	VBoxGuest_RTMpOnPair
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb8df2b3a	VBoxGuest_RTAssertShouldPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb9b070b7	VBoxGuest_RTAssertMsg2V
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb9d7a27d	VBoxGuest_RTHeapSimpleDump
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbaa97421	VBoxGuest_g_szRTAssertMsg2
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbb1ead73	VBoxGuest_RTR0MemKernelCopyTo
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbba928e6	VBoxGuest_RTHeapSimpleGetHeapSize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbc4d30f6	VBoxGuest_RTR0MemObjAllocContTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbc85935a	VBoxGuest_RTR0MemKernelCopyFrom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbe4e6114	VBoxGuest_RTLogFlushToLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbffedb55	VBoxGuest_RTMemAllocExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc1095c44	VBoxGuest_RTTimeImplode
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc1b3ada4	VBoxGuest_RTAssertMsg2WeakV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc3a1e5de	VBoxGuest_RTLogGetGroupSettings
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc3fee96e	VBoxGuest_RTMemAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc4bd5fd8	VBoxGuest_RTStrPrintfExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc63cc2f0	VBoxGuest_RTR0MemExecDonate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc71362b7	VBoxGuest_RTLogRelSetBuffering
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc8fbf4aa	VBoxGuest_RTHeapSimpleInit
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc91cea98	VBoxGuest_RTStrCopyEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc9a6a8e7	VBoxGuest_RTThreadCreateF
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xcaee97bf	VBoxGuest_RTLogComPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xcb2a6b54	VBoxGuest_RTMemExecFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xceae9d6a	VBoxGuest_RTStrConvertHexBytes
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd14e8ec2	VBoxGuest_RTTimerDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd1f3f0b9	VBoxGuest_RTSemEventWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd2a37e73	VBoxGuest_RTTimerReleaseSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd2d290ab	VBoxGuest_RTStrToUInt8Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd3a125cb	VBoxGuest_RTR0MemObjMapKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd46c35d4	VBoxGuest_RTMpOnAll
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd4b597fc	VBoxGuest_RTStrCopyP
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd5bfc897	VBoxGuest_RTHeapSimpleAllocZ
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd637869e	VBoxGuest_RTMemReallocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd69bc8e4	VBoxGuest_RTR0MemObjReserveUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd706d85c	VBoxGuest_RTTimeFromString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd88c9330	VBoxGuest_RTLogLoggerV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd984a7f4	VBoxGuest_RTStrFormatTypeRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdc700594	VBoxGuest_RTSemEventMultiGetResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xde9ca744	VBoxGuest_RTThreadYield
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdfbc69bb	VBoxGuest_RTThreadPreemptIsPendingTrusty
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe054d759	VBoxGuest_RTMemTmpFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe095cef8	VBoxGuest_RTThreadSetType
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe0dc7391	VBoxGuest_RTThreadIsMain
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe1c6b3d7	VBoxGuest_RTR0MemObjMapKernelExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe2765c54	VBoxGuest_RTR0AssertPanicSystem
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe38d562c	VBoxGuest_RTStrFormatNumber
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe3fd228f	VBoxGuest_RTTimeMilliTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe7e42113	VBoxGuest_RTThreadSleepNoLog
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe88dae73	VBoxGuest_RTMemFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe8fad285	VBoxGuest_RTSemEventMultiWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xea2f2944	VBoxGuest_RTStrToInt8Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xea38e4f7	VBoxGuest_RTLogDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xea71842b	VBoxGuest_RTMpGetPresentCoreCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xebeefa0e	VBoxGuest_RTR0ProcHandleSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xec3cc9a6	VBoxGuest_RTSemEventMultiWaitEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xee774b8e	VBoxGuest_RTLogWriteDebugger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xeea4ee73	VBoxGuest_RTR0MemObjMapUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xef6e1359	VBoxGuest_RTMpOnOthers
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf02f22ab	VBoxGuest_RTMemAllocZTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf0dbb702	VBoxGuest_RTHeapSimpleFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf26294bb	VBoxGuest_RTR0MemObjIsMapping
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf2aa79bb	VBoxGuest_RTThreadUserSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf3943009	VBoxGuest_RTTimerRequestSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf5d89855	VBoxGuest_RTLogGroupSettings
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf69aec24	VBoxGuest_RTStrToInt16Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf7397dd2	VBoxGuest_RTAssertSetMayPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf8113d66	VBoxGuest_RTMpOnAllIsConcurrentSafe
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf956a4e8	VBoxGuest_RTLogFlush
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf958d9cb	VBoxGuest_RTLogCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfa7d95c9	VBoxGuest_RTR0MemUserIsValidAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfb31e12b	VBoxGuest_RTStrToUInt32Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfba93ac9	VBoxGuest_RTR0MemObjReserveKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfbc67e88	VBoxGuest_RTMemFreeEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfe72cef7	VBoxGuest_RTStrToInt8
++EXPORT_SYMBOL vmlinux 0x00001eef	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0x0033b3a5	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0x003f0064	inet6_protos
++EXPORT_SYMBOL vmlinux 0x0053db54	get_phy_device
++EXPORT_SYMBOL vmlinux 0x0057a42f	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0x005c1542	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0x005cf447	param_set_ullong
++EXPORT_SYMBOL vmlinux 0x0069557b	mdiobus_free
++EXPORT_SYMBOL vmlinux 0x0070cd1f	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x0085e1f1	__do_once_done
++EXPORT_SYMBOL vmlinux 0x00b8c3a7	mempool_alloc
++EXPORT_SYMBOL vmlinux 0x00bd6b44	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0x00cc4b7b	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x00daf6a2	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0x00e1d088	d_invalidate
++EXPORT_SYMBOL vmlinux 0x00effacc	PDE_DATA
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x010a3a42	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x0125b495	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x013ddb0d	nvdimm_namespace_capacity
++EXPORT_SYMBOL vmlinux 0x013f1bf1	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0x01535f83	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0x015bc04d	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0x016bba17	x86_hyper_ms_hyperv
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x01a275e1	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0x01bdff09	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x01c32173	unlock_page
++EXPORT_SYMBOL vmlinux 0x01d1af43	mntput
++EXPORT_SYMBOL vmlinux 0x01d83e02	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x01f25d97	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0x02036975	__invalidate_device
++EXPORT_SYMBOL vmlinux 0x020c7b70	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x0221dbf7	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x0230d3a0	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0x02327dd7	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0x0237b57a	arch_unregister_cpu
++EXPORT_SYMBOL vmlinux 0x024bf827	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x0261d418	force_sig
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02e9bdb4	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x02f4f298	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0x02fedce6	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0x0301d8be	bio_map_kern
++EXPORT_SYMBOL vmlinux 0x03292b8c	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x0334ff19	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x033d78d1	page_symlink
++EXPORT_SYMBOL vmlinux 0x033e8f44	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x03a69301	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x03a70c4b	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0x03cbbad4	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0x03d385e0	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0x03dc968c	update_region
++EXPORT_SYMBOL vmlinux 0x03e8b811	block_commit_write
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x0426ba24	idr_for_each
++EXPORT_SYMBOL vmlinux 0x0437b311	sync_blockdev
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x0449609e	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0x0457fe71	__lock_page
++EXPORT_SYMBOL vmlinux 0x045c5e5c	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0x046efd57	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x04953668	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0x04b197f2	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x04c62fd7	__memset
++EXPORT_SYMBOL vmlinux 0x04d8c750	release_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04ea5d10	ksize
++EXPORT_SYMBOL vmlinux 0x04ee7038	register_netdev
++EXPORT_SYMBOL vmlinux 0x04f49cb4	pnp_request_card_device
++EXPORT_SYMBOL vmlinux 0x04fff17d	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0x050877b9	dmi_first_match
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x05332de5	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x0535b926	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0x053b427c	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x055c8559	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x05916789	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x0591e63e	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0x0595e91a	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0x05b793c5	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x05cc2e5e	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x06052f8d	__memmove
++EXPORT_SYMBOL vmlinux 0x06073585	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0x060778c9	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x061f4039	acpi_get_table_with_size
++EXPORT_SYMBOL vmlinux 0x0623743b	proc_douintvec
++EXPORT_SYMBOL vmlinux 0x062d9709	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x0630f96f	soft_cursor
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x063ee507	pnp_possible_config
++EXPORT_SYMBOL vmlinux 0x06410d19	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x064a19bd	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0x067a2fae	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x068a6efe	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x068c7263	ioremap_cache
++EXPORT_SYMBOL vmlinux 0x06a61158	unregister_nls
++EXPORT_SYMBOL vmlinux 0x06c0dae5	__kernel_fpu_end
++EXPORT_SYMBOL vmlinux 0x06c8c60f	brioctl_set
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x0711f0ea	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0x071f1d23	key_invalidate
++EXPORT_SYMBOL vmlinux 0x0723dabd	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0x0727c4f3	iowrite8
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x0735b18c	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0x0752d8bc	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x0757dc32	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x07825dad	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0x078772d5	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0x078822e4	gen_pool_create
++EXPORT_SYMBOL vmlinux 0x07a4b576	flex_array_free
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07a9ef84	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x07b180b2	write_one_page
++EXPORT_SYMBOL vmlinux 0x07b1dfb6	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x07be655d	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0x07c56eae	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x07cc24b4	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07ce86aa	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0x07f298a5	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x07fb2a97	would_dump
++EXPORT_SYMBOL vmlinux 0x07ff0849	twl6040_power
++EXPORT_SYMBOL vmlinux 0x08062573	revalidate_disk
++EXPORT_SYMBOL vmlinux 0x081f10d2	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x0820fc87	lro_flush_all
++EXPORT_SYMBOL vmlinux 0x08265113	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x0844364b	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0x0846717b	datagram_poll
++EXPORT_SYMBOL vmlinux 0x0864fb0d	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0x0897287b	acpi_disable_all_gpes
++EXPORT_SYMBOL vmlinux 0x08a986b1	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x08d37945	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0x08d41d3f	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x08ed39b2	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0x08fcb3b5	vfs_writev
++EXPORT_SYMBOL vmlinux 0x093e9b0c	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0x0948d823	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x09696626	acpi_decode_pld_buffer
++EXPORT_SYMBOL vmlinux 0x0975f2fa	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x0980f1c9	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0x098431ba	acpi_get_current_resources
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x09af5196	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0x09bc644c	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09e88526	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0x0a030233	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x0a0dbf87	dev_notice
++EXPORT_SYMBOL vmlinux 0x0a25b9e8	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a57863e	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x0a63cff4	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0x0a65a8c6	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0x0a661faa	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0x0a67dd52	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x0a68ec72	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0x0a6db909	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0x0a770832	register_memory_notifier
++EXPORT_SYMBOL vmlinux 0x0a8ce049	uart_resume_port
++EXPORT_SYMBOL vmlinux 0x0a957cb0	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0ac92312	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0ad42388	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x0af8074b	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b284142	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x0b2fac5c	d_path
++EXPORT_SYMBOL vmlinux 0x0b3de68a	neigh_update
++EXPORT_SYMBOL vmlinux 0x0b42366f	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b758a26	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x0b893dcf	blk_finish_request
++EXPORT_SYMBOL vmlinux 0x0b905c66	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x0b990688	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0x0ba49aa5	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x0ba94b04	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0x0babcf80	open_exec
++EXPORT_SYMBOL vmlinux 0x0bba2069	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc3f77f	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bc919ca	acl_by_type
++EXPORT_SYMBOL vmlinux 0x0bdb2dc8	do_splice_direct
++EXPORT_SYMBOL vmlinux 0x0be2ad5b	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0x0bfcca83	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x0bff4e36	xattr_full_name
++EXPORT_SYMBOL vmlinux 0x0c00ad92	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x0c0ae894	nd_dev_to_uuid
++EXPORT_SYMBOL vmlinux 0x0c21d019	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0x0c42913f	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c69c353	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x0c6bdc3f	vme_master_read
++EXPORT_SYMBOL vmlinux 0x0c825b9d	ilookup
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0ca7b7a8	acpi_check_region
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cdb7d12	__kernel_fpu_begin
++EXPORT_SYMBOL vmlinux 0x0cf14048	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0x0d021cd4	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0x0d3dda14	acpi_get_type
++EXPORT_SYMBOL vmlinux 0x0d42a510	mmc_free_host
++EXPORT_SYMBOL vmlinux 0x0d53ed85	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d597d1d	__f_setown
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d68e7c5	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0x0d71ef32	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0x0d7258f2	param_get_short
++EXPORT_SYMBOL vmlinux 0x0d80efb5	acpi_evaluate_ost
++EXPORT_SYMBOL vmlinux 0x0d9019dd	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x0d96ebd5	compat_ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0da190a9	bio_add_page
++EXPORT_SYMBOL vmlinux 0x0dc6feca	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0x0dcc4361	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x0dd599df	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x0df439a8	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0x0df58112	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0x0e075aee	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0x0e0f38b6	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0x0e3027bd	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0x0e33f39c	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x0e36496d	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e763606	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x0e7ef864	generic_write_checks
++EXPORT_SYMBOL vmlinux 0x0e87daf6	seq_release
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0ed8cc7b	acpi_evaluate_object_typed
++EXPORT_SYMBOL vmlinux 0x0ee7b834	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x0eeec7bb	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f3999f1	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x0f3b576e	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f5dab6c	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x0f66a9b0	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f8ad1c4	param_get_uint
++EXPORT_SYMBOL vmlinux 0x0f9114b4	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0x0f9b4a97	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0x0fa55ffb	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb0f70d	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fb7d3de	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0x0fc3569d	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x0fc6943e	fb_set_var
++EXPORT_SYMBOL vmlinux 0x0fc87c38	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x0fd00a68	acpi_clear_event
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x0fff2b42	page_waitqueue
++EXPORT_SYMBOL vmlinux 0x100e00e9	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x10126ec7	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x1027f4a8	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x10294acd	cdev_init
++EXPORT_SYMBOL vmlinux 0x10309451	icmpv6_send
++EXPORT_SYMBOL vmlinux 0x1072a394	csum_partial_copy_from_user
++EXPORT_SYMBOL vmlinux 0x10738989	netdev_err
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x108d6f06	agp_alloc_bridge
++EXPORT_SYMBOL vmlinux 0x10950ee1	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x1099fa5c	security_path_symlink
++EXPORT_SYMBOL vmlinux 0x109c58af	devm_free_irq
++EXPORT_SYMBOL vmlinux 0x10c3e712	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x10c7d031	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0x10eae2d3	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x10fd7c9f	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x1100999e	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x111137f8	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0x114f7292	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x11666881	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x117bcf99	__blk_end_request
++EXPORT_SYMBOL vmlinux 0x118ae3f9	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x118b0ed2	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0x118c0dc9	skb_push
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11bf7d48	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0x11ee94f9	sock_release
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120c42d6	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0x120d67d4	unregister_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x1217830a	compat_sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x123f82f3	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x12433d54	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0x1243abd1	__kernel_write
++EXPORT_SYMBOL vmlinux 0x1248ab0f	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0x1250c7e1	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x12558ea1	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x127b2c4d	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12cc0645	sg_miter_next
++EXPORT_SYMBOL vmlinux 0x12d95aa2	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x12dfeb12	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x1305d532	ucs2_strncmp
++EXPORT_SYMBOL vmlinux 0x1306b06c	i2c_transfer
++EXPORT_SYMBOL vmlinux 0x1317b1f3	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x132a2b10	i8042_remove_filter
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x13315729	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0x13363f70	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x135e4e93	param_get_ullong
++EXPORT_SYMBOL vmlinux 0x1360122a	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0x137760c3	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0x138cd66f	input_reset_device
++EXPORT_SYMBOL vmlinux 0x138ea778	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x13968c7f	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0x13a146a9	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x13a7f271	udp_del_offload
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13e05678	generic_setxattr
++EXPORT_SYMBOL vmlinux 0x13f004f9	kernel_accept
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x13ff1b98	pci_iounmap
++EXPORT_SYMBOL vmlinux 0x1403a42d	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0x141ce8c1	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x14557fb2	up_write
++EXPORT_SYMBOL vmlinux 0x1463d80d	put_tty_driver
++EXPORT_SYMBOL vmlinux 0x146eb343	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0x147a798b	sync_filesystem
++EXPORT_SYMBOL vmlinux 0x14820128	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0x14838266	serio_rescan
++EXPORT_SYMBOL vmlinux 0x149a62a0	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0x14ab06a3	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0x14b3289e	acpi_pm_device_sleep_state
++EXPORT_SYMBOL vmlinux 0x14c06b51	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0x14c3769d	secpath_dup
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x14d5f9fc	free_task
++EXPORT_SYMBOL vmlinux 0x14da914f	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0x14e298d4	arp_xmit
++EXPORT_SYMBOL vmlinux 0x14e56ed4	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x14e6cf02	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0x14e7a58c	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0x1501a3bc	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x150389d6	acpi_processor_power_init_bm_check
++EXPORT_SYMBOL vmlinux 0x15136f1e	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x151b71cb	set_binfmt
++EXPORT_SYMBOL vmlinux 0x151fd60e	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0x1530ef67	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0x1533083e	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x1547bfd6	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x15500247	fb_class
++EXPORT_SYMBOL vmlinux 0x156a8a59	down_trylock
++EXPORT_SYMBOL vmlinux 0x15799c11	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0x158294e5	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x15a83997	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15c302e1	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0x160ea4c8	sfi_disabled
++EXPORT_SYMBOL vmlinux 0x1616cb30	acpi_evaluate_dsm
++EXPORT_SYMBOL vmlinux 0x162d53cc	security_path_unlink
++EXPORT_SYMBOL vmlinux 0x16305289	warn_slowpath_null
++EXPORT_SYMBOL vmlinux 0x1642b519	prepare_creds
++EXPORT_SYMBOL vmlinux 0x165284c9	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0x165dadba	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0x1665a916	key_alloc
++EXPORT_SYMBOL vmlinux 0x1667ad75	tty_name
++EXPORT_SYMBOL vmlinux 0x167c5967	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x167e7f9d	__get_user_1
++EXPORT_SYMBOL vmlinux 0x16855149	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x16a87ec8	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0x16b85c69	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x16c851ca	fb_show_logo
++EXPORT_SYMBOL vmlinux 0x16dc4d1f	fence_init
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x16f4bd6b	inet_frag_find
++EXPORT_SYMBOL vmlinux 0x170c25ee	acpi_get_next_object
++EXPORT_SYMBOL vmlinux 0x17353a27	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x17465b17	set_pages_array_wc
++EXPORT_SYMBOL vmlinux 0x174b5c79	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0x178926b2	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x178fc438	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x1793f685	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0x179651ac	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x17a161b2	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17c532a8	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0x17e537e9	generic_perform_write
++EXPORT_SYMBOL vmlinux 0x17ee365e	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0x17efeedb	do_splice_to
++EXPORT_SYMBOL vmlinux 0x17f341a0	i8042_lock_chip
++EXPORT_SYMBOL vmlinux 0x18091ea0	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x182af0fa	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x1835811b	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x1842616c	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x1848874b	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x18828ac8	input_event
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x189acf49	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x18a0715b	nd_iostat_end
++EXPORT_SYMBOL vmlinux 0x18a59c2c	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x18b72573	register_kmmio_probe
++EXPORT_SYMBOL vmlinux 0x18b8d92e	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x18ca6192	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x18e8b540	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x190355a0	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0x190c37f5	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0x1916e38c	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x1946776e	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x1983154e	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x19865fac	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19c0ef20	account_page_redirty
++EXPORT_SYMBOL vmlinux 0x19e55061	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x19ec4a82	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x19f5857d	inet_sendpage
++EXPORT_SYMBOL vmlinux 0x1a03950b	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0x1a0c2d90	da903x_query_status
++EXPORT_SYMBOL vmlinux 0x1a24ec66	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x1a45cb6c	acpi_disabled
++EXPORT_SYMBOL vmlinux 0x1a4d7bc2	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0x1a4f7ba7	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x1a50ad6b	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x1a50bda2	set_page_dirty
++EXPORT_SYMBOL vmlinux 0x1a50c096	sock_no_listen
++EXPORT_SYMBOL vmlinux 0x1a63af34	vga_switcheroo_process_delayed_switch
++EXPORT_SYMBOL vmlinux 0x1a6415d2	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x1a654cb3	tc_classify
++EXPORT_SYMBOL vmlinux 0x1a7f8ff7	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0x1a86e5f4	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x1a9f8ac2	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0x1aa41715	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0x1aae9d85	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0x1ac5d3cb	strcspn
++EXPORT_SYMBOL vmlinux 0x1ac9885d	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0x1acd9b05	tcp_prot
++EXPORT_SYMBOL vmlinux 0x1ae09f75	_raw_write_unlock_irq
++EXPORT_SYMBOL vmlinux 0x1aee6df2	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0x1afb1aaa	acpi_mark_gpe_for_wake
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b13f3f6	dev_warn
++EXPORT_SYMBOL vmlinux 0x1b189b2c	request_key_async
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b29d19c	tty_free_termios
++EXPORT_SYMBOL vmlinux 0x1b411645	input_grab_device
++EXPORT_SYMBOL vmlinux 0x1b570d23	acpi_warning
++EXPORT_SYMBOL vmlinux 0x1b5d7f4e	fsync_bdev
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b7ed715	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x1b82dba2	nd_namespace_blk_validate
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b8b95ad	i8042_unlock_chip
++EXPORT_SYMBOL vmlinux 0x1ba71c4c	skb_unlink
++EXPORT_SYMBOL vmlinux 0x1ba878cc	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bb3e2c5	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x1bbb6f98	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0x1bd4c807	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x1bddb1bb	__ps2_command
++EXPORT_SYMBOL vmlinux 0x1be1dd26	lg_global_lock
++EXPORT_SYMBOL vmlinux 0x1c24f74d	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0x1c2e85e1	misc_deregister
++EXPORT_SYMBOL vmlinux 0x1c301f33	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0x1c699798	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0x1c8a04b0	acpi_reset
++EXPORT_SYMBOL vmlinux 0x1c9a6feb	acpi_match_device_ids
++EXPORT_SYMBOL vmlinux 0x1cac4727	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0x1ce5cede	nd_pfn_probe
++EXPORT_SYMBOL vmlinux 0x1d1056e5	crc32_be
++EXPORT_SYMBOL vmlinux 0x1d476074	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0x1d5c2f35	dump_trace
++EXPORT_SYMBOL vmlinux 0x1d7b5df3	vm_map_ram
++EXPORT_SYMBOL vmlinux 0x1d890288	led_set_brightness
++EXPORT_SYMBOL vmlinux 0x1d8b40c6	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x1d96a5d9	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0x1db658c3	is_nd_pfn
++EXPORT_SYMBOL vmlinux 0x1db6ee1f	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0x1db7706b	__copy_user_nocache
++EXPORT_SYMBOL vmlinux 0x1db7f531	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dc39582	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1ddd9889	__find_get_block
++EXPORT_SYMBOL vmlinux 0x1de74f72	acpi_execute_simple_method
++EXPORT_SYMBOL vmlinux 0x1df984ab	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0x1dfd47b3	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x1e00ba5f	d_instantiate
++EXPORT_SYMBOL vmlinux 0x1e036c98	acpi_set_gpe
++EXPORT_SYMBOL vmlinux 0x1e047854	warn_slowpath_fmt
++EXPORT_SYMBOL vmlinux 0x1e0c2be4	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x1e0dadb6	dns_query
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e3364b5	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x1e3764b3	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0x1e3c1ff3	input_free_device
++EXPORT_SYMBOL vmlinux 0x1e40df47	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x1e51af8a	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ea9c10d	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0x1eb42448	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x1eb922a3	IO_APIC_get_PCI_irq_vector
++EXPORT_SYMBOL vmlinux 0x1ec37ca0	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0x1edc53c5	param_set_short
++EXPORT_SYMBOL vmlinux 0x1ef80b99	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0x1efbf1b4	param_get_charp
++EXPORT_SYMBOL vmlinux 0x1f1307b8	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x1f385737	seq_lseek
++EXPORT_SYMBOL vmlinux 0x1f3ddcbe	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0x1f6ce67a	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x1f7459f6	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0x1f988b05	ping_prot
++EXPORT_SYMBOL vmlinux 0x1faa9bd4	phy_device_free
++EXPORT_SYMBOL vmlinux 0x1fac09fd	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0x1fb6612c	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fc8e63e	nvm_end_io
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x1ff8bffc	__mutex_init
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x2005e68a	acpi_remove_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x20092385	acpi_enter_sleep_state_s4bios
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x200e0a97	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0x201b0ac0	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0x201d4961	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0x2044aea7	amd_iommu_pc_get_max_banks
++EXPORT_SYMBOL vmlinux 0x204b8c16	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x2062db11	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x2084ede5	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0x208739f6	acpi_load_table
++EXPORT_SYMBOL vmlinux 0x20a1975a	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20a9e61b	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x20bf7bd1	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20d7e292	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0x20d88e31	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x20dc5481	pci_dev_get
++EXPORT_SYMBOL vmlinux 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x20eadeb6	ip_compute_csum
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20fbe8ee	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x20fc1ecc	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x21088823	tty_port_open
++EXPORT_SYMBOL vmlinux 0x21108a99	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x211f68f1	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x21508af3	netdev_warn
++EXPORT_SYMBOL vmlinux 0x217fc053	tso_start
++EXPORT_SYMBOL vmlinux 0x218124d3	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0x21875925	genphy_config_init
++EXPORT_SYMBOL vmlinux 0x218a36b6	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0x218a6847	dput
++EXPORT_SYMBOL vmlinux 0x219b3196	compat_sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x21a701fe	fence_signal
++EXPORT_SYMBOL vmlinux 0x21ceda93	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21e133f8	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x21e992a5	ida_simple_get
++EXPORT_SYMBOL vmlinux 0x220693a2	blk_rq_init
++EXPORT_SYMBOL vmlinux 0x2207a57f	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x220ef981	security_path_truncate
++EXPORT_SYMBOL vmlinux 0x2216463c	dma_find_channel
++EXPORT_SYMBOL vmlinux 0x2229b9d9	param_ops_byte
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x2250b9b1	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0x225aded9	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0x225d42bc	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x2275a315	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x22767127	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22d2d913	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0x22dce004	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0x22ee0f89	dqput
++EXPORT_SYMBOL vmlinux 0x22fb64a6	nf_log_register
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x231e1843	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x23281121	bioset_free
++EXPORT_SYMBOL vmlinux 0x232d18ec	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0x234bd8fd	pnp_activate_dev
++EXPORT_SYMBOL vmlinux 0x235d3640	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0x235fcc13	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x237902bb	vga_switcheroo_register_audio_client
++EXPORT_SYMBOL vmlinux 0x2381496e	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x23892dfb	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x23a10e4d	unregister_console
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23c4a74c	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x23c826a7	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23c9891c	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x23cf97db	vm_event_states
++EXPORT_SYMBOL vmlinux 0x23d02ba4	nd_btt_arena_is_valid
++EXPORT_SYMBOL vmlinux 0x23ea0ed2	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x241ab06c	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x2439da12	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x2445a234	md_write_end
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x246d838a	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0x246f437a	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x247482a9	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x2484262a	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0x2484adc3	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0x2494fbb9	unload_nls
++EXPORT_SYMBOL vmlinux 0x249b6181	pnp_register_card_driver
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x250b45f9	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x252cd274	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0x25338d91	vme_bus_num
++EXPORT_SYMBOL vmlinux 0x2565b4e9	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0x256e4dc7	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x2574eea5	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0x257de643	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x25856b5d	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x25b486d9	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0x25be085f	agp_free_memory
++EXPORT_SYMBOL vmlinux 0x25c0646a	pv_cpu_ops
++EXPORT_SYMBOL vmlinux 0x25cd061e	gnttab_alloc_pages
++EXPORT_SYMBOL vmlinux 0x25dd9186	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x25e8ed29	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x2602d2fc	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x2610f0e2	pci_set_master
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x2665d53a	key_create_or_update
++EXPORT_SYMBOL vmlinux 0x267c2016	cros_ec_check_result
++EXPORT_SYMBOL vmlinux 0x267c54c9	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x26948d96	copy_user_enhanced_fast_string
++EXPORT_SYMBOL vmlinux 0x2696fc55	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x26ac0089	cont_write_begin
++EXPORT_SYMBOL vmlinux 0x26b41431	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x26b84045	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0x26bef759	md_register_thread
++EXPORT_SYMBOL vmlinux 0x26c31cae	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x26cb34a2	mempool_create
++EXPORT_SYMBOL vmlinux 0x26cef793	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x26dca014	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x26e298e0	unregister_memory_notifier
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x271c315c	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x271cba95	acpi_bus_private_data_handler
++EXPORT_SYMBOL vmlinux 0x27443b19	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x274b799a	del_gendisk
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x275edd8d	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0x27613e1e	vga_switcheroo_set_dynamic_switch
++EXPORT_SYMBOL vmlinux 0x27717e43	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x277be5f6	dget_parent
++EXPORT_SYMBOL vmlinux 0x27845b78	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x27882b9b	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0x27ae7d0c	ec_transaction
++EXPORT_SYMBOL vmlinux 0x27b5c5f1	sk_common_release
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27c33efe	csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x28009c63	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0x2813fcac	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x28318305	snprintf
++EXPORT_SYMBOL vmlinux 0x284692b8	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x284d1739	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x2859d9b5	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0x28761c5b	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x289160e2	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x28997d8f	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x28a2b29f	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28abfe6e	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x28e09af1	iosf_mbi_available
++EXPORT_SYMBOL vmlinux 0x292720df	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0x292c520c	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0x29331872	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x293651c8	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x295e6c9c	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x297fed15	agp_generic_alloc_pages
++EXPORT_SYMBOL vmlinux 0x298168a6	bdgrab
++EXPORT_SYMBOL vmlinux 0x29818e30	dquot_initialize
++EXPORT_SYMBOL vmlinux 0x29925b2c	vfs_readv
++EXPORT_SYMBOL vmlinux 0x299933ec	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x29a83529	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x29ad58e5	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x29b0c263	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0x29b2279e	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x29bf09cf	blk_init_queue
++EXPORT_SYMBOL vmlinux 0x29bf847d	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x29c4158e	filemap_fault
++EXPORT_SYMBOL vmlinux 0x29cd1b6d	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0x2a04f7a8	block_write_full_page
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a3d8ca9	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x2a442ff8	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0x2a4e8223	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0x2a565a25	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0x2a572390	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0x2a74362b	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0x2a778032	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0x2a91e6b0	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2aaee03d	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x2ac7ae9b	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2ae7eb50	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0x2af7e095	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0x2b05a21b	intel_gtt_get
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b239f32	elv_rb_del
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b403c57	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x2b45431e	dev_mc_add
++EXPORT_SYMBOL vmlinux 0x2b4a97c0	devm_clk_put
++EXPORT_SYMBOL vmlinux 0x2b4c169c	follow_pfn
++EXPORT_SYMBOL vmlinux 0x2b674ff2	kernel_write
++EXPORT_SYMBOL vmlinux 0x2b954221	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2b9fa57d	nvdimm_namespace_common_probe
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2bb55d6e	acpi_remove_notify_handler
++EXPORT_SYMBOL vmlinux 0x2bc0bb5b	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x2bcce224	textsearch_register
++EXPORT_SYMBOL vmlinux 0x2bd26d8f	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x2bdbf9d0	security_path_rename
++EXPORT_SYMBOL vmlinux 0x2bfeb410	acpi_get_handle
++EXPORT_SYMBOL vmlinux 0x2c0ce567	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x2c16a088	fput
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c540faf	security_path_chown
++EXPORT_SYMBOL vmlinux 0x2c61dea8	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x2c668d7b	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x2c6babb0	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0x2c7b00ad	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x2ca319a6	wrmsrl_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x2cb7f160	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x2cc40ecf	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0x2cc6499e	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0x2cc93760	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x2cd4db8d	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0x2cd90423	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0x2ce4c2db	__get_page_tail
++EXPORT_SYMBOL vmlinux 0x2cf4617b	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0x2cf73cb7	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x2d048f0f	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d144e21	rdmsrl_on_cpu
++EXPORT_SYMBOL vmlinux 0x2d240ea5	d_move
++EXPORT_SYMBOL vmlinux 0x2d294419	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0x2d2bfc01	ht_create_irq
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d30f7d0	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d563fe0	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0x2d739cc4	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0x2dd16564	arch_register_cpu
++EXPORT_SYMBOL vmlinux 0x2dd89e3a	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x2dd9a36b	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x2de7b62d	param_get_bool
++EXPORT_SYMBOL vmlinux 0x2dedc4c2	acpi_format_exception
++EXPORT_SYMBOL vmlinux 0x2def7f76	rtc_cmos_write
++EXPORT_SYMBOL vmlinux 0x2dff016b	param_get_string
++EXPORT_SYMBOL vmlinux 0x2e08e9f4	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x2e0d2f7f	queue_work_on
++EXPORT_SYMBOL vmlinux 0x2e0fe05a	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e2b40d2	strncat
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e3027df	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0x2e593a27	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0x2e5d1f36	md_write_start
++EXPORT_SYMBOL vmlinux 0x2e61cb65	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x2e6cee29	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x2e86c9ea	request_key
++EXPORT_SYMBOL vmlinux 0x2e8c3379	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0x2ea6ecf2	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0x2eacc48e	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0x2eae71e5	__quota_error
++EXPORT_SYMBOL vmlinux 0x2eb15b80	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x2eb8e3dc	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0x2ef24fb9	bdget_disk
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f0fd3ea	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x2f384db3	acpi_is_video_device
++EXPORT_SYMBOL vmlinux 0x2f454a62	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2f64f89f	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x2f6f9a59	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0x2f8bed12	file_update_time
++EXPORT_SYMBOL vmlinux 0x2fa9214f	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0x2fb4f3e6	md_integrity_register
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fd9eafb	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2ff063b5	acpi_get_name
++EXPORT_SYMBOL vmlinux 0x2fff7bf0	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x30045b50	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x30226ddf	agp_device_command
++EXPORT_SYMBOL vmlinux 0x3027475e	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x303542c1	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0x3040d417	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0x304602a7	phy_detach
++EXPORT_SYMBOL vmlinux 0x304895bc	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x3058ebf0	param_ops_bint
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x307d7ede	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0x30914151	scsi_unregister
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30b04526	ida_init
++EXPORT_SYMBOL vmlinux 0x30b8cd99	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x30faf705	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x3108e6ba	tty_do_resize
++EXPORT_SYMBOL vmlinux 0x310ac1be	consume_skb
++EXPORT_SYMBOL vmlinux 0x310f02ec	memremap
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x3174667e	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x3178a4e9	nobh_writepage
++EXPORT_SYMBOL vmlinux 0x3179745e	phy_stop
++EXPORT_SYMBOL vmlinux 0x31802191	add_disk
++EXPORT_SYMBOL vmlinux 0x31a76715	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0x31a7cffb	agp_enable
++EXPORT_SYMBOL vmlinux 0x31b31f5c	csum_partial_copy_nocheck
++EXPORT_SYMBOL vmlinux 0x31c4961b	tty_port_close
++EXPORT_SYMBOL vmlinux 0x31e648fb	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0x31e76b57	recalibrate_cpu_khz
++EXPORT_SYMBOL vmlinux 0x31ec44a0	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0x3202435a	wrmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0x322707e9	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x3232293c	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0x323aba2a	down_write_trylock
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x3250821b	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0x325444ea	_dev_info
++EXPORT_SYMBOL vmlinux 0x326425ca	pci_unmap_biosrom
++EXPORT_SYMBOL vmlinux 0x3293fd5f	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x329df35e	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x32b41ea0	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x32b6984e	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x32c783e0	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0x32cc163f	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0x32ddc69b	nd_sb_checksum
++EXPORT_SYMBOL vmlinux 0x32e2572c	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0x32e6f1a0	acpi_video_backlight_string
++EXPORT_SYMBOL vmlinux 0x32fa7583	free_page_put_link
++EXPORT_SYMBOL vmlinux 0x330698a0	kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x333cb37c	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x33486c56	start_tty
++EXPORT_SYMBOL vmlinux 0x33722104	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0x337a41de	noop_llseek
++EXPORT_SYMBOL vmlinux 0x33a74249	amd_iommu_flush_tlb
++EXPORT_SYMBOL vmlinux 0x33b84f74	copy_page
++EXPORT_SYMBOL vmlinux 0x33c38e75	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x33c5d3fc	bdi_destroy
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33c9cc20	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x33eee910	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x33fcf44a	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0x34143b24	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0x341b0228	mutex_lock
++EXPORT_SYMBOL vmlinux 0x34408e9c	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0x344340ae	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0x344aa414	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0x344e4d1b	vme_bus_type
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x349213ef	cpu_core_map
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34abfd5f	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0x34cc4ff7	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x34d6543b	read_code
++EXPORT_SYMBOL vmlinux 0x34daad66	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0x34dba3cb	param_set_charp
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x3530caee	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0x3539f11b	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x353e21e3	acpi_bios_warning
++EXPORT_SYMBOL vmlinux 0x35494357	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x35567848	vm_mmap
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x35725335	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x35a327e2	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35d64d2f	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0x35e02e0d	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x360156d4	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0x360b1afe	probe_irq_mask
++EXPORT_SYMBOL vmlinux 0x362dd738	put_disk
++EXPORT_SYMBOL vmlinux 0x3632ca45	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0x363aacb7	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0x36406496	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0x36628614	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0x366875ea	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x366b5db6	tty_set_operations
++EXPORT_SYMBOL vmlinux 0x367c753e	sock_init_data
++EXPORT_SYMBOL vmlinux 0x3680037c	vc_cons
++EXPORT_SYMBOL vmlinux 0x368f308e	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0x369e1115	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36d194a4	nf_afinfo
++EXPORT_SYMBOL vmlinux 0x36edfa31	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x36f07ce9	mmc_release_host
++EXPORT_SYMBOL vmlinux 0x3701a196	csum_partial_copy_to_user
++EXPORT_SYMBOL vmlinux 0x370325be	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0x370a091f	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0x370f9850	efi
++EXPORT_SYMBOL vmlinux 0x3729f6db	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x3753e41e	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0x375a3bb8	bio_advance
++EXPORT_SYMBOL vmlinux 0x3798f9e4	dev_set_group
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37b8b39e	screen_info
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37cfe835	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0x37db8f19	dmi_get_date
++EXPORT_SYMBOL vmlinux 0x37f68ac4	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x37ff48c8	tty_devnum
++EXPORT_SYMBOL vmlinux 0x38099e13	wrmsrl_on_cpu
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x3849183a	blk_start_queue
++EXPORT_SYMBOL vmlinux 0x3862e484	nvdimm_namespace_disk_name
++EXPORT_SYMBOL vmlinux 0x38662153	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x386688ef	sock_wake_async
++EXPORT_SYMBOL vmlinux 0x38749aa4	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0x3877b207	agp_copy_info
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x3886cdf8	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0x38a2bd2b	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x38a4e4e8	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a76d50	pci_request_regions
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38b1cae3	dst_release
++EXPORT_SYMBOL vmlinux 0x38b76b2b	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x38b870b6	copy_from_iter
++EXPORT_SYMBOL vmlinux 0x38be367d	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0x38c23acd	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x38dd8a0d	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0x38f33bed	dump_fpu
++EXPORT_SYMBOL vmlinux 0x39081193	__max_logical_packages
++EXPORT_SYMBOL vmlinux 0x390a1155	phy_suspend
++EXPORT_SYMBOL vmlinux 0x390b5752	kset_unregister
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x393d4de9	crc32_le
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x3955fcf6	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x39592d39	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0x3964c441	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x397bdd46	param_array_ops
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x399ad043	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0x399f6ac1	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x399f9042	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0x39a055f3	acpi_remove_gpe_handler
++EXPORT_SYMBOL vmlinux 0x39a1572a	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x39a824db	register_md_personality
++EXPORT_SYMBOL vmlinux 0x39b16649	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39bc0b83	udp_add_offload
++EXPORT_SYMBOL vmlinux 0x39bcce3a	register_qdisc
++EXPORT_SYMBOL vmlinux 0x39c640b5	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0x39dd9223	x86_hyper_vmware
++EXPORT_SYMBOL vmlinux 0x39edab12	skb_make_writable
++EXPORT_SYMBOL vmlinux 0x39f1c2f4	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x39f51c32	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x39f9a2ff	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0x3a0779b1	register_framebuffer
++EXPORT_SYMBOL vmlinux 0x3a08475f	platform_thermal_notify
++EXPORT_SYMBOL vmlinux 0x3a1e3d9e	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0x3a1e4170	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0x3a2255d8	md_error
++EXPORT_SYMBOL vmlinux 0x3a32839e	intel_gtt_chipset_flush
++EXPORT_SYMBOL vmlinux 0x3a4c3b46	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x3a595f02	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0x3a763872	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x3a8967e7	amd_iommu_device_info
++EXPORT_SYMBOL vmlinux 0x3a938b20	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0x3a99e4c8	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3abd1647	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0x3ac30fe5	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0x3acaa9c5	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x3ad6bb9a	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0x3ad734c3	inet_bind
++EXPORT_SYMBOL vmlinux 0x3ae7ee3e	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x3b04ea9a	proc_set_size
++EXPORT_SYMBOL vmlinux 0x3b1f0b08	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x3b21fe84	from_kuid
++EXPORT_SYMBOL vmlinux 0x3b267a53	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0x3b31b1e8	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0x3b3956ff	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x3b600dda	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b6f6cd2	udp_table
++EXPORT_SYMBOL vmlinux 0x3b7aa2f4	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0x3b81b0b9	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0x3ba5667f	file_ns_capable
++EXPORT_SYMBOL vmlinux 0x3bae349e	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x3bb5114a	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x3bd4cb99	follow_down_one
++EXPORT_SYMBOL vmlinux 0x3c0725c9	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0x3c0736cb	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c483012	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x3c4b28a4	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x3c4ee114	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0x3c531a89	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0x3c5c3796	write_cache_pages
++EXPORT_SYMBOL vmlinux 0x3c5d68a1	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0x3c665c56	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c81b1ac	acpi_processor_notify_smm
++EXPORT_SYMBOL vmlinux 0x3c865542	d_drop
++EXPORT_SYMBOL vmlinux 0x3c91b697	scsi_register
++EXPORT_SYMBOL vmlinux 0x3c9898f6	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x3cafeea8	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x3cbd19fe	ata_port_printk
++EXPORT_SYMBOL vmlinux 0x3cc4a711	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3d1391e2	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x3d26f767	udp_prot
++EXPORT_SYMBOL vmlinux 0x3d2d86f6	filp_open
++EXPORT_SYMBOL vmlinux 0x3d544aa5	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0x3d7c1ed7	msrs_alloc
++EXPORT_SYMBOL vmlinux 0x3d864f39	skb_split
++EXPORT_SYMBOL vmlinux 0x3d900220	i2c_master_send
++EXPORT_SYMBOL vmlinux 0x3d9abda1	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0x3d9ee9f0	clear_page
++EXPORT_SYMBOL vmlinux 0x3da171f9	pci_mem_start
++EXPORT_SYMBOL vmlinux 0x3dbf36c9	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3de148a4	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x3de7bb0c	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0x3de7fd82	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x3deba128	proc_remove
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e065e81	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0x3e084316	posix_test_lock
++EXPORT_SYMBOL vmlinux 0x3e1729a5	put_io_context
++EXPORT_SYMBOL vmlinux 0x3e1e6424	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x3e220949	skb_copy
++EXPORT_SYMBOL vmlinux 0x3e22c0b1	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0x3e2ae3a8	acpi_release_global_lock
++EXPORT_SYMBOL vmlinux 0x3e2c4692	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0x3e324648	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0x3e3d9789	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0x3e3e4c58	node_data
++EXPORT_SYMBOL vmlinux 0x3e4dc5c4	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0x3e5bb9bd	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x3e67fc31	pci_iomap
++EXPORT_SYMBOL vmlinux 0x3e6af823	nd_region_acquire_lane
++EXPORT_SYMBOL vmlinux 0x3e882943	pcibios_align_resource
++EXPORT_SYMBOL vmlinux 0x3e8b5fe9	phy_print_status
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x3ea35991	tcp_connect
++EXPORT_SYMBOL vmlinux 0x3ed33cab	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x3f0546a8	ioread32_rep
++EXPORT_SYMBOL vmlinux 0x3f0ba86e	eth_header
++EXPORT_SYMBOL vmlinux 0x3f20ca97	rtc_lock
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f494964	dma_supported
++EXPORT_SYMBOL vmlinux 0x3f580079	fb_is_primary_device
++EXPORT_SYMBOL vmlinux 0x3f58012a	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0x3f785314	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0x3f7dd44f	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0x3f9bcc28	sget
++EXPORT_SYMBOL vmlinux 0x3fb6cbcf	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0x3fd08ba4	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0x3fe2ccbe	memweight
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x3ff597fc	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0x3ff95218	flush_signals
++EXPORT_SYMBOL vmlinux 0x4010e00b	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0x4011e255	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x401c0e16	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4039918a	clk_register_clkdev
++EXPORT_SYMBOL vmlinux 0x403a629d	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0x4042b3ab	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0x40498229	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0x4052b3f0	kern_path
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x406b867f	pci_release_region
++EXPORT_SYMBOL vmlinux 0x407c9cd3	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0x40854caa	fget
++EXPORT_SYMBOL vmlinux 0x408a4ed5	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x4097fa45	acpi_read_bit_register
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40bc108b	compat_nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x40befdbb	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40c7d843	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x40c89d46	acpi_get_table_by_index
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40dc2987	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0x40e6df69	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x4125a773	current_task
++EXPORT_SYMBOL vmlinux 0x4132344d	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x414d9060	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0x414e50b1	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x41525446	dm_get_device
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x4162b81a	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x417d203e	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x41a3fbf1	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x41baf194	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0x41bb51ff	__getblk_slow
++EXPORT_SYMBOL vmlinux 0x41c06b11	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0x41eb6d06	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x421a11c2	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0x4234f096	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x42350e8d	ucs2_strlen
++EXPORT_SYMBOL vmlinux 0x42376605	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x424f89c8	km_state_expired
++EXPORT_SYMBOL vmlinux 0x42595e58	vgacon_text_force
++EXPORT_SYMBOL vmlinux 0x425d0855	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x42873050	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0x4290d30a	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x429c0347	gnttab_free_pages
++EXPORT_SYMBOL vmlinux 0x42a02767	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42a8955c	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x42a93b8f	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x42c8de35	ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x42f245b6	passthru_features_check
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x432815dd	find_lock_entry
++EXPORT_SYMBOL vmlinux 0x432c634a	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0x432e1a4b	cros_ec_query_all
++EXPORT_SYMBOL vmlinux 0x4337bf4e	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0x433ab7d5	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x43607d51	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0x436c2179	iowrite32
++EXPORT_SYMBOL vmlinux 0x437cccc9	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x438424fb	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x43a9d32c	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x43ac46fd	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0x43b0c9c3	preempt_schedule
++EXPORT_SYMBOL vmlinux 0x43cfe6cb	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0x43d9960f	mmc_start_req
++EXPORT_SYMBOL vmlinux 0x43e39b43	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x43fc9bed	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0x4401f993	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x440d19c1	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x4411072b	skb_insert
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x44475d62	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x444df961	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0x4488ae17	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x4489da02	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0x448e085f	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x448eac3e	kmemdup
++EXPORT_SYMBOL vmlinux 0x4498731a	ip_defrag
++EXPORT_SYMBOL vmlinux 0x449ad0a7	memcmp
++EXPORT_SYMBOL vmlinux 0x449fe84b	acpi_set_firmware_waking_vectors
++EXPORT_SYMBOL vmlinux 0x44a81d5f	acpi_evaluate_object
++EXPORT_SYMBOL vmlinux 0x44aaf30f	tsc_khz
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44d09599	clkdev_add
++EXPORT_SYMBOL vmlinux 0x44d50a8e	find_get_entry
++EXPORT_SYMBOL vmlinux 0x44db0149	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x4500ee57	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x45081703	ec_get_handle
++EXPORT_SYMBOL vmlinux 0x452d5f9f	blk_run_queue
++EXPORT_SYMBOL vmlinux 0x452e4eda	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x45403778	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x457e8fec	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x457f95b4	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45db9e9c	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0x45ed278f	kfree_skb
++EXPORT_SYMBOL vmlinux 0x45f1df0a	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x45f9750f	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0x45fb3293	dquot_operations
++EXPORT_SYMBOL vmlinux 0x4604a43a	mem_section
++EXPORT_SYMBOL vmlinux 0x46076ad5	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x460de9ac	inet_addr_type
++EXPORT_SYMBOL vmlinux 0x46113bb3	compat_mc_setsockopt
++EXPORT_SYMBOL vmlinux 0x461858c3	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0x461ac773	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x461b9910	amd_northbridges
++EXPORT_SYMBOL vmlinux 0x461bcd8d	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x4629334c	__preempt_count
++EXPORT_SYMBOL vmlinux 0x46598de0	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x467df16d	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0x468b290e	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x469a5605	sock_create
++EXPORT_SYMBOL vmlinux 0x46a024e7	__neigh_create
++EXPORT_SYMBOL vmlinux 0x46a2bcea	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x46c47fb6	__node_distance
++EXPORT_SYMBOL vmlinux 0x46ce8c87	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0x46ede833	fget_raw
++EXPORT_SYMBOL vmlinux 0x46f4b10d	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x470b4107	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0x4725fdf5	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x4740b3bc	xen_arch_unregister_cpu
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x47500263	unregister_key_type
++EXPORT_SYMBOL vmlinux 0x475f010b	acpi_purge_cached_objects
++EXPORT_SYMBOL vmlinux 0x4778d003	vga_switcheroo_init_domain_pm_optimus_hdmi_audio
++EXPORT_SYMBOL vmlinux 0x477e6dcb	amd_iommu_pc_get_set_reg_val
++EXPORT_SYMBOL vmlinux 0x4786f5a2	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x478cd648	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0x478d10b2	ht_destroy_irq
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x479a08ab	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x47b69619	bmap
++EXPORT_SYMBOL vmlinux 0x47dd2063	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0x47eed8e7	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0x47fc7bad	tcp_child_process
++EXPORT_SYMBOL vmlinux 0x4801257d	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0x48193639	acpi_lid_open
++EXPORT_SYMBOL vmlinux 0x481cb9ab	acpi_enter_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x481f39db	free_netdev
++EXPORT_SYMBOL vmlinux 0x482484f6	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0x483a705d	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0x4841bdee	strnchr
++EXPORT_SYMBOL vmlinux 0x4841fc47	ip6_xmit
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x485a358b	dev_load
++EXPORT_SYMBOL vmlinux 0x486e361c	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0x48881ef6	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0x4895d342	try_module_get
++EXPORT_SYMBOL vmlinux 0x48ad5c25	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48d50e79	amd_iommu_register_ppr_notifier
++EXPORT_SYMBOL vmlinux 0x48fc56f0	fb_blank
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x492cf6e8	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0x49387290	netif_device_attach
++EXPORT_SYMBOL vmlinux 0x494e3393	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x495be582	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x495e3085	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x495fd2ec	__sock_create
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x498419f1	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0x498b6444	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0x49a14c0e	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b163b8	acpi_bus_scan
++EXPORT_SYMBOL vmlinux 0x49d06d8c	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x49fd2aa5	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0x4a17e233	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0x4a1ca083	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0x4a200d9d	path_nosuid
++EXPORT_SYMBOL vmlinux 0x4a228829	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x4a3f25c8	set_pages_x
++EXPORT_SYMBOL vmlinux 0x4a4db42c	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0x4a793765	blk_peek_request
++EXPORT_SYMBOL vmlinux 0x4a862ffe	__devm_release_region
++EXPORT_SYMBOL vmlinux 0x4a8961f5	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4ade75f0	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x4adeddec	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0x4afe7e02	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b085dbf	agp3_generic_configure
++EXPORT_SYMBOL vmlinux 0x4b120022	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x4b5dc58e	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b667176	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0x4b6924cd	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0x4b756ca7	agp_put_bridge
++EXPORT_SYMBOL vmlinux 0x4b87a7bb	generic_update_time
++EXPORT_SYMBOL vmlinux 0x4b9dfb04	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4bc06cf2	proto_unregister
++EXPORT_SYMBOL vmlinux 0x4bf71d4e	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0x4c0795c3	dst_alloc
++EXPORT_SYMBOL vmlinux 0x4c07a7e0	acpi_processor_unregister_performance
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c3654bb	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x4c3b8ad5	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0x4c5e1f18	complete_request_key
++EXPORT_SYMBOL vmlinux 0x4c6ee72d	inet_put_port
++EXPORT_SYMBOL vmlinux 0x4c783ac6	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x4c7a6ba6	inet6_release
++EXPORT_SYMBOL vmlinux 0x4c829dc3	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0x4c829e63	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0x4c878322	iosf_mbi_modify
++EXPORT_SYMBOL vmlinux 0x4c903e80	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0x4c9d28b0	phys_base
++EXPORT_SYMBOL vmlinux 0x4c9db616	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0x4ca4326f	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0x4ca9669f	scnprintf
++EXPORT_SYMBOL vmlinux 0x4caa35cc	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0x4cb618ca	ns_capable
++EXPORT_SYMBOL vmlinux 0x4cb8c78f	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0x4cc8ee69	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x4cc9c851	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4cde88a2	__serio_register_port
++EXPORT_SYMBOL vmlinux 0x4ce666e8	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0x4ce8852b	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0x4cf4bf26	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x4cf67dbb	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x4cfd6b9e	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x4d0cde91	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0x4d1750a4	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0x4d48374f	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x4d4ac179	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0x4d4b82b5	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x4d5c0cef	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0x4d66ac54	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0x4d810060	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4dba34fd	elv_rb_find
++EXPORT_SYMBOL vmlinux 0x4dc3c05b	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x4dd6761a	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0x4de22c25	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4ded0d0c	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4dfdea17	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x4e07176e	rwsem_wake
++EXPORT_SYMBOL vmlinux 0x4e0b829e	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0x4e317554	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e3a9fce	mount_bdev
++EXPORT_SYMBOL vmlinux 0x4e4c0d97	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e852bd5	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0x4ea25709	dql_reset
++EXPORT_SYMBOL vmlinux 0x4ed2b393	nd_device_register
++EXPORT_SYMBOL vmlinux 0x4ed64c90	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0x4eeb270a	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0x4ef4deca	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0x4efa8c13	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0x4f03547a	dst_init
++EXPORT_SYMBOL vmlinux 0x4f1aa117	key_validate
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f2f9dfe	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0x4f31f3bf	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f409a25	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f6629ef	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f692f7e	fb_pan_display
++EXPORT_SYMBOL vmlinux 0x4f6b400b	_copy_from_user
++EXPORT_SYMBOL vmlinux 0x4f783f30	acpi_read
++EXPORT_SYMBOL vmlinux 0x4f7a4827	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0x4f8650f9	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x4f8b5ddb	_copy_to_user
++EXPORT_SYMBOL vmlinux 0x4fd831c3	pv_mmu_ops
++EXPORT_SYMBOL vmlinux 0x4fdee897	i8042_command
++EXPORT_SYMBOL vmlinux 0x4ff6e60c	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x501f52da	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x50235938	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x50505faa	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x50529870	acpi_get_gpe_status
++EXPORT_SYMBOL vmlinux 0x5057271d	send_sig
++EXPORT_SYMBOL vmlinux 0x5058984b	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x506a5355	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x5073b407	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0x5077bdca	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x509b64ea	acpi_has_method
++EXPORT_SYMBOL vmlinux 0x50a90e8d	bsearch
++EXPORT_SYMBOL vmlinux 0x50b5c8cc	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0x50ba769a	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x50d4e49b	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x50d68377	arch_phys_wc_del
++EXPORT_SYMBOL vmlinux 0x50de2325	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x50df5015	default_llseek
++EXPORT_SYMBOL vmlinux 0x50fd64a5	give_up_console
++EXPORT_SYMBOL vmlinux 0x51164ad9	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x514a3fd0	vga_switcheroo_fini_domain_pm_ops
++EXPORT_SYMBOL vmlinux 0x51719973	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x517fffe5	may_umount
++EXPORT_SYMBOL vmlinux 0x518469dc	dump_page
++EXPORT_SYMBOL vmlinux 0x51b5f8d1	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0x51d12d4e	acpi_pci_disabled
++EXPORT_SYMBOL vmlinux 0x51dded8c	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x51f4f396	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0x51f5f326	seq_path
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x52095e19	acpi_get_data
++EXPORT_SYMBOL vmlinux 0x52130046	acpi_check_address_range
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x52286b1a	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0x523dae18	dev_open
++EXPORT_SYMBOL vmlinux 0x52402f54	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0x525e026f	acpi_os_unmap_generic_address
++EXPORT_SYMBOL vmlinux 0x526bcd44	set_user_nice
++EXPORT_SYMBOL vmlinux 0x52983a4f	vme_master_write
++EXPORT_SYMBOL vmlinux 0x52f85c2f	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0x5308b2e0	submit_bio
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x531b604e	__virt_addr_valid
++EXPORT_SYMBOL vmlinux 0x531da21d	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x533d9f1c	to_nd_pfn
++EXPORT_SYMBOL vmlinux 0x534626a1	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0x53569707	this_cpu_off
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x53608253	km_report
++EXPORT_SYMBOL vmlinux 0x536a93fa	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0x536cc847	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x536fe70e	freeze_bdev
++EXPORT_SYMBOL vmlinux 0x5377e556	hex2bin
++EXPORT_SYMBOL vmlinux 0x53983836	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x539af73c	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x53a0a6b5	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0x53a4b60a	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0x53d18f83	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x53e9e12b	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x53f723ec	sk_dst_check
++EXPORT_SYMBOL vmlinux 0x54059a2a	amd_iommu_pc_get_max_counters
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x540dab91	set_pages_wb
++EXPORT_SYMBOL vmlinux 0x54245b39	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x544b0c11	acpi_lid_notifier_register
++EXPORT_SYMBOL vmlinux 0x544ce8a2	have_submounts
++EXPORT_SYMBOL vmlinux 0x545fd280	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0x5464d3f6	acpi_remove_sci_handler
++EXPORT_SYMBOL vmlinux 0x546abd5b	d_obtain_root
++EXPORT_SYMBOL vmlinux 0x547b24e0	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x548cf880	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0x54a23294	deactivate_super
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54ae01b4	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0x54b3fb06	pci_get_device
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54e15f9b	nf_log_unset
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54f24d1a	fence_default_wait
++EXPORT_SYMBOL vmlinux 0x550d04e7	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x5511e198	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0x551b0c42	led_update_brightness
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x551bedc7	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x551ff1d3	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x5529d53f	vfs_statfs
++EXPORT_SYMBOL vmlinux 0x552ad070	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0x5533cdef	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x553614bd	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x554a1b3d	d_walk
++EXPORT_SYMBOL vmlinux 0x55596ee6	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x555d2909	get_empty_filp
++EXPORT_SYMBOL vmlinux 0x555f6938	lockref_get
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x559464c7	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0x55a1431d	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0x55b5738a	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0x55d01445	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x55e60a36	queued_spin_unlock_wait
++EXPORT_SYMBOL vmlinux 0x55f5019b	__kmalloc_node
++EXPORT_SYMBOL vmlinux 0x55fbbef2	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0x56053823	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0x5608cff4	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x56128a2c	pnp_release_card_device
++EXPORT_SYMBOL vmlinux 0x5616e254	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x56183954	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0x561ef03c	tty_hangup
++EXPORT_SYMBOL vmlinux 0x562d7353	get_gendisk
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x563aa5a7	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x5640ec23	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x5641419b	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0x56611eb4	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0x5665b5d3	generic_fillattr
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x568ff9ee	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x56c2a6c7	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56da318b	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0x56fc1429	serio_bus
++EXPORT_SYMBOL vmlinux 0x57018c0e	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x5717217c	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x571aa590	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x5731895e	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0x573191d3	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0x573cbeec	tty_mutex
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x57573cd6	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x577d35f3	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x5792f848	strlcpy
++EXPORT_SYMBOL vmlinux 0x57940a78	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x5794bdb4	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0x5795be8c	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x579e1a33	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0x57a7b36d	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0x57ba72ab	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0x57c12c25	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0x57cbae47	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0x57dee96f	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0x57e78ff1	do_splice_from
++EXPORT_SYMBOL vmlinux 0x57f64d2f	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x580d984c	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0x581796db	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0x581af860	d_genocide
++EXPORT_SYMBOL vmlinux 0x581dd694	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x5826ef62	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0x583530b1	scmd_printk
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x583d1b98	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x584738f9	rdmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x5847c560	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0x5849cf68	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0x58565ffe	key_put
++EXPORT_SYMBOL vmlinux 0x58573dfc	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0x5857b225	ioread16_rep
++EXPORT_SYMBOL vmlinux 0x58581f2f	agp_generic_free_gatt_table
++EXPORT_SYMBOL vmlinux 0x58604e4d	alloc_iova_mem
++EXPORT_SYMBOL vmlinux 0x586103be	acpi_setup_gpe_for_wake
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x587badb2	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0x587f4475	__check_sticky
++EXPORT_SYMBOL vmlinux 0x588b2956	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x58ac3cff	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x58b12577	__vfs_write
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58c5c8d7	module_layout
++EXPORT_SYMBOL vmlinux 0x58ccf553	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x58db8af6	unregister_netdev
++EXPORT_SYMBOL vmlinux 0x58e2c6b8	pmem_should_map_pages
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x58e4f525	pnpacpi_protocol
++EXPORT_SYMBOL vmlinux 0x5906b8f6	pci_get_class
++EXPORT_SYMBOL vmlinux 0x590e5789	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0x5939a151	dentry_open
++EXPORT_SYMBOL vmlinux 0x5944d015	__cachemode2pte_tbl
++EXPORT_SYMBOL vmlinux 0x59474073	pci_find_bus
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x596034cd	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0x5960b465	agp_bridge
++EXPORT_SYMBOL vmlinux 0x596d271b	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x59856243	ps2_init
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x59a0c30e	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59bc9609	acpi_write_bit_register
++EXPORT_SYMBOL vmlinux 0x59cd0685	md_update_sb
++EXPORT_SYMBOL vmlinux 0x59fadccf	get_super
++EXPORT_SYMBOL vmlinux 0x59fc40d7	ps2_end_command
++EXPORT_SYMBOL vmlinux 0x5a016867	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x5a07695d	simple_rename
++EXPORT_SYMBOL vmlinux 0x5a0a0470	cdrom_open
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a0bf56c	netdev_info
++EXPORT_SYMBOL vmlinux 0x5a37fb25	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0x5a4896a8	__put_user_2
++EXPORT_SYMBOL vmlinux 0x5a82c44a	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x5a82dfa8	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x5a82e693	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0x5a921311	strncmp
++EXPORT_SYMBOL vmlinux 0x5aabb731	kthread_stop
++EXPORT_SYMBOL vmlinux 0x5aacb439	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0x5ac376a5	acpi_install_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x5ad14f32	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x5af4953a	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5b24b5a8	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0x5b44ef16	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0x5b56860c	vm_munmap
++EXPORT_SYMBOL vmlinux 0x5b72d011	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x5b79942a	genl_notify
++EXPORT_SYMBOL vmlinux 0x5b83944a	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x5b9c808a	acpi_get_possible_resources
++EXPORT_SYMBOL vmlinux 0x5ba46709	__skb_checksum
++EXPORT_SYMBOL vmlinux 0x5bc10524	printk_emit
++EXPORT_SYMBOL vmlinux 0x5bc8d583	copy_from_user_overflow
++EXPORT_SYMBOL vmlinux 0x5bfd514d	__put_cred
++EXPORT_SYMBOL vmlinux 0x5c0442fd	acpi_gbl_FADT
++EXPORT_SYMBOL vmlinux 0x5c044473	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0x5c062aab	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x5c1b9411	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x5c2f5d85	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0x5c2fc0f9	make_kgid
++EXPORT_SYMBOL vmlinux 0x5c48c7a8	inet_listen
++EXPORT_SYMBOL vmlinux 0x5c6286c9	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0x5c63ebda	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0x5c864e09	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x5ca5428a	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x5ca73dd8	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5cf7ed3b	key_link
++EXPORT_SYMBOL vmlinux 0x5cfd0f5e	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0x5cfee5eb	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x5d0161ec	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x5d3140ad	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0x5d37c913	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x5d5476c5	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d63b2f7	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x5d7208fd	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x5d74dbcf	pnp_range_reserved
++EXPORT_SYMBOL vmlinux 0x5d8475e0	completion_done
++EXPORT_SYMBOL vmlinux 0x5d869e78	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0x5da2a365	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0x5daf96ee	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0x5dcb6aae	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x5dd4bff9	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0x5de113c4	write_inode_now
++EXPORT_SYMBOL vmlinux 0x5de7a3fb	irq_set_chip
++EXPORT_SYMBOL vmlinux 0x5e0f646f	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x5e18b16e	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0x5e1d8138	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0x5e2b8c76	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x5e33937e	skb_pad
++EXPORT_SYMBOL vmlinux 0x5e3b05d3	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0x5e8e1d9f	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ecfeec6	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5ed6cfd3	is_nd_btt
++EXPORT_SYMBOL vmlinux 0x5ee0fcf6	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x5efc5021	key_type_keyring
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f0a6426	netlink_unicast
++EXPORT_SYMBOL vmlinux 0x5f1b6690	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x5f3c7eb8	inc_nlink
++EXPORT_SYMBOL vmlinux 0x5f3f4966	pci_restore_state
++EXPORT_SYMBOL vmlinux 0x5f4c904d	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0x5f4dd519	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x5f591c0c	devm_memremap
++EXPORT_SYMBOL vmlinux 0x5f5fb85f	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0x5f7b89ec	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x5f7e451d	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x5f9a5753	acpi_device_set_power
++EXPORT_SYMBOL vmlinux 0x5f9f5c27	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0x5fa43bcc	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0x5fb2e8ef	idr_init
++EXPORT_SYMBOL vmlinux 0x5fbdf3f9	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x5fd1ac5a	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x5fd5b396	compat_ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x5fd7d437	blk_start_request
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x5fe5f446	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0x5ffcff9c	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x60159416	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x601734cd	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0x601da172	agp_generic_destroy_page
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x602ed00d	acpi_current_gpe_count
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x603df82c	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0x604316d8	acpi_finish_gpe
++EXPORT_SYMBOL vmlinux 0x604b525e	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x606e7182	thaw_super
++EXPORT_SYMBOL vmlinux 0x607c63a7	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0x6089b5b0	register_filesystem
++EXPORT_SYMBOL vmlinux 0x608e2fa0	dump_truncate
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x609f5b35	ucs2_strnlen
++EXPORT_SYMBOL vmlinux 0x60a11832	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL vmlinux 0x60a6e965	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x60afc4ff	d_splice_alias
++EXPORT_SYMBOL vmlinux 0x60c4b0eb	napi_complete_done
++EXPORT_SYMBOL vmlinux 0x60c64ef3	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x60e37060	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0x61006836	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0x610aaa40	mempool_destroy
++EXPORT_SYMBOL vmlinux 0x61180359	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x614bb773	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x61520529	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0x6164274f	vfs_readf
++EXPORT_SYMBOL vmlinux 0x618911fc	numa_node
++EXPORT_SYMBOL vmlinux 0x619cb7dd	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61c44035	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0x61c78d10	__dst_free
++EXPORT_SYMBOL vmlinux 0x61de6f0e	generic_file_open
++EXPORT_SYMBOL vmlinux 0x61ef6170	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0x61f6bf1a	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0x61fb248a	node_states
++EXPORT_SYMBOL vmlinux 0x62049256	acpi_disable
++EXPORT_SYMBOL vmlinux 0x62069401	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6226b9fa	machine_to_phys_mapping
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x6237f6b5	acpi_enable_event
++EXPORT_SYMBOL vmlinux 0x6249b559	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0x624cc57a	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0x62663113	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62748e70	acpi_set_current_resources
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x628e1d4a	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x62b2428f	phy_driver_register
++EXPORT_SYMBOL vmlinux 0x62e466cd	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0x6317356c	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x6327bf45	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0x63352dba	kobject_del
++EXPORT_SYMBOL vmlinux 0x634b1325	vfs_llseek
++EXPORT_SYMBOL vmlinux 0x636a5691	acpi_register_ioapic
++EXPORT_SYMBOL vmlinux 0x637bfdbb	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x637fd387	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0x6388591c	down_timeout
++EXPORT_SYMBOL vmlinux 0x63a01291	acpi_leave_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63aafc7d	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63c50d92	inet6_bind
++EXPORT_SYMBOL vmlinux 0x63c5e2e9	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0x63d57a95	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x63ddb3f0	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x63e9bc92	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63f3e1cd	pci_bus_type
++EXPORT_SYMBOL vmlinux 0x63fae632	devm_memunmap
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x64055a19	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x6449fd41	acpi_install_address_space_handler
++EXPORT_SYMBOL vmlinux 0x645da051	agp_generic_remove_memory
++EXPORT_SYMBOL vmlinux 0x6461924a	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0x6472641c	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64ab0e98	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x64bbc288	string_unescape
++EXPORT_SYMBOL vmlinux 0x64c32105	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0x64cf41a0	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0x64eae7ad	set_memory_array_wb
++EXPORT_SYMBOL vmlinux 0x64fa7693	__acpi_handle_debug
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x652ce9aa	nla_memcmp
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x6552d37b	simple_link
++EXPORT_SYMBOL vmlinux 0x655f1ab0	set_memory_array_wc
++EXPORT_SYMBOL vmlinux 0x6561884f	vga_client_register
++EXPORT_SYMBOL vmlinux 0x656c1a0e	string_escape_mem
++EXPORT_SYMBOL vmlinux 0x656c926c	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x6572d1e9	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0x65817195	bdput
++EXPORT_SYMBOL vmlinux 0x659806e3	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0x65b876a7	acpi_bus_unregister_driver
++EXPORT_SYMBOL vmlinux 0x65b992ac	xen_alloc_p2m_entry
++EXPORT_SYMBOL vmlinux 0x65bed5c3	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x65c12d6c	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0x65c35fc0	__seq_open_private
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65e0d6d7	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x663b60ac	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0x663f7cd0	acpi_install_table_handler
++EXPORT_SYMBOL vmlinux 0x6642eaff	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0x664e3408	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x665105ad	clear_nlink
++EXPORT_SYMBOL vmlinux 0x6652a9e3	__sb_end_write
++EXPORT_SYMBOL vmlinux 0x665ab6ce	agp_unbind_memory
++EXPORT_SYMBOL vmlinux 0x66945714	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0x669a43cd	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x669d5aa9	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x66d804b1	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x66dcebee	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0x66dd2a55	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0x66e1a039	compat_ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x66e268ea	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0x66e5c007	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x66ee7cea	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0x66ef65e9	netdev_update_features
++EXPORT_SYMBOL vmlinux 0x66f436b9	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0x6712b9f6	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0x671739ab	blkdev_get
++EXPORT_SYMBOL vmlinux 0x6729d3df	__get_user_4
++EXPORT_SYMBOL vmlinux 0x6736bb18	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0x673f815e	agp_bridges
++EXPORT_SYMBOL vmlinux 0x674ca1e4	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0x6766da7b	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x67744726	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b321b3	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x67b362b5	amd_iommu_domain_enable_v2
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67bd5a93	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0x67f07591	init_task
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x680ec266	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x681f7cb1	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0x682013a8	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0x6822d70e	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0x6824a7fb	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x683261d5	scsi_execute
++EXPORT_SYMBOL vmlinux 0x683c3be9	pci_bus_put
++EXPORT_SYMBOL vmlinux 0x68426a24	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x6858b718	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0x687124d1	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0x68746ccd	devm_memremap_pages
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x689b8cec	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68cf0525	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x68d0ec81	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0x68dc800d	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0x68f3a7ec	netdev_features_change
++EXPORT_SYMBOL vmlinux 0x691001b5	acpi_evaluate_integer
++EXPORT_SYMBOL vmlinux 0x69190965	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0x691c8cb5	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x6920ff27	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0x69271f97	pipe_lock
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x6981b716	set_trace_device
++EXPORT_SYMBOL vmlinux 0x6988d0ca	cpu_dr7
++EXPORT_SYMBOL vmlinux 0x698f2f04	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0x69a0ca7d	iowrite16be
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69a9736b	ilookup5
++EXPORT_SYMBOL vmlinux 0x69a9f48e	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x69acdf38	memcpy
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69b87484	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x69c1f1be	kern_path_create
++EXPORT_SYMBOL vmlinux 0x69ebf57e	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0x69fbc0a2	acpi_get_event_resources
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a1229e0	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0x6a206520	dev_add_offload
++EXPORT_SYMBOL vmlinux 0x6a2dca52	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0x6a35f768	generic_show_options
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a5fa363	sigprocmask
++EXPORT_SYMBOL vmlinux 0x6a60277d	acpi_buffer_to_resource
++EXPORT_SYMBOL vmlinux 0x6a64d61d	devm_request_resource
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a77633d	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0x6ac66cbe	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6acb973d	iowrite32be
++EXPORT_SYMBOL vmlinux 0x6ad85887	acpi_enable_gpe
++EXPORT_SYMBOL vmlinux 0x6add41eb	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0x6add5c9a	dmi_find_device
++EXPORT_SYMBOL vmlinux 0x6ae41bc6	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b3fe051	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0x6b4275f6	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0x6b5a0e28	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0x6b640864	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6b6ba5f6	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x6b74b9be	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0x6b8f46c3	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0x6b998031	param_get_byte
++EXPORT_SYMBOL vmlinux 0x6b9c0ef5	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x6bc2068f	pnp_stop_dev
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bc9510f	inode_permission
++EXPORT_SYMBOL vmlinux 0x6bcf066d	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6be17093	serio_reconnect
++EXPORT_SYMBOL vmlinux 0x6be46a37	amd_iommu_flush_page
++EXPORT_SYMBOL vmlinux 0x6bf1c17f	pv_lock_ops
++EXPORT_SYMBOL vmlinux 0x6c0137d2	input_close_device
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c2fa4b1	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0x6c3011cb	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0x6c44bc15	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c6b74ff	agp_generic_free_by_type
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c748b8a	neigh_table_init
++EXPORT_SYMBOL vmlinux 0x6c8627ba	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x6c8751ad	x86_hyper
++EXPORT_SYMBOL vmlinux 0x6c9ea25c	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0x6cb0f303	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0x6cb3dbd3	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0x6cb5c718	param_get_long
++EXPORT_SYMBOL vmlinux 0x6cbea728	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x6cc42aee	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0x6cd08804	sk_net_capable
++EXPORT_SYMBOL vmlinux 0x6cd40328	request_firmware
++EXPORT_SYMBOL vmlinux 0x6cdcce35	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0x6cec0a11	pci_map_biosrom
++EXPORT_SYMBOL vmlinux 0x6d0352db	acpi_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0x6d0a08d1	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0x6d0a2ffd	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d1d5d9b	iosf_mbi_write
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d3096ed	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x6d334118	__get_user_8
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d361b94	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0x6d3bc7ca	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0x6d530bfb	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0x6d616c9e	get_fs_type
++EXPORT_SYMBOL vmlinux 0x6d7d2105	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x6d8575ad	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x6d93bf9f	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x6db37bee	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0x6dc0c9dc	down_interruptible
++EXPORT_SYMBOL vmlinux 0x6dc6dd56	down
++EXPORT_SYMBOL vmlinux 0x6dcbc8eb	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0x6ddef005	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0x6de0ef80	param_set_bool
++EXPORT_SYMBOL vmlinux 0x6de19a29	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0x6de22e65	lock_fb_info
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6e1517f7	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0x6e3a3382	nvm_register_target
++EXPORT_SYMBOL vmlinux 0x6e3b8625	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0x6e3eeba3	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0x6e41f997	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0x6e47a08b	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x6e4e7f4f	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0x6e696cc3	filemap_flush
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e7962a7	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0x6e7f0fd2	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x6e8a32f7	dma_ops
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6eaa9626	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x6ec446ac	mmc_add_host
++EXPORT_SYMBOL vmlinux 0x6ec607c2	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x6eedbf57	d_delete
++EXPORT_SYMBOL vmlinux 0x6ef66e8a	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0x6f1bf786	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f2e4f46	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0x6f308ea8	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x6f321b8f	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x6f3784b0	seq_write
++EXPORT_SYMBOL vmlinux 0x6f556bdb	acpi_get_gpe_device
++EXPORT_SYMBOL vmlinux 0x6f60ac9b	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x6f66cecf	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x6f70ff02	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0x6f803c73	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x6f82261b	end_page_writeback
++EXPORT_SYMBOL vmlinux 0x6f877a0b	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6f8c352d	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0x6f9701c9	dcb_setapp
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6fde6821	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x6feb2039	acpi_write
++EXPORT_SYMBOL vmlinux 0x7023bea8	unregister_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x7029f11b	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0x702b2690	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x703224f8	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x7032e7fa	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7054a3e4	request_dma
++EXPORT_SYMBOL vmlinux 0x705b6674	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x706ae566	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x706d5492	netdev_crit
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x708a79f7	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x70a17d34	acpi_bus_get_device
++EXPORT_SYMBOL vmlinux 0x70a7847e	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x70cbd94f	generic_read_dir
++EXPORT_SYMBOL vmlinux 0x70d8ab82	acpi_acquire_global_lock
++EXPORT_SYMBOL vmlinux 0x70e9f676	param_ops_string
++EXPORT_SYMBOL vmlinux 0x70f0a2e2	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x710fdd79	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x71362d51	__brelse
++EXPORT_SYMBOL vmlinux 0x71415783	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0x71431de3	phy_device_remove
++EXPORT_SYMBOL vmlinux 0x714bddae	from_kprojid
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x717a40bc	cros_ec_prepare_tx
++EXPORT_SYMBOL vmlinux 0x71828a66	proc_dostring
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71a7035a	file_remove_privs
++EXPORT_SYMBOL vmlinux 0x71d42b07	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x71ff4675	vme_slave_request
++EXPORT_SYMBOL vmlinux 0x7217c9e6	lock_rename
++EXPORT_SYMBOL vmlinux 0x721ce219	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x72220176	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x724484da	netlink_set_err
++EXPORT_SYMBOL vmlinux 0x724c5dcd	generic_make_request
++EXPORT_SYMBOL vmlinux 0x7260e249	___preempt_schedule_notrace
++EXPORT_SYMBOL vmlinux 0x72611370	get_task_io_context
++EXPORT_SYMBOL vmlinux 0x72657636	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0x727e91f8	vfs_getattr
++EXPORT_SYMBOL vmlinux 0x7280af6c	load_nls
++EXPORT_SYMBOL vmlinux 0x72a393ca	set_pages_nx
++EXPORT_SYMBOL vmlinux 0x72a98fdb	copy_user_generic_unrolled
++EXPORT_SYMBOL vmlinux 0x72ae4f38	kdb_current_task
++EXPORT_SYMBOL vmlinux 0x72b243d4	free_dma
++EXPORT_SYMBOL vmlinux 0x72ce680a	bdi_register
++EXPORT_SYMBOL vmlinux 0x72e73d2b	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x72f640b0	netlink_capable
++EXPORT_SYMBOL vmlinux 0x72f9724a	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x72ffebcf	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0x73137e23	sock_efree
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x733ee138	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x734c013f	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0x735a0bd5	native_io_delay
++EXPORT_SYMBOL vmlinux 0x7362024e	sock_create_lite
++EXPORT_SYMBOL vmlinux 0x73688398	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0x736fc01c	clkdev_drop
++EXPORT_SYMBOL vmlinux 0x7370b255	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0x73722e62	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0x738714db	ida_pre_get
++EXPORT_SYMBOL vmlinux 0x73a47157	skb_pull
++EXPORT_SYMBOL vmlinux 0x73a85909	cdev_alloc
++EXPORT_SYMBOL vmlinux 0x73ad7ab8	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x73b3415d	register_cdrom
++EXPORT_SYMBOL vmlinux 0x73ba73e7	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0x73bbd56f	mdiobus_read
++EXPORT_SYMBOL vmlinux 0x73d237f9	keyring_search
++EXPORT_SYMBOL vmlinux 0x73dd54eb	irq_fpu_usable
++EXPORT_SYMBOL vmlinux 0x73e7b7d4	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x73ec86f5	blk_queue_split
++EXPORT_SYMBOL vmlinux 0x740a1b95	reserve_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0x740e9c54	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x740ef746	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x745f20a3	idr_is_empty
++EXPORT_SYMBOL vmlinux 0x7464f09e	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x74894c27	dev_emerg
++EXPORT_SYMBOL vmlinux 0x7489cccf	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x74904361	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x74a13cbb	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x74a9ea4b	pnp_device_attach
++EXPORT_SYMBOL vmlinux 0x74afb4de	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x74b3c4ad	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74df11e2	phy_init_hw
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74e653d9	inet_offloads
++EXPORT_SYMBOL vmlinux 0x74f43e83	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0x75091ffb	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x750f444c	pnp_register_driver
++EXPORT_SYMBOL vmlinux 0x7525a60d	kobject_init
++EXPORT_SYMBOL vmlinux 0x752a06ee	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0x7532588a	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0x7538b132	agp_off
++EXPORT_SYMBOL vmlinux 0x754d539c	strlen
++EXPORT_SYMBOL vmlinux 0x754e716c	module_refcount
++EXPORT_SYMBOL vmlinux 0x7553bcbc	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0x75b889c5	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0x75bc549a	x86_cpu_to_apicid
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75d4388d	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x75fbdefd	acpi_remove_address_space_handler
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x76208273	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x7645af6f	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x765d7480	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x765f961b	misc_register
++EXPORT_SYMBOL vmlinux 0x765ff474	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x766795e8	agp_create_memory
++EXPORT_SYMBOL vmlinux 0x76717ddb	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0x767dd8fd	acpi_get_irq_routing_table
++EXPORT_SYMBOL vmlinux 0x767ddb02	set_memory_wc
++EXPORT_SYMBOL vmlinux 0x76960ab8	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0x76bb6b11	mpage_readpages
++EXPORT_SYMBOL vmlinux 0x76c5ec99	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x76c8c0a5	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76ec93f0	dquot_drop
++EXPORT_SYMBOL vmlinux 0x76fb08a7	amd_iommu_unregister_ppr_notifier
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x773fa409	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x77456e0a	acpi_root_dir
++EXPORT_SYMBOL vmlinux 0x7751adb2	finish_open
++EXPORT_SYMBOL vmlinux 0x7757140d	con_is_bound
++EXPORT_SYMBOL vmlinux 0x775cae2c	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0x7765a385	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0x7775fba7	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0x778c90a1	tty_kref_put
++EXPORT_SYMBOL vmlinux 0x778e2341	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77c9de07	sk_capable
++EXPORT_SYMBOL vmlinux 0x77ec9d6f	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x77f517ab	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0x77f53abc	acpi_get_vendor_resource
++EXPORT_SYMBOL vmlinux 0x780eb124	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x780fdfd1	intel_enable_gtt
++EXPORT_SYMBOL vmlinux 0x7816e7df	compat_ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x783b5276	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x7841980b	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x7846af3e	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x784b498b	kset_register
++EXPORT_SYMBOL vmlinux 0x78756807	mount_ns
++EXPORT_SYMBOL vmlinux 0x78764f4e	pv_irq_ops
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x788d590a	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78a5ff8a	fence_add_callback
++EXPORT_SYMBOL vmlinux 0x78acb6dc	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0x78aec06a	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78e739aa	up
++EXPORT_SYMBOL vmlinux 0x78efd31a	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0x78f05511	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0x78f8c876	kfree_put_link
++EXPORT_SYMBOL vmlinux 0x79068fda	acpi_install_method
++EXPORT_SYMBOL vmlinux 0x791ed1c9	rename_lock
++EXPORT_SYMBOL vmlinux 0x79253b6d	first_ec
++EXPORT_SYMBOL vmlinux 0x793f4b8a	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x7984eefc	key_update
++EXPORT_SYMBOL vmlinux 0x7985d043	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x7994fc4d	inet_release
++EXPORT_SYMBOL vmlinux 0x799e6cdc	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0x79a33f85	vme_get_size
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79ad0370	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0x79b24b1d	__page_cache_alloc
++EXPORT_SYMBOL vmlinux 0x79b60f80	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x79bf865d	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0x79bfa089	locks_init_lock
++EXPORT_SYMBOL vmlinux 0x79d43d3c	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0x79dfcbdb	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x79efeb74	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0x79f3d3de	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x7a0a5c44	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0x7a2af7b4	cpu_number
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a6cdedc	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7a6e7c0b	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0x7a82cb47	rdmsrl_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x7aa100f3	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7aad1f96	skb_clone
++EXPORT_SYMBOL vmlinux 0x7ab33443	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7ad4b34f	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0x7aec9089	clear_user
++EXPORT_SYMBOL vmlinux 0x7b16235f	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b2aef6c	__krealloc
++EXPORT_SYMBOL vmlinux 0x7b33a8e4	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0x7b34c227	__nd_driver_register
++EXPORT_SYMBOL vmlinux 0x7b4af9dc	seq_read
++EXPORT_SYMBOL vmlinux 0x7b4c0faa	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0x7b52a859	wrmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x7b5a703e	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x7b710907	no_llseek
++EXPORT_SYMBOL vmlinux 0x7ba627f8	put_page
++EXPORT_SYMBOL vmlinux 0x7bad7a1a	acpi_walk_resources
++EXPORT_SYMBOL vmlinux 0x7bc2749e	setattr_copy
++EXPORT_SYMBOL vmlinux 0x7bd632e1	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x7be75ffc	acpi_walk_resource_buffer
++EXPORT_SYMBOL vmlinux 0x7bfa8ee6	phy_connect
++EXPORT_SYMBOL vmlinux 0x7c02b6f5	dm_register_target
++EXPORT_SYMBOL vmlinux 0x7c042498	netdev_alert
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c2d098f	krealloc
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c65b1a3	seq_open_private
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7c99b289	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0x7c9aa5e9	__d_drop
++EXPORT_SYMBOL vmlinux 0x7caaa381	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cb2a752	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0x7cb8ceb6	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0x7cd65e27	get_disk
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7ce247d6	input_register_handle
++EXPORT_SYMBOL vmlinux 0x7ce83365	acpi_remove_table_handler
++EXPORT_SYMBOL vmlinux 0x7ceb114a	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d166ec1	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0x7d287136	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x7d2a082f	ps2_drain
++EXPORT_SYMBOL vmlinux 0x7d39e3e3	nf_reinject
++EXPORT_SYMBOL vmlinux 0x7d3cda1c	file_open_root
++EXPORT_SYMBOL vmlinux 0x7d4d7c11	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x7d6c4b4e	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x7d6cc3e8	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d71445d	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x7d73144e	kmem_cache_alloc_node_trace
++EXPORT_SYMBOL vmlinux 0x7d882509	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0x7d94f746	acpi_os_write_port
++EXPORT_SYMBOL vmlinux 0x7d95ff5e	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0x7d96cea3	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x7da2b6aa	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x7dbc2e57	mmiotrace_printk
++EXPORT_SYMBOL vmlinux 0x7dcf5918	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0x7dd41b1f	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0x7dd554fc	unregister_kmmio_probe
++EXPORT_SYMBOL vmlinux 0x7ddb48e2	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7e14aaf0	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x7e1e7dcc	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x7e46ec94	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0x7e5c35b1	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x7e7fc3fb	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x7eaa15b9	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x7ebd4be4	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x7ec8765e	simple_follow_link
++EXPORT_SYMBOL vmlinux 0x7ec8a4eb	freeze_super
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7ef0a1b2	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x7efb837d	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f033073	thaw_bdev
++EXPORT_SYMBOL vmlinux 0x7f0edab8	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f263ed9	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x7f381152	dev_printk
++EXPORT_SYMBOL vmlinux 0x7f53af62	nd_device_unregister
++EXPORT_SYMBOL vmlinux 0x7f5e8b58	dev_err
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f6ee416	file_path
++EXPORT_SYMBOL vmlinux 0x7f759144	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x7f95f92a	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0x7fbd10d2	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x7fd4ff71	phy_device_create
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fe38f48	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x803184b7	make_kprojid
++EXPORT_SYMBOL vmlinux 0x8051c010	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0x8061cc6c	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0x8063087f	ip_options_compile
++EXPORT_SYMBOL vmlinux 0x8067c299	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0x8068c15c	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x806e3629	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0x80791a8c	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0x80818d37	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0x809388ca	idr_destroy
++EXPORT_SYMBOL vmlinux 0x80998456	udplite_prot
++EXPORT_SYMBOL vmlinux 0x80b18c4d	input_flush_device
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80eb423b	acpi_get_object_info
++EXPORT_SYMBOL vmlinux 0x810d2644	neigh_for_each
++EXPORT_SYMBOL vmlinux 0x81144f9d	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x8116d9fe	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x8116f13b	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0x811b661e	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x812ad51d	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0x81472677	acpi_get_table
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x8153019e	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x81533963	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x815f2897	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x817156e7	kernel_listen
++EXPORT_SYMBOL vmlinux 0x817483c3	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0x817f0c68	inet6_getname
++EXPORT_SYMBOL vmlinux 0x81b9aa39	__module_get
++EXPORT_SYMBOL vmlinux 0x81ce1013	md_check_recovery
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81e43d52	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0x81e59ee3	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0x81e6b37f	dmi_get_system_info
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x820a4089	seq_release_private
++EXPORT_SYMBOL vmlinux 0x8212721d	xenbus_dev_request_and_reply
++EXPORT_SYMBOL vmlinux 0x82147a70	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0x82162e6c	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x82340ade	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x82360fa8	tty_lock
++EXPORT_SYMBOL vmlinux 0x823912af	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0x823b0111	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0x82458f7f	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x82574ba1	tso_build_data
++EXPORT_SYMBOL vmlinux 0x825fc953	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0x826c2bb9	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x829534b3	fence_free
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82bdcdbd	dst_discard_out
++EXPORT_SYMBOL vmlinux 0x82bfe720	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0x82cda9d3	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0x82cf0682	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0x82dc9896	seq_dentry
++EXPORT_SYMBOL vmlinux 0x82f475fa	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0x830e547b	ioremap_prot
++EXPORT_SYMBOL vmlinux 0x833c03aa	acpi_enable_all_runtime_gpes
++EXPORT_SYMBOL vmlinux 0x8345871e	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0x8354a582	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0x836b2247	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x8373f402	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0x8384647a	acpi_map_pxm_to_online_node
++EXPORT_SYMBOL vmlinux 0x838f3647	vfs_create
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x83ad5dcf	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83bb18be	km_policy_expired
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83d8a97b	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0x83eb6b0d	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x83ec0317	inet_ioctl
++EXPORT_SYMBOL vmlinux 0x83fbbbe6	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0x8403322c	__netif_schedule
++EXPORT_SYMBOL vmlinux 0x84060081	xen_poll_irq_timeout
++EXPORT_SYMBOL vmlinux 0x8417f512	acpi_update_all_gpes
++EXPORT_SYMBOL vmlinux 0x841b3996	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0x84236ca3	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0x84240c0a	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0x8434d0f5	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x84406716	user_revoke
++EXPORT_SYMBOL vmlinux 0x844e3767	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0x84521c25	amd_iommu_enable_device_erratum
++EXPORT_SYMBOL vmlinux 0x845fd23b	__dax_fault
++EXPORT_SYMBOL vmlinux 0x846ab25c	elevator_change
++EXPORT_SYMBOL vmlinux 0x847763ac	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0x84e38a3d	fb_get_mode
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x8507c383	proc_dointvec
++EXPORT_SYMBOL vmlinux 0x8512fc2c	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x851449ca	register_xen_selfballooning
++EXPORT_SYMBOL vmlinux 0x8526c35a	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x853cb3c7	param_set_uint
++EXPORT_SYMBOL vmlinux 0x8540bb5e	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x854d047b	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x855707b4	mapping_tagged
++EXPORT_SYMBOL vmlinux 0x856191cd	mmc_request_done
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x856a3051	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x856b2074	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0x857582f7	acpi_enable_all_wakeup_gpes
++EXPORT_SYMBOL vmlinux 0x8576d77c	agp_allocate_memory
++EXPORT_SYMBOL vmlinux 0x858473ad	serio_close
++EXPORT_SYMBOL vmlinux 0x858975cb	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x858b3fe3	free_iova_mem
++EXPORT_SYMBOL vmlinux 0x85a67911	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85c657c9	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85e1f7d8	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x85fa3322	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0x8600412b	__break_lease
++EXPORT_SYMBOL vmlinux 0x860cfc43	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x861e22a4	acpi_map_cpu
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x86574d49	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0x865d263c	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x867ac5af	nd_integrity_init
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x869face6	md_done_sync
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86a6b430	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0x86ab9ad3	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x86b5a4a1	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0x86cea3c8	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0x86e3db17	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x87143afb	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x874adcf2	__nd_iostat_start
++EXPORT_SYMBOL vmlinux 0x8752aa74	simple_readpage
++EXPORT_SYMBOL vmlinux 0x876dafc3	ec_write
++EXPORT_SYMBOL vmlinux 0x877ee20f	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0x8780fa24	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x878cd015	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x878ff694	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x87aaddf8	wrmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0x87ac08a6	inet6_offloads
++EXPORT_SYMBOL vmlinux 0x87b3aeb7	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0x87ba5a3a	amd_iommu_get_v2_domain
++EXPORT_SYMBOL vmlinux 0x87be1199	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0x87d30b84	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x87f1cac1	alloc_pages_current
++EXPORT_SYMBOL vmlinux 0x880cf017	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0x881acdd5	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x883fb204	agp_generic_destroy_pages
++EXPORT_SYMBOL vmlinux 0x884f7bd2	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x886b355c	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x886fe93b	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0x887fa47e	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x888a5577	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0x888de571	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0x88908872	f_setown
++EXPORT_SYMBOL vmlinux 0x88917eba	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x88a79c2e	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x88c8be34	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0x88d15341	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x88d1bb49	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0x88fd863c	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0x891b81d9	sock_edemux
++EXPORT_SYMBOL vmlinux 0x892b26a0	set_memory_nx
++EXPORT_SYMBOL vmlinux 0x892ba16d	mdiobus_write
++EXPORT_SYMBOL vmlinux 0x892de3fb	__nla_put
++EXPORT_SYMBOL vmlinux 0x8948bd01	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0x896e4d36	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0x897cb731	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0x89ae483a	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89c034a5	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x89d1502c	component_match_add
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89fd55e8	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0x8a010e0a	tcp_close
++EXPORT_SYMBOL vmlinux 0x8a0b12c6	complete_all
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a3f5aa1	acpi_processor_preregister_performance
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a53bca4	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0x8a6944f9	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x8a6af65c	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a80d7a5	acpi_error
++EXPORT_SYMBOL vmlinux 0x8a8f0ad9	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8aa9a51c	bdget
++EXPORT_SYMBOL vmlinux 0x8aadb5c0	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0x8ab91ef1	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0x8ac828fc	tty_port_init
++EXPORT_SYMBOL vmlinux 0x8ad188c6	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0x8add6c30	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x8aec22b2	noop_fsync
++EXPORT_SYMBOL vmlinux 0x8af124e5	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0x8b009427	iterate_fd
++EXPORT_SYMBOL vmlinux 0x8b095b8b	icmp_send
++EXPORT_SYMBOL vmlinux 0x8b2f9f47	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b454798	set_posix_acl
++EXPORT_SYMBOL vmlinux 0x8b48aed9	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x8b4deaa9	vme_lm_request
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b989cf9	acpi_bus_can_wakeup
++EXPORT_SYMBOL vmlinux 0x8baa75ea	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0x8baaa245	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0x8bbb3254	__lock_buffer
++EXPORT_SYMBOL vmlinux 0x8bc5bc2c	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x8bdcdaa6	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x8bfe8c7c	pci_pme_active
++EXPORT_SYMBOL vmlinux 0x8c15831e	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0x8c183cbe	iowrite16
++EXPORT_SYMBOL vmlinux 0x8c2e3cca	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0x8c3e4641	wake_up_process
++EXPORT_SYMBOL vmlinux 0x8c40a029	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x8c4d3255	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x8c4e725d	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x8c5ca80b	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0x8c5e6cbe	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c670799	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x8c7aa1ae	netif_rx
++EXPORT_SYMBOL vmlinux 0x8c82a186	devm_clk_get
++EXPORT_SYMBOL vmlinux 0x8c934ce1	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0x8c9fc15c	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0x8ca22964	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0x8ca5cd99	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x8cae0de3	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0x8cc519d3	input_register_device
++EXPORT_SYMBOL vmlinux 0x8cc79cab	iowrite16_rep
++EXPORT_SYMBOL vmlinux 0x8cda8029	xen_clear_irq_pending
++EXPORT_SYMBOL vmlinux 0x8ce341e8	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x8ce73b8b	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0x8cf1a339	load_nls_default
++EXPORT_SYMBOL vmlinux 0x8cf6d04b	blk_make_request
++EXPORT_SYMBOL vmlinux 0x8cfd6cd0	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x8d04ec23	netdev_state_change
++EXPORT_SYMBOL vmlinux 0x8d0d3ea0	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0x8d2af3d0	clear_inode
++EXPORT_SYMBOL vmlinux 0x8d34eaa6	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0x8d43c200	agp_alloc_page_array
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d5526f9	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d5b26c0	set_pages_uc
++EXPORT_SYMBOL vmlinux 0x8d690582	__block_write_begin
++EXPORT_SYMBOL vmlinux 0x8d6d034c	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d838d91	ida_remove
++EXPORT_SYMBOL vmlinux 0x8d8d96c6	acpi_get_sleep_type_data
++EXPORT_SYMBOL vmlinux 0x8da1a3cb	acpi_remove_interface
++EXPORT_SYMBOL vmlinux 0x8daf8c42	dql_init
++EXPORT_SYMBOL vmlinux 0x8dca3a06	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0x8dee5b78	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x8deffe68	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x8df92f66	memchr_inv
++EXPORT_SYMBOL vmlinux 0x8e002cda	acpi_remove_gpe_block
++EXPORT_SYMBOL vmlinux 0x8e1953d6	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x8e2d83b6	node_to_cpumask_map
++EXPORT_SYMBOL vmlinux 0x8e2fd299	submit_bh
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e8231d6	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0x8e86b972	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0x8e9edf35	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x8eaf2a5f	vga_switcheroo_unregister_handler
++EXPORT_SYMBOL vmlinux 0x8eb90a61	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0x8eba3f5a	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x8eeddc48	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0x8f0562bc	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0x8f2703b7	wbinvd_on_all_cpus
++EXPORT_SYMBOL vmlinux 0x8f4ea17a	pci_match_id
++EXPORT_SYMBOL vmlinux 0x8f55dc5b	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0x8f6ace30	pnp_is_active
++EXPORT_SYMBOL vmlinux 0x8f840b34	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x8f8e34c5	drop_super
++EXPORT_SYMBOL vmlinux 0x8f9c199c	__get_user_2
++EXPORT_SYMBOL vmlinux 0x8fd1152e	_raw_write_unlock
++EXPORT_SYMBOL vmlinux 0x8fe1186d	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x8fe59cef	convert_art_to_tsc
++EXPORT_SYMBOL vmlinux 0x8fe95b40	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0x90121045	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0x90220ea4	sock_no_poll
++EXPORT_SYMBOL vmlinux 0x9023a30a	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x90241804	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0x90252bdc	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0x90253aa0	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0x90256141	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0x90278ac8	pci_bus_get
++EXPORT_SYMBOL vmlinux 0x902ac743	d_rehash
++EXPORT_SYMBOL vmlinux 0x902cb0f9	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x902fd536	to_nd_btt
++EXPORT_SYMBOL vmlinux 0x9035a4b5	tcp_poll
++EXPORT_SYMBOL vmlinux 0x9039b551	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0x903be13e	commit_creds
++EXPORT_SYMBOL vmlinux 0x903d3212	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0x904409c6	acpi_set_firmware_waking_vector
++EXPORT_SYMBOL vmlinux 0x9047b1fe	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x90564f31	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0x905cf16a	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x9078127e	__free_pages
++EXPORT_SYMBOL vmlinux 0x90794fdf	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0x908575fe	queued_write_lock_slowpath
++EXPORT_SYMBOL vmlinux 0x90a0f731	path_is_under
++EXPORT_SYMBOL vmlinux 0x90bcc176	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0x90e0b426	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0x90ea3dff	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0x90fba0a1	set_pages_array_uc
++EXPORT_SYMBOL vmlinux 0x90fff955	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x9140e426	udp_poll
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x914d6c97	wireless_send_event
++EXPORT_SYMBOL vmlinux 0x9156de53	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0x915da533	genphy_resume
++EXPORT_SYMBOL vmlinux 0x91607d95	set_memory_wb
++EXPORT_SYMBOL vmlinux 0x9162b4e3	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x9166fada	strncpy
++EXPORT_SYMBOL vmlinux 0x9169e226	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x91738c59	audit_log_start
++EXPORT_SYMBOL vmlinux 0x918289d0	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x918c43d6	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x91967e8e	xen_selfballoon_init
++EXPORT_SYMBOL vmlinux 0x91983498	serio_interrupt
++EXPORT_SYMBOL vmlinux 0x91ac822f	vscnprintf
++EXPORT_SYMBOL vmlinux 0x91b21240	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0x91b52b35	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x9205d0ba	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x9211e6fc	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0x9211e872	mmc_erase
++EXPORT_SYMBOL vmlinux 0x92351562	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0x92364d70	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x9258eb92	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0x925c7ccb	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0x9270cea8	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0x9291cd3b	memdup_user
++EXPORT_SYMBOL vmlinux 0x92a0e43d	tcf_register_action
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92b770d3	new_inode
++EXPORT_SYMBOL vmlinux 0x92b7d3a3	agp_generic_insert_memory
++EXPORT_SYMBOL vmlinux 0x92c61b66	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0x92d9f048	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0x92f6767f	lg_local_lock
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x92fcedfd	dump_skip
++EXPORT_SYMBOL vmlinux 0x92fd604b	acpi_pm_device_run_wake
++EXPORT_SYMBOL vmlinux 0x93022ba6	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x930a1308	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0x9310b576	vmap
++EXPORT_SYMBOL vmlinux 0x9318cf58	agp_find_bridge
++EXPORT_SYMBOL vmlinux 0x93216325	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0x932493a8	iosf_mbi_read
++EXPORT_SYMBOL vmlinux 0x932ae46d	dev_activate
++EXPORT_SYMBOL vmlinux 0x933f3e4a	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0x934bd46b	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0x935273f6	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0x9359b4e8	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0x93607c7d	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x939a1ca3	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93c12eb7	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0x93e47472	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0x93ed30b6	generic_write_end
++EXPORT_SYMBOL vmlinux 0x93eeee2b	bdi_init
++EXPORT_SYMBOL vmlinux 0x93f3e52b	acpi_extract_package
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x93fe09d3	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0x94026d06	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x942c9516	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x94475928	vme_register_driver
++EXPORT_SYMBOL vmlinux 0x945a6bc3	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0x9493161b	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94a9d410	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x94ba1991	install_exec_creds
++EXPORT_SYMBOL vmlinux 0x94bbdab0	d_find_alias
++EXPORT_SYMBOL vmlinux 0x94ca08f0	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x94d39c91	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x94e740e0	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0x94e7e180	pid_task
++EXPORT_SYMBOL vmlinux 0x94fdbae6	vme_master_request
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x95395301	acpi_exception
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x955a832f	___preempt_schedule
++EXPORT_SYMBOL vmlinux 0x956c941b	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0x9594c329	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0x95ab90de	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x95bd6e26	acpi_install_sci_handler
++EXPORT_SYMBOL vmlinux 0x95c1f535	dquot_file_open
++EXPORT_SYMBOL vmlinux 0x95d726d3	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0x95db45b6	agp_backend_release
++EXPORT_SYMBOL vmlinux 0x9604065c	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x96050177	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0x961b72dd	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0x969899b8	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0x96aba385	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x96b29254	strncasecmp
++EXPORT_SYMBOL vmlinux 0x96b5ba06	dquot_enable
++EXPORT_SYMBOL vmlinux 0x96b5d0e1	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x96c80d86	release_sock
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96ea4642	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x96f4cb36	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0x96f8af0a	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0x97051ca7	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0x970b4783	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0x9719c407	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x9719c409	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0x971a8632	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0x97235316	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0x9739f40d	blk_get_request
++EXPORT_SYMBOL vmlinux 0x973fa82e	register_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x976e5e7d	use_ibrs
++EXPORT_SYMBOL vmlinux 0x9786100b	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x97868aef	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0x9795743f	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0x9799482c	pci_release_regions
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x979f517b	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0x97a57333	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0x97c5bd0a	acpi_unload_parent_table
++EXPORT_SYMBOL vmlinux 0x97dcff38	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x97de0ddd	acpi_install_gpe_block
++EXPORT_SYMBOL vmlinux 0x97faed2b	pnp_unregister_card_driver
++EXPORT_SYMBOL vmlinux 0x980100a0	filp_close
++EXPORT_SYMBOL vmlinux 0x9815ed0f	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x9820b644	warn_slowpath_fmt_taint
++EXPORT_SYMBOL vmlinux 0x98299526	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x9829fc11	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0x98475508	skb_append
++EXPORT_SYMBOL vmlinux 0x985556ba	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x985a565a	init_special_inode
++EXPORT_SYMBOL vmlinux 0x986ab1c7	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0x986d857a	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0x986da01f	seq_pad
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x9878745c	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x988ed85d	set_memory_x
++EXPORT_SYMBOL vmlinux 0x98b5bb16	nvdimm_bus_unlock
++EXPORT_SYMBOL vmlinux 0x98c68c41	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x98f3774c	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x98f433db	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0x98fb85b5	amd_iommu_domain_set_gcr3
++EXPORT_SYMBOL vmlinux 0x98ffbdd2	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x99081d24	__scm_send
++EXPORT_SYMBOL vmlinux 0x99195078	vsnprintf
++EXPORT_SYMBOL vmlinux 0x992d300c	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x9949627b	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x996e5f13	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x996ed3ce	acpi_bus_get_status
++EXPORT_SYMBOL vmlinux 0x997f62d0	agp3_generic_tlbflush
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x9998a5f1	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99c5ed14	seq_file_path
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d3a43c	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x99daa9bf	try_offline_node
++EXPORT_SYMBOL vmlinux 0x99f068d5	x86_cpu_to_node_map
++EXPORT_SYMBOL vmlinux 0x99fb2aa1	free_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0x99fc790d	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0x9a1019b5	kobject_add
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1e94d2	lease_modify
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a1fccc2	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x9a27e2d8	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x9a3d4d7a	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0x9a655268	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0x9aa994b1	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x9ac2d2c1	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0x9adb1aad	vfs_writef
++EXPORT_SYMBOL vmlinux 0x9ae2da27	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0x9ae410ae	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9afa039e	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0x9b09bde9	irq_to_desc
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b72d292	generic_readlink
++EXPORT_SYMBOL vmlinux 0x9b741091	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0x9b74f925	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0x9b9b1f42	bdevname
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba146bf	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bbc5112	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x9bbe88b3	flex_array_put
++EXPORT_SYMBOL vmlinux 0x9bbf9c4e	d_tmpfile
++EXPORT_SYMBOL vmlinux 0x9bda7677	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9beb493f	inet_del_offload
++EXPORT_SYMBOL vmlinux 0x9bf1a718	set_cached_acl
++EXPORT_SYMBOL vmlinux 0x9c14ff25	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c529dfe	napi_disable
++EXPORT_SYMBOL vmlinux 0x9c53838b	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x9c7ad8e8	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0x9c9075e5	kobject_get
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cbe65f5	phy_device_register
++EXPORT_SYMBOL vmlinux 0x9cc4c8a9	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d299391	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0x9d33ef5e	acpi_enable
++EXPORT_SYMBOL vmlinux 0x9d3635fd	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d718752	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0x9d9e7959	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0x9da05e10	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0x9dca6970	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x9dca9a74	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x9dcfa052	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x9dd748e4	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0x9de1f663	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x9de3be85	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x9de4d400	xfrm_input
++EXPORT_SYMBOL vmlinux 0x9de69abb	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0x9df6a5da	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0x9dfff8d7	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0x9e089ae8	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0x9e098e2b	cpu_sibling_map
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e1f1753	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x9e257e22	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0x9e2f8c90	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9e323d36	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0x9e363b6b	acpi_disable_gpe
++EXPORT_SYMBOL vmlinux 0x9e3688a6	kthread_bind
++EXPORT_SYMBOL vmlinux 0x9e4e6193	simple_rmdir
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e543cb7	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x9e59fedc	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e64fbfe	rtc_cmos_read
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e79bf7b	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0x9e7d6bd0	__udelay
++EXPORT_SYMBOL vmlinux 0x9e8a07b7	console_start
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9eaf4194	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x9eb419d4	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9ef0c6d7	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x9ef1a139	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0x9effd427	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x9f1ad640	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f511477	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0x9f5a478e	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x9f6576a4	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0x9f7c1be8	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0x9f825420	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x9f87c25f	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0x9f8b90c0	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0x9f918e03	finish_no_open
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9fae5714	generic_permission
++EXPORT_SYMBOL vmlinux 0x9fc0658c	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0x9fcf4ee9	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0x9fd7cda1	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x9fdd679e	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9ff6017b	do_SAK
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa00aca2a	dql_completed
++EXPORT_SYMBOL vmlinux 0xa0408086	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0xa0426214	sk_wait_data
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa04f863e	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0xa052ea7f	set_pages_array_wb
++EXPORT_SYMBOL vmlinux 0xa053526c	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0xa0582698	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa0686eb4	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0xa06ad3ff	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0xa06ff399	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xa0766a92	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xa07773d1	follow_up
++EXPORT_SYMBOL vmlinux 0xa07a37f0	memchr
++EXPORT_SYMBOL vmlinux 0xa07b4a5a	dquot_get_state
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa07f6f7c	padata_alloc
++EXPORT_SYMBOL vmlinux 0xa0821827	mntget
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa095bb64	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0xa0abfb65	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0b61ed2	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0xa0be2fea	netif_napi_del
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0e95de0	module_put
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0ff74d6	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa1394ba4	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa14b3f5d	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0xa152319c	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0xa1695345	cad_pid
++EXPORT_SYMBOL vmlinux 0xa16e520d	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0xa178f011	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0xa18eee89	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0xa19e7e55	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0xa1b1c528	__ht_create_irq
++EXPORT_SYMBOL vmlinux 0xa1b3494e	sock_from_file
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1be8c42	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1c7a1ed	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa201540a	eth_header_cache
++EXPORT_SYMBOL vmlinux 0xa202a8e5	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa2105278	current_fs_time
++EXPORT_SYMBOL vmlinux 0xa213b814	clk_add_alias
++EXPORT_SYMBOL vmlinux 0xa218f4ee	sock_register
++EXPORT_SYMBOL vmlinux 0xa2337cc7	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0xa23e0143	__init_rwsem
++EXPORT_SYMBOL vmlinux 0xa23e0720	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0xa246d3dd	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0xa2578326	dquot_commit
++EXPORT_SYMBOL vmlinux 0xa25fdd7e	get_acl
++EXPORT_SYMBOL vmlinux 0xa27bc636	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0xa27d8bdb	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0xa2820a8b	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa28b3c7b	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0xa28e247d	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0xa2a335bd	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0xa2bbc5d7	migrate_page
++EXPORT_SYMBOL vmlinux 0xa2bbe984	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0xa2c32b61	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0xa2c7aa98	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0xa2dd9965	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0xa2eea5bc	skb_put
++EXPORT_SYMBOL vmlinux 0xa3010a3c	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0xa3035d68	inet_select_addr
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa34fcb2d	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xa350a8f8	set_memory_array_uc
++EXPORT_SYMBOL vmlinux 0xa36b2395	keyring_alloc
++EXPORT_SYMBOL vmlinux 0xa37e78b6	flex_array_get
++EXPORT_SYMBOL vmlinux 0xa3828bce	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xa3a69b46	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0xa3ace499	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0xa3c2bb69	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0xa3f819b4	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0xa4511467	crc16
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa482bc6c	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0xa4b94fea	iowrite8_rep
++EXPORT_SYMBOL vmlinux 0xa4c4f717	set_blocksize
++EXPORT_SYMBOL vmlinux 0xa4d4f0e6	global_cache_flush
++EXPORT_SYMBOL vmlinux 0xa4eb5286	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0xa4eca6a8	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0xa4fbcb79	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0xa50a80c2	boot_cpu_data
++EXPORT_SYMBOL vmlinux 0xa50ab78d	user_path_create
++EXPORT_SYMBOL vmlinux 0xa5120c7f	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xa51b4e89	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0xa52adeba	bio_reset
++EXPORT_SYMBOL vmlinux 0xa538a6b4	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa552dbb8	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0xa56251d5	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0xa56a21be	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0xa58abf9f	intel_gmch_probe
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa5a51eee	__crc32c_le
++EXPORT_SYMBOL vmlinux 0xa5c5ba49	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0xa5faaea4	release_pages
++EXPORT_SYMBOL vmlinux 0xa5fca81e	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0xa5fff89b	serio_open
++EXPORT_SYMBOL vmlinux 0xa632ed2d	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xa63322c6	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa642f588	netdev_notice
++EXPORT_SYMBOL vmlinux 0xa6610133	alloc_disk
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa67ef30b	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa6a0f38c	block_read_full_page
++EXPORT_SYMBOL vmlinux 0xa6b8e2ce	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0xa6bbd805	__wake_up
++EXPORT_SYMBOL vmlinux 0xa6bd63ca	acpi_bios_error
++EXPORT_SYMBOL vmlinux 0xa6c16c28	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0xa6febd8a	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa70b16aa	scsi_add_device
++EXPORT_SYMBOL vmlinux 0xa70fabbe	release_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0xa71638b6	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0xa72a0f5b	nr_online_nodes
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa74bcd62	rdmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0xa75aa9d0	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0xa7718c8d	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0xa7762746	cdev_del
++EXPORT_SYMBOL vmlinux 0xa788f1a0	i8253_lock
++EXPORT_SYMBOL vmlinux 0xa7b385e7	tcp_check_req
++EXPORT_SYMBOL vmlinux 0xa7d9facd	read_cache_pages
++EXPORT_SYMBOL vmlinux 0xa8076c09	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0xa8115cf4	register_gifconf
++EXPORT_SYMBOL vmlinux 0xa827cf6d	flush_old_exec
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa8638435	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0xa87190db	save_mount_options
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa881cdd4	make_kuid
++EXPORT_SYMBOL vmlinux 0xa8827dec	proc_symlink
++EXPORT_SYMBOL vmlinux 0xa883b127	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0xa890bbc5	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0xa8b11577	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0xa8b3ded4	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0xa8c9e255	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xa8e56a3b	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0xa8f4504f	vme_irq_free
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa916b694	strnlen
++EXPORT_SYMBOL vmlinux 0xa91d90d3	nla_put
++EXPORT_SYMBOL vmlinux 0xa9220a25	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0xa927513a	__genl_register_family
++EXPORT_SYMBOL vmlinux 0xa952daef	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0xa9569cb0	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa9831c10	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0xa98e6799	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0xa998214b	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0xa99b39c2	prandom_bytes
++EXPORT_SYMBOL vmlinux 0xa9a8e17f	arch_phys_wc_add
++EXPORT_SYMBOL vmlinux 0xa9ba9469	input_register_handler
++EXPORT_SYMBOL vmlinux 0xa9bd2676	__vmalloc
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9ff6fe2	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xaa142d01	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0xaa5bd08d	__pv_queued_spin_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa766159	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0xaaa229b2	kill_pid
++EXPORT_SYMBOL vmlinux 0xaac273c8	tty_check_change
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaae8ab0e	acpi_bus_power_manageable
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab0ca36c	nobh_write_end
++EXPORT_SYMBOL vmlinux 0xab324f57	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0xab47cab3	ppp_input
++EXPORT_SYMBOL vmlinux 0xab4884f0	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0xab551fad	acpi_get_data_full
++EXPORT_SYMBOL vmlinux 0xab600421	probe_irq_off
++EXPORT_SYMBOL vmlinux 0xab65ed80	set_memory_uc
++EXPORT_SYMBOL vmlinux 0xab6948cc	iput
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab770678	rdmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab7865fa	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0xab8d80c0	block_write_begin
++EXPORT_SYMBOL vmlinux 0xaba09689	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0xaba3159c	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0xaba5ac08	cros_ec_cmd_xfer_status
++EXPORT_SYMBOL vmlinux 0xaba95312	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabdbe099	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0xabf65de9	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac2babe8	scsi_init_io
++EXPORT_SYMBOL vmlinux 0xac2f60f5	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0xac398912	flex_array_clear
++EXPORT_SYMBOL vmlinux 0xac53b870	compat_mc_getsockopt
++EXPORT_SYMBOL vmlinux 0xac7f31e6	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0xac8c07ce	ata_link_printk
++EXPORT_SYMBOL vmlinux 0xaca9bcd2	pnp_disable_dev
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacb574f4	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0xacb99769	ida_destroy
++EXPORT_SYMBOL vmlinux 0xacc76868	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xad01744f	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0xad025e60	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad0d18e7	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0xad164875	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xad5b78c3	mount_single
++EXPORT_SYMBOL vmlinux 0xad698f77	dqstats
++EXPORT_SYMBOL vmlinux 0xad6aa8be	pci_clear_master
++EXPORT_SYMBOL vmlinux 0xad6e4bb6	mempool_free
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad94dec9	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0xadb0577d	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0xadd9ff5b	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0xaddbf9d0	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0xadf5eed7	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xae044bc7	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0xae062e89	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0xae0ba24b	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0xae117d83	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0xae1e3ffa	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0xae2cae79	nf_register_hook
++EXPORT_SYMBOL vmlinux 0xae2f878a	padata_start
++EXPORT_SYMBOL vmlinux 0xae407474	key_revoke
++EXPORT_SYMBOL vmlinux 0xae55f04b	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0xae65c15c	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0xae9dddb3	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0xaea140b8	single_release
++EXPORT_SYMBOL vmlinux 0xaea73cd0	fasync_helper
++EXPORT_SYMBOL vmlinux 0xaea976a8	acpi_check_resource_conflict
++EXPORT_SYMBOL vmlinux 0xaee75cd1	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0xaeee7983	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0xaf11982d	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0xaf1adf77	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf611eac	amd_nb_misc_ids
++EXPORT_SYMBOL vmlinux 0xaf6aa973	acpi_bus_register_driver
++EXPORT_SYMBOL vmlinux 0xaf6ae696	kstrndup
++EXPORT_SYMBOL vmlinux 0xaf85ef5c	path_get
++EXPORT_SYMBOL vmlinux 0xafb8c6ff	copy_user_generic_string
++EXPORT_SYMBOL vmlinux 0xafbd8029	bio_endio
++EXPORT_SYMBOL vmlinux 0xafbe0c53	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0xafc33af7	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0xafc50476	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0xafc95cc2	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0xafd5ff2c	amd_iommu_v2_supported
++EXPORT_SYMBOL vmlinux 0xaff82810	dquot_release
++EXPORT_SYMBOL vmlinux 0xb01b1db8	intel_gtt_insert_sg_entries
++EXPORT_SYMBOL vmlinux 0xb028d8fd	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0xb02bd591	_raw_read_unlock_irq
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb06e291a	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0xb081d5ba	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0xb08cd9b1	sync_inode
++EXPORT_SYMBOL vmlinux 0xb09aec05	register_key_type
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0a5b820	compat_tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0c019d9	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0xb0c03e33	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0xb0c7fe0f	__breadahead
++EXPORT_SYMBOL vmlinux 0xb0d39d36	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0xb0dbe167	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0e602eb	memmove
++EXPORT_SYMBOL vmlinux 0xb0e6d03d	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0xb0ea6102	simple_write_end
++EXPORT_SYMBOL vmlinux 0xb0eb41ff	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0xb10820e4	_raw_read_unlock
++EXPORT_SYMBOL vmlinux 0xb108e1ef	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0xb121390a	probe_irq_on
++EXPORT_SYMBOL vmlinux 0xb1293235	sock_create_kern
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb138b713	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0xb152d87d	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb17378bd	blk_put_queue
++EXPORT_SYMBOL vmlinux 0xb1873bd3	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0xb187b3a8	lg_lock_init
++EXPORT_SYMBOL vmlinux 0xb192415e	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0xb1a3e33f	proc_create_data
++EXPORT_SYMBOL vmlinux 0xb1ac32d7	iunique
++EXPORT_SYMBOL vmlinux 0xb1bb93a8	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1cfad22	rdmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xb1e5d6c9	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0xb1ffd7c2	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0xb208513c	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0xb20ecf88	acpi_run_osc
++EXPORT_SYMBOL vmlinux 0xb20f9ca4	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0xb217a80a	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0xb219d56c	wbinvd_on_cpu
++EXPORT_SYMBOL vmlinux 0xb21f29ce	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0xb25051b4	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0xb25c0892	notify_change
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb269dc76	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0xb27cd284	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0xb2aeac79	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2bf8201	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0xb2d46e5f	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xb2d5a552	complete
++EXPORT_SYMBOL vmlinux 0xb2e560f2	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0xb2f1c04a	kern_unmount
++EXPORT_SYMBOL vmlinux 0xb2f74fb6	intel_gmch_remove
++EXPORT_SYMBOL vmlinux 0xb2f81f88	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0xb2fd5ceb	__put_user_4
++EXPORT_SYMBOL vmlinux 0xb302e51e	__frontswap_store
++EXPORT_SYMBOL vmlinux 0xb309a426	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xb30d91f0	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0xb3284531	acpi_dbg_layer
++EXPORT_SYMBOL vmlinux 0xb34dd30b	inet_getname
++EXPORT_SYMBOL vmlinux 0xb34fc7cf	acpi_device_hid
++EXPORT_SYMBOL vmlinux 0xb352177e	find_first_bit
++EXPORT_SYMBOL vmlinux 0xb39bf65b	nf_log_trace
++EXPORT_SYMBOL vmlinux 0xb3bd9e17	simple_lookup
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3d64ad4	input_open_device
++EXPORT_SYMBOL vmlinux 0xb3e0df8d	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0xb3e226ba	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xb3ebd092	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb429fb8b	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0xb42a52bb	dev_crit
++EXPORT_SYMBOL vmlinux 0xb42e5f78	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xb439a2b3	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0xb443dadd	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0xb44c1438	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0xb4550762	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0xb4581ac2	phy_resume
++EXPORT_SYMBOL vmlinux 0xb4601a9e	generic_setlease
++EXPORT_SYMBOL vmlinux 0xb46c215b	bio_init
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb470b875	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0xb47189b5	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xb478d93d	acpi_get_hp_hw_control_from_firmware
++EXPORT_SYMBOL vmlinux 0xb47959ad	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0xb4b2000c	i2c_use_client
++EXPORT_SYMBOL vmlinux 0xb4cd07fd	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0xb4f78623	mpage_writepages
++EXPORT_SYMBOL vmlinux 0xb4fc36e6	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0xb4ff5083	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0xb50a673a	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0xb51961dd	tty_port_put
++EXPORT_SYMBOL vmlinux 0xb525bf57	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0xb52ee8be	intel_gtt_clear_range
++EXPORT_SYMBOL vmlinux 0xb53e44de	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0xb53e9267	__bforget
++EXPORT_SYMBOL vmlinux 0xb553342f	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0xb561193c	mpage_readpage
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb57df0f4	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0xb58e15c5	sock_rfree
++EXPORT_SYMBOL vmlinux 0xb592b357	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5c652d5	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb5d095ea	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0xb5d8be36	backlight_force_update
++EXPORT_SYMBOL vmlinux 0xb5dbd16a	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0xb6150a07	param_set_invbool
++EXPORT_SYMBOL vmlinux 0xb6234590	security_path_link
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb624fe81	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0xb631ec40	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0xb674a534	acpi_unmap_cpu
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6b1a614	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0xb6ccbe62	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0xb705cb30	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0xb70c356e	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0xb7131406	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0xb721b9bc	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0xb735920f	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0xb742b2bf	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb7543baa	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0xb75705c2	get_super_thawed
++EXPORT_SYMBOL vmlinux 0xb758b225	acpi_disable_event
++EXPORT_SYMBOL vmlinux 0xb761646c	backlight_device_register
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb775df6d	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0xb7b1208b	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7d13b93	send_sig_info
++EXPORT_SYMBOL vmlinux 0xb7d886fd	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0xb8074008	vfs_rename
++EXPORT_SYMBOL vmlinux 0xb8093690	kill_bdev
++EXPORT_SYMBOL vmlinux 0xb81b7535	pci_biosrom_size
++EXPORT_SYMBOL vmlinux 0xb825ae33	phy_disconnect
++EXPORT_SYMBOL vmlinux 0xb835c9e3	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0xb84d449e	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0xb84d541f	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0xb863285b	current_in_userns
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb87f2018	phy_attach
++EXPORT_SYMBOL vmlinux 0xb8b5395b	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0xb8b6a76c	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0xb8c16463	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0xb8c5c1f9	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0xb8e7ce2c	__put_user_8
++EXPORT_SYMBOL vmlinux 0xb8eea404	netif_device_detach
++EXPORT_SYMBOL vmlinux 0xb8fc5079	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0xb8fdcd10	mempool_resize
++EXPORT_SYMBOL vmlinux 0xb907513f	unpoison_memory
++EXPORT_SYMBOL vmlinux 0xb9195144	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0xb9329f2c	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0xb93c96f8	bh_submit_read
++EXPORT_SYMBOL vmlinux 0xb9468d4e	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0xb94db2cf	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0xb96e5115	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0xb96fda51	nd_region_release_lane
++EXPORT_SYMBOL vmlinux 0xb985c393	set_create_files_as
++EXPORT_SYMBOL vmlinux 0xb99e20b4	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0xb99f8a27	netdev_change_features
++EXPORT_SYMBOL vmlinux 0xb9b5a572	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0xb9ca9b0a	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0xb9cc9cae	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xba0c6c69	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0xba2bb5db	sock_i_ino
++EXPORT_SYMBOL vmlinux 0xba2d8594	ec_read
++EXPORT_SYMBOL vmlinux 0xba308af2	up_read
++EXPORT_SYMBOL vmlinux 0xba370af2	seq_escape
++EXPORT_SYMBOL vmlinux 0xba377bbc	pci_disable_device
++EXPORT_SYMBOL vmlinux 0xba3b3a86	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba54455f	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0xba65020d	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xba6da29b	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0xba8ade49	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0xbac3d67e	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0xbad98284	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0xbade624e	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0xbadf5da2	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0xbae47c05	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb072f5e	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0xbb0ae327	blk_register_region
++EXPORT_SYMBOL vmlinux 0xbb11c9d1	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0xbb2c5603	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0xbb34134a	iov_shorten
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb4f4766	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb89585f	get_agp_version
++EXPORT_SYMBOL vmlinux 0xbb8c5db0	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbba70a2d	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xbbaeb559	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0xbbd2036f	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0xbbd4e07b	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0xbbeb1ec6	ioremap_wt
++EXPORT_SYMBOL vmlinux 0xbc142db8	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0xbc1a7c56	param_set_copystring
++EXPORT_SYMBOL vmlinux 0xbc2031de	acpi_processor_get_bios_limit
++EXPORT_SYMBOL vmlinux 0xbc20d6aa	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0xbc23360e	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0xbc638c19	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0xbc65df25	dm_io
++EXPORT_SYMBOL vmlinux 0xbcb35cb9	__vfs_read
++EXPORT_SYMBOL vmlinux 0xbcbd2ddb	input_unregister_device
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcf11079	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0xbd01b6fb	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0xbd09754f	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0xbd22ce45	loop_backing_file
++EXPORT_SYMBOL vmlinux 0xbd462b55	__kfifo_init
++EXPORT_SYMBOL vmlinux 0xbd6d79f1	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0xbd7f2bc5	vfs_link
++EXPORT_SYMBOL vmlinux 0xbd87bff9	agp_generic_alloc_by_type
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbdaf5b07	acpi_os_read_port
++EXPORT_SYMBOL vmlinux 0xbdc6b187	cpu_tss
++EXPORT_SYMBOL vmlinux 0xbdcc6265	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0xbdde7a6f	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0xbde61d52	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0xbde70e44	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0xbded2a34	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0xbdf39147	simple_open
++EXPORT_SYMBOL vmlinux 0xbdfa238f	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0xbdfb6dbb	__fentry__
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe20d36a	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0xbe24d0c4	security_path_mknod
++EXPORT_SYMBOL vmlinux 0xbe2f9307	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0xbe30499b	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0xbe3146b6	amd_iommu_domain_direct_map
++EXPORT_SYMBOL vmlinux 0xbe33a2e9	dev_deactivate
++EXPORT_SYMBOL vmlinux 0xbe63846f	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0xbe678752	x86_dma_fallback_dev
++EXPORT_SYMBOL vmlinux 0xbe75c174	vga_con
++EXPORT_SYMBOL vmlinux 0xbe8a9f42	set_security_override
++EXPORT_SYMBOL vmlinux 0xbeb8d102	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0xbec282a6	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0xbec30d05	x86_match_cpu
++EXPORT_SYMBOL vmlinux 0xbeda4626	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbefe67de	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0xbf29d0a5	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0xbf3670d0	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xbf594923	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0xbf59eb7a	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0xbf6ecccb	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf8f7da6	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0xbf97da31	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfc177bc	iowrite32_rep
++EXPORT_SYMBOL vmlinux 0xbfdb835b	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0xbfe1c15c	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0xbfe6f427	_raw_spin_unlock_irq
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xbff6024e	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0xc0157947	down_read_trylock
++EXPORT_SYMBOL vmlinux 0xc033a9a5	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0xc0356cd4	set_bh_page
++EXPORT_SYMBOL vmlinux 0xc05e355f	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0xc067f4bb	poll_freewait
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc07c751e	vc_resize
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc0996a8a	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0a4f17f	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0xc0aa04a0	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0xc0abc0f2	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0xc0cd3b13	___ratelimit
++EXPORT_SYMBOL vmlinux 0xc1061670	dump_emit
++EXPORT_SYMBOL vmlinux 0xc15a44c6	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xc1625c6f	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0xc1744dce	agp_bind_memory
++EXPORT_SYMBOL vmlinux 0xc18340c8	down_read
++EXPORT_SYMBOL vmlinux 0xc18be15d	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0xc1af2b9a	put_cmsg
++EXPORT_SYMBOL vmlinux 0xc1b48209	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xc1c0b052	simple_statfs
++EXPORT_SYMBOL vmlinux 0xc1d31e0c	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc1f1716f	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xc203788a	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0xc20f289c	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0xc210c982	param_set_ushort
++EXPORT_SYMBOL vmlinux 0xc21b419b	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0xc22aa11b	agp_generic_create_gatt_table
++EXPORT_SYMBOL vmlinux 0xc237ce8f	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0xc2424641	agp3_generic_cleanup
++EXPORT_SYMBOL vmlinux 0xc245fa7c	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0xc24eaee7	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0xc273104f	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0xc27ff2ba	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0xc28879f6	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0xc29bf967	strspn
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2af3120	nla_append
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc310b981	strnstr
++EXPORT_SYMBOL vmlinux 0xc31f0343	nd_pfn_validate
++EXPORT_SYMBOL vmlinux 0xc3264d4c	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xc34cc0b5	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0xc35058ae	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0xc350b4eb	wrmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0xc3966737	is_bad_inode
++EXPORT_SYMBOL vmlinux 0xc39de4de	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0xc3aaf0a9	__put_user_1
++EXPORT_SYMBOL vmlinux 0xc3ac36ff	nvdimm_revalidate_disk
++EXPORT_SYMBOL vmlinux 0xc3aeb985	vfs_unlink
++EXPORT_SYMBOL vmlinux 0xc3b0a9f2	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0xc3b78d9d	udp_set_csum
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3d2c0cd	__register_nls
++EXPORT_SYMBOL vmlinux 0xc3e27e00	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0xc3ed1ebb	param_ops_short
++EXPORT_SYMBOL vmlinux 0xc439f23c	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0xc43d6742	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0xc441369a	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0xc451e86c	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0xc482cbdb	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0xc48307db	lz4_decompress
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4add59b	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0xc4b01d49	iterate_mounts
++EXPORT_SYMBOL vmlinux 0xc4f2344c	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0xc4f331c6	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0xc50604d6	touch_buffer
++EXPORT_SYMBOL vmlinux 0xc5137552	x86_bios_cpu_apicid
++EXPORT_SYMBOL vmlinux 0xc5215c6e	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0xc528983a	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0xc52c3f23	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0xc5534d64	ioread16
++EXPORT_SYMBOL vmlinux 0xc558530d	profile_pc
++EXPORT_SYMBOL vmlinux 0xc570e69a	km_query
++EXPORT_SYMBOL vmlinux 0xc5718826	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc5caf21b	abort_creds
++EXPORT_SYMBOL vmlinux 0xc5d6811c	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xc5d84324	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0xc5d9c46c	agp_try_unsupported_boot
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc62e09c3	iterate_dir
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc65abeb7	agp3_generic_sizes
++EXPORT_SYMBOL vmlinux 0xc666a132	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xc667e4dc	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xc6720e69	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0xc6772da2	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xc67db37a	vga_put
++EXPORT_SYMBOL vmlinux 0xc69977f8	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0xc69a5601	put_filp
++EXPORT_SYMBOL vmlinux 0xc6a5e3d2	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0xc6ae0fd5	__napi_schedule
++EXPORT_SYMBOL vmlinux 0xc6b27cc7	udp_seq_open
++EXPORT_SYMBOL vmlinux 0xc6b368d3	acpi_gpe_count
++EXPORT_SYMBOL vmlinux 0xc6cb465a	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6e0b4b0	arp_send
++EXPORT_SYMBOL vmlinux 0xc6f6dd90	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0xc6f8b81b	to_ndd
++EXPORT_SYMBOL vmlinux 0xc702e2ca	km_is_alive
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc72c23e4	release_firmware
++EXPORT_SYMBOL vmlinux 0xc733a903	use_ibpb
++EXPORT_SYMBOL vmlinux 0xc73f10f1	build_skb
++EXPORT_SYMBOL vmlinux 0xc74431cf	ata_print_version
++EXPORT_SYMBOL vmlinux 0xc749ed50	sk_free
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc7591cf0	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0xc75b05f7	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0xc7648204	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0xc76ab71e	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0xc7717b1d	acpi_processor_register_performance
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc78fcb91	km_state_notify
++EXPORT_SYMBOL vmlinux 0xc79407a3	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0xc79bb4cb	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7c112fa	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0xc7c12fbf	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0xc7c75d42	scsi_print_result
++EXPORT_SYMBOL vmlinux 0xc7cb92e7	get_user_pages
++EXPORT_SYMBOL vmlinux 0xc7ddce9a	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0xc7fcc5bf	acpi_resource_to_address64
++EXPORT_SYMBOL vmlinux 0xc7ff94f2	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0xc815137c	single_open
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc83f5cfc	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc85318e2	truncate_setsize
++EXPORT_SYMBOL vmlinux 0xc854715d	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0xc8581353	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0xc860e0d3	param_set_int
++EXPORT_SYMBOL vmlinux 0xc862469b	param_set_byte
++EXPORT_SYMBOL vmlinux 0xc8642791	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0xc8689cce	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xc872dcab	kill_block_super
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc88074e4	block_write_end
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc8a5a76a	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0xc8a88969	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8e28e3b	kernel_bind
++EXPORT_SYMBOL vmlinux 0xc8e621e3	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0xc8e926f9	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc94aa359	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0xc9533529	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc96c635d	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0xc9736bf7	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0xc9748b44	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0xc978479a	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xc97a2685	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0xc98a9367	single_open_size
++EXPORT_SYMBOL vmlinux 0xc98f553e	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc99f6aae	dma_spin_lock
++EXPORT_SYMBOL vmlinux 0xc9a49693	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0xc9ace8bd	security_mmap_file
++EXPORT_SYMBOL vmlinux 0xc9fef317	add_wait_queue
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca399774	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0xca4d6313	pci_map_rom
++EXPORT_SYMBOL vmlinux 0xca591fb6	inode_init_owner
++EXPORT_SYMBOL vmlinux 0xca5ee09a	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0xca832efe	kmalloc_order
++EXPORT_SYMBOL vmlinux 0xca8acc78	acpi_dbg_level
++EXPORT_SYMBOL vmlinux 0xca8f1fa1	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xcaa0bc94	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0xcab35d49	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0xcacb9f83	md_reload_sb
++EXPORT_SYMBOL vmlinux 0xcad3ba14	neigh_xmit
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb101bc3	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0xcb13709e	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0xcb1a0571	phy_find_first
++EXPORT_SYMBOL vmlinux 0xcb1b19b5	d_alloc
++EXPORT_SYMBOL vmlinux 0xcb1dcfcc	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0xcb343468	alloc_file
++EXPORT_SYMBOL vmlinux 0xcb444f9c	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0xcb460c1f	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0xcb5ad2a4	__register_chrdev
++EXPORT_SYMBOL vmlinux 0xcb733bf2	acpi_bus_set_power
++EXPORT_SYMBOL vmlinux 0xcb7dc89d	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0xcb84ec95	tcp_filter
++EXPORT_SYMBOL vmlinux 0xcb936989	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcb96845c	set_disk_ro
++EXPORT_SYMBOL vmlinux 0xcbae6c7a	acpi_lid_notifier_unregister
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbd6d852	pnp_start_dev
++EXPORT_SYMBOL vmlinux 0xcbec4bdf	param_ops_long
++EXPORT_SYMBOL vmlinux 0xcbee2d8c	vfs_setpos
++EXPORT_SYMBOL vmlinux 0xcc15d6e4	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xcc1c4aeb	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc4dd6d0	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc527608	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0xcc652efa	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0xcc75d7d8	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0xcc82add3	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xcc838223	__pte2cachemode_tbl
++EXPORT_SYMBOL vmlinux 0xcc87bc77	tty_register_device
++EXPORT_SYMBOL vmlinux 0xcc8d3f4f	acpi_os_execute
++EXPORT_SYMBOL vmlinux 0xcc970f7f	mount_nodev
++EXPORT_SYMBOL vmlinux 0xcc9aa2a6	register_sysctl
++EXPORT_SYMBOL vmlinux 0xccb0d76f	amd_iommu_complete_ppr
++EXPORT_SYMBOL vmlinux 0xccb68448	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccde6c15	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0xcceee8d6	pnp_unregister_driver
++EXPORT_SYMBOL vmlinux 0xccf4f8ce	path_noexec
++EXPORT_SYMBOL vmlinux 0xcd02081e	vga_switcheroo_register_client
++EXPORT_SYMBOL vmlinux 0xcd20667a	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0xcd2236b4	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd377549	skb_find_text
++EXPORT_SYMBOL vmlinux 0xcd57f7b0	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0xcd7140ec	prepare_binprm
++EXPORT_SYMBOL vmlinux 0xcd7ae39c	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0xcd838e1b	poll_initwait
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdca60d3	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0xcddb0270	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0xcdde2ac5	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0xcdf7f7ae	scsi_host_get
++EXPORT_SYMBOL vmlinux 0xce044088	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0xce0e2d66	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce2c45cc	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xce31856b	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0xce447c63	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0xce4904a4	acpi_leave_sleep_state
++EXPORT_SYMBOL vmlinux 0xce4e47b6	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce67469d	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0xce783737	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0xce7850e1	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0xce7f9a4f	xen_biovec_phys_mergeable
++EXPORT_SYMBOL vmlinux 0xce898423	read_cache_page
++EXPORT_SYMBOL vmlinux 0xce9f3f4a	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xceae504f	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0xcec3e99b	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xceeee392	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf0a8b2d	pipe_unlock
++EXPORT_SYMBOL vmlinux 0xcf2b1caf	input_inject_event
++EXPORT_SYMBOL vmlinux 0xcf2b8230	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0xcf53557c	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xcf5a1a11	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0xcf62b51c	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0xcf6cfe1f	msrs_free
++EXPORT_SYMBOL vmlinux 0xcf76b851	vga_switcheroo_init_domain_pm_ops
++EXPORT_SYMBOL vmlinux 0xcfa1208a	vfs_read
++EXPORT_SYMBOL vmlinux 0xcfb4a296	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0xcfd4fa9f	dev_alert
++EXPORT_SYMBOL vmlinux 0xd00e42da	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0xd014bbbf	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0xd0181dc7	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0xd022bf9d	key_task_permission
++EXPORT_SYMBOL vmlinux 0xd02abf2b	replace_mount_options
++EXPORT_SYMBOL vmlinux 0xd035c3b9	ppp_input_error
++EXPORT_SYMBOL vmlinux 0xd0493e66	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0xd054bc52	dev_change_flags
++EXPORT_SYMBOL vmlinux 0xd0565f39	I_BDEV
++EXPORT_SYMBOL vmlinux 0xd05c70b4	import_iovec
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd08b19f2	copy_to_iter
++EXPORT_SYMBOL vmlinux 0xd08f6239	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0ea3b13	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f32c4e	sock_no_accept
++EXPORT_SYMBOL vmlinux 0xd0f358ee	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fef3b2	agp_free_key
++EXPORT_SYMBOL vmlinux 0xd0ffc396	i8042_install_filter
++EXPORT_SYMBOL vmlinux 0xd10d11ca	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0xd11f66ba	set_anon_super
++EXPORT_SYMBOL vmlinux 0xd1301740	scsi_host_put
++EXPORT_SYMBOL vmlinux 0xd14b778c	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd1652a93	acpi_info
++EXPORT_SYMBOL vmlinux 0xd172e44c	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0xd178ff70	vm_stat
++EXPORT_SYMBOL vmlinux 0xd17fc2e2	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd1911b1d	elevator_exit
++EXPORT_SYMBOL vmlinux 0xd1acddb2	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0xd1af29ee	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0xd1b56d94	downgrade_write
++EXPORT_SYMBOL vmlinux 0xd1d86523	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1dd67c6	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0xd1f5d729	vfs_symlink
++EXPORT_SYMBOL vmlinux 0xd1f6c5f3	smp_num_siblings
++EXPORT_SYMBOL vmlinux 0xd2064e2f	idr_replace
++EXPORT_SYMBOL vmlinux 0xd20f3020	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xd2194e8b	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0xd22215ca	down_write
++EXPORT_SYMBOL vmlinux 0xd22daee2	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0xd2343054	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0xd242a61b	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0xd247a236	audit_log
++EXPORT_SYMBOL vmlinux 0xd24d0494	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd2916c6a	simple_unlink
++EXPORT_SYMBOL vmlinux 0xd2ad5f5e	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0xd2b09ce5	__kmalloc
++EXPORT_SYMBOL vmlinux 0xd2bb6c4d	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2fe0616	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0xd310d7d4	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0xd34cf56c	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0xd36e3d59	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0xd3719d59	paravirt_ticketlocks_enabled
++EXPORT_SYMBOL vmlinux 0xd3ad96a3	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3cf2cde	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0xd40a1592	skb_store_bits
++EXPORT_SYMBOL vmlinux 0xd439b5c1	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0xd453af12	revert_creds
++EXPORT_SYMBOL vmlinux 0xd45cc6ca	bin2hex
++EXPORT_SYMBOL vmlinux 0xd4835ef8	dmi_check_system
++EXPORT_SYMBOL vmlinux 0xd4b4f75e	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0xd4f697a1	input_allocate_device
++EXPORT_SYMBOL vmlinux 0xd50fef48	acpi_detach_data
++EXPORT_SYMBOL vmlinux 0xd53b6c37	bd_set_size
++EXPORT_SYMBOL vmlinux 0xd5480e6b	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xd548dc1d	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd563bf04	vfs_mknod
++EXPORT_SYMBOL vmlinux 0xd586e77b	clk_get
++EXPORT_SYMBOL vmlinux 0xd587c2c7	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd5c265c6	n_tty_compat_ioctl_helper
++EXPORT_SYMBOL vmlinux 0xd5db75bd	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0xd5f41d60	dcb_getapp
++EXPORT_SYMBOL vmlinux 0xd5f61fa6	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0xd5fd4566	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xd6068bf4	simple_getattr
++EXPORT_SYMBOL vmlinux 0xd60dad12	seq_open
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd620e580	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0xd623af83	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0xd627cb65	blk_complete_request
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd62c83d4	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0xd6419547	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd64eefa0	drop_nlink
++EXPORT_SYMBOL vmlinux 0xd65b8b85	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0xd66b7a03	lookup_one_len
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd68cad4d	cros_ec_cmd_xfer
++EXPORT_SYMBOL vmlinux 0xd68e1d1b	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0xd6a1455e	security_file_permission
++EXPORT_SYMBOL vmlinux 0xd6aed5d0	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0xd6b2d0c8	path_put
++EXPORT_SYMBOL vmlinux 0xd6b2ed5f	generate_pm_trace
++EXPORT_SYMBOL vmlinux 0xd6b33026	cpu_khz
++EXPORT_SYMBOL vmlinux 0xd6d9a087	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0xd6de7073	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0xd6dfeb9e	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd6f644a8	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0xd6fd5621	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0xd71c0b5f	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0xd7270c0d	sock_wfree
++EXPORT_SYMBOL vmlinux 0xd730959d	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xd7389705	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0xd75374ad	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd772377b	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0xd798de2e	done_path_create
++EXPORT_SYMBOL vmlinux 0xd7a29ea0	neigh_destroy
++EXPORT_SYMBOL vmlinux 0xd7b82846	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0xd7ce11d3	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0xd7ce9c85	pci_request_region
++EXPORT_SYMBOL vmlinux 0xd7db1dbf	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0xd7dd777b	reserve_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd7ee926a	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0xd82833b3	vga_switcheroo_get_client_state
++EXPORT_SYMBOL vmlinux 0xd833db80	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0xd8444c1f	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0xd86a8a4d	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8b4b598	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0xd8b78d2d	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0xd8d42968	register_quota_format
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd9091363	acpi_install_notify_handler
++EXPORT_SYMBOL vmlinux 0xd90c2c2f	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0xd90d65e0	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0xd910d8df	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0xd9238f28	from_kgid
++EXPORT_SYMBOL vmlinux 0xd92e2dca	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0xd94322e7	acpi_evaluate_reference
++EXPORT_SYMBOL vmlinux 0xd948aece	register_netdevice
++EXPORT_SYMBOL vmlinux 0xd956f6b5	dquot_destroy
++EXPORT_SYMBOL vmlinux 0xd969b2c7	amd_e400_c1e_detected
++EXPORT_SYMBOL vmlinux 0xd971c6c4	xen_arch_register_cpu
++EXPORT_SYMBOL vmlinux 0xd9810f07	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd990d62c	is_nvdimm_bus_locked
++EXPORT_SYMBOL vmlinux 0xd9a03b9c	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0xd9aa566a	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0xd9c67fa9	cpu_info
++EXPORT_SYMBOL vmlinux 0xd9c6f6bc	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0xd9d3bcd3	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9e20c7c	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0xd9ec2f95	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xd9ee6733	simple_dname
++EXPORT_SYMBOL vmlinux 0xda02e13f	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0xda1d0c1a	stop_tty
++EXPORT_SYMBOL vmlinux 0xda34ff46	inode_init_always
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda42fd16	__page_symlink
++EXPORT_SYMBOL vmlinux 0xda65d1f4	netif_skb_features
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda9fc7ae	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0xdab932b0	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdad6853f	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0xdae80100	_raw_spin_unlock
++EXPORT_SYMBOL vmlinux 0xdaea6e0d	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0xdb026db4	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0xdb0e4776	md_flush_request
++EXPORT_SYMBOL vmlinux 0xdb12d8a2	iov_iter_init
++EXPORT_SYMBOL vmlinux 0xdb16b170	topology_phys_to_logical_pkg
++EXPORT_SYMBOL vmlinux 0xdb28a39d	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0xdb2e540a	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0xdb3bcca6	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0xdb3d2994	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xdb40760c	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0xdb4604c6	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0xdb47f4cd	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb7305a1	__stack_chk_fail
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb8d7a2f	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0xdb8e7ddb	sget_userns
++EXPORT_SYMBOL vmlinux 0xdb953c57	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0xdbaf8b71	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0xdbb12a20	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0xdbc65abc	invalidate_partition
++EXPORT_SYMBOL vmlinux 0xdbff6351	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc22e69e	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0xdc30f707	pnp_get_resource
++EXPORT_SYMBOL vmlinux 0xdc3c41a8	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xdc3d0afb	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc498feb	genphy_update_link
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdc573cd4	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0xdc57f532	acpi_install_gpe_handler
++EXPORT_SYMBOL vmlinux 0xdc5e0904	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0xdc5f5da8	lockref_put_return
++EXPORT_SYMBOL vmlinux 0xdc699032	pci_save_state
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdccf131f	__scm_destroy
++EXPORT_SYMBOL vmlinux 0xdce04084	get_io_context
++EXPORT_SYMBOL vmlinux 0xdce2fbf0	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0xdcedb4f3	sg_miter_start
++EXPORT_SYMBOL vmlinux 0xdd0df62c	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0xdd3ba0da	locks_free_lock
++EXPORT_SYMBOL vmlinux 0xdd42952b	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0xdd5f27d4	agp_collect_device_status
++EXPORT_SYMBOL vmlinux 0xdd64e639	strscpy
++EXPORT_SYMBOL vmlinux 0xdd6b2358	input_set_keycode
++EXPORT_SYMBOL vmlinux 0xdd87df2d	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0xdd8e2174	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xddb583f6	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0xdddb28a2	seq_puts
++EXPORT_SYMBOL vmlinux 0xdde09e37	compat_nf_setsockopt
++EXPORT_SYMBOL vmlinux 0xddea2e78	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0xddef0ae2	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0xde055136	nonseekable_open
++EXPORT_SYMBOL vmlinux 0xde0c5bc7	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0xde0e4903	padata_stop
++EXPORT_SYMBOL vmlinux 0xde11516a	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0xde11ccd7	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0xde16dc16	tboot
++EXPORT_SYMBOL vmlinux 0xde17c7b0	kaiser_enabled
++EXPORT_SYMBOL vmlinux 0xde1ef4d4	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0xde389503	__alloc_skb
++EXPORT_SYMBOL vmlinux 0xde4235e0	__napi_complete
++EXPORT_SYMBOL vmlinux 0xde45bd2f	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0xde6033c9	bio_chain
++EXPORT_SYMBOL vmlinux 0xde6151db	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xde709c92	vfs_write
++EXPORT_SYMBOL vmlinux 0xde7acca2	phy_init_eee
++EXPORT_SYMBOL vmlinux 0xde8bdc09	empty_aops
++EXPORT_SYMBOL vmlinux 0xde8fa1a7	dev_uc_init
++EXPORT_SYMBOL vmlinux 0xde912354	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde9ac0fb	nd_btt_probe
++EXPORT_SYMBOL vmlinux 0xde9b17ed	agp3_generic_fetch_size
++EXPORT_SYMBOL vmlinux 0xdead93b5	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0xdec51a53	vga_switcheroo_unregister_client
++EXPORT_SYMBOL vmlinux 0xdedac7ef	agp_generic_mask_memory
++EXPORT_SYMBOL vmlinux 0xdedb6611	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0xdeee66a2	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xdf0da3cc	acpi_get_devices
++EXPORT_SYMBOL vmlinux 0xdf12a927	acpi_check_dsm
++EXPORT_SYMBOL vmlinux 0xdf1427e5	idr_remove
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf5367fb	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf5b1698	seq_vprintf
++EXPORT_SYMBOL vmlinux 0xdf5d7e22	agp_generic_alloc_page
++EXPORT_SYMBOL vmlinux 0xdf5feada	ipv4_specific
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf716457	free_user_ns
++EXPORT_SYMBOL vmlinux 0xdf785418	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0xdf8c695a	__ndelay
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdf9afac6	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0xdfba7ea7	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xdfd3a075	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0xdff66710	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xe00bd6bc	dquot_disable
++EXPORT_SYMBOL vmlinux 0xe00d2f3f	nf_log_set
++EXPORT_SYMBOL vmlinux 0xe034f953	page_readlink
++EXPORT_SYMBOL vmlinux 0xe03f153e	try_to_release_page
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe081680e	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe087f8b6	simple_empty
++EXPORT_SYMBOL vmlinux 0xe0918dc9	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0xe0ac8bd2	acpi_bus_generate_netlink_event
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0caf778	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0xe0cc4470	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0xe0ccb770	dst_destroy
++EXPORT_SYMBOL vmlinux 0xe0d8f9ae	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0xe0fee085	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0xe1059f03	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0xe108f343	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe13cd8a7	dmi_name_in_vendors
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe17d78b5	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0xe19f3baa	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0xe1a31d5b	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0xe1b26b44	set_groups
++EXPORT_SYMBOL vmlinux 0xe1bde4cc	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0xe1bf84b7	d_make_root
++EXPORT_SYMBOL vmlinux 0xe1c54c49	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe20372ae	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0xe212887f	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0xe221df57	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0xe23a5101	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe23c3139	i2c_release_client
++EXPORT_SYMBOL vmlinux 0xe247cf4f	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe259ae9e	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0xe25d9601	blk_end_request
++EXPORT_SYMBOL vmlinux 0xe27283db	pnp_device_detach
++EXPORT_SYMBOL vmlinux 0xe298a062	param_ops_uint
++EXPORT_SYMBOL vmlinux 0xe29b04e9	acpi_set_firmware_waking_vector64
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2a5a525	arp_create
++EXPORT_SYMBOL vmlinux 0xe2ac1905	bio_copy_data
++EXPORT_SYMBOL vmlinux 0xe2b46958	amd_iommu_domain_clear_gcr3
++EXPORT_SYMBOL vmlinux 0xe2cbf007	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0xe2cdc763	udp_ioctl
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2e21fbd	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0xe2f0cefd	arch_dma_alloc_attrs
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe317764d	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0xe319eb24	acpi_pci_osc_control_set
++EXPORT_SYMBOL vmlinux 0xe334bb8c	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0xe3399a75	native_queued_spin_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xe3532760	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0xe35d2a38	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0xe3687937	proc_set_user
++EXPORT_SYMBOL vmlinux 0xe372e8f9	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0xe37a7a8e	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0xe3a53f4c	sort
++EXPORT_SYMBOL vmlinux 0xe3aa9378	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3c6a99c	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0xe3cef790	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3da2383	tty_write_room
++EXPORT_SYMBOL vmlinux 0xe3e6902c	set_device_ro
++EXPORT_SYMBOL vmlinux 0xe40b3c43	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0xe40dc306	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0xe44aecfb	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0xe45fe0af	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0xe4662452	elv_add_request
++EXPORT_SYMBOL vmlinux 0xe46cdc45	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0xe4753372	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0xe484b4ab	tcp_req_err
++EXPORT_SYMBOL vmlinux 0xe484e35f	ioread32
++EXPORT_SYMBOL vmlinux 0xe4950f82	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0xe49baaee	follow_down
++EXPORT_SYMBOL vmlinux 0xe4a4b009	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0xe4c20891	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0xe4ca259a	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0xe4dcfded	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0xe4e3fab7	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe4eaab2e	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0xe502e5f3	ether_setup
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe52eb8e7	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0xe530d757	acpi_clear_gpe
++EXPORT_SYMBOL vmlinux 0xe531ac3b	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0xe5558cad	kernel_connect
++EXPORT_SYMBOL vmlinux 0xe575732b	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5815f8a	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe588895e	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0xe594d17b	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0xe5b1c388	register_shrinker
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5ca7cd6	mount_subtree
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe6162877	down_killable
++EXPORT_SYMBOL vmlinux 0xe6426153	ihold
++EXPORT_SYMBOL vmlinux 0xe64d98fe	rdmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0xe65a73d7	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xe67221ab	nvdimm_bus_lock
++EXPORT_SYMBOL vmlinux 0xe683b83d	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe69a9df4	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xe6a34955	setup_new_exec
++EXPORT_SYMBOL vmlinux 0xe6a3e811	phy_start
++EXPORT_SYMBOL vmlinux 0xe6a5a1aa	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0xe6fa60a6	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe708c67e	led_blink_set
++EXPORT_SYMBOL vmlinux 0xe716baed	acpi_unregister_ioapic
++EXPORT_SYMBOL vmlinux 0xe71f28b4	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0xe7470ad9	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0xe749c52c	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0xe74ba8d3	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xe767da1f	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0xe7790f5e	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0xe77d416d	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0xe78eb6c9	scsi_device_get
++EXPORT_SYMBOL vmlinux 0xe79d0cc8	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0xe7a504f6	key_unlink
++EXPORT_SYMBOL vmlinux 0xe7a586b5	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7ad3ecf	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0xe7bc3482	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7d736de	netdev_emerg
++EXPORT_SYMBOL vmlinux 0xe7e93f16	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0xe7f3f51a	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0xe8033384	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0xe81ef1dd	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe862153b	d_lookup
++EXPORT_SYMBOL vmlinux 0xe8731918	x86_hyper_xen
++EXPORT_SYMBOL vmlinux 0xe877e13b	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe88a1f09	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0xe893e2bb	unlock_rename
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8ad9269	vme_irq_request
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8d3fce5	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0xe8db8dd2	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0xe8ece1e8	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0xe8ef0ff0	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0xe90be5f3	console_stop
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe92135af	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0xe92b512d	dm_put_device
++EXPORT_SYMBOL vmlinux 0xe9313d80	arp_tbl
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe95e00cf	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0xe9772a88	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0xe996c25d	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0xe997667b	wrmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xe9a3ddcd	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0xe9ac774c	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0xe9acfac4	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xe9adfd85	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0xe9dac6f5	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea0ced12	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0xea10048f	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0xea11b977	processors
++EXPORT_SYMBOL vmlinux 0xea1c7dfa	arch_debugfs_dir
++EXPORT_SYMBOL vmlinux 0xea37524e	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0xea3f725d	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xea76371a	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0xea7a42f9	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xea7b8a44	acpi_install_interface
++EXPORT_SYMBOL vmlinux 0xea7cf94e	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0xea90bdd3	acpi_attach_data
++EXPORT_SYMBOL vmlinux 0xea99e9a4	do_truncate
++EXPORT_SYMBOL vmlinux 0xeab77bf8	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0xeac542cf	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0xeac73847	irq_regs
++EXPORT_SYMBOL vmlinux 0xead626c8	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0xeae3dfd6	__const_udelay
++EXPORT_SYMBOL vmlinux 0xeaedb49b	agp_generic_enable
++EXPORT_SYMBOL vmlinux 0xeaf3462d	blkdev_put
++EXPORT_SYMBOL vmlinux 0xeb02f4eb	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0xeb1b20a8	igrab
++EXPORT_SYMBOL vmlinux 0xeb1cce94	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb44339a	free_pages_exact
++EXPORT_SYMBOL vmlinux 0xeb5d2fb5	netif_napi_add
++EXPORT_SYMBOL vmlinux 0xeb5e0f0f	skb_trim
++EXPORT_SYMBOL vmlinux 0xeb8700ce	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0xeb9f564f	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0xeba85c7a	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0xebaba91b	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xebac74d8	cdrom_release
++EXPORT_SYMBOL vmlinux 0xebb67fc2	skb_checksum
++EXPORT_SYMBOL vmlinux 0xebbe266b	vga_tryget
++EXPORT_SYMBOL vmlinux 0xebf5cb00	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0xebff5cf5	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0xec1b975b	param_ops_int
++EXPORT_SYMBOL vmlinux 0xec1fdfa4	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0xec29ed5a	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec591803	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0xec59ee37	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0xec5ce167	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0xec9646cd	netdev_printk
++EXPORT_SYMBOL vmlinux 0xecac8407	__memcpy
++EXPORT_SYMBOL vmlinux 0xecaeeae0	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0xecbf4bd2	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0xeccd3e0c	acpi_handle_printk
++EXPORT_SYMBOL vmlinux 0xece2b6bd	eth_header_parse
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xecfd68ef	acpi_get_node
++EXPORT_SYMBOL vmlinux 0xed0558d7	dquot_resume
++EXPORT_SYMBOL vmlinux 0xed0d6708	agp_generic_alloc_user
++EXPORT_SYMBOL vmlinux 0xed1b9bea	vga_get
++EXPORT_SYMBOL vmlinux 0xed20168a	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0xed4bce1c	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed7a2275	__bread_gfp
++EXPORT_SYMBOL vmlinux 0xed7ec9e6	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedb9903f	param_set_long
++EXPORT_SYMBOL vmlinux 0xedba6876	__register_binfmt
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedc62a37	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0xede68339	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0xedefc01a	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xedf7ab08	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0xedfcc439	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0xee0377e5	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0xee0dcd01	param_get_ushort
++EXPORT_SYMBOL vmlinux 0xee1b50e8	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0xee1e9f23	fd_install
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee3c00fc	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0xee3e5e4e	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xee4a7d80	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0xee7eb9e1	pnp_platform_devices
++EXPORT_SYMBOL vmlinux 0xee80bbdf	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0xee814ad1	compat_sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0xee8fb824	find_vma
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xeea3cd7a	nla_reserve
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeeb92510	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0xeec2c7cf	ucs2_as_utf8
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xeef427cb	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0xef021fff	init_net
++EXPORT_SYMBOL vmlinux 0xef227b1e	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0xef2a00c6	bio_put
++EXPORT_SYMBOL vmlinux 0xef47c4b2	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0xef609be9	generic_writepages
++EXPORT_SYMBOL vmlinux 0xef873024	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0xef887695	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0xef9673a9	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0xef9aedfc	boot_option_idle_override
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefd66947	touch_atime
++EXPORT_SYMBOL vmlinux 0xefd9d31e	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0xefda8d99	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefe099c3	acpi_get_event_status
++EXPORT_SYMBOL vmlinux 0xeff4d5bb	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf00cbc85	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0xf017120d	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf0356e5b	kernel_read
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf062576b	ucs2_utf8size
++EXPORT_SYMBOL vmlinux 0xf06556e4	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0xf065f629	ioread16be
++EXPORT_SYMBOL vmlinux 0xf067257c	register_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0xf08242c2	finish_wait
++EXPORT_SYMBOL vmlinux 0xf08ba178	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf09dcb6f	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0a2820b	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0xf0a8237a	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xf0adef22	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0xf0c6e15e	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0xf0d763a5	inode_init_once
++EXPORT_SYMBOL vmlinux 0xf0eaffce	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf10684c1	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0xf10c41b4	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0xf10de535	ioread8
++EXPORT_SYMBOL vmlinux 0xf11543ff	find_first_zero_bit
++EXPORT_SYMBOL vmlinux 0xf116d4b5	copy_in_user
++EXPORT_SYMBOL vmlinux 0xf1234148	blk_put_request
++EXPORT_SYMBOL vmlinux 0xf12fcc13	km_new_mapping
++EXPORT_SYMBOL vmlinux 0xf1333ab0	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0xf137c90f	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0xf1398e2e	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xf13bc7cb	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xf13e7b39	__inode_permission
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf1620c25	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf1afe392	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0xf1b3b399	__inet_hash
++EXPORT_SYMBOL vmlinux 0xf1b405ea	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1f398ab	override_creds
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf21355eb	update_devfreq
++EXPORT_SYMBOL vmlinux 0xf217726d	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0xf229121d	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf2453283	dev_close
++EXPORT_SYMBOL vmlinux 0xf2796e33	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0xf28ed6e2	machine_to_phys_nr
++EXPORT_SYMBOL vmlinux 0xf2975262	bio_split
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2a2b163	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0xf2a9e465	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0xf2af682d	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2cb4699	vga_switcheroo_register_handler
++EXPORT_SYMBOL vmlinux 0xf2d615fd	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0xf2dda68f	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xf2fa8ce6	cdev_add
++EXPORT_SYMBOL vmlinux 0xf312cb9d	ucs2_strsize
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf32c6e2d	tty_unlock
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf3496180	kill_anon_super
++EXPORT_SYMBOL vmlinux 0xf350ed10	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0xf3516490	d_add_ci
++EXPORT_SYMBOL vmlinux 0xf35321cf	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf36906b7	softnet_data
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf38bc082	iget5_locked
++EXPORT_SYMBOL vmlinux 0xf38fb795	dqget
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf395d660	genphy_suspend
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf3986b06	acpi_os_map_generic_address
++EXPORT_SYMBOL vmlinux 0xf3afe9ee	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0xf3b0f85a	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0xf3bcdd7d	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0xf3bfe648	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf3f4804c	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0xf3f82ecf	compat_tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0xf3fa2585	input_release_device
++EXPORT_SYMBOL vmlinux 0xf3fb95a4	compat_sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0xf41185dd	fs_bio_set
++EXPORT_SYMBOL vmlinux 0xf412a451	set_wb_congested
++EXPORT_SYMBOL vmlinux 0xf41b2907	vme_slot_num
++EXPORT_SYMBOL vmlinux 0xf42fcfab	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0xf435cb2f	uart_match_port
++EXPORT_SYMBOL vmlinux 0xf441ac43	ioread8_rep
++EXPORT_SYMBOL vmlinux 0xf4440537	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0xf44d7a67	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0xf453f832	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0xf45e6ab7	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf47818ca	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0xf4a5c213	avail_to_resrv_perfctr_nmi_bit
++EXPORT_SYMBOL vmlinux 0xf4a764f5	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0xf4b754fd	acpi_resources_are_enforced
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4c8b9e7	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0xf4cec2f2	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf4f5aa42	simple_fill_super
++EXPORT_SYMBOL vmlinux 0xf4fe736a	vme_dma_request
++EXPORT_SYMBOL vmlinux 0xf4ffbede	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0xf5138c3c	agp_generic_type_to_mask_type
++EXPORT_SYMBOL vmlinux 0xf51ae235	touch_nmi_watchdog
++EXPORT_SYMBOL vmlinux 0xf51bf88b	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xf536d22e	acpi_set_gpe_wake_mask
++EXPORT_SYMBOL vmlinux 0xf53ad062	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf54ae6f4	tso_count_descs
++EXPORT_SYMBOL vmlinux 0xf5689f27	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0xf572f2bb	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0xf57e9666	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0xf5971526	bioset_create
++EXPORT_SYMBOL vmlinux 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL vmlinux 0xf5b10e67	acpi_install_global_event_handler
++EXPORT_SYMBOL vmlinux 0xf5c1c485	dup_iter
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5deee22	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0xf5e82cfd	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf5ecc9fe	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0xf5fc2c0f	inet_frags_init
++EXPORT_SYMBOL vmlinux 0xf6130c12	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0xf61c3662	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0xf62fb602	keyring_clear
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf643c1f2	kill_fasync
++EXPORT_SYMBOL vmlinux 0xf65382a9	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf67a4f6c	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf693a145	irq_stat
++EXPORT_SYMBOL vmlinux 0xf699984e	kobject_put
++EXPORT_SYMBOL vmlinux 0xf6b52d2b	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6bc3df9	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf7013ac0	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0xf7208475	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0xf727fade	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0xf72e1811	param_set_ulong
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf764868a	udplite_table
++EXPORT_SYMBOL vmlinux 0xf7769e78	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0xf77913ff	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0xf77d324b	iget_failed
++EXPORT_SYMBOL vmlinux 0xf77eb393	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0xf78b290b	posix_lock_file
++EXPORT_SYMBOL vmlinux 0xf79e97cd	acpi_get_physical_device_location
++EXPORT_SYMBOL vmlinux 0xf7c9e6a1	registered_fb
++EXPORT_SYMBOL vmlinux 0xf7d66b20	address_space_init_once
++EXPORT_SYMBOL vmlinux 0xf7db0172	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0xf7e7a9fa	ps2_command
++EXPORT_SYMBOL vmlinux 0xf80cd7e4	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf812cff6	memscan
++EXPORT_SYMBOL vmlinux 0xf81c27f0	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82d33a4	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf8539e93	framebuffer_release
++EXPORT_SYMBOL vmlinux 0xf87f0412	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0xf88e0ee2	acpi_get_table_header
++EXPORT_SYMBOL vmlinux 0xf8908451	register_console
++EXPORT_SYMBOL vmlinux 0xf8b3b184	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0xf8d04f09	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0xf8d099f1	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0xf8d5108e	input_set_capability
++EXPORT_SYMBOL vmlinux 0xf8dd41d9	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0xf8de2313	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0xf8e652cc	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf8f777c7	param_set_bint
++EXPORT_SYMBOL vmlinux 0xf904e327	padata_free
++EXPORT_SYMBOL vmlinux 0xf908dce4	uart_register_driver
++EXPORT_SYMBOL vmlinux 0xf92c2ab6	fb_find_mode
++EXPORT_SYMBOL vmlinux 0xf93e99d4	init_buffer
++EXPORT_SYMBOL vmlinux 0xf941b411	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0xf944fb76	netlink_ack
++EXPORT_SYMBOL vmlinux 0xf97c49ec	nvm_register
++EXPORT_SYMBOL vmlinux 0xf99350f9	simple_setattr
++EXPORT_SYMBOL vmlinux 0xf996dbab	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0xf9a07397	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9c0b663	strlcat
++EXPORT_SYMBOL vmlinux 0xf9d53ebe	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xf9ea3a86	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0xf9f664ad	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0xfa03d4f6	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0xfa14cc3c	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0xfa1687b6	elevator_init
++EXPORT_SYMBOL vmlinux 0xfa1ca269	pci_select_bars
++EXPORT_SYMBOL vmlinux 0xfa3088a3	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0xfa454265	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa703090	page_put_link
++EXPORT_SYMBOL vmlinux 0xfa8625e7	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0xfa981d08	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0xfaab804a	scsi_print_command
++EXPORT_SYMBOL vmlinux 0xfab334e4	proto_register
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfaf029a7	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0xfaff1f47	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0xfb0443fb	acpi_get_parent
++EXPORT_SYMBOL vmlinux 0xfb099ada	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xfb2146d3	alloc_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0xfb28de91	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0xfb31d100	skb_queue_head
++EXPORT_SYMBOL vmlinux 0xfb337420	agp_backend_acquire
++EXPORT_SYMBOL vmlinux 0xfb507276	vga_switcheroo_client_fb_set
++EXPORT_SYMBOL vmlinux 0xfb578fc5	memset
++EXPORT_SYMBOL vmlinux 0xfb691d2f	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb6f05e3	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0xfb78d136	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0xfb80c7a0	acpi_walk_namespace
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfb95753a	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbcc20b3	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0xfbcec7f1	inet_accept
++EXPORT_SYMBOL vmlinux 0xfbd676c6	seq_printf
++EXPORT_SYMBOL vmlinux 0xfbf36c4f	flow_cache_init
++EXPORT_SYMBOL vmlinux 0xfbf43652	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc0fc8d8	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0xfc19b939	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc3d2b66	get_cached_acl
++EXPORT_SYMBOL vmlinux 0xfc709995	cpu_tlbstate
++EXPORT_SYMBOL vmlinux 0xfc734327	queued_read_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xfc872fd1	get_ibs_caps
++EXPORT_SYMBOL vmlinux 0xfc8793c3	devm_release_resource
++EXPORT_SYMBOL vmlinux 0xfc898f20	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0xfc8bf4a1	genphy_read_status
++EXPORT_SYMBOL vmlinux 0xfcac0d40	acpi_install_interface_handler
++EXPORT_SYMBOL vmlinux 0xfcb2a56f	pci_dev_put
++EXPORT_SYMBOL vmlinux 0xfcb926cd	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xfcbb620d	dquot_acquire
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcee0ae4	iget_locked
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfd0a3b95	param_get_int
++EXPORT_SYMBOL vmlinux 0xfd213cf9	__frontswap_test
++EXPORT_SYMBOL vmlinux 0xfd527b3b	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0xfd687efb	sock_i_uid
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfd9ca86d	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0xfda281e9	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0xfdb9b629	ioread32be
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfdc4dec9	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0xfded3019	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xfdfb792f	amd_iommu_pc_supported
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfdfd6c90	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe047ce6	acpi_enter_sleep_state
++EXPORT_SYMBOL vmlinux 0xfe113a52	rt6_lookup
++EXPORT_SYMBOL vmlinux 0xfe13c522	acpi_install_gpe_raw_handler
++EXPORT_SYMBOL vmlinux 0xfe17047b	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xfe19480f	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0xfe252fe3	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0xfe26fc7c	nr_node_ids
++EXPORT_SYMBOL vmlinux 0xfe44a191	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0xfe5d30e9	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe682de2	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0xfe7456a8	set_nlink
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe7ef0a8	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xfe82ef95	tty_throttle
++EXPORT_SYMBOL vmlinux 0xfe916dc6	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xfe9ebbbb	acpi_osi_is_win8
++EXPORT_SYMBOL vmlinux 0xfeacab87	check_disk_change
++EXPORT_SYMBOL vmlinux 0xfeb8e028	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0xfed3a8a6	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfee8a2c3	sock_no_connect
++EXPORT_SYMBOL vmlinux 0xfeebc7c4	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0xfef2c78f	idr_get_next
++EXPORT_SYMBOL vmlinux 0xff028791	seq_putc
++EXPORT_SYMBOL vmlinux 0xff14f09d	kaiser_flush_tlb_on_return_to_user
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff2c0e32	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xff2fc45d	redraw_screen
++EXPORT_SYMBOL vmlinux 0xff32d82d	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0xff361c07	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0xff4b78a3	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0xff4c55f5	dump_align
++EXPORT_SYMBOL vmlinux 0xff642b3d	sk_alloc
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff6b0bdf	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff81416f	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffa355d1	__register_nmi_handler
++EXPORT_SYMBOL vmlinux 0xffbf945e	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0xffc02836	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffde34ee	nd_region_to_nstype
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-x86_64 0x7060bf0a	crypto_aes_encrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-x86_64 0xe409b491	crypto_aes_decrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x13a65ecf	camellia_ecb_enc_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x17bf48dc	camellia_xts_dec_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x1a08ded1	camellia_xts_enc
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x47129015	camellia_xts_enc_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x7d54edc2	camellia_cbc_dec_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x7e87ef55	camellia_ecb_dec_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x8f185793	camellia_xts_dec
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x9e8086dc	camellia_ctr_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x11b3de9f	xts_camellia_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x16061d06	__camellia_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x1636abdf	__camellia_enc_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x1da0e256	camellia_crypt_ctr
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x31bbe42b	camellia_crypt_ctr_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x4193fc2a	lrw_camellia_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x50dc55b6	__camellia_enc_blk_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x8b719630	lrw_camellia_exit_tfm
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x930f687f	camellia_decrypt_cbc_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0xa41a5ad3	camellia_dec_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0xf4521fda	camellia_dec_blk_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x4713f3be	glue_cbc_encrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x8f02ac4d	glue_xts_crypt_128bit_one
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xac7f9f95	glue_xts_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xc9c41280	glue_cbc_decrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xdbbef7ef	glue_ctr_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xf8535337	glue_ecb_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x016a957f	serpent_xts_enc_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x0c5a8af6	serpent_xts_dec_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x0ff3c26d	serpent_xts_dec
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x606a8162	serpent_cbc_dec_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x79ff0b7a	serpent_ecb_dec_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x94404ac7	xts_serpent_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x9ae34b2f	serpent_xts_enc
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x9e018632	__serpent_crypt_ctr
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x9f99663c	serpent_ctr_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0xa84ea33d	serpent_ecb_enc_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0xb113c3b7	lrw_serpent_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0xe83e9650	lrw_serpent_exit_tfm
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64 0x19dc7881	twofish_dec_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64 0x5e752773	twofish_enc_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x1fd77fb1	twofish_dec_blk_3way
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x5eb02726	xts_twofish_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x61694b97	twofish_dec_blk_cbc_3way
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x7be3ae56	lrw_twofish_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x8d75ab44	twofish_enc_blk_ctr
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x8e856922	twofish_enc_blk_ctr_3way
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0xc1ce98b1	lrw_twofish_exit_tfm
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0xf2e80e9c	__twofish_enc_blk_3way
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x00aaf935	kvm_disable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x01ccd216	__tracepoint_kvm_fast_mmio
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x028a1446	kvm_apic_write_nodecode
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x039b1873	kvm_set_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x04a8228d	gfn_to_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0557d95b	gfn_to_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x05e09dbf	kvm_inject_pending_timer_irqs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x070f9719	__tracepoint_kvm_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x080be3ad	__tracepoint_kvm_invlpga
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0901977e	kvm_vcpu_gfn_to_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0995bf4b	kvm_scale_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x09a11794	reprogram_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0d4adf8b	__tracepoint_kvm_nested_intr_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x134261a3	kvm_vcpu_block
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x15b67f7f	kvm_lmsw
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x17c114b8	kvm_write_guest_virt_system
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x17d5fb51	kvm_valid_efer
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x197a42f3	kvm_cpu_has_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1accbbcb	kvm_write_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1c867ac7	kvm_clear_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x21564cf4	__tracepoint_kvm_nested_intercepts
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x21ee1aa2	kvm_before_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2282c55a	kvm_get_linear_rip
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x23659933	kvm_vcpu_mark_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x23cac55e	kvm_inject_realmode_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x25285bc4	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x25d1ff8a	handle_mmio_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2a5a1eb5	kvm_is_linear_rip
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2c78b8d4	__gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2cf4b99f	kvm_init_shadow_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2fbed28c	kvm_emulate_hypercall
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x30b56c8e	kvm_mmu_sync_roots
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x316386bd	__x86_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x317f9e6b	kvm_enable_efer_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x37cf2d74	kvm_arch_register_noncoherent_dma
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x389f8e8a	reprogram_gp_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x39825164	kvm_task_switch
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3a4f97e8	vcpu_put
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3bafe40e	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3bd2d89e	kvm_arch_has_assigned_device
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3ca1b63e	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3e1f72e0	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3ea768bb	kvm_requeue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x40b5a629	kvm_get_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4161f4c0	kvm_get_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x44046cb1	__tracepoint_kvm_nested_vmexit_inject
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4440553a	cpuid_query_maxphyaddr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4674f5ae	kvm_require_cpl
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x482dbfd4	vcpu_load
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x485b8379	kvm_require_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4a741afc	kvm_find_cpuid_entry
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4bc4d3d0	kvm_get_cr8
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4bffc77d	kvm_apic_update_irr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4c2ab617	kvm_write_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4d1f962e	kvm_vcpu_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x502f56b2	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x58096cf0	kvm_emulate_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x585b31fa	kvm_read_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5abdf12c	kvm_arch_start_assignment
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5c2a607a	kvm_read_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5c30e030	mark_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6174cf95	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x64020e10	kvm_set_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x651d981e	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x661640ea	kvm_release_page_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x67a50ebd	kvm_x86_ops
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x67bfbd68	kvm_requeue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6a87dcad	kvm_vcpu_reload_apic_access_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6ab94a62	kvm_vcpu_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6d6da312	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6dad080d	reset_shadow_zero_bits_mask
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6f75e3ea	__tracepoint_kvm_write_tsc_offset
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x709cd8cb	kvm_spurious_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x709ff227	kvm_mmu_unprotect_page_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x72829518	kvm_get_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7332d5e1	gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x73ae496a	__tracepoint_kvm_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x75358eb3	kvm_intr_is_single_vcpu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x77de51ab	kvm_get_cs_db_l_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x78062d5b	kvm_mmu_slot_largepage_remove_write_access
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x78779d8e	kvm_init_shadow_ept_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7a699f55	kvm_set_cr4
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7b4e5588	kvm_queue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7cf16e7c	kvm_inject_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7eebee9f	kvm_vcpu_is_reset_bsp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7f5fce70	kvm_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7ff1ca84	__tracepoint_kvm_nested_vmrun
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x804cff7c	kvm_emulate_halt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x80b3738b	kvm_arch_unregister_noncoherent_dma
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x80d6eec1	kvm_emulate_wbinvd
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x813fccd0	load_pdptrs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x81d0bcc4	kvm_mtrr_get_guest_memory_type
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x82eb04b6	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x831327da	kvm_max_guest_tsc_khz
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x83bb3c3f	kvm_set_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x85392453	kvm_get_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x88cc9e65	kvm_mmu_slot_leaf_clear_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x89eb4b84	kvm_vcpu_halt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8a918e99	kvm_write_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8bfd5226	x86_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8ce4f3ab	kvm_enable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9092d606	kvm_set_msi_irq
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x916eea89	kvm_queue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x93ff5972	kvm_set_cr0
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x96dbe382	kvm_mpx_supported
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x993f3114	kvm_lapic_set_eoi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9a216313	kvm_define_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9a63df7d	kvm_mmu_load
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9ba3d37d	kvm_set_cr8
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9fc0946b	kvm_arch_end_assignment
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa0ec3a0a	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa4d57013	__tracepoint_kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa894cd6d	kvm_vcpu_gfn_to_hva
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaa878442	kvm_set_xcr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xab8dca78	kvm_set_cr3
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xac867e14	kvm_after_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xacb4f967	kvm_flush_remote_tlbs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xacf7f97c	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xad37d6ef	kvm_vcpu_read_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xad94a24f	kvm_debugfs_dir
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaefb9950	kvm_apic_set_eoi_accelerated
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaff2687e	kvm_mmu_clear_dirty_pt_masked
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb0b4c683	kvm_vcpu_read_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb134d13b	kvm_io_bus_write
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb1cc6be5	__tracepoint_kvm_inj_virq
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb326aecf	kvm_read_guest_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb48766cd	kvm_mmu_reset_context
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb50b4a37	kvm_mmu_slot_set_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb83c7106	kvm_get_dirty_log_protect
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb84456d6	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb89c1dfb	kvm_vcpu_write_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xba9ed435	kvm_mmu_set_mmio_spte_mask
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbc8fadff	kvm_vcpu_write_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbce77f4c	x86_emulate_instruction
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbf0cd20f	kvm_mmu_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc1adc2cb	__tracepoint_kvm_skinit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc5181423	kvm_set_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc56d75ce	__kvm_apic_update_irr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc599bc18	kvm_max_tsc_scaling_ratio
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xca2536fa	kvm_rdpmc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcb687091	kvm_mmu_unload
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcf0b30d5	__tracepoint_kvm_pml_full
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0459e67	kvm_has_tsc_control
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0b2727a	kvm_mmu_set_mask_ptes
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd15e9bb2	kvm_mmu_unprotect_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd53676b7	kvm_mmu_invlpg
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd615a5cc	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd68f45ac	kvm_cpu_get_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd6acba0b	kvm_set_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd70e4b56	kvm_set_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd93bbd46	gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd9f8eb08	kvm_get_dirty_log
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdabec47d	kvm_complete_insn_gp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdb0bc922	kvm_get_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdc76a6ae	reprogram_fixed_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdc79da30	kvm_vcpu_gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe00c98ed	kvm_inject_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe17f7b75	kvm_mtrr_valid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe35229af	kvm_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xea678286	kvm_read_l1_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xebcd9f61	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xed2a16a6	kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xed9da7d0	kvm_get_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xee470717	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xef5ea24d	kvm_read_guest_page_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf2312a76	__tracepoint_kvm_ple_window
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf29fee64	gfn_to_hva
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf2f286c4	kvm_tsc_scaling_ratio_frac_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf41e94f5	__tracepoint_kvm_pi_irte_update
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf4f28727	kvm_put_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf52c26a0	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf6e185e5	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf8f4642c	__tracepoint_kvm_nested_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfb459fae	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfbd95c91	__tracepoint_kvm_cr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfc4ac6a9	kvm_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfd406fba	kvm_vcpu_gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfd7aff93	kvm_fast_pio_out
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfdaa1007	kvm_arch_has_noncoherent_dma
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x28717510	ablk_decrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x298031bd	ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x35fc584a	ablk_exit
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x4c51aada	ablk_init
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x66e7c146	__ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x72d037ff	ablk_init_common
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xee862376	ablk_set_key
++EXPORT_SYMBOL_GPL crypto/af_alg 0x107ed95b	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0x11badcb8	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0x1f22d91e	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x250c48b8	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x3884b348	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0x494d193c	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x5bb5d113	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x838d9bb5	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x876b84cf	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x9c4cd872	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0xf4569a8b	af_alg_release
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x64aaace4	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0xe00f69d6	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0xee8f8eaa	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x616e20eb	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0xe56cc3b2	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x381a0467	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xad58fd60	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xc2ff8c1e	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xeb6864cb	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x312d0148	async_xor
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x5ba6edaf	async_xor_val
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x4cfbb5c8	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x9d24bf2b	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0xf1a00811	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x0e846088	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x9008f9c8	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/cryptd 0x04b11dd3	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x20a66df6	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x21340466	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x259190e5	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x69c2138e	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x83170739	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x86ccce46	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x88fb21ba	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xe8e3551a	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0xfae5bf31	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0x41a3a4e4	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x0824b26f	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x0a367202	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x2e019077	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x57c6475c	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x826e9034	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x8347667c	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xa94128f7	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xc07d9c62	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xeed645f6	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x308fb1c5	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x45a8b595	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x4e0fe220	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xa4572568	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x0b430de0	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x5a3b412f	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0x8bd13dba	xts_crypt
++EXPORT_SYMBOL_GPL drivers/acpi/nfit 0x2c746d04	acpi_nfit_init
++EXPORT_SYMBOL_GPL drivers/acpi/nfit 0xecb7411c	acpi_nfit_attribute_groups
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x1c8984c7	acpi_smbus_unregister_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x87bd07bd	acpi_smbus_register_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xb9a141b0	acpi_smbus_read
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xe1372311	acpi_smbus_write
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x06d55595	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x160bd0ea	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x184c21be	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x2fe29d50	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x3fc9fd6a	ahci_host_activate
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x425a6b73	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x456c065b	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x6c999086	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x75ed9a02	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x7a945dfb	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x7b7f6d4b	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x7c56599c	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x7f902791	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x914fd9eb	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x92c3b220	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xbeba4937	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc386ae18	ahci_error_handler
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc47b9b91	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xcbeffaef	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xd32eb28c	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xd4cfd2c3	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe6eca1f4	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xee854aea	ahci_qc_issue
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x2470d4d3	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x2eae57b5	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x3cd63154	ahci_platform_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x694b4eee	ahci_platform_resume_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x6db3a10f	ahci_platform_suspend_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x780e5a91	ahci_platform_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x7ce69b93	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x8616da3a	ahci_platform_init_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x9e52f30e	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xb12df78a	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xb92a43af	ahci_platform_suspend
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xc2739369	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xd20b9055	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0xe5e12fbf	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x02ff9464	cfag12864b_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x0ecb2e5d	cfag12864b_disable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x305dc3c6	cfag12864b_isenabled
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x3389f926	cfag12864b_enable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x9522a342	cfag12864b_getrate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0xc48e9d95	cfag12864b_buffer
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x08ab6ae4	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x7c05aad1	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xebf7749e	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xee5fc43b	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1bebf384	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3b9efd3b	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3ebb1788	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x50b71386	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x53ade01b	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x55dd7114	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x60901028	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x69cdad6e	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6c2a2c11	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6f460f14	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x7d628a0f	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x86854d44	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x96895a4d	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xaa3c183a	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb678d582	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb8a3f5f4	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc09e0b23	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc95e194c	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd52bad0d	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd765127b	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd8fdd71e	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe70fde65	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe83fe414	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xeebd7b88	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x4f1bb881	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x6852c494	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x6f4cbdaa	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x98011250	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xa5d366d5	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xabb9c070	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x1d89270f	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x42786588	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x438c636b	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x4bc2cbbc	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x5426d48d	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x5a01063e	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x5be90b1e	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x5cd27a1d	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x8acd03b4	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x933f15a6	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xd4ad3f10	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xe2dd4d39	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x08a0984f	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x1b618187	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x22b803e7	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x2fb4672d	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x610c6360	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x6c8fde42	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x95942b82	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xaa430da8	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xc3c9887b	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xdbe405a5	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xdcf53921	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x6650cf42	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0xa0f406db	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0xaddebddd	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0x49966d61	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/cpufreq/speedstep-lib 0x1b1f2bda	speedstep_get_freqs
++EXPORT_SYMBOL_GPL drivers/cpufreq/speedstep-lib 0x2b67f096	speedstep_get_frequency
++EXPORT_SYMBOL_GPL drivers/cpufreq/speedstep-lib 0xd7ab2c0c	speedstep_detect_processor
++EXPORT_SYMBOL_GPL drivers/crypto/ccp/ccp 0x04773b60	ccp_present
++EXPORT_SYMBOL_GPL drivers/crypto/ccp/ccp 0x7b9cea7b	ccp_enqueue_cmd
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x082008f4	adf_dev_put
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x11b410e1	adf_disable_pf2vf_interrupts
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x1af1ae00	adf_cfg_dev_remove
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x1dd74122	adf_dev_started
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x1e3fd243	adf_dev_in_use
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x25ce9c47	adf_service_unregister
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x2b687087	adf_dev_get
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x404c0ba8	adf_devmgr_rm_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x4c12ea06	adf_response_handler
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x5461f6d5	adf_devmgr_pci_to_accel_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x55d7a3cc	adf_enable_pf2vf_interrupts
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x5d784fa9	adf_dev_shutdown
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x6d18be43	adf_service_register
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x75f0b0bc	adf_init_etr_data
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x80257519	adf_iov_putmsg
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x8df26525	adf_disable_sriov
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x942a8f85	adf_cleanup_etr_data
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x99a161f9	adf_init_admin_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x9c376607	adf_sriov_configure
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x9dcdc0fb	adf_devmgr_add_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x9e12c4ae	adf_devmgr_update_class_index
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xa7dcd479	adf_disable_aer
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xab89ffb0	adf_dev_stop
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xac6fdf4c	adf_devmgr_in_reset
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xae996d7b	adf_send_admin_init
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xb170746f	adf_cfg_add_key_value_param
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc7573772	adf_init_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc7e65655	adf_cfg_section_add
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xcc3b167a	adf_clean_vf_map
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd08a790b	adf_exit_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd137ec96	adf_enable_vf2pf_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd1bb420c	adf_update_ring_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd6118923	adf_exit_admin_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd9abe560	adf_dev_init
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xe0ce4081	adf_dev_start
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xe85c3057	adf_cfg_dev_add
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xe909e49f	adf_enable_aer
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xedafb42b	adf_disable_vf2pf_interrupts
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x01a33ab9	dca_unregister_notify
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x31a2c8df	dca_get_tag
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x35162369	free_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x79170d39	dca_add_requester
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x7b4a0492	dca_remove_requester
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xa84dc501	register_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xac34ecec	dca_register_notify
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xacf920f1	alloc_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xbe2d69ee	unregister_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xe120d815	dca3_get_tag
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x235a7d08	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x550722b8	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xb3b9db29	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xbd9badff	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xdfcb8c20	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x54689c9a	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x71d23ee7	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x841dc3fa	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x0efd4220	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x39bb98a2	vchan_find_desc
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x5969f55f	vchan_init
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xc3df7dd0	vchan_tx_submit
++EXPORT_SYMBOL_GPL drivers/edac/amd64_edac_mod 0x1eed5db6	amd64_get_dram_hole_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0878e998	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x158a2e34	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x17d9fba7	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x1b7257d6	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x245e354b	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x24e1d881	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3cbccc6b	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x518df5af	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x53978c4c	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x55bdffe2	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x65a49b13	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6ff11f88	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x769ea863	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7b74bad3	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x827c196e	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x85d1af8b	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x894d5235	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa2e4b958	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa59ba788	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd138d1e3	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd1ee6d9c	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xefe545ce	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xfc2ee4cc	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x14878009	amd_report_gart_errors
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x1d34e996	pp_msgs
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x81d75507	amd_register_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0xb30b7e56	amd_decode_mce
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0xd3cc2686	amd_unregister_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x07262998	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x2067fe47	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x299cad9a	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x2e3b3a34	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x48a5d1b0	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x6a85c0de	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x17cc5ed3	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x2e16ad3f	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x7ec7b75d	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0xe25d224d	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x075fb2c4	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x29ea46d2	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xf755fa77	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x05876c69	i915_gpu_busy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x08a7896d	i915_gpu_raise
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x402468e9	i915_gpu_lower
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x500858b9	i915_read_mch_val
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0xe7237b0b	i915_gpu_turbo_disable
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x0a1fb27a	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x412a7e72	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x4ff2010c	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0288f239	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x04075be3	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x04d0561a	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0a544f15	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0d5cde9f	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0faa0f96	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x1c1c5494	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x29c5918a	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x333a2af6	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3af87a50	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4528a377	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x46a2a036	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4cc0328e	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4f4dd487	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x52ef4245	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5707168f	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5dfe3733	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6c7cf827	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6e39ae7f	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x814ca588	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x85ada380	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x8bfc216f	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x8dc12f25	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x979aa791	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbc9c1db7	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc6119ef9	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc887586e	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xce3430b0	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd0f4b5c5	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd66abad2	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd8f41d0c	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd9bee719	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe310c53d	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe38e1201	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf08c9a22	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf76998ce	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x427ab222	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x43f2acb7	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x47ea76d1	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x4a32211c	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x6f236dfb	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xe5e6e7b3	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xecc441d0	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x2a34bf66	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x36fad31e	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x58bdc966	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x60bf40aa	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x86723df4	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x9bef9206	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xc92298b4	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xed1e0edf	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xf87f1312	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x873983d3	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x425a24b6	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x4e485989	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x58638d68	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x680ffc29	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x72f29900	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x86f11f42	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x97d93f94	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x9cf5e468	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xbccc1c37	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc423180d	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xd5a8148b	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xd5d1124a	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xdf4375d1	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe0c6a03e	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xeb47e9c1	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xec6d772f	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xfcf8fee9	hsi_event
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x0a00a372	vmbus_establish_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x0e067a67	vmbus_allocate_mmio
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x15903638	vmbus_hvsock_device_unregister
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x1a25cd8a	hv_do_hypercall
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x25a0a3d2	vmbus_cpu_number_to_vp_number
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x271cc563	vmbus_set_event
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x2c2dcf02	vmbus_setevent
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x2e6b9b0c	vmbus_get_outgoing_channel
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x2eee8cee	vmbus_close
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x358fafa5	vmbus_prep_negotiate_resp
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x38382e06	vmbus_open
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x46a417ca	vmbus_proto_version
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x506536b6	vmbus_set_chn_rescind_callback
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x7df4c9b7	vmbus_sendpacket_mpb_desc
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x86ff5fa6	hyperv_cs
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x9ce36713	vmbus_sendpacket_pagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xa7adb86e	vmbus_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xa8a80a2c	vmbus_are_subchannels_present
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xc36f3c1c	vmbus_set_sc_create_callback
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xc8c24c80	vmbus_teardown_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xd447e5e7	__vmbus_driver_register
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xdaa07c15	vmbus_sendpacket_pagebuffer_ctl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xdb2f6047	vmbus_free_mmio
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xde52b16d	vmbus_recvpacket_raw
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xe1831da6	vmbus_sendpacket_multipagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xeadb5fcc	vmbus_send_tl_connect_request
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x2eda5a44	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xe893492f	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xfc7c9086	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x0b56a526	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x0d5bb7b1	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x32a9852f	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x50ec7c67	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x7d3476ab	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x8ff06d22	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xa740ff18	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xbafab530	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xc8c51b8f	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xcd3460da	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xcdb981ce	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xd2172080	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xdb47ee98	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xed82ae3b	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf6dcf9a2	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x2692aa0f	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x450820eb	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x5dd17239	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x8a13d3d7	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xab4e31f9	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xd76f9144	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xf9a38f84	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x01c13453	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x036437c5	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x544b2ac8	stm_source_write
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xcdb39a93	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xdf94b484	stm_register_device
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x1d486ea0	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x7220967b	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x7a01480c	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x9cf401a1	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xb38ba2f2	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-nforce2 0xcf542c6b	nforce2_smbus
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xad0678dc	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xd6af55ac	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x79d852f7	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x7bd7138c	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x2376cdab	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xe5f7eb35	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xf6ab15f1	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x14f97591	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x18308dee	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x41989dc3	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x8878185d	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x896a84a5	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x9fd9f8dc	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xb7f44b1f	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xcc3c3b0a	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xd616aa07	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xe10a3589	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x8ff0bd86	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0xdee6236f	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xea5326d6	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xebb48e72	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x7f148bb2	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xb20c930a	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xfd5b6730	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x037c2512	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x06d211bd	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x35a138ea	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x36b765b9	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x40c8b040	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x5b54f7bd	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x5ece5916	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xa4dff0ee	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xa627d221	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xc3adaf4f	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xcf179b0b	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xe58cee3d	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0cb1288d	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0d119a8c	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0fc02137	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x124f1bb3	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x14b4a442	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2481d1bc	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2566fc9c	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4aff53ae	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5f17f51c	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x64c7ab19	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x67338971	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x67ade851	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6ca3ca80	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x75de49fb	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7eabe4ca	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7ed3fb72	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x879b8785	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x918ea73a	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xab122cfc	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc2439784	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc4406bcd	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xcb08485d	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xcdd0c0cd	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd9deefa5	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe25a5810	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe738306d	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe765f105	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xea5ccb8b	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xeac8cfc0	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xec443136	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf79ef2f6	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0xc7c84dc2	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x6d486197	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x4785dd44	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x92114833	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xd7c15e4f	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x3b2bbf55	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x90e8f8e3	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xe743ce66	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x66504856	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x727eed57	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x26e43182	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x608b552f	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x89a2631a	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xb3ea7a9f	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x2251093a	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x25ae1cc8	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x38100192	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x459dbf3f	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x8cf6da5d	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x9111cc4e	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x9f446c61	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xbff8dbe7	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xca22b82c	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xd08d3cd0	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xf4ba010c	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xf646b2f4	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x04f6a5ae	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x1480b3ad	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x332ab3f1	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x4cbcddd4	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x53d3f353	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x5407221b	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x7e393ab7	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xc00dbbb8	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xc5389e3b	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x046df3aa	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x081d72f1	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x11ee2cf6	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x1507dc3d	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x2161fca3	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x37d6043d	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x3a3b0709	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x410fd5ec	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x4f87ccf8	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x91863eaf	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x992c39ff	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa3151853	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xb2a12929	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xb4c12ed9	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xb9a8f70c	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xf237d15b	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xf6f0e465	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xf8c7e8b5	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/leds/dell-led 0x86fd1ffb	dell_app_wmi_led_set
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x1aa88520	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x4e6a8222	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x588826c8	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x6b4e6e07	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xbeba5234	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xeccecb16	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x06c22db4	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x080aae89	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x10ff5447	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x25d83986	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x477a799b	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x4d13f919	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x4fdab16d	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x8f044730	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xd8c911d5	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xe8ab290c	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xf6197fb5	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x0cc27b4d	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x23004ff2	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x41a9214e	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x4949aa16	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x49df63aa	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x4fb1a66f	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x50d155ba	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x5ff431ab	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x69e8f845	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x81c2063a	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8bf52ac0	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xab8f59f8	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xbd9a5a0f	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xee3cc4d2	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x021811cf	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x0f0677b8	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x10e6a889	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1154f7a1	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x15aa8e40	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x174c2a29	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2205bcf9	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3fc7cb7f	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x469f38de	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4ba51ecf	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5b2a89c7	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5d950f2a	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5e21030c	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5ed04550	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6eef9654	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x74ab7b0f	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x84efb763	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8fe32879	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x91f02667	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x93f7fc02	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa1de5277	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa81bf581	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb7d964de	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbbace2cd	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc6673631	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc8a2f711	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe3de2ba2	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe902838d	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xec919105	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xeea27f46	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfad1ec73	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x23392fd6	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2e7a658e	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x3058a91b	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6d58c0ee	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x83bb3b50	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x94ecdd79	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xc5ac0262	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xebf572e4	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xfc6de507	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6aba7f5e	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9310ba06	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9c256008	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa1d2413a	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa448e19f	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xafbda3f3	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xb696c482	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xcbb1bae2	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x41520f32	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x61b0569e	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x862c9a61	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x95efe834	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x968b6681	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xbc652342	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xe2d6c698	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x2caa6d09	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0xa42b202d	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x39ad2dff	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4430764e	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x45ab972a	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x6b34e71c	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x81bfdb91	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa68e1f06	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xb5a19cd1	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbf1ecaf9	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc1d3e9bd	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfad9d53a	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfc62ef4e	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x17c36f29	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42dbdfc3	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x49b35849	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x55b4bd4d	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x827a42f4	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x956b291c	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9f624559	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xafeda29f	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd29923fb	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf375d009	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf5455120	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x4ab74be7	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x528b6111	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x5a019546	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x8db98e39	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xa2abde4a	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xb12d72e6	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xb2707283	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xb2bfdb70	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xb5634556	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xd356c6a9	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x1a2d76c2	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x3b03c750	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x533f7981	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x65767192	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xa94d7a17	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xbf151982	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xf610a3fa	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x0d910550	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21d0381c	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x2c7348c8	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x3443c1af	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x42c90fec	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x4f9b1bdd	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x76fd2c87	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7e4e8107	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x99a81ab3	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xa0702bce	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xab7543a9	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xb527e44b	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbe2a83ac	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc1628294	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc1db84f0	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc7b06124	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xec275c5b	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xf3c3f73f	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0x2ecdaca6	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0xc77202c7	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0xd0fd9da0	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x098f63b2	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x14e11e91	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x3090cb01	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0x39ad4e66	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x40cd1029	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x4694c8b0	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/media 0x61c7fe70	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x63259c79	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x69de546c	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/media 0x6aa9bbd9	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x7283d986	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x90268671	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x91c7994b	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0x98344344	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0xa92e7160	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/media 0xa9ee0002	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0xb54398c9	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0xccdc9532	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0x95385fb3	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x01b595b2	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x14f640b1	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x18f0bcf9	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x27044ef7	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x302a12e0	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x31524079	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x35e70dbe	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x4b1a868e	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x4b478bd5	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x50465532	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x51f3a609	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x558b4a6c	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x6c7fa556	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x8e95d936	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x96d521ef	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb363abc7	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xbaf64248	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xe7ace5f3	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xeb3481ba	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x10739e52	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x2ac95030	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x2d603b4d	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x2d69beb2	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x344163e7	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x48ae7cb6	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x559d79a1	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x6439e62f	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x68c168d8	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x7aac554b	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x89384fe1	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xbebcd293	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xca44b81e	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xcbc95a15	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xdb7955b2	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xdd87c7eb	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xf6df29bb	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xfc8191df	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xfd2188d6	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x0cec1ce7	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x4712436c	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x5aaa7020	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x6372226a	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xe1c6d440	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xe9018759	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xfe51bfb2	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x10831f61	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x7002f9ed	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x054267fb	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x29a91501	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x37c163e3	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x4ba81ef6	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x57b17815	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x5bd7e58f	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x6a3b1292	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x76c71f94	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x7f95af84	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x8ec2e810	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x990cf3af	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa9e2786a	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb581dd0e	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb99c1e67	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc28901b1	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc551f35d	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xd57b73db	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xd81753d6	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xf57ba059	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0x18fbee26	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0x63c625ef	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0x25d74a7b	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0x5a5d9a5d	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0x3b605557	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0xc8370a85	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x09dd2f9f	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xba8c6ddf	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x0574611c	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x46505945	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0xc9a6a4ae	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x20280ef0	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xcda58097	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0x3487ec17	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x03330c05	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x0756b862	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x1a12151f	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x1a5aa3e9	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x43ee82b1	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x5ebe9148	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6cb15910	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x7686ae15	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x82ef0ee1	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8844de9d	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8dabe797	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x909e7f1e	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x9299754a	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x9812e29c	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa7440b7d	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xbfbad7b2	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xeaaad561	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf3cd3c66	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf58e2977	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf6f6787d	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0xe053776f	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x2aa79c97	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x0463ef1c	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x112314c3	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x14e0e3ca	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1843a959	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x261e2c5d	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2cac8469	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x34394f50	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7aa2828d	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x8b64a2aa	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x910c5836	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xc60893e9	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcf18e9e3	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xd342f80f	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xd3af28bd	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xdc0af122	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xf69dc7a2	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xf6ae59c1	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xfc3775c5	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x314652bf	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x439fd1e9	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x501449af	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xbad5b8b8	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x030c74f9	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x063d4f98	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x7afab65e	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x86468a30	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xdd0c4e05	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xe19c00b4	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x63839a44	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x69acd1ca	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x0134e2bb	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x06ceb837	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x08844a75	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x08d5c25a	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x123fda9f	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x187ce5c1	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x18fdfd78	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x2d92539c	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x30b98434	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6dec5a01	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x83ea3106	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x85869d04	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x8c07936b	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x95175a06	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x97344ff6	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9d5d7cf8	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xa582f6d2	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xae5face9	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xae98eac3	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc16b524e	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xcb31f103	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd08b5116	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd4a8019a	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xda79aa09	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe21ed450	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe2b92017	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xfba47804	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x0a656b4c	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x126706ad	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x26184a9f	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x2e7078a6	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x50b246fb	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x54662de5	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x5725550b	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x732a0e15	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x75346033	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x76b7688d	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8f7248ba	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x9a61ef2a	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x9a695ab7	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x9e02b2f6	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa783e941	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb2ddd80e	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb898f650	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xbbf328f0	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xc6c6301c	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xca7aeae3	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xd357dacf	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf3accdd6	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfa2b5f55	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfb29ab08	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x396b9e79	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x553a86d0	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x6df52355	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x8e8873f9	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xbe568849	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x947d7fd2	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x9f85dfe7	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xa294636c	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1558bbe8	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1e6e440a	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x20a80b03	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x30718d66	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x3758ec19	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x4ac5979c	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x60ae6723	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x6dfe67ba	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7dd7f442	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7def558f	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xadceacbf	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xae4d092c	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xbd6f7033	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xc74c6e91	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xc974432d	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xdc97f834	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe2348784	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xefb2e3db	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x5b1e31cc	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x9fc12a7b	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x6af50478	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xe940f50c	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x66310cf3	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x01d3267c	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x02cf47de	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x06f7ccc1	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x07c7e5aa	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0985aa65	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1d6a20ef	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x2d2735bf	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x386b11f3	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3a871e04	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3e0bcb11	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3f13dd9d	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x413ac03f	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x42a684d7	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x47701cd8	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x48d410d9	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x4ab7f2cb	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5d20a346	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x63944535	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x6cc3e18b	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x809fd0d8	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x86eca4df	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8ebce0ad	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8ff71228	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x906d2fd6	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x96183525	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa1116f73	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xd8919ec4	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xdae76327	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xdf9378c3	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xe0a6b98a	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf216a23b	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xfbd35e36	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x27697637	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0219c4f8	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x08e330f6	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x114a1f5a	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x133adfc4	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x184964ca	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1cace362	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1ef3a428	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x213938f5	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x23b418e5	v4l2_compat_ioctl32
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2ab9d732	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2e6934ab	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2f13bc64	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4e73fa8d	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4fa5de21	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5833a575	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x624f7e10	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x71ef9d72	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x74a017c5	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7bfda7d4	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8443d1f2	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8c70c76c	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8cdfbe43	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x928659d0	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x93a798cb	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9c3e8239	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa55c185e	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xaca2544a	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc0867b17	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc111835c	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc6429d8b	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd76e439f	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xdbc8c6f2	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe3f75a04	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe943cae7	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xea5fccdf	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf377311f	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf664d6c8	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x00829869	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xac5c68f6	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xfa93fa35	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x0e7022f7	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x2991b634	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x3fdb7e8d	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x6ed17808	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x7bc1a24b	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x9e156570	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xb41d5054	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x63752762	intel_lpss_probe
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x75c527ee	intel_lpss_remove
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x8fde8250	intel_lpss_prepare
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0xbda6b4d9	intel_lpss_resume
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0xfea1041c	intel_lpss_suspend
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x05801b76	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x0c4671a2	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x220e8d0b	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x5b613820	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x69fd8105	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xaf1bb1d0	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xafceee75	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xe315ec08	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x661ac0a5	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xe054f4b3	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xfaa4cc42	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x0fc2a62b	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x36db83a8	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x507c55dc	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xc0c6d550	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xd6dcd9cb	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xe449ab26	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xe9af674a	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x2759968d	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xaa358beb	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xf3ebfed1	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x130264bb	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x1bd2724b	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x2c2ddd1b	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x4967cc03	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x5b68396b	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x877f9505	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x070b51ad	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x0d367d6c	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x0d67a9e2	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x226536da	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x26553858	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x2d2b3460	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x4060a082	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x45318d55	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xad154836	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xba8a50d3	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xe5b0b1e9	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x7bac75ac	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xf9f6dd37	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x5ad20d95	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x744fe2aa	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xd0124bc9	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xf410d2f3	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xfb6b8e87	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0986c9aa	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3412f8ed	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3d5dbdbe	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x4247c805	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x49add85f	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x4b8c850e	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x546ff0eb	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x57e48eef	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x770eca89	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x83afb5ee	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x8685d628	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x8827ce4e	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x8b257d2f	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9084fd67	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x92209ada	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa3bb056b	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa3ccd138	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa3dadfe5	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb1738579	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb5549146	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xc266ab5c	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd26c864a	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xde5c0e69	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xec14b050	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x014b0671	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x31376bcf	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x58d5875c	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x5f3a47a3	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x6bae0d0b	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x886f4ae9	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x9473baa6	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x973884b9	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x9b66e35b	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xbe26ce13	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xcc4dcc47	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xdb0dd6d4	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xe94c05f5	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0452892a	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0b65a1b2	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x11d0efe3	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1db0c67f	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2bed2bea	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2c246a19	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2c2e2737	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x31e0c23c	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x34221688	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5159375e	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5ecad30f	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x68bf4e20	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6950af85	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x69d44561	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6e2ca62b	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7de99000	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x834917e2	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x91cbae16	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9be95c10	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa26212d9	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa7607cfc	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa9ca76b0	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb6c97fc9	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbc06cd06	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc5125ced	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc8e81876	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc99a2c09	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xcacd2636	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd4955bd1	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd66e2f94	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xde5c1d3b	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe10b3cbe	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf89833e1	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf97019ca	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x3cf7d6e2	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x41902cb6	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x5dc41362	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x63eeb20f	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xd59663ed	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x844ca77a	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x8b23586c	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x8eca24ad	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xbd333b0a	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x4786d6aa	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x74da58a1	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xa203a81b	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xd1579bad	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0x7ba34674	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x363d50c2	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x8d25014d	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xcae9c39b	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xd58aa980	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x127e4ce3	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x1d61be50	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x22dfe806	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x2ccfea35	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x1399a1cc	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x35285cac	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x64037f31	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x77d9c0bb	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xc5fd824e	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xc93eeef1	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xf1fd42ba	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xfab2ed4c	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x21e3b010	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x364c0362	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x4347d3d6	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x619f3230	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x68b44531	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x75dc1ff0	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xd472a5dc	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xffef200a	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x09c92393	mei_cldev_uuid
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x0d456971	mei_cldev_get_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x1422f780	mei_cldev_register_event_cb
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x1acda26d	mei_device_init
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x2074ecdb	mei_cldev_enabled
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3c0b2219	mei_hbm_pg
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3d42f91b	mei_hbm_pg_resume
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x43094540	mei_cldev_send
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x45e8737d	__mei_cldev_driver_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x6005070a	mei_cldev_recv
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x74065028	mei_cldev_disable
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x794f3261	mei_cldev_set_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x8f4a9ac0	mei_cldev_ver
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xa1425701	mei_irq_compl_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xa3acc419	mei_reset
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xa48dc6e7	mei_deregister
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xa8e23e28	mei_irq_write_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xae188d24	mei_cldev_driver_unregister
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xb16b57ec	mei_cancel_work
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xb8762357	mei_write_is_idle
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xc5e53517	mei_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xc671519a	mei_restart
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xcb8cc678	mei_cldev_enable
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xccd5f695	mei_start
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xcebb199d	mei_stop
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xe6f2821b	mei_irq_read_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xe8dd0278	mei_fw_status2str
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/cosm_bus 0x110353ad	cosm_unregister_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/cosm_bus 0x4ebd3fa2	cosm_unregister_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/cosm_bus 0x612982b5	cosm_register_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/cosm_bus 0x84a24ee4	cosm_find_cdev_by_id
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/cosm_bus 0xbd27c3d3	cosm_register_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/mic_bus 0x3e059d33	mbus_unregister_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/mic_bus 0x477adcc1	mbus_register_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/mic_bus 0xa71f2bac	mbus_register_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/mic_bus 0xfe46efd1	mbus_unregister_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/scif_bus 0x27b8858d	scif_register_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/scif_bus 0x87aac2b2	scif_register_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/scif_bus 0xa61f04d3	scif_unregister_device
++EXPORT_SYMBOL_GPL drivers/misc/mic/bus/scif_bus 0xab9337ed	scif_unregister_driver
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x04e359ce	scif_register_pinned_pages
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x072ed52a	scif_readfrom
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x31f517c5	scif_get_node_ids
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x4c6f9582	scif_fence_mark
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x54cf5d79	scif_listen
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x5b2df187	scif_accept
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x5e5d00c7	scif_register
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x633eb428	scif_connect
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x6842b5ae	scif_send
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x6fe733a2	scif_unpin_pages
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x73291e22	scif_close
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x75203b49	scif_open
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x7d503356	scif_bind
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x81537fe1	scif_poll
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x8bf0dc9c	scif_client_unregister
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x9037e83d	scif_vreadfrom
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x9182618e	scif_get_pages
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0x9f9ec119	scif_vwriteto
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xa96dfaa7	scif_unregister
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xbc1dd1f8	scif_put_pages
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xd454b750	scif_recv
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xde5e3e3a	scif_fence_wait
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xe01e4926	scif_pin_pages
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xf7826056	scif_fence_signal
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xfa34c380	scif_client_register
++EXPORT_SYMBOL_GPL drivers/misc/mic/scif/scif 0xfe96394f	scif_writeto
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x95ea0797	st_register
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xbe92fb75	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x0f6680ea	vmci_qpair_produce_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1152e318	vmci_qpair_get_produce_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x13aa5a5d	vmci_datagram_create_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1872c7af	vmci_qpair_produce_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1a195863	vmci_context_get_priv_flags
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x25cdddea	vmci_qpair_dequev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x3ef56cd5	vmci_qpair_alloc
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4b630dac	vmci_get_context_id
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4ba5c46b	vmci_qpair_peek
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x50a255c9	vmci_doorbell_create
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x612df9ae	vmci_qpair_detach
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x677c36d0	vmci_is_context_owner
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x69ef87ff	vmci_datagram_destroy_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x6cc1a5f7	vmci_datagram_create_handle_priv
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x7172fdc0	vmci_qpair_enquev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x722d488a	vmci_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x7d540b50	vmci_qpair_consume_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x81d61eef	vmci_qpair_dequeue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9624c58c	vmci_datagram_send
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9973b9b2	vmci_qpair_consume_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9d16164a	vmci_send_datagram
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xccbb53d1	vmci_doorbell_notify
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xcf5ed7ef	vmci_event_subscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xdac94780	vmci_qpair_get_consume_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xe67343c1	vmci_qpair_enqueue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xe7e7c107	vmci_doorbell_destroy
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xee2daa1e	vmci_qpair_peekv
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x10da7434	sdhci_reset
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x3d8b740e	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x42751943	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x498f4d59	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x4d6de911	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x4de9f393	sdhci_send_command
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x4ea24a84	sdhci_set_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x5771e30b	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x6057ea51	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x60d6c96d	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x74355463	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x93507e9d	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xb004ea3f	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xcf1c341a	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x02e77418	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x2585d679	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x41cc8bc6	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x5109965a	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x51fa6547	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x6865a871	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x71a23f6c	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xa6b26f4e	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xa9911b34	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x2febd547	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xd2f5f0d1	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xeddcd539	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x1b2f86f9	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x657dcd29	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x968402af	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0x5ca604a2	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x70f64a26	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x97260288	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xb4ed2699	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0d845afa	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0f347acc	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x11ed468f	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x14602f47	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x15b8c675	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x16efb705	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1c7657fe	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1e04bfdf	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2559c20a	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2708bf71	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x28259b24	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2c99c5e8	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x33e56298	mtd_block_isreserved
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3cbfb323	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3dd23777	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x40587898	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x49de2317	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4c365a0e	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4d984f30	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x544abaf9	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5984626f	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x59b0ac44	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5d111bd6	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6175f40e	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x64c40bd7	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6cf805ff	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x75e3e771	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x76db09a2	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7bf932fe	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x82747ebc	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x96797f9c	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9ed87b33	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb3652f27	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xbcb0d005	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xbea0270a	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc205e768	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc24e96c3	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd4a9778d	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd7cf30e8	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe89528b0	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf4e9d27d	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfa5fb1a9	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x1478afeb	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x560b49d6	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x7371b707	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x757cece0	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x9358f8f7	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0xb7486c47	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0xbcbf833e	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0x17ab90d8	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x59ebd822	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x9e16fce9	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0x91078f3a	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x03b5aa7e	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x2426d6a2	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x2d275e33	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x2f92309f	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x37b29dfe	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x4ba9965b	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x7b7b611d	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x88e81c6c	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x9021ec61	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xb307c531	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xb33d9715	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xc127c6e9	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xea23e29d	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf03d5a77	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x37376fc3	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xe05989bd	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x02cf6d31	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x64d42f2e	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x8ad85e81	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x952503e6	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xb59d92b3	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xcefbc413	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x04213470	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x0e4de0f2	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3614c773	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x37ab1c2a	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x37e372ff	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3abd83c0	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3baa94b0	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3bff38b4	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x49d517aa	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x5fffa4c5	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x6293319b	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x74ea8915	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x7b002add	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x8464c3bc	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x8fbd98f3	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x97b75e8c	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc9898ec5	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xdccde644	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x476ff135	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x56477adf	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xa8074dca	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xc0ab570c	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x160663e9	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x47f58e54	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x76c482f7	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x877ee77f	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x01c10160	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x02ec4fbc	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x02fb2bbe	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x02fe7d23	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x037cf94e	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x045d7bba	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0743c951	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x08e98ebc	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x096d33e6	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0aad2a7a	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0e3e5422	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x11400273	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1543da52	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x172c682b	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1a4a3ad9	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1d9ecdef	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x206c63f0	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2668f24a	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x26dc3613	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2ad0256c	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2cfdda9c	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2f1401cb	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2f3f8da1	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x301b09f0	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x318538c6	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3654fd77	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x36c870d8	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x37447fe1	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3a6d7fb7	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3a8f2bff	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x417aad73	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x43ba5b26	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x43bd84c6	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4507cddf	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4663639e	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x47e4aa9d	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4866e3db	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5127299d	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x51a601aa	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5253909a	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x52f25c5d	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x55added6	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x568e82d1	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x57cb9774	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5b65a167	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5c09c8c9	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5ceef683	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5cfff9fe	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5d2b59a7	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5d84c709	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5e067210	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6224b1c0	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6b17d90d	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6ee5747d	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x713e9f39	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x718a20ed	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x771d7dfd	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x77e70f42	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8388e07a	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x84716045	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x84fcfcd5	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8a4f7a84	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8b09d374	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8b9d52ed	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8ceba7d4	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8f6b0124	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9079bb61	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x933caa25	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x95d7868e	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x997fc3fb	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9b1667bc	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9ca0fe01	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9d57c638	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9e5b483e	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9ea0afa4	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9ff15dc4	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa1c2e6e0	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa33c85e7	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa4e879e1	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa6f9926f	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa7c34922	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa810e18a	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xab3031b1	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xae80c2f0	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb7a6e92b	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb96488bd	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xba2bdeea	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbdf439e7	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbe2c3890	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbe5757a2	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbe7c8e28	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbf541e1b	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc08bc17c	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc0c879e6	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc0f4d542	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc138347f	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcafcd6d9	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcd118678	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd0823e00	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd193cc9a	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd3aae543	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd4a51e7d	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd74dba79	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd7b79d77	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdcb99011	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xde2924d8	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdfe9945e	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe287348e	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe577165e	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe5a98383	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe7a567af	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe919a232	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe97fa429	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe9ff5a02	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf067155b	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf8858b06	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf8f972db	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfa069841	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfa7ddfd8	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfb15e7a7	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfbd18c78	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfcc5f2aa	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfe0da167	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xff8e0e90	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x004dad91	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x06731ada	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09543b3d	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09dc16ee	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0bd19bcd	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x12c266fc	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x213e29f9	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2bd6135e	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x321df4b2	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x371a95be	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x38869ac0	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3e595690	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x444e6a4b	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x45aa2b29	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4f2a5968	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4fb8f126	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5df8fd1c	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x612473a0	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6825cd72	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6e04afb4	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x76801b40	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7d739597	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x822325b6	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8d9d9d89	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x93add442	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x98438e41	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9c35eb59	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa722f7ca	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xae0e432f	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb4a2873c	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbbc57f45	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc1b5d0dd	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcce75328	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd0cabddc	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd12ac3cb	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd4615c2b	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd4c696cb	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd69062a6	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd6aab49e	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xda923a44	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xde462559	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdfc473c0	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe88498db	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf3bcf80e	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfea6c24f	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xff3bf9b3	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x5e28947e	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xac144314	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xfe3a92f5	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x0c2b750a	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x1428f781	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x75e49f99	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x7b50e7df	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x426cec30	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xb1bd908a	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xbb4a5b25	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xc1e75ca2	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x2c95b466	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x37f01847	cpsw_ale_dump
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x4428c2d9	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x48591484	cpsw_ale_stop
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x6e819021	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x7319b519	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x791a2d9e	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x81711c06	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x86537da6	cpsw_ale_start
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x8d37def7	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xa660679d	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xb624da39	cpsw_ale_add_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xc77fd038	cpsw_ale_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xe15bafd0	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xf746f98b	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x4939d0b0	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x73d37496	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x79c14ff1	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x8aa51d98	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xdcf38683	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xee591f63	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0xbb89c302	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x0304eb96	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x1cb88a19	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x3481a3fa	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x6f27c7f9	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x6fba1c10	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x82b7741b	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x9fe86214	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xa2c0478c	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xc0d4e83d	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xce923696	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x0801d0b4	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x0fb8e952	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x8316158f	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xb117b207	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x172cb64e	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x254153ba	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x59e7683d	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x5a012c8f	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x6201e1e0	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x63f0736b	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xa05ac435	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xa8fb33d2	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xd39d7479	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x03c85470	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x3d6f8c0d	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x5fa1ad54	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x64e29dfc	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xc158749b	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xe85f8549	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x069893f9	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0a939d40	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1103a427	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1b829882	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2598b7e3	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2acab46b	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2f69c6f6	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x396f91e8	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3d0c376b	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3d6ad033	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4525eb88	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4748d50d	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4b06f9a8	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x66373324	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x67ceea63	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x825f543e	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x852138ee	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x93bec3c6	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa9a7aaed	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xacbe7f0a	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbd5aa924	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbfcf1a01	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc6c60c1a	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc8704437	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd3720329	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xdb7acf7e	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe0365016	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe7cc596b	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xee9ac807	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf37eccfb	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xfa18a1e3	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xfc0e7a3e	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x1e68d83e	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x71179089	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x135601e8	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x18c92ff4	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x268e2265	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x3f2c4d3f	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x44e591bb	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x451408c1	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x5d04d46c	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x7c809a2f	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x80dcbddb	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x970c6089	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa1fd653a	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb93eaa37	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xbeca439b	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xd25d0e29	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xd827a6f9	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf5316279	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x4bf8cf87	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x655d0f42	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xa47a2488	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xaecde430	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0xc03345e8	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x3a0fec9d	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x437f884d	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x64cdae7d	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x75d270f0	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xebf9a276	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x02aade35	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x08964e46	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x127e7b78	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x16f1235a	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1b074767	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1bf35041	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x243c6413	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x3f7dd8fb	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x4c4068e3	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x512a2413	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x57813145	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x58e953c6	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5ee5ab54	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x70f6e701	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9f455a20	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa39a3b34	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb8979af3	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb905a2fc	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xbc50de19	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc43732de	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc4a8fc91	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd40e1631	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd49b4b3e	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xda5efbab	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe05a23ae	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe5d249af	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe6099deb	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xea826aaf	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xecfce5a8	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xeecd7ee9	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf7c79d79	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x0747ab23	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x1df780a2	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x28aba080	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5310ee59	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x60cf58d2	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x61e518d7	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x865a9500	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xc43d0641	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xcec445f0	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd701f877	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xddf92fca	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xde368a81	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe522dfa2	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf4639d7c	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf91fc3a9	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xfd0a92aa	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x02aecc8a	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x14a54960	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x232aeaf7	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x4e962830	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x51268449	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x7bd566d3	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xded5ee4c	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xecd9a8e7	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x0620ab5b	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x11c7c5a5	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x13beb931	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x16357492	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2b10c0dd	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31d55d21	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x3e274ba1	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x46e923c3	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x4f8da0cb	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x5d309c33	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x75067d51	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x8ec57f3e	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xa93b6881	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xab473368	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xbc60d47d	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xccb4bb86	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xcdf51ab6	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xeb9097df	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf286d08f	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x1ab0dd6a	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x2a58aeb0	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x3279eddb	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x6ed13d6f	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x8e7ca42a	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x917f1a26	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xc008e155	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xcffc0281	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xe380eee0	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x029abbb4	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x218913e5	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x997219bc	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd314b9d6	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x04f88a09	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x062563eb	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x07ac0aa7	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x08168aad	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x0d030bd1	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x23706b54	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x26ef8fba	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x31c54045	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x379c25ef	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x4db61953	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x634af0be	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x70e36ad7	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7cb61160	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7e964dee	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x84fa95ba	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x8bc14cf9	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x90ea74bd	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x91de0f8e	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x9a58f091	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xab051dfc	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xad96a962	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xbb98ccbe	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xe2f8dcfb	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf43eafbc	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf9917a69	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xfadfdd23	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xfe0519ec	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x04dae290	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0fb98d2a	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x16d03516	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1d9050c7	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1ed7dba8	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x20ac47af	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3630ad09	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x382e49da	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5dff6618	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6b4de810	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6c64eacf	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6d3a61da	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x72ea1058	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x81497c4c	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8e0eb81d	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xafcdc668	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb70f58c7	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc41bb691	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc4e9fc8e	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xcf7e7b92	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xead471e4	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x74029f0f	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x748c88e5	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x83fd3516	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xb8ef2c09	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x00a5f52e	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x02636a72	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0432c949	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0594e406	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x09e4f571	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0c36fda9	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0c5821cd	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x23db7471	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x313a4cbb	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x323a0085	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3c62951e	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3e875b26	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x477182b0	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x54ee43ed	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x57b29e18	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6676adbe	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6774c8f1	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x72522507	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x76db7937	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x888c56e5	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x926e940c	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x9fc95397	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa23dac34	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa2486430	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa24ed4fd	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa452e893	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa50ab60e	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xaab8ace0	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xac7f9c7d	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb44a6ae6	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd3aadc42	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe2497b24	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe9b296d7	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xef66c6b4	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf30fe0a0	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf9532a7e	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xfaedc662	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xff361f27	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x236c66f4	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x46d1e17a	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x50a01e50	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x78c3cd49	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x88dd1479	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x91fa2370	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xb3ad4e22	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xb520f130	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xba530192	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc1a0d894	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xd2f254d8	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe2f4802a	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xf8dd7f6e	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x00e0a59b	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x01bce126	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x07fc741a	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0ad116ab	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0e586779	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x113b2871	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1f764ee4	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3af95363	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x421ed02a	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x426a6fd3	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x44cd7a02	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x48590f92	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x499105f8	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4cd5a526	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x51aa548c	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5c68308e	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6242c194	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x68d45523	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x71c5d479	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x81814408	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x825b6add	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x870cffd7	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x889cd7bc	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x89292b34	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8eb6a1d0	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x95dc158d	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x95f20c71	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9608508c	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9fb94bf1	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xacd8e788	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb17d18c8	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb98aada4	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb9f754a6	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbb78746d	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbc1b32a5	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc308b902	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc6f2bc6e	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xcf617deb	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd10f7e6c	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xde76731b	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe0dc81b8	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe15aee7d	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe4828d7d	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe9d505f5	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xee440638	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf74f9504	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x7d931249	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x9d17b0bd	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xbcbc95e0	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xed5a58b1	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xefaec751	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x012b5aea	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x0a8b13e2	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x416101df	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x7503bb15	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x062a93ce	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x14dba920	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x16dd7d44	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1c206c76	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x5833dd4e	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x59367b3f	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x5970e885	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6bfb3c0e	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6d5a9368	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6febcec4	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x719ac0a7	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x72718971	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x734797c1	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xcb585edc	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe1b10a06	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xfb5ae8de	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x36d1d342	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x8495ec4a	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x8a281858	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x021f7a06	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x036a4105	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x06411f51	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0717ca3b	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0b4317d7	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x10c7682d	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x249b8850	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x26d1731c	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2f42fcb0	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3507ae96	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x413ed090	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x43e8486d	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x48435ed1	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x49dccc44	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4a5844e4	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4cb5d883	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x57f9f187	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x58bbd434	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5c6cc3b1	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5dfbc748	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x68066548	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x71ae125e	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7584a315	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7ad2e512	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x82ea6322	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x84294cf1	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x88d0a212	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x88d56245	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8ed452e0	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8ff2ed6e	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9b3ee08a	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9e49ef67	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9feb68b1	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xae679e1b	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb805a0fa	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc330ed7e	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xceab3aa3	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd2ff118d	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd717ace8	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe16b37c1	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xece83a22	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf00b9738	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf41da692	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf4f5e70f	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfd852482	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x22ca38e3	mei_phy_ops
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x69b62c21	nfc_mei_phy_alloc
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0xb91361d3	nfc_mei_phy_free
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x2f601ed3	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x68267de4	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x7e46df89	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x95061e42	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x1c12b410	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x350bcd4f	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x88fdcfb5	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x8a5aef5a	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x8fd1b74f	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x9835a8b3	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xe47bd8d4	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xfc5179b5	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x03d88a78	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x13c3f067	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x45ba2863	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x0c80bf9d	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x16e16764	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x202d4ed6	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x224f51bf	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x3866e217	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x72a337b5	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x7ba66918	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x93e24e90	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x99f018c4	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xa408fe3c	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc697b0f7	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x73e8c6e2	intel_pinctrl_probe
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x91159c15	intel_pinctrl_remove
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0xd035d65f	intel_pinctrl_suspend
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0xf5181c72	intel_pinctrl_resume
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0x2520d5a8	asus_wmi_register_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0x388a2101	asus_wmi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/dell-rbtn 0x51552fca	dell_rbtn_notifier_unregister
++EXPORT_SYMBOL_GPL drivers/platform/x86/dell-rbtn 0xa060fe7d	dell_rbtn_notifier_register
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_ips 0x46809fa9	ips_link_to_i915_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0x56235c72	intel_pmc_ipc_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0x75068282	intel_pmc_ipc_raw_cmd
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0xdea07053	intel_pmc_ipc_simple_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_punit_ipc 0xa6c87106	intel_punit_ipc_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x111aafa7	telemetry_set_trace_verbosity
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x1bbf0813	telemetry_add_events
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x1be25432	telemetry_get_sampling_period
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x4294042b	telemetry_get_eventconfig
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x4cb51f18	telemetry_pltconfig_valid
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x50c1c0a8	telemetry_get_trace_verbosity
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x5847f501	telemetry_clear_pltdata
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x611fd2a7	telemetry_read_eventlog
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x64c6a83e	telemetry_read_events
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x73dcd24f	telemetry_raw_read_events
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0x82bb2dbe	telemetry_get_evtname
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0xb78846ce	telemetry_set_sampling_period
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0xbb9a2726	telemetry_reset_events
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0xbf0d3d83	telemetry_set_pltdata
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0xcbdc93cf	telemetry_update_events
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_telemetry_core 0xe7eb1528	telemetry_raw_read_eventlog
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x232b5238	mxm_wmi_supported
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x61cdf799	mxm_wmi_call_mxds
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0xe26032eb	mxm_wmi_call_mxmx
++EXPORT_SYMBOL_GPL drivers/platform/x86/thinkpad_acpi 0x706cdcef	tpacpi_led_set
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x3ecf6cfc	wmi_install_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x561c634a	wmi_evaluate_method
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x876d29f1	wmi_get_event_data
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xb5a6ebe2	wmi_remove_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xc9d4d6d1	wmi_has_guid
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xda29f8b0	wmi_set_block
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xfb882fb7	wmi_query_block
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x4d1b4c27	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x78166ce9	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x8e039a65	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0x6365870a	pwm_lpss_byt_info
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xafcf8794	pwm_lpss_bxt_info
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xb563cdb0	pwm_lpss_remove
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xc34d815f	pwm_lpss_bsw_info
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xf3b40a39	pwm_lpss_probe
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x0bae4768	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x77c5362a	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xddd3f9a6	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x330ba72b	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x4e039089	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x4ee1e048	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xa80a3de3	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xb7641524	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xe34851ba	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0xa29a5221	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x04fe5850	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0d61dbd3	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x10411be7	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x10715b20	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x10d276cc	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x19ac83e1	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1b982f63	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x256513ce	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x31869a47	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3355831f	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3614741a	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x36f4bb17	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3c6a0950	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3d9f27df	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x40349302	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x448b1143	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4502bc6c	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x48ae972d	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x51dd9fe2	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x61a23fa4	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6bd41fa9	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6c8f5701	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6db06da5	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6debfcdd	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6f7fa790	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x70d77a01	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x74ac9f9e	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x751bfd30	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x761e5c3d	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7be0eab7	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8273c8bb	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x86f4adf8	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x89ad174c	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x92331ad3	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x99d50232	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9e2ba92e	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa475de18	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xaa766db0	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb233efef	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb31b11da	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb6519be7	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe4f09a61	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfc7c89a0	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfc855c27	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfd7932e9	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xff354e2a	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0d86890e	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x13914350	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x16d02b29	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x1e3bd742	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x2eda742c	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x42c5472f	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x44cdf1e0	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x64bc1f63	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x6cbbee84	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x7d2a39c4	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x88f25cc0	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x9206c265	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb316145d	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xce3ee038	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xd5327371	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xebf1ac37	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x367f04cc	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x48b447b6	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x48ed768b	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x5416cdd2	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xd6428a05	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xe3b1c24b	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x011e9484	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0731b776	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0b6710e9	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0db4ddd0	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x18d578aa	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x203da786	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x23c27635	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x26f325cd	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2aeb199a	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x33529762	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x34f97836	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3ab6a36d	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3d7269c0	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x44681e4a	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4485a12f	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4ba59abc	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4e4110dc	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5e5ef9fa	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x618ebb97	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x72f7ddee	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7b49336b	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x898aca82	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8af2ecff	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8cc02862	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x939a9e93	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x941e2f1b	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9500d70d	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9ceccf31	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xaee963a6	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xaef6b49d	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbc0ac449	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbe49d9c5	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf1f32d9	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc190b128	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc70243cf	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc880168d	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd250c2ec	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe4b2298a	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xebb671c2	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xec04c25b	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xed843b9c	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf8716b70	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x0e478270	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x33f95d8f	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4e110adf	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x55b7b78f	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x747b38e4	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x79ca0b00	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x89099cc1	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x8ff3940e	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x9073deb3	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x92bf774f	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xa43341e9	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xa9569ad3	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xc27aac8a	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xc6ae8909	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xdc6ed935	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe56292e3	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe8ed3140	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x0a5e3b53	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x13973b09	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1459d5f4	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x15463d89	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1797e913	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x193815b0	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1eff5d50	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x215da0e6	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2b567cf5	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x550e832d	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x55eda8db	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5e52af92	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6727a0f4	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x88b04520	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8cd1ecc0	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa4caa2ae	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xae62f695	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb1074a7d	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb2704ce3	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xcb7fe8f9	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xd613b784	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe475fc43	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe6d98202	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfca8f777	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x00b983fa	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x01ec32d8	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x05563aff	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0787cae7	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x089864ad	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0981031c	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x107fd2b0	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1c4ff1c7	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1fc7ae96	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x212ff790	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2ac6922d	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2aef7d91	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x39a02fef	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x415c6652	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x433c3dec	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x45fe5279	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x599bc7a5	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5a41e2b9	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5b0d9c93	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5b692f60	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5b9801c4	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x69109347	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84019d8f	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8b822275	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9a42cfd3	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9c570089	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9e8448c0	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa8f82fda	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa9ef4d7b	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb2b9229c	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb73b8a18	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xba57ce0e	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbf513973	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc003d10b	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xcc805fb1	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd6ab4909	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe27cd88f	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf7002f24	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf9febd58	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfdf79db5	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x2ab14991	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x39a3aad7	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x46961668	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x70f8dcec	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xc5b535d2	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x09ef26c8	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x4e11e713	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x6c7c0519	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xbb79e0db	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xc73d30bb	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xc9bdffd6	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x0ca2803f	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x2eda71a9	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x3409bcc9	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x97e00f53	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xa6b8057c	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xb4919a1c	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xe990d271	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x43bff86b	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x7e3fbec7	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xa4d0c10d	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xa650964a	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xb0fd3d21	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xd06e68de	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xf7615101	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x376561eb	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x3c617713	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xae230c49	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xc32b11ad	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xdd1426a2	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x10dc6e5f	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x2b41ae76	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xa49ded00	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xedd43325	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1d64ac91	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x2492591a	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x2593079b	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x30f19596	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x3bbfe01b	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x5bce93f1	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x7d7a0eea	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x813395ed	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x829b1364	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8adb7447	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xa0d1ea78	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xa50520aa	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xaafb5402	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xc75708e0	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xc82e41a4	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xd1e721ee	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xee8a718c	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xfcb21891	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0x388e052c	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x050668a7	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x05fba4cd	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0aeb1725	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0e183937	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0f6b5fba	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1d4cae64	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2102150f	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f4f1684	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3094aceb	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x32f21743	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3831c516	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x457ac479	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4aab73f9	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4d59ae18	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x642bdb72	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6ab6d8c0	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6df1b75d	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x79a61cf0	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x7fb0c547	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9609612e	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x98303237	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9af1336c	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9b78ec3f	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa6f72de8	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb0218dbc	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb1773ca4	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb78f5f93	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb791ce6a	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xca5e707a	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd06ae41c	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd2a1efa2	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd6bc7c5f	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe18e1f36	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe63f38cf	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xea3793da	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x0cc42f55	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x251603bd	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x308d95fd	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x373f2fae	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x5c8c9b77	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xa6843eed	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xbe4e3e53	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xf99aef8b	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x207927da	comedi_pcmcia_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x27f9aab9	comedi_to_pcmcia_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x2aaebc2f	comedi_pcmcia_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x5953cb98	comedi_pcmcia_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x770b6e05	comedi_pcmcia_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x77c840d4	comedi_pcmcia_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xd7f77cd1	comedi_pcmcia_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x0777b6b0	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xa1acf007	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xc367f44e	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xc875844e	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xde5d2e02	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xe205fed9	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x508295fb	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0xb7d388e8	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0xbae0895a	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0x6ebbc1b9	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x16510501	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x2f2588b9	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x422a054f	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x552404bf	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x670906ca	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x68280a57	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x6e0af0d4	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x6f7e5e0c	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x9f9e8b7f	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xa3102dda	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb1308b1e	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb8cbd872	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xd7415fd4	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x12d888b8	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x54e56aaf	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x7794dc58	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x0d68fcd9	comedi_isadma_poll
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x12fba874	comedi_isadma_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x4a17474e	comedi_isadma_disable_on_sample
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x61f9b59b	comedi_isadma_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x6815a033	comedi_isadma_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa3d01a85	comedi_isadma_program
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa7ebb8a3	comedi_isadma_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x9d2d7ffb	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x277ba529	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x29c7ccb7	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x2c45b66c	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x43ca548f	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x49655853	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5797e25f	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5a040786	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x671c0a4f	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x678364c2	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x7574459f	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x7979f116	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xaad38835	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xb1e6f4c2	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc6a530ff	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd19cb9c8	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd2834d4a	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xde2133e3	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe0a143f4	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe1de43b5	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf11e3529	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf7fb7a78	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x2d4952f5	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x96e8e48e	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x0f44cf69	labpc_drain_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x2ce83aaa	labpc_free_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x4bdf3677	labpc_setup_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xb3e39c96	labpc_init_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xbae9144d	labpc_handle_dma_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x43df697c	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x6aa99d56	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x738f182f	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x8c132732	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xa24b17db	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xe02a9459	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xf1551b59	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xfc5bf2f5	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x06d9b7b6	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x29b7516f	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x6f932d57	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x88bcf173	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x92e06083	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xf664cf3d	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x40b354b3	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x54fb68bf	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x5578b430	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x6a189f00	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x8497017d	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x987275e3	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xa52483cb	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0xec7f612a	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x031b1961	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x1146d209	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x18b7f581	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x1e1f01fa	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x1f359592	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x4215e550	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x5a0da99b	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x64e05b8f	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x7e795091	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x8e3b74a1	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xc46c753f	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xc49eef29	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/rdma/ipath/ib_ipath 0x1514b2b2	ipath_debug
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x2ab8daa7	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4cf5936b	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x503fd4fc	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x5ab9a7f6	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x649a5b01	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8b3aeb81	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x97af6220	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xa82076db	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe87ffa90	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xedeafa76	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xf24271ab	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xffa8741f	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x0877dd5c	visor_periodic_work_start
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x0ec0434e	visorchannel_zoneid
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x149bde55	visorchannel_clear
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x1582a13b	visorchannel_signalempty
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x2886afa3	visorchannel_debug
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x37626eff	visorchannel_get_clientpartition
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x39fe5de1	visorchannel_signalqueue_max_slots
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x4063ea9d	visorchannel_signalqueue_slots_avail
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x4cbbd3e9	visorchipset_register_busdev
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x4e4bfbe5	visorchannel_signalremove
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x563d32aa	visorbus_read_channel
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x5e533597	visor_periodic_work_nextperiod
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x60aaf74b	visorchannel_uuid_id
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x610d19dd	visorbus_enable_channel_interrupts
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x6d2236e7	visorbus_clear_channel
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x720775df	visorchannel_set_clientpartition
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x7948d062	visorchannel_get_header
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x7a4ec5c5	visor_periodic_work_stop
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x85b49e2d	visorchannel_get_uuid
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x865e5ab6	visor_periodic_work_destroy
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0x96401fe5	visor_periodic_work_create
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xa428b832	visorchannel_create
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xa77f3c8a	visorbus_write_channel
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xac7771ac	visorchannel_signalinsert
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xae9128e9	visorchannel_create_with_lock
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xb21866a9	visorbus_disable_channel_interrupts
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xb4aab617	visorchannel_write
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xca18358d	visorchannel_id
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xcc89f91f	visorchannel_destroy
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xd7edca34	visorbus_register_visor_driver
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xe3b5efe1	visorchannel_get_physaddr
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xebc59b20	visorbus_unregister_visor_driver
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xed313c21	visorchannel_read
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xf990f627	visorchannel_get_nbytes
++EXPORT_SYMBOL_GPL drivers/staging/unisys/visorbus/visorbus 0xfece836b	visorbus_registerdevnode
++EXPORT_SYMBOL_GPL drivers/thermal/int340x_thermal/int340x_thermal_zone 0x247c9968	int340x_thermal_zone_remove
++EXPORT_SYMBOL_GPL drivers/thermal/int340x_thermal/int340x_thermal_zone 0x66bf36ab	int340x_thermal_zone_add
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x5b471184	intel_soc_dts_iosf_init
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x63edb99f	intel_soc_dts_iosf_interrupt_handler
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x96c831c9	intel_soc_dts_iosf_add_read_only_critical_trip
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0xe691cb08	intel_soc_dts_iosf_exit
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x63f00ce9	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x64f4c62c	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xd4d8313e	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x2553db34	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x74f034d3	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x1cc56370	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0xbec057c0	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x1bfc6284	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x52056784	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xc4d6d924	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xc6b71159	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xe3ced7cf	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xff5d16b2	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x0adc6e89	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x12182335	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x13d1fc1d	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x2b294ec5	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x90f131a8	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x986e195a	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xa5a1ddd2	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xae076f8e	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xb4f29a05	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xbeace95f	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd38845ba	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd61c4897	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd7bc0240	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xe22330ed	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xff3f483f	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x619375aa	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x89ca818c	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xd1e47518	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xd371dd12	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x4c880ed7	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xb6b0e582	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xef0dcebd	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1bf166eb	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2535c086	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x41a7fe49	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5cbe1323	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6713ab02	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6a148544	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x748f013a	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x8e191733	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x908d7851	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x920566d9	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x92e4fdc0	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xd0dfdb3f	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xe623c788	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf2655d6e	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xfd04c716	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x4ddd26ab	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x52da2f28	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x59ec8feb	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x5f9da52f	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x69c58f47	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x70a60e07	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x7377e5fd	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x85089fb1	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xb4aa1a53	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xbef80c73	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xc48b0bbb	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xccf812a6	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xdd4b4eb9	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xdea103bd	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xeff9dec5	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x04e70fee	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x081db4c9	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0f1859ba	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0f481a21	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x126550b5	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x29a57856	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4534fa61	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x459ba287	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x68494784	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x69874614	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x719fab7e	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7a0d711c	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x84cf33df	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x91faac0e	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x95907679	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x98b91cce	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa3218b41	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xae6ad129	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xaf0ecfba	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb57dfda3	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc3c457cf	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc3dcf116	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc8d187c0	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xce1c96ae	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd5868984	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xdef10143	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xdf736660	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe199b4bf	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf1ab100f	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf998a53c	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf9bcacae	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfc2ae9b2	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x0a5fbced	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x11741784	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x28f12e7e	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x44665416	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x4bb74b45	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x62d1a6a1	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x6813c979	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x94710ba2	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x96726756	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x9ccab1c5	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa4744dba	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xd01e1796	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xe3b9d533	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xe63c6f80	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x14829d33	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0xdc32e9c0	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x1e1a1030	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x2db1d042	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x488330be	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x55f5088a	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x57f1d740	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x68ea0a01	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xbb003a02	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xe73d35db	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xf4b4a111	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x499ea075	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0x2d465b91	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x19e1ce27	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x17f4c53f	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1f567929	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2b28ced6	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2d7e315a	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x36b8b751	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x3916895d	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x3e956c0a	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x560247e3	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x59266267	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x5ea63bd8	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7cdcaa59	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x88c7187d	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xa7d74803	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xb5d829e2	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xbaf00be6	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xca112e6e	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xcda9828c	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe15675c8	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe29736ef	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xeabca588	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf5b8e9ce	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x04e64200	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x04fedffe	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x11d4249e	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x13ed5443	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x22467a88	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x27dbf95d	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x353978d2	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3e78217c	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x45f88564	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x5acf68bd	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x62b50fa6	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x663332d5	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6723246b	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8f8a2b5b	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd12593e9	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xdcef4be5	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xdfcb231c	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe1561d63	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe3389044	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xed4da7ef	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf1fdec47	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf710ce23	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf9895fb9	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xfd9af100	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x2e430b3b	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x318d4450	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x4964f653	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x520b3c40	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x56b29371	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x7740ba2d	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xa907cc47	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xbb6884c6	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xbff3d0f3	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd19c0a0d	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd9f7c949	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xde82ca8e	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x01f7f977	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x06e63110	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x0bd816f0	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x122f15ac	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xb8393d34	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xc6a35d9f	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xeac816e1	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xf564a79f	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xf8ff83ce	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x05f34861	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x16a15d6f	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x173ac9b3	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x23b89d7d	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x35f2465d	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x427c8fd3	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x5ca7a08e	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x68cd34d8	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7160e743	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xbae25c07	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xbfb445a1	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xc3f8c316	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xe0d8fd82	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfdc3cfe0	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x32ce357c	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x3cc1d3d6	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xdb3c000a	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x180df6b0	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x511dac48	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x8f7cbdcd	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x9e1dbde7	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x9e66ce00	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x9f9574fa	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xa5cbffeb	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xda1581e5	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x06765f88	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x072f36a0	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x09a6f937	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0d78016e	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0fc02440	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x13cea5d5	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1a4049fd	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1b7854b7	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x20e11437	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x24ca8232	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x277cdc05	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2c87be97	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x30893591	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x333fee2c	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x396a2e7a	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3ab2b0ed	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3b59e664	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x40f326ba	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x439f45c0	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4540b7cf	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x479534c5	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5550a2a5	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6661c734	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x748567a5	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x77f5c956	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x816b9e92	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa0b52e5e	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa963f20d	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xac97316b	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb0c63b5a	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbb21c36d	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbec0c8e4	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbf22c20f	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc4bf0a28	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc65694c5	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc95201ed	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd4d2765d	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd715e41f	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf4fd31d3	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf78e8e47	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xff28f3bd	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0x0f0749b3	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x0836b63d	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3567743b	vfio_external_user_iommu_id
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x4023c4be	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x4a78cd79	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x4d7623cd	vfio_external_group_match_file
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x6a6ed456	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc1d989c5	vfio_external_check_extension
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc4913442	vfio_group_put_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xd297c66f	vfio_group_get_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xf6e3ff51	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0x43c5ade0	vfio_virqfd_disable
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0xf6962e93	vfio_virqfd_enable
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x01970115	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x033ee020	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x132b2336	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2245369b	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2245643a	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x31511644	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3625763a	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x43cf4d98	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4cb96f77	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4e01be74	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x546d10ad	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x584529b0	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5ec6551c	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5f74a213	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x602a8289	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x68ebc4d1	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x71981b39	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x77dda6a6	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x7bbf080c	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x7fab7f0c	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x91e35994	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x94e38683	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9a1f0125	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb592fa24	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbeec2f28	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc459dc4b	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd57ece0d	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd65fcfff	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd74fa6b7	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfb916e80	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0x2c63e051	apple_bl_register
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0xdab0f892	apple_bl_unregister
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x18226f43	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x194ce5b5	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x58324077	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xb29588ea	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xb715222d	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xc13c707e	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xd4296df8	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x1f22fb1c	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x5df69a47	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x6b786c6f	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x96d9af24	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xa5709089	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xaf9a85d4	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xd03ba67c	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xeb2f313b	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xeb4f9b59	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xfec611ad	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0x139e3b1e	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0x7269c204	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0xd3642d91	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x6b79b39e	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x756743dc	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/vermilion/vmlfb 0x016e6c20	vmlfb_unregister_subsys
++EXPORT_SYMBOL_GPL drivers/video/fbdev/vermilion/vmlfb 0x90c018c6	vmlfb_register_subsys
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x22a7af24	viafb_dma_copy_out_sg
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x292da7a2	viafb_irq_enable
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x30cc9311	viafb_request_dma
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x31469540	viafb_pm_unregister
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x79e6190a	viafb_irq_disable
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x9c96ecf7	viafb_find_i2c_adapter
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xb4f863e6	viafb_pm_register
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xcaefb732	viafb_release_dma
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xfff2dfd2	viafb_gpio_lookup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x00088dd2	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x23d4de74	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x3f177a0a	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xca0f39b5	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xd21ff68a	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xe19956e3	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xea413082	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xf9f5b490	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xfbd41297	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/xen/xen-privcmd 0x4f9b932b	xen_privcmd_fops
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x2f352ae5	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x8d247839	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xb00541c0	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x27bacf07	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x449c2fd5	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x4d0af966	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x5c9c7776	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x9b5912fb	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xb9919f52	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xeafd7c7d	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x00b2e5b7	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x010f82b1	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x02c6ed56	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x06025724	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x06d58609	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x07631047	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x08855367	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0a916bf6	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0b3d0756	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0c98626f	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0d1efc4a	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0fa89d80	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x10b4626f	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x13753b01	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x16726f00	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x167c927a	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1a1b13b8	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1aadd502	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1ecab46f	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x21233953	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2215f827	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x23c388c8	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x28099ffd	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x283eb58c	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2bdcc8cc	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2c09a893	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2fb696ff	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3484316f	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x396013c9	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3a253c08	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3a774132	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3c29a8df	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3c49c7e2	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3dd47789	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3e10d33b	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3e9b62aa	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f663f26	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x404bc43c	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x432ab74f	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x43d878f7	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4425aeca	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x45705d13	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x45ab65fa	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x46e88901	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4f77292e	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x532edc2e	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x537af83d	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x53c8d4fb	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x55c2a742	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x596df71a	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x599edcd9	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5c290e89	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5d35ede7	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5ec9e679	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x62198cfa	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x63d64cd4	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x67986a70	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6b38e699	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6c7d848b	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6f005c2f	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7168db6c	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x721903cc	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x74119470	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x76ee56e6	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x770334a1	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x77245f17	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x784a6a15	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x799d9eba	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x79e5b2ca	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7b73ccc5	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7bea54f0	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7c9722ba	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7f48c1b6	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7fc6eecc	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x814e021a	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x81ba0698	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x87dbb8d6	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8861ac36	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8a24dccc	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8fffb2ec	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x949f5483	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9549ff5a	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9564ff18	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x96dc8647	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9affe027	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9b93da55	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9f03c304	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9fc24f71	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa361b411	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa80342b5	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaa4c4f2b	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xacb4e10e	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaebdb66d	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb02b5a74	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb376b22d	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb3984960	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb520cf06	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb871423a	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbaf05686	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbc59f3fe	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbe7dcbc9	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbfcec814	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc0c7a55d	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcab0040e	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xce2be313	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd131f564	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd1ab67fd	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd9adf92f	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdc0ea18d	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdd02cf51	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdd692206	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdedc1f7a	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe19c2d38	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe54fd4c7	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe89f0831	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe8a98d78	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeb5fa33a	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xebbf41fb	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xec2fdf8d	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xedff58e2	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf0a9a283	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf1679cc1	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf2bca5fc	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf588145a	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfd5732f0	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0x20eea84a	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x00d27d54	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0360c134	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0719e9b1	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x09442965	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0edb3d28	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1093b108	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x13708fbf	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x14370df2	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x17889f99	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x24dd818c	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2b6e5f19	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2b8eb322	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3478f8b4	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4777f0b1	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4c15cfbb	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4f3c6888	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5199f89a	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x55bcf0f6	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5f5afa4e	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6085edbd	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x613718ad	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6a9c1203	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6f47067f	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7101b6cf	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x85e8f5d1	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x86dcf55e	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x889103fa	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8c29952b	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x94b60705	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9bca6fd4	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa084f81d	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa312d253	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa3bb0406	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa422f719	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa71bc093	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa857f655	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xad3a427d	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb0278de0	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb0480ef3	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb33cf6d2	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbb45e6be	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbbccebda	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc79ce1e6	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcceb2aeb	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xce1cd38c	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd0b5b7dc	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd1bf4b74	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd89b116b	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdd885c89	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe263e0ca	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe4d3b95f	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe9176c9f	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xef177656	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xeff15085	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf1002d16	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf13e13fd	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf30f6962	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf4a78fea	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf507a544	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfbcad741	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfc010439	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfcb78250	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1871d2f6	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x3f0bbcdf	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xa4a2c6e0	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x21611e4c	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0xef0341d3	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d62fac4	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36a28a9e	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x3879f2cf	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x6bd121d3	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x81a17396	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa5e93d91	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa8432e33	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xce8bf057	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xeeb51ead	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf56c2017	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x39bce11b	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x4b7bb452	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x658d145b	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x8000b8f0	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xabdbd159	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xc22c8a49	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x0dd169c4	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x58d22e3a	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xc7260236	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x53e9cf99	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x6f90cfec	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0x9f8b1900	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x893f921e	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xc7293205	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x1803a6ed	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x2b30f429	raid6_call
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xe4b051cf	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x0adcb055	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x221df614	base_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x4da25bec	base_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x63f42b6a	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x76203267	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xca3140ce	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfa5eee0a	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfc02472a	base_inv_true_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x4e9cc652	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x8572ce0b	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/802/garp 0x64d41e6b	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0x65b0975a	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0x7ed817cc	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0x9094003a	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0xa0ec6ba5	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0xbff6ea2b	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x3c8405b0	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x573ee572	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0x8388bd4a	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x99a51557	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xb7e3125c	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xfcb1515b	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/stp 0x5ed813dc	stp_proto_register
++EXPORT_SYMBOL_GPL net/802/stp 0xf1684b12	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x420cabd4	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x65f21358	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xc3e6901b	ax25_register_pid
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x207797ec	bt_debugfs
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x31b88865	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x79f810f0	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x7b38d353	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xa32f2a0a	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xa6769d05	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xbfbde97f	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xdee167b5	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x131b73cc	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x1b51158d	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x3dcb1e23	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x50d19fb0	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x9b1d5d8d	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xa48f6427	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xcb5dc6f7	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xffe32249	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x204bcb0c	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0xd437fe6c	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0a11e3e3	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x11caa1fb	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x139a26b2	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1410e8eb	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x16861659	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d3d372f	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x23672cd0	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2b6be7d2	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x316da947	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x31daa6c1	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x33319b66	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x43d59af2	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x49f2d695	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4a7cb791	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4e2d4d99	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x58144322	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59169ce6	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5bc4561f	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5f6ba00e	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6ad49876	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x73e79f04	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x8da9cc22	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9c41150c	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9e25b22d	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb0ec73ee	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb63137b4	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb7393153	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb89fa1c2	compat_dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc3724633	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xcd1d4070	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xda4405c2	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe4320819	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe5e45385	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xed5c63a0	compat_dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xfa9759ff	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xfc537ec8	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x0fd91eae	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x2f3a25b2	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x555554e0	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x5ad184bb	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xe84f761c	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xf0f1daa1	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x13ad690e	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x19922390	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x1f892808	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x4d7aef69	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x72558576	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xa3e113f2	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xa5dbe332	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x151a1a37	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x25412bac	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x2dbec952	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x423fff9b	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xd7c7aa32	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xeb68a4b6	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0x9fad29fa	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x0cdca2bf	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x2ebb79c6	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x3b411c7e	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x431485ef	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x56b2eeeb	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x6fbd2014	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8a7e296d	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8c2eb12e	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x9015e7f3	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xb611c610	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc285ee5b	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xcab46598	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd7c05e6d	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xe2f6184a	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xf1943fe4	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0x20ba082f	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0x0dfd7c45	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0xb45d4d22	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x29b49bda	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x2cc6d78e	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xaa43e82d	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xdcb6ef2d	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xf1f5ce78	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x78b39ab3	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x0c2f6a87	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x3be91eac	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x9d34e7bc	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xa33fd5f5	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xedf1727c	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0x993c74c2	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x0b333622	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x26592890	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x8c032a0a	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x9f120761	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xba520551	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x453ab1da	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x6504fad5	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x6d910978	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x6e1ca2ad	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x24ef7131	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x3af5823e	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x3c920ce8	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x5d77d54b	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xb37c4029	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xd5f432ec	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xf6c9e59a	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0xa94a85a8	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0xd5b2ec1c	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0xc4f7aed1	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x29aab61a	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x49a3d191	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0x8666f9a9	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x5091f977	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x5359f6dd	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x788b4ecd	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x84755b28	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xd5fedb85	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x711f1fdc	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x18f17226	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x59c26671	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xcd8a0937	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xe452850b	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xe712cc0b	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0x0e298a59	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x12091f79	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x24e3a6db	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x278df277	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x2eebda4b	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x3ad4714f	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x3ea2a6fb	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x4aa78758	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x56495141	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x5c74315e	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x62da3de0	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x72b5fe83	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x791f98a2	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x7be4d919	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xb123087a	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd3bfc237	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xde40c8b0	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x0cf112a2	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x00b3ed17	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x023347de	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x0b76454f	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x11e1f72f	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x163e59e8	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x1d2be057	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x1f216d2c	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x267ef6c5	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x4cea265b	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x4e2b2da9	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x58a151ae	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x6baad18c	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x9e154b8c	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xb247864f	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xcb4eb768	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xcc424807	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xd4393a0a	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xdb29ea5b	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x3464c59d	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x44a69a55	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x73110423	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xfb0d068f	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x03e8a132	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x0abc7e3e	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x1b8b8ff4	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x308a1c73	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3f96a061	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4ea837f0	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x57958aea	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9d6df8cc	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa8120ff0	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcd075f86	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xce3e1c39	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd28ceb7a	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd927e2d1	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd9391a94	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xddbd66d3	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xed73b629	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf3b4d4ae	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x5a0a61f5	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xa9790bde	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xab568104	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xf55def51	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x00e7825e	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0c43b437	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0cac8429	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x13333ff9	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x14558fcc	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1497885b	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1e2cc460	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x21aab3f3	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x23f18be8	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x25ad90ac	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x264daa84	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2736161e	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2d3d03b6	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3261e150	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x33441320	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3756a818	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3a38e1d0	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3a7e2875	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3b28be7c	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3d8e8fe9	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x45303951	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4a9a7a0d	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4d3156fa	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x53434385	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x546dc4b4	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5605df6d	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x570c8521	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x603546c0	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x65aa4443	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6a18dc58	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6fbd19fe	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x747fc17e	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7503168d	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7c984a1a	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x832011cb	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x882397df	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8b6bb10c	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x91aca217	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x92c4b749	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x99adf8f5	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x99c1dda2	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9c2f6b05	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa1e719bc	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa6f616ba	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa81457e3	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1a8109	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb0b1c412	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb1167349	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb3e9ffb3	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb416e56e	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb43c41e9	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb4f7843b	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb91e5e45	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb96ff7f4	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbaee3719	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbe30e77a	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc0fea649	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc31fbe37	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc3e32d59	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc95a9db2	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcbde17a4	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xccbeb51a	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xccfcb596	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd0a90284	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd70351cc	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd917bba6	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xda0edb8d	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe0335943	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe095483a	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe1925d8f	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xeedc2368	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf0ef9ea5	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf129dcb5	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf1c57025	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf5ee8803	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf8733f23	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf967e0b2	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfb39bef3	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfeac72c3	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xffe24b30	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0xbc089f1e	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0x9ce6f94e	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x617a215a	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x0b8d7b15	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x5d22fd33	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x62c374a5	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x66c478a7	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x6b0f4f38	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x7cc5feed	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x8e247657	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x94de8e39	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x9bdc399d	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xf5a6b82e	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0xc7c99ed3	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x033a0c5e	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x51e11dbf	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x66dd48ef	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xd5259c9e	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x69aab6a1	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xd20e9d53	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x1e4e35b1	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x35de0616	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x3f0ea1da	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xb8b8d129	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xc77173ed	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xd06bebfe	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xebf7e349	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0xd9e57bf9	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0xf87bbe1c	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x467e896c	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xd75d601d	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xe0857a35	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xf867b5a7	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x38699250	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x416ad84e	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x55384806	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x581e7197	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xb7191952	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xe816847e	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xf024ed39	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xf152d599	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xfdd233ec	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x6f637c46	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xada673f7	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x74a58334	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x76b57018	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x8841d39b	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x0d91d9ec	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x21d0ad4a	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x295d41e0	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x2b5a1fae	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x2e428d06	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x3c922c8d	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x63249a95	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x6a26b1a2	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x6d58b99f	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x6e3efd08	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x716adf9e	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x77013d61	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x8405e6b4	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x8a725de0	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x9b156d2b	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xa2dd1a51	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xa6d24b45	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x11db3352	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x15120981	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x1f381d8e	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x76448d53	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x8f60d113	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xb6f8be98	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xda8aec06	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x04ada63b	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xe0d73d21	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xf264e030	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0x0e6b39d1	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x25faefe6	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x4022e57e	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x87bc7a43	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x20c88aad	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x4fa0e1bf	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xa0001649	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb2553c4e	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xe38d09b0	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xe6381b5b	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x21e5403d	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x51c3a204	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xe2fb1c0a	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x6dc39b8e	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x74e166c6	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x108bc7ef	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x161d1417	xt_compat_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x2c9b2540	xt_compat_match_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x306c808d	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3a1a1f84	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3ad5cde0	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3bbe7b3a	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x4a121873	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5a2f74ab	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5cf81f81	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5f82f1f7	xt_compat_flush_offsets
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x691a6d69	xt_compat_calc_jump
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x73cee41e	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8e44c016	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xb471c669	xt_compat_match_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc200b493	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc8a5a9b4	xt_compat_target_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xcb27b72d	xt_compat_target_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xccaebfa1	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe0b4971b	xt_compat_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe5d7cde3	xt_compat_match_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xec24fd82	xt_compat_add_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xecb73661	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xf31fd269	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xf3836110	xt_compat_target_from_user
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x4c32c169	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xb7459345	xt_rateest_put
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x14ef8334	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0xb9bfe74a	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0xd7deb309	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x41108243	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x6eaba6a0	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0xf59ce69f	nci_uart_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x0e8f6238	ovs_vport_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x10217d38	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x2bf0e269	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x36a96530	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x76381fef	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x8daab7c5	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xa362f2b9	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xd6e9e6ba	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xd7f87a21	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x05762f6c	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x1e16e792	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x308ff5e5	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x4434b724	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x49409b64	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x58457511	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x59efbe21	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0x68f53351	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x706b0efb	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x7a03786f	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x7bc62829	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x845c7cd6	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x86dff261	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0x8b04cc86	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0xac3db34b	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0xaf3abeba	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xcd487104	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0xd436f8ea	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0xdc3d1368	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0xde673448	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0xeaef569d	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0xf193127f	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0xf3821fcf	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0xf4b196b2	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0xf8fac400	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x944ae3b8	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xcb17c69f	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x46274090	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb9cb41dd	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xe2c4b5e1	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0135ab7d	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x02963132	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x039e18ea	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0473e023	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x067243e1	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x06c0fa49	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x09473932	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0a9a2936	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0ba81cc9	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0be3c4a5	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0bfa2267	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c7f5a3f	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0ec773b5	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x119ccef7	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x11efa72e	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x12a54678	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x14196661	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x17e072ff	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1c8be5bf	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1d0aaafb	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1e6bc598	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1f2a9970	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1f42dedd	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2235ee0c	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x26443446	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x26d23c1e	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2737a6f8	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x27619378	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x276b756d	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2873cf16	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x29bc9056	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c6a5c27	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2d47c9c6	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x33e709e8	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x35e5ba75	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x37a3b0e4	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x38b16f64	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3a8dfe62	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3a8f50ee	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3b72b245	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3bd0552e	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c2b12a3	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c46572e	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3cb34612	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3e9274b1	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f560c10	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x40fee90d	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x429866ff	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4636f899	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x46eb534b	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4831d012	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x48cd7994	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x498cbace	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4b97673c	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4d11462a	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4dd3161b	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4f7ffc16	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x505acc5d	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x50974303	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x510b2d3d	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x52749154	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5393323f	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53d85ef7	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x546cca7b	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5491fc24	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5a30b519	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b130be2	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b3efcc7	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5bc5d7dd	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5cc6f66f	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5f70e786	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5f9f9356	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6280fad7	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x630654e4	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6413083a	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x64ca3eab	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x69af3e7a	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6ba0fc3c	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6ca3e19d	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6ea0ffff	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6f0926bc	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6fb846cd	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x702ac044	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x717ec341	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x74505013	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x74ae6635	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x750d246c	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x75e27f27	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7722e167	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x776da7fb	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x78c8d2bd	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x793094a9	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7c3a5ab2	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7c4e2ab0	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7c5a422c	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x829acb9a	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x83279e6b	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x852b6c15	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x86e8c0a5	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x87056257	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x89b58c1b	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8a8a5679	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8c43e4e2	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8d413e24	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8dce9bdb	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8e381ca3	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8e50b828	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8f4520d8	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x90776e0d	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x92a7cf39	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x92f6b08c	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x964e0f59	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x986417e2	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9921291c	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x99d89b6d	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9a4949f6	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9a58e7ba	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b6d2626	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9c6329bb	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9cf80410	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ee88fff	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa089f652	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa0de995c	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa28e7fd6	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa2b66b53	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa4542183	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa50a2847	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa7a28ed1	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa7bab75d	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa9b08a34	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa531944	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa7aac1e	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaaf83b0a	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xabaac56c	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xabae9cd9	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xac2a5431	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xacf044ce	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xacf527af	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xad56dd52	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaff481a0	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb0b211c2	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb6b325d0	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb6e6ed7f	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb6f54fee	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb788bc4b	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb83d5d67	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb894d2a3	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb8dcca71	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb9a237b0	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb9ff9cb3	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xba338fbb	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbc20dace	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbd4506cc	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbe896426	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc02cdc2c	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc463e886	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc513806c	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc7010d16	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc7d749bf	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc940ec1c	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcc7262ab	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcd246a96	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcebcebda	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd14c8eb9	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd14ef264	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd17835dc	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd2a2bbd7	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd2e72db3	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd44ebce5	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd53dec04	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd8afef12	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdb3d94ff	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdd144a24	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe0792b66	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe10425e0	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe12ff222	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe18ede21	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1aefa4f	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe248c86b	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe634fccd	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe6ca9c77	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe9b1e1aa	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xea4b2f3b	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeb6c1f84	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xebf3fca9	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xed378116	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xee8c244d	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf2b49304	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf442546a	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf4e0ba9e	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf51d0323	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf55db780	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf6113b5e	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf80d4c02	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf81aa785	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfac5de62	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfe41eb3d	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfe7c702c	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xffd1e0db	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0d2fb6dd	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15bdae95	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2a45fe67	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x3a4b8594	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x595b559f	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x59d943c8	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x69ca570b	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x6b34f2bb	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x6d72ffdd	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x80bacbe6	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x970b77bc	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xb9897a79	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd0f154bf	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xeddd614a	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf0b58738	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x06421d63	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x487fc6e9	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x4ce5747d	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x5511ee00	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x70e2578c	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x77094114	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x7f551198	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x87594bc6	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x8a17076d	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xb86b690f	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xc17a94c5	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xdc2096ea	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xed0011b2	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x09d630f6	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x465ec787	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x4e3959a8	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x56032672	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x6b64eed0	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x6f29126b	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x7702fdff	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x8f257aae	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xa59f7c8f	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xacbaad5a	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xbded1c25	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xc384209a	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd5121c7e	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x47c24478	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x5c614075	ipcomp_destroy
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x912f1ae0	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xfdacead5	ipcomp_input
++EXPORT_SYMBOL_GPL sound/ac97_bus 0xf276c8f7	snd_ac97_reset
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x1be218dd	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0xd4bb070e	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/core/snd 0x1d0ad32d	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL sound/core/snd 0x48490371	snd_device_disconnect
++EXPORT_SYMBOL_GPL sound/core/snd 0x92d0069b	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd 0xc4c2c725	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd 0xdd40339f	snd_device_initialize
++EXPORT_SYMBOL_GPL sound/core/snd 0xee0f5de5	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL sound/core/snd 0xfe8b28f9	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0x2ad21ffc	snd_compress_new
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0x8eb3e674	snd_compress_deregister
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0xf6327eaf	snd_compress_register
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x1b447983	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x528bf021	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x68cd52cd	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x6e98b682	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x7ecdbd56	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa2ee4ffa	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa4dc07eb	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xcf67293b	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xeea95e1f	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x2a6ac9b7	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x2b67c75f	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x2d4c36bf	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x57fdce11	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x7c200c13	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x9657f8ec	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xc01c2492	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xdacb636d	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xe01b67a9	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xe88cc003	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xed127e35	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x20b45a23	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x2d25d621	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x84715bf5	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xae859e86	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xd0947e90	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xd9ca5341	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xe2404fbb	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x0727dd8d	snd_hda_ext_driver_register
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x122f37d4	snd_hdac_ext_link_set_stream_id
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x196e3e41	snd_hdac_ext_link_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x1ce378b5	snd_hdac_ext_stream_get_spbmaxfifo
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x216e5dad	snd_hdac_ext_bus_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x24940094	snd_hdac_ext_bus_device_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x38db0b5c	snd_hdac_ext_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x438da405	snd_hdac_ext_stream_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x4486cb7e	snd_hdac_link_free_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x4b211d32	snd_hdac_ext_stream_decouple
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x57673f93	snd_hda_ext_driver_unregister
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x60a51894	snd_hdac_ext_link_clear_stream_id
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x63e21cae	snd_hdac_ext_bus_device_exit
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x65e0fef2	snd_hdac_ext_stream_spbcap_enable
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x6c975233	snd_hdac_ext_stream_release
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x78664366	snd_hdac_ext_bus_parse_capabilities
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x810c0b62	snd_hdac_ext_link_stream_start
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x89e4c439	snd_hdac_ext_bus_link_power_up
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x8aa5b678	snd_hdac_ext_link_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x984cb2ab	snd_hdac_ext_bus_ppcap_int_enable
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x9ae3e876	snd_hdac_stream_free_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xa733390d	snd_hdac_ext_stream_set_spib
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xad010719	snd_hdac_ext_stream_init_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xb49ccff3	snd_hdac_ext_bus_ppcap_enable
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xc1781099	snd_hdac_ext_bus_get_link
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd032ab49	snd_hdac_ext_bus_link_power_down
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd6213aeb	snd_hdac_ext_link_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xddd39355	snd_hdac_ext_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xe7a7404f	snd_hdac_ext_stop_streams
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xec58d8c6	snd_hdac_ext_bus_link_power_down_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xf4bc6914	snd_hdac_ext_bus_device_remove
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xfae2ddc5	snd_hdac_ext_bus_get_ml_capabilities
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x03afc92e	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0410c355	snd_hdac_i915_init_bpo
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x05a3ef09	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0a985156	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x14871f3f	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x17288330	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x189474c0	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x21c82a54	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x274d803b	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x282b729d	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2fdf9f70	snd_hdac_i915_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x32e76e3d	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x37510c87	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3d692a2a	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x42029d93	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x46a19c21	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x47960252	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x499499d9	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x49d7d139	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4c8eef75	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4e040cd4	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4f52599f	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4fb181ec	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5230df36	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5434bf41	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x54596642	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5484b964	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5591d5db	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x575bfc3a	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x580d71e1	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x61fba5b1	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6587d448	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x664db731	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x676bc344	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6950c1d3	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6997af31	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6f81210f	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x73187668	snd_hdac_i915_register_notifier
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x750d357e	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x79c68183	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7da5f886	snd_hdac_i915_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x800f31aa	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x80499d6a	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x82ec0e2d	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8884fc2e	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8eb87ad0	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x90756ff9	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x92a45ea0	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x95b2561c	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x96959122	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x98f2227a	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x99c697a1	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9d21e7c2	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9d3cd08a	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa07d899d	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xadcb1916	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb0be40c1	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb1bd4dea	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb933eb2a	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbbaff0d0	snd_hdac_get_display_clk
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbbd14aec	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbd4c7a99	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc1f65eb3	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc304526b	snd_hdac_set_codec_wakeup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc66069fd	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd5b69ce8	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd9ef5c38	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd8395ed	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdfd11752	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe707ca83	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe76111a8	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe97c522d	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe9d2a115	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xed396a6e	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf4efcda2	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf6e468e5	snd_hdac_display_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfc407394	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfc8a0cd7	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x116bb0f5	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x1f5376a9	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x50c61c3b	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x54528aeb	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xbf7878a9	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xf9c67db7	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x03758530	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0402db5a	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x078a0582	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0960322f	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0a35d909	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0ae59ff9	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0b627f50	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0ee05c29	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x12c96f26	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x15311336	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x15766e76	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x16e072f6	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1da83ae3	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1ddbce6d	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x20ebdd79	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x210ee3ad	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2192ecf1	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x230614ee	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x239df4ec	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x23d5feaa	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2495dbc3	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2797a60a	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2a446593	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3a9abbb4	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3aa9c768	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3bba1b0f	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3be3f28d	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x40bffa87	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x41b9dfdb	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x430ec919	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x44a4896b	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x460eea9b	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x471bda2e	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x47230e2e	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x49e7180a	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x49f1b435	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4ec01298	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x52f20ae9	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x53072004	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x543b1428	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x54de78a1	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x580f6690	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x593132a8	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5e48ecba	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5e6df704	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6042c285	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x614c8553	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6175615c	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x61dd334d	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x64100aae	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x651f1fc4	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x666d6da2	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x66805928	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x67fae8ed	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6d06032b	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6d24f2ec	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x765d94aa	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x767ad33f	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x77ace9fc	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x78532b1f	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7aad5fc5	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7bbc7547	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7bc9e151	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8484273b	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x856d159c	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x86970033	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8724e738	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x89c82bee	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8b6428ac	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8baea060	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x90ea9a8a	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x92653b97	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x96108037	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x96e1c706	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a31680a	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9bc14e74	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa30b6f57	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa68aa8c0	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa6f82649	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa80f155d	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaae8be1b	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xabc7179e	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaf5c26a4	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb1163556	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb246a23f	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb4cc19b0	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb7dd9a51	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb90c2401	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbcbc04f7	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbea6187f	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc0b5d1a4	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc468795b	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc81d647d	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc8739cbd	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcc94427a	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xce99ae46	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xced1a779	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcf5a6e18	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd10f5cab	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd1c86d69	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd2f8b42a	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd3720694	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdaef49ac	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdb449f19	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdd977eab	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xddbac971	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe77d3076	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe98b87f7	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeb628ab9	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xebbdc053	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xedb0b7d8	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeeae47fa	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xef0f8512	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xef619cd5	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf2c37352	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf5310424	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf652174b	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf85d3946	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf8e0f439	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf9587702	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf966eeff	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf989f56c	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfb9d8e9d	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfbee0b8e	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x0bd69fcb	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x1602b7c0	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x1d7e7c31	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x1dece41c	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x23635c0c	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x32a0bb11	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x3cb8f321	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x44d39d23	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x45e21ebc	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x51bbb4fa	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x587c3a01	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x683faef6	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xa7e9d413	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xabbc2c0b	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xad9f6ce7	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xd7a5d169	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe57fbbbd	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xeb3fa9ab	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xf3882f47	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xf3da45c7	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xf6b14337	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xd9ee7202	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xe6958cdc	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xba7cbcc8	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xe7ffd0d3	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x325349fd	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7b2a039d	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xddaa1776	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x54d2fefc	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x7f8aae09	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98090 0x04028274	max98090_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x0d12f399	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x668cf2d6	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x9a9c330d	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xbe6b6cd0	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x70617a04	rl6231_get_clk_info
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x7f68b24d	rl6231_pll_calc
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x8d7fa148	rl6231_get_pre_div
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0xdba4502f	rl6231_calc_dmic_clk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6347a 0xa7aa810f	rl6347a_hw_write
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6347a 0xade4bf4c	rl6347a_hw_read
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt286 0x5c7daabc	rt286_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5640 0x4632d1ce	rt5640_dmic_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0x5a788a36	rt5645_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0xb384d870	rt5645_set_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0x4398caea	rt5670_jack_resume
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0x83b60f35	rt5670_set_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0xc81ffd7f	rt5670_jack_suspend
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0xc9915e35	rt5670_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x5369aaad	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x9965ebc5	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xc108101b	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xc8e061b3	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xf5f3358a	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0x18474e6a	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x131a5db4	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x7baf56bb	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x0f618a55	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xb55f2802	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0x4f308843	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x0545439f	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x0d709f06	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x8bb3a092	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x8c053d4e	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0xdde99d9a	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0x324c0cab	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x52088869	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x8d8602b7	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/snd-soc-sst-mfld-platform 0x1ecbaa9d	sst_register_dsp
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/snd-soc-sst-mfld-platform 0xc00b934c	sst_unregister_dsp
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x2095a146	sst_configure_runtime_pm
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x25bfe21b	sst_alloc_drv_context
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x82d98b8c	intel_sst_pm
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x882d4c66	sst_context_cleanup
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x94d5f1dc	sst_context_init
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0xab14edd5	relocate_imr_addr_mrfld
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0x0e40f7af	sst_byt_dsp_wait_for_ready
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0x70a1ff93	sst_byt_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0xded07a41	sst_byt_dsp_suspend_late
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0xe10632dd	sst_byt_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0xe2da224a	sst_byt_dsp_boot
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x0066abcb	sst_dsp_ipc_msg_tx
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x01ea14aa	sst_dsp_dump
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x0e78b57f	sst_block_alloc_scratch
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x0ea91f10	sst_fw_reload
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x135dbb6b	sst_module_runtime_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x176d8473	sst_dsp_shim_write64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x17b6509f	sst_dsp_outbox_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x17bd680e	sst_dsp_dma_put_channel
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x1a3ac2d1	sst_dsp_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x1b5e8b82	sst_shim32_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x281e91ad	sst_dsp_reset
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x32963ec1	sst_block_free_scratch
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x3adeea8d	sst_dsp_shim_update_bits64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x3b46697e	sst_module_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x3fe87dc4	sst_dsp_dma_copyto
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x43acb439	sst_dsp_shim_write64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x48d121ad	sst_module_runtime_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4a045773	sst_shim32_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x5138f48e	sst_memcpy_toio_32
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x515b7310	sst_memcpy_fromio_32
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x526444ec	sst_dsp_shim_update_bits64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x5c1e219a	sst_dsp_dma_get_channel
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x5d81758f	sst_dsp_shim_update_bits_forced
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x61bc6499	sst_dsp_wake
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x6c5de75b	sst_dsp_ipc_msg_rx
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x6e1fda1b	sst_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x74687e39	sst_dsp_sleep
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x76821c79	sst_module_runtime_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x7a8cb304	sst_fw_free_all
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x7cd15b5a	sst_module_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x7ce77ba8	sst_dsp_mailbox_init
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x7e7296d3	sst_dsp_shim_write_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x80079304	sst_module_get_from_id
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x8cb92017	sst_dsp_register_poll
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x925236ca	sst_module_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x9468ff82	sst_dsp_shim_read64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x94f758c4	sst_mem_block_unregister_all
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x96962854	sst_dsp_shim_update_bits_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x9d4c422a	sst_dsp_shim_read_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x9eb8ed5e	sst_module_runtime_save
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xaddd0bf5	sst_dsp_dma_copyfrom
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb18fd74f	sst_module_runtime_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb37020a6	sst_dsp_shim_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb54b597f	sst_dsp_shim_update_bits_forced_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb6125be7	sst_dsp_outbox_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb7d44277	sst_fw_unload
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbad661c7	sst_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbcec5387	sst_shim32_read64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbe3aadf3	sst_module_runtime_restore
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xc4d5b903	sst_dsp_stall
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xc863e2f9	sst_dsp_shim_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xc879d115	sst_module_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xc897025a	sst_fw_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xcf76b4ba	sst_dsp_shim_update_bits
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xcf935374	sst_fw_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xd009edf8	sst_dsp_inbox_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xd61dc2a5	sst_mem_block_register
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xd9a2c94c	sst_shim32_write64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xdc62e86a	sst_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xde07889c	sst_dsp_inbox_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xe259ff81	sst_dsp_get_offset
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf4230a4c	sst_dsp_shim_read64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf78d0a44	sst_dsp_boot
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xff8c0f96	sst_module_runtime_get_from_id
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x2feca923	sst_ipc_init
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x73a89794	sst_ipc_tx_message_nowait
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x7a79d2bb	sst_ipc_drop_all
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x7f12fba1	sst_ipc_reply_find_msg
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0xcd1f45f8	sst_ipc_fini
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0xea50dfa4	sst_ipc_tx_msg_reply_complete
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0xea88ab17	sst_ipc_tx_message_wait
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0x5117d628	sst_hsw_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0x98bc44ca	sst_hsw_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0xd1f69f64	sst_hsw_device_set_config
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x01279a63	skl_ipc_set_large_config
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x031e2a53	skl_ipc_bind_unbind
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x149b8a2c	is_skl_dsp_running
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x20ffb436	skl_ipc_create_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x2bf4d895	skl_dsp_wake
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x308a9880	skl_ipc_set_dx
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x4690da39	skl_sst_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x5535b9d9	skl_ipc_save_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xbaee1267	skl_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xc689e8e7	skl_ipc_delete_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xc7fa501f	skl_sst_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xd6c2eff3	skl_ipc_set_pipeline_state
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xea828b42	skl_ipc_restore_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xf4cfb899	skl_dsp_sleep
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xff84e11f	skl_ipc_init_instance
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0362e190	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x038aea08	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x05569a43	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0794568a	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x079e36f4	snd_soc_tplg_widget_bind_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0d0700d3	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0dbda330	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0dffff6d	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0e6ed7fe	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x117032fb	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x14cb9fb9	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x14da7985	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1624c4fd	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1630f473	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x17fe1ad0	snd_soc_new_compress
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x18526a8e	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x191d44bb	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1949cf66	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1958b8ea	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1b4cf75d	snd_soc_resume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x234a954d	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x26ec9dca	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2b113d73	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2fc22407	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2fdc1acd	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x31c012e9	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x31cc7d08	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x326978ef	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x330d54a0	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x33f0702a	snd_soc_tplg_widget_remove
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x357eef99	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x35867318	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x375968c7	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3849ea59	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x39111c88	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3d36cd3a	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3f9ab5a8	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x422d18bd	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x446802f7	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x44f8f324	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4553d28f	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x48954f6a	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4afd5bce	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4c11fbb6	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5016e6dd	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x511a0eca	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5167a419	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x517413ff	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x51ff62c5	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5284da7b	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5603b4a0	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x58ffec81	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5b0d4608	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5b9f39bd	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x60c7420e	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x60f30195	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6282e924	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6353f274	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x63bd4fb2	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6595d01b	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6778cd8c	snd_soc_tplg_widget_remove_all
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6886f74e	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6b4bbed9	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6bf0a15b	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6d9f793d	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x70858d74	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x71f267cb	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x75218ee4	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x75b493e1	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x75be8938	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e2e10d0	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7f881f6d	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x81878d41	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x83dc5b09	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8401107f	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x86d9d010	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x88fb3111	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8b2ae875	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8eba4b13	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8ebd6591	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8fc43b92	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8fdd7452	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x912de288	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9183777e	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x931753f7	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x98844545	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x98c291e1	snd_soc_tplg_component_remove
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9a05d823	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9aaab646	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9c51f42a	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9c5673f5	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9d0f7a4f	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa0d3f30a	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa3bba03d	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa489afa3	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa8c1320d	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa9b9acf2	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xaa69ac29	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xab43abe4	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xaf58aecd	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb001d40e	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb1791b87	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb1850240	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb19939cd	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb2209f99	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb466444b	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb7c17d96	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb91e4f77	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb9b9b15b	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbcc2dea6	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbdb501b9	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc25f442a	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc5905bf3	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc65079c3	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xca06f1c5	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xccc16ed2	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcd92f2be	snd_soc_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xce8ab522	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd1d330cc	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd265dbff	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd286edb8	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd5d5d7c7	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd8548f29	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xda568c07	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdaf70109	snd_soc_component_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdb48f5a7	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdb57bc67	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdcc32556	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdd0571f4	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xde4e771c	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe07d835f	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe474d260	snd_soc_component_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe5bd35ec	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe79375bd	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe85621e0	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb5c8de7	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xee62aa5d	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xef33f46c	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf0e993e9	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf175cf9e	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf24ca204	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf37e60cc	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf3cd1952	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf4421ef9	snd_soc_tplg_component_load
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfa824d26	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfbdfa0c7	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfc79aa79	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfceaf5a4	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfd6cb18a	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfeae1e1c	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xff1d310c	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xff238202	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xffc30e1b	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xffd7eac0	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x0417d4f3	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x0817a847	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x0d5cc3c6	line6_version_request_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x16b1658c	line6_suspend
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x462be3ec	line6_send_sysex_message
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x5f3ee5f5	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x671ef022	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x829461c4	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x84cfdab9	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x87ed69a2	line6_read_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x93f20ef5	line6_read_serial_number
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xcb3790f4	line6_pcm_release
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xd64d9642	line6_pcm_acquire
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xee0367f6	line6_write_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xf2bb90b7	line6_init_midi
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x08003b2f	i915_bpo_gpu_turbo_disable
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x0d97d346	i915_bpo_gpu_raise
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x358a54ae	i915_bpo_gpu_busy
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x451432c2	i915_bpo_gpu_lower
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x7d4de94c	i915_bpo_read_mch_val
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x00832f14	rsi_config_wowlan
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x05b6e0dd	ven_rsi_91x_init
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x0748b463	rsi_default_ps_params
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x0a3486cd	ven_rsi_read_pkt
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x1e678bb2	dot11_pkt_type
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x1e6ea350	ven_rsi_91x_deinit
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x3e83544c	rsi_hal_device_init
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x40801a54	rsi_send_rx_filter_frame
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x437447f4	rsi_hex_dump
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x45ca198c	ven_rsi_dbg
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x86ee27d6	rsi_init_dbgfs
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x8e4b9d01	rsi_hci_recv_pkt
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xa54100aa	rsi_send_rfmode_frame
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xbeb5d8f5	rsi_hci_attach
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xd3025481	ven_rsi_mac80211_detach
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xd7fca56b	rsi_hci_detach
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xe20fc41c	rsi_deregister_bt
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xe777f54d	rsi_remove_dbgfs
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x3fe35aea	irq_bypass_unregister_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x418873cc	irq_bypass_register_producer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x888c5be5	irq_bypass_register_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0xf6e772c3	irq_bypass_unregister_producer
++EXPORT_SYMBOL_GPL vmlinux 0x0034f3b6	xen_has_pv_nic_devices
++EXPORT_SYMBOL_GPL vmlinux 0x00571304	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x005bff98	clk_hw_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x005d0832	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x006098b1	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00ea1b01	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x00ecd632	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x00f884d9	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x00fc947d	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x01091c47	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0x0109d998	gdt_page
++EXPORT_SYMBOL_GPL vmlinux 0x010f8e53	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x0120dd93	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x014079f7	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0x01492a60	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x0172f2ae	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0x0173e5c4	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x01848a8e	local_apic_timer_c2_ok
++EXPORT_SYMBOL_GPL vmlinux 0x018cc84d	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x01927ba2	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0x019514eb	ata_acpi_stm
++EXPORT_SYMBOL_GPL vmlinux 0x01aa63ad	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x01acc214	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x01b11ac3	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x01c676ce	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0x01c7fae3	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x02022aa8	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x0214fd57	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x022b5458	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x0232bc9e	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x023a44df	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x026211e2	memory_failure_queue
++EXPORT_SYMBOL_GPL vmlinux 0x029084c7	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x0294cf60	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0x029b5a65	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0x029c93c2	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x02cce250	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x02ef7f7b	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x02f26963	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x0314b640	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0x031c3436	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x03224582	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x03468250	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x0351e2d3	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x035413f8	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x03614dfb	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x0365b728	xenbus_watch_path
++EXPORT_SYMBOL_GPL vmlinux 0x036d0d60	acpi_match_device
++EXPORT_SYMBOL_GPL vmlinux 0x036d404c	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0x037eea6b	gpiochip_remove_pin_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x0391af81	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0x039bf30e	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x039ec550	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03ba631b	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0x03bf7cdb	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x03bfbc98	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x03deaa15	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x03ee48af	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x03fbedd5	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0x0402cbbf	preempt_notifier_inc
++EXPORT_SYMBOL_GPL vmlinux 0x042a31a8	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x0434822e	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x043607da	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0x043b935f	__tracepoint_io_page_fault
++EXPORT_SYMBOL_GPL vmlinux 0x04607da2	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x04661819	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x0469dfea	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x0485655f	amd_get_nodes_per_socket
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x04a3baa9	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04a8c179	rio_mport_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x04c1501f	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x04c3f2c1	gnttab_empty_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04c6ee32	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0x04cd5045	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x04df8fbc	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0x04e98501	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x04ecfb5c	set_memory_wt
++EXPORT_SYMBOL_GPL vmlinux 0x04f0eba8	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x04f5c52c	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x050d035d	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x0518149d	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x05235ee2	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x053494cb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0x0537de4e	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x05388cb2	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x055fedfe	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x0560d155	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x056d5294	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x0595c0e2	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x05c4831d	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x05e2bd6b	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x05ec3e2a	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x05ed7059	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x063bc01b	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x06601a78	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0x0682075d	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x0684537f	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x068e148b	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x0693f836	acpi_dev_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x06d549e6	pinctrl_free_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x06dbfb53	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x06f5d89c	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x0734af95	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x0740d399	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x074f0b84	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0x07524009	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0x075a8f6d	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0x07602b7f	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x077eedf8	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x0788b634	irqd_cfg
++EXPORT_SYMBOL_GPL vmlinux 0x07b1f734	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07f04269	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x07f4fb9d	xen_swiotlb_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x0815d487	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x082f0ab7	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x0839830c	nd_blk_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x086b1f07	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0x0874c965	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x08809133	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x088b98af	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0x088bfa7e	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x08a7592f	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x08adee76	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x08aecfb8	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x08bc0870	compat_put_timespec
++EXPORT_SYMBOL_GPL vmlinux 0x08c7e3f5	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x08dba64c	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x08f28603	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x08f36b41	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0x08fb916f	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x090caadb	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x090dfaf9	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x093d0151	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0948896a	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x094f7083	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x095a27a9	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x0963cdcf	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0x0989127e	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x0a07ce5f	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0x0a4fde00	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x0a63b2d2	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x0a77076c	xen_swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0a8d21ae	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0x0a9a535c	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x0ac2308e	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x0ac6c7ed	xen_register_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x0acc4127	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b30be87	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0b30e80c	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x0b52e502	apei_resources_add
++EXPORT_SYMBOL_GPL vmlinux 0x0b654b1c	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x0b7e1416	xenbus_unmap_ring_vfree
++EXPORT_SYMBOL_GPL vmlinux 0x0b8b22d4	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x0b9e3096	fpu__save
++EXPORT_SYMBOL_GPL vmlinux 0x0ba3a643	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0x0bb8037b	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x0bb9e76f	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x0bc649c6	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x0bd58dad	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x0be189bb	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x0be25a17	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0x0bf7a07a	__xenbus_register_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0bfdee9c	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x0bfe9788	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c227a4c	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0c27fcc1	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c3862bb	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x0c45d2be	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x0c4d62bf	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0x0c74af44	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0x0c805f93	clflush_cache_range
++EXPORT_SYMBOL_GPL vmlinux 0x0c80e3fe	efivar_init
++EXPORT_SYMBOL_GPL vmlinux 0x0c94594f	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0x0c98d2b3	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x0cb1b8cf	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0ce37e0a	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0x0cfb44da	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0d1eea68	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x0d327303	rio_release_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d4f78c0	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0x0d63b13f	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0x0d6aa401	pinctrl_utils_dt_free_map
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d668a	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0dba3445	rio_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1b38	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0deb204b	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0x0df925f6	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0x0e007edf	xen_evtchn_nr_channels
++EXPORT_SYMBOL_GPL vmlinux 0x0e0b1e49	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0x0e0b8b0c	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x0e13cb4d	apei_resources_release
++EXPORT_SYMBOL_GPL vmlinux 0x0e4cea6e	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0x0e5f76c2	set_pages_array_wt
++EXPORT_SYMBOL_GPL vmlinux 0x0e6353d8	device_create
++EXPORT_SYMBOL_GPL vmlinux 0x0e6daf39	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0x0e7484f3	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0x0e762d2d	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0x0ea41f64	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x0eb1acc9	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x0ebab034	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x0ebcfb64	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x0ec58c80	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0x0ecf823a	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x0f012044	__tracepoint_detach_device_from_domain
++EXPORT_SYMBOL_GPL vmlinux 0x0f036812	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0x0f170383	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x0f21a845	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0x0f2d7d87	mce_unregister_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0x0f312e86	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f33d080	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x0f428a8c	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0x0f488886	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0x0f4efae2	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x0f5bd3ad	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0f6763b7	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0x0f6ecdc5	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f86b96e	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0x0f89d546	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x0fa138de	xen_hvm_need_lapic
++EXPORT_SYMBOL_GPL vmlinux 0x0fcc1969	copy_from_user_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x0fcca4c7	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x0fcea368	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0x0fe2d570	xenbus_directory
++EXPORT_SYMBOL_GPL vmlinux 0x0ff29128	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x102589df	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x103a92ec	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x1050fe7a	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0x1068e204	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x107dad8e	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0x1080f548	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x109fc271	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0x10daff5d	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x110106c1	cper_severity_to_aer
++EXPORT_SYMBOL_GPL vmlinux 0x1160e87f	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x116ce656	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x117c7305	hwpoison_filter_dev_major
++EXPORT_SYMBOL_GPL vmlinux 0x118f4043	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0x1196f921	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x11aa102e	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0x11caddc7	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x11da93e5	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0x11e57569	xen_swiotlb_sync_single_for_device
++EXPORT_SYMBOL_GPL vmlinux 0x11f283ff	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x124edcac	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x1268c8ab	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x127c0bbe	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0x1289d584	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x12cf637a	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0x12d0f0b5	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x12e6d13a	rio_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x12ea3c14	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x13053ba4	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0x130a7f6e	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x130bd388	check_tsc_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x130de01d	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x133fa60e	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x13669fae	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x13711956	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0x138348e2	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x138aff76	gnttab_init
++EXPORT_SYMBOL_GPL vmlinux 0x13a8e067	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0x13ad647f	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x13b89dee	pinctrl_request_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x13c7ca89	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x13ce87e8	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0x13ec8bed	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0x13f51fc3	ms_hyperv
++EXPORT_SYMBOL_GPL vmlinux 0x141dfe84	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x142807d2	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0x1450cc70	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x146a6747	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x1477f3e9	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0x149a7d2f	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0x149de3de	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x149f09ad	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0x14a1c3c8	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x14a2d0c7	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0x14a7c565	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x14bbc02e	of_css
++EXPORT_SYMBOL_GPL vmlinux 0x14ead387	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x14f45cdf	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0x15010e1f	arbitrary_virt_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0x15398237	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x1559a7c6	nvdimm_blk_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x155dfdcb	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0x157e8ff0	xen_remap_domain_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x15b0606e	e820_any_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x15dab540	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x15e4b4b8	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x15f93bde	pci_msi_create_irq_domain
++EXPORT_SYMBOL_GPL vmlinux 0x15faa8f7	acpi_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x160d5646	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x160dc494	nd_cmd_out_size
++EXPORT_SYMBOL_GPL vmlinux 0x16237389	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0x162bf367	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x164300fa	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x16555ec7	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x16769053	md_run
++EXPORT_SYMBOL_GPL vmlinux 0x16947339	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0x169f2f5b	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x16ca6280	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x16e215c6	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x1709d3ba	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x171e1025	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x1722cfe3	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x1723f1e2	__online_page_set_limits
++EXPORT_SYMBOL_GPL vmlinux 0x173b894d	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x174b207a	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0x17614bf3	apei_resources_sub
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x17994d70	memhp_auto_online
++EXPORT_SYMBOL_GPL vmlinux 0x179a5991	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x17a8360c	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0x17cd81cf	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x17dea724	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x17e1a3ac	pinctrl_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x17eb45ce	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x17f2b4fb	print_context_stack_bp
++EXPORT_SYMBOL_GPL vmlinux 0x17fcf775	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0x1809c905	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x1829b9ed	hwpoison_filter_memcg
++EXPORT_SYMBOL_GPL vmlinux 0x183425ad	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x18582826	amd_pmu_disable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x185ee5dc	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x1898ef45	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x189a534b	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0x18a9cf07	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x18adca70	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x18c57f5a	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0x18dcc4a4	gnttab_unmap_refs
++EXPORT_SYMBOL_GPL vmlinux 0x18f5e50e	arch_apei_enable_cmcff
++EXPORT_SYMBOL_GPL vmlinux 0x18f83fab	gnttab_grant_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0x19119803	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x19129cec	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0x192e8fd3	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0x1930003a	hwpoison_filter
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x196614ce	hw_breakpoint_restore
++EXPORT_SYMBOL_GPL vmlinux 0x198a1c64	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x199106ff	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19e08e01	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x19fb015b	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x1a0520ca	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x1a2b4430	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0x1a42b68e	rio_mport_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x1a555277	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1a6b4536	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x1a726fe5	pinctrl_select_state
++EXPORT_SYMBOL_GPL vmlinux 0x1a84333f	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x1a8db718	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1a9712ff	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x1a995dc1	rio_mport_get_efb
++EXPORT_SYMBOL_GPL vmlinux 0x1a9cb062	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x1aa1a1c1	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1ad78a83	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1aeb9071	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x1aec3e03	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x1b0bb5ca	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1b38b3c6	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0x1b459352	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1b61bb96	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x1b8822d8	pinctrl_gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x1b94a4fc	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1ba50043	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x1badf138	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0x1bc5eebe	pinctrl_gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x1bddfecf	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1bde66af	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x1c0c2485	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x1c14e3f7	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x1c311cfb	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x1c4517ab	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c58b870	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c5ff742	clk_get_phase
++EXPORT_SYMBOL_GPL vmlinux 0x1c6660c7	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0x1c67d919	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c829910	__clk_mux_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1c8fe88e	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x1cc1379b	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0x1cdb2147	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x1ce26736	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x1d0f9a3b	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d23440b	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x1d2c6658	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x1d459685	xstate_size
++EXPORT_SYMBOL_GPL vmlinux 0x1d52c47d	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x1d551b9b	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d652735	__tracepoint_attach_device_to_domain
++EXPORT_SYMBOL_GPL vmlinux 0x1d739e1c	xen_set_callback_via
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7954f2	xen_xenbus_fops
++EXPORT_SYMBOL_GPL vmlinux 0x1d7b6427	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1d7cb586	clk_register_fixed_rate_with_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x1d91f7f4	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x1da80f42	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0x1daa7302	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0x1db76feb	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1dc15316	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0x1dda0fdf	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x1dde11ea	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0x1de7dc35	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x1def880e	bind_interdomain_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1e000879	hwpoison_filter_enable
++EXPORT_SYMBOL_GPL vmlinux 0x1e1e08bb	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e5f7ec2	rio_request_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0x1e68ce14	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0x1e7808a9	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e8663fd	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1e951548	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1ea0b004	__dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0x1eaac5ba	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebac2bd	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ec12779	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0x1ec4ed47	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x1ecc368a	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x1edc21cb	hwpoison_filter_flags_mask
++EXPORT_SYMBOL_GPL vmlinux 0x1ede3ff6	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0x1f1988f7	hwpoison_filter_flags_value
++EXPORT_SYMBOL_GPL vmlinux 0x1f28041f	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0x1f5683a4	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0x1f5dd733	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x1f72f097	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1f7f3253	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0x1f84ab41	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1f9bcb97	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x1faed4d8	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0x1fbbdd29	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x200cc695	__free_iova
++EXPORT_SYMBOL_GPL vmlinux 0x20386a2f	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0x206de88d	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x207f2ede	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x209ec764	xen_event_channel_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0x20aa6f51	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x20d9086e	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x20f935a0	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0x2140a0e7	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x215f779d	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0x21645f2f	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x21a563da	clk_get_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21b5dd8c	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x21be0bd5	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x21c71c62	rio_route_clr_table
++EXPORT_SYMBOL_GPL vmlinux 0x21cc8c91	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21e5250c	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0x21ed199a	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x22240afd	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x222e4647	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0x223ff585	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0x2240b197	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x228d4c6b	acpi_initialize_hp_context
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x2299ec81	perf_assign_events
++EXPORT_SYMBOL_GPL vmlinux 0x229edaaa	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0x229fad27	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x22c22b97	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0x22e2f06b	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0x2303aa0e	component_add
++EXPORT_SYMBOL_GPL vmlinux 0x23083290	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0x2315a82c	clk_mux_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2318e4e4	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0x231b8ebd	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x234aa22e	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0x2366a2c0	errata
++EXPORT_SYMBOL_GPL vmlinux 0x237a0d33	xen_swiotlb_dma_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x237a9e8d	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x2396c7f0	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0x239f16aa	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x23d51c45	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0x23dcb506	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x23df3396	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x23e5186c	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x23fed2b0	rio_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x24011e14	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x2401cb8a	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x240af384	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x240f04a3	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x2432b45f	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x2449ac19	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x245255ba	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x2462f07c	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x2469810f	__rcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2488210c	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x24a096bc	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24c37dec	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x24c7698a	xenbus_write
++EXPORT_SYMBOL_GPL vmlinux 0x24d50d98	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x24f45195	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x24f8c3ca	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0x250bbb45	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0x25142c56	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x252c09be	injectm
++EXPORT_SYMBOL_GPL vmlinux 0x252ef50e	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x25379e73	clk_set_min_rate
++EXPORT_SYMBOL_GPL vmlinux 0x2545c170	unregister_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x25bc3394	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x25bf7a0c	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0x25ce3745	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0x25d649c7	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0x25d700b8	gnttab_foreach_grant_in_range
++EXPORT_SYMBOL_GPL vmlinux 0x25f02c87	xen_p2m_addr
++EXPORT_SYMBOL_GPL vmlinux 0x25f2ee03	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0x25f473dd	device_register
++EXPORT_SYMBOL_GPL vmlinux 0x25f6c56f	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0x2601de2e	rio_mport_get_physefb
++EXPORT_SYMBOL_GPL vmlinux 0x26062cc4	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x2639f462	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0x263e4192	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0x2643baef	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0x264ae4c6	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x265b7b15	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x2676f57d	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x26965721	slow_virt_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x269b4914	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0x269bb076	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x26ad6577	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x26b3c701	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26f42b26	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0x26fd5f00	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0x2707eca0	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x27296b0b	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x274aa8cf	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0x274cf5e1	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x274d8fed	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x276aab92	xen_swiotlb_set_dma_mask
++EXPORT_SYMBOL_GPL vmlinux 0x27884207	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x278bddcb	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x279cb985	apei_exec_pre_map_gars
++EXPORT_SYMBOL_GPL vmlinux 0x27a4259e	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x27aee62c	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0x27b25e36	dax_zero_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x27c0c4be	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27cb1269	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x27d2fffc	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x27dd7abf	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x27eac0b1	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x28084a7d	reserve_iova
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x28302a80	xenbus_dev_is_online
++EXPORT_SYMBOL_GPL vmlinux 0x28780150	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x287f8ec3	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x28aa4a89	devm_pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0x28aa6a67	call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x28b220b9	xen_remap_domain_gfn_array
++EXPORT_SYMBOL_GPL vmlinux 0x28d68aaf	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0x28da8864	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x28e64c64	xen_has_pv_and_legacy_disk_devices
++EXPORT_SYMBOL_GPL vmlinux 0x28e98a4d	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x28ece97c	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0x28fe0ba4	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x29191965	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0x2924534b	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x292e604a	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x292f8e0b	acpi_processor_get_performance_info
++EXPORT_SYMBOL_GPL vmlinux 0x294bc1a5	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x29722f4c	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x29aa13df	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0x29c56d75	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0x29c76cb7	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x29cf809d	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x29d11ff4	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x29d3e729	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x29d9c6d6	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x2a5cb540	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0x2a66fbea	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a78570c	hypervisor_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x2a820596	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x2a8e6d04	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0x2a8ea857	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0x2a9c0f3a	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0x2aa4e7af	dax_clear_blocks
++EXPORT_SYMBOL_GPL vmlinux 0x2aa5cba2	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x2ac9484c	rio_route_get_entry
++EXPORT_SYMBOL_GPL vmlinux 0x2aebdadb	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x2af28370	acpi_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x2af63321	acpi_dev_resource_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x2b015b49	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x2b022c29	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x2b116fc8	__tracepoint_add_device_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b683324	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x2b7666d6	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x2b787bff	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2b952517	clk_has_parent
++EXPORT_SYMBOL_GPL vmlinux 0x2ba2060c	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x2bb5695d	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0x2bc0c9d0	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2bd16757	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2bda8773	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa985e	nd_cmd_dimm_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2c16c1a8	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0x2c1f9573	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c26633c	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c33f967	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x2c5e2388	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x2c6be107	to_nd_region
++EXPORT_SYMBOL_GPL vmlinux 0x2c6dc130	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0x2c7d9c64	xen_store_interface
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c8f130e	pinctrl_get_group_pins
++EXPORT_SYMBOL_GPL vmlinux 0x2cb25c43	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x2cbb4127	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x2cbf8ef9	acpi_subsys_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x2cd0b218	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x2ce662f6	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x2ce80094	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2cee9968	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x2d0bda44	xen_swiotlb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x2d11485c	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d25fbaf	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0x2d29ea0d	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0x2d3d8d17	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d628355	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x2d6436a6	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0x2d6e2dd5	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x2d9f2ce3	sched_clock_idle_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x2dcd87f2	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x2dcf9a49	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x2de65157	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x2de79bcf	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x2e0e4e7e	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x2e1da9fb	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e2924ed	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x2e2df7f4	irq_remapping_cap
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e490dc7	rio_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0x2e490e29	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x2e561c32	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x2e5cc3e7	klp_enable_patch
++EXPORT_SYMBOL_GPL vmlinux 0x2e6915c9	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x2e81046a	irq_chip_ack_parent
++EXPORT_SYMBOL_GPL vmlinux 0x2e88780e	pinctrl_dev_get_devname
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ec53d99	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f2a5224	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f48a778	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x2f619b68	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0x2f64415f	unregister_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f6810d4	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x2f742f7b	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x2f76a2c5	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f7746bf	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f8bfd3d	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0x2fd503c0	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x2fdaf14a	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x2fe1b40f	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0x2fe434ce	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0x2fece8ef	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0x3007af5b	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x300bee0b	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x30119c69	xenbus_grant_ring
++EXPORT_SYMBOL_GPL vmlinux 0x301da6d7	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3027c047	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x3029be81	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x303456c4	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0x303b7ccb	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x303c2793	intel_svm_bind_mm
++EXPORT_SYMBOL_GPL vmlinux 0x3050c337	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x30574fc3	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x30635782	cpu_has_xfeatures
++EXPORT_SYMBOL_GPL vmlinux 0x306f7c22	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3071dce4	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0x30738fe9	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0x30755450	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x30757a2e	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x3078d6ad	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x309497d8	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0x30bf21b5	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30cff1bb	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x30e57ee4	clk_debugfs_add_file
++EXPORT_SYMBOL_GPL vmlinux 0x30f7fa68	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x310560f7	clk_register_gpio_gate
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x31128b8e	hv_remove_kexec_handler
++EXPORT_SYMBOL_GPL vmlinux 0x311f32a4	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x3120ab27	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x31309115	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x314fad93	efivar_entry_set_get_size
++EXPORT_SYMBOL_GPL vmlinux 0x3166e9b8	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0x31720aff	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x3175141e	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x31b4cb43	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31d09988	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x31d1e9ab	xenbus_dev_error
++EXPORT_SYMBOL_GPL vmlinux 0x31da152e	ata_acpi_cbl_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x31e3eb37	rio_request_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x32007748	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x3200e515	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0x320554b0	acpi_register_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x321bdbb1	compat_get_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x32365cff	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x3236e42f	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0x325e677c	gnttab_grant_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x32625697	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x327b7488	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x32bc0fcf	preempt_notifier_dec
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32e3b076	mxcsr_feature_mask
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x336234a1	xenbus_unmap_ring
++EXPORT_SYMBOL_GPL vmlinux 0x3362b03c	xen_p2m_size
++EXPORT_SYMBOL_GPL vmlinux 0x33655159	xen_pcpu_hotplug_sync
++EXPORT_SYMBOL_GPL vmlinux 0x33804147	efivar_entry_remove
++EXPORT_SYMBOL_GPL vmlinux 0x3393c162	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x33b87dbd	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x33b96e5d	apei_exec_write_register
++EXPORT_SYMBOL_GPL vmlinux 0x33be6bfd	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x33c1b145	nvdimm_bus_check_dimm_count
++EXPORT_SYMBOL_GPL vmlinux 0x33cae143	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0x3417a563	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0x3429426f	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0x34491193	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x344d0bd6	rio_release_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x346113d1	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x3475654f	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x34915a4c	pinctrl_pm_select_idle_state
++EXPORT_SYMBOL_GPL vmlinux 0x349826aa	register_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x3499a93a	is_dock_device
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34a8da5f	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0x34b30ce4	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0x34c26ab9	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0x34d3967a	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x34d4f388	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x34e4d1cc	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0x34ee8cca	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x35026c52	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x352650ee	gnttab_batch_map
++EXPORT_SYMBOL_GPL vmlinux 0x357689e2	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x35910f72	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x35a1be97	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x35a7027c	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0x35bf2acd	nd_fletcher64
++EXPORT_SYMBOL_GPL vmlinux 0x35c2f089	rio_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x35d86128	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0x35d97efc	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x35e90a64	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x360cd5ec	pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0x360d62e2	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x36181fc6	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x361b6ef5	register_mce_write_callback
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x365e9765	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0x3667c70c	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0x366a1bb1	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x366b9703	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0x367eb510	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x368f1fea	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x3694f883	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x36969846	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x369c5b0e	clkdev_create
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36b1aac9	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x36b5497e	intel_iommu_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x36bda7b0	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x36c2c677	klp_unregister_patch
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x36f5ce08	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x3719d7bc	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x37203614	xen_unmap_domain_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x3742d90d	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x374fc448	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x376e1b20	acpi_gpiochip_free_interrupts
++EXPORT_SYMBOL_GPL vmlinux 0x3779a5c9	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0x377cc10a	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x379e9886	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x37c29c74	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x37e0b728	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0x38105f6c	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x384dcbc5	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0x385fcc10	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0x38663eb2	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0x386997d4	rio_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x38722f80	kernel_fpu_end
++EXPORT_SYMBOL_GPL vmlinux 0x38844dd5	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x38b50b89	clear_foreign_p2m_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x38c9ce6b	clk_register_gpio_mux
++EXPORT_SYMBOL_GPL vmlinux 0x38db7152	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0x38dde2c6	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x38e4b4d3	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x38e5bc5a	clk_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x38e82214	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x391f6825	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0x392fe739	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x393f57ab	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x394c4d62	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x39597d25	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x39605c8a	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x397043cd	xen_find_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x397ca2fa	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x39802b67	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x3997bfb0	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x399f7d9b	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0x39a1a062	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x39b21e29	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x39c6479c	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x39c8c858	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39e1cf4b	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x3a01d9df	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a38dc65	memory_failure
++EXPORT_SYMBOL_GPL vmlinux 0x3a3db234	divider_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a5c2b18	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0x3a7d80f9	xen_max_p2m_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x3a8e3898	pci_msi_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x3a9422cd	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3ad0e201	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x3ad70907	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0x3b00fb2a	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3b3991d8	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0x3b547bc9	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x3b63382a	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x3b7145bb	apei_exec_read_register_value
++EXPORT_SYMBOL_GPL vmlinux 0x3b79007f	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x3b79ce87	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x3b92b1eb	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0x3b9718da	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x3bd36fb4	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x3be822c5	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3be86a54	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3bf2adfe	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x3bfe94cb	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0x3c17c910	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0x3c209c76	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x3c211ac6	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3c561ea3	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3c787fe3	nd_device_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x3c7a8d48	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x3c8afb99	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x3c8c60ab	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0x3c906865	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3c98264e	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3ca6136a	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cdd165b	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x3cdfc218	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d5f392d	acpi_os_unmap_memory
++EXPORT_SYMBOL_GPL vmlinux 0x3d631956	acpi_is_pnp_device
++EXPORT_SYMBOL_GPL vmlinux 0x3d6ccf52	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x3d7ea99a	gnttab_grant_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x3d8452d0	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x3d9418ac	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0x3da67a23	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x3dae6404	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3de64d18	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0x3de92077	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3debbf33	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x3df9593f	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x3dfc436e	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x3dfd01b3	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x3dfe298f	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x3dff01ef	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x3e1806aa	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3e2d6df3	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3e4c25e9	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0x3e5384de	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x3e54b244	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3e5b0d02	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e68404f	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0x3e6bc0a7	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e7d7546	pinctrl_dev_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x3e846a81	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x3e8bdeb8	iommu_get_domain_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3ea5196d	apei_osc_setup
++EXPORT_SYMBOL_GPL vmlinux 0x3eb6c744	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0x3ebeacec	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x3ec0add1	acpi_get_pci_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3ece4c31	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x3ed554fa	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x3ed589bf	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3ee30a3b	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f1678a9	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0x3f209a8c	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x3f229c4c	oops_begin
++EXPORT_SYMBOL_GPL vmlinux 0x3f2f060a	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0x3f3a2745	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x3f584f2f	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x3f5e8000	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x3f6b7718	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x3f70fda6	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0x3f77f4fe	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0x3f84d4c9	gnttab_release_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x3fa39a15	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x3fa5af9c	nd_cmd_bus_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3fae792b	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x3fbac71f	xenbus_probe_devices
++EXPORT_SYMBOL_GPL vmlinux 0x3fdca19b	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0x3fef001c	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0x3ff71028	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0x4009cb45	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0x400a024b	acpi_scan_lock_release
++EXPORT_SYMBOL_GPL vmlinux 0x4010b80f	pmc_atom_read
++EXPORT_SYMBOL_GPL vmlinux 0x401e84c8	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x40356d20	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x40357740	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x404e7c93	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x406abf58	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x406e9373	rio_dma_prep_slave_sg
++EXPORT_SYMBOL_GPL vmlinux 0x408212ba	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0x4084e3ba	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x40984875	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0x40aef116	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40ed9d0c	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x410691b8	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x41112e41	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0x414e409d	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4174886c	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x418710e7	mce_inject_log
++EXPORT_SYMBOL_GPL vmlinux 0x41a034d0	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0x41abdef4	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x41cdfffa	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x41e6d35c	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x4213a51a	efivar_entry_set_safe
++EXPORT_SYMBOL_GPL vmlinux 0x42174d8b	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x4252b7c7	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4255026d	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x4259eb86	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x42635d55	pm_suspend_global_flags
++EXPORT_SYMBOL_GPL vmlinux 0x4277b8a7	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0x427d5c68	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x427de547	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42828380	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x42841583	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x42847f59	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x42893c9a	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0x4289fbe3	acpi_dev_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x42912415	acpi_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x42a21f5e	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0x42b3d8c4	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x42b3e22a	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0x42b630fd	xenbus_dev_changed
++EXPORT_SYMBOL_GPL vmlinux 0x42b7be91	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x42bb8d80	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x42c0c9b3	efivars_kobject
++EXPORT_SYMBOL_GPL vmlinux 0x42e5c704	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0x42f26ec7	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x42f5753e	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x42f71e80	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x43118174	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x4320a82c	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x4346225b	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x434b99c8	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x43619e1a	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x4378416c	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x437f6671	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0x438d8df2	iova_cache_get
++EXPORT_SYMBOL_GPL vmlinux 0x4395953e	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x439709ff	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x43a201f1	user_read
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43bd1f7d	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x43f81957	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x43fa2970	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x44017092	clk_hw_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x441fa356	irq_ts_save
++EXPORT_SYMBOL_GPL vmlinux 0x446e3c47	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0x4470f812	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x44b85596	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44e1e9aa	balloon_stats
++EXPORT_SYMBOL_GPL vmlinux 0x450fb522	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x45166e9d	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x45217bb5	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0x4541fe0d	mtrr_state
++EXPORT_SYMBOL_GPL vmlinux 0x454ae78c	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x454f1cb4	efi_query_variable_store
++EXPORT_SYMBOL_GPL vmlinux 0x455876e8	pinctrl_dev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x4577b6f3	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x45946f80	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x45b7d6a0	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45c2afa5	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x45d065b5	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x45d14bdf	hypercall_page
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x460247e6	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0x46046b98	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0x460f31aa	rodata_test_data
++EXPORT_SYMBOL_GPL vmlinux 0x46373660	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x46434934	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x4643b1ad	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x465270ae	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4663d883	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x466eaf5c	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x46713a2d	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0x4678157d	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x46b2917d	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x46b70eca	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x47082f2d	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x47322066	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x473a4ac9	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x4743fc1d	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x475c41f9	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x47745785	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47b914d4	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x47be2669	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x47c4f7fc	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x47d0eea2	acpi_lpat_temp_to_raw
++EXPORT_SYMBOL_GPL vmlinux 0x47de0dc7	clk_unregister_mux
++EXPORT_SYMBOL_GPL vmlinux 0x47e49d09	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x47e51f94	__efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x4816f63b	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x4820bc17	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0x4828e77b	acpi_scan_lock_acquire
++EXPORT_SYMBOL_GPL vmlinux 0x48682db9	perf_guest_get_msrs
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x486f78bd	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x489c8742	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0x48c05e6f	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x48d0b9a8	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x48d477f7	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0x48d49bb5	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0x48f94558	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x490a8df6	x86_platform
++EXPORT_SYMBOL_GPL vmlinux 0x493a806e	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0x495ae653	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x498b227c	nd_mapping_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x49992a9c	xen_pci_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x49b35b40	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0x49cf9a70	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x49e4eb33	pv_info
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x49f038b7	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x4a017cc8	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x4a02ab07	rio_unlock_device
++EXPORT_SYMBOL_GPL vmlinux 0x4a36e4b1	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x4a3c3cf9	microcode_sanity_check
++EXPORT_SYMBOL_GPL vmlinux 0x4a3c889d	pinctrl_lookup_state
++EXPORT_SYMBOL_GPL vmlinux 0x4a420d09	acpi_bus_detach_private_data
++EXPORT_SYMBOL_GPL vmlinux 0x4a43fd72	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a861843	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x4a90160e	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4ac37299	xenbus_dev_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4ac3e61f	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0x4ad159e6	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0x4ad741d2	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4ad80d1d	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x4aece87c	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x4b06869f	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0x4b211246	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x4b3965aa	xen_swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x4b5ec22d	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x4b5eec83	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0x4b613bc4	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x4b684ea0	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0x4b6cc111	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x4b88a3e0	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x4b9ea47f	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x4bae58fc	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x4bb511ad	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x4bea6ef0	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x4bedf39d	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4c0b11cc	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4c0cc372	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4c2a472b	__static_cpu_has_safe
++EXPORT_SYMBOL_GPL vmlinux 0x4c5948a1	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x4c59900b	acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c645f9e	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x4c6774dd	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4c8165c0	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0x4c874505	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x4c896cb1	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0x4cdeb9f4	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0x4cf4bcda	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d03b724	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x4d3ac991	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x4d49b4f9	acpi_ec_add_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4d5c7c05	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x4d6aa807	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0x4d70ff85	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x4da1c2d0	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4de61feb	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x4e042286	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0x4e06e294	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e3c0ebf	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x4e45d555	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0x4e549d34	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x4e55496f	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x4e57723d	apei_read
++EXPORT_SYMBOL_GPL vmlinux 0x4e5f3efa	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4e6aaa96	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x4e74e625	gnttab_batch_copy
++EXPORT_SYMBOL_GPL vmlinux 0x4e758045	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x4e97a832	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0x4e9ea51b	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0x4ea54bfa	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4eaf6cfd	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x4ee1a6fd	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x4eeec615	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f05925c	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4f1621fc	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x4f232ae7	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f451987	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x4f4efc17	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0x4f663197	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4f730459	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x4f81b531	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x4fa6860c	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x4fccdbcd	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0x4fd44083	dax_do_io
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe0f522	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4ff1e5b3	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5001a0ac	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x50098cd4	iommu_capable
++EXPORT_SYMBOL_GPL vmlinux 0x50120936	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0x5026585c	xen_irq_from_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x5029bfab	xenbus_dev_probe
++EXPORT_SYMBOL_GPL vmlinux 0x502fd88c	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x5061b054	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x507de8c6	add_memory
++EXPORT_SYMBOL_GPL vmlinux 0x5084b1bb	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x50b07f97	acpi_unbind_one
++EXPORT_SYMBOL_GPL vmlinux 0x50d1f870	pgprot_writecombine
++EXPORT_SYMBOL_GPL vmlinux 0x50dc0b24	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50e76b42	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x511459a7	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x512b1d19	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x512c0c26	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x51346b02	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0x5140aad4	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0x5149c731	print_context_stack
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x514e9875	divider_get_val
++EXPORT_SYMBOL_GPL vmlinux 0x517e8239	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x5180bff2	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x5187ac4b	xen_store_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x518935d7	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x518c2fc6	hpet_rtc_dropped_irq
++EXPORT_SYMBOL_GPL vmlinux 0x518cf477	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0x518fb8b2	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x5191bd3c	efivar_work
++EXPORT_SYMBOL_GPL vmlinux 0x51d93548	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x51eb4dbd	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x51fe53d8	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0x51fe7f9c	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x52233f9d	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x5229873a	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x522f538b	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x523d9028	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x523db296	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0x526582b4	clk_hw_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x5272d8bc	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0x527a19bc	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0x52813a36	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x529733f6	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0x52a41251	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x52a82c28	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x52c9476c	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x52cb50f7	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x52cc038f	rio_request_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x52d8c375	clk_register_divider
++EXPORT_SYMBOL_GPL vmlinux 0x52dd1c66	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0x52e9fcce	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0x53541fa3	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x53577394	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53601769	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x5360a4fe	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x53649e41	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0x538ad82c	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0x539f157b	pci_xen_swiotlb_init_late
++EXPORT_SYMBOL_GPL vmlinux 0x539f19ec	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0x53b738b2	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x53b82960	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x53d25f58	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0x53df3186	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x53f33858	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x54215db5	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0x542d67af	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x544dbc88	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0x54513345	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x545ee955	fpu__activate_curr
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x5460d1e9	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x5474b55f	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x54837120	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54a29dae	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x54e02a82	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0x54eae123	generic_access_phys
++EXPORT_SYMBOL_GPL vmlinux 0x550ce709	pat_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x55181725	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x55526907	xen_features
++EXPORT_SYMBOL_GPL vmlinux 0x556a6cd4	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x556e4390	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x5571ccee	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x55843f2c	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x558fbc83	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0x5593d715	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x55ac152a	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x55b3d3cb	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x55bb3289	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x55c644fa	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x55e5218d	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x560abccc	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x562f4167	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x5637174b	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x56398615	mark_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x564871a2	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x5654f836	erst_get_record_id_next
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x565cb272	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x567b0fb4	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0x567e27d7	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x56905901	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x56931ad6	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x56947347	dmi_walk
++EXPORT_SYMBOL_GPL vmlinux 0x569b3117	dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0x56b2c3e0	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0x56c1c5da	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56d7426b	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56f39d37	rio_dma_prep_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x5704e7a7	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0x5705a391	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x572e2909	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x5749b94f	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0x57506f34	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0x575c5f94	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0x5774ce57	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x5779d445	xenbus_exists
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57c0292f	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x57d1fdb7	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0x57e1c003	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0x57f8062c	acpi_dev_resource_io
++EXPORT_SYMBOL_GPL vmlinux 0x5801bb11	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0x58091bfb	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x580bf930	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x58110346	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x5835338e	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x584cc350	clk_hw_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x585704ab	aer_recover_queue
++EXPORT_SYMBOL_GPL vmlinux 0x585d34de	xenbus_dev_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x5871637e	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0x587bd46f	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0x58817ec6	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x588b0703	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58a5e7a8	rio_mport_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x58c4c574	__online_page_free
++EXPORT_SYMBOL_GPL vmlinux 0x58fe9409	rio_inb_pwrite_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5907df23	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0x59371588	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x594bac77	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x594f61b4	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0x594ffd40	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0x5960d6b0	user_update
++EXPORT_SYMBOL_GPL vmlinux 0x59688cf7	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x5975c487	acpi_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x597e4542	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x59b0882b	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x59b2adbf	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x59b9f235	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x59bed875	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0x59d570e9	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x59d9ac09	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0x59e7a8bb	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x5a171008	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x5a198162	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0x5a2b1b67	gnttab_free_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5a40e4fd	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x5a5a6586	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0x5a6a8530	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x5a6c62ef	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a7ee148	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x5a91b861	nvdimm_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x5ab0a105	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x5ab4de91	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x5ae75bbe	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x5ae8b829	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0x5af03a28	gnttab_claim_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5b0eb600	xenbus_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5b1899f8	free_iova
++EXPORT_SYMBOL_GPL vmlinux 0x5b1ad987	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0x5b52e25e	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x5b572787	sis_info133_for_sata
++EXPORT_SYMBOL_GPL vmlinux 0x5b5eefb1	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0x5b615718	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0x5bb73368	pinctrl_remove_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x5bce8ca1	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x5bcec8ee	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbee8a	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x5bdf32d3	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x5c586c6e	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c5dc460	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x5c66e90c	efivar_run_worker
++EXPORT_SYMBOL_GPL vmlinux 0x5c8d7f62	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x5c9b905a	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x5ca69439	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cb5c9b8	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5cd78169	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x5cd9fce8	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0x5d075c2f	pci_msi_set_desc
++EXPORT_SYMBOL_GPL vmlinux 0x5d0e73c5	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x5d0f7f54	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d2b968b	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x5d3537a1	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0x5d366dec	gnttab_cancel_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0x5d4df68c	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x5d5ca512	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x5d7701dc	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x5d8f75d0	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5dbcfa4f	boot_cpu_physical_apicid
++EXPORT_SYMBOL_GPL vmlinux 0x5dc8262c	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x5dcd7160	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x5de1692f	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0x5dfdb07d	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x5e0fbda5	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x5e249b32	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0x5e3f7c88	acpi_subsys_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x5e41d7ae	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x5e43494c	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e70bd6f	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x5e732a87	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5e77bc0a	agp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x5e8091cc	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x5e8a02aa	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0x5e9cc825	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0x5eaab96d	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x5ec06a60	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0x5ec4db95	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x5edd8400	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0x5ee0ffb1	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x5eef92bf	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x5f110447	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x5f226035	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x5f2da8c4	check_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x5f2f8f56	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x5f6d1b1d	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x5f83c9a3	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x5f84ba5e	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0x5f89d96f	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x5f925651	inet_csk_compat_setsockopt
++EXPORT_SYMBOL_GPL vmlinux 0x5f9957fc	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0x5fc010da	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x5fc27be9	acpi_dev_irq_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5fc3f89d	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x5fdcbd09	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x5fdfa2c1	amd_pmu_enable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x5fe907b7	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x5ff50674	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0x60091316	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x60218ba9	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x603978ce	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x6051a105	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x6054e50c	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0x605cd0d0	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x605d0da0	component_del
++EXPORT_SYMBOL_GPL vmlinux 0x60786286	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0x6091797f	synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x60930d37	save_mc_for_early
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60a1c713	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0x60a7b226	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x60b42d88	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x60b9665d	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0x60cd73ed	pv_apic_ops
++EXPORT_SYMBOL_GPL vmlinux 0x60df7e5a	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x60ec2944	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0x6143fe79	acpi_dma_request_slave_chan_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x614582d0	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x615b1616	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0x615b4c40	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0x616877a5	devm_pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0x6172e954	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0x61bdbbae	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0x61cde409	acpi_dev_resource_memory
++EXPORT_SYMBOL_GPL vmlinux 0x61f09d36	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0x620bc08e	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x6213659d	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6214b16c	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x621c1a29	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0x6221cb1c	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x623803c8	hest_disable
++EXPORT_SYMBOL_GPL vmlinux 0x625fcea3	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0x6289508f	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x62a0145d	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0x62a1c981	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x62bd5a6d	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x62e3b7b4	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x62ef0bf0	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x62ef14cc	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0x62f9c06e	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0x62fc49c5	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0x63150e06	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x6333072c	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x635b0db9	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0x635ec980	apei_exec_post_unmap_gars
++EXPORT_SYMBOL_GPL vmlinux 0x6382485d	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0x638fe045	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x639e8462	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x63bdcb8b	xen_unregister_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x63e00b69	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x63e17b86	divider_recalc_rate
++EXPORT_SYMBOL_GPL vmlinux 0x63ea80b3	cper_mem_err_type_str
++EXPORT_SYMBOL_GPL vmlinux 0x63f14ebe	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x6412dfc8	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0x64198a37	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0x642409a5	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x64276f1f	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x64318593	acpi_dev_filter_resource_type
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x6453799f	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x64749dfc	pinctrl_utils_reserve_map
++EXPORT_SYMBOL_GPL vmlinux 0x64a17f01	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0x64a3e0a9	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0x64b1ce42	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x64b53188	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x64b7069e	apei_mce_report_mem_error
++EXPORT_SYMBOL_GPL vmlinux 0x64d9a6bc	acpi_subsys_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x64e80dfb	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x6527a231	dbgp_external_startup
++EXPORT_SYMBOL_GPL vmlinux 0x652fdde4	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x6536953b	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0x6564e99e	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0x656ae987	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x657ace9c	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x657c029c	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x658c8186	amd_get_nb_id
++EXPORT_SYMBOL_GPL vmlinux 0x659fc137	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x65a0e4d9	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0x65bae1c0	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65d506a1	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6613cfab	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x66251018	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x6638b6cb	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x665eaf68	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x665ecab0	pv_time_ops
++EXPORT_SYMBOL_GPL vmlinux 0x666900d9	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x666e1ddb	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x6675a981	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0x667a15f7	pcc_mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x66903ce0	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x6694a249	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0x669cd7e1	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0x66c2ce1c	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66d27e06	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x66d443cc	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66dd60aa	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x66e16f83	dax_truncate_page
++EXPORT_SYMBOL_GPL vmlinux 0x66fb1d3e	xenbus_probe_node
++EXPORT_SYMBOL_GPL vmlinux 0x6703db51	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0x671ea36e	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x6739a503	balloon_set_new_target
++EXPORT_SYMBOL_GPL vmlinux 0x674dd1b1	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x675ba9cb	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0x676e3a05	to_nvdimm
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x67968b28	pinctrl_add_gpio_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x679f2c60	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x67a67a04	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0x67d5a8bd	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x6828177b	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0x683c85ad	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0x68422e98	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x684f2f98	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0x6852f62d	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0x685ee377	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6863c4ee	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x686c5944	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x68808abe	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0x68b30092	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x6910dd3e	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0x6921aa34	compat_put_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x69284b87	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x695fa438	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x69bf4027	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x69c013bd	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x69c832a2	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x69c904ff	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0x69e6ef45	acpi_pci_find_root
++EXPORT_SYMBOL_GPL vmlinux 0x69f4464e	xenbus_dev_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x6a10f384	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a184f9f	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6a26ca0a	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a694462	rio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6a6cafd2	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x6a82f56b	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a936feb	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x6ab1b8bb	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x6ab32054	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0x6acad21f	acpi_get_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0x6b0dc565	xen_set_irq_priority
++EXPORT_SYMBOL_GPL vmlinux 0x6b1039e9	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b4ef397	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0x6b63e497	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0x6b68a4dc	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6b8525ba	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x6ba0bdeb	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6bb549d9	nd_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x6bbf114f	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x6bf1b90d	dmi_memdev_name
++EXPORT_SYMBOL_GPL vmlinux 0x6bf5c4c7	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x6bf7984f	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c1251fd	apei_exec_read_register
++EXPORT_SYMBOL_GPL vmlinux 0x6c389761	acpi_bus_get_private_data
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c58dc33	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x6c6538df	init_iova_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6c655913	register_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6c73bd41	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6c8d012f	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x6ca08aea	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cb09208	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6cdb2005	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x6ce41672	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6ce99d02	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x6d15896f	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d56e5b0	nd_region_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x6d66b73d	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x6d6b8b34	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x6d865e4e	rio_mport_send_doorbell
++EXPORT_SYMBOL_GPL vmlinux 0x6d9bb1c7	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x6da7ec70	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0x6dcc57bf	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0x6ddc9899	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x6dee3701	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0x6dfd5d64	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e0d0364	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0x6e30cb09	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0x6e326b51	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x6e58ddf0	gnttab_end_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e7b2a52	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0x6e85b00b	local_touch_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6ea98361	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x6eab0907	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0x6eb69e4b	acpi_dev_add_driver_gpios
++EXPORT_SYMBOL_GPL vmlinux 0x6eb97a13	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0x6ef209c8	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x6ef66de9	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f265fe6	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x6f3ee029	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6f402ba6	acpi_dev_resource_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x6f44171f	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6f4f2257	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0x6f5ac2bb	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x6f5fe36c	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6f890012	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x6fc89892	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x6fdaf654	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x6fe03ef4	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6feb6001	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x6ffed6b9	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0x701ca03e	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x7029c830	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x702be89a	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0x704c6975	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0x707d6f09	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x7085dcea	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0x708622f2	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x708d8ddf	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x70a789a2	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70e2c883	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x710d084c	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x7119c2d6	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x71777ac6	xenbus_dev_fatal
++EXPORT_SYMBOL_GPL vmlinux 0x717ad389	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0x719e17ff	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x71a1bfe8	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x71c385e8	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x71cc1d5e	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x722ce187	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7274dd87	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x728ca3bd	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x729a043f	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x72cf714d	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x72dfa67b	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0x72e16e54	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x72e230ee	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x72fe73ef	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x73013896	xenbus_printf
++EXPORT_SYMBOL_GPL vmlinux 0x73155196	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x731dba7a	xen_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0x731f8599	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x73219e13	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x73254335	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0x7342d5be	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0x7380dbfe	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0x73811d47	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x739ac4a5	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73a77ed7	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x73afb372	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0x73c2554f	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73cbceba	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73f95314	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x741cb25a	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x7443e631	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x74457e56	apei_resources_fini
++EXPORT_SYMBOL_GPL vmlinux 0x7452adff	user_return_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x745a6e5d	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x745c14de	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x74694e13	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x74719515	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x7481afc6	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x748677ea	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x748e15cc	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0x74a3843e	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74b871bf	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0x74b9f79b	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74c08941	kvm_async_pf_task_wake
++EXPORT_SYMBOL_GPL vmlinux 0x74deb10c	used_vectors
++EXPORT_SYMBOL_GPL vmlinux 0x75133f6e	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0x751d12c7	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7521afb6	leave_mm
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x75414fde	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0x754c4ce7	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x757b49d2	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0x757bac58	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x757ed190	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x758bdd82	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7598e8e3	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x75bf4983	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75df7479	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0x76022c56	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0x7603e988	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0x761dabf4	nd_cmd_in_size
++EXPORT_SYMBOL_GPL vmlinux 0x7623d736	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x763e61a0	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x76437689	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x76837518	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x768fb920	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x76a80f04	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0x76d9b876	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0x76ebb258	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0x770f61f9	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x7712771a	unbind_from_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x772bbaab	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0x7737ed87	rio_register_scan
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x7757b51a	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x775a6ef5	kvm_read_and_reset_pf_reason
++EXPORT_SYMBOL_GPL vmlinux 0x77678f57	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x778b675a	pmc_atom_write
++EXPORT_SYMBOL_GPL vmlinux 0x77923ca7	shake_page
++EXPORT_SYMBOL_GPL vmlinux 0x77a325a6	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0x77aa8e34	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x77c7bc19	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0x77d31318	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x77dcfc7b	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0x77ddaf3d	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x77e9499d	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0x780aaf4f	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0x7825c9ee	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x782adb74	hpet_rtc_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x78575bee	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x7874b5ec	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x787c882b	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x789939af	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0x78a4942e	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x78a87728	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0x78a89000	xenbus_dev_groups
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78c98269	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x78cc5bec	hugetlb_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x78cd264d	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x78d80aca	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0x78e81925	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x78f0348e	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x791d192a	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x795c92e3	efivar_entry_size
++EXPORT_SYMBOL_GPL vmlinux 0x795fad41	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x7991fd8d	crash_vmclear_loaded_vmcss
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x79e69460	intel_iommu_gfx_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x79fdd1f7	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x7a01d993	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x7a093833	set_memory_array_wt
++EXPORT_SYMBOL_GPL vmlinux 0x7a1565a5	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x7a1b0091	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x7a21d515	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a319404	clk_register_fixed_rate
++EXPORT_SYMBOL_GPL vmlinux 0x7a488c23	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x7a4b7549	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7a9df390	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7aa0abfd	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7ab35493	rio_unregister_scan
++EXPORT_SYMBOL_GPL vmlinux 0x7ac689eb	acpi_dev_get_property
++EXPORT_SYMBOL_GPL vmlinux 0x7ac8e5b0	acpi_gsi_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7ace6f69	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0x7ad293a8	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0x7ad88cc7	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x7ad9fafa	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x7aed367f	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0x7aedf73f	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b202401	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x7b388df2	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0x7b3e0cac	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x7b42fdb7	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0x7b4997ce	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x7b53ad54	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x7b67b19d	xenbus_map_ring_valloc
++EXPORT_SYMBOL_GPL vmlinux 0x7b70ed5c	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x7b90d1a9	bind_virq_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7b9831eb	clk_hw_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x7b9b0992	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x7bbc3f3e	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0x7be2cf13	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x7c004e17	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x7c069649	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0x7c13a19d	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x7c1722f6	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0x7c2064c2	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0x7c29b819	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7c40de53	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0x7c4269dd	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0x7c9a7371	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x7c9ef889	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0x7cb10de2	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x7cceae18	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7cd8c6e5	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cedf677	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7d00c65b	nd_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x7d0456c4	pin_is_valid
++EXPORT_SYMBOL_GPL vmlinux 0x7d0e1d95	hv_setup_crash_handler
++EXPORT_SYMBOL_GPL vmlinux 0x7d36d6a8	clk_register_fractional_divider
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d662159	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0x7d84d464	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x7d9c2402	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7dc3f358	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x7dcdc93f	__tracepoint_extlog_mem_event
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7de65a03	acpi_lpat_free_conversion_table
++EXPORT_SYMBOL_GPL vmlinux 0x7de9a021	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0x7e210734	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0x7e2f80d3	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0x7e2f8759	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0x7e4cf6fb	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0x7e59a07f	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x7e63d5f7	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e76b3c4	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0x7e86cd7a	devm_acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7e96801a	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0x7e96b77b	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0x7ea1a2bc	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x7f12e93d	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x7f13d491	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x7f1557f2	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f29e9ab	__rio_local_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x7f3658e6	fpstate_init
++EXPORT_SYMBOL_GPL vmlinux 0x7f3fc9d7	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x7f43bb7b	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x7f638fb3	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0x7f70d61d	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0x7f79bbf3	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7f8a9129	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0x7fa6033f	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x7fb9a1ac	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7fd8c618	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0x7fe731b4	set_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x7fe822e6	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x7febf0ab	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0x7ff0753d	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0x800ada01	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0x8014c824	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x80156244	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x801668bf	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x80229b9e	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x8033605a	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x80443e4f	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0x804c07bb	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x808ed2f8	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x809529fd	alloc_iova
++EXPORT_SYMBOL_GPL vmlinux 0x80b76d5b	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80c9c66b	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80f12459	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x80f473dd	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x8137f1e7	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8151b1d6	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0x8152e111	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x815588a6	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8177081b	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0x8180e344	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x81897657	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x81a84515	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x81af2397	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0x81b98f9a	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0x81ccb866	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0x81cd3f33	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x8235f5f6	pinctrl_register
++EXPORT_SYMBOL_GPL vmlinux 0x823c2631	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x823c9e8a	rio_mport_chk_dev_access
++EXPORT_SYMBOL_GPL vmlinux 0x823d5091	efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x82575c40	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x825ea7fe	clk_gpio_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0x82627353	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x8284b859	rio_set_port_lockout
++EXPORT_SYMBOL_GPL vmlinux 0x829a7091	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x829e0c3e	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x82aef706	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x82b46f0a	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0x82c1da30	__rio_local_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x82c27bfd	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82dbec19	erst_write
++EXPORT_SYMBOL_GPL vmlinux 0x831525c3	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8318eac9	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0x8329ad02	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0x832a73a0	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x832a7b13	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0x832eabe4	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x834ff81a	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x836666ce	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0x836e7b00	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x83b4d5bf	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x83ba5fbb	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x83e7fa83	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x83f6d7e2	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0x841da5ed	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x8423b019	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x8427a6d3	xen_swiotlb_map_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x8429eed5	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x842cab77	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x8431d6b2	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x84368bed	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x843d70ef	acpi_is_root_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x844a9152	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x844e4083	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x84539aac	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x8487a2b6	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x848f8f50	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x848fe3ed	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0x84a11f10	nvdimm_bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x84a9ca7f	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x84cd2fbf	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x84d6fec7	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x84e0d85e	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0x84e7855c	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x84fdb0a4	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x84ffac3b	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x85054a40	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0x8506baa8	clk_unregister_gate
++EXPORT_SYMBOL_GPL vmlinux 0x850df8b9	clk_divider_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x855059ae	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0x858594ae	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0x859875b7	rio_mport_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x8598ac58	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x859a6dc3	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x859aea9a	xen_set_domain_pte
++EXPORT_SYMBOL_GPL vmlinux 0x85b82f1e	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85cb2c45	xen_has_pv_devices
++EXPORT_SYMBOL_GPL vmlinux 0x85d7edfd	hpet_set_periodic_freq
++EXPORT_SYMBOL_GPL vmlinux 0x85ed6390	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x86000f4c	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0x8605f136	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x864db66d	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x8654be58	hv_remove_vmbus_irq
++EXPORT_SYMBOL_GPL vmlinux 0x86601b10	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x86623fd7	notify_remote_via_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8666a7c5	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x866b073b	smp_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8670aae3	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x86724241	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x86819bc6	irq_ts_restore
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x86a51007	gnttab_end_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x86bc3f15	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x86db4654	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x86e51e74	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x86eb0a3f	pinctrl_pm_select_sleep_state
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x86fefa88	clk_gpio_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8702e548	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x870e16b7	xen_test_irq_shared
++EXPORT_SYMBOL_GPL vmlinux 0x87329ae8	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0x87350718	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x8748671b	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x874cc791	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0x875720c1	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x876643fc	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0x87878e45	rio_request_mport_dma
++EXPORT_SYMBOL_GPL vmlinux 0x879d1b1c	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x87de525c	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x87ea0002	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x880da9a1	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x88136838	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x883c2740	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x8856f51f	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x886f409c	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x88841cd9	efivar_entry_set
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88b58874	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0x88df2c16	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0x88fd9e16	agp_remove_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x891a5a7f	gnttab_max_grant_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x892537e3	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0x8926f83c	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x89495374	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x8956aeae	apei_exec_ctx_init
++EXPORT_SYMBOL_GPL vmlinux 0x89593a44	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x897102a4	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89cdb825	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x89d05abc	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x89e04be4	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0x89e37c79	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x8a02b6c2	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x8a43d028	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x8a456737	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0x8a4b8066	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x8a559846	gnttab_setup_auto_xlat_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a67a903	xenbus_match
++EXPORT_SYMBOL_GPL vmlinux 0x8a78989f	irq_from_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x8a78f9d3	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x8a7cb9c4	platform_thermal_package_rate_control
++EXPORT_SYMBOL_GPL vmlinux 0x8a835788	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8a951089	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8aafb860	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8ac4a86b	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0x8ad191f6	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0x8ade2c51	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0x8afc4a31	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x8afd97df	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8b03c71a	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x8b04668e	bind_interdomain_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x8b149c36	clk_is_match
++EXPORT_SYMBOL_GPL vmlinux 0x8b2373e4	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x8b3762ae	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x8b6ce896	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0x8b75c18a	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8b8ae8d3	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8b8dd7ac	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x8b9200fd	lookup_address
++EXPORT_SYMBOL_GPL vmlinux 0x8b95f20b	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x8b9c1480	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x8bec1620	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x8bfadbfd	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c06a108	xenbus_transaction_start
++EXPORT_SYMBOL_GPL vmlinux 0x8c0bb8d3	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x8c1c4b8b	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8c1ee7a0	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8c27e94c	to_nd_desc
++EXPORT_SYMBOL_GPL vmlinux 0x8c549bb2	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c66b199	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x8c6bf90a	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8c6f30c9	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c9d1661	arch_phys_wc_index
++EXPORT_SYMBOL_GPL vmlinux 0x8c9f5720	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x8cae54b5	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8cd9f935	setup_APIC_eilvt
++EXPORT_SYMBOL_GPL vmlinux 0x8cde0dcd	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0x8cea765f	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x8cf00d6b	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0x8d005769	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x8d068635	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x8d09c1a8	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x8d0e53bf	xenbus_dev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d3018fd	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0x8d3fedd6	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x8d522714	__rcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8d9fa235	acpi_os_map_iomem
++EXPORT_SYMBOL_GPL vmlinux 0x8da1256d	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0x8da19d6e	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8dacb6b5	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x8dc4378e	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0x8e134365	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0x8e21f890	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e2fccfe	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x8e542fbf	fpu__restore
++EXPORT_SYMBOL_GPL vmlinux 0x8e54a221	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x8e5f2865	xen_swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x8e7b4361	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x8e854b7a	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0x8e875419	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x8e90d6ed	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x8ee465af	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8ef6393e	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x8efd5376	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f4483ba	xenbus_register_driver_common
++EXPORT_SYMBOL_GPL vmlinux 0x8f67844e	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0x8f6bd330	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f71628d	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8f7c2e7e	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x8f7d90a5	pinctrl_utils_add_config
++EXPORT_SYMBOL_GPL vmlinux 0x8f9a47a6	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x8fc2963b	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x8ff56c4c	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x9009602a	acpi_bus_get_ejd
++EXPORT_SYMBOL_GPL vmlinux 0x900d8e12	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x90144415	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x90365c0e	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x903bb65b	acpi_dev_resource_ext_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x907feb52	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0x908aa306	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90bbe03b	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0x90c96789	restore_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x90dc29df	aout_dump_debugregs
++EXPORT_SYMBOL_GPL vmlinux 0x90de0452	platform_thermal_package_notify
++EXPORT_SYMBOL_GPL vmlinux 0x912f609d	xen_swiotlb_dma_mapping_error
++EXPORT_SYMBOL_GPL vmlinux 0x913c2ffc	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x914c12e3	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0x915ba58f	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0x91676f39	dax_pfn_mkwrite
++EXPORT_SYMBOL_GPL vmlinux 0x91708adf	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x919ec103	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x91b516fb	xenbus_free_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91d8108a	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x91e5cdbe	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x91f0c992	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0x9203e87b	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x920cc389	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x921cd0a4	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x9227f94f	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0x92410bbf	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x9273028d	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x929167a1	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x92b8118d	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92f81643	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x9312d80e	evtchn_put
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x9322761e	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x932b50f7	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0x933f5639	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x935519ce	clk_multiplier_ops
++EXPORT_SYMBOL_GPL vmlinux 0x935bd2a3	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x93650064	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0x936951f3	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0x936db988	rio_enable_rx_tx_port
++EXPORT_SYMBOL_GPL vmlinux 0x93a82a66	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0x93d8a374	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x93dc2586	pgprot_writethrough
++EXPORT_SYMBOL_GPL vmlinux 0x93ec847e	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x93faad44	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x940224e5	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x94243f93	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x943778ef	xenbus_dev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x943fc708	xen_setup_shutdown_event
++EXPORT_SYMBOL_GPL vmlinux 0x9447291d	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0x9450550e	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x94599c41	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0x946d5e47	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x948c84ad	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x949de465	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x949f7342	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x94a36598	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0x94bf904d	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x94c318be	apei_exec_collect_resources
++EXPORT_SYMBOL_GPL vmlinux 0x94e9aec5	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x9519fcb5	rio_register_mport
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x95538dc6	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x956aab70	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x957e2e60	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x959056d1	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x9591d6d1	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x95b3e62d	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95cba492	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x95d1a7eb	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x95f13fb2	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x95f5d8ce	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0x960b05a6	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0x9618f5c0	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x962b64f3	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x96436239	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x964add15	xenbus_scanf
++EXPORT_SYMBOL_GPL vmlinux 0x964d5c39	acpi_os_map_memory
++EXPORT_SYMBOL_GPL vmlinux 0x965444b2	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9660dd56	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x96626387	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x966d3bbd	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x967672f0	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x96776025	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x968e4266	xen_swiotlb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x96b0b240	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0x96d8d795	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x96e1abc5	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x972ba455	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x97386844	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x973ab8ad	cper_estatus_print
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x9755b52d	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x975bcb4f	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x977d2821	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0x9786a753	clk_fractional_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x97afcb5c	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0x97b132e2	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x98101f7b	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0x9818fcde	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x983f1236	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x987df1a4	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0x98a9a3e1	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x98dccd62	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0x98e5e7fc	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x98f9f73d	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x98ff4efb	pinctrl_pm_select_default_state
++EXPORT_SYMBOL_GPL vmlinux 0x9902f845	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0x99091212	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0x991eddea	pinctrl_force_default
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x9931b9bb	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0x99436736	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x99587230	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x99608282	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x9973add9	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x998d79d6	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x99a9ff9a	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99bfca9c	pinctrl_utils_add_map_mux
++EXPORT_SYMBOL_GPL vmlinux 0x99c02273	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x99cac210	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a247c8e	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x9a4b4442	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0x9a59a92f	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0x9a785c54	rio_mport_class
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9aab1f39	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x9ab14b93	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9ad1b551	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0x9ae66799	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9af4045c	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x9b3e0058	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0x9b422d19	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0x9b6a7412	idle_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x9b720312	acpi_target_system_state
++EXPORT_SYMBOL_GPL vmlinux 0x9b783ddd	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0x9b8f357c	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0x9b934050	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x9b9f3648	pcibios_scan_specific_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9ba1b6d3	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x9ba2bb2b	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x9bac32f6	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9bbd182c	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x9bc44921	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0x9bc5ba84	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x9bc66123	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0x9bca03ca	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0x9bcbeb4b	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0x9bd72b78	apei_write
++EXPORT_SYMBOL_GPL vmlinux 0x9be637f5	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c09dc5c	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x9c10b6d2	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9c1a0797	acpi_subsys_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x9c2de449	memory_add_physaddr_to_nid
++EXPORT_SYMBOL_GPL vmlinux 0x9c2e4b66	acpi_unregister_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x9c462261	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0x9c5b3f25	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x9c73bcfd	acpi_bus_trim
++EXPORT_SYMBOL_GPL vmlinux 0x9c8321ad	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0x9c85ff15	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x9c96a45b	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0x9caabbd3	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9cbab8bb	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cc6f286	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x9cc81dd2	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0x9cd68e75	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9cd6c6d8	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x9cdeeb16	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9ceb69a4	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0x9ced82f9	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x9d06688b	register_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x9d332713	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x9d3850e1	gnttab_alloc_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x9d3dae8a	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x9d71dcec	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9dc42d7e	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0x9dee0a20	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0x9e053cbe	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0x9e05499a	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x9e1e9210	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x9e204943	__clk_mux_determine_rate_closest
++EXPORT_SYMBOL_GPL vmlinux 0x9e32e17c	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x9e3810b8	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e697e8a	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x9e71d7e7	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0x9e86a9f6	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0x9eb9ae87	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x9ec15107	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9efc3651	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0x9f078392	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x9f0bc1e8	device_move
++EXPORT_SYMBOL_GPL vmlinux 0x9f0e20bd	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0x9f1b5ac2	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0x9f2fe763	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x9f428713	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0x9f44f49d	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0x9f4edfc1	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x9f723c5d	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0x9f73ec9d	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0x9f7aa93e	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0x9f849ec1	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x9f92af83	x86_hyper_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x9fc78475	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9fe9c2ec	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0x9fec5b71	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0x9ffb1e73	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0xa00d4bd4	to_nd_blk_region
++EXPORT_SYMBOL_GPL vmlinux 0xa014a6ac	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0xa034d5f7	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0xa054fdee	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0xa05b5234	acpi_dma_request_slave_chan_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xa07c8d9e	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0xa07e90b9	__remove_pages
++EXPORT_SYMBOL_GPL vmlinux 0xa0892273	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xa0b05bff	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa0c082e8	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xa0dd33b0	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xa0f334d1	arch_add_memory
++EXPORT_SYMBOL_GPL vmlinux 0xa10b5001	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0xa11216be	xen_store_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0xa11b55b2	xen_start_info
++EXPORT_SYMBOL_GPL vmlinux 0xa1244ec5	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0xa12fef87	gnttab_unmap_refs_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa1415ac6	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa1462f61	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0xa1498221	__tracepoint_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xa156a1f2	erst_get_record_id_end
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa1b7e4ed	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0xa1bad785	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xa1c10e04	nd_numa_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xa1d27207	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xa1ed9c8b	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xa1f79553	xen_create_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xa206be13	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0xa20afa48	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa2718017	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa2760f6c	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa288e3fe	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0xa2ac5519	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0xa2b1674d	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0xa2b9c993	clk_register_fixed_factor
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2d886ca	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0xa3095369	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xa3298446	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xa34fbd2d	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0xa353fffc	xenbus_rm
++EXPORT_SYMBOL_GPL vmlinux 0xa35d9ef7	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0xa35fe53f	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0xa3748943	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xa3803300	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xa384918b	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa386c029	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa39c87b6	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3aa1e2f	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3e58789	efivar_validate
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa3f918a2	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xa3faf5a6	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0xa4126860	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0xa42aee34	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0xa4415fc2	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0xa452c297	hpet_mask_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa452f2a4	xen_pirq_from_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa4623cbc	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0xa466de38	acpi_processor_ffh_cstate_enter
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa48a5a59	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xa4a1128f	rio_map_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xa4a92c31	input_class
++EXPORT_SYMBOL_GPL vmlinux 0xa4b73f78	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0xa4bd875c	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0xa503918a	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0xa50b1c4d	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0xa54d6636	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0xa57e9c7a	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xa5834428	pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0xa5a3038e	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0xa5baad7a	clk_hw_get_num_parents
++EXPORT_SYMBOL_GPL vmlinux 0xa5ce7e2f	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0xa5da6cdb	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xa5e6ecbe	acpi_subsys_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa60a53ef	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0xa61df3a0	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0xa621d04c	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa62892c6	efivar_sysfs_list
++EXPORT_SYMBOL_GPL vmlinux 0xa62aceda	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0xa64103a9	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xa66438e8	erst_read
++EXPORT_SYMBOL_GPL vmlinux 0xa6647139	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6c32dad	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa6e6237c	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0xa7067a7b	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa70ca802	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0xa7144677	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xa7212498	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0xa7315d7d	xenbus_watch_pathfmt
++EXPORT_SYMBOL_GPL vmlinux 0xa769d2db	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0xa7785599	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0xa799d514	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0xa7c05aff	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa7d34bfc	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0xa7fae3cb	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xa7fe5404	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa801b359	efivar_entry_iter_begin
++EXPORT_SYMBOL_GPL vmlinux 0xa80f3b73	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0xa817074c	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xa81bef70	pinctrl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa820b788	nvdimm_name
++EXPORT_SYMBOL_GPL vmlinux 0xa82b1ba6	acpi_bind_one
++EXPORT_SYMBOL_GPL vmlinux 0xa82eec5e	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0xa845fa52	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa859f6d5	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa8a3f2f6	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8b95bed	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0xa8dac047	mmput
++EXPORT_SYMBOL_GPL vmlinux 0xa8e3efde	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0xa8fd8e84	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa9065f93	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0xa9126bff	hpet_set_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa9143342	find_iova
++EXPORT_SYMBOL_GPL vmlinux 0xa92fdde1	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9303a5b	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa941ed8c	inet_csk_compat_getsockopt
++EXPORT_SYMBOL_GPL vmlinux 0xa97e2997	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0xa99ebb7e	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0xa99f146f	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xa9b94ef1	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xa9d888b1	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xaa18f467	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0xaa3518ce	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xaa60429a	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xaa71cf8f	phy_pm_runtime_put
++EXPORT_SYMBOL_GPL vmlinux 0xaa99aab7	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0xaa9c3d20	pci_get_hp_params
++EXPORT_SYMBOL_GPL vmlinux 0xaaa23d73	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xab01acbe	gnttab_request_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0xab07c28b	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xab1154df	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0xab161e9b	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xab1e0e93	hv_setup_kexec_handler
++EXPORT_SYMBOL_GPL vmlinux 0xab29ad96	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0xab34b564	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0xab387011	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xab54d57c	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0xab567d31	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xab573eb7	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab75d3ce	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0xab86e20c	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0xabbf7416	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabe4c20e	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0xabfb924a	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0xac4c1063	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xac568dc3	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0xac8440fd	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0xac8f64df	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xac8ffef2	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0xac998810	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xac9ce195	kvm_async_pf_task_wait
++EXPORT_SYMBOL_GPL vmlinux 0xaca0adc1	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xaca27e28	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xacae8a02	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0xacafa8e7	vector_used_by_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xacb9a962	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0xaccd6887	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0xacd595b7	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xacdd5d46	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xacffe377	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0xad12cbd7	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0xad13772b	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xad32eb77	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xad541832	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0xad570a4a	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xad8d8ab0	xen_physdev_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0xadaac565	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadd9e496	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xae013184	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0xae15469a	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0xae178a8b	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xae2eef20	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xae2f44a7	acpi_driver_match_device
++EXPORT_SYMBOL_GPL vmlinux 0xae574393	efivar_entry_add
++EXPORT_SYMBOL_GPL vmlinux 0xae5ec4c0	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae6eaf93	hwpoison_filter_dev_minor
++EXPORT_SYMBOL_GPL vmlinux 0xae723c65	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xae737dde	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0xae7a08db	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae7c7c5b	dmi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xae850bcd	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0xaea159a5	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xaeabe2d2	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xaec35d7f	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xaec8fb83	nvdimm_create
++EXPORT_SYMBOL_GPL vmlinux 0xaecba6be	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0xaed8a171	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xaef314e7	usb_acpi_power_manageable
++EXPORT_SYMBOL_GPL vmlinux 0xaefa8537	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0xaf18cd23	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0xaf6bb4ab	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xaf78c803	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0xaf849170	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0xaf89d9db	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0xaf9439db	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xaf9b5aa7	klp_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0xafa4ad4e	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0xafd49fc7	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0xaff3f721	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xaff6cc2f	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0xb0012c5c	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xb00b833e	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xb018830f	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xb02ac411	register_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb02e6bc4	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0xb0345f9e	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb072953c	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0xb077e70a	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xb0864747	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0bce4f0	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xb0c21ccb	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0xb0c4cd53	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0xb0d1656c	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb145a22b	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0xb15845f1	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xb172ffac	efivars_sysfs_init
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb1a5f2fe	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1b370bd	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1bedeb7	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1d93751	put_device
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1ed8d0b	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0xb1f32450	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0xb1f79df5	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0xb2064ee5	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb241f25b	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0xb24a3407	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xb24c95a2	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xb254ea62	rio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb2610308	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0xb26a1add	elfcorehdr_addr
++EXPORT_SYMBOL_GPL vmlinux 0xb275076b	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb292822a	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0xb2c3c7ad	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0xb2d3f997	pcc_mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb2eed852	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0xb312da6a	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0xb31aa325	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0xb3253ed9	hpet_rtc_timer_init
++EXPORT_SYMBOL_GPL vmlinux 0xb347bb2c	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0xb352939f	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb36f6a6f	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0xb3cf9f0d	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xb3db0fe2	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0xb3ec28f7	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0xb408ce20	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0xb429b943	set_foreign_p2m_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xb4548d80	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xb4557e67	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0xb487f5aa	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4bb8a14	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xb4d53c7a	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0xb4e14553	gnttab_query_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea2320	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb53cda0c	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0xb53d7367	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0xb5431454	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb54f4dfa	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb554fb48	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xb55e4b4f	ata_acpi_gtm
++EXPORT_SYMBOL_GPL vmlinux 0xb5652b6a	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xb57bd8d9	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0xb5848bae	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb59d42ef	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5a145bf	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0xb5a92313	klp_disable_patch
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb60717fb	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0xb60c5b60	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0xb61b2abe	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb6230f1f	gnttab_grant_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb6302f7e	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0xb634030d	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb63f50c8	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xb646ccba	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xb64e9b91	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0xb66421b2	acpi_str_to_uuid
++EXPORT_SYMBOL_GPL vmlinux 0xb68f03b4	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0xb6a2fcfd	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6e6d99d	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb6e9ca78	efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0xb6ef5db5	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xb7058cb2	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xb70afe15	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0xb718f2f9	sfi_table_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb7329c06	clk_set_phase
++EXPORT_SYMBOL_GPL vmlinux 0xb73b740a	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0xb755fa04	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0xb75610d8	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xb7718b8b	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xb77f4586	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0xb791c332	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0xb7b7f514	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0xb7d387a2	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xb7d7c12e	hpet_set_alarm_time
++EXPORT_SYMBOL_GPL vmlinux 0xb7daef3c	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xb7e3140f	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0xb7e55c53	xenbus_alloc_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0xb7e72987	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0xb7f65f9c	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb7fa24e8	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xb7fcec43	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0xb80e6fc4	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xb8353296	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xb844a457	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0xb84bb951	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0xb84d5ab4	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0xb8546bef	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb88face7	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xb8a1c88f	rio_release_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xb8a7fe27	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0xb8b2b1f7	mce_register_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0xb8bcb9b7	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8d784b0	gpiochip_add_pin_range
++EXPORT_SYMBOL_GPL vmlinux 0xb8e50962	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xb900c3ee	rio_mport_get_feature
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb93ca495	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0xb945ace8	__tracepoint_remove_device_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xb96d2b99	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0xb977e7fe	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0xb97acb77	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xb99d5837	xenbus_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025ae	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9d2d7df	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0xb9daa999	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0xb9df6c13	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0xb9e59c10	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0xb9ebc031	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0xba00d55d	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0xba041d58	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0xba1124c6	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba302236	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0xba4bf808	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0xba84e06f	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0xba94c685	cper_estatus_check
++EXPORT_SYMBOL_GPL vmlinux 0xbaa0243f	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbac069a2	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xbaf6d630	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xbaf8081f	nvdimm_bus_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0610e3	acpiphp_register_attention
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb162e8e	pinctrl_find_gpio_range_from_pin
++EXPORT_SYMBOL_GPL vmlinux 0xbb1a9621	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0xbb661124	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0xbb6f025a	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0xbb767001	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0xbb768919	rio_mport_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xbb916ca5	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0xbbb98859	edid_info
++EXPORT_SYMBOL_GPL vmlinux 0xbbd4f657	xen_pcpu_id
++EXPORT_SYMBOL_GPL vmlinux 0xbbeea1c0	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0xbc11b69a	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0xbc1c98db	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0xbc1e7480	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0xbc2c4d4c	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xbc4217d4	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0xbc4754cd	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xbc483e6c	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc72075b	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xbc7c88cc	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0xbc8f1670	rio_request_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xbc931ff5	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcb838a1	amd_flush_garts
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd614e80	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xbd671048	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xbd86b127	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xbd9381d1	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0xbdb49968	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbdd5f10f	apei_hest_parse
++EXPORT_SYMBOL_GPL vmlinux 0xbdf01611	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0xbe0500cf	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0xbe0a6d9a	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe5d0996	idle_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe8f4502	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbeaa1cd4	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xbebcd541	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xbebefbe3	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbeeee742	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0xbef4ebf7	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf10959a	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0xbf3c0fe8	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xbf546fa3	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0xbf70c548	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xbf7495b7	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0xbf89379d	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0xbf923f69	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xbf959b8a	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xbfa12f1f	rio_get_comptag
++EXPORT_SYMBOL_GPL vmlinux 0xbfaaafff	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0xbfb1be70	hv_setup_vmbus_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfd10bb7	clk_register_mux_table
++EXPORT_SYMBOL_GPL vmlinux 0xbfe2e9b2	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xbfe80de5	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xbff6079a	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xbff7888b	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xbffde8ec	compat_alloc_user_space
++EXPORT_SYMBOL_GPL vmlinux 0xc00305f6	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0xc0494705	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xc04b21bd	acpi_os_unmap_iomem
++EXPORT_SYMBOL_GPL vmlinux 0xc0506ddd	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0xc05ec844	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc0900fcf	acpi_os_get_iomem
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0b25690	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc0f97dfb	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0xc11db8ba	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0xc1234479	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xc124613a	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0xc12bfc81	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xc13669ad	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0xc145b0d8	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0xc14c2824	xenbus_probe
++EXPORT_SYMBOL_GPL vmlinux 0xc164642e	xenbus_otherend_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc183a7eb	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0xc187696a	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0xc19ce477	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0xc1aa1be6	get_device
++EXPORT_SYMBOL_GPL vmlinux 0xc1b2ab31	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xc1bd8540	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xc1e3c1fc	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0xc1ee3044	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xc1ef4829	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc1fd0b12	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0xc2105ee9	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0xc21b2b05	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc236f924	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0xc240d17f	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xc246b590	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xc254e136	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc25b8971	hv_remove_crash_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc26351f8	bind_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc287d96a	kvm_set_posted_intr_wakeup_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc2b7e1f3	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xc2c5726c	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xc30d161d	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xc31d59a4	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc3567ef3	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0xc357923c	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xc35894d4	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc3783a27	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0xc38f36d9	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc3a04506	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc3a04dcd	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0xc3a9986b	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0xc3add187	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0xc3cc7467	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc3f4cec3	intel_svm_unbind_mm
++EXPORT_SYMBOL_GPL vmlinux 0xc403434d	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc40418c5	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc426bded	xen_xlate_remap_gfn_array
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc447dd93	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xc4508626	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc48182e1	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xc484fd34	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc4a33f79	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xc4ca9428	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4d760c7	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc4e7ac96	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc4fad0ff	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0xc50554d7	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xc512626a	__supported_pte_mask
++EXPORT_SYMBOL_GPL vmlinux 0xc52970ae	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0xc5397da6	xenbus_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xc53c5c8f	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0xc53fea7c	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc5503362	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0xc553768e	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0xc569d8ce	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc59f0196	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0xc5ad2d38	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc5b3406c	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0xc5b51676	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0xc5c4911b	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0xc5d681f2	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc60886ba	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc63e7d93	static_key_deferred_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc64b7d95	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0xc64c5a49	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc66019cc	xen_resume_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc665ec7d	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc6724a93	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc68cefc7	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6a4a872	__clk_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc6bb1366	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0xc6c116ad	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xc6da7a0a	__tracepoint_map
++EXPORT_SYMBOL_GPL vmlinux 0xc7002ac4	evtchn_make_refcounted
++EXPORT_SYMBOL_GPL vmlinux 0xc700bdc6	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0xc7061ef3	iova_cache_put
++EXPORT_SYMBOL_GPL vmlinux 0xc70e7e04	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc75f6d8d	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0xc7659419	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0xc76fa6cf	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7cd6018	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xc7db996a	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7f174be	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc801634d	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0xc81b765d	put_iova_domain
++EXPORT_SYMBOL_GPL vmlinux 0xc8223c68	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0xc8406165	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0xc8466ea0	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0xc856f132	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xc87196ff	rio_local_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc87e487a	sched_clock_idle_sleep_event
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc93b2dc6	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc9641b48	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0xc9705eeb	has_newer_microcode
++EXPORT_SYMBOL_GPL vmlinux 0xc978032f	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0xc996763e	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xc9b60b5f	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xc9c3f176	hpet_register_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc9ca3066	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xca26bd10	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0xca26d568	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0xca294a0c	unregister_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xca3dfe2e	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0xca50734f	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xca52e235	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xca5a79de	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xca6343d1	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0xca73da88	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0xca7903a1	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca81ea9a	xenbus_transaction_end
++EXPORT_SYMBOL_GPL vmlinux 0xca9767cc	xenbus_read_otherend_details
++EXPORT_SYMBOL_GPL vmlinux 0xca985e09	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0xca9e293e	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcae37d01	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xcaf270b4	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xcb056b50	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb1c96a2	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0xcb36c331	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb51b8f7	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0xcb7219a8	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0xcb86998d	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0xcb87014a	ioremap_uc
++EXPORT_SYMBOL_GPL vmlinux 0xcb929e49	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0xcb958c40	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xcbb33d88	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0xcbd0a827	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xcbd2270f	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0xcbdd8f94	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0xcbe068cd	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbe8808d	pinctrl_find_and_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0xcbedba44	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcbf7ddf4	xen_swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0xcbfbddd3	get_hwpoison_page
++EXPORT_SYMBOL_GPL vmlinux 0xcc06ecbf	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0xcc108a68	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcc17495b	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0xcc295ae5	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0xcc2a88fa	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xcc4f5ef9	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0xcc620626	acpi_dev_gpio_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0xcc6213d0	devm_acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xcc7a2922	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc92ce6d	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0xccb84b0a	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0xccbeb2b4	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0xccc24256	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0xccc96910	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccd6e657	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0xccea4e34	perf_get_x86_pmu_capability
++EXPORT_SYMBOL_GPL vmlinux 0xccf7b421	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xcd2253f0	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0xcd4dd163	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0xcd5d4ef9	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0xcd667d7d	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcda2618e	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xcdaf4138	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcdd990a2	efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0xcde34ce3	add_memory_resource
++EXPORT_SYMBOL_GPL vmlinux 0xce12d037	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xce151a36	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0xce28a788	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0xce4f534d	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce84ab19	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0xce9ab7d6	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xceab4b16	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xceacf3d0	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0xceb1f126	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0xceb591a4	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xceb88d4d	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0xcec32fa9	__rio_local_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcee3008d	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcee9837f	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0xceed5627	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0xcef1dd0e	perf_check_microcode
++EXPORT_SYMBOL_GPL vmlinux 0xcef274d3	xen_swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xcf0e9b37	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0xcf53bade	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf5d8585	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0xcf8d9aab	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcf8dbc34	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0xcf8dc0e7	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xcfaf5ead	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0xcfb3a883	acpi_dev_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfe3bdc6	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xcff48317	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd00401d4	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0xd02d0832	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0xd02dbe53	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd040dda2	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xd0458ccb	xenbus_strstate
++EXPORT_SYMBOL_GPL vmlinux 0xd04edf4a	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xd055af5c	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd068342c	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0xd069972c	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xd0c00e36	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0d12e67	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd0dfad1e	xen_swiotlb_sync_sg_for_device
++EXPORT_SYMBOL_GPL vmlinux 0xd0f9eea5	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xd0fddee8	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0xd1403b4d	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0xd14f9678	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xd14f9b42	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xd1507e59	erst_clear
++EXPORT_SYMBOL_GPL vmlinux 0xd1553b3b	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0xd15e91b9	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xd160a17c	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd169e009	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0xd16ab1f4	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0xd17d26b3	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xd1a6b97c	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xd1b4d8d1	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0xd1efdb01	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd1fb0f8f	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd20fe808	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd2400fab	__xenbus_register_backend
++EXPORT_SYMBOL_GPL vmlinux 0xd25205ed	hugetlb_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd25ee25a	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xd25fa113	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xd273207e	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd2817892	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xd281fd05	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xd28285ef	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd2a272c5	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0xd2a61952	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0xd2c58ab2	apei_exec_noop
++EXPORT_SYMBOL_GPL vmlinux 0xd2d1927b	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2e5cda3	pinctrl_force_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xd2e88de5	clk_register_gate
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd2eecfa4	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0xd3052fe8	acpi_subsys_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xd30c4a6d	rio_mport_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xd32dd88c	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0xd37bab0b	__efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0xd38ba998	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0xd3a04a43	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3bb396b	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0xd3bbf198	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0xd3bddcf9	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0xd3d10ac6	nvdimm_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd404a937	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd4080357	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0xd40daf73	acpi_subsys_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd426dbc4	erst_get_record_count
++EXPORT_SYMBOL_GPL vmlinux 0xd42dfb5c	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xd42f55e6	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0xd43eced9	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xd4487fd5	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd45da5d8	nvdimm_volatile_region_create
++EXPORT_SYMBOL_GPL vmlinux 0xd45ea32f	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0xd4826646	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd4914069	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd4b173df	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0xd4b9a449	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xd4ba1891	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0xd4bd66a0	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4ece40c	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0xd4ee9c99	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0xd5030f07	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xd51e7b3f	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0xd534d00d	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0xd54d4ae3	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xd5510d71	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd56b5f64	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0xd58745bf	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0xd590a4d5	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0xd5bb7f68	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5f323a3	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0xd5f8b7e9	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0xd5fb6eb1	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd6171fb7	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd6267717	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0xd63ffa07	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0xd65bd9c8	put_hwpoison_page
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd68a4bd0	to_nvdimm_bus
++EXPORT_SYMBOL_GPL vmlinux 0xd68e6b3c	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0xd6d9c42e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0xd6ed3a8e	cper_next_record_id
++EXPORT_SYMBOL_GPL vmlinux 0xd6f23da3	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0xd6f31808	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0xd6f90089	rio_unmap_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xd6feefa5	agp_num_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd70236dc	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd70f4677	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0xd72feba2	xenbus_read_driver_state
++EXPORT_SYMBOL_GPL vmlinux 0xd7399d2a	efivar_entry_iter_end
++EXPORT_SYMBOL_GPL vmlinux 0xd74a41bd	dummy_con
++EXPORT_SYMBOL_GPL vmlinux 0xd75467f8	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0xd75b6314	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0xd764d265	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd798480f	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0xd7a62b74	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0xd7abf362	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0xd7b81ee0	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xd7c0b43d	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xd7ceaadf	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd8157354	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd82922ac	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0xd82c0dcf	acpi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xd85c1c87	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0xd872d515	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd87b07a7	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd88cd406	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xd8a079df	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0xd8a928ae	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xd8ad827c	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xd8b0a12b	acpi_pci_check_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xd8b3d780	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xd8b85191	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xd8cf61d7	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xd8dfcfad	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0xd8e0abdc	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0xd8f41fc8	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0xd9028f13	acpi_dev_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xd905f38f	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd919806a	amd_cache_northbridges
++EXPORT_SYMBOL_GPL vmlinux 0xd923afae	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0xd93263ca	rio_dev_get
++EXPORT_SYMBOL_GPL vmlinux 0xd935292f	apic
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94cccdf	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd94fa823	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd96bc1a5	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0xd97fd282	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xd986dad1	kernel_fpu_begin
++EXPORT_SYMBOL_GPL vmlinux 0xd98c72a5	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0xd9944232	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xd9b207c9	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xd9f39e86	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xda206f28	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0xda389561	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0xda3c5859	acpiphp_unregister_attention
++EXPORT_SYMBOL_GPL vmlinux 0xda8d4921	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0xda959746	__nvdimm_bus_register
++EXPORT_SYMBOL_GPL vmlinux 0xdaa06dc1	acpi_lpat_raw_to_temp
++EXPORT_SYMBOL_GPL vmlinux 0xdab77d12	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0xdadfd290	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0xdae4ac06	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdb1a046c	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xdb446afa	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb622cd3	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0xdb63a944	acpi_lpat_get_conversion_table
++EXPORT_SYMBOL_GPL vmlinux 0xdb69993c	rio_request_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xdb747300	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xdb7a3c9c	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb916fd0	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0xdb91e05c	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xdb95874e	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0xdbea5ca1	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc14a211	xen_hvm_evtchn_do_upcall
++EXPORT_SYMBOL_GPL vmlinux 0xdc188b7c	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdc1d0f9f	efivar_entry_find
++EXPORT_SYMBOL_GPL vmlinux 0xdc2bcbb2	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0xdc6699cb	acpi_dev_free_resource_list
++EXPORT_SYMBOL_GPL vmlinux 0xdc7cab5a	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc90ae6d	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0xdc90e889	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9945db	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdcb24901	usb_acpi_set_power_state
++EXPORT_SYMBOL_GPL vmlinux 0xdcb2d696	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xdcdb6a02	nd_blk_region_set_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0xdce4f03f	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xdceba854	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd18aff5	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd227165	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd39bb3b	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xdd415154	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xdd57e2b5	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0xdd58945d	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0xdd599a4a	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xdd7606f4	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0xdd9a5346	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0xddb6ca47	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddbf42da	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xddedecdf	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0xddfd51dc	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xde16f9f0	__rio_local_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xde183315	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0xde1cf934	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0xde1e684e	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0xde46e353	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xde709102	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0xde78f368	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xde7bf22d	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xde804b73	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0xde8dd926	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0xde9e2403	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xdeac5ef5	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xdeb13647	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xdeea23a0	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0xdefb2759	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf1882af	dbgp_reset_prep
++EXPORT_SYMBOL_GPL vmlinux 0xdf210213	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0xdf36c66a	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0xdf55fc18	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0xdf5df374	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0xdf622181	clk_register_divider_table
++EXPORT_SYMBOL_GPL vmlinux 0xdf66ca81	ucode_cpu_info
++EXPORT_SYMBOL_GPL vmlinux 0xdf75282c	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0xdf776b91	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0xdf8c4a76	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xdf8d8892	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0xdfa19ce8	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xdfa6fa56	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xdfaca769	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdfcbca60	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0xe0026fda	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe0159c1e	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0xe022dd0f	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe0427277	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0xe04b7dfc	clk_register_mux
++EXPORT_SYMBOL_GPL vmlinux 0xe05128b5	__add_pages
++EXPORT_SYMBOL_GPL vmlinux 0xe052aaf6	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0xe05e8ebc	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe0862031	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xe0873918	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0xe088667c	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xe089cfcc	agp_memory_reserved
++EXPORT_SYMBOL_GPL vmlinux 0xe0ada9b0	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0xe0addfbb	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0xe0b1c103	clk_set_max_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe0c77bb5	mce_notify_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe0c811b0	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xe0ceec30	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0xe0d151fc	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0xe0d4189e	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xe0fc070c	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xe10cd6ad	erst_get_record_id_begin
++EXPORT_SYMBOL_GPL vmlinux 0xe140c1bf	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0xe149f7d2	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xe16b0d30	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe1749431	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe18ad747	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0xe1b1d5e5	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xe1b592ba	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xe1bd6c99	rio_init_mports
++EXPORT_SYMBOL_GPL vmlinux 0xe1ee951a	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0xe1f1f309	x86_vector_domain
++EXPORT_SYMBOL_GPL vmlinux 0xe1f8b106	apei_get_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0xe218ed70	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xe2311567	rio_lock_device
++EXPORT_SYMBOL_GPL vmlinux 0xe25349e0	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xe25ec4ee	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xe27e694a	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xe2866cd7	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe29349dc	copy_reserved_iova
++EXPORT_SYMBOL_GPL vmlinux 0xe295c0ff	is_hpet_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe2abd6d2	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xe2fad8ff	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe310ad3f	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0xe323c797	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0xe33e5f6c	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0xe35f9cba	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0xe36547aa	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0xe3925249	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe3948ff4	acpi_walk_dep_device_list
++EXPORT_SYMBOL_GPL vmlinux 0xe39e9089	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xe3b1d5f9	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0xe3b97803	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xe3bc7fd4	hpet_unregister_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe3bda663	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe3c7022e	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe3cb7b6b	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0xe4015746	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0xe41534ce	bind_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0xe418fde4	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xe427d54d	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xe42b0091	find_module
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe44796a6	__clk_get_hw
++EXPORT_SYMBOL_GPL vmlinux 0xe4594cc5	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0xe466f8d1	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe47d9548	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xe48726d3	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe49d9769	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xe4b271a6	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4e68bc8	apei_map_generic_address
++EXPORT_SYMBOL_GPL vmlinux 0xe4ef5bf9	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xe4fe400a	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0xe50e2398	pinctrl_utils_add_map_configs
++EXPORT_SYMBOL_GPL vmlinux 0xe514d401	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xe5175d56	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0xe5243788	efivars_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe5261477	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0xe52c8173	__clk_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe545a811	get_xsave_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe5648b55	xenbus_switch_state
++EXPORT_SYMBOL_GPL vmlinux 0xe5677213	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0xe5867495	acpi_create_platform_device
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58d647f	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe59c3a7f	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0xe5a15097	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0xe5aa134b	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0xe5b478c7	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0xe5b5cf44	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0xe5b8082b	cper_estatus_check_header
++EXPORT_SYMBOL_GPL vmlinux 0xe5f9c10d	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xe61ba4ce	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0xe627cad9	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0xe64ad8ea	unregister_nmi_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe651539d	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe65b093b	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0xe660d527	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0xe66f1fc5	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6ed141e	xenbus_map_ring
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe6f83837	acpi_bus_attach_private_data
++EXPORT_SYMBOL_GPL vmlinux 0xe7232e0f	user_return_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe746849a	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe756105e	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0xe768d444	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe7b4350e	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0xe7b48a29	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0xe7bb9f21	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0xe7cd9289	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0xe7e2a728	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xe7f68a35	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0xe7f96857	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe8155bfe	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe862cc89	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0xe8762a49	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xe87e2d0c	xen_xlate_unmap_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0xe88083cf	gpiochip_add_pingroup_range
++EXPORT_SYMBOL_GPL vmlinux 0xe8898891	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0xe89bd243	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xe8b23a3c	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xe8cc1251	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0xe8f46963	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0xe9087543	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0xe90c2e7c	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe91a63e2	acpi_node_get_property_reference
++EXPORT_SYMBOL_GPL vmlinux 0xe91d6e27	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe97c3ed2	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xe9859f40	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0xe99144b6	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xe9b4e993	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0xe9ce931a	kvm_para_available
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea147be6	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea433c60	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0xea4ebd64	xenbus_frontend_closed
++EXPORT_SYMBOL_GPL vmlinux 0xea563046	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0xea628c20	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0xea6a905b	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xea9fd51f	rio_get_asm
++EXPORT_SYMBOL_GPL vmlinux 0xeaa9fe7a	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0xeafd7930	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0xeb194e2b	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0xeb2798f7	xen_destroy_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xeb2eb288	efivar_variable_is_removable
++EXPORT_SYMBOL_GPL vmlinux 0xeb306801	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0xeb370805	__apei_exec_run
++EXPORT_SYMBOL_GPL vmlinux 0xeb4428e3	pinconf_generic_dump_config
++EXPORT_SYMBOL_GPL vmlinux 0xeb4ff736	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0xeb7c8bd8	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xeb7d183e	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0xeb8274d2	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0xeb833c22	xen_has_pv_disk_devices
++EXPORT_SYMBOL_GPL vmlinux 0xeb99d2c6	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xebafb77f	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec3e636f	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0xec4012f8	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xec631f34	remove_memory
++EXPORT_SYMBOL_GPL vmlinux 0xec7cff9c	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xec938cae	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0xecad3b34	do_machine_check
++EXPORT_SYMBOL_GPL vmlinux 0xecba321c	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0xecd6fdfb	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xece7dfaf	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0xeced40c5	gnttab_map_refs
++EXPORT_SYMBOL_GPL vmlinux 0xecfdbfc4	clk_hw_get_parent_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xed0a1f4d	efivars_register
++EXPORT_SYMBOL_GPL vmlinux 0xed200276	rio_release_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xed4b1df4	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0xed5080d2	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0xed565d63	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xed6b8c01	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0xed7e81e0	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0xed981a16	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xed9ce7ef	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0xeda8652c	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0xedbc6f67	gnttab_end_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xedcdffd4	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0xedee1f76	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0xee0b212f	acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xee0b47f6	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0xee13e697	set_personality_ia32
++EXPORT_SYMBOL_GPL vmlinux 0xee302af2	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0xee3c9892	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee86d70b	acpi_ec_remove_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0xee9caf6c	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0xeebcf5ad	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xeee22cb8	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xef002518	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0xef1973b5	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xef1f6e23	apei_resources_request
++EXPORT_SYMBOL_GPL vmlinux 0xef351018	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0xef48aba9	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xef5b97c0	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6d007a	sigset_from_compat
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xef9632d6	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xefa045a2	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefbb05b2	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xefc16059	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xefc4c902	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0xefc50d37	default_iommu_map_sg
++EXPORT_SYMBOL_GPL vmlinux 0xefc94c6a	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf013f921	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0xf0318dfe	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xf0387355	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf057c960	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xf06906d2	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0xf0696401	acpi_pci_detect_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xf06ec677	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0xf06fcbfa	clk_hw_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf091145e	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0xf0b553ab	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4cfa3	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xf0df784c	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf1049874	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xf10a0e73	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0xf10f2818	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0xf14e4d24	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xf15f8543	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf192b79f	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1b551d9	ibft_addr
++EXPORT_SYMBOL_GPL vmlinux 0xf1d17057	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0xf1dab640	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0xf1fcbccb	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xf1ff48f2	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf222aa67	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0xf2275924	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0xf229b2e9	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0xf241f6b6	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xf24a02f6	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0xf26084bd	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf2672510	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0xf27769d7	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf291252d	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0xf29d3999	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xf2a52e1b	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2b27a06	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0xf2ded878	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xf2f8f75f	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf32bdc5d	unregister_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf33dc43c	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xf3623cfb	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf368769d	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0xf3696ee5	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0xf36af28b	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0xf37453ed	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf3815391	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0xf38922f9	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xf3894916	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0xf38b19cb	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3b84dfb	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3c7cdce	acpi_device_modalias
++EXPORT_SYMBOL_GPL vmlinux 0xf3d00667	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf3d16a69	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0xf3dd3ec1	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf3ebf4eb	arch_apei_report_mem_error
++EXPORT_SYMBOL_GPL vmlinux 0xf3effa9a	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf3f4cc5e	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf3fe15a0	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xf4029d4d	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0xf436327e	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xf442843b	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xf46ea06b	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4ab256f	acpi_device_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xf4ba0eb4	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf4ba53a2	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0xf4baeca1	acpi_gpiochip_request_interrupts
++EXPORT_SYMBOL_GPL vmlinux 0xf4dbbb9d	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf52a8ffa	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xf5379771	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xf53c7269	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0xf5488ffc	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf5774c77	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0xf5785b42	evtchn_get
++EXPORT_SYMBOL_GPL vmlinux 0xf589ff6c	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0xf5945bac	gnttab_free_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0xf5a38b70	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5d0e69d	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xf609a771	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0xf6185bb8	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0xf62e9f01	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xf631d525	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0xf644c626	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0xf6a9556a	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xf6b2052b	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0xf6c71a25	cper_severity_str
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6ce4173	__efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0xf6d3843a	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xf6da310d	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0xf6e29632	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf6ebc4e4	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0xf6ecc1d7	gnttab_unmap_refs_async
++EXPORT_SYMBOL_GPL vmlinux 0xf6eefa76	nd_blk_region_to_dimm
++EXPORT_SYMBOL_GPL vmlinux 0xf6f095bd	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0xf7016530	xenbus_gather
++EXPORT_SYMBOL_GPL vmlinux 0xf70e4a4d	preempt_schedule_notrace
++EXPORT_SYMBOL_GPL vmlinux 0xf72f4da0	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0xf780f563	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0xf79d79cf	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xf7a1bb8f	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xf7a2de26	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xf7b1bb03	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0xf7bc099c	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0xf7c3f273	xen_resume_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xf7cbe304	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0xf7dfd765	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xf7e48691	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0xf7f07a0f	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf8070ec3	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xf811b466	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0xf8142a5a	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf8374a0a	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0xf8420c3b	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf8990820	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xf89be8d7	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0xf8df41dc	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xf8e29f0a	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0xf8e6b564	hibernation_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8e809dd	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0xf8e9459e	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf90da188	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf91774e0	dax_fault
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf94de4cb	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf9765833	dmi_match
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9a55249	rio_route_add_entry
++EXPORT_SYMBOL_GPL vmlinux 0xf9a99f22	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0xf9ace424	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xf9af67de	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9d9264e	xen_have_vector_callback
++EXPORT_SYMBOL_GPL vmlinux 0xf9de6aea	ata_acpi_gtm_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9e53e2a	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0xf9e97f92	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xf9f04dac	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xf9f5d2f3	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0xf9fb2f04	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xfa003ad5	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xfa0d3900	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa35044a	alternatives_patched
++EXPORT_SYMBOL_GPL vmlinux 0xfa456414	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0xfa901b31	compat_get_timespec
++EXPORT_SYMBOL_GPL vmlinux 0xfa9e33f7	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0xfaa25473	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xfab78d03	acpi_dev_get_resources
++EXPORT_SYMBOL_GPL vmlinux 0xfacbe684	__rio_local_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xfadfb9ee	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0xfae1a7a3	__online_page_increment_counters
++EXPORT_SYMBOL_GPL vmlinux 0xfaf302b4	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0xfb0047f6	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0xfb0319d2	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0xfb11c599	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xfb25ce06	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb383515	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfb6358f9	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xfb64b230	acpi_processor_ffh_cstate_probe
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb9b68a6	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xfba4fff6	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0xfbb440fd	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0xfbb8f837	nvdimm_pmem_region_create
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfbcb0f80	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xfbdc5496	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xfbe020f8	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xfbee0324	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc053274	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xfc08c89a	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xfc201b66	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0xfc254d15	gnttab_free_auto_xlat_frames
++EXPORT_SYMBOL_GPL vmlinux 0xfc2adfd2	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xfc3b4246	acpi_bus_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xfc473d7e	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xfc4c6263	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0xfc62c492	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xfc968c8b	apei_exec_write_register_value
++EXPORT_SYMBOL_GPL vmlinux 0xfca6bc38	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0xfcc89d2b	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfcddf0ca	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xfce35802	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0xfd51b281	gnttab_end_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0xfd63cbd7	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xfd7243c7	erst_disable
++EXPORT_SYMBOL_GPL vmlinux 0xfd792dd1	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd9437b4	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfdccc149	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xfe0267ad	__rio_local_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xfe055d7c	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0xfe085d1f	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0xfe0c5bf0	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0xfe0d7572	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0xfe2d93ed	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xfe4684ae	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xfe5f6506	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xfe6249f1	rio_release_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xfe727411	get_phys_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0xfe7406a7	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0xfe87711a	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xfe8893ac	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfe9d94da	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0xfea6b569	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0xfeb4b008	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0xfebe0af2	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0xfec85113	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfee02f24	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xfee83cc3	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfef4be1f	acpi_dev_pm_attach
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff0a3c33	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0xff291ecf	clk_unregister_divider
++EXPORT_SYMBOL_GPL vmlinux 0xff2ce747	machine_check_poll
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff5f427c	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff966377	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xffab90cf	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffb87dd2	rio_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0xffba4dfb	clk_fixed_rate_ops
+diff --git a/debian.master/abi/4.4.0-111.134/amd64/lowlatency.compiler b/debian.master/abi/4.4.0-111.134/amd64/lowlatency.compiler
+new file mode 100644
+index 0000000..d1936f3
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/amd64/lowlatency.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/amd64/lowlatency.modules b/debian.master/abi/4.4.0-111.134/amd64/lowlatency.modules
+new file mode 100644
+index 0000000..ff4743f
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/amd64/lowlatency.modules
+@@ -0,0 +1,4616 @@
++3c574_cs
++3c589_cs
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_dw
++8250_fintek
++8250_mid
++8255
++8255_pci
++8390
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++BusLogic
++DAC960
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++abituguru
++abituguru3
++ablk_helper
++ac97_bus
++acard-ahci
++acecad
++acenic
++acer-wmi
++acerhdf
++acpi-als
++acpi_extlog
++acpi_ipmi
++acpi_pad
++acpi_power_meter
++acpi_thermal_rel
++acpiphp_ibm
++acquirewdt
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7170
++adv7175
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++advantechwdt
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++aes-x86_64
++aesni-intel
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++ah4
++ah6
++aha152x_cs
++ahci
++ahci_platform
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airo
++airo_cs
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++ali-ircc
++alienware-wmi
++alim1535_wdt
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am53c974
++ambassador
++amc6821
++amd
++amd-rng
++amd5536udc
++amd64_edac_mod
++amd76xrom
++amd8111e
++amd_freq_sensitivity
++amd_iommu_v2
++amdgpu
++amdkfd
++amilo-rfkill
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apanel
++apds9300
++apds9802als
++apds990x
++apds9960
++apple-gmux
++apple_bl
++appledisplay
++applesmc
++appletalk
++appletouch
++applicom
++aquantia
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_ps2
++arc_uart
++arcfb
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3935
++as5011
++asb100
++asc7621
++ascot2e
++asix
++ast
++asus-laptop
++asus-nb-wmi
++asus-wmi
++asus_atk0110
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atlas_btns
++atm
++atmel
++atmel_cs
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp
++atp870u
++atusb
++atxp1
++aty128fb
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avm_cs
++avma1_cs
++avmfritz
++ax25
++ax88179_178a
++axnet_cs
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1pci
++b1pcmcia
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcma
++bcma-hcd
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish-x86_64
++blowfish_common
++blowfish_generic
++bluecard_cs
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpck
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmsmac
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bt3c_cs
++bt819
++bt856
++bt866
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btuart_cs
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c2port-duramar2150
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia-aesni-avx-x86_64
++camellia-aesni-avx2
++camellia-x86_64
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5-avx-x86_64
++cast5_generic
++cast6-avx-x86_64
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_das16_cs
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc10001_adc
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++ccp
++ccp-crypto
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfag12864b
++cfag12864bfb
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20-x86_64
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipreg
++chnl_net
++chromeos_laptop
++chromeos_pstore
++ci_hdrc
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++ck804xrom
++classmate-laptop
++clip
++clk-cdce706
++clk-palmas
++clk-pwm
++clk-s2mps11
++clk-si5351
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cm4000_cs
++cm4040_cs
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmtp
++cnic
++cobalt
++cobra
++coda
++com20020
++com20020-pci
++com20020_cs
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_isadma
++comedi_parport
++comedi_pci
++comedi_pcmcia
++comedi_test
++comedi_usb
++comm
++compal-laptop
++configfs
++contec_pci_dio
++cordic
++core
++coretemp
++cosm_bus
++cosm_client
++cp210x
++cpcihp_generic
++cpcihp_zt5550
++cpia2
++cpsw_ale
++cpu-notifier-error-inject
++cpu5wdt
++cpuid
++cr_bllcd
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc32-pclmul
++crc7
++crc8
++crct10dif-pclmul
++cros_ec
++cros_ec_devs
++cros_ec_i2c
++cros_ec_keyb
++cros_ec_lpc
++cros_ec_spi
++crvml
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++csiostor
++ct82c710
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_cs
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++db9
++dc395x
++dca
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++dcdbas
++ddbridge
++de2104x
++de4x5
++decnet
++deflate
++defxx
++dell-laptop
++dell-led
++dell-rbtn
++dell-smm-hwmon
++dell-smo8800
++dell-wmi
++dell-wmi-aio
++dell_rbu
++denali
++denali_dt
++denali_pci
++des3_ede-x86_64
++des_generic
++designware_i2s
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9601
++dme1737
++dmfe
++dmi-sysfs
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++dp83848
++dp83867
++dpt_i2o
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dtl1_cs
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_wdt
++dwc3
++dwc3-pci
++dwmac-generic
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++e752x_edac
++earth-pt1
++earth-pt3
++eata
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++ec_bhf
++ec_sys
++echainiv
++echo
++edac_core
++edac_mce_amd
++edt-ft5x06
++eeepc-laptop
++eeepc-wmi
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efi-pstore
++efi_test
++efs
++ehset
++einj
++elan_i2c
++elo
++elsa_cs
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++empeg
++ems_pci
++ems_pcmcia
++ems_usb
++emu10k1-gp
++ena
++enc28j60
++enclosure
++encx24j600
++encx24j600-regmap
++ene_ir
++eni
++enic
++epat
++epia
++epic100
++eql
++esas2r
++esb2rom
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++eurotechwdt
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++ezusb
++f2fs
++f71805f
++f71808e_wdt
++f71882fg
++f75375s
++f81232
++fakelb
++fam15h_power
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_sys_fops
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdomain_cs
++fdp
++fdp_i2c
++fealnx
++ff-memless
++fintek-cir
++firedtv
++firestream
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fixed
++fjes
++fl512
++flexfb
++floppy
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fmvj18x_cs
++fnic
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fschmd
++fsl_lpuart
++ft6236
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu-laptop
++fujitsu-tablet
++fujitsu_ts
++g450_pll
++g760a
++g762
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcm
++gdmtty
++gdmulte
++gdmwm
++gdth
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++genwqe_card
++gf128mul
++gf2k
++gfs2
++ghash-clmulni-intel
++ghash-generic
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++glue_helper
++gluebi
++gma500_gfx
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-104-idio-16
++gpio-addr-flash
++gpio-adp5520
++gpio-adp5588
++gpio-amd8111
++gpio-amdpt
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-f7188x
++gpio-fan
++gpio-generic
++gpio-ich
++gpio-ir-recv
++gpio-it87
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-rdc321x
++gpio-regulator
++gpio-sch
++gpio-sch311x
++gpio-tps65912
++gpio-twl4030
++gpio-twl6040
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mouse
++gpio_tilt_polled
++gr_udc
++grace
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++gxt4500
++hackrf
++hamachi
++hampshire
++hangcheck-timer
++hanwang
++hci
++hci_uart
++hci_vhci
++hdaps
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hecubafb
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfi1
++hfs
++hfsplus
++hgafb
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-hyperv
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++hih6130
++hio
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi504_nand
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hopper
++horizon
++horus3a
++hostap
++hostap_cs
++hostap_pci
++hostap_plx
++hp-wireless
++hp-wmi
++hp100
++hp_accel
++hpfs
++hpilo
++hpsa
++hptiop
++hpwdt
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++htc-pasic3
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hv_balloon
++hv_netvsc
++hv_storvsc
++hv_utils
++hv_vmbus
++hwa-hc
++hwa-rc
++hwmon-vid
++hwpoison-inject
++hx8357
++hyperv-keyboard
++hyperv_fb
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd756-s4882
++i2c-amd8111
++i2c-cbus-gpio
++i2c-cros-ec-tunnel
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-emev2
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-ismt
++i2c-kempld
++i2c-matroxfb
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-pinctrl
++i2c-mux-reg
++i2c-nforce2
++i2c-nforce2-s4985
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-piix4
++i2c-robotfuzz-osif
++i2c-scmi
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i3000_edac
++i3200_edac
++i40e
++i40evf
++i5000_edac
++i5100_edac
++i5400_edac
++i5500_temp
++i5k_amb
++i6300esb
++i7300_edac
++i7300_idle
++i740fb
++i7core_edac
++i82092
++i82975x_edac
++i915
++i915_bpo
++iTCO_vendor_support
++iTCO_wdt
++ib700wdt
++ib_addr
++ib_cm
++ib_core
++ib_ipath
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_qib
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibm_rtl
++ibmaem
++ibmasm
++ibmasr
++ibmpex
++ichxrom
++icp_multi
++icplus
++ics932s401
++ideapad-laptop
++ideapad_slidebar
++idma64
++idmouse
++idt77252
++idt_gen2
++idtcps
++ie31200_edac
++ie6xx_wdt
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imm
++imon
++ims-pcu
++imx074
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int3400_thermal
++int3402_thermal
++int3403_thermal
++int340x_thermal_zone
++int51x1
++intel-hid
++intel-lpss
++intel-lpss-acpi
++intel-lpss-pci
++intel-rng
++intel-rst
++intel-smartconnect
++intel-vbtn
++intel_ips
++intel_menlow
++intel_oaktrail
++intel_pch_thermal
++intel_pmc_ipc
++intel_powerclamp
++intel_punit_ipc
++intel_qat
++intel_quark_i2c_gpio
++intel_rapl
++intel_soc_dts_iosf
++intel_soc_dts_thermal
++intel_telemetry_core
++intel_telemetry_debugfs
++intel_telemetry_pltdrv
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++intelfb
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioatdma
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipwireless
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++irlan
++irnet
++irqbypass
++irtty-sir
++isci
++iscsi_boot_sysfs
++iscsi_ibft
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it87
++it8712f_wdt
++it87_wdt
++it913x
++itd1000
++ite-cir
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++k10temp
++k8temp
++kafs
++kalmia
++kaweth
++kb3886_bl
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks0108
++ks0127
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kvm
++kvm-amd
++kvm-intel
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l440gx
++l4f00242t03
++l64781
++lan78xx
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-adp5520
++leds-bd2802
++leds-blinkm
++leds-clevo-mail
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-pwm
++leds-regulator
++leds-ss4200
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libahci_platform
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_cs
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++liquidio
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++litelink-sir
++lkkbd
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lmc
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac80211
++mac80211_hwsim
++mac802154
++mac_hid
++macb
++machzwd
++macmodes
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++marvell
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77693
++max77693-haptic
++max77693_charger
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mce-inject
++mce_amd_inj
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++mdc800
++mdio
++mdio-bcm-unimac
++mdio-bitbang
++mdio-cavium
++mdio-gpio
++mdio-octeon
++mdio-thunder
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++mei
++mei-me
++mei-txe
++mei_phy
++memory-notifier-error-inject
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++metro-usb
++metronomefb
++meye
++mf6x4
++mga
++mic_bus
++mic_card
++mic_cosm
++mic_host
++mic_x100_dma
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microread_mei
++microtek
++mii
++minix
++mip6
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmc_block
++mmc_spi
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi-laptop
++msi-wmi
++msi001
++msi2500
++msp3400
++mspro_block
++msr
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtd_dataflash
++mtdblock
++mtdblock_ro
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-sd
++mtouch
++multipath
++multiq3
++musb_hdrc
++mv_u3d_core
++mv_udc
++mvmdio
++mvsas
++mvumi
++mwave
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxc4005
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxm-wmi
++mxser
++mxuport
++myri10ge
++n411
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nci
++nci_spi
++nci_uart
++ncpfs
++nct6683
++nct6775
++nct7802
++nct7904
++nd_blk
++nd_btt
++nd_pmem
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++nettel
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfit
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_daq_700
++ni_daq_dio24
++ni_labpc
++ni_labpc_common
++ni_labpc_cs
++ni_labpc_isadma
++ni_labpc_pci
++ni_mio_cs
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicpf
++nicstar
++nicvf
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nmclan_cs
++nosy
++notifier-error-inject
++nouveau
++nozomi
++ns558
++ns83820
++nsc-ircc
++ntb
++ntb_hw_amd
++ntb_hw_intel
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nuvoton-cir
++nv_tco
++nvidiafb
++nvme
++nvmem_core
++nvram
++nxp-nci
++nxp-nci_i2c
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_xilinx_wdt
++old_belkin-sir
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_cs
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p4-clockmod
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++padlock-aes
++padlock-sha
++palmas-pwrbutton
++palmas-regulator
++panasonic-laptop
++pandora_bl
++panel
++paride
++parkbd
++parport
++parport_ax88796
++parport_cs
++parport_pc
++parport_serial
++pata_acpi
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pcmcia
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sl82c105
++pata_triflex
++pata_via
++pc300too
++pc87360
++pc87413_wdt
++pc87427
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_udc
++pci
++pci-hyperv
++pci-stub
++pci200syn
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmcia
++pcmcia_core
++pcmcia_rsrc
++pcmciamtd
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcnet_cs
++pcrypt
++pcspkr
++pcwd_pci
++pcwd_usb
++pd
++pd6729
++pda_power
++pdc_adma
++peak_pci
++peak_pcmcia
++peak_usb
++pegasus
++penmount
++percpu_test
++pf
++pfuze100-regulator
++pg
++phantom
++phonet
++phram
++phy-bcm-kona-usb2
++phy-exynos-usb2
++phy-gpio-vbus-usb
++phy-isp1301
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-tahvo
++phy-tusb1210
++physmap
++pinctrl-broxton
++pinctrl-intel
++pinctrl-sunrisepoint
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl2303
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8941-wled
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pn533
++pn544
++pn544_i2c
++pn544_mei
++pn_pep
++poly1305-x86_64
++poly1305_generic
++port100
++powermate
++powr1220
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_core
++pps_parport
++pptp
++prism2_usb
++processor_thermal_device
++ps2mult
++psmouse
++psnap
++pt
++ptp
++pulsedlight-lidar-lite-v2
++punit_atom_debug
++pvpanic
++pvrusb2
++pwc
++pwm-beeper
++pwm-lp3943
++pwm-lpss
++pwm-lpss-pci
++pwm-lpss-platform
++pwm-pca9685
++pwm-regulator
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa27x_udc
++qat_dh895xcc
++qat_dh895xccvf
++qcaux
++qcom-spmi-iadc
++qcom-spmi-vadc
++qcom_spmi-regulator
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qlogic_cs
++qlogicfas408
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quatech_daqp_cs
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-bcm2048
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-shark
++radio-si476x
++radio-tea5764
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++ray_cs
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++reed_solomon
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio-scan
++rio500
++rionet
++rivafb
++rj54n1cb0c
++rmd128
++rmd160
++rmd256
++rmd320
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-bq32k
++rtc-bq4802
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-hid-sensor-time
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-msm6242
++rtc-mt6397
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-r9701
++rtc-rc5t583
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-twl
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7110
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7185
++saa7706h
++safe_serial
++salsa20-x86_64
++salsa20_generic
++samsung-keypad
++samsung-laptop
++samsung-q10
++samsung-sxgbe
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_sil
++sata_sil24
++sata_sis
++sata_svw
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sb1000
++sb_edac
++sbc60xxwdt
++sbc_epx_c3
++sbc_fitpc2_wdt
++sbc_gxx
++sbni
++sbp_target
++sbs
++sbs-battery
++sbshc
++sc1200wdt
++sc16is7xx
++sc92031
++sca3000
++scb2_flash
++sch311x_wdt
++sch5627
++sch5636
++sch56xx-common
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scif
++scif_bus
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++sdhci
++sdhci-acpi
++sdhci-pci
++sdhci-pltfm
++sdio_uart
++sdricoh_cs
++sedlbauer_cs
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial2002
++serial_cs
++serio_raw
++sermouse
++serpent-avx-x86_64
++serpent-avx2
++serpent-sse2-x86_64
++serpent_generic
++serport
++ses
++sfc
++sh_veu
++sha1-mb
++sha1-ssse3
++sha256-ssse3
++sha512-ssse3
++shark2
++shpchp
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sir-dev
++sis
++sis-agp
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skd
++skfp
++skge
++skx_edac
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++sl811_cs
++slcan
++slicoss
++slip
++slram
++sm501
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smc91c92_cs
++smipcie
++smm665
++smsc
++smsc-ircc2
++smsc37b787_wdt
++smsc47b397
++smsc47m1
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4117
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als300
++snd-als4000
++snd-asihpi
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt3328
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-compress
++snd-cs4281
++snd-cs46xx
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1938
++snd-es1968
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-ext-core
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel-sst-acpi
++snd-intel-sst-core
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm
++snd-pcm-dmaengine
++snd-pcm-oss
++snd-pcsp
++snd-pcxhr
++snd-pdaudiocf
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-sb-common
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-core
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-dmic
++snd-soc-es8328
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-ssi
++snd-soc-gtm601
++snd-soc-imx-audmux
++snd-soc-max98090
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rl6231
++snd-soc-rl6347a
++snd-soc-rt286
++snd-soc-rt5631
++snd-soc-rt5640
++snd-soc-rt5645
++snd-soc-rt5660
++snd-soc-rt5670
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-skl
++snd-soc-skl-ipc
++snd-soc-skl_rt286
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sst-acpi
++snd-soc-sst-baytrail-pcm
++snd-soc-sst-broadwell
++snd-soc-sst-byt-max98090-mach
++snd-soc-sst-byt-rt5640-mach
++snd-soc-sst-bytcr-rt5640
++snd-soc-sst-bytcr-rt5660
++snd-soc-sst-cht-bsw-max98090_ti
++snd-soc-sst-cht-bsw-rt5645
++snd-soc-sst-cht-bsw-rt5672
++snd-soc-sst-dsp
++snd-soc-sst-haswell
++snd-soc-sst-haswell-pcm
++snd-soc-sst-ipc
++snd-soc-sst-mfld-platform
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-xtfpga-i2s
++snd-sonicvibes
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-us122l
++snd-usb-usx2y
++snd-usb-variax
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-vxpocket
++snd-ymfpci
++snic
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++softdog
++softing
++softing_cs
++solo6x10
++solos-pci
++sony-btf-mpx
++sony-laptop
++soundcore
++sp2
++sp5100_tco
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_dectlk
++speakup_dummy
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++spectrum_cs
++speedfax
++speedstep-lib
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi-lm70llp
++spi-nor
++spi-oc-tiny
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tle62x0
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spl
++splat
++spmi
++sr9700
++sr9800
++ssb
++ssb-hcd
++ssfdc
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++sstfb
++ssu100
++st
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++surfacepro3_button
++svgalib
++sx8
++sx8654
++sx9500
++sym53c500_cs
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink
++synclink_cs
++synclink_gt
++synclinkmp
++syscopyarea
++sysfillrect
++sysimgblt
++sysv
++t1pci
++t5403
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tehuti
++tekram-sir
++teles_cs
++teranetics
++test-hexdump
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tg3
++tgr192
++thinkpad_acpi
++thmc50
++thunder_bgx
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timeriomem-rng
++tipc
++tlan
++tlclk
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmem
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++topstar-laptop
++torture
++toshiba-wmi
++toshiba_acpi
++toshiba_bluetooth
++toshiba_haps
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_atmel
++tpm_crb
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_infineon
++tpm_nsc
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tsi568
++tsi57x
++tsi721_mport
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl-regulator
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish-avx-x86_64
++twofish-x86_64
++twofish-x86_64-3way
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++uPD98402
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udf
++udl
++udlfb
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++usnic_verbs
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vboxguest
++vboxsf
++vboxvideo
++vcan
++vcnl4000
++ven_rsi_91x
++ven_rsi_sdio
++ven_rsi_usb
++ves1820
++ves1x93
++veth
++vfio
++vfio-pci
++vfio_iommu_type1
++vfio_virqfd
++vga16fb
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-camera
++via-cputemp
++via-ircc
++via-rhine
++via-rng
++via-sdmmc
++via-velocity
++via686a
++via_wdt
++viafb
++video
++videobuf-core
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videocodec
++videodev
++vim2m
++viperboard
++viperboard_adc
++virt-dma
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_scsi
++virtual
++visor
++visorbus
++visorhba
++visorinput
++visornic
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_ca91cx42
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmlfb
++vmw_balloon
++vmw_pvscsi
++vmw_vmci
++vmw_vsock_vmci_transport
++vmwgfx
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vpx3220
++vrf
++vringh
++vsock
++vsxxxaa
++vt1211
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83627ehf
++w83627hf
++w83627hf_wdt
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83877f_wdt
++w83977af_ir
++w83977f_wdt
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++wafer5823wdt
++walkera0701
++wanxl
++warrior
++wbsd
++wcn36xx
++wd719x
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++winbond-cir
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wl3501_cs
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wmi
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x38_edac
++x86_pkg_temp_thermal
++x_tables
++xc4000
++xc5000
++xcbc
++xen-blkback
++xen-evtchn
++xen-fbfront
++xen-gntalloc
++xen-gntdev
++xen-kbdfront
++xen-netback
++xen-pciback
++xen-pcifront
++xen-privcmd
++xen-scsiback
++xen-scsifront
++xen-tpmfront
++xen_wdt
++xenfs
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xhci-plat-hcd
++xillybus_core
++xillybus_pcie
++xirc2ps_cs
++xircom_cb
++xor
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yenta_socket
++yurex
++zatm
++zaurus
++zavl
++zcommon
++zd1201
++zd1211rw
++zforce_ts
++zfs
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++znvpair
++zpios
++zr36016
++zr36050
++zr36060
++zr36067
++zr364xx
++zram
++zunicode
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/arm64/generic b/debian.master/abi/4.4.0-111.134/arm64/generic
+new file mode 100644
+index 0000000..2aa9d0e
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/arm64/generic
+@@ -0,0 +1,17653 @@
++EXPORT_SYMBOL arch/arm64/crypto/aes-ce-cipher 0x2500f1d2	ce_aes_setkey
++EXPORT_SYMBOL arch/arm64/crypto/aes-ce-cipher 0xa2125399	ce_aes_expandkey
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0x7726d288	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/atm/suni 0xc33c6c30	suni_init
++EXPORT_SYMBOL drivers/bcma/bcma 0x43a85bcc	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/bcma/bcma 0xa7748a1d	bcma_core_irq
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0x30d46b97	btbcm_patchram
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e1d6d5d	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5ebef131	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x7fe3014a	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd13ba5d0	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf06d1d74	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x01f258a1	st33zp24_pm_resume
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x582f1f59	st33zp24_remove
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xc534b075	st33zp24_probe
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xc5828c60	st33zp24_pm_suspend
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x3b3f7ed9	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x81e23739	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xe67ca73b	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x217b078b	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x2d42f25a	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x5d371057	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x9da4aba4	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xe4d81f65	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xf94afa89	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/pl330 0x185b9e5c	pl330_filter
++EXPORT_SYMBOL drivers/edac/edac_core 0x1041734c	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x006d5c25	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x03900e9b	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04d0f641	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x050d7cd9	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x064e8b6a	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0958c610	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0f7d6af8	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x10303178	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x27a824f6	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x367cb465	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3ecbecf3	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3f80d292	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x45d007c7	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x5c6e9764	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x645b715f	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x688b0853	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x6e123da6	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7f458927	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x819f38ab	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8950fab1	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x980c6e93	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa4a89a37	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xadaf5b5c	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xca79ecc3	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xcdf00673	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xcf34f91f	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xdadf0c98	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xe5ec3a25	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xea7e2f4b	fw_core_remove_card
++EXPORT_SYMBOL drivers/fmc/fmc 0x5d83cd85	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0x6a1f54f5	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0x72539b56	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x8c87975c	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x94827f7a	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x993d0932	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xa3a956c3	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xc11233e0	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0xd5607a46	fmc_driver_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xe5a1553b	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0xf25ee80f	fmc_device_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x00e1bf5b	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x01e2871b	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x023bdbe0	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02b4ef58	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x03bde15e	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x042eda98	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06a66c91	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x07bee77b	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x088e51a8	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x091ef661	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a042c35	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a05547d	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0aa2c88f	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0c07696c	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0c10c8cf	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0c134a6d	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0d23527b	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11cef0de	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1256b83f	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12c8ab02	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12e4a263	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13066087	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x130bdab5	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13f6176b	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14c579cd	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x17c5c7f0	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x17e0de23	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a1229b0	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c1e0592	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c5a83e2	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1ca8606b	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1d83d8ba	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20adbccc	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x24c08ed7	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x25e87576	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x260c065b	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x261f49de	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2660e7a1	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x27e513b0	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x28c1e923	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c4926e0	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2dce979f	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e17c6cd	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e356875	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e9151c2	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ec211ce	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2f60d0a5	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x301c2375	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3065044f	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x30765a3f	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x30faa97a	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x31da48e7	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x34362dbe	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x34568581	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x34aa1255	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3589b48f	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38baa739	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3a01c4c8	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3acfb26f	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b87f362	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b974af8	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d30d678	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d8a1bbb	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3dd66600	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3f739062	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4053ae68	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x40c681db	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x40c93434	of_drm_find_panel
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43006d0f	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x44d00307	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48912036	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4997a857	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c272b6f	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c9dd7fb	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d3f6fde	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4e1af0a3	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4efc33ce	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ffd4825	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50ca25a1	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x527d73d0	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x52987504	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x536166b8	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x53c65362	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x545602d3	drm_compat_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x549c5801	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x55759379	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x55c607b6	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57c36a77	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x58345f2b	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a094322	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a910fe9	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a9fb2ed	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5cf28aa4	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d2de09d	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d7318dc	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d98f27c	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5de23c77	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e1f8f7d	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5fed895d	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x608599d8	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x612d8de5	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x63a44f91	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x64eb6165	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67053407	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67b431fe	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68383fa5	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68ee5df2	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69763630	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6a8f559a	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6aba1ecf	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6ad7d6d9	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6c9434e4	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6d84ca78	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f54b4c6	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f844d82	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6fceb8e5	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70ee88c4	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70f7f08d	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x71e9834d	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72c1cc6b	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x740c4db6	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x75088815	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x75197756	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7834a2d3	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x79859b0b	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a9e0642	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7be4c18c	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c6543ba	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c79f3f2	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7ca06d4c	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7df0f62d	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7e53eb5d	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7e920ea9	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7ec13ee0	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x81320dfa	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82270f2c	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82560920	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x825a95fa	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8352d198	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x847aca98	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x88569c20	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x89258ab9	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8947ac77	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a9913d6	drm_of_find_possible_crtcs
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8bb6334d	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c80310b	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d97fe10	drm_of_component_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8db6cfa7	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de7bb89	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e5b0869	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91d356c0	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x940101ac	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x947685c3	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x94de8a9e	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x96387173	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97854402	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97ae58d1	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x983d9d4e	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x984dd406	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ba54494	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9c78d63a	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9c926acd	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9cd09bb9	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9d42b03e	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9e669ab7	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0560a54	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0602948	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0c8f151	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0dd2ae3	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa2925a98	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa3314794	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa48872ed	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4b3c979	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa676da92	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa853fe35	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa8e668a7	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa9f077b0	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaa739394	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad75eb78	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae51ca00	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xafe8663c	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb0dc2629	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb10b6851	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb189c4f2	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb20cb689	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb2c8dda2	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3a764c3	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb4228080	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb494ac2a	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb531584d	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5540008	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5d79549	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb6d5506f	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb6d98288	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb712727c	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb8b14f88	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb8fa328c	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xba39d264	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbac4eb44	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbb54f7bc	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbbcb3195	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbd52b24d	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe3a1282	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe4220d6	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc0bced15	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc1fbaf4f	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc48f7a8f	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc4ed0043	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc5430675	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc5beeb4c	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc91fe318	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca252ec4	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcdbc6c04	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xce97bb07	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf0cd4d2	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf65fc09	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf7024bc	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcfaefb85	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcfcf86fc	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd0b51cd0	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd1456a73	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd1c5c005	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd24d1d6e	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd297f392	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd34582e5	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd380d39f	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3e83a94	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd4f51437	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd5344f82	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd5ee09a5	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd7cd408c	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd7d77e20	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd8834681	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd8bd693a	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd9e21b1d	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdaebcb92	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdde09773	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xde061e1e	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf0997e9	of_drm_find_bridge
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf96ec88	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe0206216	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe0c9d82d	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe0cf0ceb	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe0e5af60	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe22753e2	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2d12ce7	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe462b039	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe467e26e	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe660905c	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe68917ca	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe704f542	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7224fcb	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7a41e35	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe9b237c9	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb4fb55c	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb8317ed	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed05590c	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed9075c8	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xee4ac59f	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeec99c83	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef520c76	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef646bf5	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0c4623d	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0fac240	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1955b9b	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1cb09c6	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1eb1497	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf284868b	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf3d2edcb	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf40fce69	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf5a09851	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfa691552	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb6755bd	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbdf100c	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbee89ab	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd214e51	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfdc0669e	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfdf6e09e	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfedb6e5d	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0107c256	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x01b064f2	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0255dc6b	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x02ecb3ca	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0612d7ce	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0ab9b7b6	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0c1b65ac	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0cc4a808	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0d02e2f6	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x119b28fe	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x12777e84	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x12cfe1e0	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x145d3825	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x14657aab	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1a11cf56	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1afc05b8	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1b707020	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1cfd8646	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x20bd7f77	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2153d7c6	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x240e0c9b	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x245ffac4	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x27e41433	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2c61ecfb	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2d178da6	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2f4fbdef	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x315c36e7	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x32b5b143	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x337d8295	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x384bb130	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x390060e6	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x39ce187e	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3a25a854	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3be193a0	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x42120396	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x423a4be6	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x439eb62b	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4a2566ce	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4e68001d	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4fd4742d	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x51376c82	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x53581a09	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x54c93660	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x567c63d4	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x593402d8	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5c1b942f	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5d7c49ae	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5efef669	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5fc9cbf8	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5fec8888	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x62a3989c	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x62b97c26	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x62ff231d	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6590f36b	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x65c98e67	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6660157f	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6b6d6ed7	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6cf51f37	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x71827588	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x730ab724	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7333ece3	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x740f5635	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x74cffc56	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x754c59e7	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x77765581	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x782082b9	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x786593be	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7c739719	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7d9f33d6	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x83b1a9ba	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8627ffa0	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x86f5bd96	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8de02cb6	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9285487f	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x940657ee	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9406b343	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9417ddd3	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x94411324	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x959d6690	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x987448a7	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9922bc2b	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9eac8dc3	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa0eabc7c	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa5e98016	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa64994c1	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaa516928	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaafb1115	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xacba3e7a	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xacdfedd9	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb0376ddf	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb34129a7	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb40a7e87	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb434c7c5	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb6615b0f	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb723a802	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb7bc8263	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb8179229	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xba7b8f1d	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbe4e9903	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbe88e366	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc2250c71	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc27ba4cc	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc326dc99	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc3a691e1	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc98e9b1e	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xca79107b	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcb9edb8a	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcc006418	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcc6a4a85	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcca4208a	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xce228156	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xce643396	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd3d43dd3	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd3e2cf99	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd646db57	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd83cb9b5	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdaff0234	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdb3c59e9	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdc2bad91	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdcd95e5c	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdcdc74d8	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdd7dda2e	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xddd5fc00	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xded43b36	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe0f7b350	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe2709245	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe354fa68	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe3cf0d31	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeaf51521	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeb827e0f	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeec514ce	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xef7ac027	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf094d91c	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf260bd7c	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf28cb93b	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf41a7b35	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf4d4927e	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf500019b	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf5ce8bb9	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf9f16d78	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfcb35022	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfe20f732	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x037a426f	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0eec9dbf	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1047b47c	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x14343d9e	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x149fd58a	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x216c7be8	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x24c84384	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x26364c3c	ttm_prime_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x263756e0	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b6d12e4	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2c1fc621	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2f486337	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x33468e89	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x359187bc	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x37f20345	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3bd6daf0	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x440cf455	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4874b969	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4e8dd264	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5570c7f7	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x564e1aee	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x591d7b41	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5ee53c77	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5ee757e7	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6052860c	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6ac66b4b	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6fa23711	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7353f936	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7857d22d	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7df6a58c	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7ee38fe7	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x891d05fe	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8a32f1cc	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8bc7c667	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9497364e	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x95c98805	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x95d2ff0e	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9708d8ba	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9bc89593	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9d491f7e	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9db78a2a	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9ed36a67	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9fcfac8c	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa0e1f89b	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa5ddb5f5	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa6ea2adb	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xae87b61d	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xaf8c9df0	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb0febceb	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb22b1217	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb5e2b313	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc2eb39ec	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc63af8d0	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce230be5	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xceaa037e	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd2360e92	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd2e3e689	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd5df2098	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdd0de527	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe0d89ae9	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe37a9443	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe5382ec1	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe6ec87f5	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf892c1a4	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf91768c4	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf947d771	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0e2a6864	sch56xx_read_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0f5877d4	sch56xx_read_virtual_reg16
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x34257f35	sch56xx_watchdog_unregister
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xd0417424	sch56xx_watchdog_register
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xe5022f95	sch56xx_read_virtual_reg12
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xed1d2a08	sch56xx_write_virtual_reg
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x36ae279d	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xa4e25ab6	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xabd30d26	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x14a28850	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x1cf2d250	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0xc9f1e0ea	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x30126b87	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x35693ff6	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x4bf6e0e4	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x4d5e6160	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x613fb32a	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x8613bf14	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x885889f9	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x9cad82f4	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xa8f5cc3e	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xca385079	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xca4e80a6	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xcd3fac6e	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xe6eb8ee0	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xea14b261	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xf4878884	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xfefd2645	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x21678a45	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x4d3d9aba	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0xb4aeb60a	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0xc3fb1d0f	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x2a3845a5	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x9a866215	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xb36f821d	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xc4f2e197	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x9bf6c4e9	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x9fcb9df5	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xb02483b3	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc001f274	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc5f20dd2	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xd0d1f8a4	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x2173b22f	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x2e55916f	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x7a628335	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xd07f4162	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x1803a19d	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x1a5fd0ff	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x3375a1ec	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x4e01aa99	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x771a6ab3	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xa4ec5e7e	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xafea648f	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xba2cd8e9	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc80e1b76	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x121c307b	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x4c31f979	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x4dafdc36	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xa72f323b	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xde013df5	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xc3ab40df	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xd50007a5	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xedfd353a	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x05801c13	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x05c2b5ec	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x094b131b	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x0dc6a9e5	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x220bf663	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x3027faba	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6c133276	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6dd3bead	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x7c074e0a	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x9c70fc6b	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xa0890ee1	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd269811a	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd5154908	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xe8c3ee28	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf0d965ba	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xfd0e0999	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xfe6f39ce	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x031b81b8	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xd8c0aefb	st_sensors_match_acpi_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xffdfe2cb	st_sensors_of_i2c_probe
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0xd60c15ca	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x9e9fcc36	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0xd0b05536	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0xe6094170	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x96c7a8a2	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xc910a41d	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/industrialio 0x231eb7cf	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0x27741062	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x2c86fc0e	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x3dd6c646	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0x546b238f	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x676a3874	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio 0x7d270ef4	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x800e387c	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0x8fe0c771	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0xab26c8d0	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xad1ee7bf	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xad81be63	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xb851700c	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0xca89c7f1	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0xcb8eac4f	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xebcc711b	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xfd8ee2a1	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x5f378f72	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0xde9037c2	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xada44990	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xe828165b	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0x08678f10	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x06cb1232	st_press_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x837bd2bd	st_press_common_remove
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x4c33e170	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x59bd7d7e	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x6d94fc46	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x96786e16	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xf969d1b4	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xfe6e58a5	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1f57f907	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x23c9f4da	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x289e8936	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x32358e8a	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x37ee6ae0	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x566b6b0d	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x906b24ee	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x956c8b36	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x95ec7120	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x98b997cb	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa62f6f50	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xaede07e9	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xc7fdef7e	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd86e9d6f	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd9cd8e56	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xe4043b3e	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xeb4b46b6	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xf5512d43	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x00957723	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0375c711	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0851f3f8	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0aad8bf4	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x133475e7	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1ea952f3	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x20cef799	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x21cc1c9e	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x22f3cf93	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x231c4d44	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x28e8f30d	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x29afd1b3	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2a1b4fcf	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2be91321	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x34949cbf	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x34df7704	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x38d0154d	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3d1ecf7a	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x406de9a6	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x43352032	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x43e99588	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x45a770de	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x45ce8e72	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4760c674	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4a4e736b	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4c5e74b8	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4c93c500	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4f1e85de	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x534d81f2	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x58896481	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5b8b28c9	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x651e33b7	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x664a5de6	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x66e15a39	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6ae8894a	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6dd25a12	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6e12d5d9	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x73d8c620	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x76047f2b	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x77745e18	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7a782261	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7bbed987	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7dfc1049	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x814d6353	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8226161f	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x898307c0	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x899ae007	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8ca990d7	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x90e91d84	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9836eb53	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x985f88b0	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9bc29a92	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9f5122dc	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa3e9416f	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa432baf6	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab55bd4d	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xae7d17a9	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaf1cff9c	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb063ed16	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb9e6a91a	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbabfd756	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbceddb28	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbebba21b	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc12efb89	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc415184e	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc89c6a0e	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xca4688af	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xca75833e	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcc0b9fdb	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcc86bd07	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcdaeac4b	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xce60f9e0	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd071be73	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd14bb371	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd1d00248	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd5215d58	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe8c3a231	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xea9af21b	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xeb4920b9	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xedc4b8ce	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf2bb751e	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf909e02c	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf9e9192d	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfb0c4bdf	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfcabf7b4	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x1ec9085c	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2c9790fc	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x396c336f	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x404b3f03	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x4da0cd0b	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x57524f26	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x67989774	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x8d255cd3	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x91977601	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xa3e46920	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xcbc2ef32	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xcea82833	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd51054f7	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x162063bf	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x2d839beb	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x5e7c7e9a	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x6f7e97ab	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x709f09c2	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x8165626d	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x8e3cb999	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x8ed9af46	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xa93ae1de	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xc4eba57c	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf1bf0cc7	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x89765f8a	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x981d8677	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0020d26d	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x12e9fe95	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x19a964fe	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x2de2b571	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x4d097de5	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x4fa91663	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x677d5289	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x759ac55b	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x8afe0267	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9a631abf	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xc23f0d81	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd54762ff	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xe11a9386	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xebed9274	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xfc237799	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x1ed55bbc	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x1eeff78e	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x23285d56	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x2fbbec4f	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x39620d70	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3c1d231f	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x454071d7	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x493332ea	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x6549d43f	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x65b370ee	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x67c431e6	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x82564c65	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x82e809e7	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x9cb67831	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x9ec041db	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xbe3f947d	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd04eaea9	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd7b47e1d	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xed8ac435	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf3b6a54c	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xfba74fec	rdma_resolve_route
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x06f74472	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x070602b1	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x15677cb4	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x1cf5de27	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x3fb9a42a	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x6993acf8	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x74552abc	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xac1a2a26	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xfb3e046c	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/input-polldev 0x2896f732	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x7c808bbd	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x98bdc2e5	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xde39b5ca	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xdf7b0f53	input_register_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0x242fcc0a	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xa78ea7eb	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xb4eaf37a	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xeb15c3ba	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xb3f0d8a3	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x0773c69c	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x2c90686f	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x6b35c74b	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x6d82db0d	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x87ae826f	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x9e486ce0	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x0de47b2e	ad7879_pm_ops
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xc93ac674	ad7879_probe
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x0e0387ac	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x12c17801	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x3eee6862	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50ae28c0	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x5b3251e6	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7292ab34	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x72a25a72	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa34a63ed	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc2e1debe	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc7104837	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xd8898d63	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xdd2718c7	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xfd552f7a	capi_message2str
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x08d6dc37	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x3740a150	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x50536715	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x631c64f4	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x8acb6a31	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x970974c0	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9b2a8a1b	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9fb1c0ad	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xa48a417c	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xbc19fb89	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xcfec61d6	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xd6e63125	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfa0ef66	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xeb1247f7	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xf00ec90d	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x2870fca8	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x7246ae15	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x9241827e	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x92808153	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xb60ead22	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xba6623d9	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xbc740399	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xc06de05b	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd783dc2a	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x0264f5b8	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x44fa96a4	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x9b419bcd	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xdc623242	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x863f7fa5	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0xf05e8a32	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x1a0dab7e	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x49545b6d	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xcb024b5c	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xcd213e7e	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xd482bbd9	isac_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xee8be3a1	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x25355c6c	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x721556b2	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xdfaf9f07	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x00d2860c	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x12e00b3f	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1a9a8a9c	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x26229258	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x47484b01	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x51e94882	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x545538f6	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x606982d6	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6086bc2a	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x641c704e	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7a10b345	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7ed28c7c	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x80e18e0c	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x85938908	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8eb73799	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x9afe727c	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb95b5ee2	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc839e5c3	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe1623624	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe7fc7ab8	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe90e1a30	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xea675fd9	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xfb8fef64	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x0c161f5b	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x11f9991b	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x1f529ce8	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x2a9240fe	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x440b4830	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x44a37d62	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x5b59b856	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x6d7dda0f	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x70147bfd	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x78faf1bb	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7daccb73	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x8833b0e8	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xa3c5c702	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca5df778	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xce47a6d9	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd2813054	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd947cd25	closure_put
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xdf892351	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xec6f33d0	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/dm-bufio 0x268682d2	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-log 0x6b3e9cbd	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0x6eb2b9ab	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0x9feae671	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0xfa77ceb7	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x89aa5b0a	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xa0479350	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xc1b905df	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xcac32295	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xdf69e9f4	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xfe19fee2	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/raid456 0x916accc8	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x14e436ff	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x209401d2	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x2677bb56	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x301b8ab9	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x434673b1	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x47beb30e	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x51a4059e	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x63114686	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x7e8848ab	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x8c1a146d	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xbfe2e13e	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xd1a8b122	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xd9ef5890	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x6096d1d8	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x7b44b995	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x7d368259	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xdc412bfe	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0x65d99375	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x142123cf	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x5d9898df	tveeprom_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x05dfe876	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x15ada4f6	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1e51dfbd	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2251860b	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x269086df	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2975b9bd	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3b99eee7	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3e19b685	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x41f65fd2	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5ab4496e	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x67347ac4	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x686b97e4	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6b28e85d	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7092ba42	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x73f4cf35	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x77b472e1	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7caa224e	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x92885f27	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9510a851	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x953d0287	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x96a1a3d5	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9a74fc43	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9bdeab9e	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9c436925	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa10e976c	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa1ef0cf5	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xaabf0000	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xab56e804	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb9b68548	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc0eb14ba	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc3c77f8d	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd11247dc	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe4271b09	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe51e2ea1	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe60d865f	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe6319145	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf23a08e3	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf5a34ab0	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0xe4ad9df5	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0xd44a1c36	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0xc293a34b	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x243c6154	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x5b38ccbb	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x724d0a48	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x7262d336	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xb66b4e52	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xc79bc7c5	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xe32893d1	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xed3f7139	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xf0afbfb4	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0x69ddc383	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0x8f71fefd	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0x828b4f10	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0x29ab6a1d	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0x4d1283cc	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x28d7ecaf	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x7bd34315	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0x6636075b	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0xc88ad3e4	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x92cccfc5	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0xe3c3583a	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0x936dbeea	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x2bb860f1	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xc1fb0a45	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xd3a9395d	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x8877941b	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x8c3e38dd	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x981bff6d	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xd59bbad0	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xfeaa30d7	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x24ba5f39	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x4d80a2cf	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5320c8bb	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x6e76e3c5	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x8f3970ee	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x91b0b510	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xa7c3a3d0	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xb208442a	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xc170cca7	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xda6eae8c	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xdcca62c3	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xe34a7cb5	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xebcf7769	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf378c0f9	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf9d9cc9e	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0xefb2547b	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x05277101	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x11508d0c	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x3d937969	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x6eab3227	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x87dd5e33	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xa194ac60	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x01e97078	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x3129546f	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xc2f15d4b	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xf07692ab	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xfd59366c	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x2878dc09	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x15bf27c4	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x26a2f8c8	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x4c9c9bfb	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x5ab56c55	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x731ff253	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0xa5d8dcb8	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0x34690839	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0xbd58c321	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0xeecdd40d	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0x683074b5	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0x2eec7db3	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0xecd8354f	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x2206c96a	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x433a10b0	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0x2f2356ff	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0x0224b52b	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0x90787760	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0xb34215b6	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0x167a7777	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0x5a350fbd	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0x3c04c258	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x33088b02	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0x28df2cb8	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0x75c35443	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x7340d875	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x7e96dd3e	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0x5e0ee18b	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x1565235d	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x5a466f40	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0x3a24cce8	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0xca122781	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x1158ba19	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0x0b95f8f8	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0xc2101d0d	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0x708a7499	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0x3aeb0c6d	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0xcb5484ac	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0x480271cc	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x5cc1d3e7	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x622654bb	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xe0996275	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xf880a896	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x0a15589d	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0x9707db43	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x96fc08c2	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0xb8a1c92e	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0xeb140bef	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0xea9a77a2	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x41acb674	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0xddb6f265	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0x0301330f	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0x5b863c48	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x1aa29607	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0xa9f8ff23	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0xaaa1c739	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0xa3fe3229	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x9a9f7e49	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x0eedb934	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0xba504971	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0xad242649	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0x1044eb6f	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0xb50b30a0	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x460b425d	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x721eea35	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0x1e981df3	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x0d450526	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0xef314f4c	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0x7e33ba59	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0x6b1c7d88	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0xbea39762	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0x8a662bb5	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0xc8fb1d8a	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x10a17aee	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0x5341fad1	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0x835d9006	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0xf0393caa	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x3e61693d	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x51bb71e2	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x792bd85a	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x88b88dac	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x91f6064b	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xe755ca6c	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xf36665a7	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x24395b8f	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x52ed1f2a	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x8c633cef	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xa50e9d03	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x030d61b3	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xf25ca171	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xff98f352	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x30324ccf	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x366a7541	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x3f1aae73	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x5c55fd37	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x671f6c7e	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x7979320b	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x7a7eb31a	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xbb8c0f48	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xc351501a	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0xd6b1abf9	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x18187e48	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x1bd0ffe3	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x916d1edb	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xa1945f2b	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xc3d8a289	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x87d84094	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x0db74939	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x177f6dc7	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x413905c1	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x9267c0c8	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xb409722d	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xb7447205	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xec0afa57	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x497e2379	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x65800d89	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x07b702c3	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x6be905ca	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xa5d35780	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xead67c69	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x5631ac48	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x7f29860c	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x8441a255	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x937f0cf8	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x9c946c6a	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xd14dc67b	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xd9640832	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x03a162fe	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x07d46b3b	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x1fbccec8	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x2ede701c	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x30f73571	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x43d6168d	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x46e1a027	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4aa694c7	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x5dd74616	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6c2d9278	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7154e43a	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x90775412	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x950d6f4f	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xa9af20ca	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb3bd3fbf	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc2a719e4	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc7d20647	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xdc9c3e69	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf1a9bc3e	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xfd79d7cb	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x28803e40	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2a84e2c0	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x4dda6a30	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x4e3c98a0	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x53327270	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x5fe9b3ec	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x7c57b613	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x81203d02	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x93215eab	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa24fe469	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa4b289a1	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xba4c5ca2	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xbc82ecc9	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xcd1ada58	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xe35afac5	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xe7040057	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xffe3bd1e	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x0a4ffc32	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x4b9312ac	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x63db4822	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7ce02bb7	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7e68008d	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7fd1352e	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xb3220a8e	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xb78c0407	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xbc004298	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xda5e0ecd	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xf526c5d5	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xfa61e90b	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x16dc1e92	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x0c33f33b	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x338aaa52	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x3629f00a	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x39659f4a	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x798f5011	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x958f3f50	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xe0fc3917	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x1b8c398b	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x4b3d7495	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x4f4642c4	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x75b4b6a2	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x905d6978	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xbc1aa763	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xc00fa583	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x3ceb6f4e	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x3f2742f4	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x6421dda0	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xa6e88678	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xae6fc2c6	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xca2e4b64	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xcc323051	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xdd401c9b	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x79b11a76	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xd889e990	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0x8716b081	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0x76ef43c1	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x07a3891f	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x1f4a1d6c	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x72335d2e	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/max2165 0x20f6c483	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0x2a60bf17	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0x66e19db7	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0x5ea92a92	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0x2692ccff	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0x8ea57a89	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x5f3dcfd5	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0x9fc8a1ad	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0xb07dcfdb	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0x5e9c0a95	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0x487fb8ac	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x9ed9944c	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xd54dba12	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x00773503	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x02925133	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x0ca493ba	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x65335381	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x660d7a58	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x83c108b3	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x88eee8a4	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xa694f236	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xd2ab043f	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x3f7cd528	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x462d5729	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xaf9bbc24	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xafdd27dd	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xc41a3a41	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xc7d4a754	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xcb7acee5	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xae213473	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x199323ec	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x1f0aa340	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x5bbe71c1	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x68e37ed0	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x70cf8f24	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x738d4f21	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x8f709f67	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xc43a9ae2	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xcf84ea36	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xda519924	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xee3a8206	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x53ec46cf	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xff3a4126	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x18aa9362	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x4e5ca5aa	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x7185435d	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x84d6d032	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x9c93b251	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xad9e072f	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xbc070269	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xf6eab47d	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xff6d76fc	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x3567601d	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x57b0fd8c	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x67ad42ef	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x71b8ec70	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x77b5b7a2	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x77c660ab	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x925a8fb9	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xb26f0ecf	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x634d10fa	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x835dc98f	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xef3f0ac4	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x108837d4	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x3b4f361e	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x08ee4f5a	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x54757d31	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xe32ce5ad	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x377817e1	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x44d0d31e	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x45d7da2e	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x60fb2ae9	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x8c898755	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xa314503b	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0xb5a9fdc2	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0xca4e335c	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x59a4cbab	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x6db39e99	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x957ce088	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xdfbe0156	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xf14e3350	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xf4a75e79	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0x4cf430dd	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0e403887	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0e788bf5	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1201d3d1	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x120b9268	v4l2_of_free_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x17ad63e9	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1802c661	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x19275b38	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1f204e52	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x200efd2a	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x22836dab	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x22abb491	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x22fe5128	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x25145c0b	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2a42e727	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2e557d28	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2e93d890	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3773ce40	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3d838d49	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3f0bf49d	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x437b3cc1	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x46a76b3e	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4adcfd15	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b1a5af0	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4d382701	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x505e71e5	v4l2_of_put_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5262ae7b	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5e81322d	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x619d5190	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x67119785	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6891d98e	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6e961745	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x71c118a7	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x73350f7f	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x73e6de45	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7f306e8b	v4l2_of_parse_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x83ba51d0	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x84916821	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x89de7b3a	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x90ccbd5a	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9b30259e	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9d58d3e1	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa1b230b6	v4l2_of_alloc_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa9918250	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xaa771bd9	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xaedaa65c	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xafc8c324	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb00699e8	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb03183bf	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb391b30f	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb4b8bfee	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb895e422	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbd0f8f51	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbdbbd477	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc3ee32cb	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc4dfadfb	v4l2_of_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc6603385	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc6831ece	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc9d7349c	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xca89ca93	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcbeabc09	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcf00127c	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd7d5db74	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd8b181e8	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xda0d2445	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe0fb078f	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe1d6e2f9	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe20e313c	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeaf3ab3f	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xedfc862f	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfaf3b1e4	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfb667c6d	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfcf87d0a	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfff42777	video_device_release_empty
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x298cd145	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x373e3ffa	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x42c53286	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x538f407e	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5ced8505	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6264d976	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x780a993e	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x825c5d40	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x9be4ecda	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xab88fe16	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xb51f745f	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xc8c5cd3c	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xdc07e67e	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x070270fa	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x12e5f427	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x14ecfd0a	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1b139ecd	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x21263090	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2f281ac1	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x396d3303	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3beaf8a0	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3eaf507b	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x46af17bc	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x5760684b	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x666fb21a	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6684c673	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x67f62256	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6b834a8e	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x750ca384	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x81007323	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x856808c6	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x94e46fca	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa61df94c	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xaebf3ab3	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb38cd047	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb7b59153	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xcde7b221	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd128453f	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd40ea3d9	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd6a4c482	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd953b94a	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf34214af	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x097004c2	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1b1d06c3	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1b2fae84	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2f0086e5	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x5328b86b	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x5407a6b6	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x5456304b	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x65da0520	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x666eb319	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x749c8174	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7990c43b	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7d05fa14	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x86c7d65d	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x87f0d223	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x952fca52	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x954cfcf3	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9f3a37eb	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xbb7cee47	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xcd324ca4	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd92b8a76	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xde7c3ef9	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xde998676	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xdf394dd8	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe080236f	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xec248ed7	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf43c4026	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf58b76c9	mptscsih_resume
++EXPORT_SYMBOL drivers/mfd/dln2 0x1d876499	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0x7b4102eb	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0x969e8ad9	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x645e4717	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xfcfb2666	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x0f250927	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x252d640d	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x3fd6945a	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x4af83420	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x8774bf9a	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x8a54bd3d	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x97459a1d	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x98268e87	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xa046f6a2	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xb65f95af	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf078a9aa	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/qcom_rpm 0x295fb567	qcom_rpm_write
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x1e51e983	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x6f0fd087	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x1c906870	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x717052a4	wm1811_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xdc28eb10	wm8994_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xee125089	wm8958_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x4f11f2c0	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xb59ee4a7	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0xd2c54d67	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0xb1ed8aa6	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0xb7351eb1	c2port_device_register
++EXPORT_SYMBOL drivers/misc/ioc4 0x21e7e0a1	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0x397ccde7	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/tifm_core 0x00567d87	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x21f72606	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x36b99b6e	tifm_add_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x42762af2	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x59bd5d37	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x77c95361	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0x9882c466	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xa4747088	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0xa8c2ec46	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0xd01be92f	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0xdc5b4e4c	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xe2188818	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xefcd2c4f	tifm_map_sg
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x09c5b30c	dw_mci_remove
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x33359f31	dw_mci_suspend
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x82f887ce	dw_mci_probe
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x9a12662a	dw_mci_resume
++EXPORT_SYMBOL drivers/mmc/host/of_mmc_spi 0x10112359	mmc_spi_put_pdata
++EXPORT_SYMBOL drivers/mmc/host/of_mmc_spi 0x41201c56	mmc_spi_get_pdata
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x0b63fa58	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x1c6aedb7	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x35ca52ed	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x4356f653	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x70d0d998	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xa925bf97	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xda999b86	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x3d85bbe0	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x478ebe9f	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x6f93ca45	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xe77c9a85	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0xc4aabfdd	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0xf5562c42	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0xc3b8609f	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x1b5cffc7	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/mtd 0x70c02392	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xaad47e71	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xad556fb1	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x0fe29210	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x38349969	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x81f530f0	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8b027eb8	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8f51a559	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xb20a0354	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x7ed732e5	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xa71e9f27	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xe6a17836	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x5f40c2af	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xa5001b26	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x23c1fce4	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x4af355eb	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x559f3300	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x76e6fdba	onenand_default_bbt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x023da3dc	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x0f639a86	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x29e4786f	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x311cd851	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x34aca2f9	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6d43b1d4	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6fcf5d6a	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x9ab54187	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xa3009a70	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xd0018e9d	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x2e5fb299	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x5c7dab1d	com20020_found
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xd5289f08	com20020_check
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x05f741f1	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x31fb0e51	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x4bf309c1	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x76cf9400	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x83e1a7bc	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x8463cae1	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xa02d2cc5	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xceb19baf	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xd7f9a7f6	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xdf37c255	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0x55746055	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x9d797ead	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x0d8be5fd	bgx_lmac_rx_tx_enable
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x285bde59	bgx_get_rx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x42264715	bgx_get_lmac_count
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x6dc1648d	bgx_get_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc397f585	bgx_lmac_internal_loopback
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc82be691	bgx_get_map
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xe48ca42a	bgx_get_tx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf101d1b2	bgx_get_lmac_link_state
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf9508980	bgx_set_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x13ca05f8	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x28896ae3	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x2911849d	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x41f3f394	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x5f7fc0d1	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x8b6ebb6f	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x95d334b0	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xa13aaeca	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xacbae801	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xb4181e4a	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xb6e39d2d	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xcabf41f6	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd3e1e38a	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd786f7f5	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xdd680aff	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xe7549487	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x00878854	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0507c731	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x053d3e3e	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0ac3c393	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0fe96165	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x120e9753	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x16f752e1	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1840a987	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x2c6b4505	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3a8496ba	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x47033e68	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x521b24df	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x5417ed83	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6d1dce4b	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x71310c9a	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7a98f500	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8943f0a2	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8975c3ce	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8a7e675c	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9d55fd1b	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa60361a1	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa775a186	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xac8bfaf9	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xaf38c2fe	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb0103812	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb6160433	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xbaf981d0	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xcf165385	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xdb96bfa9	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xdbf36231	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xded1d584	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe6380023	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf1938c6c	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf773d076	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x1728cfbe	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x1f19d093	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x5daa342f	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x891d2c35	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xd9df26c9	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xf5119026	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xc07ed5db	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xc16f59ad	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/freescale/gianfar_driver 0x79f28897	gfar_phc_index
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0x087c64e8	hnae_get_handle
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0x3a54afea	hnae_put_handle
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0x96f68073	hnae_ae_unregister
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xb1266858	hnae_register_notifier
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xcd78e56d	hnae_ae_register
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xd5b22815	hnae_reinit_handle
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xdf24adef	hnae_unregister_notifier
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x03a70586	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x03abe20b	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x047f0a08	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0640517f	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x10f90b14	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x171b5a99	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x23a57467	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x24a31d08	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x33c6908e	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3503ca7e	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x36235f4b	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3a9d95b2	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4462b9ac	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x522234c8	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5876c372	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5e8d73fe	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6cd2cf0a	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6f64a085	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8022e969	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8fa13feb	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x913e46eb	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x91a29492	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x91b9f5e2	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x961928ab	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa14e778b	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbaedabd3	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc3b0bd00	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcbf8059f	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcd464d53	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcfa3b5d6	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd05a7357	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd52f107d	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdb9680ff	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdf8603f1	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe6170d1c	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe74be032	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xea205dc5	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xefdcf4cd	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x00343752	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x10cc58db	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x29ea367c	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2dba909a	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x34b34b78	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x37b782ad	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3960f855	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x39e58ef3	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3d83f49c	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x47f08144	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4b98aacb	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x504c7474	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x52b7abfe	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5c90ad0a	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x61c1f714	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x63c98257	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6b509678	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6c8422fc	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6edf16b1	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6ef0785f	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6f190585	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x741d5751	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x75bed9cb	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x790d36eb	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7f62f0ad	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa0eec385	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa17a0f8a	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa635a00f	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa76649f0	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbef0067d	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc7db88d8	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc829461f	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcc9cddeb	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd520ad83	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xeeb43759	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf111e042	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf4fd9970	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfd54f74e	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x1c54e2da	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x201c876a	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x2d07a992	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x3302bfb2	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x5d0da4c5	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x7e5355ab	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xa9e0b7d2	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xd17e168a	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x1c2c2a98	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x0c07e66f	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x0d531c77	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x5855d85f	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xd7cc9cdc	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xf2dbe3a0	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x20192336	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x2fc19607	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x5b434583	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x7eb228f0	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x9a83d0eb	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xcb13ae2a	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xd2d81d9f	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xd3b41168	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xd7a34ef7	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xfd4c4427	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x5d4a193f	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x782cb439	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0xae317f1f	cavium_mdiobus_read
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0xc4122cf4	cavium_mdiobus_write
++EXPORT_SYMBOL drivers/net/phy/mdio-octeon 0x8a1d5c26	octeon_mdiobus_force_mod_depencency
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x3ea98d44	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x63e832dc	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xc1fe2a63	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/vitesse 0x1f16cc9c	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x77836be0	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe6c7ff38	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xeef6b928	register_pppox_proto
++EXPORT_SYMBOL drivers/net/sungem_phy 0x72923d3f	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x064448c5	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0x2bc5d5b7	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/team/team 0x3b67ae1a	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0x47b4bb08	team_mode_register
++EXPORT_SYMBOL drivers/net/team/team 0x5dda22c5	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0x76e79335	team_options_unregister
++EXPORT_SYMBOL drivers/net/team/team 0xb0b52403	team_mode_unregister
++EXPORT_SYMBOL drivers/net/team/team 0xfda75630	team_options_register
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x004b1a1b	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x599107f4	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x6a43ad14	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xb579d0bb	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x0ef66112	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x16669db9	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x3aad5327	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x468aecfe	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x75f46d31	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x9431786e	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xaf85a6d8	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb3865ac3	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xd26aaad5	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xd8f1c6ed	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe38913a0	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0x76ef3131	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x1b18301b	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x2ce5df24	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x58fb6168	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x6714c14f	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x727f7cbb	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x7c3fe789	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x7e8fa29b	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x8f253514	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x91817fba	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x92bef6e8	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xc0e0116b	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xd18687fd	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x2216100f	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x3035b4e5	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x34c7d45d	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x4c71ad90	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x4fa3bf85	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x54474e5b	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x6daf961c	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xa7efae45	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xb3a6a358	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xb8f080b6	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc0694a23	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xccf3c7f0	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xd2756f13	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xec3c84ed	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xf937c337	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x0ed27ee7	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x1c76551f	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x347ac2b6	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x6ed504df	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x86954bce	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x8f7f1fd5	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xbb2473de	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc15debb4	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc985f5af	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xd5285530	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xe5a570c8	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x06137590	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x0e54ef0d	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x16be4551	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2156f648	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2344d4a1	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2a6c231e	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2cfcf884	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2f4d1632	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x538c3b44	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x54b3371e	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x69e0a481	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x841133a9	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x84458404	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x98d38a84	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xa3da30ea	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xa4ed1980	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xad3b4e3c	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb0c803c5	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb8457907	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xdf0f7760	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe55f63fa	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf3ee1351	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf8fad127	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x02d1eeb6	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x04837a19	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x095e252f	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0b0efa71	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1302cc82	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x13f18ab7	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x16e78ffc	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x18fe74c5	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1a1d53c3	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2d38ad2e	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x33b4ec93	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3522bf42	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x36d29b2c	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3c799366	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3cc332a1	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3e4b1e40	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3fa83048	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4018593f	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x425bab5a	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x47fc0ea8	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4809eb50	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x492d0504	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x498fb85c	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x49b25319	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4aba9d9c	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4b6101a8	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4b644245	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4c115758	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4e802e86	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x50f5ca70	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x528afd81	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x53c3713f	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5a311d30	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5a66b88e	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5cfab81e	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5fd13421	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6c92f802	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x70e08da0	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x72212a60	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x74da9e74	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x757eccff	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x758a0de3	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x75902a9c	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x75d8c535	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x76756f69	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x79ead190	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7a9bde52	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7c522da6	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7cc879d3	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x819e5d4a	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x83dcce5f	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8610dfd9	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x862c7e47	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x893a2c5f	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8c21dd68	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8c723eee	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8c856aeb	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8f07ce89	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x97454080	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x978f9adb	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9915398a	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9b773569	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9c1fa50f	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9dab2196	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa0dc53e9	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa204e1e0	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa2cc57f8	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa5fc5613	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa7f6bf27	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaa450cba	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb5af7e34	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb8a65524	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xba3403d7	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbc9043c5	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbd2b9aa9	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbdc46168	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc0bdcf5f	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc0c9f210	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc34ff08c	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc36e1ec4	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc3cbb4d6	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc5949cd9	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc80e792b	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc85c761a	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcac41f89	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcca92caa	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xce92b245	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd0f24fc6	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd398dee4	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd57e43ba	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd60ebc99	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd6cca11b	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdf6b0136	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe0c881bf	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe2f8c6fd	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe40d0eff	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xee071f5e	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf0a70215	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf11f82e9	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf4f480a2	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf5f9b108	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf888a191	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfdaa9d71	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfe1ce865	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfe3960cc	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x2a9c6c89	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xa6ad7131	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xbf9066a3	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x00550528	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x0d15af26	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x0d373bd5	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x2dc81049	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x4b6a1dba	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x508e5cea	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x7fc06c15	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x8f72927e	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x946434c5	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x998e9f49	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xa8168197	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd8a1e431	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xf42779e8	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0f76bf21	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1723ac32	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x221275e3	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x241ce9ea	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x28237876	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x28ae197d	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x4018e45c	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x5b76ad6b	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x78ade0ad	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7be1b461	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x83c0d8e9	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8cae72aa	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9292dd40	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x98d13604	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9f4c76b2	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9ffbd45d	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb12a8949	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb897e3e8	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xba345378	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc3f2d45a	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc440b90f	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd88c258d	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe27fe1bb	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe7885fdd	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xeb9104ff	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf56788a4	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x0287b9e7	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x02bf8682	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x02d561b6	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x0e867174	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x31a591d8	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x3e34f76b	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x47d9123e	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5691ee76	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x63d796fe	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x80cd8eff	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x84e62506	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x9802f789	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x9a700808	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xae5e87e9	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb78a0ede	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xc4c3363a	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xceaed7ff	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xcf9a6a4d	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xdb5c7c33	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf4fbc049	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf542de27	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x019009ff	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x01f57255	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0fcb3161	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0feb14a2	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1433f258	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x17204782	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x18f2f668	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1b291734	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1fa42fd7	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x22f9225d	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x284c358d	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2cf09328	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2d1aeb9d	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2d449b15	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x30a236fa	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x312ead9b	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x31c8f7ac	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x330820b3	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x35894cd7	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x35ef6e6b	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3710bc7b	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x39967d7c	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3bfe6370	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3c0ecde8	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3d612aeb	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3e33519c	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3f811768	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x40776c0c	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x47074a4f	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x47195a37	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x481e42d5	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4cb554b0	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4e08dfcc	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4f7711ff	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x530f7769	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x537b6da9	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x582ae443	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5c44e57c	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5d3becb7	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x606b6e51	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6093fc75	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6169e9a1	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x653b2eb4	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x65e5c679	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x661a7d4e	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x66c7ad1a	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x692825e1	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x69de8729	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6fc7a058	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x70e4197d	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x71d8f7b7	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7338bf77	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x76bd64c6	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7da1c87f	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8a4e36a2	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8b668553	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8ba7e3e2	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8c4708bd	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8c926d0e	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8dbbad50	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x971551f2	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x98c0eb40	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9dac16c2	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9eacee42	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa3db6139	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa6a0eca3	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa92f4096	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xaa152503	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xaa591dca	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xabce6b9c	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xabf18101	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xabfc47db	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xac133c41	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb0dcd311	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb315a60d	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb4008436	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb6e4750c	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbba94067	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbdbadc6c	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc1eab9f4	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc23e4a9b	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc42eadc2	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcc01eee4	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcecac090	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd6d74e61	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd9930065	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd9dd10e6	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdea13c0d	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe2cc1ea5	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe30ff156	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe6036458	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe7a977eb	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xeb86882f	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf3b8f5a1	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf525b432	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf6b98c19	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfe0e6111	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xffca7622	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x1b06ce78	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x2447a6ab	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x314a20a8	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x5e9c24ff	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x8c8ab242	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x9a1b1df9	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xdced6db1	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x0170090d	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x050890d2	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x1b97f459	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x21a07e6c	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x25294c73	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x2e49c76f	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x3359ef1b	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x9f8e021c	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa0afca1c	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb7161e85	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xbc4a37f5	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xc8623cce	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xdee9eaf2	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xe8375ea8	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xead7b05e	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xef64033b	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf85f1771	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0x03111dbd	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x04b65ad9	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x04d45a38	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x14cf46d4	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x15132a73	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2047cf09	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3d095b9c	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3d7a4303	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3eced7d5	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4319d68e	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x43e871e5	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x43f2409e	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x575d3a52	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x58831099	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x670f4d98	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x67e48895	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6d2e7f63	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x765c850b	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7d46899d	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x80926a6c	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x836c034a	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x86da02d1	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x879b5a5e	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8a8eb9c7	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x9a6df254	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa91739a9	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xacc4cf8e	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb76b3d21	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xbd4cb719	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc2132e19	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc327f9f3	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc9d83dd6	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd5f1732a	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd6218126	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd7f1949b	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdf62d37e	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe0d9401a	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe0ed0f2e	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe7154a6b	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe882b64e	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf581d3f7	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xfccfa875	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x001e475d	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x2e254425	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x74691b09	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xe3098893	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x1d62c883	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x5a3cbf8e	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x8590a6c5	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x90b4d28f	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x213cf11f	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x29aa1bb6	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3507daa7	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x43cb285f	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x46958a0f	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x47910272	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x558b4636	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x62d5cae2	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6595f60f	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x66783590	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6813ab22	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x75a07f45	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x80ae2cd5	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x86e0443f	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x89b5a392	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8bf085c2	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa27a76e6	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa3b4ddfe	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa6a632b2	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xaafcd494	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xae19f1fe	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb7562544	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbcea5c7d	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbe226daa	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbf4779d7	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd92a4208	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xeafb478e	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf64ce85f	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x4b5f0bd7	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x941c8202	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xbbd15eb1	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xe5225d3a	wlcore_tx_complete
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x1abde707	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x4b06877f	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x8f810cba	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x83e449e5	microread_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0xa19c960c	microread_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x05602228	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x1c7fa98c	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xe5bbc76e	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x83549372	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0xb97a5169	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x79422135	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x8e606f4d	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xec0da0e0	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x04164b1a	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x17faf8e7	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x1ae86b05	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x2af24679	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x763e1dbe	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x86a81dfd	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x9375c24e	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xa1c2f9c1	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xb1d45c11	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xd223dfd3	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xebbabefe	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x0838c51f	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x0bea23ef	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x509669be	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x57b63717	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x6dbb6ff2	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x75385c62	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x75f8fa95	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x7ab2fb63	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x8d30eb63	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x8de3ba3f	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x8f6a00a5	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x9701ea58	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xc2055a61	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xc30b2aac	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xd8839267	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xe23ec428	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xea0e018f	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xf9403b07	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/ntb/ntb 0x09bbe31a	__ntb_register_client
++EXPORT_SYMBOL drivers/ntb/ntb 0x12a830ee	ntb_clear_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x1dee7eed	ntb_set_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x29df7309	ntb_db_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x45ab4902	ntb_link_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x66c0956a	ntb_unregister_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xae9b9271	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xe0fde429	ntb_register_device
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x162705fc	nvdimm_namespace_attach_btt
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x7c580a2e	nvdimm_namespace_detach_btt
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0xab034273	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x08d534c6	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0x0cbfab28	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0x1281baf1	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x185b52c4	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0x1f2c5e38	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0x2292d490	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x2555e28d	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x2f97a058	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0x30f8b17b	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0x33f35291	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0x354939f9	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0x35fc3e01	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0x36070116	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0x43f9f13f	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0x4996bffd	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x4a28d380	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x58e0c64c	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x611d8261	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0x6c2192c4	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0x6dc18a36	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0x6ffca2b6	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0x74e48bb2	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport 0x7ef3fe8f	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0x83384945	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0x84da0af9	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x96579a64	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x9c38bb64	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0xa4ddefd2	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xb615fa1e	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xc735455d	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0xd1496d8e	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0xfd6089fb	parport_negotiate
++EXPORT_SYMBOL drivers/pci/host/pcie-iproc 0x3d29a9d8	iproc_pcie_setup
++EXPORT_SYMBOL drivers/pci/host/pcie-iproc 0x850d42de	iproc_pcie_remove
++EXPORT_SYMBOL drivers/pps/pps_core 0x6bb7b1c8	pps_lookup_dev
++EXPORT_SYMBOL drivers/pps/pps_core 0x7d4450ef	pps_unregister_source
++EXPORT_SYMBOL drivers/pps/pps_core 0xaa28fa9a	pps_event
++EXPORT_SYMBOL drivers/pps/pps_core 0xc827b33e	pps_register_source
++EXPORT_SYMBOL drivers/ptp/ptp 0x49106bc3	ptp_clock_register
++EXPORT_SYMBOL drivers/ptp/ptp 0x65f62bc3	ptp_clock_index
++EXPORT_SYMBOL drivers/ptp/ptp 0x789f34f2	ptp_find_pin
++EXPORT_SYMBOL drivers/ptp/ptp 0xecf5679b	ptp_clock_event
++EXPORT_SYMBOL drivers/ptp/ptp 0xede7a913	ptp_clock_unregister
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x03c1ea4f	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x09a19990	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x1a1a393f	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x55717245	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x6987247f	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x89d4958c	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x9d637b39	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xaad10df3	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xcdb84d6e	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xfb0f3d79	rproc_boot
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0xc3153b61	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x0b5077fc	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x31343d8a	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x535ca770	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x6a3ea1fd	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x0912badd	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x1764f5da	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x257d23bf	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x306b6c08	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x4c39f937	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x4f54ea41	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x5034e362	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x56eef3c3	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x7afc6c86	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xa88e61c9	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xbb327eef	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xe4a792e2	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x03fa3e83	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x07349c3c	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0a951cc6	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0bc6899f	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x13c074f4	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x148371da	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x149d5257	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x183c5794	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x24a9a1a3	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2550e340	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2d3254d1	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x320edf98	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x428b55be	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x42cc6cd6	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4ed1d747	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5242a0ef	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x529b73fa	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5303afb0	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x54da1acc	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x560816fd	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5915b7ce	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x59292183	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5ccc441b	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x68071b27	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x757a9ac2	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x770c3649	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7efb6110	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7ff90571	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8401d6c3	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x84270588	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8e1e5c54	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa5beea88	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa600e28f	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xaabe2688	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb244e664	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb3111525	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb42c28ac	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb636cfd6	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbf4c89d5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc6b45c40	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc8b2dc27	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd8b340df	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe21ae5a7	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe62dbadd	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe66a53b5	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe8866065	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xef4bb5ff	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf6033290	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfa42254f	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfebc11a6	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x58b0ae03	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xd174fa75	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xf920a9b9	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xfffcbc31	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x81453260	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x01624b0c	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x033b99bd	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x034b862f	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x161befe6	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1857339c	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x2c3fbf5a	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x309b799b	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x35d5cd1e	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x408efd99	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4cd1336a	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x542fb030	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x54b227ff	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5854de0d	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x612e7e2e	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x660a8790	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x67772d35	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x695d0003	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6a502ba5	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6c00aa09	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6d092505	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8c38388d	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x957c125d	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9e0576d2	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9f174b51	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa0c81d73	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa91de33a	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb5536af6	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbf67e51d	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcf22a5cb	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdace18a6	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe32fb008	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe34d346d	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xeab3be75	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xef7c35be	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf1a585ef	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfc3108cf	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x297bf928	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xbada9716	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xe8a1f383	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xf061e6a3	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xf5131052	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xfbe1b69c	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x01696f75	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x028a656b	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x10246713	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x32071545	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x32a0067e	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x33914ca3	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x73898860	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xad1765ae	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xdc620a39	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xefb1a207	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xf5130051	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xf6e8ba0e	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/raid_class 0x09454445	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0x25335c63	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/raid_class 0x7f2ddbd3	raid_class_release
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x035f0782	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x046eae27	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x05d9833e	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x15e13a20	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x28d7683c	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x4cd88fc2	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x54b0a74d	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x6180923f	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x6658ed5a	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x9a14b0df	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xa98511f0	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd265c301	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xf9705377	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x0bb74967	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x0cb9cb8e	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x23fbaed2	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x28687b45	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x32b22f08	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x38c14c06	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x3d6ca429	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x3fbdd1b1	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x414e81c8	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x479bac4a	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4c26d38f	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5377fb4f	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x58946fc3	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5edc4670	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6348b0fe	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x65fbd8c8	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x703f9fa8	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x735bdea9	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x78c4ba27	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x8db1a1c8	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x929a94b9	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x92dc76a0	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9b929727	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa8f28d5b	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb2cd660b	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd0e917da	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xdb5df541	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe11d4481	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf3e8c116	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x4aafd99f	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x603a95cc	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x973ad8a9	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xa1c613ea	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xf0642320	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x30a8d4ea	srp_rport_get
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x442d974d	srp_reconnect_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xce1f11a8	srp_start_tl_fail_timers
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xf7760a46	srp_rport_put
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x13faa081	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x1541f8c0	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xb0243266	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xd3c09615	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xd4843ff7	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xd96961b2	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xe7825372	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/soc/qcom/smd 0x4ed55fea	qcom_smd_driver_unregister
++EXPORT_SYMBOL drivers/soc/qcom/smd 0x932cbc2a	qcom_smd_driver_register
++EXPORT_SYMBOL drivers/soc/qcom/smd 0xeda44e54	qcom_smd_send
++EXPORT_SYMBOL drivers/soc/qcom/smd-rpm 0xad43c23b	qcom_rpm_smd_write
++EXPORT_SYMBOL drivers/soc/qcom/smem 0x34b57571	qcom_smem_alloc
++EXPORT_SYMBOL drivers/soc/qcom/smem 0x5a710273	qcom_smem_get_free_space
++EXPORT_SYMBOL drivers/soc/qcom/smem 0xeeffa750	qcom_smem_get
++EXPORT_SYMBOL drivers/ssb/ssb 0x0121cae6	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x06bd344a	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0x08f111e5	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x1df6b8d4	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0x2a2704ff	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0x326236ed	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x496f8785	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0x6461692f	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0x65d21619	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0x700e7af1	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x950432fe	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x9cadae99	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x9fdb4b81	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xaceb50a5	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0xb628d10f	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xc215e232	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0xc9cdeb6b	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xe3ce5df5	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0xe3f3df83	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0xf3411c5c	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0c1e48aa	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0f30ee57	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0fed8315	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x155b6dbb	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x161cda94	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x19152454	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x35153364	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x3755a557	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x4b1903d0	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x635fd633	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x63ba88f4	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x85c506df	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x9a111aa9	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa37b9ab8	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa466b103	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xac723206	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xb73efda6	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xccb756e2	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xcd68596f	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xd97fd25c	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xdcbf43b4	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe5456972	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xeb136beb	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xec185868	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x17aec61c	dprc_get_obj
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x1f3aa0d3	dprc_close
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x231570c6	dprc_get_obj_irq
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x2d12b5d8	dprc_set_obj_irq
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x44940a75	dprc_get_obj_desc
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x46b4fed4	dprc_get_obj_count
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x486173df	dprc_get_res_ids
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x5aec9bb8	mc_send_command
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x5f32ddef	dpbp_close
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x72498418	dpbp_enable
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x7712a80c	dpbp_disable
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x7d9ded0a	dprc_get_obj_region
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0x90f52310	dprc_set_obj_label
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0xa9fd8a16	dprc_get_res_count
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0xb2eb5723	dpbp_get_attributes
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0xbb1a7c85	dprc_open
++EXPORT_SYMBOL drivers/staging/fsl-mc/bus/mc-bus-driver 0xc801be40	dpbp_open
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x738dc4bd	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x8f45318a	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0xcdfbf5e3	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x21da865c	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x2ef7c92c	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x639dcf52	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xcc1999d4	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x439e69f8	ade7854_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0xf109d78f	ade7854_remove
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0x142ee331	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0x15b56eca	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x021d74eb	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x03b85ca7	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0e4058e6	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x120f9e85	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x14d64cca	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x16331ffa	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x18396b63	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1e431568	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x21cc782b	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2bccb696	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2cbf774a	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x322f64db	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x32528547	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x32720a4a	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x38a7052b	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x393cb009	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x418a9487	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4620c658	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x48574a1d	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4fdc14be	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x54b94b01	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x560d25cc	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x57158454	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x57755c48	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x58b80914	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5b3a4aa5	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x68b738a8	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6974f3bd	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x70ca4f61	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x73dad738	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7b16f008	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7f545530	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7fe3e3a0	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8cda232c	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x93003911	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa454a32b	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xada78399	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb31ff07c	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb4d33509	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe14db2f	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe718a20	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xccc9b8fe	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd03def72	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd161497a	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd7c42957	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xda4986fc	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xddd29176	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe0a5c94d	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe9fe2694	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf346d5bd	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x075346b0	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0aba3152	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0c6d537c	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0f099f61	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1b063bf1	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1b1f1397	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x20d1165f	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x22a83ccb	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x362431d5	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x43fbbb9c	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x48cefea8	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4bbecc8b	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x56c79275	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5c7d93b3	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x61ea895d	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x641cc1d7	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6555decf	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7cf14a3f	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x82a64f3f	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x867cb022	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x88e84627	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x95494bf9	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9bf09722	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9d47fdab	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa68ff87e	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa6d9c88b	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa7a125ac	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa8c43126	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa8d4501f	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xac6ca871	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaef121a8	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaf463e77	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbb83acb7	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc940131f	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcb957e21	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcc2c2ff3	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcd79eeb0	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd34fc52f	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd403148a	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd4b03e6e	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd651d6a7	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd747ed58	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xda1607bf	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdb54546c	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdc0394e4	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdd8f1ad8	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xde41a827	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe3b309fe	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe55f996f	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf2854c95	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf55667a7	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf8406b85	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf8967f5f	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf9dff1e1	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfda47a57	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x07c7ab47	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0c18547f	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0ff74d9a	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0ffae1e8	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x312a9b45	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3790298a	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3abc497a	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4d229aa6	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x603b1329	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6888fb8d	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x7b4435bd	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa14cb715	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa188ed6d	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa90dd892	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xadcc7d8f	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xaf95e23c	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb1a896b9	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xba73970c	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc06e7e7b	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc76ac6d8	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc9429c23	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xccc4dd48	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd2899307	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd5640332	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf29f12f5	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xfa2f10dd	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xfe5ae893	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xfe8353f4	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02aa354c	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x07cdd778	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1a38c728	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1fb9c0c0	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x28b3bff6	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2d78c307	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2fca6bfd	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0x35432fef	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x36c65f3c	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3889ba19	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3a149d15	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4092a71b	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0x41a0d9d3	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4411bae8	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4d1fbf76	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4da9a83b	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x522d1284	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x596aa1bf	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5a3ef174	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5db778bf	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5ddaf1c3	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x63b48e8f	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x668ea252	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x669174a1	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x671b5fbf	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0x67d25887	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x716ec11f	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x721a441e	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7d61fffb	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7e5955b1	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x83dd9577	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8763062a	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x897cb8cf	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8af0831f	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8e471c0a	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8e8f2e74	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8eafcaee	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8f8ec616	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0x914abb71	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0x93dbfa8b	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9a1bb58f	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9a1ec45f	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9b4f0918	transport_init_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9f723a17	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa4ac79c8	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb2afc1ac	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb743de1a	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbdb1c919	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbdd70903	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc437f2db	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc534f376	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc58d69a0	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xca0d046e	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0xca223abb	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcd79016f	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcefba603	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd06ba20d	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd203020c	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xda4cfbe6	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdf80ffbc	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdf9640df	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe04461eb	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe3f00bee	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0xeeb677a7	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xef85886b	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf18db591	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf38319bb	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf91b1cac	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfcc533e3	target_put_session
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0x430d5b77	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0x305ad968	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0xe84b79d8	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x0e373793	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x3fb71fc6	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x49c869f5	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x4c3ee603	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x757feac9	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x7a4f3ca5	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x89059c95	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x8f1e17c2	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xb479987a	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xc5186be7	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xd61ece50	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xf5e441e1	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x1f36bc45	usb_serial_resume
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x47767b99	usb_serial_suspend
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3b304ebb	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3c71c418	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x4311cd91	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x5fedea44	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x97fa07e9	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xde804bb9	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x56b0112d	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x5f8d56d9	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x9c379411	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xadfe7376	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x254e4125	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x5918ce92	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x7775ec85	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x7eb59910	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd60501cf	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe697914d	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf0f4f083	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/core/syscopyarea 0x753eb24e	sys_copyarea
++EXPORT_SYMBOL drivers/video/fbdev/core/sysfillrect 0x06cdec9e	sys_fillrect
++EXPORT_SYMBOL drivers/video/fbdev/core/sysimgblt 0x21a4f822	sys_imageblit
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xf316902f	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0xaa38e36b	mac_find_mode
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x112596a4	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x35f4bda5	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0xa828db0b	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x23d841c6	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x358b4d60	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x88820b34	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xc9bf9026	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0xcfa70c57	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0x665c89c9	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x0deb1fc9	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x145b58a8	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x537bad2c	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xf3aa4aab	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0x33cc9d31	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xb9552b0a	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x41ad3c57	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x73ddff96	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x78e6c28d	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xd0f054b4	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xf04a9822	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0xf0d37466	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x09ada4d7	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x25f4d6d6	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x845531d0	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xfb0d579e	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x26225b82	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x67b37080	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x079f7fe2	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x9416e953	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/wire 0x2cb4cffc	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xba90c91e	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0xbe25cea6	w1_register_family
++EXPORT_SYMBOL drivers/w1/wire 0xf93f6d40	w1_remove_master_device
++EXPORT_SYMBOL fs/configfs/configfs 0x1ef825ae	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0x27b4f934	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x4e0ecf10	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x6ec83fb6	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x77dd409e	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x8552af48	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0x922feafb	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0xc94a8a0d	configfs_unregister_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0xcd9b1c0d	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xd16dc93b	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0xd8bf5e79	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0xe84e3fed	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xf7dc23d8	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0xf96b6e6f	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0xfa57b204	config_item_put
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x2cc925e0	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x4856c4a0	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0x5000b0c5	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0x67ae5e32	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0x8a098bd3	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xb1522d93	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0xb90bd1ff	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0xd5e629a2	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0xe69cd729	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0xf66e4974	ore_get_rw_state
++EXPORT_SYMBOL fs/fscache/fscache 0x070dddfd	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x0c498ea8	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x0ecdca9b	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x11831941	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x1447e843	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x2b6f409a	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0x3232df79	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x3f8fa90a	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x458427fc	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0x503bb974	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0x53f6437a	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x690bab17	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x6dac81c9	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x7b6c4c44	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x81498834	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x841510b7	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x90ad6122	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x9a42c56c	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x9f68977b	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0xa13dc31e	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0xa217e389	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0xa477ad4a	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0xaef627f2	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0xaf158a42	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0xb658be48	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0xb6f40230	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0xba03b703	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0xbcbb29cd	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xc31c1de6	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xc419b704	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0xda1b6208	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xdabf3329	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xdca42978	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0xdce7da41	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0xe606b79b	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0xe8610bc3	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0xec75adb7	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0xf1b892b5	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xf9caf751	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0xfaf55cf0	__fscache_update_cookie
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x7e511a56	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0x8c74dd1d	qtree_read_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x9ff58bac	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xafafc732	qtree_write_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xe79e8b2a	qtree_release_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x1a703ba1	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0x6d356209	crc_itu_t
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc7 0x56329ecc	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd09b2cba	crc8
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x0641307b	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0x098d2ed9	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x2d47ac83	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0x2f3dcecb	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0x3dae6a2d	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x4522d82a	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0x4cf5f5a8	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0x5752f31b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0x7257beee	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0x9134feb7	lc_get
++EXPORT_SYMBOL lib/lru_cache 0xa25dfb25	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0xb672aa97	lc_create
++EXPORT_SYMBOL lib/lru_cache 0xbfbe53d5	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0xc3a98c1d	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcc979a91	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xefec290a	lc_find
++EXPORT_SYMBOL lib/lru_cache 0xfd525ec7	lc_put
++EXPORT_SYMBOL lib/lz4/lz4_compress 0x0c222eb5	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x682a23e0	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x6703409f	lowpan_netdev_setup
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xad8efda5	lowpan_nhc_add
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xf75f661f	lowpan_nhc_del
++EXPORT_SYMBOL net/802/p8022 0x63732499	unregister_8022_client
++EXPORT_SYMBOL net/802/p8022 0xd8118863	register_8022_client
++EXPORT_SYMBOL net/802/p8023 0x141b32ad	make_8023_client
++EXPORT_SYMBOL net/802/p8023 0x8b373c0e	destroy_8023_client
++EXPORT_SYMBOL net/802/psnap 0x56ecbb82	register_snap_client
++EXPORT_SYMBOL net/802/psnap 0x9f0ba4fb	unregister_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x06dcf9a2	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x075dfcb5	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x092432be	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0x11fe1135	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0x12405f61	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x13cf9b23	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x15204987	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x3aeaa2d6	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x3bdf0089	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x432b893f	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0x43ea3a08	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x44e2ab7e	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x54b8c408	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0x58814c8a	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0x596de006	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x62db898b	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0x640b2a1c	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0x65db6f68	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x6b2f6ff5	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0x6dcb9b56	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0x729afe14	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x75cfe78f	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x7f9fd1c5	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x82e19459	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0x82ffdbf0	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0x8945fc0f	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0x9345b3be	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0x9934b81a	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x9b820e1e	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x9d69d19a	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0xa4b0673b	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0xb0bc5265	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0xba2c0084	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0xbd0e88cc	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xc1d41afd	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xd0a7965c	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xd9cdebec	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0xdde47042	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0xde1090f8	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xee4a2c4c	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf58f70c6	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfb642cb9	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x39638481	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0x6d498eff	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0xe05c72cc	atrtr_get_dev
++EXPORT_SYMBOL net/appletalk/appletalk 0xfdc2b5fe	aarp_send_ddp
++EXPORT_SYMBOL net/atm/atm 0x19620422	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x48d08f1c	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0x5b26d856	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x6ea553c6	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x724f513b	atm_charge
++EXPORT_SYMBOL net/atm/atm 0x94751304	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xa62af99e	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xc74b11bb	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xcb539211	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0xcb64a59d	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0xe76ef328	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0xf34b63a3	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/atm/atm 0xf919c28f	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0xfac5ae25	vcc_sklist_lock
++EXPORT_SYMBOL net/ax25/ax25 0x02f3e039	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x286d91f8	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x4bb9dd48	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xddb7ded2	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0xea937163	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0xec489295	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0xed802e87	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0xfc659eec	ax25_ip_xmit
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x07463dd7	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x088700e5	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0baf04b2	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0fd5fa9d	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1b12b0ad	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1f1eca51	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x272a8ff9	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2b4b8c6e	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x30d94f03	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x353f0b78	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x36ec1831	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x399c5e7f	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x473b059e	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x5345ec5f	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x534971c9	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x5696ea0a	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x593ba1a8	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x5a48e66c	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6386f08e	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x76ae1e82	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x79e15548	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x80bb571c	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x80d304c3	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8e82e0da	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x909ddbd1	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x95fc0255	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9ae32dff	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa56e7b56	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb696bb70	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbc1bf11e	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc0839282	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc6443659	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd018dc7a	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd1888807	bt_sock_wait_ready
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xde731924	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe2b79033	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe61b9352	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xeae3beea	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xef2a7fd7	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf2e48501	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf331b098	hci_unregister_cb
++EXPORT_SYMBOL net/bridge/bridge 0x7f04a49c	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x35f01696	ebt_do_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x728de689	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xc81f23ef	ebt_register_table
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x43cfb90e	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x4c1d2523	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xacf16789	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0xad3c5851	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xf27eaeb4	caif_enroll_dev
++EXPORT_SYMBOL net/can/can 0x1e373eab	can_send
++EXPORT_SYMBOL net/can/can 0x200d73bb	can_ioctl
++EXPORT_SYMBOL net/can/can 0x880b3719	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0x9389ed4c	can_proto_register
++EXPORT_SYMBOL net/can/can 0xe0d6a8de	can_rx_register
++EXPORT_SYMBOL net/can/can 0xe7bdf467	can_proto_unregister
++EXPORT_SYMBOL net/ceph/libceph 0x01203403	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0x03e1009a	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x05aac563	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x08653c48	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0c648e2e	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x1096abe3	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0x165c4376	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0x169978b1	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x1d09ab1d	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x211dee73	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0x21c60751	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x22c4e73c	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x24d897df	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x25cd096b	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x2ad91414	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0x2d6b88aa	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0x337dfcd0	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0x37815261	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3c7995d0	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0x3c8d95cc	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x3fd49c4e	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x401a473a	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x419cb09b	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0x420f8019	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x427eef26	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x4280dfa6	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x428484f3	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x4496ed1e	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0x457ba9b1	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x4a627ebd	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x4a698df1	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x4cdcd8c8	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0x50be44d4	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x5378a965	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x5abd03a3	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x68c80c5e	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0x693f16b7	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0x6956dd82	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0x6a38c128	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6fcdafef	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0x702f2625	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x7211db4f	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0x7347e2e6	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x77938e5a	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x78c25177	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0x7c66feb6	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0x7e8965c8	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0x81f0dbb3	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x81f91acd	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0x85c3c176	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0x8acd474d	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x8bed27ec	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x8c7a33d6	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0x8ee867c6	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x8efe1be8	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0x914f2db2	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x92fd8f22	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0x932303fb	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0x9985719c	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0x9f8688b7	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xa1861d67	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xa240c54f	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0xa3b1aded	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0xa54b38eb	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xacc08164	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb190136f	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0xb23fecf2	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0xb40c6f2f	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0xb42e79a1	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb733ab2d	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0xbab1d406	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xbff0325a	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xc0db9bba	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc6cee4f2	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc918d122	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0xc9441cb0	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0xc966708b	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xcff6fd9f	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd7acd83f	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xda8e5975	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0xdd43e1fb	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0xe1d1c47e	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0xe3b042ca	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xecb55c8f	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xf1800993	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xf35cb4d9	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xfd62d3c9	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0xfe2bf57c	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x36bfd088	dccp_req_err
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x50c94942	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x281a1969	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x505accf6	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x904231d4	wpan_phy_new
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xa698401a	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xb2e195d1	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xe553eacb	wpan_phy_find
++EXPORT_SYMBOL net/ipv4/fou 0x3106aeb4	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0x57557ca0	fou_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xd0750778	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0xe81594e3	gue_build_header
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x4fe0392c	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x529efaa0	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x89cd5c93	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xd534821b	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xee9fcdcc	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xfb242c58	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x4b4fd9f5	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x87ea5c4e	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xf16b99b9	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x45f6b723	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x7b478462	ipt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xecdbcb3c	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x0ad9a4fc	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/tunnel4 0x8e57f5ec	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0x48729ee1	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x9f2e7d13	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xe349b405	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xe67f8e30	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xef3c6a23	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x494d478c	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x6b46cbb8	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xcb7e64fe	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x3324bb54	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0xc672f38c	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x2ad8cf67	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0xdcd3d2ba	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x2d1fcbe1	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x51c60cfc	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x99a93335	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xa1927403	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xb03c93aa	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xc8384ea4	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xca08ca61	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xfb8d3aaf	ircomm_open
++EXPORT_SYMBOL net/irda/irda 0x01590a8b	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x041570a9	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07015ee1	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x092d38f6	irlap_open
++EXPORT_SYMBOL net/irda/irda 0x0e270af5	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x15d51cac	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0x1a9f11b6	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0x22f4efe6	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0x2a17732a	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0x2ab606bf	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0x3379720b	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x4ac9328b	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x4f26320c	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x56b99f6a	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0x69be6b33	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6b7f50b3	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0x6dbf5f8a	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7797e138	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7c2635b9	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x8bded5a2	iriap_open
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x94b1f906	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x9516f690	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x96fd8638	iriap_close
++EXPORT_SYMBOL net/irda/irda 0xaa4cdd94	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xaad2d90a	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0xaec635e4	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0xaf552faf	irlap_close
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xb9d75d30	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xc0099d7b	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xd22e8861	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0xd7702e20	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0xdcc5d5a8	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0xdd988ce6	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe4ac6f08	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0xe58ba397	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0xe7327612	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0xe7aa593d	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xf0f25ffe	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0xf1d817c4	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0xf2b37dee	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0xfc518aa7	irttp_dup
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x59e01660	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0x340a707a	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x06793aaa	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0x0c21220f	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0x55a4b17c	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0x9c68f223	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0xc1ea34f5	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0xcd471314	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0xdb1ba155	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0xf38b87b0	lapb_unregister
++EXPORT_SYMBOL net/llc/llc 0x17ef4b52	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x5d4500d4	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0x9816c71a	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0x985bbf87	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0xb0319dff	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0xbcde2313	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0xbff90337	llc_set_station_handler
++EXPORT_SYMBOL net/mac80211/mac80211 0x001cc872	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0x035b0250	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0x06908d1f	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x0809945c	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x0bd609f2	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x0d776352	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x14f6dab2	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x18b71484	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x1d6c5ff1	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x1e8ccef0	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x1fbd523e	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x2431298a	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0x25dd4850	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x28e5d7e2	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x30c83f92	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x333a161d	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x3753d257	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x3a157da8	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x3b32f65c	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x404c6c71	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x419c0202	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x47f736cf	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0x4c2b011a	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0x5298c4fb	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0x55f97e4f	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x5ee69ecf	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0x6104381e	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x6231910c	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac80211/mac80211 0x625e7477	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x64115afa	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0x66c3b857	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x701a5f00	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x773d9ad1	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x785550dd	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0x791a8422	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x7db92782	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x7e98a691	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x85096f68	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x8650e731	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0x86af62f2	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x87a8abe5	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x87b24a4a	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x8e5fee67	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x8e6f30c6	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0x8ea366d9	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x8f08f192	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x90a6799b	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x955ff08e	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x96140dd1	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0x99be41d4	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0x9a6302aa	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x9c616302	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0x9e63e94a	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0xa134e9bb	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0xa6bb9fc4	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0xa7e3ec24	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xaa582476	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0xaac21de0	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xabe3fb08	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0xad62debd	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xae106eb4	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0xaffc09ca	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xb21e798a	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xb472dbbd	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0xb64af6dd	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0xb71f11d0	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0xbc5a0475	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0xbe72493b	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0xc508dbe6	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xc7b65324	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xcaeb18b6	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xd0f08a2b	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xd30af2a8	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xd85f560e	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0xe2e812d0	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0xe8f9bb51	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xeed3569b	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xefd4d478	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xf1673b19	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0xf552f893	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xf7c9319c	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac80211/mac80211 0xf9bf8e38	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x126412f2	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x2b8f8781	ieee802154_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x4c54dbad	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0x4fc5a22c	ieee802154_register_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x6b21c115	ieee802154_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x7da8c57b	ieee802154_xmit_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0xd2ee1a04	ieee802154_alloc_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xe9d105f3	ieee802154_unregister_hw
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x10c82761	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x204f80d9	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x357b1f5c	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x37a50615	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x42018d64	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x4f9bd823	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x5ef2d944	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x712064d6	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x792c618d	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x7a5c715c	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x848ba30b	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x899f30c9	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xe2fec14c	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xe787065a	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x700ea973	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x972a9974	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xbb1ba884	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x70916321	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x7623388d	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x961e33a0	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/nf_nat 0xe17c24ea	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xe7f17e09	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0xe8cb9ed3	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/x_tables 0x253e8b44	xt_compat_init_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0x2f0630c1	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x3149502b	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x50e8afe5	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x52e45992	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x71ad054f	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x7888cae9	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x91abae98	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xa25fc115	xt_compat_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xa3ba46a6	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xdb0cae0e	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xfe35f240	xt_find_match
++EXPORT_SYMBOL net/nfc/hci/hci 0x1773c186	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0x20cda224	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0x3f4a26f8	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x46114fb2	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x514b4d46	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x5a9a0c51	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x5be1ed03	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0x63c5ab4d	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0x8a26672d	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0x915836e1	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0x92a3ac3b	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0xa0c533d4	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0xa2653756	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xa4186418	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0xa5a6e1c3	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xa8de0a30	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0xa9470251	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xaa902d33	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0xac99cb27	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xea292b87	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0xf308c3a3	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/nci/nci 0x00fe5d65	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x033255aa	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x13f1598b	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0x14857578	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0x2d78622c	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0x4397ef04	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x48551031	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0x4e4de30b	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0x5606fd4a	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0x606336ea	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x71fe700a	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x7753dbcf	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0x785c0d0f	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x7df36b5b	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x8d671e35	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0xa60d8aa3	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xa9d56e4a	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0xb6a0d25b	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xbf510fc2	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0xbf620ab7	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xd0ceae33	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xd5c7b473	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0xde2926e6	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0xe173bbf4	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0xe4a1eb9f	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xe539cd05	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nci/nci 0xe76f2f2e	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nci/nci 0xe9af075d	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nfc 0x05df4677	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x07ee2ca0	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc 0x13c4c892	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0x1e4de0ef	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0x20c6b9fe	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0x21bfeee0	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0x24dafca7	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0x26b45dfb	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0x2ed8bec9	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0x40fd7afb	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0x4cbf0477	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0x4e84cade	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0x6747d4c8	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0x75c2133f	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0x7bb95aef	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0x95d2fc57	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x9afcd157	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0x9b0dc825	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0xa1c92737	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0xa5a9a88a	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0xce3e1824	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0xe5c9d77d	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xea8d8624	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0xf7850d1c	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc_digital 0x28d85dad	nfc_digital_free_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x39c4b146	nfc_digital_allocate_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x7e23d870	nfc_digital_unregister_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xac7d4f8a	nfc_digital_register_device
++EXPORT_SYMBOL net/phonet/phonet 0x19047d3f	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0x4879c7c7	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0x62925657	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0x6415eec6	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0x7f31221c	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0x89c6f513	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0xd8ca0975	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0xe4efe844	pn_skb_send
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x10f23baf	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x23f7a410	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x6379aced	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8d42addb	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x916aa7c7	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x94ef092c	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x9e47187c	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xaccb1c30	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xc546e58c	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xc619d46e	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xca6a6c68	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xdf426645	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe20b10ad	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe7bf3c7c	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe896e22a	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/sctp/sctp 0x058887e4	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x1b6c69a2	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x9fcd66b0	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xef00807a	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x2598a475	xdr_restrict_buflen
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x76d6e6e4	svc_pool_stats_open
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xb6a05f70	xdr_truncate_encode
++EXPORT_SYMBOL net/wimax/wimax 0x1770632b	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0xb6373097	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x043e8485	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0x0441103b	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x054c5580	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0b04943f	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x0b05d02d	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0x0c4959ea	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0x0d2dc1a2	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x0f3b5479	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x0fba07d6	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x108f83a5	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x12136d36	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x13aee0ce	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0x13c0605e	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x18a37989	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x216f0ee6	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0x2558ca62	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0x25ca75e8	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x2bff0fa8	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x2c7a979d	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x309d0308	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x37cfd35f	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0x3a3204b1	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x3cd0a72d	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d6c99f8	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x4155c79a	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x42e6b961	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x454e93fc	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x5075c756	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x538f0937	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0x547cecd4	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0x589c178b	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x58ed9185	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0x5a628d79	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x5af5be40	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x62d4b888	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0x687cd28f	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x6fa3cc1b	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0x71786cb2	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0x7463bb24	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x842e7ec1	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x86a186a6	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x8bfc7ebd	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0x8f3ff0c5	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x91d7a142	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x935761b2	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x93e5b348	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x948579b6	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x9930cd04	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0x9bd55917	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x9be36c29	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0x9e02a0a9	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0x9e660d80	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x9f96655a	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1a15190	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xa78db6bf	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0xa850d7a3	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xacd5f934	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0xba3a79d1	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xbda7442c	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0xc1f6b093	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xc200bf05	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xc310df6f	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xc485e821	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0xc56d3af2	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0xc5e89905	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0xc61c0f9b	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xca76d360	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0xcab036eb	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0xd3d79cab	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0xd50b0a22	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xd5842348	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xd64876fd	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xd7870f73	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xdac94f37	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xdf39cb81	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0xe13d0f9e	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0xe29cd2b0	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0xe430fb58	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0xe55d7114	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xebe51d7f	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xf47e7062	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0xf881ad5e	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xfa3f5709	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xfc7bc6d8	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/lib80211 0x37e46be7	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0x5c8b1bf6	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x69dea410	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x7326dda7	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x9b75cb09	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0xfc4aa5de	lib80211_crypt_info_free
++EXPORT_SYMBOL sound/ac97_bus 0x70bfa0e2	ac97_bus_type
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0xb79f20c8	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x09278efd	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1859c4f2	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x5dddaaa0	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xd0a8d929	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x22c5fc9a	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x045df6a4	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x19644b06	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x237c480c	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x46d509d4	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x48501cc2	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x57427cce	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x6e4581b3	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xfdab5ab4	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0xeae81b48	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x05b98f34	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0x0d3960e6	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd 0x172e3612	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL sound/core/snd 0x1a61751c	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0x1def8604	snd_register_device
++EXPORT_SYMBOL sound/core/snd 0x207535ec	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x28e026d7	snd_jack_new
++EXPORT_SYMBOL sound/core/snd 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0x2b85b547	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0x342a2354	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x36d025a6	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x40ebf0d4	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL sound/core/snd 0x45132b1f	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x51d72d17	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0x59993577	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0x5b444c57	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0x5d95ca2e	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0x5f78e79a	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0x62a2b41f	snd_unregister_oss_device
++EXPORT_SYMBOL sound/core/snd 0x638e08f4	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0x77e4fea5	snd_jack_add_new_kctl
++EXPORT_SYMBOL sound/core/snd 0x7add7252	snd_card_new
++EXPORT_SYMBOL sound/core/snd 0x7f9baa83	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x81d53c75	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0x8ab20b45	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0x8da6eaba	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x93b6903e	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0x986dddba	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd 0x9d3fbec4	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0x9d63da89	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0x9e5bbb6b	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0x9f41ea93	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xa19b2f87	snd_cards
++EXPORT_SYMBOL sound/core/snd 0xa2d8e4b8	snd_ctl_unregister_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0xa6251602	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0xa81a0233	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xbb5e6e5c	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0xbb7f69eb	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0xc2b4a031	snd_ctl_register_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0xc513c90e	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0xc6bd8b43	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0xc6c172f3	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0xd25dc1db	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0xd264bd36	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0xd622896f	snd_device_new
++EXPORT_SYMBOL sound/core/snd 0xd88d7fb8	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0xe5e80e02	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0xe9f42b2d	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0xea42d7aa	snd_register_oss_device
++EXPORT_SYMBOL sound/core/snd 0xef9aa6f5	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0xfffd89db	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd-hwdep 0x3ecf144e	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x06b310c9	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x0a633941	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0x0bc4896c	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x0ea8fdc0	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-pcm 0x0fa5bfa7	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x213f26d1	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0x2204b75b	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0x2893a6bb	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x2c4cf06a	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0x33434298	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x346c3d23	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x34a8f5af	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x3cebeb0c	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0x3d6ac53d	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0x40e4e9d5	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x4e561702	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x530a5086	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x5898dcba	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x5b5ada79	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0x5c66f3fd	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x60cd79aa	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x6a096259	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0x6abc8c9e	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x6d0b8284	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x6fdce13f	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x71e3579a	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0x78344217	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x7e30468d	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x834dc955	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x86540b82	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x91d2753e	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x9a474df6	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0x9abf3f90	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0x9be9f9e2	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL sound/core/snd-pcm 0x9ec82701	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xa754e292	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0xa80d3461	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xaedf1861	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xc1554b3f	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0xca96d19a	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0xcaded9b1	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-pcm 0xd303ff03	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0xd8deb8b1	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0xd96a6441	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xdb10e823	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0xe1047cad	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xe1c274a4	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xe5753234	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0xf510b511	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x01dc2c0e	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x11d73c85	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x2922913e	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x2d8e2f8e	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x2da276b0	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x3634460f	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x427b7cb5	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x49f3ec2a	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x53a545ed	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x5aee6360	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x5dfa8dd6	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x645bb3f2	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x649c0253	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x6964052f	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x69a24bcf	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7abcc6f6	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb67f285d	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd2897c2e	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xe286016c	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-timer 0x01b11d28	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0x285a9917	snd_timer_global_register
++EXPORT_SYMBOL sound/core/snd-timer 0x2bf4b193	snd_timer_pause
++EXPORT_SYMBOL sound/core/snd-timer 0x4700a6e3	snd_timer_stop
++EXPORT_SYMBOL sound/core/snd-timer 0x59458183	snd_timer_resolution
++EXPORT_SYMBOL sound/core/snd-timer 0x659cdae9	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0x7c7b7ecb	snd_timer_open
++EXPORT_SYMBOL sound/core/snd-timer 0xac8f0551	snd_timer_interrupt
++EXPORT_SYMBOL sound/core/snd-timer 0xcc2c94e9	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0xd0d7f69d	snd_timer_close
++EXPORT_SYMBOL sound/core/snd-timer 0xe35b99e2	snd_timer_start
++EXPORT_SYMBOL sound/core/snd-timer 0xea2d1817	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0xf8a5978b	snd_timer_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xfa8a522a	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x17e78c79	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x1c2188b2	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x5197aca7	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x66ed5990	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x844f2fc0	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xaf12d877	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xbd534d67	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xdec6dc65	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xfb54967f	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x121d44bd	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x3a4a324c	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x50948a3d	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x63a7e41d	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x6db6d2d1	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x6e75becd	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x837d74fc	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x8609e078	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xbaba1dca	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x0b108858	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x0f6b62d9	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x0ff34007	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x17b4613d	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x220ccba4	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x23c0c556	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x26ce1efd	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x31e941ca	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4736c3f1	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x49a83bbe	amdtp_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x618979b1	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x623a956a	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x6c091624	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7139aeae	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x766c7e99	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7c4bec1e	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7e1d0233	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x800c37f2	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8eaf4b16	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x909d2d21	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x958afad8	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9711ab1d	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x982707b0	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9fcf2a83	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa78a56d7	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xab9efa08	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc1347566	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xcbd0c991	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd27f8f39	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd474ac76	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf5a4ecf5	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xfb1f1294	fw_iso_resources_free
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x6d5c48f1	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x9b37c2d6	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x0d1572a9	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x1dfa14b9	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x53174dd8	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x5ebb775a	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x6d5cc1d8	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x7514922b	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x75e9949f	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xcca49ac7	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x7b7b96ab	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xb9eadd54	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xcbdf10a5	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xe38e567d	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x0a382c8d	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0xe834ba97	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x1cef78f1	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x420bae57	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x51088c3d	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x5c6a040a	snd_cs8427_init
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x843c84be	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xe92b3022	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x53d958be	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x64897953	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xb38e7885	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xba9f3907	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xe39c231a	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xfed63956	snd_i2c_device_create
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x03a4edca	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x041058c9	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x13de7ae5	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x27975cb9	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x4b1df50a	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x4ec1ae0e	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x62732e6a	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x73e5b5eb	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x7c06f4c4	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb4028ba7	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb8a60773	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb9c8585d	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xba349dda	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xcb7e3005	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xf5c5acfa	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xf81a66d7	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xff3e6b33	snd_ac97_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x0eb751a5	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x140136ac	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x19674e4b	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x409de96b	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x4aa691b7	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x695b77e6	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x8a513e2a	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xcc0c7f2d	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xf0ea5042	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x1d9878d3	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x397b2607	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xedac822f	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x14cb9e28	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x15cfc4a0	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x32c2881c	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x3f110a0b	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x515d6423	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x5b6b5d51	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x679c0eca	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x67bc72e5	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x7f2f6d8d	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x91d66430	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb3b4b81c	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb3b879f6	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb5d167e6	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xd0c0a545	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xd273f56f	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xd4d0699c	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xea94e6d1	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xecf45ea0	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xef8aa2d1	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf3660e55	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf8b09490	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x659b7183	snd_trident_free_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x6a2db364	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x8c6465e0	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xb08d1db3	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xbf72d191	snd_trident_start_voice
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x73f1ae21	tlv320aic23_probe
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x8a4c40b7	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/snd-soc-core 0xe18b8502	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL sound/soundcore 0x1347e769	register_sound_special
++EXPORT_SYMBOL sound/soundcore 0x2c1f78ca	register_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x8fbe530c	sound_class
++EXPORT_SYMBOL sound/soundcore 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL sound/soundcore 0xb32a6cfa	register_sound_midi
++EXPORT_SYMBOL sound/soundcore 0xb7b929b5	register_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xd5fc4873	register_sound_special_device
++EXPORT_SYMBOL sound/soundcore 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x11779f20	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x1c81daa3	snd_emux_register
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x698ef89f	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x83c42d46	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x87c9ab56	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xd513c0fb	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x25d4b326	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x4abf9f95	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x81be962a	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x8fa5f186	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xda157ec1	snd_util_memhdr_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xe5301ba3	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xf81adc3c	__snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xfd2ad139	snd_util_memhdr_new
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd42a056c	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL vmlinux 0x00198002	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x004ab51b	tc_classify
++EXPORT_SYMBOL vmlinux 0x0058f756	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0x0059c7f3	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0x0070cd1f	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x0085e1f1	__do_once_done
++EXPORT_SYMBOL vmlinux 0x00b89f97	kern_path_create
++EXPORT_SYMBOL vmlinux 0x00cc6580	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x00e61772	register_netdev
++EXPORT_SYMBOL vmlinux 0x00fa2149	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x0131aaf6	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0x0133326f	of_graph_get_remote_port
++EXPORT_SYMBOL vmlinux 0x016badab	blk_register_region
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x0171d14d	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0x0173e909	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0x01768c34	__sb_end_write
++EXPORT_SYMBOL vmlinux 0x01783e98	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0x01790e94	csum_partial_copy
++EXPORT_SYMBOL vmlinux 0x01856b8e	input_reset_device
++EXPORT_SYMBOL vmlinux 0x01975ad9	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0x019927e4	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x01ae0dc5	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0x01cd2597	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0x01e4f467	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0x01f32aaf	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x0213b4f9	pnp_get_resource
++EXPORT_SYMBOL vmlinux 0x0224b729	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0x023998a3	cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0x0243c384	keyring_alloc
++EXPORT_SYMBOL vmlinux 0x024bf827	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x0257addd	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x02687bf4	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x02693882	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x026d23cb	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x029873f4	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0x029fe114	of_io_request_and_map
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a4db3b	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02b84013	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x02be3b33	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0x02cc30ec	lease_modify
++EXPORT_SYMBOL vmlinux 0x02d68fa3	param_get_short
++EXPORT_SYMBOL vmlinux 0x02e5c637	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x02ff3196	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0x03049b57	set_wb_congested
++EXPORT_SYMBOL vmlinux 0x031ee4b0	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0x0321ab25	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x032c162b	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x0338478e	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0x034c1104	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x03588a5c	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x035f891b	down_interruptible
++EXPORT_SYMBOL vmlinux 0x0360c0ef	of_get_parent
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x0390d4ca	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0x03ac3617	md_integrity_register
++EXPORT_SYMBOL vmlinux 0x03ca6e63	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0x03e43963	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0x03edac76	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x040d05b6	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x0428d696	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x045e8419	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x048d16ec	bio_map_kern
++EXPORT_SYMBOL vmlinux 0x049d6cbd	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0x04b42f6e	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0x04bc7fd5	input_register_handle
++EXPORT_SYMBOL vmlinux 0x04dac95d	dev_err
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04ea5d10	ksize
++EXPORT_SYMBOL vmlinux 0x0508046b	inet6_bind
++EXPORT_SYMBOL vmlinux 0x050877b9	dmi_first_match
++EXPORT_SYMBOL vmlinux 0x0508c7cb	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0x050cdec6	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0x05186ca4	flush_icache_range
++EXPORT_SYMBOL vmlinux 0x051e2473	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x052e8b07	of_device_get_match_data
++EXPORT_SYMBOL vmlinux 0x053fd287	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x055ab0e9	compat_nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x055c8559	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x05644d0d	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0x056a7ee7	blkdev_get
++EXPORT_SYMBOL vmlinux 0x0575176c	param_get_string
++EXPORT_SYMBOL vmlinux 0x05757d3e	dev_mc_add
++EXPORT_SYMBOL vmlinux 0x0588fc78	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x05a5caa8	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x05b09848	kernel_listen
++EXPORT_SYMBOL vmlinux 0x05ba6c9e	acpi_bus_get_device
++EXPORT_SYMBOL vmlinux 0x05bf8041	lro_flush_all
++EXPORT_SYMBOL vmlinux 0x05d6eaf4	vfs_setpos
++EXPORT_SYMBOL vmlinux 0x061225bc	tcp_child_process
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x061f4039	acpi_get_table_with_size
++EXPORT_SYMBOL vmlinux 0x06201008	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x064d62cd	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0x065cbde3	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x0660d35b	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0x066247dc	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0x066f92bf	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0x067a8424	inet_ioctl
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x068c7b31	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x068c876a	may_umount
++EXPORT_SYMBOL vmlinux 0x06911320	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0x06ce433e	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0x06e88bb1	vga_put
++EXPORT_SYMBOL vmlinux 0x06f73614	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x06fa94de	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x0707ae0a	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x0708740f	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x072b1666	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x0751fb52	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x0758d772	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x07788111	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x0779c69d	acpi_get_hp_hw_control_from_firmware
++EXPORT_SYMBOL vmlinux 0x078cd1d5	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x079f8a4a	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0x07a4b576	flex_array_free
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07a9ef84	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07ec2b4f	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0x07fdc7cb	of_phy_register_fixed_link
++EXPORT_SYMBOL vmlinux 0x0820802d	flush_old_exec
++EXPORT_SYMBOL vmlinux 0x08216310	of_get_property
++EXPORT_SYMBOL vmlinux 0x082a0eb6	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x0841e623	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x0847056b	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0x084fc808	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x085558b7	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x085fef63	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x087945e6	acpi_processor_notify_smm
++EXPORT_SYMBOL vmlinux 0x088a30c8	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x089d0420	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0x08d0e5a0	vc_cons
++EXPORT_SYMBOL vmlinux 0x08db5210	dquot_acquire
++EXPORT_SYMBOL vmlinux 0x08e273a3	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x09058f0e	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0x090fe7bc	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x0914c234	revalidate_disk
++EXPORT_SYMBOL vmlinux 0x093bfc3f	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0x094cca1c	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0x094cdbab	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x095983cd	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x095fad83	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x096655a4	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x09696626	acpi_decode_pld_buffer
++EXPORT_SYMBOL vmlinux 0x097baff7	seq_open_private
++EXPORT_SYMBOL vmlinux 0x097ca606	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0x098431ba	acpi_get_current_resources
++EXPORT_SYMBOL vmlinux 0x09866fb3	vfs_unlink
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x09952fc1	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0x09a9b948	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x09b595e1	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0x09b5d7c0	input_register_handler
++EXPORT_SYMBOL vmlinux 0x09c4b167	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c745bf	security_path_mknod
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09d0dee8	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09db4c56	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0x09ea9873	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0x0a0ddd2d	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a2d7df4	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x0a3a98fa	dput
++EXPORT_SYMBOL vmlinux 0x0a54867a	touch_atime
++EXPORT_SYMBOL vmlinux 0x0a57863e	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x0a5d3524	of_parse_phandle
++EXPORT_SYMBOL vmlinux 0x0a62573a	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x0a6505b0	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0x0a97451f	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0x0aa055d9	generic_write_end
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0aacfd46	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0ae060ca	__neigh_create
++EXPORT_SYMBOL vmlinux 0x0ae6be6a	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x0aea8ba9	sock_efree
++EXPORT_SYMBOL vmlinux 0x0af180fd	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x0af2fcb4	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b20afce	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0x0b34af6d	seq_release
++EXPORT_SYMBOL vmlinux 0x0b43d995	__bread_gfp
++EXPORT_SYMBOL vmlinux 0x0b4a4ed3	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x0b510283	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b70876e	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b891ec0	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0x0b89cfab	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x0b8e6da1	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0x0b973901	scsi_device_get
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bbd0408	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0c05e1c2	kernel_write
++EXPORT_SYMBOL vmlinux 0x0c2020be	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0x0c21d019	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0x0c31f7cc	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0x0c33f003	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x0c3a757c	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0x0c403a35	dev_printk
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c4c6479	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c6586e4	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x0c6bdc3f	vme_master_read
++EXPORT_SYMBOL vmlinux 0x0c6fa9d5	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x0c782d44	input_release_device
++EXPORT_SYMBOL vmlinux 0x0c968ae4	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0ca1b03d	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x0ca7b7a8	acpi_check_region
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cb166c5	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0x0cc62817	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0x0cd3dc7f	netlink_capable
++EXPORT_SYMBOL vmlinux 0x0cdf8f37	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x0ce05506	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0x0ceb32fd	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0x0cefd735	__module_get
++EXPORT_SYMBOL vmlinux 0x0cfeb30d	pci_iomap
++EXPORT_SYMBOL vmlinux 0x0d0445c4	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x0d39d375	register_qdisc
++EXPORT_SYMBOL vmlinux 0x0d3dda14	acpi_get_type
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d80efb5	acpi_evaluate_ost
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0da7f832	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x0dcc4361	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x0ddf8ead	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0x0e05daf8	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0x0e0977e2	sk_alloc
++EXPORT_SYMBOL vmlinux 0x0e28d9a0	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x0e2d5906	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x0e3034b6	find_vma
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e754950	from_kuid
++EXPORT_SYMBOL vmlinux 0x0e77a781	lockref_put_return
++EXPORT_SYMBOL vmlinux 0x0e8c4e9a	filemap_fault
++EXPORT_SYMBOL vmlinux 0x0e9a8aa9	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x0ea124de	udp_ioctl
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0ecfe6c5	generic_show_options
++EXPORT_SYMBOL vmlinux 0x0ed62261	follow_down_one
++EXPORT_SYMBOL vmlinux 0x0ed8cc7b	acpi_evaluate_object_typed
++EXPORT_SYMBOL vmlinux 0x0eedb3b1	of_device_is_compatible
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f08062f	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0x0f1732cc	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0x0f1a970a	free_page_put_link
++EXPORT_SYMBOL vmlinux 0x0f2c820f	truncate_setsize
++EXPORT_SYMBOL vmlinux 0x0f3b43a9	console_start
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f508f7e	do_truncate
++EXPORT_SYMBOL vmlinux 0x0f546391	bh_submit_read
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f826382	dev_load
++EXPORT_SYMBOL vmlinux 0x0f89ad81	put_cmsg
++EXPORT_SYMBOL vmlinux 0x0f917480	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fbf4924	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0x0fc2d2df	__free_pages
++EXPORT_SYMBOL vmlinux 0x0fc480b2	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x0fccc98c	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x0ff2c759	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x1029c920	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x103386f1	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x10517247	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0x105d535c	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0x1070ac15	param_ops_long
++EXPORT_SYMBOL vmlinux 0x1072a394	csum_partial_copy_from_user
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x108619aa	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0x10950ee1	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x10a0d18b	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0x10a126f1	bio_flush_dcache_pages
++EXPORT_SYMBOL vmlinux 0x10a5d326	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0x10ad9d98	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x10ae4be3	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0x10bac640	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0x10bcf03c	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0x10c28b53	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0x10e2d2b9	dev_uc_init
++EXPORT_SYMBOL vmlinux 0x10e488aa	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x10f03591	register_console
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x110d8153	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0x1147fc36	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0x1151f460	vme_bus_num
++EXPORT_SYMBOL vmlinux 0x1153b0f4	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0x1154b03c	of_get_next_parent
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x11797fa8	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x11987b1c	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11c68d61	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x11d151b0	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x11e3aa46	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x12184756	complete_request_key
++EXPORT_SYMBOL vmlinux 0x1224161e	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0x123f82f3	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x1251c439	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0x1263a626	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x126ff9ad	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12bf2e88	sock_create_kern
++EXPORT_SYMBOL vmlinux 0x12c34130	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x12c4e166	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0x12ccd0e4	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0x12d01360	misc_deregister
++EXPORT_SYMBOL vmlinux 0x12de74d1	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0x12df67d7	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0x12dfeb12	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x12f7d0aa	mdiobus_free
++EXPORT_SYMBOL vmlinux 0x1305d532	ucs2_strncmp
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x132eaf3b	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x13315729	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0x133c7311	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x13430c18	bdget
++EXPORT_SYMBOL vmlinux 0x1351877c	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0x135d9806	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x138130a7	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0x13a8fa48	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x13b46454	udp_add_offload
++EXPORT_SYMBOL vmlinux 0x13ba3df9	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x13cdee1c	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13dabf77	clear_nlink
++EXPORT_SYMBOL vmlinux 0x13ed2fc6	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0x13efc3af	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x13fe4af7	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0x14100f8c	kobject_add
++EXPORT_SYMBOL vmlinux 0x1414c17a	dqput
++EXPORT_SYMBOL vmlinux 0x14195b17	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x144830f4	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x1453ba20	cont_write_begin
++EXPORT_SYMBOL vmlinux 0x1459e85b	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0x14ba7583	vme_irq_free
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x14f32ffc	key_invalidate
++EXPORT_SYMBOL vmlinux 0x150665b2	set_binfmt
++EXPORT_SYMBOL vmlinux 0x150c82f2	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0x1520497a	i2c_master_send
++EXPORT_SYMBOL vmlinux 0x1523388b	netdev_warn
++EXPORT_SYMBOL vmlinux 0x1530720a	dquot_resume
++EXPORT_SYMBOL vmlinux 0x15364b63	ida_remove
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x1554a083	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0x1554d8d9	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0x15571d5a	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0x1563ae0b	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x15894aa2	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0x159ac449	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0x15b630b3	qcom_scm_set_cold_boot_addr
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15c302e1	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0x15c6ca59	of_platform_bus_probe
++EXPORT_SYMBOL vmlinux 0x15cdc4c5	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x15d0bb38	nd_region_acquire_lane
++EXPORT_SYMBOL vmlinux 0x15ede059	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x15eed9bd	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x1616cb30	acpi_evaluate_dsm
++EXPORT_SYMBOL vmlinux 0x16266a51	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x162cb8f7	blk_finish_request
++EXPORT_SYMBOL vmlinux 0x16766435	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x167c3d6d	make_kuid
++EXPORT_SYMBOL vmlinux 0x167c5967	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x1682ea05	proc_douintvec
++EXPORT_SYMBOL vmlinux 0x16b11f4e	kdb_current_task
++EXPORT_SYMBOL vmlinux 0x16d5d2cd	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0x16d9bffd	compat_ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x16dde15b	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x16e2d2ff	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0x16fc7ac0	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0x170c25ee	acpi_get_next_object
++EXPORT_SYMBOL vmlinux 0x170d6607	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x17171f0c	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0x1732ee50	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x173afc25	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0x17755207	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0x178ee0d9	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x179034d8	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0x1793f685	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0x17a142df	__copy_from_user
++EXPORT_SYMBOL vmlinux 0x17a54753	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17baff12	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x17c1ae00	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x17cc1ad7	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x17ce7915	tcp_close
++EXPORT_SYMBOL vmlinux 0x180d13f3	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0x1818ddb1	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x183ad76c	pci_request_regions
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x186d207e	__alloc_skb
++EXPORT_SYMBOL vmlinux 0x187cf587	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x188a75bb	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x189af188	generic_permission
++EXPORT_SYMBOL vmlinux 0x189d98b3	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0x18adf1f1	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0x18b48e28	__memset_io
++EXPORT_SYMBOL vmlinux 0x18cda8dc	inc_nlink
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x18fef9cb	xen_start_info
++EXPORT_SYMBOL vmlinux 0x1902317b	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x19070a79	inet_offloads
++EXPORT_SYMBOL vmlinux 0x1924a454	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0x192c40fb	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x1943ce34	compat_sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x1978779c	dm_put_device
++EXPORT_SYMBOL vmlinux 0x198ae015	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x1992d8dd	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0x1994e9a0	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19b8a613	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19bf12a9	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x19c66139	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0x19c8d665	udp_set_csum
++EXPORT_SYMBOL vmlinux 0x19c92189	vfs_writef
++EXPORT_SYMBOL vmlinux 0x19dfbdde	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0x19e0cdf2	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x1a450280	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x1a450a66	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0x1a45cb6c	acpi_disabled
++EXPORT_SYMBOL vmlinux 0x1a4fb35c	iput
++EXPORT_SYMBOL vmlinux 0x1a72b586	pnp_register_driver
++EXPORT_SYMBOL vmlinux 0x1a744ac6	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x1ab06748	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0x1abb02e8	file_ns_capable
++EXPORT_SYMBOL vmlinux 0x1abff136	put_page
++EXPORT_SYMBOL vmlinux 0x1ac5d3cb	strcspn
++EXPORT_SYMBOL vmlinux 0x1acbd42e	nd_device_register
++EXPORT_SYMBOL vmlinux 0x1af39403	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b2d6d2c	qcom_scm_cpu_power_down
++EXPORT_SYMBOL vmlinux 0x1b2d727f	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x1b44c91e	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x1b498698	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x1b523b25	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x1b570d23	acpi_warning
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b789da8	sock_wfree
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b9fd2fa	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0x1ba6527f	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0x1baa80dd	tty_free_termios
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bc6a0c9	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0x1bca2a90	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x1bd09b75	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0x1bd9d60f	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x1c0a79a2	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0x1c114a6a	vm_event_states
++EXPORT_SYMBOL vmlinux 0x1c3554aa	of_get_named_gpio_flags
++EXPORT_SYMBOL vmlinux 0x1c63d901	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0x1c7407d0	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x1c7ca0e0	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x1c854f1c	tty_port_put
++EXPORT_SYMBOL vmlinux 0x1c8a04b0	acpi_reset
++EXPORT_SYMBOL vmlinux 0x1c95c0b7	current_in_userns
++EXPORT_SYMBOL vmlinux 0x1ca40c5a	tcp_prot
++EXPORT_SYMBOL vmlinux 0x1ca546e2	profile_pc
++EXPORT_SYMBOL vmlinux 0x1cb3f2a1	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x1ce48000	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x1d1056e5	crc32_be
++EXPORT_SYMBOL vmlinux 0x1d190878	file_path
++EXPORT_SYMBOL vmlinux 0x1d1c9aed	get_gendisk
++EXPORT_SYMBOL vmlinux 0x1d5c9743	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0x1d6795ee	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0x1d70db25	nf_log_unset
++EXPORT_SYMBOL vmlinux 0x1d89bdac	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0x1d92d898	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x1dbbce0c	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dcc5a9e	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x1dd27b8b	fget
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1dda1ba9	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x1de0f70a	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0x1de74f72	acpi_execute_simple_method
++EXPORT_SYMBOL vmlinux 0x1de9c165	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0x1deac342	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0x1df23a12	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0x1df51d4e	__frontswap_store
++EXPORT_SYMBOL vmlinux 0x1e0dadb6	dns_query
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e272d58	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0x1e4d0ce4	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e8c4653	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0x1e9c7202	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ea06663	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0x1ea0a7ab	kernel_neon_begin_partial
++EXPORT_SYMBOL vmlinux 0x1ea82e26	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0x1eb9a7f1	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0x1edba5f4	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0x1eeb0844	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x1f0fd642	param_set_byte
++EXPORT_SYMBOL vmlinux 0x1f15a2fb	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0x1f6435e7	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0x1f6ce67a	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x1f9764bc	of_n_addr_cells
++EXPORT_SYMBOL vmlinux 0x1fad1be2	register_key_type
++EXPORT_SYMBOL vmlinux 0x1fad61e1	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0x1faf5aee	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fc601a2	nd_btt_arena_is_valid
++EXPORT_SYMBOL vmlinux 0x1fcf4d4b	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fdc7df2	_mcount
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1fede718	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x202eee21	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x202f1cba	get_fs_type
++EXPORT_SYMBOL vmlinux 0x204346af	proc_dostring
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x204f70b0	__napi_complete
++EXPORT_SYMBOL vmlinux 0x205e7182	rwsem_wake
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x20861a13	inode_permission
++EXPORT_SYMBOL vmlinux 0x208739f6	acpi_load_table
++EXPORT_SYMBOL vmlinux 0x20892274	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x20906cd5	idr_destroy
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20ae26ac	clk_get
++EXPORT_SYMBOL vmlinux 0x20b2ad40	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0x20ba1388	d_alloc
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20d12b30	tty_check_change
++EXPORT_SYMBOL vmlinux 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x20e668ef	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0x20eadeb6	ip_compute_csum
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20ffa7f6	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0x2108a569	inet_sendpage
++EXPORT_SYMBOL vmlinux 0x21157aab	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x2119b522	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0x211f68f1	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x212ee0df	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x214316b0	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0x21471461	vme_slave_request
++EXPORT_SYMBOL vmlinux 0x214b913f	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0x218979cd	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0x219c8acb	register_sysctl
++EXPORT_SYMBOL vmlinux 0x21a6ed85	dev_alert
++EXPORT_SYMBOL vmlinux 0x21cad0e4	bdput
++EXPORT_SYMBOL vmlinux 0x21d97420	param_get_uint
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21eae615	__mutex_init
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x2234b7ca	fb_blank
++EXPORT_SYMBOL vmlinux 0x2238f8c5	address_space_init_once
++EXPORT_SYMBOL vmlinux 0x223973a9	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0x223b44f7	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x224695ed	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x224ff4ad	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x2251bc68	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x227bae42	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0x22adbf55	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x22adf114	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22b83fbf	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0x22baea3d	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0x22c8f1b3	__break_lease
++EXPORT_SYMBOL vmlinux 0x22e9a2dc	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0x230b5cc5	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x23266ed8	eth_header_cache
++EXPORT_SYMBOL vmlinux 0x2364c326	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0x23852630	iget_locked
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23b74eb0	would_dump
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23bcae7d	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23c9891c	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x23da6fb9	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x240bb574	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0x241443b0	serio_reconnect
++EXPORT_SYMBOL vmlinux 0x24180200	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x24213ea9	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x242a2ce2	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x24554b35	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x24656858	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x2484adc3	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0x249847e9	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x24b7ef43	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x24d1219e	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0x24d6665e	from_kgid
++EXPORT_SYMBOL vmlinux 0x24f303d8	fb_class
++EXPORT_SYMBOL vmlinux 0x24f7bfca	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x251156f9	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x252142d6	of_find_net_device_by_node
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x252d902f	vme_dma_request
++EXPORT_SYMBOL vmlinux 0x2536277b	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x25583e23	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0x255bb072	change_bit
++EXPORT_SYMBOL vmlinux 0x25612ba0	twl6040_power
++EXPORT_SYMBOL vmlinux 0x256a0a17	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0x256cb176	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x2570e830	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x25a28d01	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0x25a4457f	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0x25a90dab	dentry_open
++EXPORT_SYMBOL vmlinux 0x25b1360e	input_flush_device
++EXPORT_SYMBOL vmlinux 0x25e8ed29	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x2600882b	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x26243706	seq_path
++EXPORT_SYMBOL vmlinux 0x2625aa7e	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x26301fbb	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x263971d1	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x264dbf52	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x265636b0	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x2665d53a	key_create_or_update
++EXPORT_SYMBOL vmlinux 0x26689b0c	seq_lseek
++EXPORT_SYMBOL vmlinux 0x2685421a	load_nls_default
++EXPORT_SYMBOL vmlinux 0x26ae3256	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0x26d077ae	msm_pinctrl_remove
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26ed2f7c	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x27012e6c	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0x2711878c	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x271cba95	acpi_bus_private_data_handler
++EXPORT_SYMBOL vmlinux 0x2724ba66	__ioremap
++EXPORT_SYMBOL vmlinux 0x273a82e1	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x273ec35b	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x275e2243	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0x2781763e	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x2781bfb6	get_task_io_context
++EXPORT_SYMBOL vmlinux 0x27852d99	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x2787d728	key_unlink
++EXPORT_SYMBOL vmlinux 0x27961538	tty_port_close
++EXPORT_SYMBOL vmlinux 0x27ae7d0c	ec_transaction
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27d17d90	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x27d53e5a	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0x27d6b048	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x27e1ff9b	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0x27e507b7	write_one_page
++EXPORT_SYMBOL vmlinux 0x27ec0e8d	dev_open
++EXPORT_SYMBOL vmlinux 0x28027fe5	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x281cd328	nf_log_register
++EXPORT_SYMBOL vmlinux 0x282bbf09	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x28318305	snprintf
++EXPORT_SYMBOL vmlinux 0x2857611f	md_write_start
++EXPORT_SYMBOL vmlinux 0x285e9f27	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x287707ee	proc_symlink
++EXPORT_SYMBOL vmlinux 0x2892febb	block_write_full_page
++EXPORT_SYMBOL vmlinux 0x289c6647	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x289efd1e	of_device_is_available
++EXPORT_SYMBOL vmlinux 0x28a2b29f	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28a8d2e2	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x28abfe6e	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x28bd7e1f	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0x28bdce0d	nvm_register
++EXPORT_SYMBOL vmlinux 0x28d7ffea	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0x28f0fb34	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x28fa0441	of_match_node
++EXPORT_SYMBOL vmlinux 0x28fa1448	seq_release_private
++EXPORT_SYMBOL vmlinux 0x29007343	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x290562fa	dm_get_device
++EXPORT_SYMBOL vmlinux 0x290e67d6	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x2911c291	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x291ba05d	udplite_table
++EXPORT_SYMBOL vmlinux 0x29301bc0	free_task
++EXPORT_SYMBOL vmlinux 0x293d6e1b	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0x2944be03	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x2957ad54	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x29686676	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0x297866d1	iunique
++EXPORT_SYMBOL vmlinux 0x297898b5	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x29b2279e	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x29c4f403	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x2a0e2649	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0x2a2bab87	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a3fc9cb	netdev_alert
++EXPORT_SYMBOL vmlinux 0x2a802d91	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0x2a88a3b8	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x2a9aaa6e	deactivate_super
++EXPORT_SYMBOL vmlinux 0x2aa1ad41	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x2aa1e98c	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0x2aa2bcb6	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2afaa1fc	ns_capable
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b1053d9	elevator_exit
++EXPORT_SYMBOL vmlinux 0x2b2174c6	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b3e1994	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0x2b9737a9	d_path
++EXPORT_SYMBOL vmlinux 0x2b988723	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0x2b9a217f	default_llseek
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2ba8288e	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x2bb55d6e	acpi_remove_notify_handler
++EXPORT_SYMBOL vmlinux 0x2bbc954a	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0x2bd143b6	vme_register_driver
++EXPORT_SYMBOL vmlinux 0x2bfbab10	__memmove
++EXPORT_SYMBOL vmlinux 0x2bfeb410	acpi_get_handle
++EXPORT_SYMBOL vmlinux 0x2c013c1a	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0x2c0ebcb9	__inode_permission
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c334b08	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x2c3d2c09	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x2c4ccd00	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0x2c75332c	get_disk
++EXPORT_SYMBOL vmlinux 0x2c784d16	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0x2c7bc4aa	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0x2c84f8f2	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0x2c8d427e	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0x2c96ce78	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0x2cac5530	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0x2cb9b73a	seq_putc
++EXPORT_SYMBOL vmlinux 0x2cbab359	scsi_unregister
++EXPORT_SYMBOL vmlinux 0x2cce48b3	elevator_init
++EXPORT_SYMBOL vmlinux 0x2cf73cb7	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x2cf8d489	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x2cfdff87	seq_write
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d358888	blk_make_request
++EXPORT_SYMBOL vmlinux 0x2d4008be	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x2d45e2b2	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0x2d5e1c76	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x2d658a12	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0x2d699e6b	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x2d71a8ce	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0x2d76f925	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x2d872e7b	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x2d991d22	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0x2da7a895	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x2db1e0c6	dql_init
++EXPORT_SYMBOL vmlinux 0x2dc7d02c	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0x2dd0ea0a	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0x2dd9a36b	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x2ddd0658	do_splice_direct
++EXPORT_SYMBOL vmlinux 0x2de1327b	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0x2de8e491	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x2dedc4c2	acpi_format_exception
++EXPORT_SYMBOL vmlinux 0x2dee212d	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x2df720a0	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0x2e0d2f7f	queue_work_on
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e25b0e2	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x2e25de76	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0x2e2a966e	padata_start
++EXPORT_SYMBOL vmlinux 0x2e2b40d2	strncat
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e4a8138	sk_wait_data
++EXPORT_SYMBOL vmlinux 0x2e593a27	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0x2e6628eb	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0x2e7922f0	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0x2e7be112	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x2e7de757	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x2e86025b	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x2ea4c1c9	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0x2eb2e051	dm_io
++EXPORT_SYMBOL vmlinux 0x2ec8d798	build_skb
++EXPORT_SYMBOL vmlinux 0x2ecbce17	of_count_phandle_with_args
++EXPORT_SYMBOL vmlinux 0x2ed22486	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0x2ed64963	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x2eeb06e9	input_inject_event
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2ef985dc	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x2f031697	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f10bffc	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x2f384db3	acpi_is_video_device
++EXPORT_SYMBOL vmlinux 0x2f3857e2	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x2f461948	netif_rx
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2f4adc41	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0x2f69bd0e	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0x2f7c5100	vfs_writev
++EXPORT_SYMBOL vmlinux 0x2f9cf162	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x2fa47374	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0x2fb26a40	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fba07c9	scsi_print_result
++EXPORT_SYMBOL vmlinux 0x2fbb815d	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0x2fbc53b9	cdev_init
++EXPORT_SYMBOL vmlinux 0x2fbd4046	phy_stop
++EXPORT_SYMBOL vmlinux 0x2fc7db24	netdev_err
++EXPORT_SYMBOL vmlinux 0x2fdc8b1b	sk_free
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2ff063b5	acpi_get_name
++EXPORT_SYMBOL vmlinux 0x300461bb	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0x301a9788	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x301add7d	udp_prot
++EXPORT_SYMBOL vmlinux 0x3022e627	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x302b0557	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x30400a1c	kobject_del
++EXPORT_SYMBOL vmlinux 0x304cb22f	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0x304ec72b	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x305cec12	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x307cf82e	pci_dev_get
++EXPORT_SYMBOL vmlinux 0x309270b7	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x30a18299	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30ac9cf7	napi_complete_done
++EXPORT_SYMBOL vmlinux 0x30b1a97a	proc_set_size
++EXPORT_SYMBOL vmlinux 0x30c91128	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0x30e2bf7f	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310f02ec	memremap
++EXPORT_SYMBOL vmlinux 0x310fb90c	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0x312930ec	inet_accept
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x3148b49a	security_path_chown
++EXPORT_SYMBOL vmlinux 0x315d04bf	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x315d66f0	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x31711ec6	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x3192d28a	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0x319d2aad	netlink_unicast
++EXPORT_SYMBOL vmlinux 0x31a4767f	qcom_scm_hdcp_available
++EXPORT_SYMBOL vmlinux 0x31a6e091	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x31b3ab9c	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0x31c13372	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x31c7b37a	empty_aops
++EXPORT_SYMBOL vmlinux 0x31cf8771	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0x31e1181a	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x31ecd408	param_set_ulong
++EXPORT_SYMBOL vmlinux 0x31f4261b	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0x32002aeb	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0x3209cc37	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0x320fdc35	commit_creds
++EXPORT_SYMBOL vmlinux 0x3211724f	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0x3236c3f4	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0x324b3877	up
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x3258b116	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0x3258e7d6	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0x32d43cc7	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0x32ddc69b	nd_sb_checksum
++EXPORT_SYMBOL vmlinux 0x32e6f1a0	acpi_video_backlight_string
++EXPORT_SYMBOL vmlinux 0x33332aa5	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x333cb37c	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x3344e7df	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x33465b74	softnet_data
++EXPORT_SYMBOL vmlinux 0x3350d369	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x336eb716	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x33778321	bio_add_page
++EXPORT_SYMBOL vmlinux 0x33ac5616	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x33f52656	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0x33fcf44a	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0x34025654	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0x341bdb4f	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0x3420fbe8	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0x34477055	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x3459c30e	dump_skip
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34bebaa9	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0x34c16168	of_parse_phandle_with_fixed_args
++EXPORT_SYMBOL vmlinux 0x34c1b9a8	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x34c60d31	skb_find_text
++EXPORT_SYMBOL vmlinux 0x34cb61b2	loop_backing_file
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x352014ee	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0x3539f11b	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x353e21e3	acpi_bios_warning
++EXPORT_SYMBOL vmlinux 0x3540a469	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0x3541b26e	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x35423d51	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x35975647	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0x35a69dc2	of_get_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35aa6fbe	__getblk_slow
++EXPORT_SYMBOL vmlinux 0x35f6f906	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x35f917c6	pid_task
++EXPORT_SYMBOL vmlinux 0x36008157	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x360b1afe	probe_irq_mask
++EXPORT_SYMBOL vmlinux 0x360f8f8a	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0x360ff19f	down
++EXPORT_SYMBOL vmlinux 0x3629f77a	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x362c2cda	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0x3637e777	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0x365c3e95	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x366cc73c	unlock_rename
++EXPORT_SYMBOL vmlinux 0x369e1115	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x36a3b9ef	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36d005e8	mmc_of_parse_voltage
++EXPORT_SYMBOL vmlinux 0x36f272a1	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0x370f9850	efi
++EXPORT_SYMBOL vmlinux 0x371549e4	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x376783d1	ps2_init
++EXPORT_SYMBOL vmlinux 0x376c60d8	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0x376d3bd5	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x378b623b	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0x37acaee7	generic_setlease
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37b1b1ae	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37db8f19	dmi_get_date
++EXPORT_SYMBOL vmlinux 0x37ec9e28	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0x37efe3f3	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0x37fb5941	dump_truncate
++EXPORT_SYMBOL vmlinux 0x3806d8bf	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0x380ee87a	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x381cce9c	console_stop
++EXPORT_SYMBOL vmlinux 0x3821b354	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0x3832e2e2	ata_port_printk
++EXPORT_SYMBOL vmlinux 0x38538a67	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x385600a2	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x3860621b	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0x386fda4e	param_set_int
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x38892944	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x3889fe45	proc_create_data
++EXPORT_SYMBOL vmlinux 0x388f6574	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0x38986e93	of_platform_device_create
++EXPORT_SYMBOL vmlinux 0x38a331ad	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0x38a6b158	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x390447a8	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x391ff865	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x393a5ead	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0x393d4de9	crc32_le
++EXPORT_SYMBOL vmlinux 0x3940f028	inet_put_port
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x3955fcf6	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x39683712	is_bad_inode
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x399ad043	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39c9e9b6	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0x39d95e45	sget
++EXPORT_SYMBOL vmlinux 0x39de2aa9	is_nd_btt
++EXPORT_SYMBOL vmlinux 0x39e943d6	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0x39eb2ee1	misc_register
++EXPORT_SYMBOL vmlinux 0x3a11ee2f	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x3a16030d	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0x3a2ac330	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x3a2fe795	of_parse_phandle_with_args
++EXPORT_SYMBOL vmlinux 0x3a31a3ab	nd_namespace_blk_validate
++EXPORT_SYMBOL vmlinux 0x3a583a68	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0x3a612316	up_write
++EXPORT_SYMBOL vmlinux 0x3a6681e3	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0x3a6abd35	iget_failed
++EXPORT_SYMBOL vmlinux 0x3a6e66c5	ppp_input_error
++EXPORT_SYMBOL vmlinux 0x3a734858	of_get_ddr_timings
++EXPORT_SYMBOL vmlinux 0x3a8545df	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0x3a87d50f	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3ab41b25	__copy_in_user
++EXPORT_SYMBOL vmlinux 0x3af47da9	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0x3b0d2948	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0x3b26bd23	__dax_fault
++EXPORT_SYMBOL vmlinux 0x3b2a0f00	km_policy_expired
++EXPORT_SYMBOL vmlinux 0x3b300948	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x3b397fc3	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0x3b39b9ec	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b6d2d5b	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x3b7959e5	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0x3b7aa2f4	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0x3b90439f	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0x3b99aad3	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x3bd32936	current_fs_time
++EXPORT_SYMBOL vmlinux 0x3bf092c6	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0x3c090872	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0x3c15deb8	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x3c2781ae	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c483012	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x3c549b21	acpi_bus_unregister_driver
++EXPORT_SYMBOL vmlinux 0x3c79801b	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x3c7a852e	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3cdf5e60	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3ceb6f4a	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0x3cf1dae2	path_is_under
++EXPORT_SYMBOL vmlinux 0x3cf453c0	kobject_put
++EXPORT_SYMBOL vmlinux 0x3cf6ae7b	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0x3cfae893	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0x3cffe2d9	tty_mutex
++EXPORT_SYMBOL vmlinux 0x3d04c042	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0x3d05281f	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0x3d093081	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0x3d1d1976	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0x3d1e59c9	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0x3d1fa6f0	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0x3d216c52	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0x3d2fbad1	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0x3d43ea1a	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x3d5f7194	of_translate_dma_address
++EXPORT_SYMBOL vmlinux 0x3d95020f	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x3d9ee9f0	clear_page
++EXPORT_SYMBOL vmlinux 0x3da6f525	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x3db3e9db	nd_btt_probe
++EXPORT_SYMBOL vmlinux 0x3dbc52ef	get_super_thawed
++EXPORT_SYMBOL vmlinux 0x3dbf36c9	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0x3dc6e09a	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3dd5f9b7	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0x3deac448	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0x3df986cc	pmem_should_map_pages
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e1d3345	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x3e32f0ae	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x3e36b63c	skb_make_writable
++EXPORT_SYMBOL vmlinux 0x3e46421b	__scm_send
++EXPORT_SYMBOL vmlinux 0x3e57ea21	inet_listen
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x3ea8d00a	of_device_register
++EXPORT_SYMBOL vmlinux 0x3eed83c8	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0x3eef6b45	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0x3efb7e1d	nf_reinject
++EXPORT_SYMBOL vmlinux 0x3efea462	genl_notify
++EXPORT_SYMBOL vmlinux 0x3f126281	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0x3f39d96c	padata_stop
++EXPORT_SYMBOL vmlinux 0x3f41d2c6	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f88837d	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x3f94dc05	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x3fd13173	skb_split
++EXPORT_SYMBOL vmlinux 0x3fd395a1	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x3fe0b032	bio_chain
++EXPORT_SYMBOL vmlinux 0x3fe2195e	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x3fe2ccbe	memweight
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x3fec47e4	input_free_device
++EXPORT_SYMBOL vmlinux 0x40261a03	force_sig
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4039918a	clk_register_clkdev
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x405fad35	down_read_trylock
++EXPORT_SYMBOL vmlinux 0x406a7a2f	dev_emerg
++EXPORT_SYMBOL vmlinux 0x4088e609	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40b28355	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0x40bd07a6	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40c89d46	acpi_get_table_by_index
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40e6df69	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x4102c4ee	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x410f4bb7	__irq_regs
++EXPORT_SYMBOL vmlinux 0x411d026c	__nd_driver_register
++EXPORT_SYMBOL vmlinux 0x41233aa8	lock_rename
++EXPORT_SYMBOL vmlinux 0x414269ed	get_io_context
++EXPORT_SYMBOL vmlinux 0x41456be8	__get_page_tail
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x41506ca5	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0x41531b84	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x4171cb57	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x41a3fbf1	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x41a860d0	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0x41ac0931	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0x41b3c739	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x41baf194	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0x41d7bd4e	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0x41e828ca	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0x41ed30cd	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0x42026de8	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0x42116a0f	param_array_ops
++EXPORT_SYMBOL vmlinux 0x42122cbf	inode_init_once
++EXPORT_SYMBOL vmlinux 0x42123390	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x42350e8d	ucs2_strlen
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x426a8ac5	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x42780e8e	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x428434b4	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0x42889a89	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0x4289324d	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42ae5af0	dqstats
++EXPORT_SYMBOL vmlinux 0x42ef087e	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0x42fb8542	dma_mark_declared_memory_occupied
++EXPORT_SYMBOL vmlinux 0x42ff9892	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x43080a58	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0x431bb27e	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x4382ee13	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x439910e8	seq_read
++EXPORT_SYMBOL vmlinux 0x439efcc7	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x43c28f02	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x440db70d	nd_dev_to_uuid
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x441e135b	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x442612dd	compat_tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x442bca4e	bio_copy_data
++EXPORT_SYMBOL vmlinux 0x44362d99	get_cached_acl
++EXPORT_SYMBOL vmlinux 0x443a4f1d	phy_device_create
++EXPORT_SYMBOL vmlinux 0x443aea28	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0x4441b4ff	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0x4449d9b8	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0x44512f1a	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x44619120	find_lock_entry
++EXPORT_SYMBOL vmlinux 0x4462332b	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0x44680168	mii_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x447d3417	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x44832189	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x448447ce	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0x448eac3e	kmemdup
++EXPORT_SYMBOL vmlinux 0x4494692f	get_user_pages
++EXPORT_SYMBOL vmlinux 0x449ad0a7	memcmp
++EXPORT_SYMBOL vmlinux 0x44a81d5f	acpi_evaluate_object
++EXPORT_SYMBOL vmlinux 0x44b0a4e9	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44bb99d5	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x44c63710	dst_discard_out
++EXPORT_SYMBOL vmlinux 0x44da2b70	param_set_charp
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44f814aa	__find_get_block
++EXPORT_SYMBOL vmlinux 0x45081703	ec_get_handle
++EXPORT_SYMBOL vmlinux 0x4509119c	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0x4509f80e	acpi_device_hid
++EXPORT_SYMBOL vmlinux 0x45166994	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0x452af0be	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0x452c8389	mount_bdev
++EXPORT_SYMBOL vmlinux 0x4533fbb3	of_n_size_cells
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x453e081a	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x45520ec7	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x45832567	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x459478b7	input_event
++EXPORT_SYMBOL vmlinux 0x4595a46d	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0x45a55ec8	__iounmap
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45df0dd6	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0x45f1a098	of_device_alloc
++EXPORT_SYMBOL vmlinux 0x45fd9191	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x46195cec	param_set_bool
++EXPORT_SYMBOL vmlinux 0x461ac773	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x461dded5	simple_getattr
++EXPORT_SYMBOL vmlinux 0x462c660f	proc_dointvec
++EXPORT_SYMBOL vmlinux 0x46359720	phy_device_remove
++EXPORT_SYMBOL vmlinux 0x4646a1a1	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0x46473021	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0x4651a2c1	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x465e32df	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x466af742	kill_bdev
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x467df16d	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0x4695bdfb	single_release
++EXPORT_SYMBOL vmlinux 0x469bb0a0	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x469f4e11	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0x46c26f34	devm_request_resource
++EXPORT_SYMBOL vmlinux 0x46c47fb6	__node_distance
++EXPORT_SYMBOL vmlinux 0x46cfc302	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x46eb81e7	filemap_flush
++EXPORT_SYMBOL vmlinux 0x46fa72d3	__put_cred
++EXPORT_SYMBOL vmlinux 0x46fbd812	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x46ff37dc	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0x470b530a	con_is_bound
++EXPORT_SYMBOL vmlinux 0x470f490a	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0x4722ea66	datagram_poll
++EXPORT_SYMBOL vmlinux 0x4728aa77	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0x4728fe50	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x4743b306	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x4751e46e	md_register_thread
++EXPORT_SYMBOL vmlinux 0x475f010b	acpi_purge_cached_objects
++EXPORT_SYMBOL vmlinux 0x477beb34	devm_memunmap
++EXPORT_SYMBOL vmlinux 0x478df3d4	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x47a86a69	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0x47a87ada	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x47deef86	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x47f05be9	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0x47f2df4e	vfs_create
++EXPORT_SYMBOL vmlinux 0x47fc6aea	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0x48193639	acpi_lid_open
++EXPORT_SYMBOL vmlinux 0x481cb9ab	acpi_enter_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x48208c4c	pnp_device_attach
++EXPORT_SYMBOL vmlinux 0x4829a47e	memcpy
++EXPORT_SYMBOL vmlinux 0x483524ba	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0x4839dca3	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0x4841bdee	strnchr
++EXPORT_SYMBOL vmlinux 0x48511666	keyring_search
++EXPORT_SYMBOL vmlinux 0x4851dd14	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x485ea905	iterate_mounts
++EXPORT_SYMBOL vmlinux 0x48718af4	done_path_create
++EXPORT_SYMBOL vmlinux 0x488a240e	inet6_getname
++EXPORT_SYMBOL vmlinux 0x48a35942	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x48ac8df4	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48be0672	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x48d1aa01	up_read
++EXPORT_SYMBOL vmlinux 0x48e47cfd	of_get_next_child
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x490ce836	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0x493d9b01	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x49419641	mmc_add_host
++EXPORT_SYMBOL vmlinux 0x494c48e8	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0x494ecfbb	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0x4955aea5	d_make_root
++EXPORT_SYMBOL vmlinux 0x4956828e	phy_attach
++EXPORT_SYMBOL vmlinux 0x4956e60f	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x49689bf8	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0x497743c6	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0x497a1d8e	elv_add_request
++EXPORT_SYMBOL vmlinux 0x497e2681	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0x49829e9b	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0x49930938	idr_replace
++EXPORT_SYMBOL vmlinux 0x49931643	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0x49a2fa04	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b163b8	acpi_bus_scan
++EXPORT_SYMBOL vmlinux 0x49bab933	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0x49cec1e3	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x4a1a72bf	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x4a2205b9	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0x4a3bd063	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0x4a745019	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x4a85e9f6	mii_check_media
++EXPORT_SYMBOL vmlinux 0x4a8929c1	down_write
++EXPORT_SYMBOL vmlinux 0x4a8961f5	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x4aa8c794	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4ac342dd	serio_rescan
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4ae73f80	scmd_printk
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b22b35f	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0x4b2c73e8	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0x4b42e2f9	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b7de1c3	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0x4b7e4e32	ps2_end_command
++EXPORT_SYMBOL vmlinux 0x4b7f75a6	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0x4b9a6f1d	input_grab_device
++EXPORT_SYMBOL vmlinux 0x4b9bf432	block_write_end
++EXPORT_SYMBOL vmlinux 0x4ba2560b	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0x4baf1712	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4bf89340	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0x4c07a7e0	acpi_processor_unregister_performance
++EXPORT_SYMBOL vmlinux 0x4c14cd30	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x4c25b0ea	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x4c2c88d1	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c58b752	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0x4c5a76c1	dquot_operations
++EXPORT_SYMBOL vmlinux 0x4c6f9ef3	test_and_change_bit
++EXPORT_SYMBOL vmlinux 0x4c74ae09	module_refcount
++EXPORT_SYMBOL vmlinux 0x4ca9669f	scnprintf
++EXPORT_SYMBOL vmlinux 0x4cada7bd	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x4cc13251	neigh_for_each
++EXPORT_SYMBOL vmlinux 0x4cd07790	register_shrinker
++EXPORT_SYMBOL vmlinux 0x4cd584c2	tcp_poll
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4ce736c9	__register_nls
++EXPORT_SYMBOL vmlinux 0x4ce8fd5f	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0x4cf9f379	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x4cfb51a2	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x4cfba808	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0x4d084f86	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0x4d0d163d	copy_page
++EXPORT_SYMBOL vmlinux 0x4d22a93b	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0x4d27da75	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0x4d5130a2	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0x4d5a0ded	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0x4d748daf	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0x4d76a188	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x4d894e11	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x4d8b3b8e	free_user_ns
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9af71e	simple_rmdir
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4da84d59	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0x4db9835d	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0x4dc491f5	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4e03ceb1	uart_match_port
++EXPORT_SYMBOL vmlinux 0x4e096b59	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0x4e0be919	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0x4e1bba15	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0x4e229d83	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x4e237ea7	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x4e2a32c6	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0x4e2b0225	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e38a78f	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0x4e4335de	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0x4e44a84c	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x4e5717f8	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x4e6781d3	inet_getname
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6aba8e	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e72bd32	acpi_bus_register_driver
++EXPORT_SYMBOL vmlinux 0x4e9dffb5	ip_fast_csum
++EXPORT_SYMBOL vmlinux 0x4ea0b708	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0x4ea2569d	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x4ea4cea3	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x4ea84b02	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0x4efad5b5	bdi_init
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f1d199d	phy_resume
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f25784b	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f441a02	inet_release
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f6c2072	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0x4f74f963	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0x4f783f30	acpi_read
++EXPORT_SYMBOL vmlinux 0x4f7a4827	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0x4f8a4481	elv_rb_del
++EXPORT_SYMBOL vmlinux 0x4f8a5132	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x4f9c36e0	of_device_unregister
++EXPORT_SYMBOL vmlinux 0x4fbac036	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0x4fbf8cb0	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x4fc94042	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0x4fcdc4ff	dquot_release
++EXPORT_SYMBOL vmlinux 0x4fd9b9af	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x4feaf654	PDE_DATA
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x50271f50	page_put_link
++EXPORT_SYMBOL vmlinux 0x50542d11	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x5060f6f9	dquot_initialize
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x5085646b	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0x5085bcb6	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0x5094e57d	__ps2_command
++EXPORT_SYMBOL vmlinux 0x509b64ea	acpi_has_method
++EXPORT_SYMBOL vmlinux 0x50a90e8d	bsearch
++EXPORT_SYMBOL vmlinux 0x50b2372a	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0x50ba769a	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x50c55c03	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0x50d4cdbd	override_creds
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x51110975	pnp_release_card_device
++EXPORT_SYMBOL vmlinux 0x51164ad9	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x51174a17	inet6_offloads
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x5129ea20	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x51416774	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0x51563e5d	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x515e2975	pci_bus_get
++EXPORT_SYMBOL vmlinux 0x51749fc8	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x517690a2	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0x51930ec4	file_update_time
++EXPORT_SYMBOL vmlinux 0x51ac1bbd	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0x51c1fcbe	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0x51d12d4e	acpi_pci_disabled
++EXPORT_SYMBOL vmlinux 0x51e6dd07	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x51e77c97	pfn_valid
++EXPORT_SYMBOL vmlinux 0x52013df2	fd_install
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x52049ebb	nvdimm_bus_lock
++EXPORT_SYMBOL vmlinux 0x52095e19	acpi_get_data
++EXPORT_SYMBOL vmlinux 0x52130046	acpi_check_address_range
++EXPORT_SYMBOL vmlinux 0x5216e0b0	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x52260211	blk_start_queue
++EXPORT_SYMBOL vmlinux 0x522aed34	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0x5239ce3b	___ratelimit
++EXPORT_SYMBOL vmlinux 0x524cefe5	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0x525248c0	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x525e026f	acpi_os_unmap_generic_address
++EXPORT_SYMBOL vmlinux 0x52762c0f	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x5280bd13	redraw_screen
++EXPORT_SYMBOL vmlinux 0x52840a4e	of_find_device_by_node
++EXPORT_SYMBOL vmlinux 0x5288ec17	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0x528d92b9	fsync_bdev
++EXPORT_SYMBOL vmlinux 0x52983a4f	vme_master_write
++EXPORT_SYMBOL vmlinux 0x52ba628a	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0x52cb4ae2	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0x52d45422	input_set_capability
++EXPORT_SYMBOL vmlinux 0x52e3b397	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0x52f46c09	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x530f0197	amba_request_regions
++EXPORT_SYMBOL vmlinux 0x53162b21	netdev_change_features
++EXPORT_SYMBOL vmlinux 0x531c828d	led_set_brightness
++EXPORT_SYMBOL vmlinux 0x531ff1d7	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x5337df25	vfs_rename
++EXPORT_SYMBOL vmlinux 0x534d21c8	vfs_read
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x536cc847	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x5377e556	hex2bin
++EXPORT_SYMBOL vmlinux 0x538660cf	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x53981748	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0x539af73c	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x53b7075b	mii_ethtool_sset
++EXPORT_SYMBOL vmlinux 0x53d03ed1	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x53d7f3cb	pnp_stop_dev
++EXPORT_SYMBOL vmlinux 0x53f6e7a9	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x53ff2003	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x54216812	inode_init_always
++EXPORT_SYMBOL vmlinux 0x54245b39	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0x543570e6	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0x54399c83	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x544b0c11	acpi_lid_notifier_register
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54b3b792	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0x54c192ed	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54cf4898	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x54d4bded	ida_init
++EXPORT_SYMBOL vmlinux 0x54dbce24	phy_connect
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54fef89d	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x550a1f79	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0x55107d0f	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0x5511ff6a	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x553c61eb	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x5544c84a	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x555b70b5	of_node_to_nid
++EXPORT_SYMBOL vmlinux 0x555dabc9	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0x556112ae	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x55772753	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0x558407eb	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0x5584e535	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x55bf2942	input_open_device
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x55efee64	compat_ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x55f5019b	__kmalloc_node
++EXPORT_SYMBOL vmlinux 0x560df0a5	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x56176859	dev_close
++EXPORT_SYMBOL vmlinux 0x561b25ea	pnp_possible_config
++EXPORT_SYMBOL vmlinux 0x562f0f22	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0x56342ce1	down_timeout
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x564f4f0d	phy_find_first
++EXPORT_SYMBOL vmlinux 0x566e480e	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0x56745399	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x5674cbc2	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x569b81c9	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x569be04c	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x56a7b98e	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56daa6ad	bioset_create
++EXPORT_SYMBOL vmlinux 0x56e5a059	mmc_start_req
++EXPORT_SYMBOL vmlinux 0x56ea2028	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x56eda255	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0x572d0104	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x573e5b3b	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x573ee331	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0x5747878a	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x57681532	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x57729976	path_get
++EXPORT_SYMBOL vmlinux 0x577d35f3	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x5788ff48	vme_bus_type
++EXPORT_SYMBOL vmlinux 0x5792f848	strlcpy
++EXPORT_SYMBOL vmlinux 0x579f164a	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0x57a8792d	walk_stackframe
++EXPORT_SYMBOL vmlinux 0x57b1c8ea	proc_remove
++EXPORT_SYMBOL vmlinux 0x57cb01af	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x57d608f1	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x57dd3a38	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x581bb64d	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x58604e4d	alloc_iova_mem
++EXPORT_SYMBOL vmlinux 0x586c6b3e	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x58ac2127	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0x58ac360a	key_revoke
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58c543dc	generic_readlink
++EXPORT_SYMBOL vmlinux 0x58de1239	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0x58dfa857	fasync_helper
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x58f4994a	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0x5903fe1c	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0x5913897b	ip_defrag
++EXPORT_SYMBOL vmlinux 0x5914d567	mii_check_gmii_support
++EXPORT_SYMBOL vmlinux 0x59200079	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0x59237842	path_nosuid
++EXPORT_SYMBOL vmlinux 0x5974b86b	kernel_bind
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x59979ea6	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59d5a64a	finish_open
++EXPORT_SYMBOL vmlinux 0x59ec892a	inet_frags_init
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a0f917a	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0x5a921311	strncmp
++EXPORT_SYMBOL vmlinux 0x5a9b90b0	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0x5a9c9cf3	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x5a9f1d63	memmove
++EXPORT_SYMBOL vmlinux 0x5a9fcc92	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x5aade2f5	of_graph_parse_endpoint
++EXPORT_SYMBOL vmlinux 0x5ab22c10	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0x5ab506f5	da903x_query_status
++EXPORT_SYMBOL vmlinux 0x5ae041fd	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x5af66df5	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x5af7e43c	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5b253638	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0x5b41e85d	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x5b4b0078	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0x5b56860c	vm_munmap
++EXPORT_SYMBOL vmlinux 0x5b64c348	input_close_device
++EXPORT_SYMBOL vmlinux 0x5b86697f	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0x5b9c808a	acpi_get_possible_resources
++EXPORT_SYMBOL vmlinux 0x5baafac2	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x5bbff954	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x5bc10524	printk_emit
++EXPORT_SYMBOL vmlinux 0x5bc1ec96	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0x5bc2052f	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0x5bdfafce	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0x5bf7098d	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0x5c0442fd	acpi_gbl_FADT
++EXPORT_SYMBOL vmlinux 0x5c4b4f41	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0x5c5d75d2	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0x5c7c8cc1	d_drop
++EXPORT_SYMBOL vmlinux 0x5cb9864e	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0x5cc89365	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0x5cc8c7c7	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0x5cd885d5	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5d0d4922	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0x5d112304	__memcpy_fromio
++EXPORT_SYMBOL vmlinux 0x5d160b38	sync_blockdev
++EXPORT_SYMBOL vmlinux 0x5d2422ff	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0x5d29cf3d	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x5d3670e3	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0x5d36a048	arp_xmit
++EXPORT_SYMBOL vmlinux 0x5d4e250d	notify_change
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d703ee7	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0x5d74dbcf	pnp_range_reserved
++EXPORT_SYMBOL vmlinux 0x5db1511b	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0x5dbce5ba	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0x5dbf732d	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x5dfa5b6d	bdget_disk
++EXPORT_SYMBOL vmlinux 0x5dfe4cec	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x5e1a5e22	inet6_protos
++EXPORT_SYMBOL vmlinux 0x5e21f8e2	uart_resume_port
++EXPORT_SYMBOL vmlinux 0x5e3268bd	vga_client_register
++EXPORT_SYMBOL vmlinux 0x5e34ba63	ppp_input
++EXPORT_SYMBOL vmlinux 0x5e4b722c	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x5e5da5ee	dummy_dma_ops
++EXPORT_SYMBOL vmlinux 0x5e61489a	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x5e64f6bb	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x5e72ab85	phy_init_hw
++EXPORT_SYMBOL vmlinux 0x5e88f791	blk_get_request
++EXPORT_SYMBOL vmlinux 0x5e8fefbc	param_set_ushort
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5ea79efe	fence_default_wait
++EXPORT_SYMBOL vmlinux 0x5eaba6db	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ece766f	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5ee4d6fd	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0x5ef0803c	bd_set_size
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f00d2bc	sock_from_file
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f0c3d5c	nvm_end_io
++EXPORT_SYMBOL vmlinux 0x5f17154a	__check_sticky
++EXPORT_SYMBOL vmlinux 0x5f1d1a37	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0x5f2628f3	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x5f80d5ab	ps2_drain
++EXPORT_SYMBOL vmlinux 0x5f9ecfc2	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0x5fd9b233	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x5fe7184f	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x602cb0a7	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0x602ed00d	acpi_current_gpe_count
++EXPORT_SYMBOL vmlinux 0x6032995e	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x6058a0c8	release_sock
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x6095ee8a	find_get_entry
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x609f5b35	ucs2_strnlen
++EXPORT_SYMBOL vmlinux 0x60a4ba8c	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x60e07a70	vfs_statfs
++EXPORT_SYMBOL vmlinux 0x60e85b2d	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0x610ef0c3	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0x6112781e	pci_select_bars
++EXPORT_SYMBOL vmlinux 0x61194f46	kobject_get
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x6149e19b	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x614bb773	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x61520529	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0x61640afd	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0x6165baf6	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x617a71fb	vmap
++EXPORT_SYMBOL vmlinux 0x6181fded	pci_match_id
++EXPORT_SYMBOL vmlinux 0x618911fc	numa_node
++EXPORT_SYMBOL vmlinux 0x619547bb	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0x6196456d	tcf_register_action
++EXPORT_SYMBOL vmlinux 0x619cb7dd	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61e149d2	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x61ef6170	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0x61f7721f	kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x6214f07a	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6228042b	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x622ada9e	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0x62435756	serio_close
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62748e70	acpi_set_current_resources
++EXPORT_SYMBOL vmlinux 0x6276bace	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0x627f188c	tty_port_open
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x62cd13a6	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0x62d77950	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0x62e09753	skb_insert
++EXPORT_SYMBOL vmlinux 0x62ea9088	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0x62fd243e	of_find_property
++EXPORT_SYMBOL vmlinux 0x6312f8d8	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0x63172507	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x632e3b14	dev_add_offload
++EXPORT_SYMBOL vmlinux 0x63364ab8	of_node_put
++EXPORT_SYMBOL vmlinux 0x6383f762	block_commit_write
++EXPORT_SYMBOL vmlinux 0x63a01291	acpi_leave_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63b867c4	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0x63bf7da5	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63d00bf2	param_get_int
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63f50663	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0x63f65e61	__inet_hash
++EXPORT_SYMBOL vmlinux 0x63fa80b9	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x640de7d0	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x642c9fc1	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0x6431a819	tty_port_init
++EXPORT_SYMBOL vmlinux 0x6449fd41	acpi_install_address_space_handler
++EXPORT_SYMBOL vmlinux 0x64511336	copy_to_iter
++EXPORT_SYMBOL vmlinux 0x645f4a2a	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0x6460cc85	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0x64676dbe	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0x6474618b	tty_unlock
++EXPORT_SYMBOL vmlinux 0x648bb6ab	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64a9e33b	netdev_state_change
++EXPORT_SYMBOL vmlinux 0x64bbc288	string_unescape
++EXPORT_SYMBOL vmlinux 0x64d3f879	cdrom_open
++EXPORT_SYMBOL vmlinux 0x64de42f0	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0x64f38642	setattr_copy
++EXPORT_SYMBOL vmlinux 0x64fa7693	__acpi_handle_debug
++EXPORT_SYMBOL vmlinux 0x650bb597	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x6515a372	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x651910bb	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x652ce9aa	nla_memcmp
++EXPORT_SYMBOL vmlinux 0x652e25e1	md_check_recovery
++EXPORT_SYMBOL vmlinux 0x65345022	__wake_up
++EXPORT_SYMBOL vmlinux 0x653892fe	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x653dc254	key_put
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x654bd764	of_root
++EXPORT_SYMBOL vmlinux 0x655f93eb	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x656c1a0e	string_escape_mem
++EXPORT_SYMBOL vmlinux 0x65817527	d_add_ci
++EXPORT_SYMBOL vmlinux 0x65a07ba7	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0x65aaf889	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0x65c76f05	scsi_execute
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65e0d6d7	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x65f1416c	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x660d2f26	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x663f7cd0	acpi_install_table_handler
++EXPORT_SYMBOL vmlinux 0x6650aaa9	md_write_end
++EXPORT_SYMBOL vmlinux 0x66532bb1	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x66591465	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x66a34909	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0x66f0349a	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x671eb0ee	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0x67276286	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x67309181	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x67454958	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x675229a3	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x6782fcd0	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x679713c9	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0x679d6c5c	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0x67aa41d2	d_find_alias
++EXPORT_SYMBOL vmlinux 0x67b00636	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0x67b0fcda	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b334ca	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67fe7903	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x680adbda	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x680beebe	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0x681d8ddc	processors
++EXPORT_SYMBOL vmlinux 0x6824988f	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x6828d0a9	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x6834e43c	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0x6835bbdf	have_submounts
++EXPORT_SYMBOL vmlinux 0x6859ee9b	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0x687b2391	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x68812c15	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0x68830423	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0x68947ad8	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0x68948063	tty_kref_put
++EXPORT_SYMBOL vmlinux 0x689b12c3	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68d524aa	mount_single
++EXPORT_SYMBOL vmlinux 0x68f278ef	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0x691001b5	acpi_evaluate_integer
++EXPORT_SYMBOL vmlinux 0x69150785	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0x691a2e5a	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x691ada92	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0x69287857	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0x693b99b7	pnp_is_active
++EXPORT_SYMBOL vmlinux 0x693bcce5	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0x6954df55	bio_split
++EXPORT_SYMBOL vmlinux 0x69564440	set_nlink
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x69867882	gen_pool_create
++EXPORT_SYMBOL vmlinux 0x69954beb	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69ae44fc	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0x69e764d9	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0x69f69ef0	pci_find_bus
++EXPORT_SYMBOL vmlinux 0x69fbc0a2	acpi_get_event_resources
++EXPORT_SYMBOL vmlinux 0x69fe0bfe	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a403f91	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0x6a57e0bf	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a5fa363	sigprocmask
++EXPORT_SYMBOL vmlinux 0x6a60277d	acpi_buffer_to_resource
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a9de420	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6ad2066a	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0x6adbc067	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0x6add5c9a	dmi_find_device
++EXPORT_SYMBOL vmlinux 0x6aea21e1	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6af44c9c	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x6af76595	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b640864	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6b696a04	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0x6b73ab21	kset_register
++EXPORT_SYMBOL vmlinux 0x6b7e3eef	page_symlink
++EXPORT_SYMBOL vmlinux 0x6b8a3b0d	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0x6b8eb6c4	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bd6a506	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6be3b3bf	end_page_writeback
++EXPORT_SYMBOL vmlinux 0x6be66ede	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x6be70afe	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0x6bf98745	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c2cdc47	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0x6c367c20	irq_set_chip
++EXPORT_SYMBOL vmlinux 0x6c392546	sock_init_data
++EXPORT_SYMBOL vmlinux 0x6c3c3310	nd_region_release_lane
++EXPORT_SYMBOL vmlinux 0x6c465f18	km_state_expired
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c5535b6	d_rehash
++EXPORT_SYMBOL vmlinux 0x6c5d99c7	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c64ac55	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c70a3b7	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x6c77212e	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x6c7c352d	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x6cbf8f47	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x6cd0d7d0	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0x6cdba154	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0x6ced5f5c	nonseekable_open
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d2eabf3	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d58ca15	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0x6d73018b	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0x6d7c8688	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0x6d8e805b	simple_link
++EXPORT_SYMBOL vmlinux 0x6db1b80c	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0x6dbf3507	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x6dd8fba2	audit_log_start
++EXPORT_SYMBOL vmlinux 0x6ddefdcb	phy_driver_register
++EXPORT_SYMBOL vmlinux 0x6dec332b	generic_setxattr
++EXPORT_SYMBOL vmlinux 0x6ded9efa	gnttab_alloc_pages
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6df410eb	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0x6e0a129a	padata_free
++EXPORT_SYMBOL vmlinux 0x6e0d55fb	try_module_get
++EXPORT_SYMBOL vmlinux 0x6e11d676	d_walk
++EXPORT_SYMBOL vmlinux 0x6e254bf7	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x6e265637	tty_name
++EXPORT_SYMBOL vmlinux 0x6e2868f8	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e7b9f42	prepare_creds
++EXPORT_SYMBOL vmlinux 0x6e7f0fd2	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x6e805810	fence_init
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6ea76843	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x6eb01263	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x6ecf85a9	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0x6ecf929f	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x6efabdac	phy_disconnect
++EXPORT_SYMBOL vmlinux 0x6efd1518	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f26cb7b	idr_get_next
++EXPORT_SYMBOL vmlinux 0x6f2b2dbd	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x6f3f1952	request_key_async
++EXPORT_SYMBOL vmlinux 0x6f428079	of_mdio_find_bus
++EXPORT_SYMBOL vmlinux 0x6f4d81ed	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0x6f5679f4	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0x6f5e6ec0	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0x6f5ec7ec	idr_init
++EXPORT_SYMBOL vmlinux 0x6f6736f4	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0x6f6e24f6	dup_iter
++EXPORT_SYMBOL vmlinux 0x6f86b600	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6f8e09db	sock_create
++EXPORT_SYMBOL vmlinux 0x6f98a140	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0x6fa9f8e8	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0x6fbc50c0	iterate_fd
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6feb2039	acpi_write
++EXPORT_SYMBOL vmlinux 0x6ff89ab8	security_mmap_file
++EXPORT_SYMBOL vmlinux 0x700283c5	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x70160088	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0x7023bea8	unregister_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x7029de98	__page_symlink
++EXPORT_SYMBOL vmlinux 0x703a203b	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x7047c251	to_nd_btt
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7067f839	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x70b0bb78	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0x70c51726	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x71123e3d	phy_print_status
++EXPORT_SYMBOL vmlinux 0x7115fc1a	__devm_release_region
++EXPORT_SYMBOL vmlinux 0x71274271	param_set_uint
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x7162069a	param_get_ushort
++EXPORT_SYMBOL vmlinux 0x716f4477	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x7178ae96	to_ndd
++EXPORT_SYMBOL vmlinux 0x717ecdae	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71a7a989	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0x71b211b6	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0x7226968d	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x722f2cde	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0x723cdbdc	single_open
++EXPORT_SYMBOL vmlinux 0x72402364	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0x7265ac65	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0x7283b8d3	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x728a3ad4	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x728f194b	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0x72a4f317	netif_device_detach
++EXPORT_SYMBOL vmlinux 0x72c7c81e	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0x72d545a9	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x72edf28e	register_netdevice
++EXPORT_SYMBOL vmlinux 0x72fa4aac	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0x72fd470d	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0x73156ea2	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x731dba7a	xen_domain_type
++EXPORT_SYMBOL vmlinux 0x732f5d8c	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x7335791a	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0x73359498	do_splice_to
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x735f6acd	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0x7376a8e9	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0x7378a327	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0x739a604e	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x73a04d8a	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x73c900ec	md_reload_sb
++EXPORT_SYMBOL vmlinux 0x73cafb34	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x73ea4733	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x73eb2e45	is_nvdimm_bus_locked
++EXPORT_SYMBOL vmlinux 0x73f01ac6	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x7411a885	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x741608c3	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0x742b6d83	path_noexec
++EXPORT_SYMBOL vmlinux 0x74480fe0	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x747422b1	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x74a472c5	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x74b23289	param_set_invbool
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74cdf9b6	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x74d42d75	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74eb9142	thaw_super
++EXPORT_SYMBOL vmlinux 0x752c4c86	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x752c8f9e	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0x7531f190	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0x7532588a	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0x753c0591	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x75573801	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0x755db024	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x7561238a	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0x7562b0f9	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x75850d01	__vmalloc
++EXPORT_SYMBOL vmlinux 0x759a0bfe	generic_update_time
++EXPORT_SYMBOL vmlinux 0x759fb902	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x75ba2c54	msm_pinctrl_probe
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75ce1511	iommu_get_dma_cookie
++EXPORT_SYMBOL vmlinux 0x75cfa192	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0x75fbdefd	acpi_remove_address_space_handler
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x760e9fe0	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x761a5dc9	sk_common_release
++EXPORT_SYMBOL vmlinux 0x76211c91	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0x762168fb	dma_find_channel
++EXPORT_SYMBOL vmlinux 0x762188b8	inet_frag_find
++EXPORT_SYMBOL vmlinux 0x763dc945	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0x7643a36f	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x7645af6f	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x7658d0d7	__dst_free
++EXPORT_SYMBOL vmlinux 0x765ff474	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x766cf794	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x767d5d4a	revert_creds
++EXPORT_SYMBOL vmlinux 0x767dd8fd	acpi_get_irq_routing_table
++EXPORT_SYMBOL vmlinux 0x768f3a9b	nobh_writepage
++EXPORT_SYMBOL vmlinux 0x769e1bce	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x76a35f54	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0x76a5b343	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0x76aa9bdb	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x76ab4033	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0x76abf68b	scsi_register
++EXPORT_SYMBOL vmlinux 0x76cd4b59	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x76d08052	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76d7adfc	seq_open
++EXPORT_SYMBOL vmlinux 0x76e50ddf	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0x76ed772b	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x76f41530	ilookup5
++EXPORT_SYMBOL vmlinux 0x76fdb988	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0x770f4bc2	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0x7710cb45	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x773fa409	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x774341f4	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x77456e0a	acpi_root_dir
++EXPORT_SYMBOL vmlinux 0x7753ad3d	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77b30354	free_netdev
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77e1bfb8	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x77ea42a6	dm_register_target
++EXPORT_SYMBOL vmlinux 0x77f53abc	acpi_get_vendor_resource
++EXPORT_SYMBOL vmlinux 0x78025ecf	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x783ba1a5	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x7846af3e	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x787a0a97	pnp_disable_dev
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78bcb3e1	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x78c19a6d	mempool_resize
++EXPORT_SYMBOL vmlinux 0x78d47d50	dev_warn
++EXPORT_SYMBOL vmlinux 0x78dc7962	add_disk
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78eb7938	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0x78f3bff1	eth_header
++EXPORT_SYMBOL vmlinux 0x78f75981	submit_bh
++EXPORT_SYMBOL vmlinux 0x78ffeae6	bdi_destroy
++EXPORT_SYMBOL vmlinux 0x79068fda	acpi_install_method
++EXPORT_SYMBOL vmlinux 0x790d26de	seq_file_path
++EXPORT_SYMBOL vmlinux 0x792f82ff	dst_destroy
++EXPORT_SYMBOL vmlinux 0x793c59d6	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0x793f94e6	of_find_node_by_name
++EXPORT_SYMBOL vmlinux 0x7956d437	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x79575e68	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0x79607008	init_net
++EXPORT_SYMBOL vmlinux 0x7967a3c7	of_dev_get
++EXPORT_SYMBOL vmlinux 0x796fc4d7	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x7978ed45	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x7984eefc	key_update
++EXPORT_SYMBOL vmlinux 0x7985d043	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x79a33f85	vme_get_size
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79bf5156	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x79f46a1a	bioset_free
++EXPORT_SYMBOL vmlinux 0x7a09e930	__f_setown
++EXPORT_SYMBOL vmlinux 0x7a1fbaca	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0x7a34eaee	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x7a3591ec	key_validate
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a548a95	node_states
++EXPORT_SYMBOL vmlinux 0x7a6cdedc	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7a72aa84	vga_get
++EXPORT_SYMBOL vmlinux 0x7a9bf2d0	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7aafab0e	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7accad01	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7b02bd0d	d_invalidate
++EXPORT_SYMBOL vmlinux 0x7b16235f	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b2aef6c	__krealloc
++EXPORT_SYMBOL vmlinux 0x7b2b0bf9	sync_inode
++EXPORT_SYMBOL vmlinux 0x7b332e27	inode_init_owner
++EXPORT_SYMBOL vmlinux 0x7b52b594	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x7b6646bb	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x7b7acab0	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0x7b809578	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x7b9094d8	module_put
++EXPORT_SYMBOL vmlinux 0x7b9c304f	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0x7bad7a1a	acpi_walk_resources
++EXPORT_SYMBOL vmlinux 0x7bb96349	mpage_readpages
++EXPORT_SYMBOL vmlinux 0x7bbb9156	sg_miter_next
++EXPORT_SYMBOL vmlinux 0x7bbe4779	compat_mc_setsockopt
++EXPORT_SYMBOL vmlinux 0x7bdddf30	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0x7be75ffc	acpi_walk_resource_buffer
++EXPORT_SYMBOL vmlinux 0x7bf2d3e0	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0x7bf6bc59	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c1d4500	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0x7c2d098f	krealloc
++EXPORT_SYMBOL vmlinux 0x7c3fbf70	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c74cf4c	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x7c7853a8	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0x7c78f77e	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0x7c7d3a4e	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0x7c8c90e0	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cb7ba56	input_register_device
++EXPORT_SYMBOL vmlinux 0x7cd85ea8	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0x7cde31d1	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x7ce08e2d	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7ce83365	acpi_remove_table_handler
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7d0235c2	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d17e38d	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0x7d440dfd	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d7d63df	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x7d8b463e	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x7d94f746	acpi_os_write_port
++EXPORT_SYMBOL vmlinux 0x7dae5af5	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x7db329f9	do_SAK
++EXPORT_SYMBOL vmlinux 0x7db4c6d8	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x7dba55da	register_quota_format
++EXPORT_SYMBOL vmlinux 0x7dd4ba95	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7dfa7710	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0x7e01989a	key_task_permission
++EXPORT_SYMBOL vmlinux 0x7e0b5a09	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x7e147408	nobh_write_end
++EXPORT_SYMBOL vmlinux 0x7e1b7066	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x7e21c5b6	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0x7e747995	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0x7e9da777	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x7ea7c37f	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x7eaf81c7	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0x7ebb5df1	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x7ebd4be4	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x7ed35979	acpi_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0x7edda9c7	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7ef9b4e1	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f197c5f	d_genocide
++EXPORT_SYMBOL vmlinux 0x7f1b184e	sock_create_lite
++EXPORT_SYMBOL vmlinux 0x7f1c4ed2	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f263ed9	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x7f2d40d2	rt6_lookup
++EXPORT_SYMBOL vmlinux 0x7f4fbe87	md_error
++EXPORT_SYMBOL vmlinux 0x7f557f78	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0x7f59ffc1	vm_map_ram
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f9265f5	param_ops_string
++EXPORT_SYMBOL vmlinux 0x7f9be15e	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0x7fbb6433	netlink_set_err
++EXPORT_SYMBOL vmlinux 0x7fbd10d2	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x7fcc2af3	mmc_release_host
++EXPORT_SYMBOL vmlinux 0x7fd50115	compat_tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fe38f48	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x800a948c	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x805e4b20	simple_follow_link
++EXPORT_SYMBOL vmlinux 0x8068c15c	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x80791a8c	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0x80820566	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0x8085b32c	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x80b429e7	blk_complete_request
++EXPORT_SYMBOL vmlinux 0x80beac4e	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x80c76fa3	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80ca87e9	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80d85a46	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0x80eb423b	acpi_get_object_info
++EXPORT_SYMBOL vmlinux 0x80f5cd14	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x81275f46	compat_sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x81376ae2	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0x81472677	acpi_get_table
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x814efa30	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0x814f7a1b	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0x8152a402	flush_signals
++EXPORT_SYMBOL vmlinux 0x81533963	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x81533edb	__netif_schedule
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x81754e62	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x818253de	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x81a7094f	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81de29fa	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0x81e6b37f	dmi_get_system_info
++EXPORT_SYMBOL vmlinux 0x81e8ad17	sock_no_listen
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x8212721d	xenbus_dev_request_and_reply
++EXPORT_SYMBOL vmlinux 0x822122aa	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x82458f7f	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x829d3cbd	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82b37648	simple_open
++EXPORT_SYMBOL vmlinux 0x82ba5bd8	set_bh_page
++EXPORT_SYMBOL vmlinux 0x82c1cc20	genphy_update_link
++EXPORT_SYMBOL vmlinux 0x82edddcb	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x82fd2343	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0x8306375b	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0x8313e670	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x833ea7cc	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0x83461af7	mii_link_ok
++EXPORT_SYMBOL vmlinux 0x83474216	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x83a65a8d	__d_drop
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83c1269e	km_is_alive
++EXPORT_SYMBOL vmlinux 0x83c43bee	icmpv6_send
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83d05ea5	vc_resize
++EXPORT_SYMBOL vmlinux 0x83e2d7a0	compat_ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x84060081	xen_poll_irq_timeout
++EXPORT_SYMBOL vmlinux 0x84271222	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0x84397514	devm_free_irq
++EXPORT_SYMBOL vmlinux 0x843f3da5	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0x8448a79e	ip6_xmit
++EXPORT_SYMBOL vmlinux 0x844e3767	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0x846225c6	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x847d8b25	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0x84873902	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0x84c38a0a	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0x84c82e3f	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0x84cadf80	netdev_crit
++EXPORT_SYMBOL vmlinux 0x84e3be99	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x85030730	of_find_node_opts_by_path
++EXPORT_SYMBOL vmlinux 0x85061b76	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0x853c3821	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0x854d7bfa	dev_deactivate
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x85705f4c	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x858b3fe3	free_iova_mem
++EXPORT_SYMBOL vmlinux 0x85a4c911	security_path_link
++EXPORT_SYMBOL vmlinux 0x85b35e34	abort_creds
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85b6aeb6	get_acl
++EXPORT_SYMBOL vmlinux 0x85c5a33e	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85e673c2	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x8605dbde	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0x8623aeac	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x863ce981	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86cb2ae3	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0x86d8572d	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x86deb7e3	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0x86ea4d38	complete_all
++EXPORT_SYMBOL vmlinux 0x86ed6f1f	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x8703851b	cdev_add
++EXPORT_SYMBOL vmlinux 0x870ace6c	acpi_bus_get_status
++EXPORT_SYMBOL vmlinux 0x8713dfa1	of_mdio_parse_addr
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x8736dc86	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0x873bbed1	set_user_nice
++EXPORT_SYMBOL vmlinux 0x873fade4	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x87463141	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x876dafc3	ec_write
++EXPORT_SYMBOL vmlinux 0x87744bc1	blkdev_put
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x879651b6	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0x87c3b1ad	param_set_long
++EXPORT_SYMBOL vmlinux 0x87d8b692	make_kprojid
++EXPORT_SYMBOL vmlinux 0x87e84d1d	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0x87eb69f5	irq_stat
++EXPORT_SYMBOL vmlinux 0x880d5276	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x881f6358	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x883ab471	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0x8845cfc0	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x884da2c1	release_firmware
++EXPORT_SYMBOL vmlinux 0x88772551	compat_mc_getsockopt
++EXPORT_SYMBOL vmlinux 0x8879b38f	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x887f6334	dump_page
++EXPORT_SYMBOL vmlinux 0x887fa47e	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x88928cb6	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x889a35f0	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0x889c757f	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0x88b4e83b	down_trylock
++EXPORT_SYMBOL vmlinux 0x88b64b33	dma_alloc_from_coherent
++EXPORT_SYMBOL vmlinux 0x88d1d196	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0x88e15dd8	dquot_get_state
++EXPORT_SYMBOL vmlinux 0x88e39746	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0x890a6ffb	of_node_get
++EXPORT_SYMBOL vmlinux 0x890c30ea	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0x892de3fb	__nla_put
++EXPORT_SYMBOL vmlinux 0x89377985	init_task
++EXPORT_SYMBOL vmlinux 0x897dffe9	pci_request_region
++EXPORT_SYMBOL vmlinux 0x89865f63	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x898abf5a	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0x8997503d	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0x89981c8b	update_region
++EXPORT_SYMBOL vmlinux 0x899c6469	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89b12986	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x89b8faf1	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0x89b9dc0d	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x89cecf26	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89ff9936	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x8a128602	update_devfreq
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a2549b5	locks_init_lock
++EXPORT_SYMBOL vmlinux 0x8a2627b6	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x8a372b5d	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0x8a3b34d2	put_io_context
++EXPORT_SYMBOL vmlinux 0x8a48cee2	nvdimm_namespace_disk_name
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a5ac174	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x8a6af65c	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x8a6e6564	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x8a701eae	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x8a7c557f	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a80d7a5	acpi_error
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8aa57c4f	udp_table
++EXPORT_SYMBOL vmlinux 0x8abb2201	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0x8afd6af6	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0x8b00bc46	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x8b25096a	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0x8b2cd0af	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b47f101	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x8b484538	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b7b2563	start_tty
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b989cf9	acpi_bus_can_wakeup
++EXPORT_SYMBOL vmlinux 0x8baae5d8	from_kprojid
++EXPORT_SYMBOL vmlinux 0x8bb3cb1e	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x8bb90980	security_path_truncate
++EXPORT_SYMBOL vmlinux 0x8bbbbb44	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x8bc5e2d2	register_gifconf
++EXPORT_SYMBOL vmlinux 0x8bcac3f2	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x8bcc5b39	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x8bce2653	flow_cache_init
++EXPORT_SYMBOL vmlinux 0x8bcfb90b	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x8bd0a3fd	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0x8be76dc5	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0x8be96c39	page_waitqueue
++EXPORT_SYMBOL vmlinux 0x8beeae72	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x8bffd200	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x8c0cc366	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0x8c314c4e	noop_llseek
++EXPORT_SYMBOL vmlinux 0x8c31ecec	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0x8c37170b	sk_dst_check
++EXPORT_SYMBOL vmlinux 0x8c463705	set_device_ro
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c63e736	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0x8c77af12	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0x8ca6de7f	irq_to_desc
++EXPORT_SYMBOL vmlinux 0x8cb021ab	fput
++EXPORT_SYMBOL vmlinux 0x8cc2fa05	of_gpio_simple_xlate
++EXPORT_SYMBOL vmlinux 0x8cda8029	xen_clear_irq_pending
++EXPORT_SYMBOL vmlinux 0x8cdcdf22	no_llseek
++EXPORT_SYMBOL vmlinux 0x8ce47f47	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0x8cf8198a	scsi_host_get
++EXPORT_SYMBOL vmlinux 0x8d179528	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x8d2a030f	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0x8d4ae15c	acpi_match_device_ids
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d651b59	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x8d6eb673	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d7cf02e	ata_link_printk
++EXPORT_SYMBOL vmlinux 0x8d8b27c2	__register_chrdev
++EXPORT_SYMBOL vmlinux 0x8d8d96c6	acpi_get_sleep_type_data
++EXPORT_SYMBOL vmlinux 0x8d90b5b9	keyring_clear
++EXPORT_SYMBOL vmlinux 0x8da1a3cb	acpi_remove_interface
++EXPORT_SYMBOL vmlinux 0x8dbc8375	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0x8dc727b2	dev_set_group
++EXPORT_SYMBOL vmlinux 0x8de2576e	dmam_release_declared_memory
++EXPORT_SYMBOL vmlinux 0x8df92f66	memchr_inv
++EXPORT_SYMBOL vmlinux 0x8e0921dd	netdev_info
++EXPORT_SYMBOL vmlinux 0x8e1fea16	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0x8e228ae5	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0x8e40d4ad	genphy_resume
++EXPORT_SYMBOL vmlinux 0x8e42e9ea	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0x8e44f60e	scsi_init_io
++EXPORT_SYMBOL vmlinux 0x8e4db788	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0x8e4e545b	ip_options_compile
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e79a2cf	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0x8eab8752	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0x8eaca4f4	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x8eb8e8e7	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0x8ebaa876	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0x8ed8a9a0	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0x8eea49fa	amba_device_register
++EXPORT_SYMBOL vmlinux 0x8f20d534	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x8f2eb215	amba_find_device
++EXPORT_SYMBOL vmlinux 0x8f3787be	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0x8f3a3e77	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x8f3b8b64	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0x8f572676	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x8f591440	blk_put_request
++EXPORT_SYMBOL vmlinux 0x8f678b07	__stack_chk_guard
++EXPORT_SYMBOL vmlinux 0x8f695ca0	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0x8fce5282	fb_find_mode
++EXPORT_SYMBOL vmlinux 0x8fdaaf67	unregister_nls
++EXPORT_SYMBOL vmlinux 0x8fea6fb3	mntget
++EXPORT_SYMBOL vmlinux 0x8ff6f386	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0x900a09d8	audit_log
++EXPORT_SYMBOL vmlinux 0x9023994e	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0x9023a30a	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x902a32f1	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0x9054068d	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x90565dd3	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0x906581ec	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0x90807ad2	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0x90875aa9	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0x90970029	pci_save_state
++EXPORT_SYMBOL vmlinux 0x909e346f	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x90ac3102	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x90ba1540	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x90bbe4c7	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0x90c3b265	sock_edemux
++EXPORT_SYMBOL vmlinux 0x90e6ec66	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x90f85655	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x90f86748	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x9102bfc4	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0x911b6d80	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x911f4647	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0x91203258	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0x912ff2c6	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0x9136298f	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x913656f3	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x9137feb5	iommu_put_dma_cookie
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x9161610a	of_find_all_nodes
++EXPORT_SYMBOL vmlinux 0x9166fada	strncpy
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x91817439	compat_sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x918c6374	mempool_alloc
++EXPORT_SYMBOL vmlinux 0x919cb19e	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x91ac2f79	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0x91ac822f	vscnprintf
++EXPORT_SYMBOL vmlinux 0x91c38477	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0x91eddf22	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x92205cb6	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x923a31d8	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x9289e19c	pci_release_region
++EXPORT_SYMBOL vmlinux 0x9291cd3b	memdup_user
++EXPORT_SYMBOL vmlinux 0x92a117c2	alloc_pages_current
++EXPORT_SYMBOL vmlinux 0x92a44a80	fence_add_callback
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92de484e	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0x92f5f5fd	skb_pad
++EXPORT_SYMBOL vmlinux 0x92f9c591	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x92fab92b	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x92fbf694	unlock_page
++EXPORT_SYMBOL vmlinux 0x93022ba6	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x9308a3a9	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0x9332527e	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0x934544cf	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x934fddad	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x93538371	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0x9368567b	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0x936b6c78	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x93836fc2	copy_from_iter
++EXPORT_SYMBOL vmlinux 0x93891e7d	netlink_ack
++EXPORT_SYMBOL vmlinux 0x9390f226	ida_destroy
++EXPORT_SYMBOL vmlinux 0x9394b285	filp_open
++EXPORT_SYMBOL vmlinux 0x93a5c449	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93d679d2	down_write_trylock
++EXPORT_SYMBOL vmlinux 0x93df0922	request_firmware
++EXPORT_SYMBOL vmlinux 0x93f3e52b	acpi_extract_package
++EXPORT_SYMBOL vmlinux 0x93f62a3b	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x9450e19e	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x9451e6d2	generic_file_open
++EXPORT_SYMBOL vmlinux 0x9456acba	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x94782027	mii_nway_restart
++EXPORT_SYMBOL vmlinux 0x9488e728	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x948b5fb8	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x949b754f	mempool_destroy
++EXPORT_SYMBOL vmlinux 0x94a01d84	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0x94a2d99b	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x94b88628	of_get_next_available_child
++EXPORT_SYMBOL vmlinux 0x94bd0da0	__frontswap_test
++EXPORT_SYMBOL vmlinux 0x94c083c2	generic_mii_ioctl
++EXPORT_SYMBOL vmlinux 0x94c14c82	inet_bind
++EXPORT_SYMBOL vmlinux 0x94e52301	input_set_keycode
++EXPORT_SYMBOL vmlinux 0x94f7ec71	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x94f94c56	sk_capable
++EXPORT_SYMBOL vmlinux 0x94fc00e5	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x9515abf5	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x9516c0d1	pnp_start_dev
++EXPORT_SYMBOL vmlinux 0x95395301	acpi_exception
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x954d4502	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x956cdfae	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x956e39d1	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0x956f9d18	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0x9588d789	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0x958a6c29	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0x95bbeadc	set_posix_acl
++EXPORT_SYMBOL vmlinux 0x95e6f5e7	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0x95f23bc8	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0x96220280	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x962aa11e	of_get_min_tck
++EXPORT_SYMBOL vmlinux 0x96318a71	stop_tty
++EXPORT_SYMBOL vmlinux 0x9632199d	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x964482ad	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0x96680d30	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0x966bccdf	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x967ec1d0	set_anon_super
++EXPORT_SYMBOL vmlinux 0x969b972b	pnp_register_card_driver
++EXPORT_SYMBOL vmlinux 0x969cf15d	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0x96b29254	strncasecmp
++EXPORT_SYMBOL vmlinux 0x96c0a984	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x96c46c13	__breadahead
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96cdbfed	fb_set_var
++EXPORT_SYMBOL vmlinux 0x96fbb19c	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0x970dc69e	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0x970fc182	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0x97193271	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x9719558d	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0x971a260a	blk_queue_split
++EXPORT_SYMBOL vmlinux 0x972f8928	of_find_node_by_phandle
++EXPORT_SYMBOL vmlinux 0x97371575	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x973fa82e	register_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x97651ac5	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x976fe0ba	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x978591b7	register_cdrom
++EXPORT_SYMBOL vmlinux 0x97868aef	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x97a57333	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0x97c5bd0a	acpi_unload_parent_table
++EXPORT_SYMBOL vmlinux 0x97f52fb2	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x97fdbab9	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x98082893	__copy_to_user
++EXPORT_SYMBOL vmlinux 0x9821ff76	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x9829fc11	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0x98446ff7	ether_setup
++EXPORT_SYMBOL vmlinux 0x98461957	mii_check_link
++EXPORT_SYMBOL vmlinux 0x985cd241	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0x985e6777	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x98849b56	unload_nls
++EXPORT_SYMBOL vmlinux 0x989b28a8	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0x98b62324	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0x98c43561	of_find_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0x98c68c41	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x98cf60b3	strlen
++EXPORT_SYMBOL vmlinux 0x98e1ad9c	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0x98fa154d	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x99195078	vsnprintf
++EXPORT_SYMBOL vmlinux 0x9922fc84	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x99335958	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x993e7130	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x99412010	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0x99441a83	read_cache_page
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99529f74	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0x9956fe8b	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x996b3e93	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x996c7db8	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x99896476	of_graph_get_next_endpoint
++EXPORT_SYMBOL vmlinux 0x99937fd7	passthru_features_check
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99c6c3cc	xen_biovec_phys_mergeable
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d3a43c	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x99db75aa	generic_perform_write
++EXPORT_SYMBOL vmlinux 0x9a10af71	vfs_write
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a259890	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0x9a2b692c	simple_setattr
++EXPORT_SYMBOL vmlinux 0x9a58ce7d	pci_get_device
++EXPORT_SYMBOL vmlinux 0x9a7c2084	drop_nlink
++EXPORT_SYMBOL vmlinux 0x9a908b80	test_and_clear_bit
++EXPORT_SYMBOL vmlinux 0x9a97566a	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0x9aae20d1	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0x9ab02d32	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x9ac9c9e6	skb_clone
++EXPORT_SYMBOL vmlinux 0x9adeaba0	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9aef7188	dcb_getapp
++EXPORT_SYMBOL vmlinux 0x9b2ad4e5	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b70ae90	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0x9b7e3573	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0x9b857e13	blk_start_request
++EXPORT_SYMBOL vmlinux 0x9b9a691a	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9ba78fc9	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0x9ba8db72	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0x9bb47c75	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0x9bbc1f4b	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0x9bbe88b3	flex_array_put
++EXPORT_SYMBOL vmlinux 0x9bc2e70e	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0x9bc6ef31	add_wait_queue
++EXPORT_SYMBOL vmlinux 0x9bc792b6	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9c1a7601	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x9c1ae76f	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x9c2f557c	kfree_put_link
++EXPORT_SYMBOL vmlinux 0x9c3cd0a0	simple_dname
++EXPORT_SYMBOL vmlinux 0x9c480717	noop_fsync
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c5bc552	finish_wait
++EXPORT_SYMBOL vmlinux 0x9c632dd6	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x9c76d50c	sock_no_poll
++EXPORT_SYMBOL vmlinux 0x9c7ac405	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0x9c7e9804	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0x9c9a9092	__vfs_read
++EXPORT_SYMBOL vmlinux 0x9ca1536e	sk_net_capable
++EXPORT_SYMBOL vmlinux 0x9ca37b63	ps2_command
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cba14cc	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0x9cbaf09d	netdev_update_features
++EXPORT_SYMBOL vmlinux 0x9cc33e33	send_sig
++EXPORT_SYMBOL vmlinux 0x9cc9b35e	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d1386e6	set_security_override
++EXPORT_SYMBOL vmlinux 0x9d1a5e3a	__memcpy
++EXPORT_SYMBOL vmlinux 0x9d1aa952	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x9d3676b7	sock_i_ino
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d6c06c1	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0x9d767815	dma_release_from_coherent
++EXPORT_SYMBOL vmlinux 0x9d825412	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0x9d8ffca1	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0x9d98e718	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0x9da05e10	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0x9dba371f	follow_up
++EXPORT_SYMBOL vmlinux 0x9dc7c2eb	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x9e0104b3	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x9e0176f4	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e1a32cb	touch_buffer
++EXPORT_SYMBOL vmlinux 0x9e25f589	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0x9e2f8c90	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9e38fa25	write_cache_pages
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e73cb48	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e7d6bd0	__udelay
++EXPORT_SYMBOL vmlinux 0x9e8953f9	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9eae3b3b	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9ec25cd1	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x9eccbfa0	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0x9edd107e	pci_bus_type
++EXPORT_SYMBOL vmlinux 0x9eebb027	block_read_full_page
++EXPORT_SYMBOL vmlinux 0x9ef518e6	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x9f11be7e	down_killable
++EXPORT_SYMBOL vmlinux 0x9f20b8a0	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x9f25963f	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0x9f3d3415	elevator_change
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f4ca63a	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x9f5a6e2d	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0x9f6735a7	fget_raw
++EXPORT_SYMBOL vmlinux 0x9f7c1be8	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0x9f948897	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0x9f97e196	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9fac6b12	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0x9fc3a63a	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x9fd338a1	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0x9fd55567	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x9fd7cda1	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9ff823ee	set_page_dirty
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa002db53	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0xa0234f40	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0xa0307ef6	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa04581ef	migrate_page
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa05a6fe8	km_query
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa0647b31	md_update_sb
++EXPORT_SYMBOL vmlinux 0xa07a37f0	memchr
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa0854aae	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0xa086fd20	pcibus_to_node
++EXPORT_SYMBOL vmlinux 0xa0a3c418	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0xa0af0da7	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0b6ece6	scsi_add_device
++EXPORT_SYMBOL vmlinux 0xa0d6a53a	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0e11c3f	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0ff74d6	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xa100d1bc	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0xa1042496	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa116d50f	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa12697d3	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa1498e03	phy_detach
++EXPORT_SYMBOL vmlinux 0xa14b3f5d	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0xa16efc70	backlight_device_register
++EXPORT_SYMBOL vmlinux 0xa184dc98	netdev_features_change
++EXPORT_SYMBOL vmlinux 0xa1872afc	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0xa18b56e1	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0xa19d537a	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1d46941	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa1f34342	generic_make_request
++EXPORT_SYMBOL vmlinux 0xa202a8e5	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0xa2088013	iommu_dma_init_domain
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa23afabd	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0xa23f712f	bdi_register
++EXPORT_SYMBOL vmlinux 0xa257f3e0	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0xa2702ea8	of_dev_put
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa2a335bd	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0xa2a57803	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0xa2ad55d2	set_cached_acl
++EXPORT_SYMBOL vmlinux 0xa2b788d5	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0xa2c0b6e2	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0xa2d4a483	neigh_update
++EXPORT_SYMBOL vmlinux 0xa2ea220d	freeze_super
++EXPORT_SYMBOL vmlinux 0xa2eb25bd	__block_write_begin
++EXPORT_SYMBOL vmlinux 0xa2ef3e31	vme_lm_request
++EXPORT_SYMBOL vmlinux 0xa2fdcb8e	set_create_files_as
++EXPORT_SYMBOL vmlinux 0xa3021ab6	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0xa311e1c9	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa32a4989	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0xa339022c	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0xa354e8e5	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0xa358c37e	init_special_inode
++EXPORT_SYMBOL vmlinux 0xa35bde3e	dst_init
++EXPORT_SYMBOL vmlinux 0xa3671cb0	input_unregister_device
++EXPORT_SYMBOL vmlinux 0xa36c0101	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0xa36d3a09	registered_fb
++EXPORT_SYMBOL vmlinux 0xa37011ac	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xa37e78b6	flex_array_get
++EXPORT_SYMBOL vmlinux 0xa3800675	tso_count_descs
++EXPORT_SYMBOL vmlinux 0xa39a0f3f	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0xa39bf40a	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0xa3aa2d7b	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0xa3e17f56	node_to_cpumask_map
++EXPORT_SYMBOL vmlinux 0xa3f44a80	module_layout
++EXPORT_SYMBOL vmlinux 0xa40111bd	load_nls
++EXPORT_SYMBOL vmlinux 0xa4168b60	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0xa416ee7b	skb_trim
++EXPORT_SYMBOL vmlinux 0xa426b5c0	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0xa4292f11	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0xa43b01e1	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0xa44290b3	of_iomap
++EXPORT_SYMBOL vmlinux 0xa44f5c24	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0xa4511467	crc16
++EXPORT_SYMBOL vmlinux 0xa4526dca	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0xa454653a	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0xa46c0f20	empty_zero_page
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa473398f	of_find_i2c_device_by_node
++EXPORT_SYMBOL vmlinux 0xa4812f0c	dquot_disable
++EXPORT_SYMBOL vmlinux 0xa49b012f	n_tty_compat_ioctl_helper
++EXPORT_SYMBOL vmlinux 0xa4b189ab	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0xa4d48b76	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0xa4e3f66c	security_path_unlink
++EXPORT_SYMBOL vmlinux 0xa53dab6e	of_mm_gpiochip_add
++EXPORT_SYMBOL vmlinux 0xa547ef6f	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0xa54b1ddd	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa567a9c6	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0xa572179e	drop_super
++EXPORT_SYMBOL vmlinux 0xa5765434	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0xa5976124	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa59fa009	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0xa5a51eee	__crc32c_le
++EXPORT_SYMBOL vmlinux 0xa5dcf280	unregister_netdev
++EXPORT_SYMBOL vmlinux 0xa5ed0a3f	mutex_lock
++EXPORT_SYMBOL vmlinux 0xa60d55af	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0xa614beb1	unregister_key_type
++EXPORT_SYMBOL vmlinux 0xa61570f2	user_revoke
++EXPORT_SYMBOL vmlinux 0xa616e8ea	serio_interrupt
++EXPORT_SYMBOL vmlinux 0xa6183d9a	tso_build_data
++EXPORT_SYMBOL vmlinux 0xa63322c6	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa6488f0e	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa67ab424	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa6bd63ca	acpi_bios_error
++EXPORT_SYMBOL vmlinux 0xa6c31b60	register_framebuffer
++EXPORT_SYMBOL vmlinux 0xa6ce705f	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0xa6e79984	acpi_device_set_power
++EXPORT_SYMBOL vmlinux 0xa6ef1e1d	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa7079e35	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0xa72a0f5b	nr_online_nodes
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa7373dea	dmam_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0xa739e139	blk_init_queue
++EXPORT_SYMBOL vmlinux 0xa751e4ec	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0xa7542043	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0xa75c80a6	vfs_getattr
++EXPORT_SYMBOL vmlinux 0xa75ca8a2	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0xa761b513	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0xa78df429	param_get_bool
++EXPORT_SYMBOL vmlinux 0xa7a71341	file_remove_privs
++EXPORT_SYMBOL vmlinux 0xa7ae0fad	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0xa7bcaa6a	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0xa7be526f	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0xa7da41c7	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0xa7edb25c	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0xa7ee4348	bio_advance
++EXPORT_SYMBOL vmlinux 0xa7f67a49	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0xa827a0f6	simple_unlink
++EXPORT_SYMBOL vmlinux 0xa8390889	follow_pfn
++EXPORT_SYMBOL vmlinux 0xa840df33	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa8539120	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0xa862242e	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa87cf413	clear_bit
++EXPORT_SYMBOL vmlinux 0xa87cfcc1	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0xa8a39641	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0xa8a56595	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0xa8a8110c	kernel_neon_end
++EXPORT_SYMBOL vmlinux 0xa8c66d9d	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0xa8cb9902	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0xa8cbe740	sock_wake_async
++EXPORT_SYMBOL vmlinux 0xa8fa0523	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa91088cc	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa916b694	strnlen
++EXPORT_SYMBOL vmlinux 0xa91d90d3	nla_put
++EXPORT_SYMBOL vmlinux 0xa91e5485	prepare_binprm
++EXPORT_SYMBOL vmlinux 0xa9220a25	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0xa92d0171	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa97b3b21	of_find_node_with_property
++EXPORT_SYMBOL vmlinux 0xa9838c16	simple_statfs
++EXPORT_SYMBOL vmlinux 0xa994c670	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0xa9992614	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0xa99b39c2	prandom_bytes
++EXPORT_SYMBOL vmlinux 0xa9a0d91c	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0xa9a4f320	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0xa9a6d82a	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xa9b248b6	idr_for_each
++EXPORT_SYMBOL vmlinux 0xa9ba34d7	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9e07767	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0xa9fc193e	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0xaa02e4da	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0xaa03879a	amba_release_regions
++EXPORT_SYMBOL vmlinux 0xaa08f90a	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0xaa0c52b4	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0xaa0eb1b8	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0xaa0f3159	of_mm_gpiochip_remove
++EXPORT_SYMBOL vmlinux 0xaa1963a3	of_mdiobus_register
++EXPORT_SYMBOL vmlinux 0xaa1f1a37	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0xaa40619c	napi_disable
++EXPORT_SYMBOL vmlinux 0xaa50f7b0	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0xaa5b82cb	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0xaa61dd40	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xaa66dbe1	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0xaa6ed06e	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa89f41a	dquot_enable
++EXPORT_SYMBOL vmlinux 0xaa8a6194	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0xaa9bc305	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0xaaa3d980	alloc_disk
++EXPORT_SYMBOL vmlinux 0xaab2a2d1	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0xaab98203	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0xaacc3134	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaae8ab0e	acpi_bus_power_manageable
++EXPORT_SYMBOL vmlinux 0xaaf3dc7e	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xaaf52fa5	install_exec_creds
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab0e69d0	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0xab206150	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0xab2d9daf	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0xab40cca9	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0xab435267	blk_free_tags
++EXPORT_SYMBOL vmlinux 0xab551fad	acpi_get_data_full
++EXPORT_SYMBOL vmlinux 0xab600421	probe_irq_off
++EXPORT_SYMBOL vmlinux 0xab668abf	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab6e210b	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0xab72ddcd	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xaba57cbe	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0xabbbd444	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xabbc4335	simple_write_end
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabcd1cbe	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0xabd2e45c	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0xabde4436	param_set_bint
++EXPORT_SYMBOL vmlinux 0xabf144dc	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0xabf6b5bb	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac226d8d	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0xac330002	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0xac3737d1	ilookup
++EXPORT_SYMBOL vmlinux 0xac398912	flex_array_clear
++EXPORT_SYMBOL vmlinux 0xac435e88	put_tty_driver
++EXPORT_SYMBOL vmlinux 0xac46be3a	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0xac4727d0	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0xac5e1d6c	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xac708eda	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0xac930f2c	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0xac9ab5da	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0xac9cb009	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0xac9d2d83	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0xaca5824b	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacc5b5d2	csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacd76bc6	generic_getxattr
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xad01744f	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad12df1f	dst_release
++EXPORT_SYMBOL vmlinux 0xad164875	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xad2945d1	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0xad33fc0e	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0xad418f77	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0xad45bcdf	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0xad5be382	textsearch_register
++EXPORT_SYMBOL vmlinux 0xad63e4b5	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad898dd5	of_phy_connect
++EXPORT_SYMBOL vmlinux 0xad89b0d1	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0xad9facd6	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0xada6e5b8	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xaddeec12	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0xade1e1b4	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0xadf33470	mmc_cleanup_queue
++EXPORT_SYMBOL vmlinux 0xadf64ca3	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xae15036c	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0xae4a1bda	csum_tcpudp_nofold
++EXPORT_SYMBOL vmlinux 0xae4a2d49	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0xae4af362	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0xae5eda39	udp_poll
++EXPORT_SYMBOL vmlinux 0xae78f252	cdrom_release
++EXPORT_SYMBOL vmlinux 0xae8c4d0c	set_bit
++EXPORT_SYMBOL vmlinux 0xae8d7eb6	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0xaea8e059	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0xaea976a8	acpi_check_resource_conflict
++EXPORT_SYMBOL vmlinux 0xaec11255	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0xaef0e66d	inet_del_offload
++EXPORT_SYMBOL vmlinux 0xaef428f0	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0xaef6c567	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0xaefebbdd	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0xaeff954f	fb_pan_display
++EXPORT_SYMBOL vmlinux 0xaf0e5ed6	send_sig_info
++EXPORT_SYMBOL vmlinux 0xaf2161a1	bio_init
++EXPORT_SYMBOL vmlinux 0xaf33d0f4	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf4011b6	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0xaf53f745	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0xaf6ae696	kstrndup
++EXPORT_SYMBOL vmlinux 0xaf6bf4bd	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0xaf819163	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0xaf8eb4b9	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0xafa5d057	param_set_ullong
++EXPORT_SYMBOL vmlinux 0xafa7f7f9	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0xafbc2861	do_splice_from
++EXPORT_SYMBOL vmlinux 0xafc9c8f9	dentry_unhash
++EXPORT_SYMBOL vmlinux 0xb0085b6f	bio_endio
++EXPORT_SYMBOL vmlinux 0xb009bec8	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0xb00f5d91	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xb02249a4	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0xb024ec43	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0xb032b6e4	__kernel_write
++EXPORT_SYMBOL vmlinux 0xb0362af6	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xb03f6691	framebuffer_release
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb05fd1c1	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0xb06cb1fd	i2c_release_client
++EXPORT_SYMBOL vmlinux 0xb0763117	secpath_dup
++EXPORT_SYMBOL vmlinux 0xb078a6a4	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0xb07fb4f7	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0xb0871b4e	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0xb0946219	pci_clear_master
++EXPORT_SYMBOL vmlinux 0xb094e3d0	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0e0f008	poll_freewait
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb11383ce	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0xb121390a	probe_irq_on
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb13ae87a	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0xb147a855	dql_reset
++EXPORT_SYMBOL vmlinux 0xb1508faf	thaw_bdev
++EXPORT_SYMBOL vmlinux 0xb152e9db	mount_pseudo
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb161c4bc	i2c_use_client
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1c86f11	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1d2b6b3	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0xb1ff47c6	blk_end_request
++EXPORT_SYMBOL vmlinux 0xb20ecf88	acpi_run_osc
++EXPORT_SYMBOL vmlinux 0xb2116994	bdevname
++EXPORT_SYMBOL vmlinux 0xb21dd9d3	dump_emit
++EXPORT_SYMBOL vmlinux 0xb2469c65	set_groups
++EXPORT_SYMBOL vmlinux 0xb25edae3	clkdev_add
++EXPORT_SYMBOL vmlinux 0xb25f0859	arp_create
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb281b86b	key_alloc
++EXPORT_SYMBOL vmlinux 0xb29c75de	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0xb2ab6609	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2dcd45e	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0xb3035556	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0xb31e8cc3	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0xb31fcb5a	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0xb3284531	acpi_dbg_layer
++EXPORT_SYMBOL vmlinux 0xb3291d0f	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xb37789e4	xen_dma_ops
++EXPORT_SYMBOL vmlinux 0xb37bee52	rename_lock
++EXPORT_SYMBOL vmlinux 0xb3861370	genphy_config_init
++EXPORT_SYMBOL vmlinux 0xb38721c2	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0xb3a3b3dc	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0xb3aee8c5	write_inode_now
++EXPORT_SYMBOL vmlinux 0xb3b76b4d	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3d926ef	nd_device_unregister
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb3f84166	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xb40557d6	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb425132e	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb4717d2d	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xb47189b5	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xb485fdee	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0xb4b9fd60	pnp_device_detach
++EXPORT_SYMBOL vmlinux 0xb4cdca20	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0xb4dbd0c7	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0xb4f8bea0	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0xb4fc735b	idr_remove
++EXPORT_SYMBOL vmlinux 0xb502adb1	devm_iounmap
++EXPORT_SYMBOL vmlinux 0xb51a0b0b	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0xb51e3cc7	of_find_backlight_by_node
++EXPORT_SYMBOL vmlinux 0xb5291dd7	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0xb540d5d5	request_key
++EXPORT_SYMBOL vmlinux 0xb54cab27	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0xb55811ff	pci_set_master
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5b6d668	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0xb5c90fad	lookup_one_len
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb5d92671	of_graph_get_port_by_id
++EXPORT_SYMBOL vmlinux 0xb5ddb7ab	ihold
++EXPORT_SYMBOL vmlinux 0xb6051d65	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0xb6157625	sock_rfree
++EXPORT_SYMBOL vmlinux 0xb6203ffa	pci_get_class
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb626080c	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0xb641fdb1	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb67b55b3	free_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb69877c1	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0xb69f9b00	mempool_free
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6a73ba4	finish_no_open
++EXPORT_SYMBOL vmlinux 0xb6d13eeb	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0xb6d3daf1	qcom_scm_hdcp_req
++EXPORT_SYMBOL vmlinux 0xb6dfd754	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0xb6e09436	give_up_console
++EXPORT_SYMBOL vmlinux 0xb71fb74f	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0xb7384bc2	nf_register_hook
++EXPORT_SYMBOL vmlinux 0xb747f6ed	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb74caff7	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb7810799	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0xb79831aa	fs_bio_set
++EXPORT_SYMBOL vmlinux 0xb7a1e1e9	tty_register_device
++EXPORT_SYMBOL vmlinux 0xb7a9d4dc	flush_dcache_page
++EXPORT_SYMBOL vmlinux 0xb7b89bb6	sget_userns
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7d46b54	param_get_charp
++EXPORT_SYMBOL vmlinux 0xb7d7e1e1	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xb7e4b758	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0xb7f511da	lockref_get
++EXPORT_SYMBOL vmlinux 0xb80fa620	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0xb8543dfa	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0xb85a478d	vfs_link
++EXPORT_SYMBOL vmlinux 0xb85d2069	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb887a9f2	param_ops_short
++EXPORT_SYMBOL vmlinux 0xb89eb40c	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0xb8cd6c51	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0xb8ce0991	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0xb8ddbbe2	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0xb8ddbfa6	__blk_end_request
++EXPORT_SYMBOL vmlinux 0xb8e8e06b	register_filesystem
++EXPORT_SYMBOL vmlinux 0xb8ec9e4f	tty_lock
++EXPORT_SYMBOL vmlinux 0xb8fa8eaa	dqget
++EXPORT_SYMBOL vmlinux 0xb8fdc9e8	tty_register_driver
++EXPORT_SYMBOL vmlinux 0xb8ff83fa	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0xb92d2365	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0xb93c4e20	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0xb9613a6a	pci_release_regions
++EXPORT_SYMBOL vmlinux 0xb98639cf	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0xb98827c6	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0xb99c0636	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0xb9db201e	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0xb9db8dd0	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xb9dcff1d	free_buffer_head
++EXPORT_SYMBOL vmlinux 0xb9ddf11c	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xb9f33719	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0xba277ed2	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0xba2c7dbb	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0xba2d8594	ec_read
++EXPORT_SYMBOL vmlinux 0xba2ffec2	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0xba3dd124	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba4a05d4	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0xba5aa85b	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0xba5bde53	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0xba6773a9	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xba687ed6	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0xba766d81	kill_block_super
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb22ae3d	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0xbb34134a	iov_shorten
++EXPORT_SYMBOL vmlinux 0xbb34be87	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb4086db	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0xbb4f4766	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb6ba498	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0xbb7735dc	kern_path
++EXPORT_SYMBOL vmlinux 0xbb7c5680	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0xbb88a8f4	__lock_page
++EXPORT_SYMBOL vmlinux 0xbb93d6ff	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbbaeb559	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0xbbccb5a0	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0xbbdd7555	tcp_filter
++EXPORT_SYMBOL vmlinux 0xbbf3b71d	security_path_rename
++EXPORT_SYMBOL vmlinux 0xbc07e281	qdisc_reset
++EXPORT_SYMBOL vmlinux 0xbc2031de	acpi_processor_get_bios_limit
++EXPORT_SYMBOL vmlinux 0xbc3b3696	cdev_alloc
++EXPORT_SYMBOL vmlinux 0xbc4ca93d	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0xbc797713	blk_run_queue
++EXPORT_SYMBOL vmlinux 0xbc9c9e82	tty_throttle
++EXPORT_SYMBOL vmlinux 0xbca410e7	param_get_ulong
++EXPORT_SYMBOL vmlinux 0xbca6685a	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0xbcba3210	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcd04ac3	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0xbd07ba7f	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0xbd15846c	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0xbd2feeb4	seq_printf
++EXPORT_SYMBOL vmlinux 0xbd3654c8	kthread_bind
++EXPORT_SYMBOL vmlinux 0xbd462b55	__kfifo_init
++EXPORT_SYMBOL vmlinux 0xbd5e15c8	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0xbd66c65b	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0xbd6d79f1	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0xbd702083	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0xbd747890	__bforget
++EXPORT_SYMBOL vmlinux 0xbd8fb634	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbd936652	netdev_printk
++EXPORT_SYMBOL vmlinux 0xbdab8bd1	of_find_matching_node_and_match
++EXPORT_SYMBOL vmlinux 0xbdae32d0	of_cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0xbdaf5b07	acpi_os_read_port
++EXPORT_SYMBOL vmlinux 0xbdb6bf96	gnttab_free_pages
++EXPORT_SYMBOL vmlinux 0xbdbc13a1	complete
++EXPORT_SYMBOL vmlinux 0xbdbd313a	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0xbdcc7117	unregister_console
++EXPORT_SYMBOL vmlinux 0xbdd5fc2b	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0xbde05aa8	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0xbdf8083a	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0xbdf82bd3	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0xbe04cf6e	single_open_size
++EXPORT_SYMBOL vmlinux 0xbe1add73	qcom_scm_set_warm_boot_addr
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe48e789	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0xbe50fd80	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0xbe534a5d	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0xbe76ad17	check_disk_change
++EXPORT_SYMBOL vmlinux 0xbe8d73d4	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0xbe9d17f9	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0xbea12735	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0xbed30104	dcb_setapp
++EXPORT_SYMBOL vmlinux 0xbee51c38	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf06f97c	put_filp
++EXPORT_SYMBOL vmlinux 0xbf189671	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0xbf1d2056	get_empty_filp
++EXPORT_SYMBOL vmlinux 0xbf27d21f	del_gendisk
++EXPORT_SYMBOL vmlinux 0xbf2d5fd5	kill_fasync
++EXPORT_SYMBOL vmlinux 0xbf41ee8b	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0xbf762625	nd_iostat_end
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf98cbdc	register_md_personality
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfaa9b37	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0xbfab5faf	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xc012d515	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0xc0159677	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0xc016cff7	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0xc02c4f7f	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc0a15f5b	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0bf0089	__seq_open_private
++EXPORT_SYMBOL vmlinux 0xc0c20ef3	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc0d5d4fb	page_readlink
++EXPORT_SYMBOL vmlinux 0xc0de9e47	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0xc0fa40e4	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0xc0fbb068	key_type_keyring
++EXPORT_SYMBOL vmlinux 0xc104db1c	pci_get_slot
++EXPORT_SYMBOL vmlinux 0xc1057170	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0xc13ce0b8	__serio_register_port
++EXPORT_SYMBOL vmlinux 0xc14d3a82	kill_pid
++EXPORT_SYMBOL vmlinux 0xc15a44c6	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xc169cdd1	nd_region_to_nstype
++EXPORT_SYMBOL vmlinux 0xc1948d3b	icmp_send
++EXPORT_SYMBOL vmlinux 0xc1966d8d	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0xc1a6c8db	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0xc1b4bff0	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xc1badf39	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0xc1bbaf6f	nvdimm_namespace_common_probe
++EXPORT_SYMBOL vmlinux 0xc1bd6fed	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1e416f8	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc1f5cc24	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0xc21a044b	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0xc2291c7f	dev_activate
++EXPORT_SYMBOL vmlinux 0xc249f4ab	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0xc26194d2	amba_driver_register
++EXPORT_SYMBOL vmlinux 0xc286055c	pnp_unregister_card_driver
++EXPORT_SYMBOL vmlinux 0xc286f194	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0xc29bf967	strspn
++EXPORT_SYMBOL vmlinux 0xc2a227cc	skb_checksum
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2af3120	nla_append
++EXPORT_SYMBOL vmlinux 0xc2bc0315	neigh_table_init
++EXPORT_SYMBOL vmlinux 0xc2bc120e	dev_notice
++EXPORT_SYMBOL vmlinux 0xc2d5724a	phy_device_free
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc2ff2f00	dquot_destroy
++EXPORT_SYMBOL vmlinux 0xc2ff86a6	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0xc30622a6	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0xc30c4b4f	__brelse
++EXPORT_SYMBOL vmlinux 0xc310b981	strnstr
++EXPORT_SYMBOL vmlinux 0xc310daf8	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0xc3674f5c	netif_device_attach
++EXPORT_SYMBOL vmlinux 0xc36a629d	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0xc3735914	tcp_req_err
++EXPORT_SYMBOL vmlinux 0xc37a4dfc	nvm_register_target
++EXPORT_SYMBOL vmlinux 0xc3a7be25	lg_global_lock
++EXPORT_SYMBOL vmlinux 0xc3bebaca	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0xc3c27b73	sync_filesystem
++EXPORT_SYMBOL vmlinux 0xc3c28af2	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3d74204	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0xc3deb75c	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0xc418fcb4	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0xc4542d54	of_clk_get
++EXPORT_SYMBOL vmlinux 0xc459e847	phy_start
++EXPORT_SYMBOL vmlinux 0xc47f10b9	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0xc47fd8e8	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0xc48307db	lz4_decompress
++EXPORT_SYMBOL vmlinux 0xc484556e	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0xc4973907	param_get_byte
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4cc7ffb	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0xc4dad695	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0xc4f629d9	save_mount_options
++EXPORT_SYMBOL vmlinux 0xc540fff3	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0xc5434ea4	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0xc568717c	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0xc56be5fe	acpi_pm_device_run_wake
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc59a990a	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0xc59b00fc	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0xc5df7be6	kernel_read
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc6133ddd	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc63785fa	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0xc65b7f2f	simple_lookup
++EXPORT_SYMBOL vmlinux 0xc666a132	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xc6746eb5	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0xc6772da2	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xc699d625	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0xc6b368d3	acpi_gpe_count
++EXPORT_SYMBOL vmlinux 0xc6cb465a	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6fc461b	generic_fillattr
++EXPORT_SYMBOL vmlinux 0xc705ad6a	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc72cdfe5	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0xc734490e	of_get_cpu_node
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc7591cf0	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0xc7712347	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0xc77248f3	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0xc779b90e	init_buffer
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc78463ac	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc78ceec7	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0xc7975aa8	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc79f8743	compat_ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7c6fa1a	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0xc7db968b	tcp_connect
++EXPORT_SYMBOL vmlinux 0xc7ed42f3	of_graph_get_endpoint_by_regs
++EXPORT_SYMBOL vmlinux 0xc7f00777	brioctl_set
++EXPORT_SYMBOL vmlinux 0xc7f53385	get_phy_device
++EXPORT_SYMBOL vmlinux 0xc7fcc5bf	acpi_resource_to_address64
++EXPORT_SYMBOL vmlinux 0xc8009348	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0xc800ff28	seq_pad
++EXPORT_SYMBOL vmlinux 0xc803ad48	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0xc8163153	__register_binfmt
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc83eba65	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0xc83f5cfc	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc866cb17	tty_set_operations
++EXPORT_SYMBOL vmlinux 0xc869c221	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc877f3aa	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc89f79d4	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8ad1169	acpi_processor_register_performance
++EXPORT_SYMBOL vmlinux 0xc8b46863	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8b8dd55	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0xc8cd7466	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0xc8da3314	get_super
++EXPORT_SYMBOL vmlinux 0xc8e37178	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0xc8effc88	mntput
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc913b690	new_inode
++EXPORT_SYMBOL vmlinux 0xc91b12cd	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0xc92ec61e	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0xc931df2e	skb_dequeue
++EXPORT_SYMBOL vmlinux 0xc93f8dd7	make_kgid
++EXPORT_SYMBOL vmlinux 0xc952b0b2	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc96b03ca	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0xc978479a	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xc98514f4	bio_reset
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc9a0a53b	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0xc9a0a580	poll_initwait
++EXPORT_SYMBOL vmlinux 0xc9a51f61	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0xc9a9b081	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0xc9aba090	skb_unlink
++EXPORT_SYMBOL vmlinux 0xc9b19192	downgrade_write
++EXPORT_SYMBOL vmlinux 0xc9b3b637	dev_uc_del
++EXPORT_SYMBOL vmlinux 0xc9d15de9	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0xc9ed60ca	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0xc9f29f13	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0xc9f6235d	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0xc9f73e62	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0xca0ca571	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca2d3919	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0xca2ff204	down_read
++EXPORT_SYMBOL vmlinux 0xca406537	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0xca54052f	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0xca5ee09a	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0xca6c8a60	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0xca757005	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0xca7b34d7	vme_irq_request
++EXPORT_SYMBOL vmlinux 0xca832efe	kmalloc_order
++EXPORT_SYMBOL vmlinux 0xca8acc78	acpi_dbg_level
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xca9523f0	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0xcabc7888	idr_is_empty
++EXPORT_SYMBOL vmlinux 0xcabdef2b	clkdev_drop
++EXPORT_SYMBOL vmlinux 0xcad47639	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0xcadd12ab	mount_ns
++EXPORT_SYMBOL vmlinux 0xcaf13b5a	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0xcaf1b455	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcafaff05	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb095c69	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0xcb128141	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0xcb2acace	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0xcb358b71	param_ops_int
++EXPORT_SYMBOL vmlinux 0xcb3721fc	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0xcb4dac73	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0xcb4e4edc	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0xcb604f3c	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0xcb733bf2	acpi_bus_set_power
++EXPORT_SYMBOL vmlinux 0xcb76aefb	km_state_notify
++EXPORT_SYMBOL vmlinux 0xcb7fd82b	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0xcb936989	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcbae6c7a	acpi_lid_notifier_unregister
++EXPORT_SYMBOL vmlinux 0xcbbbc43a	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbed6894	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0xcbff5e68	mempool_create
++EXPORT_SYMBOL vmlinux 0xcc047754	iov_iter_init
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc440f28	dst_alloc
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc59637f	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0xcc6d8844	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0xcc73d9a4	user_path_create
++EXPORT_SYMBOL vmlinux 0xcc7482d0	d_lookup
++EXPORT_SYMBOL vmlinux 0xcc856d88	nf_log_trace
++EXPORT_SYMBOL vmlinux 0xcc8d3f4f	acpi_os_execute
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccfd3b46	__pagevec_release
++EXPORT_SYMBOL vmlinux 0xcd114f1f	tty_hangup
++EXPORT_SYMBOL vmlinux 0xcd20667a	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd44da04	clk_add_alias
++EXPORT_SYMBOL vmlinux 0xcd4fa5ca	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0xcd52b447	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0xcd57f7b0	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0xcd6f8828	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0xcd935a8d	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0xcd994293	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdc46ea8	vfs_fsync
++EXPORT_SYMBOL vmlinux 0xcdebeb24	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0xcded9fa9	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0xcdfad0c1	of_translate_address
++EXPORT_SYMBOL vmlinux 0xce0e2d66	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xce150fa9	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0xce195031	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0xce1a23f2	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce308228	pci_bus_put
++EXPORT_SYMBOL vmlinux 0xce3dbc57	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0xce41c600	d_delete
++EXPORT_SYMBOL vmlinux 0xce45d41d	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0xce4904a4	acpi_leave_sleep_state
++EXPORT_SYMBOL vmlinux 0xce4c636b	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0xce4e47b6	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0xce58f6e1	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce772fec	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0xce7850e1	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0xce99e6b0	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0xcea67e78	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0xcea6f151	backlight_force_update
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xceae504f	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0xceb1717d	completion_done
++EXPORT_SYMBOL vmlinux 0xcec96ad8	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0xcecc98e0	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0xcee4dfc9	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcefdf2ec	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0xcf0243b4	wake_up_process
++EXPORT_SYMBOL vmlinux 0xcf058146	elv_rb_find
++EXPORT_SYMBOL vmlinux 0xcf5a32d6	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0xcf63d2dd	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0xcf6b27e9	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0xcf7a1185	d_instantiate
++EXPORT_SYMBOL vmlinux 0xcf7b720d	__sock_create
++EXPORT_SYMBOL vmlinux 0xcf87ef12	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0xcf8f6d16	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0xcfa460f8	file_open_root
++EXPORT_SYMBOL vmlinux 0xcfad823c	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0xcfae9b91	ping_prot
++EXPORT_SYMBOL vmlinux 0xcfb4a296	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0xcfc69f7a	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0xcff0f5dc	netif_skb_features
++EXPORT_SYMBOL vmlinux 0xd0086627	vme_master_request
++EXPORT_SYMBOL vmlinux 0xd0312db3	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0xd0511ee9	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0xd0530dfd	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0xd0587156	genphy_read_status
++EXPORT_SYMBOL vmlinux 0xd06380e6	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd0721297	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0xd072b6b4	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0xd08f6239	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xd0963ad4	pipe_lock
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0b5c2bb	of_graph_get_remote_port_parent
++EXPORT_SYMBOL vmlinux 0xd0d10e0b	blk_rq_init
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0f5c49b	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd1033632	netdev_emerg
++EXPORT_SYMBOL vmlinux 0xd138dd08	fb_get_mode
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd1615e23	seq_escape
++EXPORT_SYMBOL vmlinux 0xd1652a93	acpi_info
++EXPORT_SYMBOL vmlinux 0xd178ff70	vm_stat
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd1898b27	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0xd18ff827	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0xd1aeffb6	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1e9c401	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0xd1ebd536	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0xd1f7e61c	vm_mmap
++EXPORT_SYMBOL vmlinux 0xd2148a16	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xd225a785	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0xd22d682e	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0xd24260ca	of_phy_attach
++EXPORT_SYMBOL vmlinux 0xd24ba4c1	fence_free
++EXPORT_SYMBOL vmlinux 0xd24db1d3	account_page_redirty
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd25e16e3	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd2916290	km_report
++EXPORT_SYMBOL vmlinux 0xd2b09ce5	__kmalloc
++EXPORT_SYMBOL vmlinux 0xd2d03845	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd31ccb06	of_machine_is_compatible
++EXPORT_SYMBOL vmlinux 0xd3259d65	test_and_set_bit
++EXPORT_SYMBOL vmlinux 0xd3559ef4	__memset
++EXPORT_SYMBOL vmlinux 0xd358fe3c	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0xd36e3d59	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0xd3935074	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0xd3a78b6e	sock_register
++EXPORT_SYMBOL vmlinux 0xd3b12742	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0xd3b28225	netif_napi_add
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3c0c411	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0xd3f25734	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0xd3fd1d44	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0xd40faee5	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0xd41fe818	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xd43baa60	param_get_long
++EXPORT_SYMBOL vmlinux 0xd44995eb	nd_integrity_init
++EXPORT_SYMBOL vmlinux 0xd45cc6ca	bin2hex
++EXPORT_SYMBOL vmlinux 0xd46a7e94	dget_parent
++EXPORT_SYMBOL vmlinux 0xd46dcb72	set_disk_ro
++EXPORT_SYMBOL vmlinux 0xd4835ef8	dmi_check_system
++EXPORT_SYMBOL vmlinux 0xd48fae42	simple_release_fs
++EXPORT_SYMBOL vmlinux 0xd48fdeef	dql_completed
++EXPORT_SYMBOL vmlinux 0xd496e435	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0xd49a565c	igrab
++EXPORT_SYMBOL vmlinux 0xd49e9450	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0xd4a53a0a	__invalidate_device
++EXPORT_SYMBOL vmlinux 0xd4c3fefb	inet_select_addr
++EXPORT_SYMBOL vmlinux 0xd4c9f53f	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0xd4cf4db0	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0xd4d7bd47	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0xd4e7aa3d	ioremap_cache
++EXPORT_SYMBOL vmlinux 0xd50cd0e6	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0xd50fef48	acpi_detach_data
++EXPORT_SYMBOL vmlinux 0xd5107f2a	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0xd521bc11	pnpacpi_protocol
++EXPORT_SYMBOL vmlinux 0xd53b1f28	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0xd53e7d76	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd54fedc2	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0xd560ab35	dump_align
++EXPORT_SYMBOL vmlinux 0xd5692116	sock_i_uid
++EXPORT_SYMBOL vmlinux 0xd569703c	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0xd56f9fd3	skb_copy
++EXPORT_SYMBOL vmlinux 0xd5753c26	pci_disable_device
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd5bbdf3d	genphy_suspend
++EXPORT_SYMBOL vmlinux 0xd5c11790	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0xd5c18e13	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0xd5d2e9a2	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0xd5dcdd59	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0xd5eeb682	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0xd5f84369	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0xd600cdf4	eth_header_parse
++EXPORT_SYMBOL vmlinux 0xd600e307	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0xd60d01fb	kill_anon_super
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd62d6977	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0xd632d73a	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0xd63c0398	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd649f89f	led_blink_set
++EXPORT_SYMBOL vmlinux 0xd655f199	acpi_processor_preregister_performance
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd6cda4e2	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0xd6d8d162	kmem_cache_alloc_node_trace
++EXPORT_SYMBOL vmlinux 0xd6ea832d	simple_empty
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd729cd4c	path_put
++EXPORT_SYMBOL vmlinux 0xd729eb66	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0xd7426c99	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd75d1aa3	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0xd7a640ca	arp_tbl
++EXPORT_SYMBOL vmlinux 0xd7bfaae3	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0xd7d98900	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0xd7daa5d5	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0xd7e236b8	of_get_pci_address
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd7fdc645	pipe_unlock
++EXPORT_SYMBOL vmlinux 0xd824f53b	of_find_compatible_node
++EXPORT_SYMBOL vmlinux 0xd840459c	dev_driver_string
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a597f9	__get_user_pages
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8acdf28	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0xd8b124f2	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0xd8be2b1f	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0xd8d939bc	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd8fec09e	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xd901a34b	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0xd907ac27	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0xd9091363	acpi_install_notify_handler
++EXPORT_SYMBOL vmlinux 0xd9108fdf	clear_inode
++EXPORT_SYMBOL vmlinux 0xd92a9785	kernel_accept
++EXPORT_SYMBOL vmlinux 0xd92afb55	of_clk_get_by_name
++EXPORT_SYMBOL vmlinux 0xd9399c28	mdiobus_read
++EXPORT_SYMBOL vmlinux 0xd94279cd	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0xd94322e7	acpi_evaluate_reference
++EXPORT_SYMBOL vmlinux 0xd9468197	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0xd9586a12	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0xd9681e76	blk_peek_request
++EXPORT_SYMBOL vmlinux 0xd96c6ed7	vga_tryget
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd9b549e2	__nd_iostat_start
++EXPORT_SYMBOL vmlinux 0xd9c7f0cf	soft_cursor
++EXPORT_SYMBOL vmlinux 0xd9d88441	__vfs_write
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9e0d174	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0xd9e8b176	seq_puts
++EXPORT_SYMBOL vmlinux 0xd9f33fcf	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0xda01479c	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xda124963	kernel_connect
++EXPORT_SYMBOL vmlinux 0xda28f7ac	seq_dentry
++EXPORT_SYMBOL vmlinux 0xda38fb06	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda54091b	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0xda7647ac	security_path_symlink
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda8ffdaa	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0xda9fc7ae	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0xdac236e7	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdad69f38	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0xdaea6e0d	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0xdb2bfce0	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0xdb395f78	inet6_release
++EXPORT_SYMBOL vmlinux 0xdb3bcca6	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0xdb4469f5	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0xdb4a0051	led_update_brightness
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb6febad	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0xdb7305a1	__stack_chk_fail
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdbbc18cb	pnp_activate_dev
++EXPORT_SYMBOL vmlinux 0xdc03ab85	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc1b54d5	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0xdc2640a6	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0xdc3c41a8	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc4ea282	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdcb764ad	memset
++EXPORT_SYMBOL vmlinux 0xdcc0b004	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0xdcc1cf02	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0xdcd6bd76	of_get_mac_address
++EXPORT_SYMBOL vmlinux 0xdceda190	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0xdcf3ea11	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0xdcf43861	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0xdd0cc37b	wireless_send_event
++EXPORT_SYMBOL vmlinux 0xdd0e7941	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0xdd3b9ebb	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0xdd4859e4	phys_mem_access_prot
++EXPORT_SYMBOL vmlinux 0xdd5a3b6b	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0xdd64e639	strscpy
++EXPORT_SYMBOL vmlinux 0xdd7a1a2b	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0xdd7b1ce1	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0xdd82a139	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0xdd98e3b2	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0xdd9be6b1	iget5_locked
++EXPORT_SYMBOL vmlinux 0xddc999b4	sock_no_bind
++EXPORT_SYMBOL vmlinux 0xddd44680	security_inode_permission
++EXPORT_SYMBOL vmlinux 0xddf3e254	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0xde2317e2	compat_sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0xde434656	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0xde47aeb6	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0xde5cc2a6	put_disk
++EXPORT_SYMBOL vmlinux 0xde6151db	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xde79d6f0	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0xde80a735	devm_memremap
++EXPORT_SYMBOL vmlinux 0xde8a3918	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde977239	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0xdea57829	compat_nf_setsockopt
++EXPORT_SYMBOL vmlinux 0xdec61345	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0xdefe30f1	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0xdf00fe24	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0xdf0d5a63	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0xdf0da3cc	acpi_get_devices
++EXPORT_SYMBOL vmlinux 0xdf12a927	acpi_check_dsm
++EXPORT_SYMBOL vmlinux 0xdf230cf0	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf5c288c	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf76c3b2	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0xdf8c695a	__ndelay
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdfab8b1c	xfrm_input
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xe000e63f	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0xe031c235	netdev_notice
++EXPORT_SYMBOL vmlinux 0xe0326c0b	node_data
++EXPORT_SYMBOL vmlinux 0xe0438a25	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0xe0444878	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe068f910	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xe06f04d8	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe083e3a8	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe08ec1cf	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xe09aa2a9	key_link
++EXPORT_SYMBOL vmlinux 0xe0ac8bd2	acpi_bus_generate_netlink_event
++EXPORT_SYMBOL vmlinux 0xe0aec74c	nvdimm_bus_unlock
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0c10c92	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0xe1005c17	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0xe1041b4f	md_done_sync
++EXPORT_SYMBOL vmlinux 0xe110189e	ida_pre_get
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe11a23e8	pci_map_rom
++EXPORT_SYMBOL vmlinux 0xe11f3cbc	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0xe12dfd38	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe13cd8a7	dmi_name_in_vendors
++EXPORT_SYMBOL vmlinux 0xe162b329	__frontswap_load
++EXPORT_SYMBOL vmlinux 0xe1727117	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe1763885	__devm_request_region
++EXPORT_SYMBOL vmlinux 0xe17c5953	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0xe187871a	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0xe19c5d82	bio_put
++EXPORT_SYMBOL vmlinux 0xe1aabded	tty_do_resize
++EXPORT_SYMBOL vmlinux 0xe1b0f928	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0xe1b5fe84	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0xe1b940ec	serio_open
++EXPORT_SYMBOL vmlinux 0xe1d65576	vfs_symlink
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe20372ae	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0xe225b677	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe2492db0	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe2628761	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xe2684593	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0xe278468c	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0xe27f88cd	skb_store_bits
++EXPORT_SYMBOL vmlinux 0xe294f814	devm_release_resource
++EXPORT_SYMBOL vmlinux 0xe29b83ab	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2c1a315	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe310ce39	generic_writepages
++EXPORT_SYMBOL vmlinux 0xe317764d	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0xe319eb24	acpi_pci_osc_control_set
++EXPORT_SYMBOL vmlinux 0xe34f0b92	simple_readpage
++EXPORT_SYMBOL vmlinux 0xe3647862	mapping_tagged
++EXPORT_SYMBOL vmlinux 0xe36f8cc9	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0xe383b8fc	__skb_checksum
++EXPORT_SYMBOL vmlinux 0xe3a53f4c	sort
++EXPORT_SYMBOL vmlinux 0xe3acd102	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0xe3ae1bb6	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3c4c2c6	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe422bbd0	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0xe449a081	lock_fb_info
++EXPORT_SYMBOL vmlinux 0xe44a9b40	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0xe45aad4e	dev_mc_del
++EXPORT_SYMBOL vmlinux 0xe48291f0	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xe497d75e	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xe4a47b15	napi_get_frags
++EXPORT_SYMBOL vmlinux 0xe4a48890	md_flush_request
++EXPORT_SYMBOL vmlinux 0xe4a81788	dev_change_flags
++EXPORT_SYMBOL vmlinux 0xe4bb20d2	read_code
++EXPORT_SYMBOL vmlinux 0xe4e31f47	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe4eaab2e	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0xe4f11bb7	d_move
++EXPORT_SYMBOL vmlinux 0xe4f3017d	serio_bus
++EXPORT_SYMBOL vmlinux 0xe505969c	vfs_llseek
++EXPORT_SYMBOL vmlinux 0xe51487cf	padata_alloc
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe52ab7a8	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0xe5514d51	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe5a0a3e2	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0xe5b36734	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5e4773c	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe5f69788	udp_disconnect
++EXPORT_SYMBOL vmlinux 0xe6318d8e	__page_cache_alloc
++EXPORT_SYMBOL vmlinux 0xe65a73d7	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xe660c4f7	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0xe66286c5	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0xe667067f	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0xe6700597	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0xe67bd7fe	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe69a9df4	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xe6bc0a20	mdiobus_write
++EXPORT_SYMBOL vmlinux 0xe6ddad02	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0xe6e3f53e	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe70235e7	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0xe706d5ad	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0xe7235b2d	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0xe725eda0	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0xe7353072	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0xe74ba8d3	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xe764ef56	kill_pgrp
++EXPORT_SYMBOL vmlinux 0xe7655dba	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xe78bd45d	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xe79b55b2	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0xe7a07c06	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7e751f8	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0xe7f8230b	__genl_register_family
++EXPORT_SYMBOL vmlinux 0xe8088ea5	f_setown
++EXPORT_SYMBOL vmlinux 0xe81b9305	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0xe81ef1dd	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xe81ffd6b	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe84096c9	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0xe843de9f	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe87d259f	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0xe87e9ea2	dma_mmap_from_coherent
++EXPORT_SYMBOL vmlinux 0xe8844ba7	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0xe8855b3b	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0xe8a16f88	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8b67c95	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8cf6615	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0xe8e74e0c	tty_devnum
++EXPORT_SYMBOL vmlinux 0xe8ef0ff0	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0xe90ddc5e	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0xe912dafe	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe92368f6	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0xe93deec5	proto_register
++EXPORT_SYMBOL vmlinux 0xe9424aa7	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe95e00cf	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0xe975274b	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xe97e5df2	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0xe97ea521	skb_push
++EXPORT_SYMBOL vmlinux 0xe98e2faf	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0xe9986ef6	xattr_full_name
++EXPORT_SYMBOL vmlinux 0xe99bc786	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0xe9b68e0b	release_pages
++EXPORT_SYMBOL vmlinux 0xe9bbfb6f	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0xe9d4adfe	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xe9f8beb1	of_get_address
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea63858c	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0xea7a42f9	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xea7b8a44	acpi_install_interface
++EXPORT_SYMBOL vmlinux 0xea90bdd3	acpi_attach_data
++EXPORT_SYMBOL vmlinux 0xea928efe	d_splice_alias
++EXPORT_SYMBOL vmlinux 0xea96805f	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0xeaa15c51	nvdimm_revalidate_disk
++EXPORT_SYMBOL vmlinux 0xeabcddb6	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0xeacc06f7	fence_signal
++EXPORT_SYMBOL vmlinux 0xeae3dfd6	__const_udelay
++EXPORT_SYMBOL vmlinux 0xeae760f0	devm_clk_get
++EXPORT_SYMBOL vmlinux 0xeb1949a5	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0xeb264670	acl_by_type
++EXPORT_SYMBOL vmlinux 0xeb363c09	pnp_unregister_driver
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb44339a	free_pages_exact
++EXPORT_SYMBOL vmlinux 0xeb603e21	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0xeb6bb9b2	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0xeb960183	generic_read_dir
++EXPORT_SYMBOL vmlinux 0xeba1d5a7	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0xebc3ff4e	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0xebc40c3a	param_ops_bint
++EXPORT_SYMBOL vmlinux 0xebc7bb37	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0xebc8c59a	vfs_readv
++EXPORT_SYMBOL vmlinux 0xebd7aa9e	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0xebe1ef21	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0xebf90d6f	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xebfe978d	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0xec1133be	bdgrab
++EXPORT_SYMBOL vmlinux 0xec20411b	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0xec3ae04f	dma_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec61626d	kset_unregister
++EXPORT_SYMBOL vmlinux 0xec756806	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0xeca22695	dquot_drop
++EXPORT_SYMBOL vmlinux 0xeca632e7	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0xecb46636	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0xecbbf490	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xeccd3e0c	acpi_handle_printk
++EXPORT_SYMBOL vmlinux 0xecdc392c	mmc_free_host
++EXPORT_SYMBOL vmlinux 0xece34b94	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xecf1b770	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0xecf23fab	proto_unregister
++EXPORT_SYMBOL vmlinux 0xecf92fb7	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0xed05da22	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0xed076f70	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0xed11a98d	posix_test_lock
++EXPORT_SYMBOL vmlinux 0xed11f6ca	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0xed41e3b8	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0xed433664	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed5a3241	neigh_xmit
++EXPORT_SYMBOL vmlinux 0xed8694b7	neigh_destroy
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc2ac52	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0xedc30bed	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xee032596	freeze_bdev
++EXPORT_SYMBOL vmlinux 0xee09d342	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0xee24efc3	phy_device_register
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee32de34	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0xee3e5e4e	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xee43b816	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xee4e633f	follow_down
++EXPORT_SYMBOL vmlinux 0xee6167d0	sock_release
++EXPORT_SYMBOL vmlinux 0xee7eb9e1	pnp_platform_devices
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xee97678e	inet_addr_type
++EXPORT_SYMBOL vmlinux 0xeea3cd7a	nla_reserve
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeeb4ef4e	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0xeebe1ec5	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0xeec2c7cf	ucs2_as_utf8
++EXPORT_SYMBOL vmlinux 0xeec8de0d	of_match_device
++EXPORT_SYMBOL vmlinux 0xeeee5e88	of_phy_is_fixed_link
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xeef23851	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0xef0933d9	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0xef0a2e6e	elv_rb_add
++EXPORT_SYMBOL vmlinux 0xef56a03c	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0xef8a5cf0	generic_write_checks
++EXPORT_SYMBOL vmlinux 0xef8df7a9	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0xefa165ce	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefe7132f	__quota_error
++EXPORT_SYMBOL vmlinux 0xeff72ea5	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0xeffb2242	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xefffcaad	skb_append
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf0066c75	arp_send
++EXPORT_SYMBOL vmlinux 0xf014d94f	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0xf0155e4a	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf0303e19	read_cache_pages
++EXPORT_SYMBOL vmlinux 0xf036ebea	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0xf0542112	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf062576b	ucs2_utf8size
++EXPORT_SYMBOL vmlinux 0xf06c8b3c	_dev_info
++EXPORT_SYMBOL vmlinux 0xf070159d	amba_driver_unregister
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf0915de8	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0xf0972a3a	bmap
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0a27b87	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0xf0a8237a	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xf0d6fa00	fb_show_logo
++EXPORT_SYMBOL vmlinux 0xf0d7a187	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf0f339e2	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0xf0f78887	udp_del_offload
++EXPORT_SYMBOL vmlinux 0xf102b5cc	dquot_commit
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf11316e1	alloc_file
++EXPORT_SYMBOL vmlinux 0xf122f68c	of_device_is_big_endian
++EXPORT_SYMBOL vmlinux 0xf135cf6e	first_ec
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf157e1bb	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0xf1655704	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0xf1720e8d	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf1baa94c	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0xf1bda30d	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0xf1c0b299	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0xf1c2bed9	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0xf1c2c922	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1ee6a07	vfs_readf
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf217726d	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf24717c9	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0xf25170b2	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0xf26039e7	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0xf2793eb0	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0xf27ec4dd	skb_pull
++EXPORT_SYMBOL vmlinux 0xf28b68c3	seq_vprintf
++EXPORT_SYMBOL vmlinux 0xf2996278	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf2a0459d	lg_local_lock
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2a2b163	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0xf2b7ebdc	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2ed5d7f	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0xf312cb9d	ucs2_strsize
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf32eefe3	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf3343cef	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf37d3499	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf3986b06	acpi_os_map_generic_address
++EXPORT_SYMBOL vmlinux 0xf39d52cb	skb_put
++EXPORT_SYMBOL vmlinux 0xf39da3da	of_get_child_by_name
++EXPORT_SYMBOL vmlinux 0xf3a3b25c	phy_suspend
++EXPORT_SYMBOL vmlinux 0xf3a426a4	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0xf3b0b01d	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0xf3ca109d	simple_rename
++EXPORT_SYMBOL vmlinux 0xf3e24395	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf4584828	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xf466f4b8	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf4835f92	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xf484f8f8	invalidate_partition
++EXPORT_SYMBOL vmlinux 0xf495a686	pci_pme_active
++EXPORT_SYMBOL vmlinux 0xf4b754fd	acpi_resources_are_enforced
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4e3e068	mount_subtree
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf51bf88b	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xf5309e79	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf552eff9	mpage_readpage
++EXPORT_SYMBOL vmlinux 0xf55440d9	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xf559d050	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL vmlinux 0xf5b6e9d2	mmc_request_done
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5d45448	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf6034709	ata_print_version
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf63b5ca3	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0xf6598537	tty_write_room
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf694e92a	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0xf6b6cfe3	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0xf6b8cc21	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6bc57ef	iterate_dir
++EXPORT_SYMBOL vmlinux 0xf6c913fa	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0xf6daac51	d_tmpfile
++EXPORT_SYMBOL vmlinux 0xf6e0fa06	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0xf6e8ee98	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6f0ffed	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf725acb4	d_obtain_root
++EXPORT_SYMBOL vmlinux 0xf737765c	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf77555cd	__memcpy_toio
++EXPORT_SYMBOL vmlinux 0xf78992c3	consume_skb
++EXPORT_SYMBOL vmlinux 0xf790c4d6	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xf79e97cd	acpi_get_physical_device_location
++EXPORT_SYMBOL vmlinux 0xf79ebaab	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0xf7b0695a	mem_section
++EXPORT_SYMBOL vmlinux 0xf7cc6375	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0xf7d4f18f	kfree_skb
++EXPORT_SYMBOL vmlinux 0xf7dedad8	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf812cff6	memscan
++EXPORT_SYMBOL vmlinux 0xf819ec4c	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0xf8252fc0	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf835b60c	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0xf839382d	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0xf8507e78	mmc_erase
++EXPORT_SYMBOL vmlinux 0xf85a5c1f	pnp_request_card_device
++EXPORT_SYMBOL vmlinux 0xf87450d0	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0xf883c215	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0xf88597be	param_set_short
++EXPORT_SYMBOL vmlinux 0xf8885aef	param_get_ullong
++EXPORT_SYMBOL vmlinux 0xf88c900f	kobject_set_name
++EXPORT_SYMBOL vmlinux 0xf88e0ee2	acpi_get_table_header
++EXPORT_SYMBOL vmlinux 0xf8924ff4	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0xf89620a0	__scm_destroy
++EXPORT_SYMBOL vmlinux 0xf89e97d4	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0xf8abe649	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0xf8bf7ddc	nf_log_set
++EXPORT_SYMBOL vmlinux 0xf8d049ab	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0xf8d04f09	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0xf8d4f343	__lock_buffer
++EXPORT_SYMBOL vmlinux 0xf8e398fc	memstart_addr
++EXPORT_SYMBOL vmlinux 0xf8ea63a6	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf8f0d8c7	mount_nodev
++EXPORT_SYMBOL vmlinux 0xf8f892c2	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0xf916e181	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0xf92f5b9f	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0xf93136d1	udp_seq_open
++EXPORT_SYMBOL vmlinux 0xf93218d0	dma_release_declared_memory
++EXPORT_SYMBOL vmlinux 0xf93e25f1	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0xf956c339	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0xf96fdbdd	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0xf9702a1a	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xf971b318	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0xf9753e05	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0xf9836f56	i2c_transfer
++EXPORT_SYMBOL vmlinux 0xf9848c65	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0xf989b2c5	blk_put_queue
++EXPORT_SYMBOL vmlinux 0xf992ffa6	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0xf99ef5d1	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0xf9a2dde0	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9a5373e	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0xf9b55e13	param_ops_byte
++EXPORT_SYMBOL vmlinux 0xf9c0b663	strlcat
++EXPORT_SYMBOL vmlinux 0xf9d4997a	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0xf9dde891	wait_for_completion
++EXPORT_SYMBOL vmlinux 0xf9e01863	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0xf9e31d32	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0xf9edc4f9	import_iovec
++EXPORT_SYMBOL vmlinux 0xf9f741af	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0xf9fac1b2	I_BDEV
++EXPORT_SYMBOL vmlinux 0xf9fbe6d1	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0xfa47465f	ida_simple_get
++EXPORT_SYMBOL vmlinux 0xfa50951f	of_find_node_by_type
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa53ecad	vme_slot_num
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa5e36ee	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0xfa5f8ca2	dquot_file_open
++EXPORT_SYMBOL vmlinux 0xfa60a8e2	proc_set_user
++EXPORT_SYMBOL vmlinux 0xfa7633f8	pci_restore_state
++EXPORT_SYMBOL vmlinux 0xfa843739	kern_unmount
++EXPORT_SYMBOL vmlinux 0xfaa9c280	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xfad57702	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xfadc06c5	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfaf4ee9e	nvdimm_namespace_capacity
++EXPORT_SYMBOL vmlinux 0xfafca23d	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0xfb0443fb	acpi_get_parent
++EXPORT_SYMBOL vmlinux 0xfb103f99	devm_clk_put
++EXPORT_SYMBOL vmlinux 0xfb106721	filp_close
++EXPORT_SYMBOL vmlinux 0xfb12406e	tso_start
++EXPORT_SYMBOL vmlinux 0xfb136a02	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0xfb1e660a	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0xfb2b6b9f	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0xfb5d890e	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb80c7a0	acpi_walk_namespace
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfb95e472	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0xfba2108b	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbe8ff5e	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc0cb047	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0xfc0e8c64	acpi_pm_device_sleep_state
++EXPORT_SYMBOL vmlinux 0xfc48db8f	amba_device_unregister
++EXPORT_SYMBOL vmlinux 0xfc4b6d0a	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0xfc52047f	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0xfc772238	kobject_init
++EXPORT_SYMBOL vmlinux 0xfc849c1d	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0xfc8dfe35	setup_new_exec
++EXPORT_SYMBOL vmlinux 0xfc8ecce4	cad_pid
++EXPORT_SYMBOL vmlinux 0xfc9ce196	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0xfca4b754	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0xfca6db10	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0xfcac0d40	acpi_install_interface_handler
++EXPORT_SYMBOL vmlinux 0xfcb926cd	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcf412af	component_match_add
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfcfecaf3	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0xfd3540f0	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0xfd7d2f14	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0xfd7fd50f	nf_afinfo
++EXPORT_SYMBOL vmlinux 0xfd863ef8	kill_litter_super
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfdf5f643	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfdffd458	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe047ce6	acpi_enter_sleep_state
++EXPORT_SYMBOL vmlinux 0xfe0edefe	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0xfe17047b	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xfe1fd55f	of_phy_find_device
++EXPORT_SYMBOL vmlinux 0xfe26fc7c	nr_node_ids
++EXPORT_SYMBOL vmlinux 0xfe5127ac	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe5e1cca	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0xfe7aca5d	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe832a45	security_file_permission
++EXPORT_SYMBOL vmlinux 0xfe83c112	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0xfe8f18cd	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0xfe916dc6	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xfe951f7c	set_blocksize
++EXPORT_SYMBOL vmlinux 0xfe9d54c5	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0xfe9ebbbb	acpi_osi_is_win8
++EXPORT_SYMBOL vmlinux 0xfeb696b1	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0xfebb2b52	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0xfec8dcfc	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfee33616	open_exec
++EXPORT_SYMBOL vmlinux 0xfeebc7c4	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0xff0471be	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0xff0b3d19	kthread_stop
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff1f60ad	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0xff256dbf	cdev_del
++EXPORT_SYMBOL vmlinux 0xff2a2fa6	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0xff3197f6	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff6e76a1	submit_bio
++EXPORT_SYMBOL vmlinux 0xff6f6d28	alloc_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff7cc786	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0xff7e15b6	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0xff8cd740	block_write_begin
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff90a205	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffc83b78	dev_crit
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xfffb1362	udplite_prot
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x0de87c6d	ablk_set_key
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x60d428b3	__ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x6aec89ba	ablk_exit
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x9614ba3b	ablk_init_common
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xc1f23811	ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xd0a09e44	ablk_decrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xe2abc0d7	ablk_init
++EXPORT_SYMBOL_GPL crypto/af_alg 0x157fd021	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x36dfbfd8	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0x373614f5	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x3a2af6d6	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x3adf1280	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x42449c9c	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0x5d7e28c3	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x9bd0baa0	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xae17ec44	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0xc6222c18	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0xcb39de78	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x97f55968	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0xb865c29a	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0xee295397	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0xca026a62	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0xd0c4fc6f	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x4aac0822	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x4d20b260	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x9ac66fc0	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xc75ff472	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x6ecbaf4c	async_xor_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0xf211e47a	async_xor
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0xd5926094	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x241be770	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x9769a386	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x7d90db70	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0xf9e66c25	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/cryptd 0x1334951a	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x18bee0ec	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x20fe9b70	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x2f59e28b	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x345ebc6a	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x386718c8	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x75a9c005	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xac57a7a9	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xb935f338	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xc5607d81	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0x83a493bb	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x25d4da0b	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x4877b10a	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x4cfb3c0a	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x69295d4e	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x756bb735	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x8347667c	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x9e28d4e8	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xe2a2f067	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xfed8d22e	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x62fea1a8	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x96d11d59	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xe8b43656	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xea686fe5	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0xb1472896	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x8f3a8b58	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0x73baa2ba	xts_crypt
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x1bea3038	ahci_host_activate
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x21faa853	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x27925e3b	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x494ba7fa	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x50a61451	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x54ff97ab	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x56274b4b	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x5909b328	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x618746a0	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x73f896cc	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x7459986f	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x76ee644a	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x79880c56	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x7eab1992	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x96d8d25a	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa0bbd397	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa8442870	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xac3af4c4	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xb44be916	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xb8c9e5dd	ahci_qc_issue
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xd1ef7165	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xdbf00951	ahci_error_handler
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf7863717	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x2e44502f	ahci_platform_suspend
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x36687cd7	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x3737776c	ahci_platform_resume_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x3b887ecb	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x707dd74b	ahci_platform_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x891b7ce7	ahci_platform_init_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x9b12a4ad	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xb11261b2	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xd074b507	ahci_platform_suspend_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xd0c76804	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xe5c2e08c	ahci_platform_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xeb5c4793	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xf7c0ac84	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0xfa1efe5c	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/ata/pata_sis 0xc88b537a	sis_info133_for_sata
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x35117f79	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xa7e9bf63	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xa9413c01	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xfeac6ea7	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x01e6c9fa	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1750233c	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x30e5745e	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x347318d0	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x35190218	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x364d6304	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x39276860	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3c19abf7	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x450964b8	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x47845b2f	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x58af2789	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x5cfd8629	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x5fafc343	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x85aa9c4d	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x89f44867	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x94c4e484	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x9d290491	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xa9395ca3	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc4b89843	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xda72a1eb	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdc6ef468	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe99bdc7f	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf07b5b26	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xfd250d3d	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x45734e8d	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x555a20c4	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x82b62931	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xc40b657a	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xc51e59c1	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xe467f053	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x0624f65b	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x0be26b21	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x48385cbf	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x4f924d67	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x92fcadc8	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xa7fb8afa	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xb72632fb	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xd2250a10	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xd2cd0494	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xe0eeb475	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xee9fde34	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xffe65509	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x21154027	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x3911b618	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x3d5b3e26	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x40b502a6	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x57695e25	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x59ac251f	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xa42c162a	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xb5cc1950	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xcbff133f	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xd6b0ff21	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xf66d4cef	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x4f10c1db	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0xb3709421	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0x9cbf04a7	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0x17268489	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x184703dc	qcom_cc_map
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x18c43deb	clk_is_enabled_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x1ad28e9c	clk_rcg_bypass_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x1f4159b0	clk_byte2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x3b0b58e5	clk_regmap_mux_closest_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x53f95e39	clk_pll_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x612214bd	clk_edp_pixel_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x669bd1fd	qcom_find_freq
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x67ae803a	clk_rcg_pixel_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x709d9cf0	clk_pll_configure_sr
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x73964fc2	clk_dyn_rcg_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x73b3f9cb	qcom_find_src_index
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x77c457fa	qcom_reset_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x77d31a97	devm_clk_register_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x8c4dbdbe	clk_branch_simple_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x8d53d96e	clk_rcg_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x90b53166	clk_pll_configure_sr_hpm_lp
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x95b69adf	qcom_cc_really_probe
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x999e1e71	clk_branch2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x99d2c773	clk_rcg2_shared_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x9e2e91a1	clk_rcg_bypass2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xaace56b1	clk_rcg_esc_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xb190ca1b	clk_enable_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xc7994798	clk_branch_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xcb0c5248	clk_byte_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xcd0a83c6	clk_rcg2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xd25fd154	clk_rcg_lcc_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xd5834229	clk_disable_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xe703bcad	clk_pll_vote_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xed2aa16c	qcom_cc_probe
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xf1f136dc	clk_pixel_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xf69c2f55	clk_pll_sr2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xf93e315f	clk_regmap_div_ops
++EXPORT_SYMBOL_GPL drivers/cpufreq/arm_big_little 0x29c20777	bL_cpufreq_unregister
++EXPORT_SYMBOL_GPL drivers/cpufreq/arm_big_little 0xe81a5cc8	bL_cpufreq_register
++EXPORT_SYMBOL_GPL drivers/crypto/ccp/ccp 0x04773b60	ccp_present
++EXPORT_SYMBOL_GPL drivers/crypto/ccp/ccp 0x1f486895	ccp_enqueue_cmd
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x0eaf186f	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x71018251	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x816feef7	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xdf986b01	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xe25e411a	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x01b6e398	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x18b7186a	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x59cabcda	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c75af1d	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x22c782c2	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x44463502	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x45697d44	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x5872b3e9	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x59840e97	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x5c74f48a	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6ceb4404	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x76102611	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7cf0a5ca	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7faa68ba	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x82054145	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x89a82246	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x90fd3957	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x9130d778	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x93a1b745	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xaf245b49	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb488f2f1	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb5b78fbb	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd9422738	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe0f3f343	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xeb33a276	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf94cd7fe	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/firmware/arm_scpi 0xe342fbf5	get_scpi_ops
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x07a2a8ef	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x1003790c	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x6846ac8f	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xd3434b12	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xee9a0540	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xfd365a17	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0xc263d331	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0xf4be044d	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x10b49e27	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x8d4c02dc	drm_display_mode_to_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xa1b94fbc	drm_display_mode_from_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xa833b3d5	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xcad3e1bc	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xed22a979	of_get_drm_display_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x3744e909	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x91a5ef3a	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xa23b471f	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x01eaa6c3	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0653d05d	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x084c05b4	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0ceb04f4	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0db5c6a7	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x216b8943	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x22f0f41a	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2965428c	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x298b8cf8	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2f2897ef	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2f37b55f	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x32354dd0	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x33dfc6f0	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x36576a29	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x372f3e64	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x38fe5193	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x44ef6e4d	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x468319dd	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4de2556a	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5047197d	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x697dd28d	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x746f65d9	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x77f404c2	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x88d8e84b	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x955d40c1	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9b0dd535	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa35d2174	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa55557b6	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xacb72838	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb030cfdb	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbec7e5b1	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc4270761	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd2542134	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd638ca51	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xdca6b2db	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xeb19a628	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x45c731b6	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x160c803a	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x23d9d22e	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x466cbafb	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x5c8ea18e	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xab0e7786	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xbed40f00	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x0081cbe3	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x0d4f5b36	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x20427b5e	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x20fcd54c	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x68b1fd8c	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x69d3c08c	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xb269cd7c	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xe0b21328	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xea2290dd	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x6b181db9	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x01435b04	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x09553a5a	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x21f583b2	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x2304e8c3	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x38fa43b9	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x3912c69e	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x3f19ba34	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x3f38bc03	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x59202e8f	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x97b51fb5	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x9b922748	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa1671e47	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa65ed36a	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc471f471	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc740de7e	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xd1514288	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xdac42fa7	hsi_add_clients_from_dt
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe21a9661	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xa8b91e16	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xb02a84ca	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xf71bdb80	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x076524af	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x2721ccff	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x2af66529	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x2f642720	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x4a013897	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x8b32106e	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x8dc9dbf8	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xa5b377a3	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xaf320c03	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xb214b8e9	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xc5ec6549	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xd1a458d7	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xe4ee9fa0	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xeba66ddf	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xfa1e18ec	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x077f03a5	hwspin_lock_register
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x121722e6	hwspin_lock_unregister
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x3490d54c	hwspin_lock_request_specific
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x4ad9b23b	hwspin_lock_get_id
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x4f95b0d8	__hwspin_trylock
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x861100c9	__hwspin_lock_timeout
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x991a32df	hwspin_lock_free
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0xcf1e9812	hwspin_lock_request
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0xd054c455	__hwspin_unlock
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0xe977b532	of_hwspin_lock_get_id
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x053cdd6a	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x12199842	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x1642c3de	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x206a86ca	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x6ed46691	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x92708b22	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xbb54ca2f	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x2ead4898	stm_source_write
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x671ced97	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x9320ec6b	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xc624a4bd	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xf16b26e7	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x1d069ddf	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x64949f09	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x7d2942b9	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xceec3a94	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xf230cabe	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x07027b57	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xcfd39942	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x1d937dc5	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x1f4607b3	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xaf13b2b7	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xcd1c74c5	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xfd4245e9	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x070c37ac	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x13429c4f	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x22b26633	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x4fdd357a	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x8902f8c4	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x989025f4	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xa20328ec	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xc004014f	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xe8adfb29	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xe9f2d1af	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x5ecbd11b	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x65923228	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xa6ee5af9	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xec2003a9	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x74319cf0	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xce7f0de4	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xee334c5e	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x0db3453a	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x1b0d55cf	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x52225f40	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x60a993b8	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x790d4825	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x938d0200	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x948c73fa	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xc0144e80	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xcae769cd	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xe3b16f21	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xf27aa65d	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xfdd8454f	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0313b25e	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x068bf5a1	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0a0aa067	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x132e471a	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x1843a6c2	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2d28f89d	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2e871f75	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3606b51c	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x36860813	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4bcc7e49	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x57db93f1	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5f591357	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x650ae2d3	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6dcd7dfc	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x8d73e9de	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x8de529e4	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x8e6c3afa	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x92a923ca	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa0bbac0e	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa8f16b15	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xab3cd0e5	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xabb84c94	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb3adaaa9	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb3bb4261	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xbaac9a3d	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd88cece6	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xde7e2e69	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xdfe9926c	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe2061f9c	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe221c725	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf531358f	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0x95ca0b0a	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/matrix-keymap 0xded35569	matrix_keypad_parse_of_params
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x834e429b	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x299e2897	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xab4a7d3b	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xd4a3d0fd	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x315e33f2	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x747e5313	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xf9492f3f	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x427f7084	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x782fc9b2	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x34ff9b92	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x540f0394	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xc1bd2fa3	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xcd301645	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x16f95168	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x19cea53b	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x26318c2f	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x3b8f9175	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x538d0f87	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x63bf3471	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x976ed078	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xb477ef21	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xe2483622	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xea9b8cb1	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xec2dddd1	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xef6807d8	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x26e98892	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x3b1b24aa	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x426ba147	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x5f01978f	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x8250d2ab	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x9e4467ad	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xae245f87	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xc48b766f	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xcc5cde01	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x042479bd	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x14d8b76c	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x1ea0bb7c	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x2a38895b	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x3cd05ab0	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x40dbe1be	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x40dd906a	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x5e8e62fe	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x6d1ac04d	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x78cc0a99	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x82c8bfd5	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa3151853	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa33c67ad	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc053d7d6	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc0bc7ec8	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc795421f	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xdf401399	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xee32fb3b	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x2fa1096e	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x5e7dfe01	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x731c121e	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x918dde43	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x9ab23920	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xa5d53c04	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x2566863c	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x3326a89d	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x36bbcb51	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x3e69cac6	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x7d5a271d	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x8d92827e	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x8e67cb40	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xb00ca950	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xdcd6a815	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xe17b3164	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xe2d3edd7	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x15170300	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x23361d64	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x37870cc5	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x59c2df26	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x5a23cda7	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x6927650a	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x85f12646	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8bf52ac0	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x9e04b86d	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc5e1dba3	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xca04c910	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xd5bcc230	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xd84d4359	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xd9b768c7	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x021811cf	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x0f0677b8	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x10e6a889	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1154f7a1	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x15aa8e40	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x174c2a29	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2205bcf9	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3fc7cb7f	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x469f38de	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4ba51ecf	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5b2a89c7	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5d950f2a	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5e21030c	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5ed04550	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6eef9654	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x74ab7b0f	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x84efb763	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8fe32879	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x91f02667	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x93f7fc02	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa1de5277	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa81bf581	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb7d964de	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbbace2cd	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc6673631	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc8a2f711	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe3de2ba2	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe902838d	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xec919105	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xeea27f46	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfad1ec73	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2ebcb317	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x4f84a053	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xa3318dba	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb5630ecc	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xbd755087	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xc08ae58d	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xd94b9e32	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xef60bd62	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xf4372d6a	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x2f799b20	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6aba7f5e	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9310ba06	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9c256008	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa1d2413a	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa448e19f	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xafbda3f3	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xcbb1bae2	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x2aa99890	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x5c1fd4dd	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x5fc86fc6	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x7361a36f	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x8de9ca6e	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xd4dde53e	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xe340a9fb	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x65b4ad34	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0xcfc61aa2	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x17f32c81	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4430764e	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x45ab972a	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x60b182fd	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x714fc5db	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7c199038	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x97a04078	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa68e1f06	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xdcdd2e33	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfad9d53a	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfc62ef4e	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x100f8d64	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x17c36f29	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42dbdfc3	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x49b35849	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x55b4bd4d	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x827a42f4	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9f624559	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xafeda29f	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd29923fb	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf375d009	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf5455120	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x048a1e77	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x163eb4ba	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x56651425	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x6c2d9325	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x9417da59	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x9cf5a1e6	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xc6eb0871	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xd4252ed6	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xd790bd75	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xee50ac86	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x057076e0	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x0c617ce2	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x1965eaa2	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x293984a6	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x7f96df3f	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xcfa549d4	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xe86c71df	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x0e00f408	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x2496b4ed	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x2c284346	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x3cbc993c	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x474e19f2	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x583ec228	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x6a8815eb	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7012da7b	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x81bf417c	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x926a4250	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x99a81ab3	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xabf25c8d	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc22747b0	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xcb418d3d	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xe2dffc88	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xe5596693	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xec2c5c95	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xf481d8af	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0x96121f26	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0x8959a3f2	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0xc3cbbd92	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x0c4db4ff	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x2326f5c9	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x2851df0b	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x2ce989a1	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x2df5c50b	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x30a73411	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/media 0x32fe7449	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x37d9203c	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/media 0x4ffb13cf	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0x5c0f9ce6	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0x6b66a4e8	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/media 0x71c29fbe	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x9e1f3229	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0xa8fb56b5	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0xc51a8376	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0xdacd331b	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/media 0xdd961ed3	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0xe0dc76ec	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0x57914a26	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x13a7047e	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x22dbc661	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x22deb6fa	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x240de3b9	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x2ecaee89	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x364dec5c	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x4475e8af	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x740f70ee	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x7f0eb135	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x83a07504	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x850f4eb9	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x8d98c01f	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x993c5ce0	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x9ca88133	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xc41e1e20	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xcae3286d	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xcd025f46	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd2642ab8	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf1dc091d	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x13e11d2c	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x28c33119	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x34da67b3	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x39d70329	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x40c34786	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x40d14f52	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x4a93600f	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x4cfe095d	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x52c4505e	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x600e7ea1	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x667a08ee	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x6b77c698	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x7d0f1623	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x88fdf39b	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa1ecff84	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa438ec78	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xee15ab6d	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xee5cd390	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xfa2f9fb8	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x192a5b9a	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x1c299069	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x756361b1	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x8c175a9b	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xcae2a6f3	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xd1c8ef8a	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xf1bb4d39	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x0b2585ce	xvip_get_format_by_fourcc
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x3c7eb685	xvip_set_format_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x490bd11c	xvip_get_format_by_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x5a8a8ee5	xvip_enum_frame_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x66a2d746	xvip_cleanup_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xb3395181	xvip_clr_and_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xdc6211da	xvip_of_get_format
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xe818dc55	xvip_init_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xe895d3b0	xvip_enum_mbus_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xfbe93ab2	xvip_clr_or_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x16c440e6	xvtc_of_get
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x3c16a6b1	xvtc_generator_stop
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x47d7900b	xvtc_generator_start
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0xa8a0f912	xvtc_put
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x424a2178	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x961fbfed	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x11bd5dd5	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x11d7bda4	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x1d589572	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x59f052f3	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x5c75ead6	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x66726878	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x6bed271f	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x7b6f6dab	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x869139b6	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x86aa2ff2	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9ce752b3	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa2c6afd0	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xae1f07f3	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xba750b79	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc1b41c55	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xcb8b4939	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xd3aeb2e4	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xd84e30dd	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xfb3db78e	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0x9012503f	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0x6537c71f	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0x7cbf7ee8	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0x7ef28139	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0xe97fcca5	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x97f16ee8	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xd0da4d3b	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xf1c8b84a	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x1df5006e	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x2c869e40	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x330a4fac	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xc508341e	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xca16a237	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0x3d9d5d44	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x086dc6b1	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x08b5273c	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x09e95913	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x0b1c8b5f	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x184bf0a5	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x2bb55218	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x2be70a98	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x36b77825	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x4928754f	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x5401183e	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x62271689	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x78a0b9cb	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8a891f39	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x9312e97f	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xbae42f07	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd4e67508	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xda474eaa	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xde6a9275	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe8ee4e15	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xfdc35a7d	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0x5ac1cdaa	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x35bad508	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x0ffb16b4	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x157e8d0e	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1ebc995f	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x252b73e5	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x4b4947fe	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x50972535	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x513795e1	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7e5991f8	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9369c020	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9b9709c1	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9ddf9b06	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xa5a847a0	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xb3548dfb	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xd129fbc4	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xd6d7185c	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xecf9333d	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xee1a6e5f	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xff2e66a2	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x23727ade	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x68480867	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x88b42763	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x9f332f04	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x1d3a18ab	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x41aaaaf9	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x7bb6bd7f	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x7d4743db	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xc49f8cdf	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf6900747	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x8ccbacaa	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0xff65b90c	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x04adad11	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x05d7f703	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x0e3f75f6	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1ea7889c	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x20e7be20	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x29fc1b15	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x3700e630	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x424276d6	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x484ff1e5	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6259c18c	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x75fbd13d	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x77c7136e	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7ba6049e	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7bc5a664	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7d14d377	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x8cb74086	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9ee76c40	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xa541f78e	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xa8ac8560	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xaf400eae	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb1ff4427	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb9e55719	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc37d8b7f	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd1b9ff63	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xda0417a3	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xde6ad01b	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf3c47a6d	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x03685914	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x14286df3	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x24f7038f	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x26a456ed	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x29fa07fe	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x2d00ea29	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x34bb9c4d	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4b7c68f1	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x64a56599	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6a8da6b6	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8d6c536f	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x9138fdbd	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa19ad793	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb831ffba	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb85bd5b1	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xbdd9c1a9	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xcb2d2b57	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xcbf39d8a	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xd8322ef7	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe317111d	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf8801e3d	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfb7272f6	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfd5612b4	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xffe4b24f	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x2673f178	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x553a86d0	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x9e84da65	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xabe92e7b	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xbc8f35ef	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x297523a2	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xbd4484a9	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xfb183d9f	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1c8fa2a8	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2a48a8c2	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2eeddc65	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x35328274	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x3a976c3c	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x43c8f892	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x44a68dbc	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x493ec6ad	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x5b61d874	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x62c77d76	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x87b7f500	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xa31b3667	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xa96f3bf7	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xac916792	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xc68ccba8	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe49f98c7	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf58c1537	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfc84ae44	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x392637e6	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x71ca45f0	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xb08ce783	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xffc2ce95	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x8ae30758	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x015e4f96	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x07612643	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x09b7dd95	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0a04b7eb	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1d1b70a8	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1d707504	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x227631f2	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x22fee211	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x24f8e77f	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x265b0d0d	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x2865d56a	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x2cf4b655	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x516dcab1	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x6a3a593c	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x73de5fd3	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x89506cc4	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8eaf085a	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa33e5f50	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa3e33a9b	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa7023525	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xacd0e5b0	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xae776955	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb0c5a4ec	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc19a821b	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc91ad516	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc9e736a7	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xd0ddf34c	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xed0f9a13	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf2ba4189	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf9048ec8	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf9d87c69	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xfc967df9	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x0ddc2440	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x007ec2f1	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x02a51d95	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x133adfc4	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x160c1b54	v4l2_compat_ioctl32
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1ef3a428	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2ab9d732	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2f654dbe	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x355f710a	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3832f95a	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3f317f1f	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4a5907bf	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4c7c12b0	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4e73fa8d	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4f1aaa92	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x55276b36	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x577ce198	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x59ec3269	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x71c7cc90	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x72f92055	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x74a017c5	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x757edd40	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7bfda7d4	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa703ec55	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xaab64d31	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xaca2544a	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xae33e2c6	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb4697517	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb771b2c5	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc2746eeb	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc6429d8b	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xdeec3f1d	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe3a31678	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe8cfe6fa	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xed716246	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf2159e2f	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf329880a	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf4c03d3f	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x28b6acbc	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x9f85658c	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xf8e4cd2a	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x040fb053	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x1768df17	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x365b03f3	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x3afde6c7	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xcf293595	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xe37ffc64	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xe440e118	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x218fe6c0	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x76f269b5	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xa551aeca	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xa64e67d0	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xa9867470	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xc59132d1	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xc5b75e39	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xf7c66c13	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x37edb9d5	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x4e23e82e	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xeb2caf5c	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x5443dbc8	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x61d739f9	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x897ea51e	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xabcf1dd5	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xca3d1b56	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xe05d97b4	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xea8fa361	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x1e5d8e78	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x32f8bd50	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x43b1e3b2	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x2079bb29	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x32764e41	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x72cc0561	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xbce1b55f	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xcd001fc6	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xef390115	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x12de9e6f	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x1c266945	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x1d6c66ff	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x303aa9c5	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x4b164cb3	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x96dd7e37	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xb3eec59b	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xcd692839	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xd9b85a87	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xdc43d892	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xfd5d302f	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x3bbce250	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x3c9e22a9	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x45171651	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x75362e1c	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x7859689a	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xce976e5f	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xd6c14727	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0426cc03	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x08bf242d	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0c7370e4	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x14fd8a6f	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x20bba084	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x250bfe67	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x469397da	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x5a586902	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x5e25e205	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x5fccea82	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x61dd89b0	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x68055f2e	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x79738223	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x7ae55982	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x7e76e5d2	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x800d7a23	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9e3efaba	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa2c114a4	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa8f18049	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb3c10e2c	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xbd76a325	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xc642c0d3	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xebbab936	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf59f010d	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x15faaa77	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x42df5fd3	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x454fa784	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x5c5d550d	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x5f7d6885	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x6fd62efc	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x70407652	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x7a260b04	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x7bffdde1	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x82fc665b	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xb5a3f6c0	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xcfd31171	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xe77cd264	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0248a10e	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x03077570	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0727a062	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x13ed5fec	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x17340a21	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x24b340c2	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2c090b3d	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x308c8124	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x35bf0229	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3d1fbe99	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x414e093c	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5a44db02	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x60565437	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6f966fa8	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x76066d63	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7ef7de9d	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7f8cd3aa	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x909400aa	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9952130a	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa969c7fe	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa99490c0	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb3f26e05	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbf8446ad	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xcb57c4c2	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xcefa35f6	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd56fee47	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xea352e8c	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf1466dc1	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf256b27d	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf26063cc	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf386f43f	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf519f42c	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf548614e	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf6ad655a	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x160a9200	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x27eae693	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x44ae616e	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x4e183196	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x8d93d2dc	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x14e0a454	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x6841f5a5	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x8f08dea8	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xfcb4c476	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x22563af1	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x35b91dbc	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x59630957	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xe73a8071	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0x78cc04bb	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x433ce429	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x5b192ac5	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xb56719cd	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xe88a1441	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x12cb5bbe	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x1e4659ce	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xea265698	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xec7b995b	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x004db518	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x09f3e74e	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x205690f4	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x427837b5	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x793ccf52	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x845b9384	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xfcf84550	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xfd9b3eb9	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x3d5c975e	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x50a44478	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x8e718182	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x96b37d14	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x9d1ce543	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xb49b2eae	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xf02a9b24	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xf705dd18	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x95ea0797	st_register
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xbe92fb75	st_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0x465be09e	dw_mci_pltfm_remove
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0x9689e166	dw_mci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0xcc532ba0	dw_mci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x08ca123f	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x173ba328	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x1769bebd	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x3395d1a2	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x46db3ded	sdhci_set_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x522313b7	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x6034c5c6	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x62f17361	sdhci_reset
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x6e07a3ef	sdhci_send_command
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xa006b200	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xa5b96afc	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xa755c5a4	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe11259b6	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xf0e80013	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x0c63887b	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x201af957	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x20fa3261	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x2ebdb5a5	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x4f146c06	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x9bfc1026	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xbe457e08	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xdac97d22	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xfb160b8f	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x0a6eeed5	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xc859eeab	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xf770cb43	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x1a709ad2	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x6422d102	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xe9895554	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0x79233f30	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x3465937a	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xbe84303e	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xea47bd03	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x00a4927e	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x079e6811	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x08a6154d	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0daf773e	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x111bf88d	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x11eb45ad	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x14dfdc98	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1519dc74	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1a54daaf	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1ace1f01	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1c50ac65	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x20c95690	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x348b8ab2	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3539466a	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3cea5fad	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4a49e2db	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4d347997	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x535beddf	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x59c5be78	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x66c62e16	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6f939b1d	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x70412780	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x788ac3e7	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7c2e8f20	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x80590305	mtd_block_isreserved
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x868ce4df	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x900e6c1b	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x940c788d	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9454398f	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa56aef7a	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa92bf585	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb15089a8	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb87367d2	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc082f8eb	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc1d3ee21	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc9bd3111	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcbdf1df9	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xddee932e	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe0e4dc08	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe58fc1a7	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xee63df6e	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfa688767	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x7651aecb	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x7bc38963	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x9ab10c91	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xaf2523ca	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xd3c18c0b	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/nand/brcmnand/brcmnand 0x35fe0408	brcmnand_probe
++EXPORT_SYMBOL_GPL drivers/mtd/nand/brcmnand/brcmnand 0x37112db7	brcmnand_remove
++EXPORT_SYMBOL_GPL drivers/mtd/nand/brcmnand/brcmnand 0xaee44341	brcmnand_pm_ops
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x0b8f59d2	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x106aae29	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0xfab51961	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x8249c3d5	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0xfcd439ad	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0xecd9005f	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x16e9c798	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x254ea914	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x2e252267	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x4f2648d1	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x82293e2d	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x83b86936	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8b1578f2	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8bf11237	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x9f734227	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xa1cb2658	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xa3a8c135	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xd09eedb2	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xde1ed00a	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xfd3cb810	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x39750183	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x8c1cc3af	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x28334bc9	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x68fdd923	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x9286651e	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xad0579e1	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xb6d664bd	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xd49e0ed5	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x040dc0e6	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x04510c34	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x104f9120	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x1372ae58	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x19441bf4	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x24753782	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x376c1a73	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x4d64b478	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x5d1ce639	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x62a283c7	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x64283e57	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x75dc037c	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x8cce8fcf	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb328a8bc	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc0837b28	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xe1803e2d	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xf193c840	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xfd20a288	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x0002f05e	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x66ec9df0	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x83546626	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xe9722088	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x30d97d4d	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x61682470	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xab0c9862	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xce533b94	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0x5d3ad084	arc_emac_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0x77035210	arc_emac_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x00c8c3b8	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x022f1631	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0411ae62	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x04e66bcc	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x086629c2	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x088c9550	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x08e12934	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x08ec9419	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0919213a	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b7c7068	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x100b99e8	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x11252d25	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x11cff8ec	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x14e5e90a	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x178582d6	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x18fd0bc1	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1a3f020b	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1c7dc768	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1c90d24c	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1de260c2	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x217de901	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x24921ce8	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2613a6de	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x276be6b3	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2c4176ff	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2de2b877	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2e09fb96	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2e4124b1	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3327adb3	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x394ac983	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x44ceafc9	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x45c0b783	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x45ccd892	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4648d443	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4c51670f	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4e109105	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5273138b	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x536fd2af	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x54d818b1	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x55981ea2	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x57bfcebd	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5bfdc0dd	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5c1a9377	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x60059b03	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x65b98106	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x679ca179	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x686ef0be	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x68ad3035	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x68f81eac	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6be2bd9b	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6cf81687	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6f3654b4	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x768e24e8	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x76ecd451	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x784a3921	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7987c446	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7a1d529d	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7b1f8c80	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7f5b5baf	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x83c2401c	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x83e3d5d8	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x86084d91	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x87da673f	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8b001033	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8e2226c4	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8ed4c3d6	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x922ba4fc	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x92d7d9fd	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x94b63b8c	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x95687b9a	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9645d199	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9a6d773c	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9c5b1fa2	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9e254e33	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa09c3628	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa19ed9f1	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa1fb5752	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa252ca6c	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa3475149	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa45e0653	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa4cb9174	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa5f4f402	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa83b37c2	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa8835315	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa9635ed4	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xad564cd7	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb356d2e0	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb36c89b0	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb662b5a5	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb76e6444	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb8183219	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb892af48	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb90497f3	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb7f03ce	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbd493a89	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbdde9b61	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc2e41d8b	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc3c72b4e	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc44499ea	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc56e456e	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc747e635	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc7ed4526	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc9fbe444	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xca7151be	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcb45db07	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcd9522c7	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd04e58db	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd5e40ad9	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd7aa1eea	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdc0eb614	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdd155463	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdd24077d	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdffccef1	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe441d240	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe6c161be	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe9fbf1ed	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xec648070	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xecd29de4	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xee5e3e30	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf0cfefb0	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf42fd2a1	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf7064ff5	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf8d6f8ec	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf8e8be9b	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09543b3d	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1590d617	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x15b359e6	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1df175f1	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x28c508d3	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3c7ef130	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x47047cdc	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x493771fc	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4a3085c5	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5fa8993e	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x65b594c2	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x68f16f2f	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6a6cb38d	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x71a1013e	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x78762b9e	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x79c305f0	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x79dc6e28	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7b447d73	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x82e378f4	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x87105654	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x875f8a41	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8bc3ad2f	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8c0d32de	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8ec57b06	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x984e78c0	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9c30e1ea	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9cbdc9a4	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9dbc680b	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa12cdea1	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa162221d	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb6ffc8df	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb81e6b4f	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb87180cb	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb894c358	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbb909a5d	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbfadb418	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc8d8c300	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd3ece570	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe2c07599	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe3257b81	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6454fa9	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xedfd3bc3	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf2ec4661	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf3767941	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf3781b36	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf79f10f7	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x269de73b	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x5e28947e	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xac144314	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x266823df	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x64f7cc7b	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x95b81399	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xa1774be1	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x80598585	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x84913482	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xd2670495	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xe49b571e	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x508bd7a1	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x5d6d72b7	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x5fe97620	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x67ef5a38	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x687bb020	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x78337bed	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x8ac4a47b	cpsw_ale_start
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x91563224	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xa869bc16	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xbcd9cda8	cpsw_ale_dump
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xbd4175c7	cpsw_ale_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xcf910ff9	cpsw_ale_stop
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xd67302d6	cpsw_ale_add_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xdf076062	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xf440aa1b	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL drivers/net/geneve 0xd1faa205	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/geneve 0xfb3c083d	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x0baafd40	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x168b67d8	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x39b2e39c	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xab3aea5c	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0xebaabf5a	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x2f321094	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x3760f801	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x7e62cf72	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xa12a61be	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xbfb85aec	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xcbe62e9f	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xcce00245	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xd66f7cd3	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xdf892db1	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xf69e1378	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x279aa60d	mdio_mux_init
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x6318757f	mdio_mux_uninit
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x40e95be0	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x81f8bb91	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xf3fd98bb	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xfa4ba7a2	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x04c07e26	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x09395c66	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x112ca513	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x16d8f6e2	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x1ba25fa5	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x61f98bdb	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x6fa8c661	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x775c416e	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xbaaf9992	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x06ace317	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x4b00a0ef	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x7de499bd	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x7e28712f	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xb7457142	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xfdaf4114	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x10448412	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1b8143a3	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1d9c888c	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2d91e8fa	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2f917577	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x34181130	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x378cce51	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3943d81d	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3a8e441a	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3dc7902f	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x5582e35f	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x578b78e2	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6afd4174	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8ad77da3	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8e44670e	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x92be9a9c	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x942dd3b3	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9479dcef	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x94bb8913	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa9888400	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xaa19faa0	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xaa311b7d	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb55eaf56	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb78130d2	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbc78d97c	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc54b38d0	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc76aa22f	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xdb490af9	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe2b01f82	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe3a756b9	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe699b4ae	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf8fa1fdd	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x32fde5cd	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x5bae90a9	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x00aa7311	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1397f8fa	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1978ae7c	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1b9f7ada	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x3723038a	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x3de22fa6	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x579c0173	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x58070ebe	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x62c5c680	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x8f4f25cd	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x9a3c4ca8	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x9be5193c	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x9ce69b36	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xabf4bf8f	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xc22ea769	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xe7c37d20	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x4675453a	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x5697d553	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x687302e3	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x9387abd1	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0x7319be77	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x24ce874c	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x4fcb72e9	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x8e7a6786	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xb2735ddf	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xf755424a	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0a144e65	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x126c5af8	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1e1dc4f4	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x216d960a	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x223333ac	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x272ff23e	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x2ff1cbd7	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x44f7e827	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x47e5051f	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x4dd8b2d9	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x56845365	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x70107690	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x71b9e8b5	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7971fbd4	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7ab0e0f7	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7c50b8f2	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7dde5b58	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x839b9936	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8da16094	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa125db36	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa40a720d	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xaa40a0c9	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xaaf3e478	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xba490ce4	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc6ffe064	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd17574dd	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd9fac131	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xee37d24d	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf039f255	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf0634b52	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xfee51904	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x0dbb85f7	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x16cddd7a	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x2a25b5c1	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x4a7d6ec4	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x4d2483ec	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5620e001	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x86ad8c60	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x9ba8c098	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x9cf0ad8f	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xaf9cef43	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xb47dd2ce	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xc9a36328	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe350e13f	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe793d706	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe9c22a00	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xfe5fddeb	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x0449f79b	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x1bf4d0d4	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x4a5b2600	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x806fd10b	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xaf7200f1	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xe017c357	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xee93164b	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xff144578	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x04a92459	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x08e6d27c	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x11a21f65	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x16741e47	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x1a40c6c8	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2b54769d	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31919f45	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x3394223d	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x481da5d5	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x492e67cd	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x9f94f7fb	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xac365615	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xafc95829	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb6665bf6	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xbfaec758	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xcfd29bc9	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xd1c34125	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf4d00146	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xfb93ccc8	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x060998bb	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x259d5f26	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x538b2330	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x5b9f0a84	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x6d32631b	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x7718fe50	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x9691ee63	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xa8794683	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xd9518642	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x590bdd4b	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8ed3a457	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc80d7678	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf694b71d	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x0219d6d7	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x055aba3b	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x16bcff4a	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x23461df0	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x25318379	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x2d58c72d	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3723eb0c	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3c1f7e31	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x453d7162	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x458cb7be	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x549e2024	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x5c395857	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x63321303	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x63f1108f	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x77267da5	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7989bc89	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x84f6616e	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x899e03e6	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x947196fc	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x9e5a1a89	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaea62eb8	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xb217357f	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xbb7dc11b	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xc14c956c	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xc9231376	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xceb5295f	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xe354eba4	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x013f4414	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x150fde16	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1e6a722d	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x35238b68	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3a3c3b64	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4366fcf3	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x56069591	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6b4de810	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x71b44887	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x74f2bab9	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x904cb684	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x92f9e8c2	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x96f2e20d	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x99b80a86	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa90f3cc8	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb6e17f1b	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xba71a497	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc93c1453	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd444e03a	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe03c604f	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe3bba7be	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x06b74d72	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7ec0af32	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x91ee8471	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xb53a3be4	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x017ea821	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x09151fb0	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0f5842c7	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x14207cc1	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x183cf1df	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x2566e1ad	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x34f951af	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x35893126	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x402a6236	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4363f38b	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4499a65e	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x48e9e8db	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x51fe8146	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5e987e2b	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6a4b2704	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x70fe1bcd	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x795d9388	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7bfbf07e	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7d947729	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7e7c25e0	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8d50a009	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x924cdbf9	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x98c6d92b	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa1fa000a	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa64c2a01	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa741e6f1	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xaed9bd4f	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb05404f3	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb13f1f6f	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc18988c7	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc8406ca5	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc9d510ba	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd23a2822	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd8e4591b	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe0a8ff0a	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe8606995	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xeec8623c	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf1a0f8c5	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x23cd983d	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x48b23bcc	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5721ba88	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x60093b5f	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x66fcfcac	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x77421226	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x9f90631d	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xa308811a	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xa9060977	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc45f2b97	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc7a8c030	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xceb9f73b	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xfe0dc97b	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x004a19a9	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x02a3fca5	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0773e2e6	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1898f2e6	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2186838a	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x229fb756	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x252958a7	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x29dde0f5	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2b1d9603	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2e7acdb4	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3289c52f	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x350903ff	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3599772d	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3777ec2e	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3819a2cd	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3c0166d2	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3e0027e9	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x41b71b1e	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x41fce233	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x42ec7a6e	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x50ee6184	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x59c75666	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x632450b3	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6fa309b5	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7372ad1e	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x771e0dbf	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x780a5658	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7a8cbb03	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7aaa89d6	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x87dd1441	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x885bbe09	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8b30fafb	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9445409d	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x96b6313c	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9af4f197	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9c2d66fa	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xaf4df7fd	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb95332e1	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbe35103d	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xda4117b4	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdeef3f91	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe053261a	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf3ea25fd	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf49169d3	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf51b8e64	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf62ed647	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x1e4ce304	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x34062491	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x54e9a2cf	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x7c933df3	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x89540146	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x636f2dbd	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x72ffc7c2	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x972891a4	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xe952cfe1	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x0dea1162	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x11c6bd55	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x16cbaf01	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x2033e76c	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x218c0999	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x2a18f420	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6cae2a6d	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x787f2a30	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x7b6ea8e3	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x8e750d9d	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xd66160d3	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe18f610c	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe2a4cb35	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe99c28c5	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xfc0503cf	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xfe2237aa	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x325ddecf	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x48dbfab2	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x7f8bb77a	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x08331da5	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x08bd89df	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0bb92656	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0fd3d423	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x10198595	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x12db5709	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x158d1aec	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1619afe2	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1e4dfbee	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1f73a129	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x22756adf	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x22c1f007	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2614399d	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x27da9a8a	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2bd12722	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2ee63e48	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2f0041a5	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x382686ca	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x40e291b4	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5417046b	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5a6d3bc5	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5a9736ed	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5b074062	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5b1fa1d8	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x620e799c	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x62397dd4	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x62778053	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x646b0d2c	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x70469697	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x706503c8	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8365f56e	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8a67ec4a	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8aa7e59c	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9230ef88	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x96d23ccc	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa3d00221	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa913b0b5	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb198763d	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb805a0fa	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc3a041f8	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xcd547767	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xde0037e8	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xeefc05a4	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf7d89455	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfd2a11ba	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x2de36eb3	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xaf71f65b	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xb7342191	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xc4a15ff6	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x19b73710	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x2872087d	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x7302cf2d	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x8dd66f77	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xa0a6eb73	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xb5335ac8	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xb833b8c7	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xdaaac5b4	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x16f7d737	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x1a94f131	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x5cc417c7	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x12adf52a	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x15abbf84	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x1d72d4de	of_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x202d4ed6	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x224f51bf	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x35599f29	of_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x3866e217	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x3b9a3c8f	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x3ea2f7ca	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x99f018c4	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xaacb2980	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc697b0f7	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe9a5d74a	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x045574cb	ufs_qcom_phy_disable_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x07e038c3	ufs_qcom_phy_init_clks
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x0a51a42d	ufs_qcom_phy_power_off
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x0ecc05a4	ufs_qcom_phy_calibrate_phy
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x10735c70	ufs_qcom_phy_remove
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x3a70c0ea	ufs_qcom_phy_power_on
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x3d8e69ad	ufs_qcom_phy_init_vregulators
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x4982d01e	ufs_qcom_phy_enable_dev_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x4bc66a88	get_ufs_qcom_phy
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x6873417d	ufs_qcom_phy_generic_probe
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x75ef51e3	ufs_qcom_phy_start_serdes
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x7a630182	ufs_qcom_phy_set_tx_lane_enable
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x83e5cebc	ufs_qcom_phy_calibrate
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x890d0d82	ufs_qcom_phy_exit
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x8c28372b	ufs_qcom_phy_is_pcs_ready
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x8eaa90fd	ufs_qcom_phy_disable_dev_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x953841c2	ufs_qcom_phy_enable_iface_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xae9dc3af	ufs_qcom_phy_save_controller_version
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xcaa35dc8	ufs_qcom_phy_enable_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xfca7449b	ufs_qcom_phy_disable_iface_clk
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x8626e4bc	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xbd5dd69c	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xec7f4db5	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x3384b40f	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x3db9142c	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x3f7a9697	mc13xxx_get_num_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xb876cb48	mc13xxx_parse_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xc09fffa6	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x30b502c9	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x64efb6b9	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x6c5e3e76	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xb14bf9a0	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xbadfb5ed	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xf3ffb0be	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0x3ae553e0	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x049b170d	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x04cdd10e	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0a5adc69	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1032c5b7	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1344683b	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1556b664	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x24577e7d	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x26a1fc77	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x274ed1e8	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x298d2b59	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2fbd5f39	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x34c07612	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x365aa0a8	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x36f20f8d	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x382d417e	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x38f34343	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3927acdc	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a84e82e	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3c4445b7	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4e058758	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4ee9ee60	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x56d6e78f	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5c2a51aa	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x62e57c14	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6da3ec27	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7039e79f	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x73862c44	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x749d9b94	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7944103c	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7b89f55a	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7c8bf5e9	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x83736194	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8d8420fc	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x964d8fb8	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x981a395b	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa5f43b7f	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa7ef4518	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb08c5919	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb251d11b	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbf22cd27	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc3bc8fc0	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc7e2960b	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe5a597ec	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef1f155c	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef4d9301	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfadd279c	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x00b03abf	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x15b77fdc	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x33706674	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x59816b52	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x59f6a45d	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x75108404	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x7cf84922	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x7e3087f2	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xaba8accd	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xae715c1e	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb6269cf9	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xc2cf04a5	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xdb95fbf1	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xef326e1c	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf12505b2	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf77b88b0	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x03f2936b	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x1400a2c9	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x6f98ae4b	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x8b14afd9	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x9b412f44	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xf922c3fc	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x02aea2ab	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x04a034df	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0e175f0b	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x116983d7	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x117d086c	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1336906a	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1596237f	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1d751553	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2ff76b35	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x363273ad	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3f3818a5	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x48506a86	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x577b0f2d	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5e526332	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x66560212	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6adf62e7	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6d785107	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x78c76afa	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7ddd58f7	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7e8850cb	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x81339060	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x948670d6	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x97cebe45	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9e805d10	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa1b89445	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa7a5469f	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa967320b	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa9e2bfbb	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xad75e89e	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbe90e50b	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc25af3a4	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc6e25285	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd048f1cc	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd1c48c34	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd743b264	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd7b12454	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd8c5cd31	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd8cd5555	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe7dd261f	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf447fa8d	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfb6bbdd5	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfe1eaa5e	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x04f4a6ec	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x08e17dbf	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x0b20087b	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x14bc7b4a	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x311b0a76	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x3469bc8f	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x36b2f7df	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x5856485a	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x5ec3ea49	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x679988ca	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x918990ae	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xacf5d4c6	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xb6963b22	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xb8772981	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xbf0dd5b6	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xcdddaa14	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xd19fa5f5	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x0add27da	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x20d55aeb	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x243aa42a	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2927306a	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x321f9513	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x37a245a1	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x40e03de3	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x539fdb91	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5811c6f9	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5c5898cf	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5dcabfac	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6457690b	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6722c4f4	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x74603c81	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x839a0a22	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x998b9da0	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9df5d152	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa3e3c5dc	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb98c37bc	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xdffcf20d	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xeb22cd4b	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf0fbdde7	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf10717fa	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfce47b57	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0b1de088	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0edc64fa	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x12bb37d0	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x12bf9887	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1ecad041	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1fe134a9	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x23dba846	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2cf3fe40	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x34c139b5	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x47fa9fc2	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4a112e9a	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5774d9d1	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x63c06873	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6b3b9fd5	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6b810d3c	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6d490866	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6ec77981	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7163dfd8	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x743eb98e	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7dbf32b3	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8e9b77d7	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8fb817f8	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9176c38f	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x94ac18b2	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa2a206fc	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa3c35908	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xaa64515f	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xaaf9e4b3	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xafac19c8	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb3eb9de8	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb80a4e26	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb8f3abfb	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xba69fb06	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc9d24e6	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xda919db0	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xdc1603e5	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe2e4202a	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe8c987bd	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf293be3d	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfbfb2a61	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x66e2812a	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x944a362e	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xbb13ce91	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xe6108393	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0bac2817	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x10d569cc	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x1800e7a0	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x43cf34da	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x81070660	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xd79ad1af	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xf88d3615	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x0231e7ed	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x1f9adccd	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x2807ac5f	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x43c42f38	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x75320cfd	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xb1327f4c	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xbf4503fc	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x0397927a	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x0c0b2394	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x2c29044c	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xa8a7e23a	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xc21e5a4b	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xd4812397	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xe505894f	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x58988041	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x9f706fea	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xa24ec535	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xc1387343	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xdd4b9b37	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x3cb79f1f	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x4fc87ca7	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x84c5dbea	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xf79f6ec7	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x01bd5e08	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1c26f4aa	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x2cad06d3	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x39ae6d4d	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x52c2f4a7	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x6a2f7f0e	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x6d526fcc	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x6d856a1f	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x784a38e2	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x791053e7	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8122943b	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x823e6b30	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8b4a19a8	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xc3b791b1	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xcbbecb2e	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xdbcc6c2e	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xe0e41c0e	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xfe054e33	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0xf0239914	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x03d4dad8	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x10700776	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x196138d7	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1b9d1062	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1ef5813c	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x22ab9e71	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x24d0dd65	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2b2e5332	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x31e32acf	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x45117c14	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x486ff2bc	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5029efc6	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5497d796	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x56b82457	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5dfad081	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x634080ae	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6f351a78	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x76fa9d82	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x785dce9c	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x82e585dd	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8407492e	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9706c589	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9a01b3d5	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa05b9597	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa5092297	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa787df47	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xaa4bec02	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xca0dc546	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcfb2ee1e	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd128b53e	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd85d04b1	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe5e5e0b1	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf0251642	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf104df0f	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf86c7b36	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x31dc7c5d	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x6f8fbba7	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x79bd9235	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x85440426	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x9570dac0	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x989fb095	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xcee97118	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xecb5a48f	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x25728805	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x44a370bc	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x53c7c0ea	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x64cb0f7c	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xd02d2a3b	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xd26baabc	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0xa90e528a	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x48999d00	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x742be731	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0x6d2d8b50	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x1c198ed0	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x271dc7cd	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x374dbcdc	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x66d57106	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x6eecc073	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x7ef38f00	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x823e6ab4	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x92c19371	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xaad7d70d	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb19d2110	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xbdd39422	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xccb140e6	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xf687b1be	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xc1b3fe65	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xdd7e871d	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xe99a770d	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0xc77de2e8	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x173d3afd	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x187c400f	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x21b6aa1d	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x3121beca	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x3e29f61e	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x3f40afb6	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x400abc74	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x487c2045	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6d5248dc	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x79a6a371	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x9bacc455	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa889c421	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xaf1904ef	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xb0da904b	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xb6bee8df	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd17bbc44	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd9fd0879	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xef24f417	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf131bdb0	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf8bde62f	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xfcec0fd7	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x560d0ef8	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0xe8d13b78	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x62fa8e53	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x7507b603	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x910c7591	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xac91f1a3	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xb654ba40	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xc44007b7	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xc4bbedae	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xfff4bfb2	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x28fa437d	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x4cdc157f	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x52f391e1	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x9b0bb9b4	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xc17e7ba9	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xe2afe636	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x0b29db1b	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x2625eda9	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x36d763c7	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x4af1572a	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x5d1d5127	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x86628806	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xca07519b	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x15f27437	fsl_mc_resource_free
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x22ebe54c	fsl_mc_object_free
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x26ae0f34	dprc_scan_objects
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x2912c6a9	fsl_mc_io_set_dpmcp
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x415de135	fsl_destroy_mc_io
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x4ddcc96a	fsl_create_mc_io
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x5fddc8b4	fsl_mc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x62d1c89c	fsl_mc_portal_allocate
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x6d48e82f	fsl_mc_bus_exists
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x6e00454c	fsl_mc_resource_allocate
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x8aca6100	fsl_mc_portal_reset
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0x8fdbb066	fsl_mc_bus_type
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0xa7ea280e	fsl_mc_io_unset_dpmcp
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0xaf57121f	fsl_mc_object_allocate
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0xc79322e8	fsl_mc_device_remove
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0xd24178ca	fsl_mc_device_add
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0xe73c4178	fsl_mc_portal_free
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0xebbc5e8f	dprc_scan_container
++EXPORT_SYMBOL_GPL drivers/staging/fsl-mc/bus/mc-bus-driver 0xfe2c7ff5	__fsl_mc_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0x96b58fbc	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x1a0fbd27	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x23786f65	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x369c1824	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x7b40d05b	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x7ce1833d	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x8b12d7a0	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x8ee5b352	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xa22ff03a	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xd2151543	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xf148a4b5	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xf85999ca	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xf870891a	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x1b8405aa	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x46a0fb94	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x523c4964	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x56355aa9	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x91eeb28b	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xa150b798	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xca0006c7	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xcc8263f4	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe1165ed5	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe276d36e	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xf7095f2e	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xfb60671d	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x260ec4ae	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xab1e1263	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xea2e76bb	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x6676ad8b	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x7f0289c8	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x9496a298	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0xb10f21c6	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0x973d5ee9	imx_usbmisc_init
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xa2553988	imx_usbmisc_init_post
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xbefe3dc2	imx_usbmisc_set_wakeup
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x21b7c96c	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x4f8a1b96	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x791c1e4f	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x9d63adc1	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x9e3500a0	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xc9f0d089	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x0b6ec58e	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x0c7991b8	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x1191de9c	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x17e13411	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x30bfafba	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x39bd6cd6	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x41652627	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x47785b5a	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x616dc70a	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x6b2ea4ed	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x70631117	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x72394db7	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x82382ddf	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x9957f5cb	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xc3bbe1a9	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x23192f9f	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x52134434	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x89ca818c	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xd371dd12	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x418956f6	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x9d63e9bf	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x9fda93d2	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x16ca691b	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1dcefe32	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2e58bbd5	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x3863e2be	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6240d703	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x64c78c45	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6a464e3a	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x759621d2	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x8c3489c7	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x8c8b4666	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xab9f50cd	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb2125d8d	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xd128abd6	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf315ad74	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xfcdfcf44	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x1d1b03d8	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x1df46690	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x4587f736	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x5865d982	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x63ada566	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x6fd38bf2	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x7505df7f	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x7a572ec3	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x7e823bf0	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x7fe97ab8	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x986df35f	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x9a80c2aa	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xe4934e3f	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xe6156c6a	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xf2bc3316	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x00534b10	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x057e4a37	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x09b7151f	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x124442ca	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x20df9c82	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x27484492	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2d5261b4	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x39ddabcc	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x459ba287	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x486a9280	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4aaedbdc	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4ad2bc1f	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4b040d01	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4f386527	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x51f50db7	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x565ceb35	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x631ea281	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x68494784	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7726d63b	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x77baab68	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8207b078	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x887e5eb8	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8bbd499b	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9ea74d07	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9ed6d7f5	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc0ccf880	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2fd6673	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xdadc3e74	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe984fe62	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe9f81948	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xeca8d85f	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xee1789b5	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x05b2eb52	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x1c5ba183	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x77ce7389	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x7e3eafb4	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x9b079286	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x9f391d98	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa460e3d1	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa4744dba	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa90e178c	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xce35920f	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xd09ed744	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xd36fcf53	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xd44bfe91	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xffa60d83	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x5e337a34	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0xd07cb016	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x8e44c5b4	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x94e18a3a	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x9fcf5ef1	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xa71f7d78	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xb15d307d	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xb75bda1d	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xc185f9b0	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xc19eaa28	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xd624607c	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xbbdb84cb	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0x59651c4a	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x52f2b906	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x0b6baabc	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x100e0fde	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x19e43980	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1aef7c37	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1f1194fc	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2b0f9847	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x69f61664	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7992612f	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x855a65d3	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x9f3ec6b2	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xba4e1b75	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc565bf60	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xcb17f8ee	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xcf7b91f6	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xdd3fa395	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe692c831	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf1d28c8c	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf24a159d	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xfbae34ad	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xfd5d2b84	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xfefc9045	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x11b52171	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x210a7fcb	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x258d34ab	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3a8a385a	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4c66c8f6	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4f7de1e0	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x5476f23d	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x5b39e547	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6df2e6f2	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6ef46ef9	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x71df200b	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x75c4d44d	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x866572b8	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x9192509c	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x944de70e	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xabf41b26	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xaed00082	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb2f8fbce	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb90b7cdf	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xcc146108	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe1528e53	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xedbad93c	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf5174591	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xffab9eda	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x0db67bf6	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x205ce0a7	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x494da29b	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x5637a49e	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x598c67af	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x8825b5b1	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xb766d48d	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xbe51b63f	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xc5032c17	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xc688f3af	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xc74311fc	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd3968af7	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x0bd816f0	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x122f15ac	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x16035ca7	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x1f487b42	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x39d58e11	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x4e2f2560	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x8d5b3f67	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xc1db9ce1	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xd3dd2bd0	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x059ed094	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x08f6d4ee	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x10e8cfda	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x23d89adc	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x2d42d34c	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x2e07ad34	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x34071818	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x41356c56	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x511c8e73	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x9ad34447	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xad1cb96c	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xca568ea3	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xced0daf9	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xdbceaeaa	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x18f50991	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x26c59518	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x8fff3041	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x174aba40	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x2c24ff37	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x41928418	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x9ca23aed	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xb426561f	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xfbcd9374	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xfdba58e8	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xfddee83e	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0c07be41	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0d78016e	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0e6bf50c	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0fc02440	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x11be25ba	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x13e82d3c	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1423699f	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1632e313	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x184ead64	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x18b8b296	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1d05b68a	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x22d35c37	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2580ed12	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2ee4db7a	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x335c326d	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x389b55a7	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3b35d878	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3dc2f40a	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x40efa5aa	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4e1bc53b	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4f7c0842	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x60179dd1	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x61a113f2	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6e8521fd	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6fbebe50	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x816b9e92	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x90204094	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x91215eba	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x95e873f9	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x99ba1fdc	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9ad5a3ff	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9b5b795f	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa67e53e1	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa7b09551	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa8e1aa79	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xac97316b	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xad34c843	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb81205d5	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd2195751	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd91247e9	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xdfbe58df	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0xbfc12438	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0x09354409	__vfio_platform_register_reset
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0x84dbee1a	vfio_platform_unregister_reset
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0xd5e0b705	vfio_platform_remove_common
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0xdc1b7297	vfio_platform_probe_common
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3567743b	vfio_external_user_iommu_id
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3b2fac32	vfio_external_group_match_file
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x601a23f2	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x94d0e726	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xa8c3e122	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc1d989c5	vfio_external_check_extension
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc4913442	vfio_group_put_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xe0ace7e0	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xe1d5a6ec	vfio_group_get_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xf24dd7ee	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0x3f9fb178	vfio_virqfd_enable
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0x80502bbf	vfio_virqfd_disable
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0ba91889	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x16d236da	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1a19f393	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1e52f6f9	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x21147741	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x23156c8c	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x29e357c6	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x39076137	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3a8e8d5f	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3bcc5413	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x52170513	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5362e064	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x58ccc7e8	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x65cada4e	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x6724d3af	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x72aac5ca	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x846a045c	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x96170780	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9ccf11a5	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9e0fcc00	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa9e34688	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xaa41d22e	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xafa17b67	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbe3af66f	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc7eac1fc	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xccebc768	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd3d50067	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xdf7f499f	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe713111e	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xea4c1a37	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x12423e88	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x47b7a008	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x67fe8da6	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x7d3b15fd	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x9e345634	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xa6a3ec9b	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xf25c4b01	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x0a1bdfe7	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x12f064bf	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x2158f475	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x73f1db0e	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x98a3d8e1	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xb14c7026	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xb5c72cd4	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xc4e22fa7	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xd5ff6e56	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xff68e36f	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0xa7c5a432	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0x0913c0e8	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0x150a5e8a	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x16ffe563	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0xcf70b0b1	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x0a35550e	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x1be2c907	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x5917acf9	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x80fd4a0f	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x897e217e	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xad3bcfa9	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xb5dbcd9e	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xc8ece771	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xd5442a7c	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/xen/xen-privcmd 0x823e4c3c	xen_privcmd_fops
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x13668e03	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x3040d3f0	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x8708e516	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x05943e3a	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x156dcc10	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x59981451	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x80218c29	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x8a531f00	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xd62c0194	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xebb78d05	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x012e5dff	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x02148f84	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x05fe83a6	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x08fd1d3a	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0a586f8f	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0a876290	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0e755512	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x169c19d7	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x173a7c9d	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x18316fc6	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1a1b13b8	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1d458b62	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x219573ce	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x259d2295	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x276351b1	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x27faa7aa	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x284f1496	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x292d3799	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2a687eda	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2b105707	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x315d05bc	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x32113da0	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x341ea369	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x34282b53	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3596e606	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3b317059	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3b56924b	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3b7c2f24	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3c3de50b	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3d12e682	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f9c1c77	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x437a9acf	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4408c9c2	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x448670f9	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x44dff28a	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4d998f06	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4e0cfa77	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4e4c706a	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4fb6a7a9	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51e31a40	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x52d205c2	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x53cfa4fc	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x53f0cbe2	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5433069c	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x54c824e6	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x56405290	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x58ffe22f	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x591fe4ae	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x59d5a2c8	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5a477608	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5b159aaa	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5c1e8e97	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5d9ce83f	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5e29ba67	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x61bbac19	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x61de3fb4	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x620f0051	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6371aa39	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6655bfc2	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x688f1173	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x696b37f3	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x69d52719	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6a94b718	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x70cd93a6	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7333a036	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x73e13d47	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x77fada57	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x78b417e6	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x796ede4b	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x799d9eba	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7c9722ba	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7e0f2d7c	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x82b9d267	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x85b90f08	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x88289af1	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8cbb8083	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8da5bbd0	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8fde4ef5	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8ff63e6e	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x919e4751	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x953ed1d1	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9578d6ff	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x96fcc827	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9d91adc5	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9e9d6d79	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9f230649	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa1d9683a	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa4d9cc0c	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb103eb49	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb10d8a3b	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb1370d57	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb41f7c02	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb4b74b3d	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbbee7153	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbd353c3e	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbf7b451a	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc073a66e	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc1f4c018	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc344f844	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc63cb018	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc8608aa6	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc920e4b2	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc9a73f22	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcf9d3534	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcff281ac	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd0adf378	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd0f4eb2d	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2bf1d3f	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2d0d044	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd9268a27	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe09f165e	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe1689964	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe17fde24	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe5178db5	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe572d5a2	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe689c128	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe709c4b7	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe89dc784	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf04f18d3	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf21db6bc	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf647dbc1	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfa45f831	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfa4bb38c	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xffc33dcb	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xffd20bb2	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0x5fa2f832	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x017cd641	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x056f8b0c	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0d67cca7	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1093b108	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x119f6683	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x16d41bd5	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1a983675	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1e66e9fe	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1f8f4494	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x247fa563	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x26e9d47c	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2a13fa50	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3310948b	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x390dac81	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x392b5386	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3aaa2cbe	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3e052148	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x435c6a9f	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x49a37069	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4b144431	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5c8215e8	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5d29cee9	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6085edbd	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x70c0891e	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7654f347	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x787b1151	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x804960f1	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x89636e14	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8d2b93fc	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x972756ee	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9a86d989	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa5e8572d	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa6090adf	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa831526a	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb0480ef3	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb39ff10b	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb6b60849	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb89596b6	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbcd24af8	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc03da5e6	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc2beb273	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc3138488	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc3f98621	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc5d186fc	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcad7be29	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcd0877b3	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xce7c1fd4	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd0b5b7dc	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd5dbe981	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd688c4b1	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd894cbfe	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xde1e5ad4	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xde391e21	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe226f9bf	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe7f8acbd	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe9814ddc	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed841e88	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf097afba	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf6640d3a	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf986ae89	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfcc3ca72	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfd24985d	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x685615d7	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x98068911	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xcafde29c	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x2eacc8f8	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x5c7c685d	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x06206bcb	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36a28a9e	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x62c94fb4	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x695b5ba9	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x70386cbe	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x7fe5bde0	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x81a17396	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xdfcc1e56	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xe0ecc0fb	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf56c2017	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x0bd168ba	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x1f83e52e	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x3a1b03aa	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x54b69530	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x6d48a266	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xba093ec9	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x2a6ac76a	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x2d36909e	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xf028c16a	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL kernel/torture 0x0d3809aa	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x5095dc41	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xcfbd6c58	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x4d8e8a5c	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x52c234c9	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x1803a6ed	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x2b30f429	raid6_call
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xe4b051cf	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x0adcb055	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x221df614	base_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x4da25bec	base_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x63f42b6a	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x76203267	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xca3140ce	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfa5eee0a	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfc02472a	base_inv_true_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x5a4fedaa	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x83b08557	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/802/garp 0x26b30821	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0x2a04d5ff	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x4b714a03	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0x6a547d93	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0xab7648a4	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0xb29d2793	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x3845a141	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x97503f0a	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xa719ed9d	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xb75c0543	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0xdc5be33c	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0xe8ecb783	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/stp 0x5bdb5327	stp_proto_register
++EXPORT_SYMBOL_GPL net/802/stp 0xf92b9e8d	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x43aacc44	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x99156f30	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xfab338a4	ax25_register_pid
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x078fd6f6	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x43fcabdc	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x4d6ed7c2	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x53953f1a	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xc2341a4a	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xd7827cf6	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xe579e223	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xea182d51	bt_debugfs
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x6204b406	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x74899e77	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x902294b0	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xa97bf7db	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xbf8a1849	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xceb7213d	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xdee824b4	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xe609839e	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x64f34c17	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0xb9cfd22d	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x06711d6b	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x144e2be2	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1c371116	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1e54d81e	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x28c2c340	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2a5f7c13	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2b53b7c4	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3505c49e	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3c63189d	compat_dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x42f628ea	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4a7e28fb	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5231d686	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x526144ca	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59e93606	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5a784ff1	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x609abaa7	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x623cb169	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x64e8ebe0	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x68cb080b	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x8ab8a88b	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x8b5289a0	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x908995f7	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x99c521b0	compat_dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9f1a62f3	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa5c2ed55	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa5eae370	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xbb09037b	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xbcf4a5fb	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc01f49df	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc4e95e42	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xcdd97689	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xce5d1128	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd05268a8	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xdf87254a	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xea5db010	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xff17995c	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x2f936d67	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x49458fe0	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x5064904d	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x7360268f	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xe14537c5	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xeb8a857e	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x0d0d9998	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x14ec4836	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x410f8d0b	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x42e45c04	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x4d7aef69	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x9b4d3da4	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xe0636522	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x2c5d2738	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x40e8b2f4	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x9e848d55	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xa9348e49	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xebdf0ca2	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xf20d2f6b	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0x098adb8a	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x018f5c27	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x19f3bf15	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x1c11fc60	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x1c8296ba	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x295f3dea	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x4ea5430d	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x508cd007	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x6d742738	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc2c50ef1	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xcfade8b1	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xe7e29e08	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xec53672d	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xf31d8136	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xfc79b0b2	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xfe2bd2f1	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0xa5422e84	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0xd98c41db	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0x14bfd4b1	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x3dc5fd27	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x9c2f1040	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xa33d0c32	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xdc4fc2e8	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xddef1360	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x40ece27e	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x27693bef	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x99a370ae	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xd8b10c8a	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xefb843cc	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xf1ee8e1c	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0xda067fc2	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x06dd9ae6	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x80bd9619	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x909890e4	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xa12faa82	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xe1ca1f93	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x00bf912a	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x2e974871	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x4b3b6004	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x97153886	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x02d6f742	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x291d4b43	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x4de4d979	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xd7e8984e	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xdd103328	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xe268d145	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xf2619a25	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x0da73ad0	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x4c1d1bf9	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0x2519967e	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x334b2bb2	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0xc70f3da3	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0x59a30793	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x139d37ea	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x13d1cd86	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x62590170	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x73b39d14	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xab307748	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x6ea30a5b	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x539d50bb	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x8ffbef0e	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x9197bea8	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xa533a106	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xa683aecb	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0xd5cc5df3	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x0eb5574e	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x1064fe7e	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x1ff12936	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x3e2ec352	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x4d06ae63	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x613ed2b6	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x61afc47c	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x730e7188	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x86638f97	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x9adbc4f5	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc653f47d	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xcf8d3d77	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd528185c	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd73c69da	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xe382dbe5	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xff57a389	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x90e93ca1	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x00d813ec	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x08cb3e5d	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x11e1f72f	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x1f216d2c	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x2142d062	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x33441e12	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x43f90bba	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x57f7dd57	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x58a151ae	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x5e4c8997	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x6307ef23	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x668fd28c	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x683f3501	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x95ecf18b	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xb06004fd	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xbcd3e2ed	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe1745601	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf8f93179	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x44998607	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x8729a220	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x8a1ce48c	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xb9107e88	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x033a730a	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x03b97d7e	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x1b7b6af6	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x35295367	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3784cc3e	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x5506eff7	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x61a7fc83	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x65c8d546	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6e4934c0	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7bc98af9	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x93feacb5	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9495ead1	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd06a5682	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xdd57fbfd	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xe1985c08	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xe288f689	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf3b4d4ae	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x0c38c017	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x3dcd63ee	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xc54163dd	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xd59d3549	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x02357c55	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x03f22d11	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x08044cac	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0934633d	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0ac75d9f	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1135c19d	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1166232b	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x125b8fc1	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x177fe163	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1f104050	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x206ded43	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x20df469d	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2d2622d2	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2dd02ed2	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2f23f60b	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x31d3bce7	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x35277805	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x379fafe4	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x38c2e269	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3bc10891	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3e6b0da5	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x408c140d	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x411b2a4d	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x53297554	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x585ef5fa	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x586e66a9	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x59df1ad5	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5db9d965	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6212661e	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x670f06a3	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6868defc	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x688a525d	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6b60f8ab	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6ebc264a	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6ecc3af5	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7227521d	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x765b2547	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x806ad15c	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x825199bb	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x82d2adda	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x83ae002c	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x84d86cac	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8a93821b	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8dc5de70	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8f69020c	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8fc6ec95	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x92532e14	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x938432cb	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9450a9ef	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9526d4b9	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x985aa0fb	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9a3eb644	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9ee1850a	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9f036ba7	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaa0bf0c3	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xabb464bf	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb14534de	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb354f879	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb4219ce2	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb79cf94a	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc1329c66	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc644fad3	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc68c5976	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd0e434f2	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd1c8bf3e	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd39b001c	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd492a9a5	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd4fcdba1	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd6fdf59d	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe1275999	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe12881b2	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xea37cb1b	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xec187081	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xee6d0de1	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf2e1588e	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf2e710f9	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf5e94a07	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf63c2469	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf653ad1a	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfde03963	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x465a5f4a	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0x7d3fa5fb	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x929753aa	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x0a284587	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x0df9be4f	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x1546182b	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x154cf707	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x43baa4c6	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x4aa09c5b	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xb26d4532	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xe05322b2	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xe8d1b723	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xea55413a	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0xbed5cd23	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x41f609cc	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x5b51adbb	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x6e457ac0	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xc4f13fc5	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xad131109	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xae9ecb7a	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x023ba664	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x09157149	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x0bff34ea	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x1d3b0b37	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x2e9f4c30	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xd07a993d	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xd6d7f0b6	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0x06e5e6be	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0x08eaa549	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x08cd01d1	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x3f346823	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x4e94782a	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xc9ee4162	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x1376cf90	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x2ea649c7	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x3f70abf2	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x5354377b	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x7091a5c1	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x9a7694ab	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xa71e4f22	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xabbec2e8	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xc8ff393b	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x1d36d064	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xf5364599	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x8841d39b	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x8c467622	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xf57a006a	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x07acb807	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x0d753944	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1318fdc2	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x198a5d28	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x2649e202	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x326d2245	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x35b7c21b	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x376322ed	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x39bb555a	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x58b3f2bf	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x66b03e44	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x73f5df3f	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xb76149dd	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xb7b4c04e	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc3e3d1c3	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc3ed3c6c	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe7c55aec	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5d044c13	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5d2d54d0	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x74678f21	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x8261a046	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x8b6f89e0	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x8fba14c6	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xc280aadc	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x37a48c15	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x47e569df	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xf73e5ad0	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0x64d72bcf	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x30773c43	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x438f64b5	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x5d42bb32	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x07ae83ac	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x5cbacd54	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x97269007	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xadeecb3e	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xc445a811	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xef127a4d	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x12d8da20	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x7df71812	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xc2e17e76	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x66a7958e	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x7fa9b9b9	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x00388f3b	xt_compat_match_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x161d1417	xt_compat_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x1880a5ae	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x37694de7	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3a80e1e3	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x54994873	xt_compat_match_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5d9ac9e3	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5f82f1f7	xt_compat_flush_offsets
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x6483d5ec	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x691a6d69	xt_compat_calc_jump
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x73088912	xt_compat_target_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x73cee41e	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x7502ab2b	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x7b83ee8e	xt_compat_match_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8cb47df6	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9aed4e38	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xa2afe21e	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbaa7d856	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc66b587a	xt_compat_target_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd1863d39	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd6911ba7	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe0b4971b	xt_compat_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xec24fd82	xt_compat_add_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xfb71cdb1	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xfc635ee1	xt_compat_target_from_user
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xe9ef9dd0	xt_rateest_put
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xf156a7fd	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x2381022a	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x612bc9d6	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0xa6376ed0	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x173b5e03	nci_uart_register
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x430e8aad	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x48209b80	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x1002c835	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x16dc21e9	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x1f5a6b29	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x3128743a	ovs_vport_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x39183ff0	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x65931b7b	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x9e58bea0	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xa0c4f170	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xd49c5a53	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x08ca4e52	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x0982e907	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x099e3769	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0x0eb3b677	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0x1190c662	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0x15be20fe	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x2eb78f83	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x37a5f9d1	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x4c17e0bd	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x598164c5	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x7b2fa5db	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x7bc62829	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x7c167352	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x85132417	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x8771eb0f	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x8a32f9a2	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0x9faca91f	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0xa43080bf	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0xb2a95c34	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0xb95bdc15	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2a02c0e	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc9983424	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0xdc31c1c2	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0xfdab668c	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0xfe840783	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x8c02234a	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xdc9649fe	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x090302f6	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x254e9e7d	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xa2adbf2f	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x00325002	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x004eaaef	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x03da6b53	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0435b4a6	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05b865c3	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x061a940f	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x075013eb	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x075c92b9	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x07c95274	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x081f2ef3	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0846db58	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b9d1620	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c699896	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0d04102e	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0e185ece	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x10490f43	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x10faf9dc	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x12e10e91	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x13599a61	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x14564725	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1506f3e1	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x15716f80	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x16f1a164	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x17428b8e	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1765aac8	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x19ecb4cc	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1a85eaff	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1ac7daa1	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1b327902	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1b551c16	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1bb76a2c	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1d0d1671	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1e2aec35	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1f2a9970	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1fe0ab0a	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x20057c28	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x219b1e5a	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x229edf11	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x246f3fce	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x25f3f505	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x267eb195	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x26cb32cb	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x27d4aaca	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x27f81202	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x284164a2	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x289f95a8	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x29938c12	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x29b7c461	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2a6887ba	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2bf338e9	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c626025	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c7d778b	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c82ec7f	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2d703da7	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2ddb8129	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2e5801ea	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31e46761	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x37117a3d	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x37392ca9	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x39698753	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c1f992b	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3d3bf214	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3e008938	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x42d54f64	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x47458223	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x47ca2ef8	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4a75d505	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4af0ddef	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4bdbac87	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4ca8e7f6	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4d8695ee	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4e00f213	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x50be4f9f	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53dfc630	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x55a0d440	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x55e5795a	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x57861b58	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x58540713	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5863e256	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b244892	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5df9a772	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5f0eb6ed	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5fb31fea	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x649f75b3	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6517c1e4	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x664cd472	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x68e5bf2e	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x69c807b2	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6ae46bfb	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6b2af141	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6d0fd9bd	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7246759e	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x74bd2713	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x787cb438	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7a2c799c	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7ae5d192	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7afb8b60	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7baf8f64	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7dbc437f	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7dc6dedd	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7e25a40c	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80209eda	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8088d9d7	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80dca99a	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x81877a69	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8422a5d8	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x85be0466	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8608904d	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x87801f26	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x89cbca95	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8a2fa280	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8cce36d5	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8de0c0e0	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8ff75ab4	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x91fecb9e	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9272be7d	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x94f8d444	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x94fb8840	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x951a98f1	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98335e14	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x983dd6dd	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98a71da1	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b2499c9	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b612e83	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b7f06b3	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9cab4fae	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9cb5d6ee	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa08957ff	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa80816cc	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa9114c0b	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xab121b00	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xabc5f2ea	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xad760673	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xae3c0e88	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf21bb28	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb0e7729a	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb13a0001	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb2657701	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb29a4024	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb33436e8	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb339cf10	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb42f8efd	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb5af41d1	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb60ac573	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb8220bd4	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb941abd2	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc0060bbd	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc18d1c55	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc1b062c7	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3e6c3f7	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc51f65d0	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc67dcad1	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc7067e51	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc7284cd1	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc774a4af	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc981cc43	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcb8c8b36	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcc193337	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcc7a2cfd	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcd19607d	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd1de6a9b	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd23b07ad	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd28804ce	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd48de102	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd79069e4	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd819a07f	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdb080289	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdba6490d	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdba70d76	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdbc83283	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdc5f2728	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdef7eade	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdfba95dd	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdffd4ec5	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe31e9783	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe33d3aab	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe3c72636	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5afc5fa	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe6829be7	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe90aeb7c	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe9bc1143	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeae51c3b	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xebae5d45	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xec0d5452	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xec3361cc	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedac6cf4	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xee39b397	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef7adc13	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf0dc5de0	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf1372155	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf2114e0e	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf46c1375	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf5187a7c	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf5c11666	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf6f3a94d	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9236123	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfb15f2bb	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfb3c2720	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfce42f43	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x03439003	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0d1f22d0	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x483ac492	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x4f5c2123	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x59d943c8	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x79d98244	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x87b13c3e	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x970b77bc	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x9f7d49bb	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xb365fa95	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xcbd296d0	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd01c3340	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xdb05d97d	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xea541b80	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xfdee048c	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x06c4a32e	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x308e22eb	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x36eae013	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x4c320139	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x5681665a	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x7e72fb93	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x9444ea9b	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xb4f47de9	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xcba32c78	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xd2e8b507	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xd568f374	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xd5b3bb06	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xef7321c2	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x06848b4f	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x14269660	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x156d9e9a	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x442affc9	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x47c5a859	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x4b740296	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x89465208	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xab172dae	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xaef3febe	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xc7198f6a	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xc988c158	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd09ac015	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd767f398	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x362c2005	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x47281d12	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xb5fa7759	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xbc2d2412	ipcomp_destroy
++EXPORT_SYMBOL_GPL sound/ac97_bus 0xe6bc75e7	snd_ac97_reset
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x4a8195ab	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x5954292a	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/core/snd 0x4056107e	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd 0x46d92a0c	snd_device_initialize
++EXPORT_SYMBOL_GPL sound/core/snd 0x78757160	snd_device_disconnect
++EXPORT_SYMBOL_GPL sound/core/snd 0xb7ba9926	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd 0xb7ce30c8	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd 0xcf953392	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL sound/core/snd 0xd024c08a	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x389bc339	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x5158d14b	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x75230961	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x83f582d8	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xabad44c6	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xad6f172e	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xe27a3a8b	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xee791f47	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xfe7af512	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x188a372f	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x2ac11cd8	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x372dbad3	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x42a70324	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x5d6f32ed	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x73ddbbd2	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xa73a7edf	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xb4c3d93b	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xba105f1f	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xdc2fc632	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xefde7d71	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x02a633a1	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x12dac3f0	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x50324e68	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x57cb4254	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x6103ad2b	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x78fa9017	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xe0fc2398	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0033be34	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x006fc33b	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0155c3e1	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x05d55a57	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x06b2f674	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0924e507	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0aed2c8f	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0b019e2a	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x13e9c8fb	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x15156212	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x15de06a9	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x17ac0396	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x186ebd5c	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1ef00bed	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x28f2e11f	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2e9388c5	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x413d12df	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x42069ac6	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4422fc42	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x48c5aa04	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x492db876	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4c77eebd	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4ccf72b8	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4fc3e69c	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x533ee054	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x544a62c9	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x55ea9416	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5a784813	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5db2aacc	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5e721209	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x63f2fb4f	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x684d8676	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6d4af999	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6ece4346	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x70d67c11	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x73fc8bbc	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x73ff46a2	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x783c5839	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7a8a88c0	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7ec0ba0c	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8222b262	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x840b3006	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8bd108fd	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x91e1e9ac	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9ae4ed1d	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa4e29588	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa7b0afa7	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa98150b1	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa9eceed2	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xab725b2d	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xad3bb77e	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb7ce49a9	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb8f83621	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb99daec2	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbad924c1	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc142bb9f	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc2260373	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcd482251	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcf273e88	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd051eafd	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd24b993d	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd78b5b0e	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xde364830	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdea3c518	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdf92cd00	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe662064b	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xebdba487	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xec4e7bc4	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf4321c0f	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf947b2e2	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfc057f3a	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x27dc7c38	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x4109f2fb	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x81c66b03	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xcb4ef198	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xcd41d767	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xeca82bdc	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x01e4d483	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x02869cfc	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x04e16500	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x05032796	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x053b34af	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x090a9e2b	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0a30bc87	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0d3bd44a	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0d801e58	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0e847122	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x147fecd3	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x158cad8a	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x17223faf	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x185a5469	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x190aae98	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x19a44185	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x261a6749	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x280bb1d6	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x28b3823a	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x28d846e8	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x29f97767	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2a1a1b22	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2d90e74a	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2f68c5bd	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x30af5b11	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x30bc2bc0	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3d19c414	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3d818edd	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3e450f8d	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4d85566c	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4e24425e	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x56f18160	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5a829cf3	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5e1d80c8	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5f84bbc4	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x632179e6	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x672c6338	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6964abd3	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6a68acd0	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6b219b3e	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6b329cd3	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6b33c07c	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6c0a45b8	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6c193569	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6f6abd2b	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7135f9e3	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x72f6a55c	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x785cf4e1	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x79633797	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7a5a4e0a	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7c1bdbba	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7e4a68b0	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7f5a223e	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x808e8962	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x82eccb64	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8e0eb144	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8e4303d4	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8f96c81a	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9188305c	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x94f61108	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9600b08c	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x96a638c7	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9806bfdd	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x996a6900	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa0f7ea56	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa39447d2	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa3b14bc2	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa620f335	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa6c50662	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa75f7af4	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa8f07725	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xada181f6	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb13a3800	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb26f2ff6	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb80da27d	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb9726120	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbbbc18ac	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbcc1c943	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbd849361	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbdac7f26	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbecc4352	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc45c1852	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc477b28c	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc76b4890	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc99dece8	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcab6eabf	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcbb93208	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcbea5888	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcc170b04	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xce1f1a39	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xceaf2dfe	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcf116f0a	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcf5b1ee4	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd1e715fd	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd412a0d8	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd43bc2fe	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd7114120	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd77ea919	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xda14ccc8	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdb81ca8e	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe043986f	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe109618f	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe4370911	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe5be0398	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe70115c0	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe795c894	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe9285206	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeaa6e396	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xed8766e2	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xee2d2ef1	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf0279e13	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf03000ef	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf18bb826	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf1cab010	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf37c00e9	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf61a48a7	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf72919fd	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf766a80c	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf9efad1e	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfb39b429	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfb596c26	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfbbd0663	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfbc5217f	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfc7caa0e	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x05e35bac	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x0b94ae0b	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x1585939b	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x44a5931b	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x4a1f73ce	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x642ad372	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x86f2de72	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x9b943582	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xa03827d3	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xa1261328	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xa4bc2006	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xaf40e507	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xbb941f21	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xc084b7ad	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xca7122c3	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xd0292cc8	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xd26cd91a	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xdbf61794	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe712fd00	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xeda36503	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xf33ac589	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x7d05786f	cs4271_dt_ids
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xc3d8d52f	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xc51b420f	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xbf638dbf	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xbfeb1c4b	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x5afef306	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x8c876018	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x9d7f74a8	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x34d6d0c8	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0xd7dda028	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98090 0x241ca6ae	max98090_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x188142f7	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x55063f01	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x9c15f814	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xa88d8d3b	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x70617a04	rl6231_get_clk_info
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x7f68b24d	rl6231_pll_calc
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x8d7fa148	rl6231_get_pre_div
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0xdba4502f	rl6231_calc_dmic_clk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0x3e81021d	rt5645_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0x4e7d624a	rt5645_set_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677 0x353b33c1	rt5677_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677-spi 0x0414ffa7	rt5677_spi_write_firmware
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677-spi 0x8d584a9f	rt5677_spi_read
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677-spi 0xd658ccf9	rt5677_spi_write
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x2765c5f1	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x85f25e36	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x86b9a016	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xdd370573	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xf51f60f6	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0xe5f96733	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x32cead2f	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0xcc3276f3	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x5ac34972	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xa9f9fad8	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0x9ce3c363	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x071827ec	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x8d06873b	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xa0bdf544	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xec01137a	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0xb107d187	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0xf90c02d1	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0xa555f3c3	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0xedf62bac	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0x7e78a386	asoc_qcom_lpass_cpu_platform_remove
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0x8a0ca204	asoc_qcom_lpass_cpu_dai_ops
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0xaba35299	asoc_qcom_lpass_cpu_dai_probe
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0xba652082	asoc_qcom_lpass_cpu_platform_probe
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-platform 0xae160151	asoc_qcom_lpass_platform_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x03dc13bf	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x098d2c78	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0bd47a5c	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x11837e44	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x12cc95b7	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x13cad695	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x152a974a	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1aed5b90	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1db37b8d	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1e30a778	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1e676d1b	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1fb1a7c5	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1ffd40ed	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x20f0cd9f	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x23f14109	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x23f1a776	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x244b4556	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x29232ba7	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x292b0881	snd_soc_resume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2b73648a	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2bb1774a	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2c56e27d	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2d06f073	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2d8364b6	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x32bf9d4a	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x36dc90e5	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3ceba97f	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3d978d0e	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3f33fcfc	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4006bde8	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4040e895	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x41d56eb1	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x43a566b9	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4484c1b1	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x451ab423	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x466139ab	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x491b4929	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4b2b86b6	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x504166dd	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x513117d7	snd_soc_component_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x51af3d20	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x53d97f0d	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x54b7f147	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x581d6a87	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x598a6141	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5a933b75	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5a94063d	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5b92718b	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5d88e2f9	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6058e2dc	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x62566480	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x628a8b6a	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x63ef2185	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x64a173a4	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x67fc0778	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x697d0812	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6a75b9bb	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6b9bc5e8	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6ddbe09d	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6fec4f8a	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x71552721	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x73658305	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7a74ba40	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7cc3495c	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e852642	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7f4ebc80	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x806032ed	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x80ba8351	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x81652f37	snd_soc_component_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x85335e62	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x86235903	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x86d6d247	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8783bac1	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8786d174	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8e2deb2c	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x90f1dd59	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x91213661	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x926c95a7	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x92d7ae14	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9427c66e	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9699b717	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x97a55f8a	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x97ca9e09	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9a529e28	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9aa606cf	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9f119eab	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa0b07ac7	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa1e6ab35	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa23781d9	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa42c4c34	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa562a65f	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa5b47537	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa6c551fe	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa98bb2cb	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa9a935e6	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xaa64f67d	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xac69c007	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xacdf247e	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xad840477	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xaee4da20	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb27161ca	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb5367e07	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb69ee640	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb733487f	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb78ba51d	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb7c54b68	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb8387d68	snd_soc_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbb5fda91	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbc803b74	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbccc77e3	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbdf462f7	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc3e2f024	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc3e85bbd	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc575ea11	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc66d6845	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc94d45ab	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcb7bb298	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcbc2a9e3	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcdbb1aa5	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcee7966c	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcf850b67	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd27cbd0b	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd3f90b89	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd449b9b1	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd606e92c	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd629beb9	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd8c2a8b6	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd9616256	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdad182f7	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdcfd1bc5	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdd9860a7	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xde14f7a9	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdebde15f	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe140f865	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe2414b9a	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe27a8dc9	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe581a402	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe8b1f0fb	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf09268d3	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf0ce4960	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf167b4c1	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf1d636de	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf837e36d	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf84dbe42	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf98e41b6	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfa4eb02f	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfae398a7	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfbef4dac	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x03bc7402	line6_write_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x058cbf78	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x4b08215b	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x7fc3e2d9	line6_read_serial_number
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x87b1c3f1	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8d94dd59	line6_suspend
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x9cf521d9	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xae03de02	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xb4bdf529	line6_send_sysex_message
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xc52855ec	line6_read_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xce7beae4	line6_pcm_acquire
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xd079cb26	line6_version_request_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xd99add49	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xf07d5614	line6_pcm_release
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xf4961b88	line6_init_midi
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x3fe35aea	irq_bypass_unregister_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x418873cc	irq_bypass_register_producer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x888c5be5	irq_bypass_register_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0xf6e772c3	irq_bypass_unregister_producer
++EXPORT_SYMBOL_GPL vmlinux 0x000727e6	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0x00418287	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x0054e764	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0058dd62	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x007a86e4	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00bc8bd5	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0x00da0734	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x00f9ca74	of_usb_host_tpl_support
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x014c03cd	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0x015d4436	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x017bb602	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0x0199be18	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0x01c6cb0c	cpu_cluster_pm_enter
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x01e1dc10	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x01f4a648	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0x01fc230b	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0x0200ea5e	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x022029ee	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0x022fe091	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0x02362a8a	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x024f5b41	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x026c17cd	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0x02731983	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x0273526a	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x0293a800	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x02af4867	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0x02cf3cd9	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x02d8aa42	xenbus_map_ring_valloc
++EXPORT_SYMBOL_GPL vmlinux 0x02d9bf87	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0x02da7200	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x02e90b0d	nd_numa_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x0321cdbf	of_alias_get_highest_id
++EXPORT_SYMBOL_GPL vmlinux 0x03275457	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x0345555a	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x034648ed	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x03482ed8	of_irq_parse_raw
++EXPORT_SYMBOL_GPL vmlinux 0x03535d7a	of_reserved_mem_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x036175d0	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x037aff07	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x03853ded	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0x0389b853	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03a70861	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x03a94e5d	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x03a9e18e	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x03adafea	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x03c2597e	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x0402cbbf	preempt_notifier_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0405f950	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x04064796	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x043b935f	__tracepoint_io_page_fault
++EXPORT_SYMBOL_GPL vmlinux 0x043dd02d	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x043f39fd	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0x044c3a12	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x049a5259	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04b5d2d1	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x04c29301	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x04c3f2c1	gnttab_empty_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04d4e5a5	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0x04df8fbc	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0x04ec17a5	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0x04f59392	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x050b10ae	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0x050bb5dc	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x051d986c	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0x053494cb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0x0534e309	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x054014e8	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0x054116cf	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0x054cc119	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x05573fd7	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x05577955	of_console_check
++EXPORT_SYMBOL_GPL vmlinux 0x055d8fb8	of_get_display_timings
++EXPORT_SYMBOL_GPL vmlinux 0x055ff12e	xen_xlate_remap_gfn_array
++EXPORT_SYMBOL_GPL vmlinux 0x056b063d	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x057db067	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0x05813fea	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x059f085d	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0x05b651cb	mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x05de7276	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0x060e4a9a	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0x0611d53a	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x064517f7	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x06ad3eda	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0x06bbcf2e	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x06cab725	xen_dbgp_reset_prep
++EXPORT_SYMBOL_GPL vmlinux 0x06d549e6	pinctrl_free_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x06dc75c1	thermal_zone_of_sensor_register
++EXPORT_SYMBOL_GPL vmlinux 0x071f5752	of_property_count_elems_of_size
++EXPORT_SYMBOL_GPL vmlinux 0x0732d786	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0736aae4	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x073ba9a9	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0x074be532	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x075c8daa	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0x075f4c98	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x077eedf8	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x078eeab6	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x0790fb80	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0x079939f4	devm_regmap_init_vexpress_config
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07c8bdea	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x07e0dcea	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0x07e54717	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0x07eeb243	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x08034a59	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x08080b88	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x080817a1	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0x0808f36d	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0x0809a147	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0x080a7639	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x080b171d	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x0828e143	pinconf_generic_dump_config
++EXPORT_SYMBOL_GPL vmlinux 0x084535d4	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0x0860da59	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0x0867b1bb	of_devfreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x08719d3b	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x08729f1f	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x0874b3b6	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x087c2603	of_irq_parse_one
++EXPORT_SYMBOL_GPL vmlinux 0x088bfa7e	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x08974957	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0x08a32e26	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x08b6d934	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x08bc0870	compat_put_timespec
++EXPORT_SYMBOL_GPL vmlinux 0x08c654c2	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0x08e52062	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x08f0f2a0	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x090c1275	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0x0919e9a5	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x094bab42	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x0952af60	fb_videomode_from_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x095509dd	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x0956becd	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x096c89f4	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x097adb57	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x0983b9ae	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0x098886a3	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0x0993407f	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0x09ab86d6	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x09b09b29	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0x09d1195f	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x09ed1151	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0x0a027bed	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0a071c27	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0x0a26ecb5	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0x0a495443	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x0a6b8326	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0a87efff	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x0ab0e4c3	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x0ab74684	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0x0acfa48e	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0x0ade4d4f	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x0ae99bde	dev_pm_opp_get_suspend_opp
++EXPORT_SYMBOL_GPL vmlinux 0x0aeda021	of_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x0af4a2a9	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x0af8455f	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b212df4	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x0b4cf31a	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x0b52d745	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0x0b6b4b34	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x0b76054d	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0x0bb256bd	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0x0bcc14da	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x0bd56790	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0x0be13fff	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x0be29f64	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x0bf68452	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c130827	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c367827	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0x0c80e3fe	efivar_init
++EXPORT_SYMBOL_GPL vmlinux 0x0c9d77d8	usb_acpi_set_power_state
++EXPORT_SYMBOL_GPL vmlinux 0x0ca95934	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0x0cb8061f	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0d085af2	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x0d1a7e41	thermal_zone_of_sensor_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0d222e30	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x0d37c14f	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d4a5658	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x0d539781	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x0d699ebb	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x0d7a7e2d	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0d95871d	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0x0da1f692	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x0da295c6	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0x0da6a3db	to_of_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x0da74c6e	is_dock_device
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0df0889c	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0e007edf	xen_evtchn_nr_channels
++EXPORT_SYMBOL_GPL vmlinux 0x0e047d86	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0x0e2a80f0	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0x0e38202a	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0x0e382f89	cpu_topology
++EXPORT_SYMBOL_GPL vmlinux 0x0e48c501	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0x0e5ba5ed	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x0e857eaf	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x0ea41f64	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x0ebb8180	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x0ecf823a	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x0ed4b19b	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x0edadc32	acpi_dev_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0f012044	__tracepoint_detach_device_from_domain
++EXPORT_SYMBOL_GPL vmlinux 0x0f044b39	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0x0f2260e9	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x0f2d2fa9	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0x0f312e86	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f39dc07	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x0f6ebbeb	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f885976	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x0f9b28c3	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x0fe2d182	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x0fe2d570	xenbus_directory
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x10165981	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0x10166f06	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0x103278e7	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0x104c9927	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1052c8c7	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0x1078a8ce	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x108fa72f	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x10ba2f4c	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0x10d326d2	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x10da60bc	acpi_gpiochip_free_interrupts
++EXPORT_SYMBOL_GPL vmlinux 0x10e2b409	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x10edf404	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x10f63ed6	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x1108690f	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0x111d0d08	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x113f2335	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0x113f5397	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0x1148d40b	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x114988f8	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x1169ac49	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x117201c1	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x1179f2c9	of_overlay_create
++EXPORT_SYMBOL_GPL vmlinux 0x11821d33	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0x11879cc8	xenbus_read_otherend_details
++EXPORT_SYMBOL_GPL vmlinux 0x11b56d59	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x11c25e57	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0x11caddc7	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x11e7a24a	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x11ff059c	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x120cc828	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x121e40ec	kvm_get_dirty_log_protect
++EXPORT_SYMBOL_GPL vmlinux 0x122075d6	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x1223ec95	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x125a121b	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0x1263e462	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x1295d57c	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0x12b17889	dev_pm_opp_of_cpumask_remove_table
++EXPORT_SYMBOL_GPL vmlinux 0x12bace49	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x12cb5ef6	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0x12d903c7	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x12e0be2b	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x12fd878b	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0x130de01d	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0x1318fde4	of_get_fb_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x13791b5a	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x138aff76	gnttab_init
++EXPORT_SYMBOL_GPL vmlinux 0x13ad647f	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x13b89dee	pinctrl_request_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x13b94d6b	kvm_vcpu_gfn_to_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x13ce87e8	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0x13d19998	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x13df9827	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x1400127c	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0x1428b5ce	efivar_entry_set_get_size
++EXPORT_SYMBOL_GPL vmlinux 0x143098d1	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x14321080	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x14339760	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x145e179b	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x14c82778	user_update
++EXPORT_SYMBOL_GPL vmlinux 0x14f4ac2e	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x152b1f9a	acpi_dev_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x153fbb81	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x15757029	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x15c77b61	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x15d802fb	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x1617f275	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x1620e94e	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0x162ebf91	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x1670084d	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0x1677a4e4	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x1696faa4	dev_pm_opp_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x16b8a4fe	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0x16bff484	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x16c0958f	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x16f4c780	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x16f7cb14	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0x17326a4e	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0x1740e33c	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1755326b	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x178333eb	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x178dd6f6	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x17a18aa1	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x1809afd2	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0x180bbd5b	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x180c57ca	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0x181c6a38	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x181ca621	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x184e524c	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x184f5b7e	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x18522ddb	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x18603301	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x1863f79c	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x187b7511	dev_pm_opp_of_cpumask_add_table
++EXPORT_SYMBOL_GPL vmlinux 0x189695a5	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x189f45d4	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x18a2b380	mark_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x18add928	xen_swiotlb_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0x18ae68a8	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x18b38126	__nvdimm_bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x18c4838c	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0x18db9cec	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x18f83fab	gnttab_grant_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0x19119803	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x19450f5b	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x1947e466	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x1965f735	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x19a2a541	dev_pm_opp_get_freq
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19a36c72	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x19b39dad	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x19bf6224	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x19c66b23	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x19ddc584	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1a1e6ede	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1a369c02	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0x1a38a574	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0x1a482458	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x1a497655	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x1a5e574d	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1aa960cd	of_dma_is_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x1ac98f2e	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1b0c5448	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0x1b0e74e6	__clk_mux_determine_rate_closest
++EXPORT_SYMBOL_GPL vmlinux 0x1b22cd62	dax_clear_blocks
++EXPORT_SYMBOL_GPL vmlinux 0x1b297d1b	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x1b356377	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x1b4949e2	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x1b4d9afd	nd_region_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x1b4ec9df	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x1b588577	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x1b5e8ec7	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x1b746245	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x1b8822d8	pinctrl_gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x1b96ef33	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x1b99eaa1	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x1bc3e133	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x1bc5eebe	pinctrl_gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x1bc9a8a9	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x1be3e7e3	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x1bf79554	xenbus_unmap_ring
++EXPORT_SYMBOL_GPL vmlinux 0x1c0e74a8	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1c1f7305	__xenbus_register_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x1c207064	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x1c3933fd	clk_register_fractional_divider
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c5e3dbb	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x1c5ff742	clk_get_phase
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1c898a29	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x1c93df42	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x1c949507	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x1c953b16	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1c9baaea	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0x1cc93ef6	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0x1ccced9c	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x1cce687d	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x1cdb2147	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x1ce37750	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0x1d1b4c31	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d5e5247	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0x1d652735	__tracepoint_attach_device_to_domain
++EXPORT_SYMBOL_GPL vmlinux 0x1d739e1c	xen_set_callback_via
++EXPORT_SYMBOL_GPL vmlinux 0x1d73b4d5	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1d7cb586	clk_register_fixed_rate_with_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x1d802119	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0x1dc3b52d	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x1dd31d73	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0x1de6e54b	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0x1def880e	bind_interdomain_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1df9fd02	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0x1e2372ef	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x1e353fac	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0x1e3b7950	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0x1e420cd6	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0x1e593e8c	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e68ce14	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0x1e6ae5c0	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e83fee6	HYPERVISOR_physdev_op
++EXPORT_SYMBOL_GPL vmlinux 0x1e872da4	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1e9903b4	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x1eadd8b6	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebac2bd	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ecc368a	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x1ecf367f	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1ef66522	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x1f064eaf	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0x1f131579	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1f3d8432	of_platform_populate
++EXPORT_SYMBOL_GPL vmlinux 0x1f4172ec	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x1f490044	acpi_cppc_processor_probe
++EXPORT_SYMBOL_GPL vmlinux 0x1f5cddf5	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x1f5e4cbb	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0x1f6e9a77	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1fa05f68	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x1fb111f9	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0x1fdb7161	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL vmlinux 0x1fef2190	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0x1fef6bd0	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0x2018b8cd	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x202e4180	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x203e5470	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x20497c5a	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0x205a42f3	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x20938d8d	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0x20986a11	kvm_vcpu_init
++EXPORT_SYMBOL_GPL vmlinux 0x209cdff5	pinctrl_utils_add_map_mux
++EXPORT_SYMBOL_GPL vmlinux 0x20a283a6	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0x20aa6f51	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x20b7a0f9	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x20c3967c	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x20c86f0e	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x20daebb4	of_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL vmlinux 0x20e81d61	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x20ec9737	acpi_subsys_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x211ca02e	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0x212a3ee3	pinctrl_dev_get_devname
++EXPORT_SYMBOL_GPL vmlinux 0x21466a34	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x214ccaa4	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x2173ae76	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0x21771b81	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0x2192c3c7	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0x2196ce4a	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0x21a563da	clk_get_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x21a99ca4	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21bd635f	vchan_init
++EXPORT_SYMBOL_GPL vmlinux 0x21c5e605	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x21c8e723	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21ddac44	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x21eb73b2	of_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x21ebeea6	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x221eb471	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0x222e906f	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0x223cf9d7	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0x2245c5f4	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x224604fa	dev_pm_opp_add
++EXPORT_SYMBOL_GPL vmlinux 0x2253aab1	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x22bdf47b	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x22d134c9	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x22fb6b28	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x23003aaf	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0x23059b51	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x2315a82c	clk_mux_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2315b184	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0x23344c6b	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0x236556c4	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x2366a2c0	errata
++EXPORT_SYMBOL_GPL vmlinux 0x23680181	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0x236c0b42	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0x23703e36	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x2396c7f0	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0x23a09498	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0x23b23f23	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0x23b797db	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x23fc8519	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0x24011e14	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x24016ba7	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0x2402bb1b	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x2436e347	of_clk_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0x243b192b	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x2444eadf	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x245394b6	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x24563693	acpi_device_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2496c461	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24c7698a	xenbus_write
++EXPORT_SYMBOL_GPL vmlinux 0x24d2bfec	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x24e57c4a	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0x24e84718	of_pci_msi_chip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x2520a5d6	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0x252ea6c0	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x25379e73	clk_set_min_rate
++EXPORT_SYMBOL_GPL vmlinux 0x2545c170	unregister_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x2579c995	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0x258bea37	xenbus_switch_state
++EXPORT_SYMBOL_GPL vmlinux 0x25c94816	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x25d72c5b	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0x25e5c14f	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x25f33ed3	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0x25ffe268	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0x261594f8	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x2648fa82	clk_hw_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x265b1cab	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0x265dd9f3	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0x26655ce5	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x267b6cdb	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x268fe1e4	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26bb5b7a	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x26c3db49	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26f1428a	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x26f7dde2	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL vmlinux 0x27087d3c	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x27178b45	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x272532f4	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x2729bfb2	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x273d1c17	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x273f5f44	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x274cf5e1	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x274fcf82	gnttab_map_refs
++EXPORT_SYMBOL_GPL vmlinux 0x275173b7	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x277e15fa	efivars_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x277f34de	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x2780ca0b	pinctrl_dev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x27c0c4be	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27d354b1	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0x27e72428	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x27f37ff2	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x2807af62	of_css
++EXPORT_SYMBOL_GPL vmlinux 0x281c3bd4	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x282ca723	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x28304b1d	pin_is_valid
++EXPORT_SYMBOL_GPL vmlinux 0x283a7a23	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0x2840556b	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x2841e284	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x2861bbee	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0x286349d6	of_genpd_del_provider
++EXPORT_SYMBOL_GPL vmlinux 0x28669007	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x28a2e03a	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x28a74cb5	pinctrl_utils_dt_free_map
++EXPORT_SYMBOL_GPL vmlinux 0x28d8a10c	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0x28e05fcb	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x28f211d2	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0x28fbcc58	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x29066ea1	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x29094607	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x290997b2	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0x290d6a4f	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0x290d87a8	acpi_dev_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x2911da24	nd_blk_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x291b60c5	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0x293aa830	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x294df28e	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x2970094e	ata_acpi_gtm_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x299cdb35	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x29b3d5b8	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x29b52a00	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0x29caf42f	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x29ed2130	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x2a461033	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a72832d	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0x2a787eab	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0x2a81be35	xen_remap_domain_gfn_array
++EXPORT_SYMBOL_GPL vmlinux 0x2a8286dd	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0x2a8334de	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0x2a8c2142	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x2a95cbd2	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x2aacacb3	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0x2abfc540	kvm_init
++EXPORT_SYMBOL_GPL vmlinux 0x2ad605cd	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x2ad9d24d	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x2ae013f4	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x2af63321	acpi_dev_resource_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x2b07debf	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0x2b116fc8	__tracepoint_add_device_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x2b11cea3	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x2b1f3266	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b29ba94	kvm_read_guest
++EXPORT_SYMBOL_GPL vmlinux 0x2b351382	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2b505bbd	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x2b59dae5	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x2b5ccd21	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0x2b5e2ec3	acpi_dma_request_slave_chan_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x2b952517	clk_has_parent
++EXPORT_SYMBOL_GPL vmlinux 0x2b9ddab2	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0x2ba62b0f	pinconf_generic_dt_node_to_map
++EXPORT_SYMBOL_GPL vmlinux 0x2ba6d944	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0x2bc5662a	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x2bd9bede	clk_fractional_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2bdfa79b	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa985e	nd_cmd_dimm_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2bfd3356	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x2c1cef9c	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c4f0b53	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x2c70d584	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x2c744fc5	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0x2c7d9c64	xen_store_interface
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c97f8a2	of_reconfig_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2c9c140a	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x2cb3b718	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0x2cd0b218	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cece7b4	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0x2d08e17c	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x2d18d81e	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x2d19924f	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d230128	acpi_device_update_power
++EXPORT_SYMBOL_GPL vmlinux 0x2d2e053d	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x2d3c4d6e	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d5aaceb	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2d6d3061	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x2d8cad24	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0x2d977df2	gnttab_unmap_refs_sync
++EXPORT_SYMBOL_GPL vmlinux 0x2d98d23d	xen_swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2da4034e	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x2da8cbe5	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x2dac6883	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x2db7cfbb	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x2db8d5e6	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x2de0b6c7	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x2de5d76f	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x2df84ec4	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0x2e0857e5	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x2e1bf3eb	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x2e1da9fb	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e39196f	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x2e435842	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0x2e5d14da	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x2e8867f1	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0x2e8bbad9	kvm_write_guest
++EXPORT_SYMBOL_GPL vmlinux 0x2e9670c0	pl320_ipc_transmit
++EXPORT_SYMBOL_GPL vmlinux 0x2eb22264	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ec509c6	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0x2ec534d4	xen_swiotlb_map_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x2ec53d99	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2ec96cfb	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0x2ecf411e	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0x2efd84bc	max_gen_clk_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f37f098	xen_swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f64415f	unregister_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f6c29ea	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x2f7a7c99	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x2f83c425	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0x2fa0bf21	efivars_register
++EXPORT_SYMBOL_GPL vmlinux 0x2fa32ca2	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x300cfa9f	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x300e8bed	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x30153d89	xenbus_watch_path
++EXPORT_SYMBOL_GPL vmlinux 0x3020816f	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x304e4ad3	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x3079f9d3	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0x307e538f	__xenbus_register_backend
++EXPORT_SYMBOL_GPL vmlinux 0x308d0d11	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0x309496c0	kvm_write_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x309fbdd9	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x30a4627e	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x30c819d2	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30d3cf24	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x30dd94e5	clear_foreign_p2m_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x3128865c	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x313d7f79	acpi_pci_check_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0x3141f2bd	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x31433e6b	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x3150e4db	pinctrl_remove_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x3152b9da	acpi_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x317d3703	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0x318dba34	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x31bb89f4	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31d03fa0	dev_pm_opp_of_get_sharing_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x31d73541	xen_xlate_unmap_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x31f4619e	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0x31f5b8c2	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0x3205b1ac	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0x321132f8	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x321bdbb1	compat_get_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x3227df6f	kvm_vcpu_read_guest
++EXPORT_SYMBOL_GPL vmlinux 0x32441cb8	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x325e677c	gnttab_grant_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x327cb845	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x328915c0	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x328c7930	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x32bc0fcf	preempt_notifier_dec
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32eb20c3	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0x3326d61f	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0x33506c51	xenbus_unmap_ring_vfree
++EXPORT_SYMBOL_GPL vmlinux 0x3350c615	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x33554ded	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0x33579d47	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x33831c26	cppc_get_perf_caps
++EXPORT_SYMBOL_GPL vmlinux 0x339ad9ba	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x33a347f8	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0x33d3dfd8	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x33fc179b	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0x34436d17	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x3447fa22	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x3459dff6	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x3474a3ba	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x3474d7d9	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34a8da5f	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0x34ce9d9b	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x34d9d7a5	nvdimm_create
++EXPORT_SYMBOL_GPL vmlinux 0x34e0e062	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0x34f5956c	kvm_vcpu_gfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0x350633b0	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x352650ee	gnttab_batch_map
++EXPORT_SYMBOL_GPL vmlinux 0x3541d4dc	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x354b222f	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x35503dc5	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x357daddc	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x35bf2acd	nd_fletcher64
++EXPORT_SYMBOL_GPL vmlinux 0x35e4ed2c	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0x35fec963	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x36247e21	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3625a48c	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0x363f1dde	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x3656cd1c	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x36674b86	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x367eed23	kvm_get_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x368f1fea	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x3692835b	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36b826d9	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x36bda7b0	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x36c43263	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x36d5d8c6	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x36e2eeee	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x36e3614e	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x36e39024	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0x36e702fe	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0x36eab37e	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x371dbd7c	gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x372d07fa	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0x372ddd35	mpc8xxx_spi_tx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0x37376cfc	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x373c8a8d	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x375fda1e	acpi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x37698f5f	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x377d6e80	user_read
++EXPORT_SYMBOL_GPL vmlinux 0x3783e8c2	of_irq_parse_and_map_pci
++EXPORT_SYMBOL_GPL vmlinux 0x37980c9d	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0x37b14f4b	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x37b9e43b	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x37ccab90	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x37fa9bd8	pl08x_filter_id
++EXPORT_SYMBOL_GPL vmlinux 0x37fed6f4	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x380cf537	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x380edecf	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0x381069c8	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x3824b2c9	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x382e7f97	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x38304231	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x383600a2	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0x384a6981	__gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x384d0b21	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0x38639300	of_overlay_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x38b21dcd	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0x38b2c484	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x38e02884	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x38e5bc5a	clk_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x38ee470a	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x38f9e7ab	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x390e126d	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0x39239c6e	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x392fe739	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x3954a269	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x39597d25	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x397598ee	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x39897224	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0x3990bad0	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0x39927625	irq_of_parse_and_map
++EXPORT_SYMBOL_GPL vmlinux 0x39b19eaa	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x39bfbc70	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x39eeea91	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0x3a0203c2	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a3db234	divider_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a6775d4	of_dma_get_range
++EXPORT_SYMBOL_GPL vmlinux 0x3a84f528	of_get_display_timing
++EXPORT_SYMBOL_GPL vmlinux 0x3a87f9a1	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3aac9a90	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x3aadb3a4	of_thermal_is_trip_valid
++EXPORT_SYMBOL_GPL vmlinux 0x3ab867b6	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3ad0e201	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x3ad1e524	unregister_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x3addc7d5	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0x3ae3329d	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x3ae4eca8	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0x3b05cd41	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0x3b3b820f	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0x3b3fb3dc	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0x3b547bc9	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x3b676edd	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3b7bb80f	efivars_kobject
++EXPORT_SYMBOL_GPL vmlinux 0x3b92b1eb	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0x3b9d3225	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0x3bcaca18	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x3c290984	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x3c382643	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x3c3862fc	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3c3b3221	kvm_vcpu_write_guest
++EXPORT_SYMBOL_GPL vmlinux 0x3c5d460b	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x3c7a8d48	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x3c831441	arm_check_condition
++EXPORT_SYMBOL_GPL vmlinux 0x3c8882e7	mpc8xxx_spi_rx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3c9c9e13	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3ccd436f	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cdc3904	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0x3cf013cb	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x3cf76b98	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x3cfb7134	of_clk_src_onecell_get
++EXPORT_SYMBOL_GPL vmlinux 0x3d057eb2	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0x3d1e58f3	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x3d1ebbc3	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3d3273b1	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d4e5fde	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0x3d5f392d	acpi_os_unmap_memory
++EXPORT_SYMBOL_GPL vmlinux 0x3d64abc6	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x3d669013	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x3d7ea99a	gnttab_grant_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x3d8dd34f	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x3da67a23	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x3dc526a9	arizona_of_match
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3ddeeba9	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0x3ddfa951	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3def8e08	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3dfc436e	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x3e1f72e0	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL vmlinux 0x3e2d6df3	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3e375c28	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x3e3950f6	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0x3e4b8b3c	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0x3e55ec6c	clk_gpio_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e740b03	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0x3e7a2f7e	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x3e7fe7c2	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x3e900e6f	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x3e926d21	clk_debugfs_add_file
++EXPORT_SYMBOL_GPL vmlinux 0x3ea39e84	xen_swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x3ea60e7c	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3eb63593	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3ebd0bc0	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x3ec8e671	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3ef3a71c	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f01b364	of_usb_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x3f2c0f8e	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x3f30b883	of_irq_get_byname
++EXPORT_SYMBOL_GPL vmlinux 0x3f49cfb8	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0x3f4f5bcc	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0x3f52c651	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0x3f648286	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0x3f84d4c9	gnttab_release_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x3f907237	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x3fa5af9c	nd_cmd_bus_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3fb974b3	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x3fdb5e45	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL vmlinux 0x40053394	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x400a024b	acpi_scan_lock_release
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x404ec0e8	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x40a1b554	acpi_initialize_hp_context
++EXPORT_SYMBOL_GPL vmlinux 0x40a8d1e7	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40d4fb5d	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0x40dbc442	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x40e73a6c	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x40e8237a	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x40f396a8	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0x414f5535	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0x41502f73	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0x415ba6d5	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x4190042e	nd_mapping_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x419a0bf4	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0x41a13cee	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x41a60abc	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x41b32f40	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x41de6a5a	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0x41e4c749	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0x4213a51a	efivar_entry_set_safe
++EXPORT_SYMBOL_GPL vmlinux 0x422f58b0	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x4235d31d	clk_register_gpio_mux
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x4259f14f	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x42635d55	pm_suspend_global_flags
++EXPORT_SYMBOL_GPL vmlinux 0x427de547	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x42823660	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x428c8b1e	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0x42a7dd6f	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x42b8556a	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0x42d2ca92	iommu_capable
++EXPORT_SYMBOL_GPL vmlinux 0x42d79467	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0x42f133c3	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4312f61b	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0x43184f29	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0x432671ba	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0x432c16f6	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x433a5041	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x43619e1a	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x438d8df2	iova_cache_get
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43b466b0	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x43c2a786	__cpu_clear_user_page
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43d510e5	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x43d98114	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x43e78954	nd_blk_region_to_dimm
++EXPORT_SYMBOL_GPL vmlinux 0x43f0b02d	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x43f2a60c	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x43f73ba9	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0x43f81957	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x43fd8aeb	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0x44140109	ata_acpi_cbl_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x443a2f7d	of_property_read_u32_index
++EXPORT_SYMBOL_GPL vmlinux 0x444f1735	cpu_pm_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x446b2a59	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x446e3c47	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0x4474f2db	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0x4479f0aa	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x449aa69d	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x44a793ab	HYPERVISOR_grant_table_op
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44de3140	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0x44e16ccc	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x44e1e9aa	balloon_stats
++EXPORT_SYMBOL_GPL vmlinux 0x450cea8d	xenbus_watch_pathfmt
++EXPORT_SYMBOL_GPL vmlinux 0x450fb522	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x45489c6b	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x4576337f	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x458255b7	xen_swiotlb_sync_single_for_device
++EXPORT_SYMBOL_GPL vmlinux 0x4587c452	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x459b34e7	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x45a34de4	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x45aff401	max_gen_clk_probe
++EXPORT_SYMBOL_GPL vmlinux 0x45b05c72	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0x45be423b	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45d1a7b3	pinctrl_register
++EXPORT_SYMBOL_GPL vmlinux 0x45e0cec4	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x45e32e62	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x45f138c9	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x46066e5b	perf_pmu_name
++EXPORT_SYMBOL_GPL vmlinux 0x460ab1ea	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0x461a2e5d	clk_register_divider
++EXPORT_SYMBOL_GPL vmlinux 0x461bb269	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0x46297db5	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x46390cce	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x463ef60e	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x4642e9aa	acpi_dev_add_driver_gpios
++EXPORT_SYMBOL_GPL vmlinux 0x4659b2e5	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x4661024d	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x466e3ef6	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x467ed88b	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x468dfeaf	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0x46b650fa	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0x46ca36f0	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0x46ce49da	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0x46f46e11	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x46fd31cb	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0x47112ff0	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x4713484e	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x471c55f2	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x471daf86	clk_register_divider_table
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x4752984b	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0x475beb18	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x477a190d	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x477b1206	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0x477ed1c4	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0x478424cb	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x4785519b	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47b4d25b	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x47b96b15	clk_register_gpio_gate
++EXPORT_SYMBOL_GPL vmlinux 0x47c4f7fc	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x47d0eea2	acpi_lpat_temp_to_raw
++EXPORT_SYMBOL_GPL vmlinux 0x47de0dc7	clk_unregister_mux
++EXPORT_SYMBOL_GPL vmlinux 0x47e48cd8	arizona_of_get_type
++EXPORT_SYMBOL_GPL vmlinux 0x47ea0ada	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0x47f67fff	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0x4828e77b	acpi_scan_lock_acquire
++EXPORT_SYMBOL_GPL vmlinux 0x485021f2	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0x48586d90	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL vmlinux 0x486634aa	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x487326f7	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x489355d0	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0x4895eda2	of_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x48adf8f5	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x48b32053	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x48c84813	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x48e43504	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x48e9dc90	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0x48f612e3	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x48ff5070	xen_swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x493376b3	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x4992059e	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x499806d6	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x49dd75ef	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x49e0fd21	__cpu_copy_user_page
++EXPORT_SYMBOL_GPL vmlinux 0x49e8074c	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x49feb496	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x4a1cd5fd	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0x4a35c1d8	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x4a420d09	acpi_bus_detach_private_data
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a62e590	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x4a657d3b	pinctrl_utils_add_map_configs
++EXPORT_SYMBOL_GPL vmlinux 0x4a72e6c0	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x4a8b75e8	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x4a90160e	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x4a945624	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4acde6f0	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x4adc40b9	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x4ae56fdf	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4ae82044	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0x4af56a26	free_iova
++EXPORT_SYMBOL_GPL vmlinux 0x4b01c9e6	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x4b22cf9e	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0x4b33d651	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4b4a4c9f	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x4b5b6a43	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0x4b604af9	xenbus_grant_ring
++EXPORT_SYMBOL_GPL vmlinux 0x4b72c4f4	amba_apb_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x4b8541c0	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x4bc5a1b9	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x4bcdcb5e	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c645f9e	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x4c7ac74d	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4ca0cb10	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x4ca1b389	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0x4cd43668	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x4cd566a8	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d0f59ea	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x4d185105	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0x4d393a54	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0x4d47af35	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0x4d56c375	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0x4d70d889	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x4d91f430	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x4d96da25	acpi_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0x4d9d75b6	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x4da4d78f	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x4dc0a874	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x4dc5d7f6	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0x4dc6f4f6	efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0x4ddc20ab	of_platform_depopulate
++EXPORT_SYMBOL_GPL vmlinux 0x4ddedc42	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4dfcc2cf	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e113519	elf_hwcap
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e2b42a0	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0x4e48b401	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x4e5f3efa	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4e67af8a	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x4e6f56f2	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4e926b11	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0x4e9782ea	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x4eae0827	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x4ebb1465	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4eda17f8	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4ede37f4	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0x4ef2dc8d	pinctrl_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f05925c	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4f08b6d1	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0x4f0c8aa8	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x4f1999b9	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f378f3e	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0x4f5069b3	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4f781379	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x4f98d766	cpu_pm_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4fa001bb	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0x4fab11ab	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0x4fb118bc	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0x4fb66559	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0x4fbada8d	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4fcb6237	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4ff9ad1e	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x50035c2d	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x5005b69e	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0x50075a10	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x5011e2ee	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x501b6297	to_nvdimm
++EXPORT_SYMBOL_GPL vmlinux 0x50233774	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x5026585c	xen_irq_from_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x503f0dfb	xen_swiotlb_set_dma_mask
++EXPORT_SYMBOL_GPL vmlinux 0x5047202a	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x505261f0	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x505f796b	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5068e20a	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x506cec73	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0x50837001	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x509654ec	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x50b80599	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50f63a52	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x510bd618	xen_unmap_domain_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x5117b500	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x5121385a	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0x5121cce9	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x512c17a8	xenbus_probe_devices
++EXPORT_SYMBOL_GPL vmlinux 0x5143b473	device_move
++EXPORT_SYMBOL_GPL vmlinux 0x514b9327	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x514e9875	divider_get_val
++EXPORT_SYMBOL_GPL vmlinux 0x51606299	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0x5187ac4b	xen_store_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x5191bd3c	efivar_work
++EXPORT_SYMBOL_GPL vmlinux 0x519bdada	acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x51abc305	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0x51bb991d	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0x51c62eb2	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x52182b32	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x521e6fc7	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x522f538b	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x523324a1	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0x52415ee9	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x5265363b	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0x5272d8bc	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0x52a41251	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x52ae6191	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x52c8f60c	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x52d35f18	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x52f75139	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0x53073226	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0x5310a5a8	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x53313e00	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x5365b04d	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x539ba031	arch_pick_mmap_layout
++EXPORT_SYMBOL_GPL vmlinux 0x53a3bbea	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x53ad40af	xenbus_map_ring
++EXPORT_SYMBOL_GPL vmlinux 0x53efc2e4	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x54215db5	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0x543fca58	of_prop_next_u32
++EXPORT_SYMBOL_GPL vmlinux 0x54473115	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x547afd49	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x547d25d2	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54aa7108	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0x54b0ff56	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x54bd7f0d	mmput
++EXPORT_SYMBOL_GPL vmlinux 0x54d3b42c	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x54e1d488	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x55021407	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0x550ee0c3	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x551fabb9	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0x5533862f	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x55526907	xen_features
++EXPORT_SYMBOL_GPL vmlinux 0x55619a01	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0x556aac3a	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0x556e4390	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x5575a3aa	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x55879900	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0x559f2b4e	of_clk_parent_fill
++EXPORT_SYMBOL_GPL vmlinux 0x55bb62c8	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x55d800fd	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x55e6e762	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x55f7cd12	of_clk_add_provider
++EXPORT_SYMBOL_GPL vmlinux 0x5606adb5	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x561b5fa8	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0x5624c671	acpiphp_unregister_attention
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x563a8149	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x56401158	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x564226d5	dev_pm_opp_is_turbo
++EXPORT_SYMBOL_GPL vmlinux 0x56529601	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x565447b2	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x565c09f2	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x565ee25e	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0x566465e8	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0x567a0c5e	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0x5680542e	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x568c1862	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0x56947347	dmi_walk
++EXPORT_SYMBOL_GPL vmlinux 0x56c21b81	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56e9103b	cpu_pm_enter
++EXPORT_SYMBOL_GPL vmlinux 0x56f63a64	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x570ac4dd	alloc_iova
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x573e3690	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x575c5f94	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0x575eeefe	gpiochip_add_pingroup_range
++EXPORT_SYMBOL_GPL vmlinux 0x57670662	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x5775bed5	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0x5779d445	xenbus_exists
++EXPORT_SYMBOL_GPL vmlinux 0x577c5f93	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x578bc17e	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57ab95f2	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x57c86f20	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x57e24f4f	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x57f28e45	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x57f7f501	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0x57f8062c	acpi_dev_resource_io
++EXPORT_SYMBOL_GPL vmlinux 0x58086e8e	vchan_find_desc
++EXPORT_SYMBOL_GPL vmlinux 0x58110346	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x581e6ed1	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x585d1f82	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x587a561c	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x588ffbf2	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0x58958b43	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58a9d916	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x58d936e1	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x58e14f15	HYPERVISOR_event_channel_op
++EXPORT_SYMBOL_GPL vmlinux 0x58eca86b	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x5915ed00	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0x59984724	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x59b05cac	clk_hw_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x59b2adbf	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x59b58738	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0x59c49e7e	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0x59cac3a2	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x59f40659	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x59ff7a28	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0x5a02967f	kvm_read_guest_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x5a15499c	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x5a2b1b67	gnttab_free_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5a37baa7	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0x5a3dc24c	acpi_node_get_property_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5a609c59	gnttab_foreach_grant_in_range
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a845851	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0x5ac68de9	power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x5ad7bd0e	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0x5ae6118c	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x5ae79466	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0x5aef8808	pci_fixup_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x5af03a28	gnttab_claim_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5afbc8bc	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x5b19a82c	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0x5b32620c	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5b51395d	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0x5b5534a5	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x5b57ba22	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0x5b86f05a	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x5bb59242	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bd4970b	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5be8c2de	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0x5c27f55c	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0x5c28d977	of_alias_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x5c2e21cf	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0x5c5917c8	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c66e90c	efivar_run_worker
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cb95cb6	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x5cb9de67	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x5cbbc62a	devfreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5cd04eb1	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x5d0e5b2d	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d12f373	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x5d366dec	gnttab_cancel_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0x5d4cb6a0	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x5d54084e	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x5d55722e	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0x5d56fa74	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0x5d5734b9	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x5d6f5189	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x5d828eae	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5da77452	kvm_put_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x5daea356	clk_hw_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x5db18786	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x5db2b9d6	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x5dbef774	of_fixed_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0x5dbf8815	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5dcd7160	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x5dde35d2	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x5de38807	of_dma_router_register
++EXPORT_SYMBOL_GPL vmlinux 0x5df5bcdf	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e61bf19	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0x5e66439e	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x5e8b8e44	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x5eb891f7	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x5efa61c9	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x5f16b820	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x5f226035	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x5f3abca3	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0x5f61558f	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0x5fc27be9	acpi_dev_irq_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5fec6d15	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x5ff52bbd	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0x5ffdb9b7	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x60091316	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x6015e6e6	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x6018af5a	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x603603e4	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x60442822	phys_to_mach
++EXPORT_SYMBOL_GPL vmlinux 0x604d470f	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x60506567	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x6076d7ea	efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x60b68057	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x60df526e	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x612050d0	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x615159fc	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x615a881f	devm_pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0x617c0d42	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x61a54419	of_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0x61ae4e8d	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x61c66ae1	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x61ca6c2e	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x61cde409	acpi_dev_resource_memory
++EXPORT_SYMBOL_GPL vmlinux 0x61d7f610	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x61e0abd3	mpc8xxx_spi_rx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x61ea233e	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x61f243fd	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x6202519b	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0x620ac713	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x620b6e1f	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0x620bf64b	cppc_set_perf
++EXPORT_SYMBOL_GPL vmlinux 0x6214b16c	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x62197ba2	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x624173db	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6264c011	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x6274b64a	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0x62924c82	nd_cmd_in_size
++EXPORT_SYMBOL_GPL vmlinux 0x62a558b1	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x62bd5a6d	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x62dd8cd2	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0x62ea2c57	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x63150e06	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x631bf29c	pcc_mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0x63223427	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0x63304059	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x63329c37	default_iommu_map_sg
++EXPORT_SYMBOL_GPL vmlinux 0x633d05ac	dax_zero_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x6340a25a	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0x635993cf	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x635a7abc	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0x638e7c8a	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0x63c9bf6b	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x63e17b86	divider_recalc_rate
++EXPORT_SYMBOL_GPL vmlinux 0x63ebcef1	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x63f14ebe	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x640683ce	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x6415c022	nvdimm_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x64318593	acpi_dev_filter_resource_type
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x644781ef	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x644d7b14	find_module
++EXPORT_SYMBOL_GPL vmlinux 0x6452b545	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x646d4887	pinctrl_select_state
++EXPORT_SYMBOL_GPL vmlinux 0x647209ab	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0x647537f3	pl320_ipc_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x64b27250	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL vmlinux 0x64cb95a8	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0x64e80dfb	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x650d23a0	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x6579f4be	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65de0503	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x65e78d97	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0x65fc5100	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x66012b84	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0x660721c9	xenbus_alloc_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x660cf4ad	of_property_read_string_helper
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x6616a142	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x661d9c77	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x664fdf65	vcpu_load
++EXPORT_SYMBOL_GPL vmlinux 0x6664bd37	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x66661183	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x66918a31	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0x6696411b	usb_acpi_power_manageable
++EXPORT_SYMBOL_GPL vmlinux 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x66ab55c2	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0x66b9b7dc	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x66bcb855	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0x66bd8b90	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66ed025b	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0x67012b9b	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0x671117b3	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0x671eda66	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6739a503	balloon_set_new_target
++EXPORT_SYMBOL_GPL vmlinux 0x6740f2f6	of_clk_del_provider
++EXPORT_SYMBOL_GPL vmlinux 0x674a0a22	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x674eb7ba	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x67516d76	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0x675281ce	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x676ad5ef	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x677689a6	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x679b1359	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x679b8f50	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x67cca607	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0x67cd6f01	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x67e4a24f	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x67e7ba99	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x6806d6d4	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x681578fe	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x68187066	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0x681ae195	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x6828e4b2	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0x682bae85	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0x68517eb2	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0x685d2ad0	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0x686e2d92	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0x688e23a7	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x68975d13	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x68b8fcd6	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x68c20662	clk_register_mux
++EXPORT_SYMBOL_GPL vmlinux 0x68cbed37	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x68f59400	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x690d9a30	xenbus_dev_fatal
++EXPORT_SYMBOL_GPL vmlinux 0x6921aa34	compat_put_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x6926277d	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0x69347a39	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0x69370070	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x693ada78	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x69448669	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0x69597723	gnttab_unmap_refs
++EXPORT_SYMBOL_GPL vmlinux 0x6966d235	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x697ae409	of_get_nand_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x69810015	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x699012ed	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x69ae066e	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x69c6c688	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x69ed50c9	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0x69f04353	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0x6a02ed73	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0x6a1271cb	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a2fdc13	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a569bc3	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a6cafd2	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a936feb	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x6a97eef2	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6aa9a280	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x6aaae8fc	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x6abae301	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x6acad21f	acpi_get_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0x6aeb79aa	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x6b0dc565	xen_set_irq_priority
++EXPORT_SYMBOL_GPL vmlinux 0x6b18546e	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0x6b1bb0f8	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0x6b20597d	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b424128	of_resolve_phandles
++EXPORT_SYMBOL_GPL vmlinux 0x6b46c8f1	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x6b6764d0	dev_pm_opp_find_freq_floor
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6b9e9e56	pinctrl_utils_add_config
++EXPORT_SYMBOL_GPL vmlinux 0x6bb6c8a2	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0x6bd13ea5	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x6bd90ffe	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0x6bda211d	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x6bf1b90d	dmi_memdev_name
++EXPORT_SYMBOL_GPL vmlinux 0x6c07bef2	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c1904b1	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6c389761	acpi_bus_get_private_data
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c515aff	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x6c61a15b	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x6c655913	register_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6c836af4	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6c8c21ce	of_property_read_u64
++EXPORT_SYMBOL_GPL vmlinux 0x6c8daffe	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0x6c9aae76	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6ce8d429	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0x6cf47ecc	vcpu_put
++EXPORT_SYMBOL_GPL vmlinux 0x6cf66d64	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x6cf816d9	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0x6d0a0fd7	xen_swiotlb_sync_sg_for_device
++EXPORT_SYMBOL_GPL vmlinux 0x6d0c3ad8	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x6d1b43dd	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x6d249b51	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0x6d2a644e	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d354cb5	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x6d447ed1	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x6d52a1a7	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x6d5a458d	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0x6d6cb45b	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0x6d7e10ad	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6d802a0b	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0x6ddd51ed	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0x6de7a30a	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e0f31c8	irq_chip_ack_parent
++EXPORT_SYMBOL_GPL vmlinux 0x6e58ddf0	gnttab_end_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6e8b57b3	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x6e906fb4	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6e95264a	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x6e9a7d3e	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0x6ea93f5a	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x6eb593c4	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0x6ec50638	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0x6ed7e436	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0x6ee05c4b	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0x6ef96962	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x6f124a2c	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x6f145325	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6f147de0	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x6f18d1ec	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0x6f1c7bbf	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f210d9f	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x6f241188	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0x6f25d9f4	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x6f36f606	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0x6f402ba6	acpi_dev_resource_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x6f42fbf0	acpi_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x6f433ffd	__free_iova
++EXPORT_SYMBOL_GPL vmlinux 0x6f5199b6	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x6f51fda5	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0x6f63a813	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6f673b3a	xenbus_dev_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x6f79e47a	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x6f7c3e89	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6f9e49c0	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x6f9f3890	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6fcae8e8	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x6fd14912	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6fd35319	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x6fdbfc63	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6fe92080	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x6ff0c23b	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x70104d3b	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0x70118c4b	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x704e9a07	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x7064da8b	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x709017d1	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0x70a789a2	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x70b7eab5	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0x70b97089	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70c91637	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70e493ba	otg_ulpi_create
++EXPORT_SYMBOL_GPL vmlinux 0x70eab0b4	acpi_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x70ecf41a	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0x70ed51fd	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7106bccf	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0x710b2f43	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x71374bf4	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x7179ed04	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0x718643aa	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x719e17ff	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x71c52da5	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x71c54107	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71dca6a1	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0x721e9aa7	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x722d069b	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x722dc962	devm_acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x723456c1	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x723e5bc0	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0x725436ff	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7275dff7	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x72864e0a	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x7290aa85	fsl8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7295e701	of_pci_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0x72a514b7	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x72babb7f	__dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0x72e2f348	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0x72ec394b	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0x73013896	xenbus_printf
++EXPORT_SYMBOL_GPL vmlinux 0x731947f3	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0x731a623a	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0x7321c01b	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x73378a39	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0x733c888d	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7364dd90	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x73675e23	register_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73ac895c	of_dma_configure
++EXPORT_SYMBOL_GPL vmlinux 0x73c2554f	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73debeec	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x73ea029e	clk_hw_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x73fa2112	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0x74301787	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x74454148	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0x74499da6	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x7459fcd2	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x746ecd5d	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x74861e05	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x749fb923	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x74a22ad4	pinctrl_lookup_state
++EXPORT_SYMBOL_GPL vmlinux 0x74a8b202	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74da3c0e	acpi_gpiochip_request_interrupts
++EXPORT_SYMBOL_GPL vmlinux 0x750596a3	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0x750aca25	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x750e4fcd	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x750e7d34	ulpi_viewport_access_ops
++EXPORT_SYMBOL_GPL vmlinux 0x75133f6e	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0x751b716f	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x7526000a	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x7534975f	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0x754228de	efivar_entry_set
++EXPORT_SYMBOL_GPL vmlinux 0x755f7d25	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0x7568ebbb	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x757b49d2	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0x75802938	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x759139cb	of_pci_check_probe_only
++EXPORT_SYMBOL_GPL vmlinux 0x75ac93d3	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0x75c35695	pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0x75c3eae8	pinctrl_add_gpio_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75d80971	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0x75dc1382	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0x75e4fc28	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x762a0be6	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0x76590f45	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x765eaf1d	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0x765f455e	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x76999a26	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0x769c6b63	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x76aaa2f7	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x76b10d5b	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0x76c49af1	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x76cab0a6	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x76d9b876	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0x7712771a	unbind_from_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x7742cd75	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x7757b51a	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x776b3d91	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0x7774b0e2	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x77b60414	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x77b835cf	of_get_nand_ecc_strength
++EXPORT_SYMBOL_GPL vmlinux 0x77b9ec66	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x77c41e16	cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x77f9c4e2	dev_pm_opp_get_opp_count
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x785f9263	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x787c882b	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x789c3b1c	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0x789eff28	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0x78ae7a14	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78b5cdfe	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0x78cc5bec	hugetlb_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x790c80a9	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794667cf	acpi_get_psd_map
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x795a93fd	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x7995c5e9	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x799fb71a	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0x79a3f0d7	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x7a01fd01	kvm_read_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x7a0b59ee	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0x7a0c8a84	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a30fd84	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x7a319404	clk_register_fixed_rate
++EXPORT_SYMBOL_GPL vmlinux 0x7a3e97fc	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x7a519ab9	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x7a546be5	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7a679604	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x7a8b7986	of_thermal_get_trip_points
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7aa6285a	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL vmlinux 0x7ab2f064	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x7ac8e5b0	acpi_gsi_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7adeb87a	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b2163bd	HYPERVISOR_tmem_op
++EXPORT_SYMBOL_GPL vmlinux 0x7b3354e7	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x7b41240b	dev_pm_opp_of_add_table
++EXPORT_SYMBOL_GPL vmlinux 0x7b661483	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0x7b678562	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x7b70ed5c	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x7b90d1a9	bind_virq_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7b9135be	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x7b94c3aa	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0x7b952271	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0x7b957987	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x7bba23d7	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0x7bba2402	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x7bd9a283	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0x7c004e17	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x7c147be2	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x7c16d540	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x7c1722f6	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0x7c1907fe	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x7c34ed44	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0x7c39b6ea	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7c8123b1	init_iova_domain
++EXPORT_SYMBOL_GPL vmlinux 0x7c889463	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0x7c96a6f2	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x7c9a7371	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x7c9c8d4e	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x7c9eec07	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0x7ca81022	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x7cb06816	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0x7cb65406	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0x7cbd6dfe	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0x7cc53b51	xenbus_dev_is_online
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7cd8c6e5	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cedf677	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7cf37d48	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x7d00c65b	nd_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x7d3ecd57	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d5dd4d1	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0x7d742ffe	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x7d87fc51	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7d982202	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0x7d9d79d4	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x7da81251	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7db9e524	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x7dca0518	HYPERVISOR_multicall
++EXPORT_SYMBOL_GPL vmlinux 0x7dd7be86	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7de65a03	acpi_lpat_free_conversion_table
++EXPORT_SYMBOL_GPL vmlinux 0x7deb73b4	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7df65884	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x7df6ba19	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x7e064eb4	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x7e0ca40e	pinctrl_utils_reserve_map
++EXPORT_SYMBOL_GPL vmlinux 0x7e115070	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x7e133671	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x7e2cb40b	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x7e43cdb8	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0x7e4841cb	pinconf_generic_dt_subnode_to_map
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e64d7b5	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0x7e64f6d3	xenbus_frontend_closed
++EXPORT_SYMBOL_GPL vmlinux 0x7e65c0f2	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x7e66c2a6	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x7e7d3bfb	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x7e8152d5	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7ea1a2bc	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x7ea54c1b	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0x7ebd073b	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0x7ec7a5a2	nvdimm_name
++EXPORT_SYMBOL_GPL vmlinux 0x7ecef81a	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0x7ee9ae6d	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x7efa0a3d	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x7efc80cc	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x7f030f55	max_gen_clk_remove
++EXPORT_SYMBOL_GPL vmlinux 0x7f109389	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7f133e68	acpi_dev_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x7f13d491	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x7f21af5e	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f2551a1	of_irq_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x7f379748	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7f8e28d5	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x7f8e49cd	pinctrl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7fa6e70d	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7fc208d1	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7fe4b39a	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x8013dbe6	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x8035eba1	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x813b9a1a	of_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8141817b	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x8143b386	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8152e111	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x815588a6	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8165c4a8	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0x8169c38a	dmi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x8170ccef	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0x81717e2b	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL vmlinux 0x81772466	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x817f07e1	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0x81a0485a	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0x81b2f496	mpc8xxx_spi_tx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x81c2ff8d	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0x820aacf7	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x820e15ff	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x8237de11	nvdimm_volatile_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x8272b9d9	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x82781d01	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x82873d20	of_clk_get_parent_count
++EXPORT_SYMBOL_GPL vmlinux 0x828ed8c3	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x82b18e88	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x82c86670	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0x82c885da	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x82d41c1a	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82e9c4be	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0x82f01e93	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x834faca6	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x836c588b	gfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0x83742948	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x83764323	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x839bb420	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0x83bdaf16	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x83c1fb75	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0x83c7c860	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x83e42537	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x83ee0635	dax_fault
++EXPORT_SYMBOL_GPL vmlinux 0x84039e73	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x841bb359	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x84298aa7	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0x84368bed	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x843d70ef	acpi_is_root_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x8444deb3	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x8487a2b6	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x84aabda6	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x84bfac29	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x84efa89a	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x85024844	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x8506baa8	clk_unregister_gate
++EXPORT_SYMBOL_GPL vmlinux 0x850df8b9	clk_divider_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8515fce1	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x851882b9	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x851f1efa	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x8533f4a2	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x853e9dbe	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x85c3d483	of_irq_to_resource_table
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85d0f8d5	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x85d7211c	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x85da6367	pinctrl_find_and_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x85ffa4bc	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8617cb32	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x86623fd7	notify_remote_via_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8666a7c5	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x866b33df	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x866fa680	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x867cf98b	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x868e73c6	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x868fb4c6	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x86a51007	gnttab_end_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x86a65d91	amba_ahb_device_add_res
++EXPORT_SYMBOL_GPL vmlinux 0x86a94554	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f3f49b	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x86f4d5ce	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8702e548	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x870e16b7	xen_test_irq_shared
++EXPORT_SYMBOL_GPL vmlinux 0x8722a885	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8723b979	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x87362f1b	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x874800ce	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x87672d85	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0x87a5b10e	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x87b28cd5	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x87c9e4b0	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x87ceb73f	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0x87dd74a0	of_clk_src_simple_get
++EXPORT_SYMBOL_GPL vmlinux 0x87e52483	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0x87f8846a	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x88136838	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x883208d1	of_fdt_unflatten_tree
++EXPORT_SYMBOL_GPL vmlinux 0x883c2740	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x884a805a	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0x886b3439	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x886b5575	dt_init_idle_driver
++EXPORT_SYMBOL_GPL vmlinux 0x88776f1c	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0x887e54a0	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x8898b7b6	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x88a223ed	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88c0a5c0	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x88ec4c0c	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x89013f17	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x8914d4ea	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x891a5a7f	gnttab_max_grant_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x8924f677	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x892b26a0	set_memory_nx
++EXPORT_SYMBOL_GPL vmlinux 0x892b48a3	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8932eaae	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0x8939b143	__clk_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x893c5cab	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x8945ccf3	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x894fbf33	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x896a6e63	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x8978952c	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0x89aa8574	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0x89ac492f	kvm_vcpu_gfn_to_hva
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89bd0e97	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x89d282fb	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x89ea6e27	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0x89fab6a9	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0x8a0f1fc8	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x8a25cc8e	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x8a449163	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0x8a4b61d3	pinctrl_dev_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x8a554a36	mpc8xxx_spi_strmode
++EXPORT_SYMBOL_GPL vmlinux 0x8a559846	gnttab_setup_auto_xlat_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a78989f	irq_from_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x8a9306c1	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x8a943181	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0x8aa507fc	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x8ab0a000	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8ac1cf2c	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x8ac728c9	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x8acaba21	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0x8ad96aac	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8ae2fe24	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x8b03c71a	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x8b04668e	bind_interdomain_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x8b0d1765	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x8b149c36	clk_is_match
++EXPORT_SYMBOL_GPL vmlinux 0x8b1f4e3e	pinctrl_get_group_pins
++EXPORT_SYMBOL_GPL vmlinux 0x8b353f6c	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8b56d75c	genpd_dev_pm_attach
++EXPORT_SYMBOL_GPL vmlinux 0x8b5edf69	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8ba5afe9	HYPERVISOR_memory_op
++EXPORT_SYMBOL_GPL vmlinux 0x8bc72122	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x8bd8e006	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x8bec2d55	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0x8bf1299f	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c06a108	xenbus_transaction_start
++EXPORT_SYMBOL_GPL vmlinux 0x8c154607	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x8c1ef03e	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x8c25413b	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x8c365d59	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x8c642361	xen_swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c659b6c	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0x8c7238e2	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0x8c72a970	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c95767b	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8c96dde8	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0x8c987d40	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x8ca1e204	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8cae54b5	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x8cb577bb	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8ce1720b	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0x8cea765f	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x8cf9f262	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x8cfaad17	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0x8cfb3326	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0x8d046f52	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x8d1ff7ab	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d372ea9	xenbus_free_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x8d7fc280	xen_swiotlb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x8d855bfa	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0x8d8a3817	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x8d9fa235	acpi_os_map_iomem
++EXPORT_SYMBOL_GPL vmlinux 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x8dabcac2	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0x8dbf7aaa	privcmd_call
++EXPORT_SYMBOL_GPL vmlinux 0x8de07726	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL vmlinux 0x8e2b25c2	videomode_from_timings
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e3001d2	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0x8e3cc019	put_device
++EXPORT_SYMBOL_GPL vmlinux 0x8e8af9e4	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x8e9736f6	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x8eab694e	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x8ebbc651	__clk_get_hw
++EXPORT_SYMBOL_GPL vmlinux 0x8ee9694e	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x8eff2bba	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f35b7a0	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0x8f563853	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8f58de86	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8f600f21	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f843080	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x8fa78a22	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8fa98c05	xen_swiotlb_dma_mapping_error
++EXPORT_SYMBOL_GPL vmlinux 0x8faac947	clk_register_gate
++EXPORT_SYMBOL_GPL vmlinux 0x9009602a	acpi_bus_get_ejd
++EXPORT_SYMBOL_GPL vmlinux 0x901c09e6	inet_csk_compat_getsockopt
++EXPORT_SYMBOL_GPL vmlinux 0x9028194d	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x9033c293	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x903bb65b	acpi_dev_resource_ext_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x908d827f	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x908fe032	acpi_ec_add_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0x90930f15	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90b763f1	HYPERVISOR_console_io
++EXPORT_SYMBOL_GPL vmlinux 0x90d8e4b4	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x90e0def6	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x90efb40b	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x90f37aed	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x9108ee8d	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x910a7c99	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0x910da37d	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x912bca1a	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0x913f39a9	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9141806f	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0x9146524e	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0x9156f276	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0x91655545	acpi_cppc_processor_exit
++EXPORT_SYMBOL_GPL vmlinux 0x91722f75	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x91951d42	pm_genpd_syscore_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x91a428b8	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x91aa9618	of_get_nand_on_flash_bbt
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91f0c992	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0x920aacca	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x920cc389	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x924e9581	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x9258a817	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x926f3d00	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x9282ecb1	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x92987d00	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x92a86927	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x92abdeda	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0x92b14cbc	of_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x92b17b1b	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x92b9fa7a	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x92c0f9c4	mpc8xxx_spi_tx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x92d9f078	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92dddf14	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0x92e80a0f	of_platform_default_populate
++EXPORT_SYMBOL_GPL vmlinux 0x9312d80e	evtchn_put
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x935519ce	clk_multiplier_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9367b64d	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x93771404	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0x93846161	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0x9384beb5	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x9384ce87	dev_pm_opp_find_freq_ceil
++EXPORT_SYMBOL_GPL vmlinux 0x93b28e77	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x93d8beb8	acpi_unbind_one
++EXPORT_SYMBOL_GPL vmlinux 0x93dc785b	of_get_nand_ecc_mode
++EXPORT_SYMBOL_GPL vmlinux 0x9400c5af	set_foreign_p2m_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x9405a572	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x943fc708	xen_setup_shutdown_event
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x949f7342	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x94a173be	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0x94c70f61	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x94e236b4	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0x94e62d2e	__set_phys_to_machine_multi
++EXPORT_SYMBOL_GPL vmlinux 0x94ee6c62	of_dma_xlate_by_chan_id
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x9519ffa4	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x9523c906	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x952eb775	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x954f2863	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x9571f1d3	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x9583018b	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x958dc1c1	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x95b78c30	dev_pm_opp_init_cpufreq_table
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95d19a29	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0x95df7148	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0x95ea827e	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x95ffd45d	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x96158b5e	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x96214789	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x9625e652	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x962a8600	reserve_iova
++EXPORT_SYMBOL_GPL vmlinux 0x963422e0	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x964264bd	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x96474e16	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x964add15	xenbus_scanf
++EXPORT_SYMBOL_GPL vmlinux 0x964d5c39	acpi_os_map_memory
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x965a01c7	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9664d82f	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0x968a9b61	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x96946d50	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x9695058f	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x96956b24	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x96a2ee56	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x96b9f6c6	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x96c0f9dc	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0x96f273bb	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x97206fde	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x9723ba6d	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0x9733e6f4	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0x97425499	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x97454da0	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x9746da92	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x974981d8	clkdev_create
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x97646244	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x977f11c8	of_pci_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x97816139	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x9792db97	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x97948f07	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x97c850e2	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0x97ccd69a	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x97d687e3	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x9805d37d	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x981060e8	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0x98128223	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0x98183b06	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x984303ab	clk_gpio_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x98574320	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x98746eb7	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x9874d128	__efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x988ed85d	set_memory_x
++EXPORT_SYMBOL_GPL vmlinux 0x98a2c4ed	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x98b766a1	of_get_nand_ecc_step_size
++EXPORT_SYMBOL_GPL vmlinux 0x98ba1c47	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x98d1507c	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0x98e18068	acpi_is_pnp_device
++EXPORT_SYMBOL_GPL vmlinux 0x98efa53f	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x98f9f73d	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x99152712	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x993d21b5	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x99551030	dev_pm_opp_free_cpufreq_table
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x9973add9	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x9977185c	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x998d79d6	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x9990a79f	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x99a9ff9a	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x99b0fc9b	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99be7dd2	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x99e4a4f8	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a45b07e	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x9a545e31	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x9a6cee13	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0x9a6f2ec3	of_dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x9a7d77e2	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x9a849ab3	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x9a87ab68	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9a923583	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x9aa78e4e	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9ac134ed	__efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0x9acb6480	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x9adb3a22	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x9adb5fc4	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x9ae02b9b	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x9ae65f31	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9aee7ff5	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9b3dc7cf	xen_swiotlb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x9b634e9d	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x9b6b58c9	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x9b709686	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0x9b7a80b2	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x9b7aea8e	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0x9ba2bb2b	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x9bb50477	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9bb94293	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x9bca03ca	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0x9bcb3c23	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c01d795	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0x9c2e4b66	acpi_unregister_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x9c3f0955	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x9c42b950	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x9c4935cc	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0x9c515d05	acpiphp_register_attention
++EXPORT_SYMBOL_GPL vmlinux 0x9c8a7f00	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9c8ccf18	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0x9c93b764	to_nd_blk_region
++EXPORT_SYMBOL_GPL vmlinux 0x9cabe712	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9cb43ecd	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ceed576	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x9d062818	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x9d06688b	register_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x9d1e1244	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x9d296893	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0x9d2bc06c	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x9d31137f	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x9d3850e1	gnttab_alloc_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x9d3bb958	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x9d466ad7	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x9d8ac05f	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x9d96c0a6	nvdimm_blk_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9dd0930d	nd_device_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x9dd5a2d2	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x9dd6c044	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x9e17e3de	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e61ddc9	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x9e7e48d5	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x9e84b7f1	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0x9e86ff61	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0x9e8ca699	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x9e955ff3	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0x9ea1116f	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x9eb18fd3	xenbus_match
++EXPORT_SYMBOL_GPL vmlinux 0x9eb725f7	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x9eb85890	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ef7dfda	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9f00ad33	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x9f2766df	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0x9f472ad4	amba_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x9f517986	HYPERVISOR_hvm_op
++EXPORT_SYMBOL_GPL vmlinux 0x9f5bdb05	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0x9f78d030	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0x9fbdfcc6	iommu_get_domain_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x9fc0e5fe	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0x9fcb8e58	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fe30d1a	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9ff86c1f	of_pci_find_msi_chip_by_node
++EXPORT_SYMBOL_GPL vmlinux 0xa01199b8	efivar_entry_find
++EXPORT_SYMBOL_GPL vmlinux 0xa014a6ac	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0xa03439db	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0xa04bbe7c	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0xa06820b9	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0xa0743c14	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0xa09ef299	of_genpd_get_from_provider
++EXPORT_SYMBOL_GPL vmlinux 0xa0bcbe98	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xa0be15e9	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0xa0c8f3b4	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xa10e0d50	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0xa11216be	xen_store_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0xa1498221	__tracepoint_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xa160c26a	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0xa1695cc5	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa1a663a3	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0xa1c5475f	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa1c980a4	find_iova
++EXPORT_SYMBOL_GPL vmlinux 0xa1ed9c8b	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xa1f79553	xen_create_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xa1ff8887	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xa2159e9b	of_device_get_modalias
++EXPORT_SYMBOL_GPL vmlinux 0xa24fa884	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xa25d8343	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0xa266fa63	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0xa26b6248	dax_pfn_mkwrite
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa2718017	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa28b12c4	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xa2ac5519	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0xa2b48d16	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xa2b9c993	clk_register_fixed_factor
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa30dd2cc	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0xa310f5d4	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xa3222287	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xa32346a7	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xa3408713	dev_pm_opp_disable
++EXPORT_SYMBOL_GPL vmlinux 0xa349bf34	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xa34ee837	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0xa353fffc	xenbus_rm
++EXPORT_SYMBOL_GPL vmlinux 0xa382bd61	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xa384918b	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa386c029	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3a35864	of_fixed_factor_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3e58789	efivar_validate
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa3e8482e	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xa3ed8a48	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0xa40dadca	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xa427ae64	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0xa428e201	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xa42a804e	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0xa437a446	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xa452f2a4	xen_pirq_from_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa457712a	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa461d629	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0xa47792a4	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa4837caa	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa4bbbbfb	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xa4c22e8b	clk_hw_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0xa4e0e1a1	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0xa4eb879b	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xa4ec3611	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0xa516a5a6	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0xa55d942a	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0xa56de409	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xa573f4a0	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0xa5854261	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL vmlinux 0xa5944755	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xa59a3b08	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0xa5ad3a37	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0xa5b32dea	to_nvdimm_bus
++EXPORT_SYMBOL_GPL vmlinux 0xa5c99a1d	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa601131e	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0xa616b28c	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa62892c6	efivar_sysfs_list
++EXPORT_SYMBOL_GPL vmlinux 0xa62cdcfc	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa62e4c78	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xa6345d11	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xa63e682d	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0xa64cafc6	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0xa6647139	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa67959dc	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0xa67c4cd2	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xa68a5d8e	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6bcf97f	acpi_subsys_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xa6c68449	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0xa6debf25	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa714384c	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa738af57	acpi_subsys_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xa73ab21a	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa74f2cac	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0xa77b82bf	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa7841b38	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0xa7925498	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xa7ac7e46	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0xa7c05aff	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa7ccc758	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa7da9db7	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0xa7fbc604	kvm_vcpu_read_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xa7fd1051	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xa801b359	efivar_entry_iter_begin
++EXPORT_SYMBOL_GPL vmlinux 0xa804a39e	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0xa850dafc	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa8a7f414	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0xa8b061da	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xa8b18185	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8b95473	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0xa8cd0e6a	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xa8fb4827	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0xa8fc2004	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0xa900a0b2	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa913689b	xenbus_probe_node
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa935b4b9	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xa952b7eb	acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xa9aef2e1	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL vmlinux 0xa9c1d705	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xa9dc6c98	of_pci_msi_chip_add
++EXPORT_SYMBOL_GPL vmlinux 0xa9dcd7f1	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9e41608	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0xaa0d93f0	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0xaa102bf3	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xaa136511	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0xaa1746cc	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xaa1eaaa4	xenbus_dev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xaa3e6760	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xaa41a148	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xaa62002e	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0xaa70b9d1	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaabcbaa0	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0xaac9e14b	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xaad6ebc6	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xab01acbe	gnttab_request_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0xab117daa	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0xab29ad96	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0xab46f307	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xab4bedf6	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0xab567d31	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab63fbf4	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab86b58f	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xab8ceced	gnttab_batch_copy
++EXPORT_SYMBOL_GPL vmlinux 0xab973d42	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xabab79ed	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabd41786	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xabe262d5	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xabf43a13	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0xac407382	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xac54f272	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0xac61d61a	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0xac642bec	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xac6fbb74	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xace9848e	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xacef9e1d	md_run
++EXPORT_SYMBOL_GPL vmlinux 0xacf721f2	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0xad10fa6f	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0xad2d70be	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0xad3242c0	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0xad3e35c4	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xad5fe647	efivar_entry_size
++EXPORT_SYMBOL_GPL vmlinux 0xad74aa29	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xad827b06	amba_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xad834820	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xad83bce2	clk_register_mux_table
++EXPORT_SYMBOL_GPL vmlinux 0xad9514cf	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0xada912b3	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadd70ac9	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xade6c821	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xae519221	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0xae57927d	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0xae5a0a20	acpi_register_gsi
++EXPORT_SYMBOL_GPL vmlinux 0xae5c6116	device_register
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae6c3cdd	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae7e7e41	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xae81922b	of_overlay_destroy_all
++EXPORT_SYMBOL_GPL vmlinux 0xaeb2c9a2	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0xaeb928aa	acpi_create_platform_device
++EXPORT_SYMBOL_GPL vmlinux 0xaec32b6c	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xaef31438	of_get_dma_window
++EXPORT_SYMBOL_GPL vmlinux 0xaf0e32ed	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0xaf17ca24	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xaf1fe905	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xaf348da7	cpu_pm_exit
++EXPORT_SYMBOL_GPL vmlinux 0xaf58560d	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0xaf90d103	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0xaf9a111a	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0xaf9fed1b	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0xafaefd79	xenbus_dev_groups
++EXPORT_SYMBOL_GPL vmlinux 0xafaf8048	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0xafb07262	__pfn_to_mfn
++EXPORT_SYMBOL_GPL vmlinux 0xafb680ef	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0xafb8a69c	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xafc0e75e	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xafc3f927	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xafc9a40b	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0xafd94a01	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xafedc5b2	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xb005e74d	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0xb00b833e	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xb0213dc8	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xb025ef4e	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0xb02ac411	register_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb0377bc6	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb046d35f	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0xb0604953	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0xb075996a	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0xb0771f25	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0xb077e70a	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xb0b46be1	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0bce4f0	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xb0d1656c	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0xb0fc71da	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xb10da827	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0xb1352f19	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb161bb3a	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0xb172ffac	efivars_sysfs_init
++EXPORT_SYMBOL_GPL vmlinux 0xb17bd66f	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb17f1698	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1ae4061	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb1aeba47	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xb1b370bd	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0xb1b65109	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1f367de	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0xb1f46f83	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0xb205f58c	of_irq_find_parent
++EXPORT_SYMBOL_GPL vmlinux 0xb211436e	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb225f5ad	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb255bc43	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0xb260bfa5	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0xb285b8f8	xen_in_preemptible_hcall
++EXPORT_SYMBOL_GPL vmlinux 0xb287799e	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0xb28b893b	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb28f9084	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb2901560	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0xb29c6a58	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xb2b7fd93	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xb2ba986b	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xb2ce4350	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb2dd090c	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb2e915b3	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb2ea581f	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0xb2f89990	bgpio_remove
++EXPORT_SYMBOL_GPL vmlinux 0xb3018bb4	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb3042981	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0xb31fa773	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0xb32e1334	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xb345f5e7	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xb347bb2c	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0xb3511b55	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0xb355864f	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xb35942c7	kvm_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0xb35a6032	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0xb37aa174	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xb38811a7	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0xb392c21c	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0xb3a69712	dev_pm_opp_of_remove_table
++EXPORT_SYMBOL_GPL vmlinux 0xb3b0f9e0	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0xb3bc2d12	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0xb3c4430f	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0xb3e5794e	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xb400c2e1	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xb401b22e	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0xb4295bcc	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0xb42b99e4	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xb4302cee	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0xb46929e8	of_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xb46d3b90	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0xb478a4c1	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0xb48617c1	xen_dbgp_external_startup
++EXPORT_SYMBOL_GPL vmlinux 0xb494c197	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4bcaa16	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xb4cac147	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xb4d227f0	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0xb4d4c570	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xb4dd16f1	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0xb4e14553	gnttab_query_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb4edf76e	kvm_release_page_clean
++EXPORT_SYMBOL_GPL vmlinux 0xb4fa7465	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb50645f7	kvm_get_dirty_log
++EXPORT_SYMBOL_GPL vmlinux 0xb5159e50	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb5278e98	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xb53418e8	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb54e53d6	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0xb56f999c	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xb5848bae	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb58b3222	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb5942e84	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0xb596bd91	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5b3ffd4	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xb5c37a1e	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xb5e5c069	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0xb5ea1d41	of_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xb5eaeac9	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb5fff9b7	of_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6230f1f	gnttab_grant_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb628e9cc	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0xb62d2a04	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xb6341925	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0xb63c99f6	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb660826c	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xb66421b2	acpi_str_to_uuid
++EXPORT_SYMBOL_GPL vmlinux 0xb6825608	nvdimm_pmem_region_create
++EXPORT_SYMBOL_GPL vmlinux 0xb6917e77	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0xb6942d1e	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0xb6a34c3f	amba_ahb_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6da14c1	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0xb6dee91f	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xb6e6d99d	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb6f3a587	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb700fbc6	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0xb7154114	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0xb7181dc5	kvm_vcpu_block
++EXPORT_SYMBOL_GPL vmlinux 0xb721311e	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb7329c06	clk_set_phase
++EXPORT_SYMBOL_GPL vmlinux 0xb73b740a	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0xb7409268	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0xb78a9658	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xb7a95656	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0xb7a99707	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xb7b00a3f	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0xb7bef2b0	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0xb7f2fe2d	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb81b7789	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb823285b	pinctrl_force_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xb83a05a4	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xb83b50b7	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xb8446948	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0xb86379c7	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0xb866ec42	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xb86d854c	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb8929b67	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0xb8936b22	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0xb8a234ee	hypervisor_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd4560	acpi_dev_gpio_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0xb8d1f25c	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0xb8e5d14c	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb9065f5e	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0xb917b6d7	return_address
++EXPORT_SYMBOL_GPL vmlinux 0xb9216371	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0xb931fdaf	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0xb935e306	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0xb9365cf0	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb93cc84b	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0xb945ace8	__tracepoint_remove_device_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xb956e101	xen_xenbus_fops
++EXPORT_SYMBOL_GPL vmlinux 0xb97bdc62	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0xb99d5837	xenbus_read
++EXPORT_SYMBOL_GPL vmlinux 0xb99fcb80	acpi_bus_trim
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9bdadf9	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9f22512	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0xba1e6aeb	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba323156	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0xba6412a7	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0xba83d177	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0xbaab2b7f	of_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbac5a0ff	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0xbad282ea	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0xbae28c30	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0xbaf49676	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xbaf6d630	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb24b451	rq_flush_dcache_pages
++EXPORT_SYMBOL_GPL vmlinux 0xbb2cb128	of_prop_next_string
++EXPORT_SYMBOL_GPL vmlinux 0xbb2e5c8b	efivar_entry_remove
++EXPORT_SYMBOL_GPL vmlinux 0xbb3e0285	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0xbb406ed3	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0xbb4a3584	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0xbb5e0164	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xbb6f025a	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0xbb72f687	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0xbbd0f49c	of_pci_get_devfn
++EXPORT_SYMBOL_GPL vmlinux 0xbbf5c2c8	of_clk_get_parent_name
++EXPORT_SYMBOL_GPL vmlinux 0xbbf857f3	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xbc054766	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0xbc06c159	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0xbc12f66a	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0xbc1ac2b5	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0xbc3cb16b	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0xbc50ab83	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc744a94	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0xbc7511de	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0xbc9b5317	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0xbc9bcc4b	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcbcdd2f	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbcf48c00	pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0xbd038a83	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd5e6aa8	of_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0xbd606ec6	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0xbd671048	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xbd6d05d9	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0xbd7188bc	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0xbd82e35b	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbd883518	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0xbdb4c490	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbddea563	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbde6ac9e	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xbded2df3	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0xbdf78b08	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe2da513	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0xbe31ad24	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0xbe367a21	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0xbe476e04	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe96dfd8	of_reconfig_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbe985e7e	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbeabd2cf	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xbeade8f8	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbebcd541	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xbecb6b87	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0xbedec016	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbef8fa49	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0xbefa1485	pinctrl_pm_select_default_state
++EXPORT_SYMBOL_GPL vmlinux 0xbefdd96c	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf48bd33	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0xbf4bc22c	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xbf556321	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xbf5e2370	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xbf628e41	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xbf651893	devm_power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xbf74119b	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xbf89987d	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xbf8d1cb1	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0xbf9fc6c8	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xbfeb8301	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0xbfec1d49	ata_acpi_stm
++EXPORT_SYMBOL_GPL vmlinux 0xbffde8ec	compat_alloc_user_space
++EXPORT_SYMBOL_GPL vmlinux 0xc00023eb	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xc00ac7f3	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc00d64f5	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0xc04b1fc6	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0xc04b21bd	acpi_os_unmap_iomem
++EXPORT_SYMBOL_GPL vmlinux 0xc052deee	amba_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0594649	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc069f60e	efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0xc06e3cd3	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0xc07ea3e7	of_mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc0900fcf	acpi_os_get_iomem
++EXPORT_SYMBOL_GPL vmlinux 0xc099a341	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0b97e41	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0xc0c23d7e	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0xc0d0bdde	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc0f9caa3	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0xc10abab3	pcc_mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xc127cb42	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xc14c2824	xenbus_probe
++EXPORT_SYMBOL_GPL vmlinux 0xc156dd39	xenbus_dev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc15b4f48	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xc164642e	xenbus_otherend_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc1a1a4db	of_irq_parse_pci
++EXPORT_SYMBOL_GPL vmlinux 0xc1a7bdc6	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0xc1b8c9be	get_device
++EXPORT_SYMBOL_GPL vmlinux 0xc1c62327	acpi_get_pci_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc1ea24e0	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xc2016f55	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0xc2070153	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0xc2262fab	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc22d77f8	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc2338f68	of_get_videomode
++EXPORT_SYMBOL_GPL vmlinux 0xc23d2d81	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0xc23d8f6a	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0xc257b984	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0xc2610be6	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0xc26351f8	bind_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc27bc911	xenbus_dev_remove
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc294ff32	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0xc2ac3282	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xc2b3e7fa	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0xc2bd7249	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0xc2cb8dd3	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0xc2d7abd8	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc2e75598	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0xc2f07ed6	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0xc2f0b78e	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xc2fc09fa	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xc3053e99	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0xc305b826	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0xc31fa5fc	inet_csk_compat_setsockopt
++EXPORT_SYMBOL_GPL vmlinux 0xc337f76c	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc34a8574	dev_pm_opp_get_max_clock_latency
++EXPORT_SYMBOL_GPL vmlinux 0xc3514e6f	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0xc352cb02	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xc357923c	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xc3664b1e	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc384e97e	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0xc385cb58	perf_num_counters
++EXPORT_SYMBOL_GPL vmlinux 0xc38cc8a5	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc38f36d9	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc39683ab	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc39a79e3	gfn_to_hva
++EXPORT_SYMBOL_GPL vmlinux 0xc3a04506	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc3cea382	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0xc402e842	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0xc41d6f95	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc4292bdc	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0xc42f0155	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0xc444106c	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc45813eb	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xc46981f6	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc49bb59a	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0xc4c6b225	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4e363ba	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc4e9e47b	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc4ffc1ec	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xc5149446	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc537425c	kvm_vcpu_write_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xc5397da6	xenbus_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc542ffd6	acpi_processor_get_performance_info
++EXPORT_SYMBOL_GPL vmlinux 0xc55e495c	dev_pm_opp_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc569d8ce	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc58044c0	nvdimm_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xc5c5b804	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0xc5c66223	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0xc5d681f2	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc5ee6550	kvm_vcpu_gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xc60813cc	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc6242224	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc6327246	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc63dae86	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0xc63e7d93	static_key_deferred_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc65f5cfc	kvm_io_bus_write
++EXPORT_SYMBOL_GPL vmlinux 0xc66019cc	xen_resume_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc69ef7ea	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0xc6a4a872	__clk_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc6b4ba8e	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc6c43839	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0xc6cbd3fe	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xc6cf919f	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0xc6d2c6d9	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0xc6da7a0a	__tracepoint_map
++EXPORT_SYMBOL_GPL vmlinux 0xc6f86205	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0xc7002ac4	evtchn_make_refcounted
++EXPORT_SYMBOL_GPL vmlinux 0xc7061ef3	iova_cache_put
++EXPORT_SYMBOL_GPL vmlinux 0xc710e938	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0xc719c432	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc73f9dc7	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xc7415bbb	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0xc77847a9	dev_pm_opp_set_sharing_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xc77f2236	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc7810075	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc79dcf60	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7b179ea	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7d1951a	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7fa2846	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0xc80256f9	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0xc8094035	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0xc811c3ff	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xc81ca9fc	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xc8276e68	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0xc8455fce	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0xc85d85ef	acpi_dma_request_slave_chan_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc893f932	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8ce5791	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc8ceebfd	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc916e992	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xc929db63	input_class
++EXPORT_SYMBOL_GPL vmlinux 0xc929e6eb	clk_hw_get_parent_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc95e96b6	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc9641b48	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0xc974e66c	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0xc9779dc9	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0xc97d1140	cpufreq_cooling_get_level
++EXPORT_SYMBOL_GPL vmlinux 0xc97e5c5f	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xc9847225	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0xc9a6f330	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xc9b184b3	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0xc9b1c154	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xc9e5036a	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc9fb865e	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0xca33c3e2	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0xca488302	of_devfreq_cooling_register_power
++EXPORT_SYMBOL_GPL vmlinux 0xca5cff31	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0xca6983da	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xca6fb112	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xca72dbc0	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca81ea9a	xenbus_transaction_end
++EXPORT_SYMBOL_GPL vmlinux 0xcab91d83	of_regulator_match
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcad3869d	of_modalias_node
++EXPORT_SYMBOL_GPL vmlinux 0xcaf58713	pinctrl_pm_select_sleep_state
++EXPORT_SYMBOL_GPL vmlinux 0xcb0e56cb	clk_hw_get_num_parents
++EXPORT_SYMBOL_GPL vmlinux 0xcb14c0fb	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb1d1bf6	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0xcb236596	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xcb2ed5a7	ata_acpi_gtm
++EXPORT_SYMBOL_GPL vmlinux 0xcb42cb40	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb5859e2	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0xcb592952	mpc8xxx_spi_rx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0xcb692fba	of_thermal_get_ntrips
++EXPORT_SYMBOL_GPL vmlinux 0xcb883d97	kvm_vcpu_read_guest_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcc057881	of_reserved_mem_device_release
++EXPORT_SYMBOL_GPL vmlinux 0xcc0703ad	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xcc17599d	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0xcc292851	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0xcc2f6a0f	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xcc397b57	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0xcc4dae13	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xcc5cae2b	gfn_to_memslot
++EXPORT_SYMBOL_GPL vmlinux 0xcc608d99	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc98cce6	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0xccaf495f	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0xccbe11ef	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccd65236	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0xcd03b471	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0xcd0e711e	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0xcd46e83d	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xcd6949fd	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xcd7b0337	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xcd80c256	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xcd84b547	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9ab45e	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcdad5539	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0xcdb2b912	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcde10f5e	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xcdf3943d	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0xcdf9799b	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xce151a36	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0xce37466a	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xce3feef3	nvdimm_bus_check_dimm_count
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce7487b8	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xce9ae62d	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xceb1f126	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0xcec9cd23	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcee82549	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xceed8c16	__set_phys_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0xcef18bf7	of_pci_get_host_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0xcf035c1a	phy_pm_runtime_put
++EXPORT_SYMBOL_GPL vmlinux 0xcf497573	xenbus_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xcf54e0ae	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf5c0514	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0xcf61e28f	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0xcf638e2f	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xcf88cd35	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0xcf8bf3f1	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0xcf8f71d0	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0xcf91dcde	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd0048eae	dev_pm_opp_get_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd01b2524	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xd026d518	HYPERVISOR_vcpu_op
++EXPORT_SYMBOL_GPL vmlinux 0xd02bc107	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd0424a53	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0xd0458ccb	xenbus_strstate
++EXPORT_SYMBOL_GPL vmlinux 0xd057c6e2	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xd05a3351	of_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xd0612d57	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd068ce61	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xd0857cdf	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xd0928bed	efivar_entry_add
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0d750c3	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0xd0e7adf0	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0xd10c8df7	acpi_subsys_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd10f90e4	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0xd1109c6a	pci_msi_create_irq_domain
++EXPORT_SYMBOL_GPL vmlinux 0xd11ae2d1	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0xd11b966c	__efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0xd124c086	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0xd1256217	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0xd139868a	__of_genpd_add_provider
++EXPORT_SYMBOL_GPL vmlinux 0xd139f708	nd_cmd_out_size
++EXPORT_SYMBOL_GPL vmlinux 0xd144b77b	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xd146f870	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd14791d7	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xd15460d0	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xd15b95bc	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0xd15df943	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd17b3ba3	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xd181fc8e	of_gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xd185a08a	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd1a65fea	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xd1aa7d8d	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xd1afc849	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0xd1bd8c19	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0xd1e301dd	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd1f64399	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd23bb32e	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xd2401d33	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xd249ee30	bgpio_init
++EXPORT_SYMBOL_GPL vmlinux 0xd25205ed	hugetlb_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd267160e	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd2817892	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xd2a1c430	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0xd2ab202f	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xd2b492fc	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xd2bd938d	xen_remap_domain_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0xd2dcac4e	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2e4a83d	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd322d582	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0xd32a46fe	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0xd32b6da7	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xd334f800	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xd33795d8	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0xd3399042	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd33ada8b	cci_probed
++EXPORT_SYMBOL_GPL vmlinux 0xd34ba057	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0xd361ccff	xen_swiotlb_dma_mmap
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3c5a318	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0xd3dce3da	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd404a937	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd408425f	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xd4093ac6	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd424db81	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xd432a76d	gfn_to_pfn
++EXPORT_SYMBOL_GPL vmlinux 0xd4487fd5	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd4570f58	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xd463caa0	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd468407f	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xd471760e	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0xd47b3a07	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd49b8f81	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xd4a5f503	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0xd4bd66a0	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4c3a952	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xd4c467ba	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0xd4d5bf34	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xd4db2ba7	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xd4e92628	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0xd4ebb116	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0xd52fbb0d	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd53ca083	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0xd552414b	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0xd55545c8	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd56b5f64	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0xd59856b4	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd5ba47ed	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd6097b31	clk_hw_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd622ed70	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0xd638283a	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xd6446ae6	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd6515705	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd6862038	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xd6d4a192	component_add
++EXPORT_SYMBOL_GPL vmlinux 0xd6d8f36c	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0xd6d9c42e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0xd6e17cea	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd7009328	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd70a29e5	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xd728a5c1	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0xd729cc35	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xd72abee5	kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0xd72b2041	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0xd72feba2	xenbus_read_driver_state
++EXPORT_SYMBOL_GPL vmlinux 0xd7399d2a	efivar_entry_iter_end
++EXPORT_SYMBOL_GPL vmlinux 0xd74bb580	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0xd754e362	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0xd76860e8	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd76d355f	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd77f1347	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0xd792294d	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0xd7976f42	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0xd7d1d94e	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0xd7d4470e	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7e95bb3	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd81ff90a	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd8245366	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xd83bcee5	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0xd8408b61	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd88e235d	acpi_bind_one
++EXPORT_SYMBOL_GPL vmlinux 0xd8a6eacf	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0xd8a92c25	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0xd8c455dd	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xd8e7f708	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0xd8f0ef0c	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xd8f157cf	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xd916dd39	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xd932080a	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL vmlinux 0xd933adc0	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd942f78d	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xd9445269	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd94aa457	display_timings_release
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd9876c86	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xd996045e	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xd9a5425d	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0xd9b4a054	devfreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xd9b6bedc	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xd9d7afd6	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0xd9da1c21	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0xd9e25aad	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xd9f10a79	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xda0e3ec4	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xda0ef981	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xda143e35	vchan_tx_submit
++EXPORT_SYMBOL_GPL vmlinux 0xda238d16	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0xda2e37cc	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0xda3600c0	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0xda44b860	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0xda555e9a	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0xda578901	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xda6fc80d	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xda84ff7f	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xda8fabc9	component_del
++EXPORT_SYMBOL_GPL vmlinux 0xda914ac3	of_reconfig_get_state_change
++EXPORT_SYMBOL_GPL vmlinux 0xdaa06dc1	acpi_lpat_raw_to_temp
++EXPORT_SYMBOL_GPL vmlinux 0xdaa0f101	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xdab28e32	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0xdab39f2d	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0xdadc7de9	copy_reserved_iova
++EXPORT_SYMBOL_GPL vmlinux 0xdae1e369	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xdae715e0	videomode_from_timing
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaf0b19a	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdb038eee	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xdb0550a6	dev_pm_opp_remove
++EXPORT_SYMBOL_GPL vmlinux 0xdb18ddfa	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xdb22edd4	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdb31b435	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xdb37b487	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0xdb3c5147	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb5c3dd9	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0xdb636b13	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0xdb63a944	acpi_lpat_get_conversion_table
++EXPORT_SYMBOL_GPL vmlinux 0xdb6ff40c	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0xdb736319	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xdb84da2b	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb915183	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xdb916fd0	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0xdb91e05c	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xdb962b1f	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xdbc87c98	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xdbcc9135	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0xdbd8d68e	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0xdbe579b0	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0xdbebe67c	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0xdbf38f3e	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc14a211	xen_hvm_evtchn_do_upcall
++EXPORT_SYMBOL_GPL vmlinux 0xdc237da4	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xdc27efa2	pci_get_hp_params
++EXPORT_SYMBOL_GPL vmlinux 0xdc2c9aa3	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xdc38d266	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0xdc5e9f2f	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xdc6699cb	acpi_dev_free_resource_list
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc8adaa0	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xdc910a62	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xdc9769ee	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdcc3150b	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0xdccd5038	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xdcefd8f0	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd3cf762	nvdimm_bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd57e2b5	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0xdd5cd0d5	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0xdd60dc69	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0xdd7d2910	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xdd89f793	acpi_dev_get_property
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xde090781	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0xde27bc96	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xde40c637	dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0xde4239a1	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xde46e353	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xde63a5f1	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xde9e2403	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xdebbb07b	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xded3bd4b	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xdee017c0	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xdee5630b	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xdef38560	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xdf0518ca	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdf091357	pm_genpd_remove_subdomain
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf156a8f	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0xdf21b876	of_cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xdf29b316	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0xdf542d22	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0xdf7e7bbb	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0xdf8c8c11	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0xdfa587a2	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0xdfb9fde5	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0xdfdd2c59	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe02f1361	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0xe0353ee0	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe04560dd	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0xe0535f47	dax_truncate_page
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe074477e	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xe08fda2f	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0xe092aad1	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0xe09928f9	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0xe0a8f14f	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0xe0b1c103	clk_set_max_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe0b2d0e1	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0xe0b78b01	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0xe0e3147c	HYPERVISOR_sched_op
++EXPORT_SYMBOL_GPL vmlinux 0xe0f43ae2	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0xe135b4e3	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xe13c73d6	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xe13d9365	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xe16e82b3	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xe16f4b7e	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe17aae33	xenbus_dev_probe
++EXPORT_SYMBOL_GPL vmlinux 0xe17c1ac6	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xe17f641e	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe1a6ef28	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xe1b9ecc4	xenbus_dev_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xe2050091	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0xe24c3dff	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xe25fddb1	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0xe26a9d08	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0xe26fab9c	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe28226ba	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe298c611	kvm_clear_guest
++EXPORT_SYMBOL_GPL vmlinux 0xe2993d39	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0xe2a1d666	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0xe2dfa5bb	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0xe2f26ebc	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xe2f39377	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0xe2f5a5f2	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe303a9d8	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe30aac55	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0xe336e3af	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0xe358115a	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0xe3739b4c	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xe3948ff4	acpi_walk_dep_device_list
++EXPORT_SYMBOL_GPL vmlinux 0xe39ebb0d	cppc_get_perf_ctrs
++EXPORT_SYMBOL_GPL vmlinux 0xe3bd6eed	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0xe3cd405a	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0xe3f12a3f	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0xe41534ce	bind_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0xe4181758	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe44638ad	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0xe44a260c	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe455a539	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe46a61c4	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe4a6f1bc	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0xe4c158e2	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4d5bda8	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0xe4e31279	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xe4e9df28	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0xe4f1515a	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xe4f4426d	pinctrl_find_gpio_range_from_pin
++EXPORT_SYMBOL_GPL vmlinux 0xe4fb67da	pinctrl_force_default
++EXPORT_SYMBOL_GPL vmlinux 0xe52e2dfc	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0xe52e9322	amba_apb_device_add_res
++EXPORT_SYMBOL_GPL vmlinux 0xe535db95	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0xe538cd65	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0xe538d695	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0xe53d056d	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0xe546b736	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe5568b3b	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0xe57dc9a7	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xe5800e07	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58a35f2	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe59d70df	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0xe5bbe468	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0xe5cbd3c0	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0xe5de7e6a	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0xe5ea4d7a	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0xe5f99af5	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xe601fbb0	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe6154358	xenbus_dev_changed
++EXPORT_SYMBOL_GPL vmlinux 0xe6325f9d	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe64dc69f	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe65d8653	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0xe66183b9	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0xe67adcc0	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe68260a2	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0xe69fdbdc	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0xe6be82aa	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6e13d69	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe6f83837	acpi_bus_attach_private_data
++EXPORT_SYMBOL_GPL vmlinux 0xe6fb38cf	arizona_of_get_named_gpio
++EXPORT_SYMBOL_GPL vmlinux 0xe7086256	__of_genpd_xlate_simple
++EXPORT_SYMBOL_GPL vmlinux 0xe714bb4e	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0xe7216340	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0xe725f3a8	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe74f1b10	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xe74f8b1d	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0xe767a3ff	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xe768d444	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe7bb0dd5	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xe7bbe27c	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0xe7bd985c	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe7e788f5	nd_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0xe7ed71e2	acpi_pci_find_root
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe80a0a62	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe853d6c0	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0xe85a9fd3	cpu_cluster_pm_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe861034a	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe89bd243	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xe89e8b8a	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0xe8a96073	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0xe8ba1ec3	of_pci_range_parser_init
++EXPORT_SYMBOL_GPL vmlinux 0xe8c3971e	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xe8ccd305	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0xe8f46963	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0xe8f83b2f	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe9066578	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0xe9104bba	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0xe912239c	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe956a75c	pl320_ipc_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe959ecf4	of_pci_parse_bus_range
++EXPORT_SYMBOL_GPL vmlinux 0xe99e0244	devm_pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0xe9a363cd	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xe9a8e38f	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe9af74d8	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0xe9d0869f	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xe9d26e1c	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xe9e43537	dax_do_io
++EXPORT_SYMBOL_GPL vmlinux 0xea021eec	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea20cb01	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0xea267c84	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xea2c553e	gnttab_unmap_refs_async
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea44d5d2	of_pci_range_parser_one
++EXPORT_SYMBOL_GPL vmlinux 0xea4ff0af	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xea580e38	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xea628c20	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0xea661462	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0xea73db01	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0xea84e1b8	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xeaa60a34	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xeaa70ab1	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0xeac4f037	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0xeae08ca3	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0xeae82ed9	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xeafc435e	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0xeb0f4a3c	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0xeb15e405	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xeb2798f7	xen_destroy_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xeb2eb288	efivar_variable_is_removable
++EXPORT_SYMBOL_GPL vmlinux 0xeb459b8c	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0xeb6a3b90	acpi_dev_pm_attach
++EXPORT_SYMBOL_GPL vmlinux 0xeb7d183e	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0xebc02b26	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0xebc48108	to_nd_desc
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xebeca308	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xec0528bb	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xec0e1750	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec1b3ef4	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec353217	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0xec5d79fc	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xec75ef37	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xec7a4029	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0xec934473	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0xec951565	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xeca0a974	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0xeca11b0f	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xecb78166	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0xece11f2f	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xece149dc	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xecf04566	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xecf224d6	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xed2850cd	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xed8014d8	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0xed8fabda	cpufreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xed981a16	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xeda3caee	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xedbc6f67	gnttab_end_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xedc04068	pm_genpd_init
++EXPORT_SYMBOL_GPL vmlinux 0xedd26dec	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xedee13f8	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0xedf5760b	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xedfeec65	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xee26f06b	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xee42bcc7	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0xee472e40	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee7b7d65	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xee87a30c	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0xee94cae5	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xeeb81c0f	pm_genpd_add_subdomain
++EXPORT_SYMBOL_GPL vmlinux 0xeec34e4f	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xeec419f4	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0xeedb3915	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0xeee22cb8	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xeefab77e	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0xef302581	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6d007a	sigset_from_compat
++EXPORT_SYMBOL_GPL vmlinux 0xef84408f	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xef8d3006	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefb0fe23	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0xefbfd2a0	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0xefd44bcb	devm_acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xefdab0a3	pm_genpd_syscore_poweron
++EXPORT_SYMBOL_GPL vmlinux 0xefe33ec6	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xefea041b	acpi_dev_get_resources
++EXPORT_SYMBOL_GPL vmlinux 0xeff0f9a7	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xeff2e95f	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0xeff3ad3d	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xeffd0b84	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0xf018ff4f	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf032e4bb	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf05dd959	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0xf0696401	acpi_pci_detect_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf0922faf	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0d94c81	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf107f8ee	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xf10cbf45	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xf1232ac1	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0xf1261697	acpi_subsys_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0xf13fc43e	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf14e4d24	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xf158d777	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0xf1684648	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0xf17a69e7	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0xf17dc0d6	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xf18044a2	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf18e9292	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xf195d905	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1ca85f7	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xf1da20b1	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0xf1f44469	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf234882a	dev_pm_opp_find_freq_exact
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2b75a39	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf2d237e2	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0xf2ea68d8	of_get_pci_domain_nr
++EXPORT_SYMBOL_GPL vmlinux 0xf2ec53c2	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca959	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf3171efc	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf32bdc5d	unregister_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf33dc43c	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xf34b26cd	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xf35e793f	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf37eb580	acpi_ec_remove_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf38c6aeb	of_display_timings_exist
++EXPORT_SYMBOL_GPL vmlinux 0xf395b1e0	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf3adc8ea	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3bc3e85	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3cda6a2	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0xf3cedb25	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0xf3d16a69	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0xf3e3d846	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xf3f0e417	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf3f68d39	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xf3f9c626	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0xf3fa3b08	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0xf403eb46	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0xf42ae2ef	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL vmlinux 0xf44a80e5	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0xf44fc361	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0xf45788b4	__clk_mux_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0xf46ae88c	nd_blk_region_set_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0xf476e327	acpi_match_device
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf49574be	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xf4984457	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4abf8f7	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0xf4e5219b	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf515c331	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0xf5379771	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xf549524a	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf5571547	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0xf5584320	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf55e4cc7	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0xf5657510	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0xf5785b42	evtchn_get
++EXPORT_SYMBOL_GPL vmlinux 0xf58fee33	gpiochip_remove_pin_ranges
++EXPORT_SYMBOL_GPL vmlinux 0xf5945bac	gnttab_free_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0xf5965f5f	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5c16763	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xf5d58674	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xf5edfac5	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0xf5f2a4e2	__of_genpd_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0xf60eb1a4	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0xf626e88b	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0xf6357ebd	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0xf64862b1	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0xf64e293b	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0xf6585005	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0xf667a680	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0xf66b00fe	acpi_subsys_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf6745e85	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0xf6a6fc55	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6d861c6	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0xf6de8ebf	acpi_driver_match_device
++EXPORT_SYMBOL_GPL vmlinux 0xf6e492a2	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf7016530	xenbus_gather
++EXPORT_SYMBOL_GPL vmlinux 0xf717b743	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xf719d1ff	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xf742b925	gpiochip_add_pin_range
++EXPORT_SYMBOL_GPL vmlinux 0xf764782d	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0xf767ccc3	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0xf796bcdf	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0xf79daff5	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0xf7a2de26	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xf7a387dd	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf7c3f273	xen_resume_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xf7d63e0c	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xf7f0ab52	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xf7f81272	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0xf8087728	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0xf80b3175	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0xf82c5a8f	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf862a648	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xf86810db	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf8825cc9	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0xf883e15b	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf89cbf73	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xf8a0b1e4	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0xf8ac2c54	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xf8df78fd	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf90756b4	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xf9285c87	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf931f4b3	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf935beb7	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xf93d278f	pinctrl_pm_select_idle_state
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf967422b	HYPERVISOR_xen_version
++EXPORT_SYMBOL_GPL vmlinux 0xf9765833	dmi_match
++EXPORT_SYMBOL_GPL vmlinux 0xf98ccda5	kvm_vcpu_mark_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf9987a62	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9d8256f	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xf9f04dac	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xf9f5d2f3	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0xf9f640cd	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0xfa1e3e6c	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa8061a5	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0xfa901b31	compat_get_timespec
++EXPORT_SYMBOL_GPL vmlinux 0xfab55a4e	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0xfab59529	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0xfad8d516	of_get_regulator_init_data
++EXPORT_SYMBOL_GPL vmlinux 0xfb0047f6	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0xfb153692	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xfb165467	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb3577ee	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0xfb626aa8	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc100600	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xfc201b66	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0xfc20b74e	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0xfc254d15	gnttab_free_auto_xlat_frames
++EXPORT_SYMBOL_GPL vmlinux 0xfc25da26	put_iova_domain
++EXPORT_SYMBOL_GPL vmlinux 0xfc30b9c2	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0xfc31287d	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xfc3b4246	acpi_bus_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xfc436610	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0xfc5bef55	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfc605d18	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0xfc750406	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0xfc82f83d	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfc8675b0	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0xfc9e6184	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0xfce2c99a	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xfcfd65ff	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0xfd3e0531	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xfd514e2e	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0xfd51b281	gnttab_end_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0xfd525fb4	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0xfd5dd111	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xfd667cba	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd8ee5e0	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xfdbbf423	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xfdc0e53a	to_nd_region
++EXPORT_SYMBOL_GPL vmlinux 0xfdc13b7e	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xfdc1f6d9	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xfdeb6f8c	nvdimm_bus_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xfdf1255f	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0xfe0b8177	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0xfe0f7740	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xfe17e93d	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0xfe18dfe6	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xfe46424a	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0xfe470a83	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0xfe588407	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfe9f836b	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xfea55166	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0xfeab7c2c	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0xfebdda59	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfee9f30b	device_create
++EXPORT_SYMBOL_GPL vmlinux 0xfeeeaadf	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xfefafff4	acpi_subsys_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xfeffee0e	xenbus_dev_error
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff23cad3	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0xff291ecf	clk_unregister_divider
++EXPORT_SYMBOL_GPL vmlinux 0xff2d6e96	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0xff5424a9	xenbus_register_driver_common
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff607313	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff6c01e0	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xff7c9c71	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffba4dfb	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xffcbf5ea	of_usb_update_otg_caps
++EXPORT_SYMBOL_GPL vmlinux 0xffcf13f6	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0xffd40995	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0xffe7881b	dummy_con
+diff --git a/debian.master/abi/4.4.0-111.134/arm64/generic.compiler b/debian.master/abi/4.4.0-111.134/arm64/generic.compiler
+new file mode 100644
+index 0000000..33e5508
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/arm64/generic.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu/Linaro 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/arm64/generic.modules b/debian.master/abi/4.4.0-111.134/arm64/generic.modules
+new file mode 100644
+index 0000000..cee8f2d
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/arm64/generic.modules
+@@ -0,0 +1,4393 @@
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_fintek
++8250_mid
++8255
++8255_pci
++8390
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++DAC960
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++ablk_helper
++ac97_bus
++acard-ahci
++acecad
++acenic
++acpi-als
++acpi_ipmi
++acpi_power_meter
++acpiphp_ibm
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++aes-ce-blk
++aes-ce-ccm
++aes-ce-cipher
++aes-neon-blk
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++ah4
++ah6
++ahci
++ahci_ceva
++ahci_platform
++ahci_qoriq
++ahci_xgene
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am53c974
++amba-pl010
++ambakmi
++amc6821
++amd
++amd-xgbe
++amd5536udc
++amd8111e
++amdgpu
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apbps2
++apds9300
++apds9802als
++apds990x
++apds9960
++appledisplay
++appletalk
++appletouch
++applicom
++aquantia
++ar1021_i2c
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_emac
++arc_ps2
++arc_uart
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arm_big_little
++arm_big_little_dt
++arm_mhu
++arm_scpi
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3722-regulator
++as3935
++as5011
++asc7621
++ascot2e
++asix
++ast
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++ata_generic
++ata_piix
++atbm8830
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atm
++atmel
++atmel-flexcom
++atmel-hlcdc
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp870u
++atusb
++atxp1
++aty128fb
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avmfritz
++ax25
++ax88179_178a
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1pci
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm-keypad
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm63138_nand
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcm_iproc_tsc
++bcma
++bcma-hcd
++bcmsysport
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++berlin2-adc
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmnand
++brcmsmac
++brcmstb_nand
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++cap11xx
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc10001_adc
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++ccp
++ccp-crypto
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipone_icn8318
++chipreg
++chnl_net
++ci_hdrc
++ci_hdrc_imx
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++clip
++clk-cdce706
++clk-cdce925
++clk-max77686
++clk-max77802
++clk-palmas
++clk-pwm
++clk-qcom
++clk-rk808
++clk-s2mps11
++clk-scpi
++clk-si514
++clk-si5351
++clk-si570
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmtp
++cnic
++cobalt
++cobra
++coda
++colibri-vf50-ts
++com20020
++com20020-pci
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_parport
++comedi_pci
++comedi_test
++comedi_usb
++configfs
++contec_pci_dio
++cordic
++core
++cp210x
++cpia2
++cppc_cpufreq
++cpsw_ale
++cpu-notifier-error-inject
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc32-arm64
++crc7
++crc8
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++csiostor
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++db9
++dc395x
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++ddbridge
++de2104x
++decnet
++deflate
++defxx
++denali
++denali_dt
++denali_pci
++des_generic
++designware_i2s
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++digicolor-usart
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9601
++dme1737
++dmfe
++dmi-sysfs
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++dp83848
++dp83867
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_mmc
++dw_mmc-exynos
++dw_mmc-k3
++dw_mmc-pci
++dw_mmc-pltfm
++dw_wdt
++dwc3
++dwc3-pci
++dwc3-qcom
++dwc_eth_qos
++dwmac-generic
++dwmac-ipq806x
++dwmac-lpc18xx
++dwmac-meson
++dwmac-rk
++dwmac-socfpga
++dwmac-sti
++dwmac-sunxi
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++earth-pt1
++earth-pt3
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++ec_sys
++echainiv
++echo
++edac_core
++edt-ft5x06
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efi-pstore
++efi_test
++efs
++egalax_ts
++ehci-msm
++ehci-platform
++ehset
++elan_i2c
++elo
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emac_arc
++emac_rockchip
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++empeg
++ems_pci
++ems_usb
++emu10k1-gp
++enc28j60
++enclosure
++encx24j600
++encx24j600-regmap
++ene_ir
++eni
++enic
++epic100
++eql
++esas2r
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++ezusb
++f2fs
++f71805f
++f71882fg
++f75375s
++f81232
++fakelb
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_sys_fops
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdp
++fdp_i2c
++fealnx
++ff-memless
++fintek-cir
++firedtv
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fixed
++fjes
++fl512
++flexfb
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++fsa9480
++fscache
++fsl-edma
++fsl_lpuart
++fsl_pq_mdio
++ft6236
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu_ts
++g450_pll
++g760a
++g762
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcc-apq8084
++gcc-ipq806x
++gcc-msm8660
++gcc-msm8916
++gcc-msm8960
++gcc-msm8974
++gcm
++gdmtty
++gdmulte
++gdmwm
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++genwqe_card
++gf128mul
++gf2k
++gfs2
++ghash-ce
++ghash-generic
++gianfar_driver
++gianfar_ptp
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-74x164
++gpio-74xx-mmio
++gpio-addr-flash
++gpio-adnp
++gpio-adp5520
++gpio-adp5588
++gpio-altera
++gpio-amd8111
++gpio-amdpt
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-fan
++gpio-grgpio
++gpio-ir-recv
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-rdc321x
++gpio-regulator
++gpio-syscon
++gpio-tps65912
++gpio-twl4030
++gpio-twl6040
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio-xgene-sb
++gpio-zynq
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mouse
++gpio_tilt_polled
++gpio_wdt
++gr_udc
++grace
++grcan
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++gxt4500
++hackrf
++hamachi
++hampshire
++hanwang
++hci
++hci_uart
++hci_vhci
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfs
++hfsplus
++hi6421-pmic-core
++hi6421-regulator
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++hih6130
++hip04_eth
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi-acpu-cpufreq
++hisi504_nand
++hisi_thermal
++hix5hd2_gmac
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hnae
++hns_dsaf
++hns_enet_drv
++hns_mdio
++hopper
++horus3a
++hostap
++hostap_pci
++hostap_plx
++hp100
++hpfs
++hpilo
++hpsa
++hptiop
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++htc-pasic3
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hwa-hc
++hwa-rc
++hwmon-vid
++hwspinlock_core
++hx8357
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd8111
++i2c-arb-gpio-challenge
++i2c-bcm-iproc
++i2c-cadence
++i2c-cbus-gpio
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-emev2
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-kempld
++i2c-matroxfb
++i2c-mt65xx
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-pinctrl
++i2c-mux-reg
++i2c-nforce2
++i2c-nomadik
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-piix4
++i2c-qup
++i2c-rk3x
++i2c-robotfuzz-osif
++i2c-scmi
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-thunderx
++i2c-tiny-usb
++i2c-versatile
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xgene-slimpro
++i2c-xiic
++i40e
++i40evf
++i5k_amb
++i6300esb
++i740fb
++ib_addr
++ib_cm
++ib_core
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_qib
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibmaem
++ibmpex
++icp_multi
++icplus
++ics932s401
++idma64
++idmouse
++idt77252
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imon
++ims-pcu
++imx074
++imx2_wdt
++imx6ul_tsc
++imx_thermal
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int51x1
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++iproc-rng200
++iproc_nand
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++irlan
++irnet
++irqbypass
++irtty-sir
++iscsi_boot_sysfs
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it87
++it913x
++itd1000
++ite-cir
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++kafs
++kalmia
++kaweth
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++kvaser_pci
++kvaser_usb
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l4f00242t03
++l64781
++lan78xx
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcc-ipq806x
++lcc-msm8960
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-aat1290
++leds-adp5520
++leds-bcm6328
++leds-bcm6358
++leds-bd2802
++leds-blinkm
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-ktd2692
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max77693
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-pwm
++leds-regulator
++leds-ss4200
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libahci_platform
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++liquidio
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++litelink-sir
++lkkbd
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac80211
++mac80211_hwsim
++mac802154
++macb
++macmodes
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mailbox-test
++mailbox-xgene-slimpro
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++marvell
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max5821
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max77693-haptic
++max77693_charger
++max77802
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc-bus-driver
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++mdc800
++mdio
++mdio-bcm-iproc
++mdio-bcm-unimac
++mdio-bitbang
++mdio-cavium
++mdio-gpio
++mdio-mux
++mdio-mux-gpio
++mdio-mux-mmioreg
++mdio-octeon
++mdio-thunder
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++metro-usb
++metronomefb
++mf6x4
++mga
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microtek
++minix
++mip6
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmc_spi
++mmcc-apq8084
++mmcc-msm8960
++mmcc-msm8974
++mmci_qcom_dml
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi001
++msi2500
++msm
++msm-rng
++msp3400
++mspro_block
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt8173-max98090
++mt8173-rt5650-rt5676
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtd_dataflash
++mtdblock
++mtdblock_ro
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-afe-pcm
++mtk-pmic-wrap
++mtk-sd
++mtk_wdt
++mtouch
++multipath
++multiq3
++musb_hdrc
++mv_u3d_core
++mv_udc
++mvmdio
++mvsas
++mvumi
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxc4005
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxser
++mxuport
++myri10ge
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nci
++nci_spi
++nci_uart
++ncpfs
++nct6683
++nct6775
++nct7802
++nct7904
++nd_blk
++nd_btt
++nd_pmem
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_labpc
++ni_labpc_common
++ni_labpc_pci
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicpf
++nicstar
++nicvf
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nosy
++notifier-error-inject
++nouveau
++nozomi
++nps_enet
++ns558
++ns83820
++ntb
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nuvoton-cir
++nvidiafb
++nvme
++nvmem_core
++nvmem_qfprom
++nxp-nci
++nxp-nci_i2c
++nxp-ptn3460
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_mmc_spi
++of_xilinx_wdt
++ofpart
++ohci-platform
++old_belkin-sir
++omap4-keypad
++omfs
++omninet
++onenand
++opencores-kbd
++openvswitch
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++palmas-pwrbutton
++palmas-regulator
++pandora_bl
++panel
++panel-lg-lg4573
++panel-samsung-ld9040
++panel-samsung-s6e8aa0
++panel-sharp-lq101r1sx01
++panel-simple
++parade-ps8622
++parkbd
++parport
++parport_ax88796
++pata_acpi
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_of_platform
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sis
++pata_sl82c105
++pata_triflex
++pata_via
++pc300too
++pc87360
++pc87427
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_udc
++pci
++pci-stub
++pci200syn
++pcie-iproc
++pcie-iproc-platform
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcrypt
++pcwd_pci
++pcwd_usb
++pda_power
++pdc_adma
++peak_pci
++peak_usb
++pegasus
++penmount
++percpu_test
++pfuze100-regulator
++phantom
++phonet
++phram
++phy-bcm-kona-usb2
++phy-berlin-sata
++phy-berlin-usb
++phy-exynos-usb2
++phy-gpio-vbus-usb
++phy-isp1301
++phy-msm-usb
++phy-mt65xx-usb3
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-qcom-8x16-usb
++phy-qcom-apq8064-sata
++phy-qcom-ipq806x-sata
++phy-qcom-ufs
++phy-qcom-ufs-qmp-14nm
++phy-qcom-ufs-qmp-20nm
++phy-tahvo
++phy-tusb1210
++physmap
++physmap_of
++pinctrl-apq8064
++pinctrl-apq8084
++pinctrl-ipq8064
++pinctrl-msm8660
++pinctrl-msm8916
++pinctrl-msm8960
++pinctrl-msm8x74
++pinctrl-qdf2xxx
++pinctrl-spmi-gpio
++pinctrl-spmi-mpp
++pinctrl-ssbi-gpio
++pinctrl-ssbi-mpp
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl172
++pl2303
++pl330
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8941-pwrkey
++pm8941-wled
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pn533
++pn544
++pn544_i2c
++pn_pep
++poly1305_generic
++port100
++powermate
++powr1220
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_core
++pps_parport
++pptp
++prism2_usb
++ps2mult
++psmouse
++psnap
++ptp
++pulsedlight-lidar-lite-v2
++pvrusb2
++pwc
++pwm-atmel-hlcdc
++pwm-beeper
++pwm-berlin
++pwm-fan
++pwm-fsl-ftm
++pwm-lp3943
++pwm-mtk-disp
++pwm-pca9685
++pwm-regulator
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa168_eth
++pxa27x_udc
++qcaspi
++qcaux
++qcom-coincell
++qcom-spmi-iadc
++qcom-spmi-pmic
++qcom-spmi-temp-alarm
++qcom-spmi-vadc
++qcom-wdt
++qcom_bam_dma
++qcom_gsbi
++qcom_hwspinlock
++qcom_rpm
++qcom_rpm-regulator
++qcom_smbb
++qcom_smd-regulator
++qcom_spmi-regulator
++qcrypto
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-bcm2048
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-shark
++radio-si476x
++radio-tea5764
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++reed_solomon
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio500
++rivafb
++rj54n1cb0c
++rk808
++rk808-regulator
++rmd128
++rmd160
++rmd256
++rmd320
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-as3722
++rtc-bq32k
++rtc-bq4802
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-hid-sensor-time
++rtc-hym8563
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max77802
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-msm6242
++rtc-mt6397
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-pl030
++rtc-pl031
++rtc-pm8xxx
++rtc-r9701
++rtc-rc5t583
++rtc-rk808
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-snvs
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-twl
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtc-zynqmp
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7706h
++safe_serial
++salsa20_generic
++samsung-keypad
++samsung-sxgbe
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_sil
++sata_sil24
++sata_sis
++sata_svw
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sb1000
++sbp_target
++sbs-battery
++sc16is7xx
++sc92031
++sca3000
++sch5627
++sch5636
++sch56xx-common
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scpi-cpufreq
++scpi-hwmon
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sdhci
++sdhci-acpi
++sdhci-iproc
++sdhci-msm
++sdhci-of-arasan
++sdhci-of-at91
++sdhci-of-esdhc
++sdhci-pci
++sdhci-pltfm
++sdhci-pxav3
++sdhci_f_sdh30
++sdio_uart
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial2002
++serio_raw
++sermouse
++serpent_generic
++serport
++ses
++sfc
++sh_veu
++sha1-ce
++sha2-ce
++shark2
++shpchp
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sir-dev
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skd
++skfp
++skge
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++slcan
++slip
++slram
++sm501
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smd
++smd-rpm
++smem
++smipcie
++smm665
++smsc
++smsc47b397
++smsc47m1
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als300
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt3328
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-cs4281
++snd-cs46xx
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1938
++snd-es1968
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm
++snd-pcm-dmaengine
++snd-pcm-oss
++snd-pcxhr
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-apq8016-sbc
++snd-soc-core
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-es8328
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-ssi
++snd-soc-gtm601
++snd-soc-imx-audmux
++snd-soc-lpass-apq8016
++snd-soc-lpass-cpu
++snd-soc-lpass-ipq806x
++snd-soc-lpass-platform
++snd-soc-max98090
++snd-soc-max98357a
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rl6231
++snd-soc-rt5631
++snd-soc-rt5645
++snd-soc-rt5677
++snd-soc-rt5677-spi
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-storm
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-xtfpga-i2s
++snd-sonicvibes
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-variax
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-ymfpci
++snic
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++softdog
++softing
++solo6x10
++solos-pci
++sony-btf-mpx
++soundcore
++sp2
++sp805_wdt
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_dectlk
++speakup_dummy
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-fsl-dspi
++spi-gpio
++spi-lm70llp
++spi-mt65xx
++spi-nor
++spi-oc-tiny
++spi-pl022
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-qup
++spi-rockchip
++spi-sc18is602
++spi-tle62x0
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spl
++splat
++spmi
++spmi-pmic-arb
++sprd_serial
++sr9700
++sr9800
++ssb
++ssb-hcd
++ssd1307fb
++ssfdc
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++sstfb
++ssu100
++st
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++svgalib
++sx8
++sx8654
++sx9500
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink_gt
++synclinkmp
++syscopyarea
++sysfillrect
++sysimgblt
++sysv
++t1pci
++t5403
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc3589x-keypad
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tehuti
++tekram-sir
++teranetics
++test-hexdump
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tg3
++tgr192
++thmc50
++thunder_bgx
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timeriomem-rng
++tipc
++tlan
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++torture
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_atmel
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_infineon
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps65218-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl-regulator
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udc-xilinx
++udf
++udl
++udlfb
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmisc_imx
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vcan
++vcnl4000
++ves1820
++ves1x93
++veth
++vexpress
++vf610_adc
++vfio
++vfio-amba
++vfio-pci
++vfio-platform
++vfio-platform-amdxgbe
++vfio-platform-base
++vfio-platform-calxedaxgmac
++vfio_iommu_type1
++vfio_virqfd
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-rhine
++via-sdmmc
++via-velocity
++via686a
++videobuf-core
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videodev
++vim2m
++viperboard
++viperboard_adc
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_scsi
++virtual
++visor
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vrf
++vringh
++vsock
++vsxxxaa
++vt1211
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83627ehf
++w83627hf
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++walkera0701
++wanxl
++warrior
++wcn36xx
++wd719x
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x_tables
++xc4000
++xc5000
++xcbc
++xen-blkback
++xen-evtchn
++xen-fbfront
++xen-gntalloc
++xen-gntdev
++xen-kbdfront
++xen-netback
++xen-privcmd
++xen-scsiback
++xen-scsifront
++xen-tpmfront
++xen_wdt
++xenfs
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgene-dma
++xgene-enet
++xgene-rng
++xgene_edac
++xgifb
++xhci-plat-hcd
++xilinx-tpg
++xilinx-video
++xilinx-vtc
++xilinx_can
++xilinx_uartps
++xillybus_core
++xillybus_of
++xillybus_pcie
++xor
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yurex
++zaurus
++zavl
++zcommon
++zd1201
++zd1211rw
++zforce_ts
++zfs
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++znvpair
++zpios
++zr364xx
++zram
++zunicode
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/armhf/generic b/debian.master/abi/4.4.0-111.134/armhf/generic
+new file mode 100644
+index 0000000..f1cf242
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/armhf/generic
+@@ -0,0 +1,17621 @@
++EXPORT_SYMBOL arch/arm/crypto/aes-arm 0x276b2f72	private_AES_set_encrypt_key
++EXPORT_SYMBOL arch/arm/crypto/aes-arm 0x6c62e582	AES_decrypt
++EXPORT_SYMBOL arch/arm/crypto/aes-arm 0xc30fcbed	AES_encrypt
++EXPORT_SYMBOL arch/arm/crypto/aes-arm 0xcf024ae9	private_AES_set_decrypt_key
++EXPORT_SYMBOL arch/arm/crypto/sha256-arm 0xb2fb22d3	crypto_sha256_arm_update
++EXPORT_SYMBOL arch/arm/crypto/sha256-arm 0xfe72d9b0	crypto_sha256_arm_finup
++EXPORT_SYMBOL arch/arm/lib/xor-neon 0x0f051164	xor_block_neon_inner
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0x28865246	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/atm/suni 0x60735f70	suni_init
++EXPORT_SYMBOL drivers/bcma/bcma 0x21349343	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/bcma/bcma 0xa5cf640c	bcma_core_irq
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x0b2fc68d	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x14a61d86	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x1a5366ad	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0x32e95dbc	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x4267110a	pi_register_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0x54aeb4e7	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x77cb7e98	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0x934ced6d	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0xb21ba07d	pi_unregister_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0xba8572da	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xc4535e64	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0xcd61ed66	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0xf401bf9a	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0xf8861f31	pi_write_regr
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0xf3c1edc8	btbcm_patchram
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1b97b3aa	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x2d7b39da	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x7017d696	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x80673e93	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xc789b2ae	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/nvram 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x17ff2c1d	__nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x2adec1e0	__nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x7da28f12	nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL drivers/char/nvram 0xa8813189	__nvram_write_byte
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x10ea5d1c	st33zp24_pm_resume
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x2ef04afe	st33zp24_probe
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xc1d80b27	st33zp24_remove
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xdab79a76	st33zp24_pm_suspend
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xa58737d1	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xb6fa5fdb	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xc3951615	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/crypto/caam/caam 0x1c758e97	caam_get_era
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0x0eeeda83	caam_jr_alloc
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0x39f7a4ea	caam_jr_free
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0x4f72b77d	caam_jr_strstatus
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0xa9acf1c7	split_key_done
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0xbf5c38b3	caam_jr_enqueue
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0xcfae1daa	gen_split_key
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x2d3b8e7d	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x77232b05	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xc361df8a	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xd41b767d	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xeb0b4d9d	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xfdd6f19e	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/pl330 0x5b1b30e0	pl330_filter
++EXPORT_SYMBOL drivers/edac/edac_core 0x723d88cf	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0155015f	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04dd92ce	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x12078646	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16932a5b	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x1892c4a6	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2433a624	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x29f991dd	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x402acacb	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x476ca0ab	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4d5d4eca	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x6366fcc7	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x6a378268	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x6d3a9cd7	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x743d9fdc	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7a63914d	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7e431b14	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7e7a8ca4	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8f10da39	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9bc62b9c	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa4054c10	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xad4bb1db	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb33e37b8	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb4381a23	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xbd79dbdb	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xc09d918c	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xc3351ee7	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xcafd6e35	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd958d5eb	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xf5d7c26a	fw_cancel_transaction
++EXPORT_SYMBOL drivers/fmc/fmc 0x1c5dd5d2	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x217af28f	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0x49282c21	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0x4f4e2e6d	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x73769209	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x76687a6d	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x9d231fdc	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xb68d3298	fmc_driver_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xd2b212cd	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xfbd2b46b	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xfed999ca	fmc_device_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x01702970	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x058a5feb	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x07e365a5	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0845b221	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a5434c2	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0b02d0d6	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0b0ee1ce	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0be3efd0	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0d04fb20	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fccafb1	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1040e60a	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x10d80e29	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11117238	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x16795d05	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1828c054	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x18eada96	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x19556d5c	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x199305ea	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x19d0e504	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a4d348f	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a708d10	of_drm_find_bridge
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1adb9b89	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1b657b66	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c12e1bb	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1d5175b3	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1f5a985b	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20a01c17	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20b7f60e	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20cf6d1a	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20e8e8af	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2128ceaf	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x217c0aa1	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22c1d7a0	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22cb3e42	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2346be15	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x24de41b4	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2664bf6f	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x266aaddd	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x283e4146	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2945379f	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ab2d7fd	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2af36995	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2b4b735e	drm_of_find_possible_crtcs
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c2b6f00	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ce3f9f1	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2cf26f42	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d924dd1	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e539904	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2f7e1ec2	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3004c03a	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3010d70c	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x30f825e7	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3202aacd	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x323f50f8	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x343fd321	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x346127a7	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x34bef6d9	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x35b559dd	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3a80da06	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3a95f59c	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b7a8f6b	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3bfe21b6	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3c4a61f6	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d873fd5	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3df051d6	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3e229318	drm_of_component_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3f2b43c4	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x40b41502	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4267c72b	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x433850de	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4394ed4a	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43ad8cef	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4588cee0	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x469649f7	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x482c78ba	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48660ba7	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x492780c1	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4bc06e98	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d343214	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d72d2ef	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d9e3c7d	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50312251	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5046b582	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5089f0d3	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50d8b31a	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x515a89c7	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x544e0704	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54541cfc	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x549c8681	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x55a4870f	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5760e410	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x576d2482	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x579a89f3	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a1adb68	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a268d54	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d5379a8	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d56a873	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5da26702	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5f1c3b44	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5fac7566	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x60705c37	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x61297f57	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x619cef3d	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x61a779f6	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x61a8f4c2	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x65633c7b	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x665b7704	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x66938852	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x672b3cb2	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69827995	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69e2ac2a	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6a0dd4c6	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6aa05474	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6b047178	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6c010fd4	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f61ff4d	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x71bdba4b	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x71e3005e	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x71fed2a2	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72825fb4	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x73310d00	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x76e8b212	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x786eba9d	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x788dd5a3	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x792c0b18	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x79b02ee9	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a491e83	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a59bb13	of_drm_find_panel
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a9d557c	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7ae9f5b2	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b612a69	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b9fbf85	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7d6ac1c9	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7e574728	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7ec7cc80	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7fc66427	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x802e3249	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x80606d1e	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x820bd217	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x823b0c90	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x84e706b6	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8518e420	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x861d167f	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8752799b	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8793f17d	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x87c9aad9	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x87cfa9cc	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x880cfd03	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x888c0ca1	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x88987525	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x89895e87	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c2c93e3	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c3ac142	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e3a72dc	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e89370f	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f4bdf84	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x911013d4	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91e2377e	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92fa718a	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x930fd3e0	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x93b6085c	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9477e132	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x94822865	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x95a7101b	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x964b2d11	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x96a8c3f8	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x96b215dc	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97258c4b	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x974bebf4	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97607789	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9bf7693d	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9c0a10d1	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ce981e8	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9d5d80bc	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa11351d5	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa142614c	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa23515ec	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa29641de	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa371d8fe	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa39e0abb	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa428c286	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa44784fe	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa457e0fa	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa638709f	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa669b540	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa78c2344	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa794d915	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa8a6f4b6	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa8c3235b	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa973af26	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaa86ea26	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaaffbcaa	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad00c3b1	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xadf62c6d	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae6ffa55	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae8f9184	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaeab4f72	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb0227aa0	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb1953a1e	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb276aa59	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3905fa3	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb4c949c7	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb501e994	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb526c596	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb59086e3	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5ffefc0	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb63249e5	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb740d1b2	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb8e3adc4	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbd4c6eeb	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbdc1b815	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbdf1b76f	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe3cd6b3	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbef26cae	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbfea5292	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc04233c0	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc084b7f7	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc120bca0	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc26a18f7	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2d81a69	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc353e4ee	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc3901dcd	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc3eefafb	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc4aa2808	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc61e3f07	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc6985205	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc71d8496	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc898e02c	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc9972a90	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc9fadd7e	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcddf932a	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcde1b0c9	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xce68a113	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf29a9b1	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd40d1a81	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd49f410e	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd4e255a0	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd4f82a25	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd64afb6f	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xda855e63	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xda9c5f88	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdae187d9	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdb212186	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc477a87	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe179553b	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe18c079e	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe21e757b	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe514eb56	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe5aaef01	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe5bb11bb	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe655c929	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe752e50a	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe8cae44c	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe91d77be	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea7bfb47	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeaad29a2	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeac9fc97	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed937148	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeec805f4	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef0e2bf6	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0179e1c	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf569249e	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf585b300	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf5a8375a	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf70f5932	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf8645719	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf89aeb2b	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf94b1539	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9ed744f	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9f16d45	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfac72b04	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb845719	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc274d0d	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd4ad1c0	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfdc59134	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfdcf10dd	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfe6762ea	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfe6dfbbc	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff98b3c2	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x04cbef66	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x06dcf726	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x09f33f69	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0bb4f74b	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0e222386	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f075f5c	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x12823958	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x12f6737d	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1308a3b8	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x13c0c770	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x13fe6b10	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x145cfd0c	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x150c249b	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x169d7fe1	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x176404dd	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x178823e1	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1ab65610	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1c0b2173	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1dfaba21	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2008d8ee	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x20f63499	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x21604521	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x21a5ddf8	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x24e89e94	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x29f587ef	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2e17a704	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3321540f	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x366ed18d	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3963ed57	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x39b38961	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3c69a0e8	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3dadbf8b	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3e96d709	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3f6ef70a	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x40539fbe	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x41838302	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x41e98349	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x44ea137d	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x450c170a	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x470ae482	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4765b5a6	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x49ecba25	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4b64453a	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4d6b4ad8	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4de8ddad	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4e5d83a9	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x518e50df	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x561f8f34	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x56ddaede	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x590d3e27	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5a0e0065	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5c42030d	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5d9ac3f6	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x61e1b4bd	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x63168954	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x633757a3	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6379858d	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6393744d	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6422e6f8	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x64661eab	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x67adbe49	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6976494b	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6bc5daf7	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6c19a748	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6e77bfd6	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6ec6a37a	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x78f24bd2	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7e8ea845	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7ed10bc2	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x818ecab5	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x81c8e755	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8262d362	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84bf73ed	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x89e43543	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8ba3124f	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8da603ba	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8e169ef1	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8e1e01f3	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x916b2773	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9290c829	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9363de3f	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x999c8b90	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9df0917b	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9f4c6a6b	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9f5c2e69	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa1b9cbfb	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa35f6a68	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa43cf23d	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa4ea784f	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa67e6e41	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa7ab605d	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa7dcaac3	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa90bd3e7	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa9298b47	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa9e1ea12	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaaa5c493	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0b7fc1	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab6a09f3	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaca6dd95	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xae09cf6d	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xae227655	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb31e5b13	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb4d2c593	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb72711fb	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb754c54a	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb88c56ea	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbb414fe8	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbe580179	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc1b8f3ca	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc315ce49	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc48c27e8	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc5c8f58b	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc649d338	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc8ebe29f	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcc236372	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcc28ce32	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xccd7e210	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd0c459cf	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd386dbdf	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd49e42cd	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd6362d67	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd733200a	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xda046fde	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xda996666	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdb4d0a6e	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdd5aa78a	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdd72f025	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdfc2f7c8	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe008b08d	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe29594e4	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe548796c	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe9ef072d	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeb45b95c	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeb4c15f3	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xec48e82b	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeef650fb	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf42ed710	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf52e9c49	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf56e5310	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf8bc5e09	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfd2be624	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfe817f8c	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x024ae3b7	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x07187d74	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x07ed8317	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x081b0409	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0ab411c8	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0f9c41e4	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x132b05be	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x136ec7fa	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1b336a9e	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1d87c039	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x21cdf2ac	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x23daeb64	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x23dd1c52	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x25b4bc50	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2c7fac9b	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x35e22cf0	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x381b9e2a	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x39e7de7d	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x44520d82	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x44f5031e	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4628b006	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4ffdb3eb	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x534114bf	ttm_prime_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x55d20c0d	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5cf59609	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x67b1d568	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6c0ec969	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6d0a7db1	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x792404b5	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7e42c319	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8064631e	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x82ea7c4f	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x84efaa06	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x850da819	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8589758d	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x86bb8a6c	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8b2a80ae	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8b82c35b	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x92434b89	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x92c98a16	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9e515b33	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9f77c8da	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa5e8be19	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa610a7ca	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xaf6f5af5	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb51417d6	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xba4bfa2a	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbc250d26	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc403ce66	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc4389b90	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc4f69ff4	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc6883d7f	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc968d68f	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc97a5560	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc9fafd1d	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd166368b	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd38fd1fb	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd6638ec9	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe7a4013e	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe9ec2d3e	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xed43df93	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xefc4df0d	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf658468a	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfd7484d3	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfe8cc064	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xff72c92c	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x05c4129f	host1x_syncpt_read_max
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x09da8ff0	host1x_job_add_gather
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x1f7e884f	host1x_channel_request
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x21f564aa	tegra_mipi_request
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x369d7b41	host1x_device_init
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x43799a4e	tegra_mipi_calibrate
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x5bc17440	host1x_job_submit
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x5e4eec7f	host1x_syncpt_id
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x6144c39f	host1x_client_unregister
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x6ff9dc76	host1x_job_put
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x7b8242e6	host1x_device_exit
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x89722559	host1x_syncpt_get_base
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x8c04ae8f	host1x_job_unpin
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x8e5d2683	host1x_syncpt_read_min
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x9451a33e	tegra_mipi_free
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x97c3cd70	host1x_job_alloc
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xa158b6e7	host1x_syncpt_base_id
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xa30b9558	host1x_channel_free
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xa615905b	host1x_syncpt_request
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xa9448779	host1x_driver_unregister
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xab84f521	host1x_syncpt_incr_max
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xafb6b1cd	host1x_syncpt_get
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xbb7076a9	host1x_syncpt_free
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xbdf82579	host1x_job_get
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xc2befdd8	host1x_syncpt_wait
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xc6e8bf34	host1x_syncpt_incr
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xc788d980	host1x_driver_register_full
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xce9d5a76	host1x_client_register
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xd01ed311	host1x_channel_get
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xd9b3dd95	host1x_channel_put
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xe1717509	host1x_job_pin
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0xf87367fd	host1x_syncpt_read
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0e2a6864	sch56xx_read_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0f5877d4	sch56xx_read_virtual_reg16
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x34257f35	sch56xx_watchdog_unregister
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x78fee2cc	sch56xx_watchdog_register
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xe5022f95	sch56xx_read_virtual_reg12
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xed1d2a08	sch56xx_write_virtual_reg
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x24bac235	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x2a0d78d3	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x70afa14a	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x203e5aaa	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0xafec2d46	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0xec81e009	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x0b96a47c	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x0bc469f3	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x1a5b179c	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x33801bc9	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x3508b720	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x359944a1	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x55626aa9	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x720d2989	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x723f2ec3	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xaa0bc933	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xc3735c9d	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xd1421dfa	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xefede4e1	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xf7ae91f7	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xf8399002	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xfa9f86ad	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x037824e5	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x0ea26d36	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x1842da0d	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x80922b9a	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x01e274cc	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x95acb968	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xdeadb178	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xf29e711a	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x667d3a00	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x91ccb437	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xce7bc909	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xd4505c9e	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xde25280d	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xe01e704d	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x6140e765	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x66206304	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x7962b160	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xd97f9b17	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x07099efa	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x100a3af0	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x2b141003	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x369f9d68	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x3945c7e9	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x5bb398f0	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x5ed41563	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8e7a9526	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x903c4b17	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x151694e4	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x27b0dad1	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xbe8f3cae	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xefa5580f	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xfb798839	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xb0d1afb3	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xcc2bf909	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xf975317b	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x18bcecb3	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x1ee3d2b4	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4985eeda	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4e549e4c	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6e4dc103	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x75fbeac2	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x7be2e707	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x8c775d8f	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x903e66b9	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x95e0b342	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x988eb7b2	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xa9ad91b1	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xbe0f6a94	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd45b2145	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xe1b5518c	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf8b66f93	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xfe0a299e	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xa3d7b8b1	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xd100fdfe	st_sensors_of_i2c_probe
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0x46822e0d	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0xc1a9099e	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0xffc4168e	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0x61c2b0a9	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x79bcb494	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xf6e327a4	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/industrialio 0x03a331db	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0x040ec79b	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x404a7783	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x417353cf	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x4f98af00	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0x5242ddf3	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x5a27ba72	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0x80c9edf4	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0x8e9a1070	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x92dbfdf8	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xa6d8d765	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0xa8c9ff2e	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xbe315bca	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0xbf9ec717	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xd699c09a	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xe3486a1b	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xf99686d8	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x6d53afb0	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0xcdc11e4d	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x642f84ef	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xd863d1a9	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0x1ba92718	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x1a8c0729	st_press_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x96b7d0a0	st_press_common_probe
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x39943785	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x5347cc38	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x6d61f062	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x7df81f32	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x8e7ebec0	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xdb079dcb	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x07bd0b0c	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x12b7cecc	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1c9f7b88	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x2236345b	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x25ffe96a	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x34cf4300	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x4414df46	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x44366cf0	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x51c24dbe	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x8fde99a0	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x9a0dccae	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa64dbe7f	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xb2ee5705	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xbd0e8cb9	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xdc2a1b88	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xf1cf5045	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xfc3546f5	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xfd39ef11	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x03c8fa6e	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x045701b2	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x076edd29	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x07f68eaf	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0d5146c9	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0dd4a24d	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x104b0bcc	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1143fa07	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x12a1823a	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1ce9f490	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e79b131	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1ffd4ca5	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x27e68366	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x28174a4b	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x28dfa1ee	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x29fbe7c7	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2a8bb0ed	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2c8ea8af	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2f1d7744	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2fe4aea4	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3054926c	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x31a7c281	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3334935e	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3581cf3f	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3693c1a3	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3be9d986	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3f0fd1bd	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x46bae125	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x475c4901	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4f40a7a3	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4f9c958b	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x520b2638	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5336555c	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x55beccbd	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x57969949	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x57fc39da	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5c7afe43	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5f571911	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x60ef2f9e	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6a2efad8	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6a30845f	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6e54fe7c	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x73747d33	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7801b6b3	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7857f2d2	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x78e025cf	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7b01d4fb	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x828b6fbc	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x86a6dddf	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x88d6ffcc	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8941a74b	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x90e3c587	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x924e939c	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x97ca3231	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x98430510	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9a4e7518	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9b58a7d6	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa127eff0	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa165109c	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa3055be7	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaeec157e	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb038ce56	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb1a312e1	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb74c9b3c	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb79fe4a0	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb9343a91	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbc4f72e8	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbf965ec0	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc7afa43e	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc8fa3fcf	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcd40d542	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcf20bfb7	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcff541f1	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd056227d	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd24d6c1c	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd4c34115	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd5232e8b	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd96cea57	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe104fca4	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe19846f0	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe4c8c58c	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe76c6e3f	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xef979f26	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf145a477	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfecb4643	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2be5ca57	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2e319d62	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2e464bb9	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x4eb12ff3	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x4ff84933	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x5329076e	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x88a14227	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x9004ca8f	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xa797755c	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xc6bfe073	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd85cd1e2	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xf7095f84	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xfe8fc02a	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x52c2a014	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x72d1e281	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x73c30593	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x9e7aad54	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xaba6119f	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xb9c38b34	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xba08f56a	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xbc3b83e4	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xc55dc59f	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xde9e1b2c	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xfaf6ef74	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x704eb386	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xe4c3a55e	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x047e6c96	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x08e1e8a1	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x109792ae	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x214afbb4	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x51ca3885	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x52c9e429	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5ac18ebc	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x78a6474d	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x986d9059	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9ff0d13a	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb351ab57	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb9576aa6	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xc03db78a	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xde4e2e10	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf9b4973d	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x19dabb80	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x2545ced8	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x44a989ef	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x44e4eb9a	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x4ffcb4ff	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5a772680	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5e8ce063	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5f669af7	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x678fd2b5	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x6ad77be2	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x71da1989	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x72950fc4	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x757b32f0	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa8b55e1c	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xbb787e94	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xcada1c6e	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd7ae5c96	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xdf5f2c22	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xe587d58e	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf7d8f80f	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf8514261	rdma_get_service_id
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x197024d6	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x1a3f7cca	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x427ea5c2	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x45617c31	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x499ae997	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x50039de3	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x55186a40	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x7f424ad2	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xc7998fb0	__gameport_register_port
++EXPORT_SYMBOL drivers/input/input-polldev 0x11a17587	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x6ecfc24c	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x6f2c4d4f	input_register_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x7ce98e98	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x8531fe21	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0xf5a96ac7	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x44ce1b0c	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x80a6210f	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xf26a8ffa	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x15358af5	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x60293371	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xa6264e54	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xde5547c7	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xfbb69827	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xfd3c095e	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xfde208b2	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x533ec80f	ad7879_probe
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x66a4834d	ad7879_pm_ops
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2f135ece	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x309be598	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x44e324d4	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x4cad034b	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7be43632	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7c75a886	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x96fcd87f	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa7c4fd6c	capi_message2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc10fe128	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc3ea61c9	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xdcbe44e6	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe8ad9bd1	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xf02c9a9b	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x078498af	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x2014d987	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x27d040bf	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x4c5ef6be	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x507b009f	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x65fddc6e	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x7300afb7	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x8d0bc962	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x99632ed9	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xa909acbc	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xbdb5cdf8	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xd9dd75b3	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdd3340ca	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xed990606	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xf5a0997f	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x0a92c2a2	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x1a9d4786	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x273b82aa	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x400fa7f5	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x68e7b3dd	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x9e7dabfe	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xc3292c3f	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xca5a7e2c	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xfe4a83fb	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x27f6080d	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x85c6536d	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xa691f595	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xc4d035cb	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x0348aee6	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x80bcc207	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6d5b2497	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x1902813d	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x53678c4e	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x8c6e878d	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xcbfc3945	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xf46ae679	isac_irq
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x78b5baa1	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xa5082632	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xe8a36acf	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x088900e3	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x09815650	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x14a472d9	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x21c011d8	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x22df7260	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x37b1f8a7	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x38b73dcc	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4f2bd96e	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x513879be	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6575d503	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x729ada76	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x75cf3f17	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x782920c0	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x9117cc5b	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa36bc1bc	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb755543c	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb93204b0	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc2206f6e	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xcded436e	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd403bb26	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5deb0d5	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe1e81011	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe499a69b	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x3c50baa9	omap_mbox_disable_irq
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x441e2964	omap_mbox_enable_irq
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x7c7e2c3b	omap_mbox_restore_ctx
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0xafaec100	omap_mbox_request_channel
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0xe0d58ed2	omap_mbox_save_ctx
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x097f2af8	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x10dc0d06	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x21c7828c	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x3361c614	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x442c40f3	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x66d28e22	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x6969b5d8	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7b55ca4f	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x9e8b3cee	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xa00946d0	closure_put
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xab2d2b84	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xad29a6f5	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaec09a2b	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaf77343c	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xc04554f7	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca580595	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd5d0b1ec	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe47e0829	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xf8fd4bac	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-bufio 0xa7978f56	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-log 0x5628cfa8	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-log 0xa661f883	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0xa80f66b9	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0xad9617f9	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x99865772	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x99907599	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xa7559b2f	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xab27e62d	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xb5db9b1e	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xf0695d36	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/raid456 0x85b71bb1	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x14001acf	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x38aa7d3e	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x5d03a6f5	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x664332ff	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x8bf685f5	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x96705fe1	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xa6902a2c	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xab0fe299	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xb34d5e61	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xc219bbfb	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xce1b8433	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xcf21ddb5	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xdae7d9ee	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x03865958	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x756fa1de	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x95848c08	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xb241f706	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0xaada2c08	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x0c59dc8a	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x2280ca05	tveeprom_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0c777d9f	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0f52e45a	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1dd85735	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2c26329b	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x31a87056	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x344908d4	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3656cb10	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x43c173c5	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5ba918c0	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5d8d7411	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5e7b38e7	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5e8a94c9	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x629f9d31	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x645f4003	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6660376b	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x72180695	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7f561fd8	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80c8dd54	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8633f37b	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8dedab4f	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x923be4d4	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9850cb88	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9c19040b	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb196ca0a	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xba05f27f	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xbb1e97ce	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc0158331	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc79e0b51	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd5757859	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdb1a8bd4	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdc094c39	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe3a188e1	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xead71b30	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xef861f33	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf1d3726e	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf48116c6	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf7a115cf	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfd459c8b	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0x03776d54	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0x553ec009	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0xf4650f86	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x0296788e	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x258829ea	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x7668456c	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x83c50749	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xa1acfc8c	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xc2d94262	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xcec7e607	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xe80e667d	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xefc0d4d2	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0xa7e3bddd	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0xd1235b24	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0xe69081fe	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0xc7a1be6a	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0xd94566cc	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x2f06d2ff	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x46207883	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0x798ffed5	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0x4cbc1bdf	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x9d09af8e	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0xa8731ad2	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0x6795d903	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x5452f9e3	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x9084c3b8	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xfb617f70	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x11f271ff	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x172af3cb	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xa14ccffc	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xab9316f2	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xd0c444f4	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x093c1c75	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x16091c2d	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x1f341936	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x376b2ed7	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x3827ac1f	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x3eddca7a	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5b2d5529	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x63530b2e	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x67c00ef2	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x6a2eb97e	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7c132154	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x9db860f3	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xc87898a3	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xe3b900f3	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf0734eb6	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0x92a8ebe6	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x214f8327	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x7490a802	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xaca83000	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xcfdbd710	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xe5b8e8cb	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xf6ef9cf2	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x16abce8d	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x6f297d8e	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xa9f2a178	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xbe7c97ab	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xc5a732e1	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xe5af7444	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x2a905fd0	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x345099a6	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x36789543	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x54094c8a	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xbe8698ae	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0x7ef48650	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0x538f3ebc	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0xa4918463	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0x737d6265	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0x34d090f2	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0x7cccc340	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0xa28b0453	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x4ce2add7	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x8415f25c	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0x065b4120	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0x7e6c6d45	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0x9402c9fe	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0xfe2dae4d	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0x0a1e0abf	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0x2438b1a4	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0x1c2c5615	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x8ab43f2e	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0x9591713d	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0xa8e7998a	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x30ea58d2	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x4236cec2	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0x3cc81ffd	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x5022bdbe	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0xeffa4f7d	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0x1571c679	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0x4e73eed0	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0xf9db9a68	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0xda9741ce	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0x33e1840f	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0xd10b1ee5	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0x7de2105b	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0x7f10ee9a	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0xf1ab8f80	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0xcf633bed	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x42599d33	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x864a5f22	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xd541de66	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x2a75821b	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0xd1872316	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x2bb102eb	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0xe2e1c542	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0xc3ca4423	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0x7901b3b5	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0xcbedf74f	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0x3b205aa7	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0x551cd346	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0x6dcd11d8	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x58a9ea61	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x453e4081	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x93dc4566	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0xd94dc628	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0xa5bbda21	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x7ca24e97	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0xaca3d9b6	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0xb775d256	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0xdb547f19	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0x5d033caf	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x09f207c1	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x1b0c948b	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0x57987e5c	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x481bd9be	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x3f9381a9	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0xd3b6cd6d	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0x3a7846b2	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0x3cdf3d11	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0x838beb9a	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0xe0476e4a	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x5e612819	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0xc37c6493	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0x9bfc6826	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0x423d2271	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x4b219479	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x62fc9e7f	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x6f7df600	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x7aec0f04	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xa43a2700	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xf6f711b4	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xfe6a447f	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x06b34e5e	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x128fbf05	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x27d6d075	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x5f2a75fb	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x9fc9ed3c	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xf1c0a06f	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xf82427e3	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x192e0a58	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x41b10c89	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x444ff2d8	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x44b700fb	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x75c93ae9	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x77aefee0	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x869cb3c6	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x87a2b53c	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xf9e68885	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0xdcf1e746	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x358aa18f	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x5f6e9c1a	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x60cd3501	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x79cf827b	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xca41b8e2	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe70da410	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x181fc91c	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x4dc7762d	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x65db6206	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x8fcd94b2	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x9f448826	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xbb2f5622	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xdb6f8fa2	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x45db04ca	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xe12bc4ca	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x46189693	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x5655b45d	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xe9c5be7c	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xec0c9adf	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x3b234a35	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x491cc953	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x70cec2da	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xd6cf6fb2	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xdce1cdb6	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xe04761d4	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xeb47247a	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x032120e8	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0603dacf	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x2284bbfd	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x28a208bf	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x3a5cce81	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x3bf676b3	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x43eed874	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x44125bc7	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4eefe5d6	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4feac66e	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x590fc09b	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x690943a0	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6f2a73b2	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x8d5cd042	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x9de6d007	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x9f328c06	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb344c18c	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb4de5fde	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc7523e33	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xdc34e453	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x0ac3016e	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x23ba22d7	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x4089efe0	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x4e66eb5a	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x4fdd3502	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x60c92993	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x6338dc64	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x68c0c559	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x7013e54b	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x768c14e8	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x76e6600e	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x8b0c53c6	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa8350d33	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xba6484de	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xd089a3b3	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xeac00e54	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xfe412439	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x48870733	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x4a046ecb	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x72cb6f81	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x74491379	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7b8c807d	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x870a0b53	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa1094887	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xafcfdbe8	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xbacee3ac	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xc0097294	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xed868fef	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xee45dae3	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x6852015d	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x424de473	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x47b9a455	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x88c72e91	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x895a58b7	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xbaae5800	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xd0f9c356	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xf6106110	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x971870c7	soc_camera_client_g_rect
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0xa9ad5efc	soc_camera_calc_client_output
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0xbcc128c0	soc_camera_client_s_crop
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0xd548da82	soc_camera_client_scale
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x28b9d87f	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x6b2d5955	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x7a867b8b	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x8095ab68	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x8d87ed28	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xc3dea060	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xde595dec	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x58f76c59	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x9541920e	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x997de40d	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xa3065c6b	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xc9cb2d6c	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xdf9b8266	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xe4bdfd2b	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xf8c4838f	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x181b11d4	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x8ecf7afb	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0x2c6949a1	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0x71136d5e	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x4e1b98bb	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x840e3b55	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xb1c6490d	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/max2165 0x4707ab20	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0xad801c8c	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0x227e503e	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0xa1b656ca	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0xabfb8862	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0x28baa614	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x1e46df4a	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0x880ab7b5	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x7fcd06f5	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0xa1bd4a86	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0xc440d56a	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x323d9a19	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x7b732463	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x04aa7bc0	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x14a0f6a8	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x48ad2691	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x5d4d9421	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x6049beec	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x62b1c1b3	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xa8abee5f	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xcaa788c3	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xe9561bc3	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x001a75fa	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x4b52cf64	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x550e7831	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x8f8d33a7	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xce16b769	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xd79300bc	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xf67c7da6	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x8393bca6	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x0ae53a2e	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x10f8972f	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x112f801a	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x25a774a7	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x6bbe1052	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x84714ddc	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x8b1ebb3a	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xa8779b5d	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xabdf0bee	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xf9feca3f	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xfc6e5519	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x861e0e16	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xe0a45a99	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x0163967b	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x1d36d5df	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x78611d6a	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xa5004320	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xb6cd9a8b	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xcd67a1b4	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xdcfdae59	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xe0bb8335	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xf4d1da0e	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x06a3ea3b	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x10e459a1	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x1a25b347	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x1d29aa67	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x323b5be9	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x7183a474	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x8e6dffb8	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xb8848e0b	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x1edaa73b	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xa1607c5d	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xdeb994c2	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0xd582318d	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0xfe453047	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x31fbf694	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xb0efdce1	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xef13b27a	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x067085e1	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x1257e361	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x3ac66a6c	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x75ffad8d	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xa677bc2f	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xe8629cc9	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x96f2b975	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0xe153090a	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x1660a731	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x9cca4e51	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x9df4466b	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xa135c6a8	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xd175ed1d	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xeb55a642	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0x135d8e63	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0506b093	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0992b2b6	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0b53bf2f	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0bfd1f76	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x10d6202e	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x11b24fa4	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x13aead98	v4l2_of_free_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x142c826f	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x174a5988	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1828e7b6	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1f2ab1da	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x214cacf1	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x240fe006	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x24ac34f0	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x32d9e41c	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36d7dbe4	v4l2_of_alloc_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x378ae0ae	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3a15cfd0	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3a523282	v4l2_of_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bf47be2	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3fde67f2	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x418a409b	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x42273866	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x463d5aab	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x50d90b76	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x540797e0	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x57d1e4e7	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x59d8bf48	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x651067fd	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x658e4a20	v4l2_of_parse_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x666c5708	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x690d3b8f	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x69c7be79	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6ba07d53	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6d2a1a9b	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x75b823ff	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x791b3642	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7c64c61b	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7ddb0466	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x84826813	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x851aa6a5	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x87683259	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x88843c62	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x89943850	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8ab5d504	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8c5d3f9a	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8c80ed03	v4l2_of_put_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x91822ed9	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9cc35d7f	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa08914b7	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xaecf6417	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc056e705	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc1d264ea	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc4259f5c	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc96e2328	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcaa70785	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcb5db031	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcb8804b9	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcbdf2a97	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcdd5cb05	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd3aa84ad	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdadb8cc8	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdae7d4a7	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdb5f1301	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdc86b200	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe754fb30	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xec1da54c	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeeabdc50	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf7a11de1	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf7a4085d	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf9adbcb9	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfd349f69	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfe6b815a	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x28179388	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x2fb75fea	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x43b10ac4	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5b5c17c8	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x645afb31	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6ca69b32	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6fb88eb2	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x8c9b5da4	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x8f7e5fe3	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x94dc915a	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x9b92f785	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x9c8608b4	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa323ef21	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xb12ff19c	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x098755f9	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x0e315a37	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x12facd51	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1c228078	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1e59399f	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x24882b93	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x290f18f5	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2d92cd9d	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2efb7631	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3256dc3e	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4094f96c	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x51a6f040	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x5372ae36	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x66450193	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6bfa80ac	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x716a4321	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x754cab90	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x762230a7	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x79d9cccb	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8755076b	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x94a24b3c	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xaab42aed	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xae51c586	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc85cb875	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc9b375d2	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd942c9c9	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdc180bf6	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xde8ca46c	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xeda86a79	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x039a9d8b	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0822adaf	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x15decc1b	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1620ce1f	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x3582ae9c	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x3da0921d	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x56afb662	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x5c32b596	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x601b93d0	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x6a0092a9	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x6f4cc504	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x79521573	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x84ed62de	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x88f5c11c	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x893bc828	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9df5c02b	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9f0d7ecc	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb3a3742c	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb7344589	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb8b7ac26	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xcfee7e7f	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd5728026	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd627587f	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xda85f1b5	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xde062ef5	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe5e33ea2	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xfb133181	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x2ac405dd	cros_ec_register
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xa7805423	cros_ec_remove
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xa82273fd	cros_ec_resume
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xe6f49cd9	cros_ec_suspend
++EXPORT_SYMBOL drivers/mfd/dln2 0x148da556	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/dln2 0xaab526cd	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0xc95c30f4	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x705464df	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xc21b8bab	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x1922df45	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x1e09e9b9	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x499d858f	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x6d344121	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x7afb0986	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xae357bea	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xb261b124	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xbcabc5cb	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xbccdbd3a	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xe3f68599	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf11c8317	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/qcom_rpm 0xd042c9be	qcom_rpm_write
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x6ac9f451	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x96a6b023	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x0659ec9e	wm8994_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x34635707	wm8958_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xa17571c8	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xab01552a	wm1811_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x6204713c	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x757bdbcf	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x8a05ed90	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0x2f2833e6	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0x6f671c6d	c2port_device_register
++EXPORT_SYMBOL drivers/misc/ioc4 0xcf1bdfce	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xf81018d3	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/tifm_core 0x0f00cb7e	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0x2091287a	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x232a14b7	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x39f86aa1	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0x3c5f7576	tifm_add_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x627798f1	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x6bbfdc3c	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x6e64bf39	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x6f03d881	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0x807f4182	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xacf2e7f6	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xd71ac5c2	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xd74b2700	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x45e50f5b	dw_mci_resume
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x52ab9010	dw_mci_remove
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0xe113c0fd	dw_mci_probe
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0xe8c7a308	dw_mci_suspend
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x378f2335	tmio_mmc_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x6d3deee9	tmio_mmc_sdcard_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x753b53af	tmio_mmc_host_probe
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x7a6fd700	tmio_mmc_sdio_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x83dae06f	tmio_mmc_host_free
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x90805728	tmio_mmc_host_runtime_resume
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x93099aaf	tmio_mmc_host_alloc
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xd3f398b2	tmio_mmc_host_remove
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xe8f50627	tmio_mmc_host_runtime_suspend
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xf02062dd	tmio_mmc_card_detect_irq
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x186c95db	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x42b318bc	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x575e56c0	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x70167940	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x7fbb35ec	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xbf7a6cd8	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xc5e42847	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0xada7ee88	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0x865b1cc3	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xb1b04c3e	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xe4a80928	denali_remove
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x0042376c	onenand_default_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x42547943	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x484c042e	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x990d9a36	flexonenand_region
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x1d3f4aba	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x29d53845	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x4d1a819d	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x4ec771c7	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x7351fe97	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xa8edaf7f	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xb9a924d1	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xceec02f3	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xdb6d51ae	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xed86a7e8	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x3aee36a8	com20020_found
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x8e1f3785	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x94dd28d3	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x0e30c448	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x1a576ec6	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x1a6e6cd6	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x1f24e3de	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x59690bc6	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x76a2c75e	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x8ad08bb0	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xaa4a0349	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xb166bd7d	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xe3e92165	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0xde1b12f4	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0xbbd5476f	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x0eda6198	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x230ad79d	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x2cdd4fbd	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x2dd7d59b	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x495328c8	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x6ea064df	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x90006dbb	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x90e41fdc	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xa9171642	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xae12dcea	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xb098d2af	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xbb085360	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xc641c6a3	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd8defa1c	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xdc65afd3	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xf6d9c501	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x01d4238b	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x06223b9e	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0649ff1e	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x09e571aa	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0ec3aa1a	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x19fd6c08	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x21d7b74a	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x2b9e03c0	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x32841b43	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x32fee243	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3cacf585	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3e522c99	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x407e2c8e	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x409ecbac	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x448f3b34	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4b478893	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4bb1ecd8	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4de31aaf	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x57e8cab4	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x59f57cf7	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x75639a2b	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7dc572f3	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8fb7b062	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x95fdf682	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa08f12bf	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa273ab5a	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa8b6ac9a	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb31cda9e	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb66200cc	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc44db77d	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc531fffc	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00a4f2f	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe74f3899	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf1a2e08f	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x255cc1ba	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x3f1a9cf7	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x4f1a9a61	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x74c2be41	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x81508123	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xc1a80bd5	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x268f202b	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x7fc720c8	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/freescale/gianfar_driver 0x79f28897	gfar_phc_index
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0x081b37e8	hnae_get_handle
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0x091db4f9	hnae_ae_unregister
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0x0a642da2	hnae_reinit_handle
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0x2ce1d3f2	hnae_ae_register
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xb1266858	hnae_register_notifier
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xdec4873d	hnae_put_handle
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xdf24adef	hnae_unregister_notifier
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b11cf7b	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0bc03466	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0e4836bd	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1756ddb4	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x17a1ed77	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x18a165ac	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x20e6e3ca	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2d00ef73	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x36be7142	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x379af837	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3f0fc542	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4ca5873b	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5a3f10bd	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5d7cfa78	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5fdd6e52	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6012cee5	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x68e20a57	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x731ece62	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7f6fd916	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x816af207	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x857f3685	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x875f280c	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8aa73380	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8b3be309	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8c5807e7	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x91d864a5	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9e21b539	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa65a449d	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xab5a2417	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb548426	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc6c706dc	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc7c26948	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd0508910	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdff30781	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe751c396	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe85237be	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfc547df4	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfed4a5b2	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x01e4ac90	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x062e0eca	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0a101d0d	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0b241ff5	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x190791c5	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x19b3f8e4	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1b06bdb8	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2a734d63	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x34f457db	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x389b564d	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x45e85197	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4cee40e6	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5562b945	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5e0c9f37	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x68121063	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x69659cab	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6dbaea61	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6f41607e	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7007eec1	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x72f59953	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7e5499c5	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x874ef215	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x885dc453	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9314cff6	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa560ddab	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa8442fa8	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xad683ae3	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb2e1cdbb	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb45b04ca	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbf0d022a	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbf6437c2	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcd73264f	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd6b0be56	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdd302e30	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe8583eaa	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe9249293	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf7a32c03	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xffb3480b	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x075a30db	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x2038b9d8	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x51d5f256	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x55e30b93	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xcb5c8545	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xf1558af8	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xf741371d	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xf742cbb9	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xe3e8b3a9	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x0a31a781	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x2e4a402e	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x7ef67f78	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xafd57826	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xb8ffcc4d	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x27fa866e	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x3a1aa161	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x3c8034d0	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x7057e69a	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x86ddc364	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x934108b2	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xa02f854c	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xa9356528	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xc9c9a2fe	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xe8a94c0f	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x2848a050	mii_link_ok
++EXPORT_SYMBOL drivers/net/mii 0x4fad86d4	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0x6556febd	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0x7d0c50ea	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0xc6dabcc6	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0xeda294d0	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0xf96ea56a	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0xfa4a9094	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x4a265bca	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xad3a3f5b	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x056c81c4	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x3ba7b68b	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x8b8788a0	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/vitesse 0x87f92709	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x50f31801	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x8e7a4a50	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x9cd4823c	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/sungem_phy 0xc7f532e9	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x1088b88c	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0x1d48c0b8	team_options_register
++EXPORT_SYMBOL drivers/net/team/team 0x1de83e03	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0x438b68b4	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0x4f2e7735	team_mode_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x8338922f	team_options_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x88582c59	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/team/team 0xd2ed42f4	team_mode_register
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xbc487c3f	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xbe18d6fd	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xf617daa8	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xf7453bfe	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x06f6fb4e	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x09cf457c	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x54bf5a78	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x7cd21b8f	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x8e801aef	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xad64b9dc	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xbe456ee1	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xc9e2f727	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xd7152319	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xd791ef41	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xfad7ff3c	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0xd883d531	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x0129729b	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x21ca6739	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x2758a0c7	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4d881e1c	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4e206a48	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x5150bc01	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x59111643	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x65706843	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x8744270a	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xc339f777	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfa928b3b	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfcaab3cd	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x05e9b376	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x2cf757de	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x3f243bf9	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x49e4cac2	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x49f33e33	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x4e579f3f	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x7493aa23	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xa7ed5dbb	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc10d80b7	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xd0e43672	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xdc5958d6	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xdd5c95a4	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xf056e2db	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xfabe987b	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xfbce95ac	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x20c20cfd	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x62b4d6a3	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x739ae933	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x9b540432	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xb52d87e9	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xb70c47bf	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc6723c5d	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xd0554cbf	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xdeb178ee	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xe12ac269	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xe475e614	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x0ad5ccdf	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1268fc81	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x144e39ad	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x29f29fb3	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x3cfbc755	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x617d2819	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x63e2ef1e	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x64322beb	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x690f4542	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7619cdfd	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x80e7bf7c	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x85620edc	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x8dbc05bc	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9cc48dcc	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xa4339295	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xa52e5967	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb1f79564	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb2714ee9	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb55577e5	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xc80848b6	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd167c3fc	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe91f804f	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe9401f60	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0224295d	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0599f1da	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x095ae6a4	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0bb3ef43	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0c69924d	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0cbd18fd	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0d17a5ec	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0d99cbba	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0fb3cfbd	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x146b552c	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x16a863f6	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x24ee288c	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2b68eb2c	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2c9e5bb3	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x30d60e9c	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x325a6d65	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x33d905c4	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x348162b6	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3632433b	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x37ce4b36	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3858aa3a	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x38811a35	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x397412b5	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x39a70c5a	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3e5a06f4	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4009a24f	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x430a08b2	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x432e094b	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x438a2683	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x44b8acf5	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x491c0bb1	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4aa48c78	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4b06edb4	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4ea9504f	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x51d6f42c	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x53da5fd1	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x56db0f32	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x57008d4d	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5ae4d75f	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5de97c94	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5e8e2d3a	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5f474589	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5f6ecb63	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5fd9eaf7	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x63016a88	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x640f6f26	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x649a6755	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x689b2ee4	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6a08a70a	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6bc03a8c	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6cea49de	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6e632967	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6f23c805	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x749c46a1	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x76c4176f	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7ddb4e49	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7fc85fb0	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x826321e6	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x83981ab5	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x84a6e403	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x85d69384	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8694eca4	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x88e31069	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8945031b	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8997c39a	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8fbcb288	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x907f4be9	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9412bb53	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x95527151	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x95c770fd	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9a750b1e	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9c4b6d15	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9e733b11	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa05b97bb	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa0dd8665	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa5324b86	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa5bbf27b	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa72f7ee2	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaa767531	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaf5db13a	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb14c5bdb	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb200f30c	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb5cffd52	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbabac192	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbadf2160	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbe985ee8	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc46071df	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc7887829	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcfd2a847	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd359a07b	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd5801f80	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd7458259	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe11c282a	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe3aeeebe	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe67c75ae	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe9ed289c	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xeb8ef855	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xef6ae004	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf0323fdb	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf19e3c5c	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf1df7fb7	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf3e0df35	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf8fbc8e6	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfb34d61d	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfe628b98	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x25e1a2aa	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x9322848d	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xa247d9be	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x009f88b1	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x1c3ebae8	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x1e848bef	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x41eb2ebe	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x63548f8e	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x6a4877cf	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x777b3b55	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x92b341e3	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xa7de38d5	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xbbb93fdd	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xc7153351	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd76fdc1b	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xe4ddf0fc	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x01873018	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x08580e37	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0ad69602	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x11ed711f	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x16a946d1	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1a3bfb01	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x35ba6c5a	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x3937a87f	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x3b7f884b	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x4593a77a	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x523ab11c	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x53348ec0	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x554e6750	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x6b5c668b	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x76902394	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x81434184	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x85971e65	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8bb1d3d8	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9004629b	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x99c4ac35	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xaef21f6a	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb3a36294	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xbeb119c9	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc7cdfbcc	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe0c89585	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xefbd9888	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x0e8dc252	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x16c33e4b	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x16d13542	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x2723b380	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x2726e2ac	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4b35b6bc	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x72df9c60	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x72fe3f07	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x858c8181	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x9ef6a580	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa7231706	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb3b946a9	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb5012c68	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xc30951ec	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xc793f30e	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xcd516b68	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xdb4a45e7	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xe7c7ec80	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf2fe4097	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xfaa4ae4d	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xfba3e00b	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x005db417	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x00ac0be4	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x01c009ac	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x03e4fb75	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x055e228d	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0bf66024	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0db6744d	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0df66f7c	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0f505fad	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x140e6573	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x17f5eac8	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x19d02c85	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1a7f22f7	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1da5ee47	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x22e8cec3	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x239b7811	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x24ab0d6b	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x295cc70b	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2d4e3a10	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2e34e5af	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2e91497a	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3157f850	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x35252e72	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3792ded1	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x37bec136	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3dd56380	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4110516c	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x41282ae2	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x48a87e66	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aadfbc2	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4b6fa313	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4c3ac897	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4da9bbc0	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x537c848e	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x58276a53	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x583e44b5	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5d6702b7	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x620b7678	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6d60d260	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6f53dc4e	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x713e1235	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x72df1c29	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7649e3e1	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7a17b39d	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7af8b521	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7c4a2eab	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x80650100	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8136fb66	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x82f9ec2d	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8563e214	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x86bf7ef9	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x876bb254	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8df54667	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8e397060	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8ef04219	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8effefc5	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x940888dd	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9830471f	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9ec8c527	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9f13a4b2	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9f80e48e	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa375fbdc	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa443e030	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa55f1cca	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa64d6ff3	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa74ea66a	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa91f3245	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xab3ffb08	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xabb932d4	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb154c943	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb20872eb	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb2dc1fb7	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb6127fba	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb6429d36	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbe01cb40	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc1540a26	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc2593247	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc4bead48	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc7e89a69	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xca3e31ab	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcbccd9c8	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd0d4686f	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd202b721	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd7a3701c	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd827e829	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd975e6fd	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd98ebb61	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdb4b5f4c	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdd2ec5ce	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdfd77856	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe4cda72f	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe7404263	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xed0ddb2c	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf290538d	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf4515a68	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf4c4c138	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf72e9d98	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf83ee14d	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf9687081	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x180d7a46	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x208d96c4	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x26bb7eb8	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x436814a2	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x496d7aef	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x8f81067c	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xfd34aff0	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x05182837	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x08072747	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x19391fa0	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x279a7c05	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x4d837754	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5bfb0c47	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5c59a092	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5d8151f7	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x8202c9a4	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x8bb7feab	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x8ce51af7	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa5c73e36	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xc1d3c041	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xcac33ef8	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xce2cb7f2	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xef9e637d	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf5e9f8a5	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0x031bfd9c	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x042a75b4	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0a36c28c	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0b93e820	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x10f7aa5d	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x275aaa36	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x33eb74de	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x377cc8e3	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x39733cf7	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3bb3c3e9	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3c3f32f2	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3cf6eb56	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3d11dd94	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4bbee457	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4ca42fcd	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4f62e7a9	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5df66c60	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x71bd484a	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x76855a00	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x77d4ecaa	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7c29e8b3	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x838880c7	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8842da97	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8851589f	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8eb8e914	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x941a705c	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x9b920e24	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa32d89fd	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xaac4cc55	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xab73706d	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xabd85b14	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xbad3d3a6	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc4256f72	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc7eb8255	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xcf1c7bf0	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdecead33	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdfc60f29	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe137e24e	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xea9129a4	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf7bb137d	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf9672706	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xfc049182	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x13ccc653	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x83f85bfc	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xcaa30216	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xcfea4645	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x095189e0	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x33118c98	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x6bf928a8	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xbf0f2f82	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x10122aad	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1f719554	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x24f15cbc	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2aa3d369	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3352b182	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x36be4e39	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3b93e62a	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3d4c6f71	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3faac9e2	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x44dae7f7	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4c19be73	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6a3e6095	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x7b202e73	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x86b5dd75	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8c2df732	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x90a2594f	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9735885d	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa3239742	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb0304fc3	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbb87fcf8	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbf905272	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xcccc9b20	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xcce44f90	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd002a4dc	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd71faeba	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd734f96b	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xec5c6e37	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf176bb23	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x1f4203c3	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x20479eea	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x8a5a8fff	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xcbd1737f	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x142103d0	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x96a537ef	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x9d1bbcdf	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x1ce8844f	microread_remove
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x98dc1367	microread_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x046b3234	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x6f8b446c	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xfe53b3c0	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x4d64cdca	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x8c6c1c62	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x0cbdd888	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x1e7a6e01	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x3c9d6959	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x08e2536b	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x0daccf8f	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x2753aa51	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x4de0dbf8	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x5ea58997	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x767af843	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xa3fa2502	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xaa6f7c84	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xc06e5fe2	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xc38ef1a8	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xf2d272de	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x09fe66cb	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x18fb87c5	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x2b03336c	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x4338f4d0	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x47762f3f	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x4b8a8fe9	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x768010c4	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x86d33413	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x977c363d	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xa9e3fc50	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xb95db3ac	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xcbd7a141	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xcc559e0b	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xcc6b0b52	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xd20ee2ed	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xd957e2bf	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xef2c959e	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xfb48db14	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/ntb/ntb 0x18f952fe	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0x56483876	ntb_db_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x5cb206a4	ntb_clear_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x62733a02	ntb_link_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x7ff110be	ntb_register_device
++EXPORT_SYMBOL drivers/ntb/ntb 0x8da2bba4	__ntb_register_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xcf3a7cf7	ntb_unregister_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xd1b30171	ntb_set_ctx
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0xdb6e5b0a	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x038ee0a9	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0x0a28d509	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0x19fad623	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x1c098d8a	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0x25fecd78	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0x2d485e4f	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0x38cd3188	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x3947939c	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0x4ba9d6e8	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x6720fc29	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0x6b580372	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x79f2fa53	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0x7cba3fd7	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x880a8687	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x9b7f70ba	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0x9e1bbab4	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0xb1182720	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0xb19d8ce5	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0xb72284be	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0xbbe633b4	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0xc243ab4c	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xd27057a4	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0xd5a197e9	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xe68b84f2	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0xeec76bd1	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0xeefc8039	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0xf243add4	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0xf2569442	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0xf3d70af4	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0xf47195c8	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0xf77ae3e3	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0xf876af5d	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport_pc 0x4cab5001	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0x52b52061	parport_pc_probe_port
++EXPORT_SYMBOL drivers/pci/host/pcie-iproc 0x8a1601f5	iproc_pcie_setup
++EXPORT_SYMBOL drivers/pci/host/pcie-iproc 0xd3fa94e5	iproc_pcie_remove
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x196dc724	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x212a169a	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x336c2edc	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x99251618	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xb199f18f	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xbe97709c	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xde68f4f7	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xe3b9af09	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xe5d92baf	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xf36f7721	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/rpmsg/virtio_rpmsg_bus 0x68009703	rpmsg_send_offchannel_raw
++EXPORT_SYMBOL drivers/rpmsg/virtio_rpmsg_bus 0x88ae4762	rpmsg_destroy_ept
++EXPORT_SYMBOL drivers/rpmsg/virtio_rpmsg_bus 0x8df90ea0	rpmsg_create_ept
++EXPORT_SYMBOL drivers/rpmsg/virtio_rpmsg_bus 0xb7e01e1e	register_rpmsg_driver
++EXPORT_SYMBOL drivers/rpmsg/virtio_rpmsg_bus 0xc4cc4c03	unregister_rpmsg_driver
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0x3e06da02	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4ac73793	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x60d59edc	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x9d371116	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xf010b230	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x23fdc4a4	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x3a7a702f	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x5a2580ce	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x6832399d	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x6cef238b	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x79028b84	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x79425123	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x89c24009	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x8c7a97f2	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xb42947f2	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xbbd73ff0	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xce4a6cd8	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x06ca172d	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0be1aec5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0e49cb7a	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x105d3659	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x109e2831	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1185aa2a	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1339c595	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1384c88d	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x13f9504f	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x14718517	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x177a8d78	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1c7b67de	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2b03e77c	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2b110724	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4e740621	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x503f0de6	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x59163335	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5b64a3bd	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5bc335d8	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x632c1da4	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x63794b88	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x74e2e838	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7a3801dc	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7ac35c31	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7acdfbc0	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7ce50738	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8a0d6b98	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x904b4db8	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x95639822	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa2e67aaa	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa64866d1	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xaa4225ce	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xade948f4	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xaea21842	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xafb3bc4e	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbcb181e4	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbd80de6d	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc6409d6c	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd0a5964c	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd186153b	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd3a03483	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xde2b1945	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdfcb97a9	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe2cb201c	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe9f9d152	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xed9e90aa	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf24259c2	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf92e4b58	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfbfc1217	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfc4489f9	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x20d8b3ae	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x34cc7156	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a65878d	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x95193c16	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0xeb5e6290	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0494177a	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0571ed71	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c81c545	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0d9d40e4	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x18c86d1e	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1a171a5c	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1c3c189e	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3d68b663	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x46199bb0	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x467d698d	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x533f2a01	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x54ff9a40	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x63ebebb5	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x679a48db	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x70ef987e	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x798d0b8e	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7b34b250	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8592823b	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8916fe06	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8c56c94c	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8ecc0e8c	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x96928eb2	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xac03cb6c	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb15c10b8	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb28651fc	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb40cefa0	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb55dceba	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xba37681f	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbc23194b	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc0d80341	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc13b2342	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc887b598	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcbe99585	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd4d31780	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe83d92f2	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe9877114	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x03c81e44	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x172f542a	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x1ae9c485	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xa97b6c9e	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xbee03eea	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xe76d3a3a	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x00f5d3d1	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x0f245823	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x15010e78	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x33fbe5e8	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x5fc01750	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x616d2876	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xad23509d	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xb00a8d01	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xc222536b	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xcfa74ec9	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xddc4968c	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xf05d1637	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/raid_class 0xb3609724	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0xe38a0fbe	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0xf564962a	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x177ff1e6	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x205cf692	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x31215a28	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x508c4a38	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x6b0e9f0b	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x753c3177	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x91cdb038	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x9fc6e839	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xa4350546	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xbcdff7ef	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd3e699f0	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xdcfe66a0	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xf31e3a81	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x02f8ccf0	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x0e4c87b2	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x126494ca	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x146aa871	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x179c502f	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1c565132	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x20f91100	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5035ad69	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x50f4b443	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6cb46221	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6cddf46d	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x714af75b	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x78bc5f39	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7cbf8e1e	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7d437518	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x83f407d5	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x85af0f5b	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x8a765c98	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x929bd77c	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc6b808cd	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd15f8ff0	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe5884dc9	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe815f97b	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe96522da	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xeed17bb3	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf8db582f	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xfc64c336	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xfeb22106	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xfebaa8dd	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x1d45bdef	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x7df2e4f5	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xa2158068	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xd0d2821a	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xe05f4d94	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x0a0719cd	srp_start_tl_fail_timers
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x281f37ae	srp_rport_get
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x2a173a80	srp_rport_put
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xf4619d85	srp_reconnect_rport
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x352ef0b2	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x61a17c00	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x62e18496	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x9c465aa7	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xca1e4024	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xd37136ad	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xe5aaa6a7	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/soc/qcom/smd 0x8161c0de	qcom_smd_driver_register
++EXPORT_SYMBOL drivers/soc/qcom/smd 0xb2bf1b9d	qcom_smd_driver_unregister
++EXPORT_SYMBOL drivers/soc/qcom/smd 0xeda44e54	qcom_smd_send
++EXPORT_SYMBOL drivers/soc/qcom/smd-rpm 0x2f5501c0	qcom_rpm_smd_write
++EXPORT_SYMBOL drivers/soc/qcom/smem 0x5a710273	qcom_smem_get_free_space
++EXPORT_SYMBOL drivers/soc/qcom/smem 0x63ef36e3	qcom_smem_alloc
++EXPORT_SYMBOL drivers/soc/qcom/smem 0x932eb0e3	qcom_smem_get
++EXPORT_SYMBOL drivers/ssb/ssb 0x000cbe94	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x3ba18221	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0x4a104b6a	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x559ca68c	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x5e444d9b	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x5ee62299	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0x7d94607b	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0x8333efdc	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0x9a956f90	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0x9c51e225	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0xadaf6c3c	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0xadf00ed8	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xb5d917a7	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0xb731e868	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0xbed474c5	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xdd69e065	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0xe688385d	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0xe9f712bd	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0xf51c3af1	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0xf9669994	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x11f72c82	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x12172608	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x13abe828	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1d641d04	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x25d60a11	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x27801dd9	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x340e0b5a	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x3ce36afe	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x4145ea54	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x47eefaa6	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x4910dd10	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x4d039a71	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x7246661c	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x8e3e08eb	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x9d69c6f0	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa01b37c0	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa1bcfe43	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa9e64fd2	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xaf0a80b1	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xb79d2c66	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xd1b619a1	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xde19b212	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe0da5e07	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe973b079	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x7faf6bd8	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x910374d9	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x1de776b4	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x183aabca	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x89e19161	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xd16c5e70	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xebde9eda	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x24f77508	ade7854_remove
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x2692755b	ade7854_probe
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0x47a65abb	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0x34a2ab3c	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/nvec/nvec 0x459c12ee	nvec_write_async
++EXPORT_SYMBOL drivers/staging/nvec/nvec 0x6a1a153b	nvec_write_sync
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x00d32ec7	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x010e17f7	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0a465ff6	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0bb01060	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0c99a7a2	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0e533682	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0e979699	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x18a02ba4	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1f893d10	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x203ee996	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x28653261	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2a8c52a9	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x32fefc24	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3cd161c1	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3fa22a37	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4120fd88	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x47f99892	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x510f4f75	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x53503bdf	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5662b7bb	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x56c04fa3	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5758537a	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x59fb36d5	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5c12dc1f	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x62894319	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x690a8d29	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x767765d0	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7c1d9635	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7c6e26dc	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8683532f	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x86b1ea77	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x89d43baf	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8dc152db	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8f048390	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9315a090	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x981c8e29	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa1a6e8dd	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa3ae7a8a	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb10dfa05	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc47900dc	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc54825df	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc9b9d4dd	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd1dd4a3b	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdbc3bf8a	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdd6d0d07	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe22ab15e	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xecbd1e6c	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf039e28b	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf54b7271	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfcfe6bb0	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x041ee992	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x07feb41c	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x095a9a09	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0bb6b5d3	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0e7d98d3	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x106494f6	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x15b1de89	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1d7a93a1	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x293548eb	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2a6bd0b4	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2b364fb7	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2f6d2746	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x38ea9fff	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3c568424	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3f7969d5	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x408243b0	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x421aed6d	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x44ddfeb5	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4df01c77	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5b026557	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x641072f7	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x645eae1b	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x68959a86	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x691cf2ed	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6f10fbc4	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x740ddd4b	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8a7afa27	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8aeb16f4	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x90bd6bca	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x91281115	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x97e1dca6	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x982bf39a	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa0823741	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa0eb3d03	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa6d62771	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaa85c9cd	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb3828ee6	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb5183c04	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc82f8ef3	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xca2c47f5	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcf4c2491	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd19841a8	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd9b593de	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdbed5aad	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xde6895e8	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe3c65065	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe511d4bd	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe5ee82ab	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xeaca9ae9	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xeb914002	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xebc3f786	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf0caa22d	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf1beffdc	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfa311949	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfc7b0d9e	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x019edf66	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x07cc5957	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x1d1be6a7	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x1def640b	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x305f6e3c	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x33070798	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4538a714	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x51234e99	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x537c8e65	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5ada30f9	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5fa18b5e	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6cc813fe	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8004a59f	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x82834fa5	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x971baf72	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x99d61feb	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x9ce8a92d	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa0c15ccb	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa1c5bd0d	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa8dfbcb5	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xabe40eca	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb10416ac	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb15e780f	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb9e188d0	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc2440b9a	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc3affc8b	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe47f51aa	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe68ca88f	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02bafdf4	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x04cc0edb	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x07011271	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x11ddcb3f	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x128ad4a4	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x14dd9fe4	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x16aadb85	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1fd60b19	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1fef0ca2	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0x20fe0a93	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0x277dc497	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x28a94d2d	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2c21b644	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3180a8f5	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x33b44037	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0x386d2c54	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0x389e7261	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x38d462c7	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x393024a8	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3ba33a9c	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3dd68b52	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3e99008e	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x45a5faab	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4707f681	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x476b33af	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4818c539	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4a8ddc52	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4d6f9ea7	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5067753d	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x51d6d208	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x523b64fd	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0x56353522	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5933221e	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5b7df050	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5ba956f1	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5bfaefa6	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x70cea526	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0x79835a8c	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7bd85b65	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x839dbf3a	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8475f4ca	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8622560c	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0x86bd1b77	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8722437f	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8a43b4c4	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8c5f2e38	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8d5984bf	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9c3b344b	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa3695382	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb24d81cf	transport_init_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbdf2c8da	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbea494c6	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc0562c39	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc9c39344	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc9d637fc	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcaba53cb	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcb6a46cc	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xccb585cb	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcf989dd0	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd4289d55	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd50766f7	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdba27308	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdc49538f	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe58ece05	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe894d436	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf3ab182c	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf7d93569	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfbe1f1b2	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfd94ba39	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0x04ef09aa	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0x856b66f2	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0x41501004	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x22f81dc6	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x32b3d3a4	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x38f3a4dc	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x4c04006b	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x69e82cb4	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x71c0614d	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x7651e99a	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xcd3e7b79	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xdab13912	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xdf2f0040	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xe60f85ee	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xf7c6908d	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x796996a7	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x9f5fecb0	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x2e91ca97	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x367ce26a	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x59f824d9	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x7bda5e6d	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x821e9390	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x937e412c	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x2be05e5b	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x91f15814	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xdc9d7695	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xdff85253	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x08388bc1	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x18e16b49	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1ce75fc9	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x475fc6fc	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xa7cd52b3	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd65762d5	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf3cb5abb	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/syscopyarea 0xa50ceb6b	sys_copyarea
++EXPORT_SYMBOL drivers/video/fbdev/core/sysfillrect 0x3e2c2c8c	sys_fillrect
++EXPORT_SYMBOL drivers/video/fbdev/core/sysimgblt 0x987b5b3c	sys_imageblit
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xe9e76187	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0xfbfe32ef	mac_find_mode
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x2822d166	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x35baf93e	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x3e36fa23	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x613feca4	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x9f9e6ec6	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xdaed1dd3	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xe542ca23	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0x9acf0ea9	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0xd119dd5f	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x3424948d	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x69e878a5	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x9eb161db	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xd1e2ef02	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0x8919bdbf	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xc9125a10	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x6e303757	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x8903b899	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x9ac8d81b	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xa557ec5d	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xadb94f4a	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0x8aaa158b	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x1618bed3	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x25dd31bf	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x2c9dbd6f	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xf2ce9350	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x2406d401	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x9b547eb3	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x5e98963c	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x842f751c	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/wire 0x14d4bfb8	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xbd1ad4e4	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xc8946a24	w1_register_family
++EXPORT_SYMBOL drivers/w1/wire 0xf3006573	w1_unregister_family
++EXPORT_SYMBOL fs/configfs/configfs 0x05ff8d88	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x1cadb62e	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x1e7b9a8a	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x2a702015	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0x30cc25d5	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0x34bea5d1	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x428804c1	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x4fdf250d	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0x68e68da0	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0x693134d1	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0x74958d33	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0xd2a7f61a	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0xe4132d8f	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xf5cdb856	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0xfede5146	configfs_unregister_default_group
++EXPORT_SYMBOL fs/exofs/libore 0x0d22d2ee	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x724d93a1	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0x8c2104c7	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0xa2338dd8	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xb5ce5870	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0xd8f3e9b0	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0xe02937ba	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0xe29f69a9	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0xebc309f6	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0xfc416ec2	ore_truncate
++EXPORT_SYMBOL fs/fscache/fscache 0x01166d01	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0x02f05c61	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x05ab1850	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x177d08f3	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x18514066	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x1b94a60d	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0x25631afd	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x2d4b4e16	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0x324a0030	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0x499a9ace	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x4b1ce5de	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x4be68262	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x4d67be44	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x4dc41049	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x563930c0	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0x60eff1b9	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0x611425b5	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x616aa005	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0x67972715	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x6ab195db	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x6af4ec75	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0x6c641f7f	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x7022218f	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x811858e0	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x8a4b96aa	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x8e449211	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0x9944ee72	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0xab90d6dc	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xc39024b6	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xc89afb7b	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0xce03939f	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0xdc536d8f	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xdd10cc1e	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xe195e1b2	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0xe483419a	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xedd04140	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xf6b3c20f	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0xf9717730	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0xfc9a0b53	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0xfcbc75fd	fscache_object_mark_killed
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x1b708e28	qtree_read_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x305ab4c1	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0x3dbdc8c5	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xc1ab07b1	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xcbc7ef53	qtree_write_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x3771b461	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc-itu-t 0xf5b4a948	crc_itu_t
++EXPORT_SYMBOL lib/crc7 0x66213969	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0x41248eaf	crc8
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x03f599c7	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0x22ee90d9	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x4feade4b	lc_create
++EXPORT_SYMBOL lib/lru_cache 0x56fc3ea0	lc_put
++EXPORT_SYMBOL lib/lru_cache 0x619ed575	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x84e0214b	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0xb673970e	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0xbbe7c23c	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0xc48fa976	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xc6e4cd46	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0xcb990a55	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcea6747e	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0xd212c9f0	lc_get
++EXPORT_SYMBOL lib/lru_cache 0xeb13128b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0xf460a486	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0xf5ea5f5c	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0xf6acec20	lc_find
++EXPORT_SYMBOL lib/lz4/lz4_compress 0xcbc5d521	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x26c3aa22	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x269de703	lowpan_netdev_setup
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xb33de3fa	lowpan_nhc_del
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xd9ed6158	lowpan_nhc_add
++EXPORT_SYMBOL net/802/p8022 0x45cd6b6e	unregister_8022_client
++EXPORT_SYMBOL net/802/p8022 0xe9c92084	register_8022_client
++EXPORT_SYMBOL net/802/p8023 0x309cb34e	destroy_8023_client
++EXPORT_SYMBOL net/802/p8023 0x35fc3aae	make_8023_client
++EXPORT_SYMBOL net/802/psnap 0x6011dcd4	unregister_snap_client
++EXPORT_SYMBOL net/802/psnap 0xc9910587	register_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x00a10a91	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x0166ab87	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0x0ee279bb	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x1a37c7e9	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x20aa5d87	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0x23033634	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0x239a6273	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0x2493ff2f	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0x3200689b	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x4377515f	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x45946329	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0x45c2947c	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0x46982cdf	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x47653791	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0x4cf1af66	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x546bfc07	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x76c3985a	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0x7a8c94dd	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x7db87f3f	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x832b09d9	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0x8e2d7a5c	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x8f0490d0	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x9ce58e4f	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x9fff6394	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xa0bed5a3	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0xa414d79e	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0xa4e7dd2e	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0xa9ba4956	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0xad78c0e9	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0xafed9db0	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0xb5715e74	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0xb6e096c6	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0xb75a2370	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xc0fcfe60	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xc8d6e130	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0xd20ff10f	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0xd2353dc0	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0xd605f6ef	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xe8f3b87f	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0xeb19c171	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0xeb212644	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0xf180eb0b	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x79569ac8	aarp_send_ddp
++EXPORT_SYMBOL net/appletalk/appletalk 0xcf712946	atrtr_get_dev
++EXPORT_SYMBOL net/appletalk/appletalk 0xe608d51f	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0xf5b4eef8	alloc_ltalkdev
++EXPORT_SYMBOL net/atm/atm 0x105ecc3e	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x279c945c	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x5b1277dc	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0x77ef835d	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0x8d52d9f8	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0x9acd0d97	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xa46cfdfc	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0xa75d193c	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xbfb3ccdb	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xc8c48f1c	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0xcc56159f	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0xedf81350	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0xf1774b53	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/atm/atm 0xf69f4920	atm_charge
++EXPORT_SYMBOL net/ax25/ax25 0x0e714d92	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0x1dbe5d61	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x30ab3ea0	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x3eff790c	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x5c576c1e	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0x68c7f637	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0x9ea72c37	ax25_ip_xmit
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xd0974115	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x089e44de	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x097277bb	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0abdf2a3	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0b6dce1e	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0c3f1b76	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0c92e03b	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1300e46c	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x141950b4	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x15bd45c2	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1b8d22e2	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1d21d2ab	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1df1c49a	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2c44740e	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2f6c54c2	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x369f658f	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3ff21bc3	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x454c887f	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4d181eba	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x629decde	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x64c949c1	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6e98fd31	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x704c9f38	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x70676325	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x75593edb	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x80381e9c	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x88b7d0d8	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8f8ce4e7	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x93f53e56	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x944d8653	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9f54a243	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb4ea399a	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc9357007	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd2259027	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd37f7ec6	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe4b33473	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe56ec06b	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe69c751d	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe8d0b881	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe9f2d98b	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xedf46244	bt_sock_wait_ready
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xfeed54a3	bt_sock_unlink
++EXPORT_SYMBOL net/bridge/bridge 0x1ce97d9f	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x06a04042	ebt_register_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x100e43cb	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xa522763a	ebt_do_table
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x3cd53c9f	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x509598d0	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x98cb41b2	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xa58c5538	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xba9da190	caif_disconnect_client
++EXPORT_SYMBOL net/can/can 0x05c16228	can_send
++EXPORT_SYMBOL net/can/can 0x3aa8ce45	can_ioctl
++EXPORT_SYMBOL net/can/can 0x9b856ac7	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0xb56542f9	can_proto_unregister
++EXPORT_SYMBOL net/can/can 0xc52323c4	can_proto_register
++EXPORT_SYMBOL net/can/can 0xcca71ec3	can_rx_register
++EXPORT_SYMBOL net/ceph/libceph 0x08e2c808	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0c21bed0	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0x0d4de47d	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0x13542f04	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0x13695166	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0x1525c9e2	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x152f9ee2	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0x159aa0f7	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x1a1dc311	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x20d81cac	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0x22a027ce	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0x24489f8b	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0x2a684497	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x2b45bb31	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x2d0ccda8	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x31c948f1	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x32c6d5ad	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x3894fb60	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3d144d3f	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x3da4ee03	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x3f4529e4	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x40e1d2fa	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x459d47f9	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x46ffcf2a	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x47886603	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0x47a9920e	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x4ca7240d	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x4fa1379d	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0x5091e966	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0x51f3f3a1	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x542061f5	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x54ef988e	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x60d68bcf	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x61f015b9	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0x61fa18b9	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6f345c1a	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0x71f01c20	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x72b37b9f	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x74cc3d56	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x75e9a202	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0x7e7dea0f	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x7f4313bd	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0x8060df73	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0x85520843	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0x8b7fafb1	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x8f27c0b4	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0x90d749e2	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9aaff844	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa1ebde8f	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0xa394aa2d	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0xa4cc81bc	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0xaaac2844	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0xadf75da4	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xaf199884	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb189bdb8	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0xb19dc152	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xb22ee579	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb655e08c	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xb9a85d33	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xc091669d	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc645d800	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc7b0c0f3	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0xc9458067	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xca670f06	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xcf06af2f	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0xcfd089ff	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd5383217	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xd813625e	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xdbf22739	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xdd4ddf68	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xde0eb6ba	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xe3c929bf	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xe41c52ce	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0xe55d9bcd	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0xe69000be	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xecfa48d7	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0xeee19bf6	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0xef41c898	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0xeff72249	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xf4de86fe	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xf58739aa	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0xf5965d46	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0xf5d17500	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0xf5ed769e	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0xf7e3713b	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0xfa27171c	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0xfa47d77a	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0xffd9d43a	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x5270e55f	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x6c9dd34c	dccp_req_err
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x00b5f807	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x5bba91f7	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x69d52073	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x825be101	wpan_phy_find
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xbd9b4cec	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xd293b073	wpan_phy_new
++EXPORT_SYMBOL net/ipv4/fou 0x0c07b4a3	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0x481970c0	fou_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xed741d6f	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0xf6616a60	gue_build_header
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x2451d8ba	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x2ff3d674	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xc0dcce5e	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xcfaa5a67	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xe4de0a4e	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xf40cc6a8	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x7798e5e5	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x9bb0a872	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xd041ee06	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x6f8edf5f	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xd7c62acf	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xf061b02e	ipt_do_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x39632d4d	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/tunnel4 0x5e9ce3a1	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0xae6078e7	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x1f6a3b6e	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x8bf02102	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x9f050310	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xa5c5fffc	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x381e39f9	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x7a92821e	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xe63655b2	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x9d5c02ec	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/tunnel6 0xfa2e21ad	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x21570429	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x3672cf7e	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x2c1b1a4c	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x2caefa95	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x2fa69276	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x33689294	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x765bfec4	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xa082ce73	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xa3cbbb69	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xb0989b81	ircomm_flow_request
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x0ce16a84	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0x156a6b0c	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0x16b2c5cc	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x17a491c5	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0x1e8d817d	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x1f1b3031	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x2a774e45	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x36cad55b	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0x37791344	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x495ec116	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0x4fec0251	iriap_close
++EXPORT_SYMBOL net/irda/irda 0x5284a821	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x5c62fef2	iriap_open
++EXPORT_SYMBOL net/irda/irda 0x6257a6a0	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x6492e28c	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x6974c7f3	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x6a339789	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6b76aa70	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0x6c27e761	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x6c923bc1	irlap_open
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x731cec71	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7e67ca6e	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x82a0567e	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0x8982c8d9	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x8a44dd5e	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0x90ddb6bd	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x93445ab7	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x9b3673c5	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x9ffda243	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0xa0af73e1	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0xa66d461c	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0xb357084f	irlap_close
++EXPORT_SYMBOL net/irda/irda 0xb3c13d7f	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0xb8916442	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xbf7dd554	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xbfa7c08d	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0xc477368d	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0xcadce3d0	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xf199cba4	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0xf80be94f	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0xfe86bcc5	async_wrap_skb
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x0722148f	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0x7b2b9499	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x1877dee8	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0x1a934bac	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0x33e40592	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0x3a354fa5	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0x64659d48	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0xc177f3df	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0xcfcd5e96	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0xd458623b	lapb_connect_request
++EXPORT_SYMBOL net/llc/llc 0x03425f5a	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0x07083bd5	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0x093a267b	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0xe1275434	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0xe4d13528	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0xe634a9df	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0xed4b8929	llc_sap_open
++EXPORT_SYMBOL net/mac80211/mac80211 0x02166686	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x030e96b5	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x037503c9	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x05835f27	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac80211/mac80211 0x0aabe15a	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac80211/mac80211 0x0fbb9658	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0x112b0279	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0x115b1ba9	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0x22f89030	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0x26d760b3	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x2ceaf4e6	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x2d93cbfd	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x32e0c810	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x3420a016	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x361e8777	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x3c5f9792	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x40fc15a4	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x41122ef0	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x4a7b9f47	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x4ab5d3ed	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0x5aab2eb9	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0x5bbdcad1	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x5f5cad90	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x61bc1d7f	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0x6668bec7	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x66eff3a9	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x68e52799	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x68e9a69f	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0x69b607e5	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x69de096c	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0x6c7003b5	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x6fc88cf2	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0x72fb6df6	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0x7410134d	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x76b9ef28	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x77a719a0	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x7fda4748	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0x80f69e35	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0x87cf8722	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x907f65e5	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0x91434a4b	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x94ed48e7	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x952a4d74	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0x9688c3fd	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x980d9260	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0x993514af	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x9d67616c	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xa7933817	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xb1aaef91	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xb3001df4	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xb48c72cb	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xb53a5a8a	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xbc7839a4	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0xbe93040f	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0xc3ab5395	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xc3c9eab3	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xc8278c4c	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0xc8de30ad	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xc9fc54a8	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xcbc6c766	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xcc58d639	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xced89626	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0xcf87c057	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xd5362840	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xd6a47bb0	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xd7a88266	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0xd9b63d9f	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0xda0e4f25	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xda2ae79d	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xdae94003	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xdb3e38dc	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xdf98cd1c	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0xe49b24ca	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xe6562ce9	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0xe7419b30	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0xea7d2c35	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xec5dad7d	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xef68bf65	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xefe2a696	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xf1ce0774	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xff0d887c	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0xfffcdd92	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac802154/mac802154 0x11ad1036	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0x2e03aef2	ieee802154_alloc_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x45a0587e	ieee802154_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x50daa4da	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x74a0d5bc	ieee802154_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x9c8f5408	ieee802154_unregister_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xaf66186b	ieee802154_xmit_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0xb6fcb381	ieee802154_register_hw
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x051023cf	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x15790420	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x1ba32c43	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x29b9353b	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x2b01093d	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x38e514e2	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x4b71ac50	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x6a601028	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x8ff5c825	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x9a26c14d	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x9c238527	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xaf00c179	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xc8b4a51e	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xf7872e52	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x45eebc00	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xe10c3ddd	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xf2d920c3	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x8fab7f6a	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0xa95707fb	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xac06dedc	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0xba70369d	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xbea27287	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0xf3148105	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/x_tables 0x0d1080b0	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x26eb388b	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x517b4141	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x5a46b8fc	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x5f8b0aac	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x9dae53c0	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x9ed22da4	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xae4e6a75	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xb8cb7278	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xf142b3ce	xt_unregister_match
++EXPORT_SYMBOL net/nfc/hci/hci 0x07b94087	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x177c7f98	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0x182c5dd9	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0x192e24c7	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x1d3e198e	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0x1ea608b2	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x2d1df2ef	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0x3df393d9	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x4725a975	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0x6a03c72c	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x7121e3aa	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0x9ab6d56d	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0x9c5cfd05	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xac2cef72	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xc54898de	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0xc7c40fc3	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xd1ca5cf6	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0xdbffc141	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xe9437d80	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xf4c15b40	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0xf5eeb40f	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x00bcbb31	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x05373843	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x07671483	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0x17e6a4d2	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x1e5593e0	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x2a8eb0ff	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0x2cd7ce3b	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x4459c313	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x5d2924b4	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0x67a4d9bc	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0x6959e9c7	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0x70cd8b78	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x74b1096f	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0x7be02db2	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0x803e7bda	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nci/nci 0x81626f40	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x939d7ff7	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x93d02b80	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0x99cf0c10	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nci/nci 0x9f53007d	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xa5c8e1b9	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0xa880c68c	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xd5b380a5	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0xd8bfc36d	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0xdce207d6	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0xde819531	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xea993704	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xf0d2f4e7	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nfc 0x06ed9c43	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0x27f899cb	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0x392e8042	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0x428672f4	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0x5052025e	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0x541a5bd7	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x6bd49833	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0x6d8fea78	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0x755c6705	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0x793c17b9	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0x82669e4a	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0x8e06791c	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x91089ea9	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0x97c5eb4d	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0x9e289dab	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xae12811c	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc 0xaed2cc56	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0xb3ba7a33	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0xbb32397e	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0xc22044c8	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0xc3000e50	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0xd2ec7871	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0xf353b5ea	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0xffb7b726	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc_digital 0x15a9737d	nfc_digital_unregister_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x94f8c2ee	nfc_digital_free_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x9d816a6a	nfc_digital_register_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xf2c9c4c4	nfc_digital_allocate_device
++EXPORT_SYMBOL net/phonet/phonet 0x28a0941a	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0x391b58de	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0x463f7b1c	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0x5726452c	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0x7791abd7	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0xe1e03ecf	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0xe94ebee8	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0xee8a1c1b	phonet_proto_unregister
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x14a18313	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1c8ef8fc	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x323c44e3	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x3d386298	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x70344ed1	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x7b8e5346	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x9347c243	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x99ecb259	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x9ddf9580	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xbdb1f2b2	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xda12f549	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe3f3b806	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf2e6a81e	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf786198c	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf9638a79	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/sctp/sctp 0x255d748c	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x2bd05589	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x5d9061cf	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xc405f33d	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x32952aee	svc_pool_stats_open
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xd36b6ba1	xdr_truncate_encode
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xe72e9614	xdr_restrict_buflen
++EXPORT_SYMBOL net/wimax/wimax 0x926930e7	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0xe6b73d0d	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x08cd4871	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0e4ee2e5	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x12410294	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x18c2c933	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x1acfb34b	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x1ea19502	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x2128e54a	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0x213fe3a8	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x24128b44	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0x249f2605	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0x25af8483	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x27ba2a26	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0x28b4713d	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x2a0a83b6	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x2c0bec05	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x2d271b3a	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x30540452	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0x3111f0ef	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x3261273f	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x327a83be	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0x3795fffd	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x414e9f8c	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x42408965	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x424d9a36	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x4e6aa21a	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x526cc5d4	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0x54281177	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x5812ecf2	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0x5a44dcea	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x5f4577c3	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0x62543fa0	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x63f36531	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0x68da613b	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6a6f47aa	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x6db9500a	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x716df198	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0x74b562c0	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x7678e2cd	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x76900928	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x84589266	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x84c6e59b	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x851a2629	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x871ccf95	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0x87a28a53	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x88a9b995	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x8c49708f	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0x928a73e6	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0x952aa315	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x9581b655	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0x966ff54d	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x9b7b6ad6	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0xa0455ad1	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1e94eae	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0xa32d9c97	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0xa5f914c7	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xa9715396	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xa99d8f07	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0xabe57ebe	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xb2eabe7f	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0xb3382741	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xb3bec628	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/cfg80211 0xb6c2e398	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xbae5f878	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0xbd661b58	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xc4c99179	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xce29e513	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0xd2d7a80d	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0xd55dd064	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0xd5a5cd0e	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xd6d40027	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0xd7b9eaf1	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0xd838bf40	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0xd8bb7928	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xd9ca3b99	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xe1231925	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0xe5b6d907	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe673aa48	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0xe853f2f1	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xeb6d7c6c	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xf10477e6	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xf42c6d5e	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0xf7e66485	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xf806d431	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xf9e4e347	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/lib80211 0x097aeb5b	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x0f246b62	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x7603f7c5	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x9b86178b	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0xb6dfad95	lib80211_crypt_info_free
++EXPORT_SYMBOL net/wireless/lib80211 0xfc94cda7	lib80211_crypt_info_init
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0xa126d2b4	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x090e48f4	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x4391dc67	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x926fc38b	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xd1a3389f	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xaffc6982	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x127b30fb	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x1cdc0812	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x59eb74ae	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x8102ed2f	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xb11ba32d	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xb2c7f684	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xea0e5748	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xed42580b	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0x68c87646	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd-hwdep 0x453db91c	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x0966d18d	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x0c16fcb2	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x19ef6546	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x1fc042b8	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x230c55af	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x45a10251	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x45b8d988	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x4bfbffc0	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x670ce41e	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x74a44bab	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7818524a	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7f6d7c67	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x87c12213	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x8f6ac83c	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x8f8cc321	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xa2cf3d64	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xaab3441d	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb9b7db5f	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xee8a0f5f	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xf213bcd9	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x25ec34f2	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x3868ec31	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x3ce32021	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x41876fe7	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x43a57657	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x6363a0a5	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x93b2a5f3	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xf2c719f6	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xf7daac3d	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x016728d8	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x2d73b866	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x85762629	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x8f27bfd1	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x93f03492	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xd0d52b26	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xdf1535bf	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xe78f414f	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf72d9189	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x08f9cb19	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x10bce2db	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x12c05401	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x14d604d9	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1ef24866	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x368097a5	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3a4ac735	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4462ba95	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4de50af8	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x51e85d8e	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x549c2fe1	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x54ff6e4f	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x606e3b1a	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x60e80ef7	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x659ab42e	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x65c286d1	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x6f0e4a8f	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7330e4ba	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x74a68f35	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x759e4f1e	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8fab3ad8	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9c87f4bb	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa78ea0e4	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd1e3e0f4	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd35e6311	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xedbfdfb4	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf14bee72	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf1ce1036	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf21a8ff7	amdtp_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xfc37fa3e	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xff668852	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xff95a1c0	snd_fw_transaction
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x0ba0fad5	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0xe70be2fe	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x0dc5f34c	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x41ede8ca	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x550a7091	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x59f4044c	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x5da1bad8	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x7faa469d	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xc1788ea7	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xc91ad5f3	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x1d7193c0	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x29fbd126	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x67c26138	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x6ac50dc8	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x1ea1794e	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0xa741f45d	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x7d487702	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x81ca5bf2	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xbb35491f	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xbe6bb37b	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xdfa78b94	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xea3d881f	snd_i2c_device_create
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x093fd4f0	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x28d09f82	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x29b24eae	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3602954d	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3920b924	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3cf16ae0	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x40f27690	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x9b1b0bab	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xa2d4a2e0	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xac93cd5a	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb640a3fd	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb9a3f781	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xcf2ee897	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xcf64ec49	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xdab44140	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xe46bd88e	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xe9dd3ed8	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x03c1ac2c	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x5ff115a8	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x9911cf64	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x092b443a	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0f89eda9	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x19fb0d16	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x27188883	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x2d67bfef	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x354378b7	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x3f92fd9c	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x415e4d84	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x47dab05e	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x6277547f	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x8070211b	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x90c51c43	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x9dbf64be	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa523058d	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xab2c69b0	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb12de3e5	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb2f410fd	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb4a69e93	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb5e4bdda	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc74f5def	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf9e89488	oxygen_write16_masked
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x40100520	tlv320aic23_probe
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x93782251	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/fsl/snd-soc-fsl-utils 0x46c9472d	fsl_asoc_get_dma_channel
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x04fcaae0	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL vmlinux 0x0018454e	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0x001ee95a	imx_ssi_fiq_base
++EXPORT_SYMBOL vmlinux 0x003aa7fe	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0x003ed69a	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x00467a05	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0x004db6ce	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x004eda74	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0x005065a0	do_splice_to
++EXPORT_SYMBOL vmlinux 0x008584b2	of_find_property
++EXPORT_SYMBOL vmlinux 0x00887eaa	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x0095b072	dump_align
++EXPORT_SYMBOL vmlinux 0x00c5ac2f	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0x00ce96f1	nvm_register
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x00e0b287	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x00e4bce5	kern_path
++EXPORT_SYMBOL vmlinux 0x00ee529c	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x01044858	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0x01139ffc	max_mapnr
++EXPORT_SYMBOL vmlinux 0x0116e79e	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x011a9e53	elf_hwcap2
++EXPORT_SYMBOL vmlinux 0x013e0a75	of_get_min_tck
++EXPORT_SYMBOL vmlinux 0x01425840	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0x01552e7a	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0x0163eebc	serio_bus
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x01717a49	set_disk_ro
++EXPORT_SYMBOL vmlinux 0x0176121a	fget
++EXPORT_SYMBOL vmlinux 0x0186e2de	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x019611c0	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0x01a3d310	omap_set_dma_channel_mode
++EXPORT_SYMBOL vmlinux 0x01a557f4	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0x01b2a85c	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x01b7fd59	dispc_read_irqstatus
++EXPORT_SYMBOL vmlinux 0x01c670fa	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0x01cf6c74	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x01e912f3	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x01ea132e	dispc_runtime_put
++EXPORT_SYMBOL vmlinux 0x01eebf2f	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x01fcca46	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0x0203e378	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x02196324	__aeabi_idiv
++EXPORT_SYMBOL vmlinux 0x02239d4b	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0x0238f408	snd_cards
++EXPORT_SYMBOL vmlinux 0x02573b36	omap_disable_dma_irq
++EXPORT_SYMBOL vmlinux 0x02627eb3	of_gpio_simple_xlate
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x02735b8b	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL vmlinux 0x0287990f	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x029b767e	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x02ee26c1	free_pages_exact
++EXPORT_SYMBOL vmlinux 0x02ef742b	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x02fb4584	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x02fdf039	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0x03005606	omapdss_get_version
++EXPORT_SYMBOL vmlinux 0x03026722	mempool_alloc
++EXPORT_SYMBOL vmlinux 0x0303cc57	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0x030eaacb	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0x0313be5e	inet6_offloads
++EXPORT_SYMBOL vmlinux 0x0331cc3b	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0x0334795d	icst307_s2div
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x0339a336	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0x034faea4	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x035a1d10	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x03676d4b	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0x037385d2	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x03753cec	dump_page
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x0399a584	scsi_print_result
++EXPORT_SYMBOL vmlinux 0x039a80e2	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0x03a1ee0b	bdi_destroy
++EXPORT_SYMBOL vmlinux 0x03ba39b0	v7_flush_user_cache_all
++EXPORT_SYMBOL vmlinux 0x03d2173b	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0x03d22642	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0x03d6e28e	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x03e543c4	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL vmlinux 0x03f4273c	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x03f7666b	fget_raw
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x0404ddf5	blk_put_request
++EXPORT_SYMBOL vmlinux 0x0417717d	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x0425269b	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x042ac44a	of_phy_register_fixed_link
++EXPORT_SYMBOL vmlinux 0x042d7954	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0x043e33a3	md_write_start
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x04509380	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0x0460b324	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x04666a84	skb_store_bits
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x048a5fa2	simple_map_init
++EXPORT_SYMBOL vmlinux 0x04942810	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0x04afd4fb	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04fb6a93	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0x05004223	unload_nls
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x053123e5	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x053a224c	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0x05567428	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x055ac146	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0x056abb62	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x05773cb9	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x057e924f	nf_log_trace
++EXPORT_SYMBOL vmlinux 0x05a28065	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x05d6b1d6	nand_scan_tail
++EXPORT_SYMBOL vmlinux 0x05fe562f	shdma_chan_remove
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x062c5029	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x065dc2b5	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0x065f2374	omapdss_default_get_resolution
++EXPORT_SYMBOL vmlinux 0x06607f92	dss_feat_get_supported_outputs
++EXPORT_SYMBOL vmlinux 0x0669d851	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x06b74716	skb_checksum
++EXPORT_SYMBOL vmlinux 0x06b77ec2	tcp_filter
++EXPORT_SYMBOL vmlinux 0x06b88dc0	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0x06bbd02d	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0x06c96ef1	vc_cons
++EXPORT_SYMBOL vmlinux 0x06e477fa	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0x06f738a1	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x072a3c29	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x072a8f8d	__set_fiq_regs
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x0738d509	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x073f8508	register_gifconf
++EXPORT_SYMBOL vmlinux 0x073ff079	of_graph_get_port_by_id
++EXPORT_SYMBOL vmlinux 0x0753e932	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0x07597153	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0x075e7035	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x0769c590	__put_cred
++EXPORT_SYMBOL vmlinux 0x0773749f	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x07a4b576	flex_array_free
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07b49bdf	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07cf9099	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0x07f27ba7	km_state_notify
++EXPORT_SYMBOL vmlinux 0x08181990	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0x081f3afb	complete_all
++EXPORT_SYMBOL vmlinux 0x0821ef27	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x086c289b	nonseekable_open
++EXPORT_SYMBOL vmlinux 0x088d3717	cdrom_open
++EXPORT_SYMBOL vmlinux 0x088e4341	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0x08a26e10	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x08a83705	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0x08ae047c	omapdss_output_unset_device
++EXPORT_SYMBOL vmlinux 0x08c88b6b	__kernel_write
++EXPORT_SYMBOL vmlinux 0x08d8da8d	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0x08e26800	down_write_trylock
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x08fc2593	md_error
++EXPORT_SYMBOL vmlinux 0x09073ede	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x094c05a9	mount_bdev
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x0960be97	of_n_addr_cells
++EXPORT_SYMBOL vmlinux 0x0961bb2f	request_key_async
++EXPORT_SYMBOL vmlinux 0x0964666c	udp_ioctl
++EXPORT_SYMBOL vmlinux 0x096694e1	snd_unregister_device
++EXPORT_SYMBOL vmlinux 0x096985ec	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0x097ec1ff	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x0982551c	nla_put
++EXPORT_SYMBOL vmlinux 0x0982c3b4	generic_write_end
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x099de538	put_page
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09cf1b46	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09ddff54	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x09dea6e6	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x0a0786de	udplite_table
++EXPORT_SYMBOL vmlinux 0x0a11563a	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x0a1cfea6	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a2dfd6f	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0x0a3131f6	strnchr
++EXPORT_SYMBOL vmlinux 0x0a373226	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0x0a469d23	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0x0a5bb9b3	bio_add_page
++EXPORT_SYMBOL vmlinux 0x0a6e6994	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0ab47b2c	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0x0ac84643	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x0acaf67b	free_netdev
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0aed40dc	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x0af4debc	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b280984	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0x0b2d425c	of_node_put
++EXPORT_SYMBOL vmlinux 0x0b48677a	__kfifo_init
++EXPORT_SYMBOL vmlinux 0x0b4c14c7	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0x0b57155e	tegra_io_rail_power_off
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b784e1b	snd_dma_free_pages
++EXPORT_SYMBOL vmlinux 0x0b8399f5	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0x0b94088e	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x0b9afb67	snd_timer_open
++EXPORT_SYMBOL vmlinux 0x0ba92431	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bbcf7b4	inode_permission
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bf8df2d	locks_init_lock
++EXPORT_SYMBOL vmlinux 0x0c03a0c3	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0x0c10b570	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0x0c2b5ea0	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x0c31ea7c	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0x0c33d28f	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c549551	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c75b1ac	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x0c816aab	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0ca54fee	_test_and_set_bit
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cbc61a6	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x0cbe5918	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x0ce25b75	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0x0ce66529	pci_iomap
++EXPORT_SYMBOL vmlinux 0x0ce81af7	snd_info_register
++EXPORT_SYMBOL vmlinux 0x0cfefe1e	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x0d19e84f	genphy_read_status
++EXPORT_SYMBOL vmlinux 0x0d1bcfca	seq_path
++EXPORT_SYMBOL vmlinux 0x0d20677f	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x0d218c76	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0x0d3f57a2	_find_next_bit_le
++EXPORT_SYMBOL vmlinux 0x0d4d7a32	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d843123	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0dc1a78c	bin2hex
++EXPORT_SYMBOL vmlinux 0x0dd3fbfc	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0x0de0dd84	elevator_init
++EXPORT_SYMBOL vmlinux 0x0dfca621	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0x0e0a3e8c	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0x0e1cfd86	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x0e3343f7	inet_put_port
++EXPORT_SYMBOL vmlinux 0x0e4dfd2b	pci_iounmap
++EXPORT_SYMBOL vmlinux 0x0e524884	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e778918	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x0e89381d	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0x0e987230	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0x0ea9b388	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0x0eaeae0a	md_update_sb
++EXPORT_SYMBOL vmlinux 0x0eaf451e	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x0eb34e45	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x0ebeb310	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0x0ec1b47f	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0eea0399	strscpy
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f0dea5e	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x0f2f284a	send_sig_info
++EXPORT_SYMBOL vmlinux 0x0f2fa670	proc_set_size
++EXPORT_SYMBOL vmlinux 0x0f312d1b	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x0f3fb63a	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0x0f42a810	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f5a5c8b	of_graph_get_remote_port
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f83ace7	cdrom_release
++EXPORT_SYMBOL vmlinux 0x0f848910	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x0f9683e9	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL vmlinux 0x0fa2a45e	__memzero
++EXPORT_SYMBOL vmlinux 0x0fa31bdf	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0x0fa5e3b2	lock_rename
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fcac39f	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x0fd55ad2	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0x0fded04c	bio_advance
++EXPORT_SYMBOL vmlinux 0x0ff178f6	__aeabi_idivmod
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x0ffcb649	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0x1005336b	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0x1013e70e	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0x1028808d	snd_ctl_replace
++EXPORT_SYMBOL vmlinux 0x10436099	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL vmlinux 0x104c3c88	proc_set_user
++EXPORT_SYMBOL vmlinux 0x1054dc44	omap_dss_get_overlay
++EXPORT_SYMBOL vmlinux 0x105d1993	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0x106f13ab	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x1072a394	csum_partial_copy_from_user
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x10994586	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0x10a45d99	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0x10b1c48d	amba_find_device
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x11145431	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0x112748bd	omap_vrfb_adjust_size
++EXPORT_SYMBOL vmlinux 0x11446fd5	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x1165ce6d	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0x116a5a95	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x119b50e7	elf_check_arch
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11ce7a74	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0x11edfc52	of_parse_phandle_with_args
++EXPORT_SYMBOL vmlinux 0x11ee57a2	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x12122737	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0x121a00c7	mpage_readpages
++EXPORT_SYMBOL vmlinux 0x121d8aaa	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x122fcabf	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0x123508bf	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x1251e5f5	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0x126a724d	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x1282af01	tty_hangup
++EXPORT_SYMBOL vmlinux 0x1289c48c	noop_fsync
++EXPORT_SYMBOL vmlinux 0x12961b5b	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12a53c13	udp_poll
++EXPORT_SYMBOL vmlinux 0x12c07f72	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0x12da5bb2	__kmalloc
++EXPORT_SYMBOL vmlinux 0x12dd4d24	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x12e8317c	flush_dcache_page
++EXPORT_SYMBOL vmlinux 0x12eaf17c	of_get_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0x12f7c68f	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x1300f205	snd_device_new
++EXPORT_SYMBOL vmlinux 0x130ebc9f	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x1312353b	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x13315729	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0x13713b09	dquot_operations
++EXPORT_SYMBOL vmlinux 0x1389f102	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x13953e0b	path_noexec
++EXPORT_SYMBOL vmlinux 0x13a01cce	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x13a4958f	cros_ec_cmd_xfer
++EXPORT_SYMBOL vmlinux 0x13ab2e2c	dev_warn
++EXPORT_SYMBOL vmlinux 0x13bc8da4	notify_change
++EXPORT_SYMBOL vmlinux 0x13c32e2a	snd_dma_alloc_pages
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13e82432	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x13f1713f	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x13f18020	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0x13f373f3	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x1420b379	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0x143363cb	ether_setup
++EXPORT_SYMBOL vmlinux 0x144d6f29	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0x144d79bb	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x144e5c5e	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0x14628c2a	make_kuid
++EXPORT_SYMBOL vmlinux 0x14847267	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x149557cc	cdev_add
++EXPORT_SYMBOL vmlinux 0x14a1a776	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0x14a41e88	of_root
++EXPORT_SYMBOL vmlinux 0x14aaf062	tty_free_termios
++EXPORT_SYMBOL vmlinux 0x14b15e48	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x14d4a9c5	_change_bit
++EXPORT_SYMBOL vmlinux 0x14f3fa0a	of_find_node_with_property
++EXPORT_SYMBOL vmlinux 0x14f845c6	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0x15230849	inet_getname
++EXPORT_SYMBOL vmlinux 0x154ba012	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x1558f693	udp_set_csum
++EXPORT_SYMBOL vmlinux 0x1578555f	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0x157c5c82	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0x15929ec3	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x1593c8ef	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x15a51cef	omap_dss_find_output_by_port_node
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15bdf967	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0x15d998bb	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0x160f7d5a	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0x161080f7	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0x1612ca2a	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0x162ccc0c	lg_local_lock
++EXPORT_SYMBOL vmlinux 0x162f5487	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x16305289	warn_slowpath_null
++EXPORT_SYMBOL vmlinux 0x16334174	sock_rfree
++EXPORT_SYMBOL vmlinux 0x1641e68f	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x164d1ce7	set_posix_acl
++EXPORT_SYMBOL vmlinux 0x164f02ba	vfs_setpos
++EXPORT_SYMBOL vmlinux 0x166250c3	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0x16753144	pps_event
++EXPORT_SYMBOL vmlinux 0x16820a5e	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x1683a50b	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x168cf911	nla_reserve
++EXPORT_SYMBOL vmlinux 0x16a03228	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0x16afe616	snd_ctl_rename_id
++EXPORT_SYMBOL vmlinux 0x16b495b3	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0x16bd0514	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x16d83714	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x17434491	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0x174afb1a	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0x17615297	dss_mgr_start_update
++EXPORT_SYMBOL vmlinux 0x1784f057	dispc_ovl_set_fifo_threshold
++EXPORT_SYMBOL vmlinux 0x179c7a20	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x179d6636	i2c_transfer
++EXPORT_SYMBOL vmlinux 0x179d75ae	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17c3e063	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0x17e9df27	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0x17f96191	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0x18034aa8	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0x180bd219	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x1813a0e3	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x1830e248	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0x183c29e3	skb_find_text
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x18444b84	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x184e48f1	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0x185933d6	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0x18727d0e	d_move
++EXPORT_SYMBOL vmlinux 0x187c37de	fsync_bdev
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x188ea314	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x189c5980	arm_copy_to_user
++EXPORT_SYMBOL vmlinux 0x18b6d498	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0x18bd76a4	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x18c2227f	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x18ef5045	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0x19000f56	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0x1929f521	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x19579780	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0x19610e1f	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0x19673c60	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0x19674e35	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0x196ca79d	of_device_alloc
++EXPORT_SYMBOL vmlinux 0x1970a11d	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0x197dc3b3	omap_set_dma_src_burst_mode
++EXPORT_SYMBOL vmlinux 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19a051fd	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x19a273f9	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x19ac4674	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19ca07ce	vm_event_states
++EXPORT_SYMBOL vmlinux 0x19cbf364	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x19daa02b	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x19f5809b	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0x1a20c540	omap_vrfb_supported
++EXPORT_SYMBOL vmlinux 0x1a3162bb	netdev_crit
++EXPORT_SYMBOL vmlinux 0x1a592a01	__f_setown
++EXPORT_SYMBOL vmlinux 0x1a5a88e1	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0x1a65f4ad	__arm_ioremap_pfn
++EXPORT_SYMBOL vmlinux 0x1a70b06a	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x1a8ae252	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0x1a929120	pci_match_id
++EXPORT_SYMBOL vmlinux 0x1aaa074c	open_exec
++EXPORT_SYMBOL vmlinux 0x1abbd226	cros_ec_check_result
++EXPORT_SYMBOL vmlinux 0x1ac7242d	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0x1ad1f2e7	_memcpy_fromio
++EXPORT_SYMBOL vmlinux 0x1adbf6b4	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b021bb8	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0x1b2d6d2c	qcom_scm_cpu_power_down
++EXPORT_SYMBOL vmlinux 0x1b2e4db6	tty_mutex
++EXPORT_SYMBOL vmlinux 0x1b498d8a	d_find_alias
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1badc9c9	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0x1bb1536f	snd_info_create_module_entry
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bb694a2	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0x1bc71ce2	sk_common_release
++EXPORT_SYMBOL vmlinux 0x1bf53617	down_write
++EXPORT_SYMBOL vmlinux 0x1bf60a64	get_super
++EXPORT_SYMBOL vmlinux 0x1c018ff7	secpath_dup
++EXPORT_SYMBOL vmlinux 0x1c1326eb	__break_lease
++EXPORT_SYMBOL vmlinux 0x1c1d8101	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x1c4fb15f	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0x1c59b83a	__inet_hash
++EXPORT_SYMBOL vmlinux 0x1c5e3878	icst525_idx2s
++EXPORT_SYMBOL vmlinux 0x1c6575c1	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x1c6b4371	dma_supported
++EXPORT_SYMBOL vmlinux 0x1c8eb3d6	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0x1cb98296	follow_down_one
++EXPORT_SYMBOL vmlinux 0x1cd4bf3e	snd_jack_set_parent
++EXPORT_SYMBOL vmlinux 0x1cfb04fa	finish_wait
++EXPORT_SYMBOL vmlinux 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL vmlinux 0x1d06c1cf	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x1d1758fd	__nla_put
++EXPORT_SYMBOL vmlinux 0x1d1fc1a2	__frontswap_store
++EXPORT_SYMBOL vmlinux 0x1d3657df	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x1d3d214e	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0x1d54c56a	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x1d6b1280	eth_header_parse
++EXPORT_SYMBOL vmlinux 0x1d6e398e	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0x1d7aeb17	elv_add_request
++EXPORT_SYMBOL vmlinux 0x1db7dc40	pgprot_kernel
++EXPORT_SYMBOL vmlinux 0x1dc26826	__mutex_init
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dc6761b	dquot_enable
++EXPORT_SYMBOL vmlinux 0x1dd41cef	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1e041b4c	_snd_ctl_add_slave
++EXPORT_SYMBOL vmlinux 0x1e047854	warn_slowpath_fmt
++EXPORT_SYMBOL vmlinux 0x1e092854	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e400a34	serio_rescan
++EXPORT_SYMBOL vmlinux 0x1e4976d3	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0x1e5840b7	vga_get
++EXPORT_SYMBOL vmlinux 0x1e602c96	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0x1e63bbcd	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e978065	of_dev_put
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ea7fd62	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x1eae3556	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x1ec38bbd	__scm_destroy
++EXPORT_SYMBOL vmlinux 0x1ecbc3c1	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x1ecc7b52	put_disk
++EXPORT_SYMBOL vmlinux 0x1eeb848e	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0x1f1a24c5	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x1f2b3c35	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0x1f34cd6c	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0x1f38aa06	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x1f471f3b	misc_deregister
++EXPORT_SYMBOL vmlinux 0x1f4aac7a	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0x1f530054	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x1f665a2d	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x1f720d0d	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0x1f7e807f	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x1fa7c516	dup_iter
++EXPORT_SYMBOL vmlinux 0x1fab5905	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fc3f137	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x1fca35f8	kernel_bind
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1febceac	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x200ca532	devm_clk_get
++EXPORT_SYMBOL vmlinux 0x20205f64	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0x2032cac7	param_set_bint
++EXPORT_SYMBOL vmlinux 0x20421305	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x205ec8de	omap_dispc_register_isr
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x207a6e76	snd_pcm_new_internal
++EXPORT_SYMBOL vmlinux 0x2094fb62	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20b00659	param_set_int
++EXPORT_SYMBOL vmlinux 0x20b48453	sk_dst_check
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20ee820b	of_get_named_gpio_flags
++EXPORT_SYMBOL vmlinux 0x20f6fcc0	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x2104400f	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x21110dbf	mmioset
++EXPORT_SYMBOL vmlinux 0x211331fa	__divsi3
++EXPORT_SYMBOL vmlinux 0x2117dae7	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0x2133aa2b	ns_capable
++EXPORT_SYMBOL vmlinux 0x213f72dd	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x214679c3	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x21577a55	lookup_one_len
++EXPORT_SYMBOL vmlinux 0x2157965d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x215d352c	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x216d759a	mmiocpy
++EXPORT_SYMBOL vmlinux 0x21847dff	inet_accept
++EXPORT_SYMBOL vmlinux 0x219410d7	submit_bio
++EXPORT_SYMBOL vmlinux 0x21b35d61	from_kuid
++EXPORT_SYMBOL vmlinux 0x21c601b4	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21e4ea1f	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0x21f02cf2	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x21f7eb8f	claim_fiq
++EXPORT_SYMBOL vmlinux 0x2206434b	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0x221fa2d0	mntput
++EXPORT_SYMBOL vmlinux 0x2225441a	filp_open
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x222fa684	lg_global_lock
++EXPORT_SYMBOL vmlinux 0x2232a8a5	mempool_free
++EXPORT_SYMBOL vmlinux 0x223cc898	omap_vrfb_max_height
++EXPORT_SYMBOL vmlinux 0x224c7761	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0x2252cb88	dss_mgr_disable
++EXPORT_SYMBOL vmlinux 0x2256fafa	div64_u64_rem
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x2277d558	mx53_revision
++EXPORT_SYMBOL vmlinux 0x229c418d	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x22a72d81	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22ba0bf4	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0x22c4563f	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x22ca5f4c	pci_select_bars
++EXPORT_SYMBOL vmlinux 0x22ce8ac0	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x22dfdd06	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x22e46d58	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0x22e53f50	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0x22f6b423	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0x22fc4f3a	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x22ff8d67	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x230d2404	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x231ea417	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0x232ff0a5	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0x2373ddd8	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23a5fa0e	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x23aa49d3	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23c1e442	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23d08724	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x23f5c468	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x243cd544	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x246dda66	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x2480fad3	snd_ctl_free_one
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x2489700e	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL vmlinux 0x24a97e7e	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0x24add95e	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0x24e28859	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0x24f677b4	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x250113b4	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x2527a087	vme_slave_set
++EXPORT_SYMBOL vmlinux 0x252be3cf	__lock_buffer
++EXPORT_SYMBOL vmlinux 0x25305434	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x253e4a57	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x2545b70e	vme_bus_type
++EXPORT_SYMBOL vmlinux 0x255acb5f	tegra_powergate_sequence_power_up
++EXPORT_SYMBOL vmlinux 0x25630570	pci_bus_put
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x257782fa	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0x2578a911	of_find_node_by_type
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x25a6e50b	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0x25b1e72e	fput
++EXPORT_SYMBOL vmlinux 0x25c1a972	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0x25c369cf	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x2642e451	clkdev_drop
++EXPORT_SYMBOL vmlinux 0x2647f295	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x2664b633	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0x26667376	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0x26765ea4	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0x26855ddb	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x268d5988	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x269a00e9	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x26bb950b	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0x26c2128c	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0x26c29b3b	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x26c80382	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0x26df7325	snd_card_free
++EXPORT_SYMBOL vmlinux 0x26e18f10	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26eb7756	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0x2704c027	param_set_ulong
++EXPORT_SYMBOL vmlinux 0x271fe233	vfs_link
++EXPORT_SYMBOL vmlinux 0x2742ca9b	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x27437c87	snd_timer_start
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x2748e172	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0x274d6e72	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x275ef902	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0x27636858	block_read_full_page
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x279e587d	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0x27a2d045	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27c0e93b	netlink_unicast
++EXPORT_SYMBOL vmlinux 0x27cfd7b0	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x27d4b02c	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x27e7dec0	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x27edcbff	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x27ef2be2	mtd_concat_destroy
++EXPORT_SYMBOL vmlinux 0x28118cb6	__get_user_1
++EXPORT_SYMBOL vmlinux 0x28153a39	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x282e5b10	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x283212d0	input_open_device
++EXPORT_SYMBOL vmlinux 0x28342b8c	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x28353aa9	release_pages
++EXPORT_SYMBOL vmlinux 0x283a9e52	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x283e266b	key_type_keyring
++EXPORT_SYMBOL vmlinux 0x284642fd	proc_remove
++EXPORT_SYMBOL vmlinux 0x286001b5	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0x287b87fb	nf_register_hook
++EXPORT_SYMBOL vmlinux 0x28875d02	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0x288d5e49	tegra_dfll_register
++EXPORT_SYMBOL vmlinux 0x28a2bfd5	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28c69bb5	pci_request_regions
++EXPORT_SYMBOL vmlinux 0x28d6861d	__vmalloc
++EXPORT_SYMBOL vmlinux 0x28f1c46a	bio_endio
++EXPORT_SYMBOL vmlinux 0x291325b8	register_sound_special
++EXPORT_SYMBOL vmlinux 0x2926cd15	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x29380022	tegra_ahb_enable_smmu
++EXPORT_SYMBOL vmlinux 0x29415b49	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x29551e5b	omap_dss_find_output
++EXPORT_SYMBOL vmlinux 0x296bc320	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0x297060e0	of_graph_get_next_endpoint
++EXPORT_SYMBOL vmlinux 0x29a56167	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0x29e1b020	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0x29f209d1	phy_connect
++EXPORT_SYMBOL vmlinux 0x29f63d05	of_device_register
++EXPORT_SYMBOL vmlinux 0x29fdda53	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0x2a0575d1	mmc_release_host
++EXPORT_SYMBOL vmlinux 0x2a079479	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0x2a23c7e7	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a31b08d	vme_irq_free
++EXPORT_SYMBOL vmlinux 0x2a3aa678	_test_and_clear_bit
++EXPORT_SYMBOL vmlinux 0x2a4041fd	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x2a57cc9b	dm_put_device
++EXPORT_SYMBOL vmlinux 0x2a5afaef	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x2a5b560f	of_find_matching_node_and_match
++EXPORT_SYMBOL vmlinux 0x2a716e56	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x2a7476ff	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0x2a7cac99	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x2a8820f4	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x2aa0e4fc	strncasecmp
++EXPORT_SYMBOL vmlinux 0x2aa9af95	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2ab387e9	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x2abf4b50	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x2abf5311	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2adbe7db	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0x2ae93cbe	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0x2af48197	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0x2af4b9ca	d_walk
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b12925d	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x2b19d9ff	vga_client_register
++EXPORT_SYMBOL vmlinux 0x2b20bd12	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b4e956e	mempool_create
++EXPORT_SYMBOL vmlinux 0x2b5c83e5	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0x2b5c8b86	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2bd25af8	alloc_file
++EXPORT_SYMBOL vmlinux 0x2be0f12d	dql_completed
++EXPORT_SYMBOL vmlinux 0x2beb31ba	snd_timer_pause
++EXPORT_SYMBOL vmlinux 0x2bf407aa	of_phy_connect
++EXPORT_SYMBOL vmlinux 0x2c14323a	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c292f38	security_path_unlink
++EXPORT_SYMBOL vmlinux 0x2c335e82	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0x2c3cb0be	param_set_short
++EXPORT_SYMBOL vmlinux 0x2c3d6054	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x2c3e9ee7	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x2c4c4e0f	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0x2c5b59d2	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0x2c709f2f	snd_pcm_open_substream
++EXPORT_SYMBOL vmlinux 0x2c79fc4e	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x2c7c8e9a	pcibios_min_mem
++EXPORT_SYMBOL vmlinux 0x2c81ec75	__irq_regs
++EXPORT_SYMBOL vmlinux 0x2c95f91a	vfs_create
++EXPORT_SYMBOL vmlinux 0x2c97642b	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0x2c988955	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x2caf61ff	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x2cb98afa	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0x2cc9557e	eth_header
++EXPORT_SYMBOL vmlinux 0x2cefb27e	snd_ctl_notify
++EXPORT_SYMBOL vmlinux 0x2cf11d63	set_blocksize
++EXPORT_SYMBOL vmlinux 0x2d080f29	dev_printk
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d3e3837	dquot_file_open
++EXPORT_SYMBOL vmlinux 0x2d4647f9	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0x2d49e707	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x2d558cbd	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0x2d6004db	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x2d6507b5	_find_next_zero_bit_le
++EXPORT_SYMBOL vmlinux 0x2d770676	dispc_mgr_go
++EXPORT_SYMBOL vmlinux 0x2d971d7e	snd_timer_stop
++EXPORT_SYMBOL vmlinux 0x2dd6e6f4	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0x2dd9a36b	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x2dda372b	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x2de4b45e	phy_device_remove
++EXPORT_SYMBOL vmlinux 0x2e01daa3	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0x2e022666	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x2e056ab2	would_dump
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e40eb0a	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0x2e5810c6	__aeabi_unwind_cpp_pr1
++EXPORT_SYMBOL vmlinux 0x2e5ac7e7	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0x2e83af74	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x2e94a5b2	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x2e974e90	unlock_page
++EXPORT_SYMBOL vmlinux 0x2ea1e081	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0x2eaa47ba	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0x2ebae93f	devm_free_irq
++EXPORT_SYMBOL vmlinux 0x2ebc8675	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0x2ec4c3fe	bmap
++EXPORT_SYMBOL vmlinux 0x2ec524ad	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x2ecd441b	fence_free
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2ef744f7	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f087d1a	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL vmlinux 0x2f1cdb65	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x2f1d67b4	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x2f24d359	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0x2f3ea1c8	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2f4ce050	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0x2f5f2a57	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0x2f6a2f4f	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0x2f97749b	kobject_put
++EXPORT_SYMBOL vmlinux 0x2fa70b6f	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2ffc62c5	snd_ctl_find_id
++EXPORT_SYMBOL vmlinux 0x30127f47	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL vmlinux 0x301ab7f8	md_done_sync
++EXPORT_SYMBOL vmlinux 0x301feb55	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0x302e8dbf	drop_nlink
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x3033f555	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0x303fed20	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x3046c8e7	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x30805c96	proc_symlink
++EXPORT_SYMBOL vmlinux 0x3082a0b3	dss_feat_get_supported_color_modes
++EXPORT_SYMBOL vmlinux 0x308aad56	omap_vrfb_min_phys_size
++EXPORT_SYMBOL vmlinux 0x309654a0	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x3098b52f	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30a9122d	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x30c45cc3	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0x30c4cc3c	of_get_address
++EXPORT_SYMBOL vmlinux 0x30ce346b	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0x30ce80e0	tty_register_device
++EXPORT_SYMBOL vmlinux 0x30cffaf6	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0x30de4686	ppp_input_error
++EXPORT_SYMBOL vmlinux 0x30df6c6a	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x30e3241a	snd_pci_quirk_lookup
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x30e8d074	blk_init_queue
++EXPORT_SYMBOL vmlinux 0x30ffad99	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310917fe	sort
++EXPORT_SYMBOL vmlinux 0x310e2013	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL vmlinux 0x31380354	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x313bf7c6	__skb_checksum
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x315c2ae8	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x31749656	netif_rx
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x318799fa	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x318db920	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x3191f109	__krealloc
++EXPORT_SYMBOL vmlinux 0x31a0caa9	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0x31a4767f	qcom_scm_hdcp_available
++EXPORT_SYMBOL vmlinux 0x31aaf14f	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0x31b31f5c	csum_partial_copy_nocheck
++EXPORT_SYMBOL vmlinux 0x31de7cf9	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x31f0bb78	__kmap_atomic_idx
++EXPORT_SYMBOL vmlinux 0x31f6ad14	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0x32105c9b	netdev_printk
++EXPORT_SYMBOL vmlinux 0x32369c42	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0x3243b574	acl_by_type
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x3273b3d0	snd_device_register
++EXPORT_SYMBOL vmlinux 0x3276d36c	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0x327e6556	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0x328a05f1	strncpy
++EXPORT_SYMBOL vmlinux 0x32907b91	idr_remove
++EXPORT_SYMBOL vmlinux 0x329d62b9	__vfs_write
++EXPORT_SYMBOL vmlinux 0x32a12d8d	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0x32cfd42b	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0x32ea8769	snd_info_create_card_entry
++EXPORT_SYMBOL vmlinux 0x3316845e	idr_get_next
++EXPORT_SYMBOL vmlinux 0x3317e709	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0x335401cf	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0x3363b490	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0x3365c2d5	ping_prot
++EXPORT_SYMBOL vmlinux 0x3395b5e8	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33dbfd93	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x33f32071	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0x3413d539	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x3413f500	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0x341dbfa3	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x3440e3ad	napi_disable
++EXPORT_SYMBOL vmlinux 0x344b7739	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x346f9578	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x34711a9e	pci_restore_state
++EXPORT_SYMBOL vmlinux 0x3478d323	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x349d8218	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0x34ac4674	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0x34dc71f5	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x34dee224	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0x34e4710a	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x34f6ed20	sget_userns
++EXPORT_SYMBOL vmlinux 0x3507a132	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0x35163cd4	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x3517ab90	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0x3529fc41	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0x353ca4f1	skb_copy
++EXPORT_SYMBOL vmlinux 0x353de98f	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x353e3fa5	__get_user_4
++EXPORT_SYMBOL vmlinux 0x3546d038	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x356b0f85	nand_scan_ident
++EXPORT_SYMBOL vmlinux 0x356facef	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0x35826289	pipe_unlock
++EXPORT_SYMBOL vmlinux 0x3586f745	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0x359a5c56	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0x35a22af7	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35c2a5a0	phy_stop
++EXPORT_SYMBOL vmlinux 0x35c7a871	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0x35f31c77	audit_log
++EXPORT_SYMBOL vmlinux 0x35fbd6a1	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x360b1afe	probe_irq_mask
++EXPORT_SYMBOL vmlinux 0x3612c10f	tmio_core_mmc_enable
++EXPORT_SYMBOL vmlinux 0x36149dd7	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x36216902	mmc_erase
++EXPORT_SYMBOL vmlinux 0x3623e2ba	cros_ec_query_all
++EXPORT_SYMBOL vmlinux 0x362da24c	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0x3649e016	vga_put
++EXPORT_SYMBOL vmlinux 0x364ee807	vfs_rename
++EXPORT_SYMBOL vmlinux 0x366a4b27	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0x367ba856	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0x36889610	block_write_begin
++EXPORT_SYMBOL vmlinux 0x36994960	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x36a9e764	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x36bb7fc0	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36cf26b4	kernel_listen
++EXPORT_SYMBOL vmlinux 0x36dcfefc	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0x36fdda67	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x370e0511	wake_up_process
++EXPORT_SYMBOL vmlinux 0x372400fd	snd_pcm_stop
++EXPORT_SYMBOL vmlinux 0x3741e173	ata_link_printk
++EXPORT_SYMBOL vmlinux 0x37448371	save_mount_options
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x3758a50f	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0x3775fa1b	ps2_drain
++EXPORT_SYMBOL vmlinux 0x37768f05	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0x3779785c	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0x37846c91	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL vmlinux 0x3798eab9	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0x379dee5f	trace_print_symbols_seq_u64
++EXPORT_SYMBOL vmlinux 0x37a6c305	d_add_ci
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37b8f456	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37df31a2	inet6_protos
++EXPORT_SYMBOL vmlinux 0x37e74642	get_jiffies_64
++EXPORT_SYMBOL vmlinux 0x37f24acc	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x37f614b7	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x380666d2	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0x380ce0e0	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x38355142	soft_cursor
++EXPORT_SYMBOL vmlinux 0x38379ae0	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0x385605b0	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x3893549e	commit_creds
++EXPORT_SYMBOL vmlinux 0x389acf0c	gpmc_configure
++EXPORT_SYMBOL vmlinux 0x389ecf9e	__bswapdi2
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38d3b5ee	netlink_capable
++EXPORT_SYMBOL vmlinux 0x38fc89e1	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x390beb83	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0x390f51d4	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x3910a612	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0x3924dd56	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x39582651	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL vmlinux 0x39730d06	atomic_io_modify
++EXPORT_SYMBOL vmlinux 0x397f2e02	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x39809f76	phy_find_first
++EXPORT_SYMBOL vmlinux 0x3993ed4a	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x399de6b5	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0x39a33502	snd_seq_root
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39beead1	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL vmlinux 0x39cd60f8	poll_initwait
++EXPORT_SYMBOL vmlinux 0x39e61b4d	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0x39ef68fe	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x3a09332a	seq_release
++EXPORT_SYMBOL vmlinux 0x3a1ac054	set_normalized_timespec64
++EXPORT_SYMBOL vmlinux 0x3a2044ec	do_SAK
++EXPORT_SYMBOL vmlinux 0x3a430c38	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x3a56147d	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0x3a638808	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x3a89a5e9	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3abb26b0	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x3ac60bf2	__seq_open_private
++EXPORT_SYMBOL vmlinux 0x3ad254bc	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x3aea53b1	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0x3af378de	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0x3afee99b	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0x3b090e81	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x3b2c2015	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0x3b632681	blkdev_get
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b708b01	snd_info_free_entry
++EXPORT_SYMBOL vmlinux 0x3b891a71	snd_ctl_remove_id
++EXPORT_SYMBOL vmlinux 0x3b91f3af	snd_free_pages
++EXPORT_SYMBOL vmlinux 0x3b9545f0	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0x3bb116f7	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0x3bbc56e1	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x3bbf46ea	vga_base
++EXPORT_SYMBOL vmlinux 0x3bc24eeb	filemap_flush
++EXPORT_SYMBOL vmlinux 0x3bdbca8a	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x3bfe0bce	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0x3c1837e6	simple_open
++EXPORT_SYMBOL vmlinux 0x3c3462c0	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0x3c3b226c	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0x3c3e3f17	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x3c3f528b	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c4a2e9a	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x3c6c8965	mount_ns
++EXPORT_SYMBOL vmlinux 0x3c77663e	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0x3c7a2ff4	skb_trim
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c83f770	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x3caabeda	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0x3cb9c869	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3ced9ce6	poll_freewait
++EXPORT_SYMBOL vmlinux 0x3cfa969a	proc_douintvec
++EXPORT_SYMBOL vmlinux 0x3d10b96d	padata_alloc
++EXPORT_SYMBOL vmlinux 0x3d30409d	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0x3d3c540f	elf_hwcap
++EXPORT_SYMBOL vmlinux 0x3d45d38c	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x3d4f8e47	arp_send
++EXPORT_SYMBOL vmlinux 0x3d64d39a	of_find_backlight_by_node
++EXPORT_SYMBOL vmlinux 0x3d8657c5	get_acl
++EXPORT_SYMBOL vmlinux 0x3da526aa	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0x3db7fc1e	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x3db9c299	dquot_initialize
++EXPORT_SYMBOL vmlinux 0x3dc58977	sock_edemux
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3dff20af	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x3e2b7a51	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x3e2c93df	dmam_release_declared_memory
++EXPORT_SYMBOL vmlinux 0x3e43714c	nobh_writepage
++EXPORT_SYMBOL vmlinux 0x3e56562f	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0x3e7b70a7	may_umount
++EXPORT_SYMBOL vmlinux 0x3e884f4b	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x3e8b086c	kunmap
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3ea69cf2	skb_clone
++EXPORT_SYMBOL vmlinux 0x3ee152ca	kdb_current_task
++EXPORT_SYMBOL vmlinux 0x3ee593b2	fb_find_mode
++EXPORT_SYMBOL vmlinux 0x3ef1b496	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x3ef3537b	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL vmlinux 0x3ef8bf96	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x3f1b6bf0	single_release
++EXPORT_SYMBOL vmlinux 0x3f29b3b9	ip_defrag
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f46bba6	dss_mgr_disconnect
++EXPORT_SYMBOL vmlinux 0x3f4da97b	fb_class
++EXPORT_SYMBOL vmlinux 0x3f5b67d5	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x3f616ce2	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x3f7ccf82	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x3f7dbc5c	textsearch_register
++EXPORT_SYMBOL vmlinux 0x3f800449	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0x3f995d94	d_path
++EXPORT_SYMBOL vmlinux 0x3fa6f225	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0x3fab3ca9	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0x3facd7cd	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4039918a	clk_register_clkdev
++EXPORT_SYMBOL vmlinux 0x4059792f	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x407136b1	__put_user_8
++EXPORT_SYMBOL vmlinux 0x407a3275	omap_start_dma
++EXPORT_SYMBOL vmlinux 0x4080315f	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0x4085c17c	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a2d1dd	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x40a7c8c9	netdev_err
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40ab31d1	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x40ad3abc	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x40b013bc	fs_bio_set
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c5edbf	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40cbac39	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40ed524a	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x40ef5d32	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0x40f07981	__ashldi3
++EXPORT_SYMBOL vmlinux 0x40f19e30	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0x411acc07	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x4134b50a	tty_unlock
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x4152b0f5	vc_resize
++EXPORT_SYMBOL vmlinux 0x41579469	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0x415d192c	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x41690404	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0x4171072f	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0x417ced06	path_put
++EXPORT_SYMBOL vmlinux 0x41804208	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x418a5367	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x4194f197	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0x41ae0569	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x41bddf6e	blk_finish_request
++EXPORT_SYMBOL vmlinux 0x41c00f35	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0x41c3a8be	kern_unmount
++EXPORT_SYMBOL vmlinux 0x41ce0215	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x421e5f63	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0x42356932	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x423d81ed	ida_pre_get
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x4258a0f7	ptp_clock_index
++EXPORT_SYMBOL vmlinux 0x425c74d5	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0x4279b749	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x427c4f7e	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x42851bb7	touch_atime
++EXPORT_SYMBOL vmlinux 0x428c5b86	__register_nls
++EXPORT_SYMBOL vmlinux 0x429376e8	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0x4298b775	v7_flush_kern_cache_all
++EXPORT_SYMBOL vmlinux 0x429be6d3	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42b55720	md_reload_sb
++EXPORT_SYMBOL vmlinux 0x42d4bb99	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x42dd1f9b	km_state_expired
++EXPORT_SYMBOL vmlinux 0x42f295ab	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x4308f67f	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0x4319dc4f	param_set_uint
++EXPORT_SYMBOL vmlinux 0x4326ae49	fb_pan_display
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x435769dc	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0x437e2524	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x43811663	amba_driver_register
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x4386f3ee	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x43a3962a	of_cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0x43aaa73a	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0x43d2b492	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x43e08d45	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x43f90c7a	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x441ed159	omap_get_dma_src_pos
++EXPORT_SYMBOL vmlinux 0x442495c9	tmio_core_mmc_resume
++EXPORT_SYMBOL vmlinux 0x442a45d7	tso_start
++EXPORT_SYMBOL vmlinux 0x442ea3ef	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0x44366cfc	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0x443c67db	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0x443dd5e3	update_region
++EXPORT_SYMBOL vmlinux 0x44438b96	hex2bin
++EXPORT_SYMBOL vmlinux 0x444569f2	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x4454786e	blk_peek_request
++EXPORT_SYMBOL vmlinux 0x445d5eac	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0x44643b93	__aeabi_lmul
++EXPORT_SYMBOL vmlinux 0x446c90ed	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0x4477d4d4	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x447cec0c	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0x44816200	snd_ctl_remove
++EXPORT_SYMBOL vmlinux 0x44af70c9	set_cached_acl
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44cd3212	truncate_setsize
++EXPORT_SYMBOL vmlinux 0x44da5d0f	__csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0x44dd3d8d	completion_done
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44f33917	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0x44f34095	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x450672f5	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0x45199775	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x452a979b	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x457968ad	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0x45846b52	i2c_use_client
++EXPORT_SYMBOL vmlinux 0x4596f759	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x45aea035	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0x45bda0d5	system_serial_low
++EXPORT_SYMBOL vmlinux 0x45ca69f1	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0x45ce2ecb	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0x45d40f1b	uart_match_port
++EXPORT_SYMBOL vmlinux 0x45d81a3d	generic_setlease
++EXPORT_SYMBOL vmlinux 0x461ff521	account_page_redirty
++EXPORT_SYMBOL vmlinux 0x462a2e75	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x4656155c	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x465757c3	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x468ff47d	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0x46ca5f9f	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x46cf73a6	sock_register
++EXPORT_SYMBOL vmlinux 0x46d3b28c	__div0
++EXPORT_SYMBOL vmlinux 0x46d76b71	inet_frags_init
++EXPORT_SYMBOL vmlinux 0x46f2af46	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x46ff761d	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x470f2481	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x471b5bb0	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0x473e5e21	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x4747b5f6	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x476b1969	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x478df0cb	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x47acf829	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0x47bfe63e	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x47c11c8a	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0x47c1d6f6	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0x47d0d1a0	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x47d0f585	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0x47dff5a6	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x47e70229	v7_flush_user_cache_range
++EXPORT_SYMBOL vmlinux 0x47f757de	elf_platform
++EXPORT_SYMBOL vmlinux 0x47f99322	snd_timer_global_free
++EXPORT_SYMBOL vmlinux 0x480f2f6b	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0x481ce6ce	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x485938c1	__register_chrdev
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x485cafae	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x485e933c	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0x48601988	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0x4875a19c	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x488d2a90	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0x488e25dc	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0x48a5b067	__machine_arch_type
++EXPORT_SYMBOL vmlinux 0x48b79cbf	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48ba4df8	__serio_register_port
++EXPORT_SYMBOL vmlinux 0x48c8670f	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x48e658df	dss_mgr_set_timings
++EXPORT_SYMBOL vmlinux 0x48f2eaaf	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x490a0804	dput
++EXPORT_SYMBOL vmlinux 0x490b99ac	seq_pad
++EXPORT_SYMBOL vmlinux 0x49178719	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x4942a81d	iget5_locked
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x4963bd0b	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0x4967796e	dst_destroy
++EXPORT_SYMBOL vmlinux 0x4980a627	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0x498c48b7	tty_do_resize
++EXPORT_SYMBOL vmlinux 0x49986deb	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0x499cb58c	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x499f59df	kmap_to_page
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b77ed2	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0x49b84ec8	bio_map_kern
++EXPORT_SYMBOL vmlinux 0x49be09e7	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0x49bf213d	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0x49c6545f	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x49ca43fc	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0x49ebacbd	_clear_bit
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x4a009a05	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0x4a0eeb09	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x4a222e61	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0x4a2cc05e	netdev_emerg
++EXPORT_SYMBOL vmlinux 0x4a39e5a1	omap_set_dma_src_params
++EXPORT_SYMBOL vmlinux 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL vmlinux 0x4a5565c4	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x4a57b339	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x4a6d35d8	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x4a766656	skb_insert
++EXPORT_SYMBOL vmlinux 0x4a7b595d	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4ac11307	genphy_resume
++EXPORT_SYMBOL vmlinux 0x4ac58331	unregister_mtd_chip_driver
++EXPORT_SYMBOL vmlinux 0x4ae2bd61	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0x4aea2bb8	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b1ec3e2	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x4b25a208	sock_create_kern
++EXPORT_SYMBOL vmlinux 0x4b3eea3a	arp_create
++EXPORT_SYMBOL vmlinux 0x4b469b36	amba_release_regions
++EXPORT_SYMBOL vmlinux 0x4b570b7b	snd_pcm_lib_read
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b666f52	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0x4b77ca17	free_user_ns
++EXPORT_SYMBOL vmlinux 0x4b78933c	qcom_scm_set_cold_boot_addr
++EXPORT_SYMBOL vmlinux 0x4b8b242f	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0x4b8f189e	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0x4b9642ee	filemap_fault
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4bafd021	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x4bce0f36	gen_pool_create
++EXPORT_SYMBOL vmlinux 0x4bcf03a4	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x4bd2df55	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x4be7fb63	up
++EXPORT_SYMBOL vmlinux 0x4be85a03	memweight
++EXPORT_SYMBOL vmlinux 0x4c1abade	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0x4c2165fa	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0x4c233a44	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0x4c24e17e	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0x4c28d297	tc6393xb_lcd_set_power
++EXPORT_SYMBOL vmlinux 0x4c29dcbf	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x4c2ae700	strnstr
++EXPORT_SYMBOL vmlinux 0x4c33081d	omapdss_compat_uninit
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c3492a7	of_get_parent
++EXPORT_SYMBOL vmlinux 0x4c3d0c0c	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0x4c42467d	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0x4c5b0273	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0x4c5d0f16	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0x4c5fc58c	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0x4c70a59a	devm_memremap
++EXPORT_SYMBOL vmlinux 0x4c80c574	__dst_free
++EXPORT_SYMBOL vmlinux 0x4c86184b	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x4c982bfb	mmc_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x4ca03bd3	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0x4cbc6ed1	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x4cc2854d	tegra114_clock_assert_dfll_dvco_reset
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4d076f51	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x4d0d163d	copy_page
++EXPORT_SYMBOL vmlinux 0x4d146d68	vfs_writef
++EXPORT_SYMBOL vmlinux 0x4d1f9bef	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0x4d26f927	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x4d3ac3b6	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0x4d3c153f	sigprocmask
++EXPORT_SYMBOL vmlinux 0x4d45d89e	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x4d525b05	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0x4d5e876f	seq_read
++EXPORT_SYMBOL vmlinux 0x4d7903a8	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0x4d818fdd	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0x4d83b295	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x4d8d82d2	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4d9b6d35	snd_pcm_format_size
++EXPORT_SYMBOL vmlinux 0x4dd71d09	bh_submit_read
++EXPORT_SYMBOL vmlinux 0x4dd81e51	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4dec6038	memscan
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4e0fe78e	have_submounts
++EXPORT_SYMBOL vmlinux 0x4e1562f1	of_get_child_by_name
++EXPORT_SYMBOL vmlinux 0x4e2c6d6d	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e506013	omap_dma_link_lch
++EXPORT_SYMBOL vmlinux 0x4e645238	uart_resume_port
++EXPORT_SYMBOL vmlinux 0x4e66cbf6	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6db866	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e70ff08	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0x4e7fae86	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0x4e932a0d	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0x4ea0da4a	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x4ea8959b	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0x4ebf44ec	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0x4ec5dab1	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0x4ee557f1	snd_pcm_new_stream
++EXPORT_SYMBOL vmlinux 0x4ef2f5cf	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0x4f14ef5a	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x4f17a826	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f6041ef	dns_query
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f6d9ca5	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0x4f74e9cc	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x4f77a21d	register_shrinker
++EXPORT_SYMBOL vmlinux 0x4f7d0150	skb_pull
++EXPORT_SYMBOL vmlinux 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL vmlinux 0x4f89c9de	gpmc_cs_free
++EXPORT_SYMBOL vmlinux 0x4f916aaf	fb_set_var
++EXPORT_SYMBOL vmlinux 0x4f9eb0a2	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0x4fa6fc8c	key_task_permission
++EXPORT_SYMBOL vmlinux 0x4fa9837e	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0x4fba6c89	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x4fe5d55d	pci_map_rom
++EXPORT_SYMBOL vmlinux 0x4fe95c0d	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0x4ff5526c	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0x4ffc0157	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x4ffc7860	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x50321cac	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL vmlinux 0x503dea45	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0x5041aeba	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x506c326d	netdev_state_change
++EXPORT_SYMBOL vmlinux 0x5079d1d4	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0x509784c3	seq_open
++EXPORT_SYMBOL vmlinux 0x509817cf	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x50b134bf	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0x50b2947d	dev_uc_init
++EXPORT_SYMBOL vmlinux 0x50b66bcb	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x50bca9a1	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0x50d3551b	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x50d5612e	dispc_mgr_get_sync_lost_irq
++EXPORT_SYMBOL vmlinux 0x50d669fc	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x50fdcf54	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x511746c1	dump_fpu
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x51277349	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0x5132b832	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x514cc273	arm_copy_from_user
++EXPORT_SYMBOL vmlinux 0x514db909	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x51c6db18	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0x51d559d1	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x51e77c97	pfn_valid
++EXPORT_SYMBOL vmlinux 0x51e868f1	d_drop
++EXPORT_SYMBOL vmlinux 0x51e9de1c	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x51ef33b8	kstrndup
++EXPORT_SYMBOL vmlinux 0x51f4a5c9	of_device_get_match_data
++EXPORT_SYMBOL vmlinux 0x51f9fcd5	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x52165f97	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x522a3a22	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0x522dbc03	snd_card_new
++EXPORT_SYMBOL vmlinux 0x522edb3b	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x523b1351	force_sig
++EXPORT_SYMBOL vmlinux 0x52569df4	led_set_brightness
++EXPORT_SYMBOL vmlinux 0x5266c716	generic_write_checks
++EXPORT_SYMBOL vmlinux 0x5272535e	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0x5279bd7e	dm_io
++EXPORT_SYMBOL vmlinux 0x5284728f	clear_inode
++EXPORT_SYMBOL vmlinux 0x528c709d	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x528d0c14	idr_init
++EXPORT_SYMBOL vmlinux 0x5290328e	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0x529a684e	__frontswap_test
++EXPORT_SYMBOL vmlinux 0x52aa2aa5	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x52af562a	__crc32c_le
++EXPORT_SYMBOL vmlinux 0x52bb841c	atomic_io_modify_relaxed
++EXPORT_SYMBOL vmlinux 0x52c0d9e6	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL vmlinux 0x52e9f41e	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x52f81007	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x533052a1	set_user_nice
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x534b408d	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x53776096	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0x53795ae8	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0x53957d60	input_grab_device
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x541cfd31	registered_fb
++EXPORT_SYMBOL vmlinux 0x54301f48	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x54326658	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0x54348868	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x54597c70	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0x547077ec	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x547ce898	dispc_read_irqenable
++EXPORT_SYMBOL vmlinux 0x54812610	__invalidate_device
++EXPORT_SYMBOL vmlinux 0x54840f36	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x548dc7b2	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54b22e1a	xattr_full_name
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54d2c6a6	flow_cache_init
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54f21487	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x54f6830a	omapdss_get_default_display_name
++EXPORT_SYMBOL vmlinux 0x54fc36e7	seq_lseek
++EXPORT_SYMBOL vmlinux 0x55070dce	vme_lm_request
++EXPORT_SYMBOL vmlinux 0x5508cc69	clear_nlink
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x55502815	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0x555467c8	iterate_fd
++EXPORT_SYMBOL vmlinux 0x5567198b	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x556abe61	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x557a1f5e	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0x55b0854c	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x55c6b231	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x55dff2e6	do_splice_from
++EXPORT_SYMBOL vmlinux 0x55e1add9	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x5628e231	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x562b6949	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x563952a3	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x565aeb39	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x565d85cb	neigh_destroy
++EXPORT_SYMBOL vmlinux 0x567cb5ca	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x5689afe7	dispc_ovl_enable
++EXPORT_SYMBOL vmlinux 0x568d6e64	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x56a026bb	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0x56a25d0a	param_set_ushort
++EXPORT_SYMBOL vmlinux 0x56a76805	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0x56b7fe8a	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x56bc2f15	dispc_ovl_set_channel_out
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56e856cb	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x56efb124	page_readlink
++EXPORT_SYMBOL vmlinux 0x56f1d895	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0x570de61c	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0x5726b9e5	path_is_under
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x5748b16d	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x575d6376	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x577184fd	path_nosuid
++EXPORT_SYMBOL vmlinux 0x57a6c2d5	unlock_rename
++EXPORT_SYMBOL vmlinux 0x57b157e0	of_node_get
++EXPORT_SYMBOL vmlinux 0x57bc169b	dev_close
++EXPORT_SYMBOL vmlinux 0x57c18ed8	__inode_permission
++EXPORT_SYMBOL vmlinux 0x57c51a6b	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x57d408b9	dev_err
++EXPORT_SYMBOL vmlinux 0x57e2bfee	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x57f7add4	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0x5804e127	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0x580a38c2	generic_file_open
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x58227d9a	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0x5826a269	f_setown
++EXPORT_SYMBOL vmlinux 0x5827e12a	shdma_init
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x58516557	omap_set_dma_src_data_pack
++EXPORT_SYMBOL vmlinux 0x5865468f	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x58769651	param_get_charp
++EXPORT_SYMBOL vmlinux 0x58990bd0	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0x58a0fdd2	snd_pcm_lib_free_pages
++EXPORT_SYMBOL vmlinux 0x58ae28f9	param_ops_string
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58c277ff	cros_ec_cmd_xfer_status
++EXPORT_SYMBOL vmlinux 0x58d4be15	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0x58d633c7	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x5905b3cb	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0x5905d860	vm_stat
++EXPORT_SYMBOL vmlinux 0x5919ef1e	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x591a1b6b	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x5942e45b	kfree_skb
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x594e1317	__modsi3
++EXPORT_SYMBOL vmlinux 0x594ffd4f	revert_creds
++EXPORT_SYMBOL vmlinux 0x59569f3f	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x598542b2	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x598cd828	udp_table
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x598fc5ad	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0x59a17bfc	tegra114_clock_tune_cpu_trimmers_high
++EXPORT_SYMBOL vmlinux 0x59a567e9	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59b59e45	dev_set_group
++EXPORT_SYMBOL vmlinux 0x59c42b98	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x59d29dab	v7_flush_kern_dcache_area
++EXPORT_SYMBOL vmlinux 0x59d8223a	ioport_resource
++EXPORT_SYMBOL vmlinux 0x59db12b2	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0x59dce247	sock_wfree
++EXPORT_SYMBOL vmlinux 0x59e5070d	__do_div64
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a0dda57	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x5a5d8a08	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0x5a6c74c1	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0x5a71d0a5	devm_release_resource
++EXPORT_SYMBOL vmlinux 0x5a822a4d	inc_nlink
++EXPORT_SYMBOL vmlinux 0x5a9571ea	down_read
++EXPORT_SYMBOL vmlinux 0x5aa0a327	tso_build_data
++EXPORT_SYMBOL vmlinux 0x5ab166cc	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0x5abf01cf	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0x5ae5be44	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x5afe6427	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5b025e51	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0x5b04be5a	disable_fiq
++EXPORT_SYMBOL vmlinux 0x5b0ad32b	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0x5b0c560e	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0x5b14a80b	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0x5b19634d	div_s64_rem
++EXPORT_SYMBOL vmlinux 0x5b39c3c8	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0x5b4f887b	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x5b5e799a	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x5ba93f6e	simple_rmdir
++EXPORT_SYMBOL vmlinux 0x5bb9daec	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0x5bd5ed4f	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x5bea4d6d	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x5bf912f1	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0x5c22ac15	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0x5c265cba	sg_init_one
++EXPORT_SYMBOL vmlinux 0x5c2d8378	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0x5c45bea6	__find_get_block
++EXPORT_SYMBOL vmlinux 0x5c76a7a9	kmap
++EXPORT_SYMBOL vmlinux 0x5c81c4a3	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0x5c9284a0	processor_id
++EXPORT_SYMBOL vmlinux 0x5c966717	sock_i_uid
++EXPORT_SYMBOL vmlinux 0x5cad151b	proto_register
++EXPORT_SYMBOL vmlinux 0x5cb238c0	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0x5cc1f228	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x5cc78e61	__bforget
++EXPORT_SYMBOL vmlinux 0x5cdcf53a	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0x5ce8983e	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x5cedfefc	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0x5cee9652	page_waitqueue
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5d240936	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d657fcd	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0x5d6e1496	tegra_dfll_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x5d812fc5	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x5d93e602	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x5da8f67a	generic_permission
++EXPORT_SYMBOL vmlinux 0x5daa6a13	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL vmlinux 0x5dbd0cdd	snd_pcm_hw_param_first
++EXPORT_SYMBOL vmlinux 0x5dce60d2	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0x5dcf6341	outer_cache
++EXPORT_SYMBOL vmlinux 0x5dd08e21	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0x5dd60b32	update_devfreq
++EXPORT_SYMBOL vmlinux 0x5e0f0dc9	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0x5e1f67b2	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0x5e1fcf28	mmc_start_req
++EXPORT_SYMBOL vmlinux 0x5e2a6f5f	nand_unlock
++EXPORT_SYMBOL vmlinux 0x5e372f28	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0x5e38e581	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x5e3b6db0	vfs_readv
++EXPORT_SYMBOL vmlinux 0x5e48b158	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0x5e76f2b6	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL vmlinux 0x5e866d85	prandom_bytes
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5e9c1fbd	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0x5e9f431c	__check_sticky
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ebbc33c	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x5ec09d58	finish_open
++EXPORT_SYMBOL vmlinux 0x5ec50fb1	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5ef74115	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0x5effdea3	nvm_end_io
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f065de7	register_cdrom
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f199d55	omapdss_unregister_output
++EXPORT_SYMBOL vmlinux 0x5f27323c	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x5f28272a	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0x5f35b396	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x5f3eb0ee	omapdss_register_display
++EXPORT_SYMBOL vmlinux 0x5f4a0e84	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0x5f64028f	send_sig
++EXPORT_SYMBOL vmlinux 0x5f754e5a	memset
++EXPORT_SYMBOL vmlinux 0x5f7e1ad2	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0x5f870bee	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0x5fb2ac97	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x5fb5769c	arm_coherent_dma_ops
++EXPORT_SYMBOL vmlinux 0x5fbfaa44	simple_lookup
++EXPORT_SYMBOL vmlinux 0x5fce2e23	file_ns_capable
++EXPORT_SYMBOL vmlinux 0x5fd268cb	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x5ff11cc3	pcibios_min_io
++EXPORT_SYMBOL vmlinux 0x5ff5110a	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0x60055baa	dispc_mgr_get_vsync_irq
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x60196726	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x602c96f0	copy_to_user_fromio
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x6038cdf9	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x604b8789	dquot_acquire
++EXPORT_SYMBOL vmlinux 0x6066ee30	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x606ce740	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x60835f71	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL vmlinux 0x60ad576e	pci_bus_get
++EXPORT_SYMBOL vmlinux 0x60bc1ad0	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0x60d9b18a	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x60e0c717	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0x610c409d	dispc_ovl_check
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x61398f3f	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0x61594c9a	of_graph_get_remote_port_parent
++EXPORT_SYMBOL vmlinux 0x6178e7b9	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0x617a218d	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0x61914ada	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0x61aba5f4	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0x61b2b70a	neigh_xmit
++EXPORT_SYMBOL vmlinux 0x61b3560c	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61c37e3b	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0x61c6914c	blk_get_request
++EXPORT_SYMBOL vmlinux 0x61c8b97b	devm_request_resource
++EXPORT_SYMBOL vmlinux 0x61d2b08c	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0x61f51ec9	mount_nodev
++EXPORT_SYMBOL vmlinux 0x6200c1e1	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0x6202de56	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x6205f16e	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0x62064d86	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0x620b78ea	omap_dss_get_next_device
++EXPORT_SYMBOL vmlinux 0x620c63ff	sock_init_data
++EXPORT_SYMBOL vmlinux 0x6210cae7	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x621b2076	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0x6220b4a2	crc32_le
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x62296be1	qcom_scm_get_version
++EXPORT_SYMBOL vmlinux 0x62375a16	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x626caa0d	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62740cdb	input_release_device
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x62895ebb	pci_get_class
++EXPORT_SYMBOL vmlinux 0x62a9313b	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x62ae2d0e	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x62bec5c2	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x62c59f75	__free_pages
++EXPORT_SYMBOL vmlinux 0x62cae6b1	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0x62cb7bbc	sock_i_ino
++EXPORT_SYMBOL vmlinux 0x62d214fe	snd_pcm_set_sync
++EXPORT_SYMBOL vmlinux 0x62fe183f	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0x630845f1	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x631e815f	edma_filter_fn
++EXPORT_SYMBOL vmlinux 0x6344d256	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0x634eb100	dqput
++EXPORT_SYMBOL vmlinux 0x63535636	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0x636b3461	omap_dss_get_num_overlays
++EXPORT_SYMBOL vmlinux 0x637b7532	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0x63904382	cpu_user
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63d35610	bio_reset
++EXPORT_SYMBOL vmlinux 0x63e8ddfe	msm_pinctrl_probe
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63eebb33	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x64140bb6	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0x641e3789	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0x6424432a	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0x642cff64	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x648961a1	single_open_size
++EXPORT_SYMBOL vmlinux 0x6498244d	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64a22ff0	dispc_mgr_set_lcd_config
++EXPORT_SYMBOL vmlinux 0x64b3793e	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x64cb45a4	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL vmlinux 0x6510a5a9	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x6527e34a	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0x652e0ea8	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x653e44c4	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x6543c822	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0x65466939	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x656de0f4	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0x6574ada2	pci_request_region
++EXPORT_SYMBOL vmlinux 0x659028d9	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x659fd7f1	simple_getattr
++EXPORT_SYMBOL vmlinux 0x65afe064	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0x65b6e927	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0x65b928a5	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65de7d06	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x66227eae	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0x6630a823	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x6638468e	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0x664e46bb	kfree_put_link
++EXPORT_SYMBOL vmlinux 0x6658b385	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0x66626835	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0x6663dde1	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x666c1195	security_mmap_file
++EXPORT_SYMBOL vmlinux 0x6672a7dc	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0x66d6912e	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0x66de1f5e	dma_release_declared_memory
++EXPORT_SYMBOL vmlinux 0x66e2cb75	snd_power_wait
++EXPORT_SYMBOL vmlinux 0x66eac305	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x66ffa736	da903x_query_status
++EXPORT_SYMBOL vmlinux 0x6730c039	tty_lock
++EXPORT_SYMBOL vmlinux 0x675c6c7d	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0x676bbc0f	_set_bit
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x677762d0	dquot_release
++EXPORT_SYMBOL vmlinux 0x6797751a	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x679c2a38	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0x67a37882	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b73692	bio_init
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67cbe720	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x67d9f3c5	proc_create_data
++EXPORT_SYMBOL vmlinux 0x67db9277	dev_crit
++EXPORT_SYMBOL vmlinux 0x67e02294	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x67f71652	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x680cb98e	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL vmlinux 0x6810c535	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x68182a69	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x683ee517	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0x685133b1	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0x6856b7ad	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0x68749231	kern_path_create
++EXPORT_SYMBOL vmlinux 0x6879fd7a	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x688304d6	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x68869bae	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0x68932797	pci_get_device
++EXPORT_SYMBOL vmlinux 0x6894b11a	of_io_request_and_map
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL vmlinux 0x68ad0bd4	from_kgid
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68dcf87d	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0x68e01ab8	__vfs_read
++EXPORT_SYMBOL vmlinux 0x68f5aeb7	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0x68fb581a	icst307_idx2s
++EXPORT_SYMBOL vmlinux 0x68fef2cf	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x69118735	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0x6915eb38	down_interruptible
++EXPORT_SYMBOL vmlinux 0x691c5ca4	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x691c6102	default_llseek
++EXPORT_SYMBOL vmlinux 0x692819de	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0x6943566c	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0x69533ca7	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x697510be	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0x697c05d5	iterate_mounts
++EXPORT_SYMBOL vmlinux 0x69a315a2	security_path_symlink
++EXPORT_SYMBOL vmlinux 0x69a35e03	snd_register_device
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69aeb63e	seq_open_private
++EXPORT_SYMBOL vmlinux 0x69b40d42	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0x69b6f8d9	omap_set_dma_transfer_params
++EXPORT_SYMBOL vmlinux 0x69f2f1bb	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a0e85d3	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a65ac00	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x6a733e51	_dev_info
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a8d479b	inet_addr_type
++EXPORT_SYMBOL vmlinux 0x6a8fec1f	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0x6a958917	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0x6aa01a34	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x6ab48403	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0x6ab5bd1c	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x6ac14431	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6ad571a2	vfs_getattr
++EXPORT_SYMBOL vmlinux 0x6ad809ed	key_validate
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6afb0b06	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b09706c	kthread_bind
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b2de90e	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x6b3ac0be	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0x6b41c604	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x6b4b1bc1	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x6b7226e9	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x6bbc6c45	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bd816eb	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c1ce5ce	strcspn
++EXPORT_SYMBOL vmlinux 0x6c1ebc19	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL vmlinux 0x6c399004	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x6c44cac1	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c6cdd4d	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c72ed55	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x6c98e51d	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0x6ca34abf	elevator_exit
++EXPORT_SYMBOL vmlinux 0x6cb072a4	nand_bch_init
++EXPORT_SYMBOL vmlinux 0x6cc38b50	tty_throttle
++EXPORT_SYMBOL vmlinux 0x6cdc5c6b	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6cdfe47e	md_flush_request
++EXPORT_SYMBOL vmlinux 0x6cf2fb34	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x6cf7d02a	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x6d0a6e58	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d1c44dd	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0x6d271464	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d348384	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x6d6599ba	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0x6d662533	_find_first_bit_le
++EXPORT_SYMBOL vmlinux 0x6d71b33c	page_put_link
++EXPORT_SYMBOL vmlinux 0x6d779d98	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0x6d811771	snd_jack_report
++EXPORT_SYMBOL vmlinux 0x6d859e4d	init_task
++EXPORT_SYMBOL vmlinux 0x6d8967fb	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x6d9a088c	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0x6da8a028	start_tty
++EXPORT_SYMBOL vmlinux 0x6da9ca5e	input_register_handler
++EXPORT_SYMBOL vmlinux 0x6dd9cff4	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6df92c58	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0x6e0b8a39	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x6e0bcb33	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x6e11b7ca	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0x6e3b819f	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0x6e4b023c	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x6e61ece7	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0x6e62ff08	snd_pcm_period_elapsed
++EXPORT_SYMBOL vmlinux 0x6e64f2c5	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x6e6514ed	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x6e68e70a	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x6e6ccac3	snd_timer_global_new
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e879060	mapping_tagged
++EXPORT_SYMBOL vmlinux 0x6e8cc930	address_space_init_once
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6ea84116	skb_append
++EXPORT_SYMBOL vmlinux 0x6ec9ccdb	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0x6ece94ca	tty_set_operations
++EXPORT_SYMBOL vmlinux 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL vmlinux 0x6f0f06bd	param_get_long
++EXPORT_SYMBOL vmlinux 0x6f13130c	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f299527	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0x6f3037c3	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0x6f5cfcd1	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0x6f710106	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6f9c5663	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x6fa20a2c	key_put
++EXPORT_SYMBOL vmlinux 0x6faa450b	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6fcfd938	eth_header_cache
++EXPORT_SYMBOL vmlinux 0x6ff74212	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x6ffa49ba	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL vmlinux 0x7029b1d7	inet6_getname
++EXPORT_SYMBOL vmlinux 0x703dc458	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7062b4cd	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0x706b6669	vfs_readf
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x7073ea76	snd_ctl_register_ioctl
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x70a2f416	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0x70a7b4d8	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0x70aef38d	setattr_copy
++EXPORT_SYMBOL vmlinux 0x70ba2b6c	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x70bef355	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0x70ceebe4	nf_log_register
++EXPORT_SYMBOL vmlinux 0x70d78339	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x70e39dae	dss_uninstall_mgr_ops
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x710cfd6f	inet_bind
++EXPORT_SYMBOL vmlinux 0x7119db7f	omap_dss_pal_timings
++EXPORT_SYMBOL vmlinux 0x7123fa91	arp_xmit
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x712ae15b	import_iovec
++EXPORT_SYMBOL vmlinux 0x712ed37b	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x71342f95	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0x71470ff1	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x7169102e	omap_dss_ntsc_timings
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x7195aeef	dma_mark_declared_memory_occupied
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a5bd88	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71a9bd34	thaw_super
++EXPORT_SYMBOL vmlinux 0x71c90087	memcmp
++EXPORT_SYMBOL vmlinux 0x71cfb419	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x71f65175	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x71f95bb7	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x71fc8e3a	dquot_resume
++EXPORT_SYMBOL vmlinux 0x72110810	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x7215ce39	tegra_dfll_unregister
++EXPORT_SYMBOL vmlinux 0x7226bd59	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0x72350130	___ratelimit
++EXPORT_SYMBOL vmlinux 0x723b2ac8	vm_map_ram
++EXPORT_SYMBOL vmlinux 0x7270b2ab	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0x7273d1f0	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0x7296d8a2	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x72a0e6f2	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x72a106f2	param_ops_long
++EXPORT_SYMBOL vmlinux 0x72b9492b	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x72b9672d	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0x72cc3e7b	key_link
++EXPORT_SYMBOL vmlinux 0x72d58de9	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x730522de	elm_config
++EXPORT_SYMBOL vmlinux 0x73158440	of_match_node
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x73284c2c	pps_unregister_source
++EXPORT_SYMBOL vmlinux 0x733b927f	__quota_error
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x73435ae6	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0x73911cba	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x7393c18e	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x73973923	I_BDEV
++EXPORT_SYMBOL vmlinux 0x73d1d253	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0x73e20c1c	strlcpy
++EXPORT_SYMBOL vmlinux 0x73e827a6	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x73f58e8d	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0x7406b944	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x742e08f2	mmc_add_host
++EXPORT_SYMBOL vmlinux 0x746e9274	skb_push
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x7475bceb	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x74ba3cc0	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0x74bb05d8	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x74bb848c	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74c31e2c	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x74e46dac	imx_ssi_fiq_tx_buffer
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74f3ef75	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0x7505bdef	memchr_inv
++EXPORT_SYMBOL vmlinux 0x751175ca	inet_offloads
++EXPORT_SYMBOL vmlinux 0x751b40b5	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0x7524fe8e	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x7542d8f4	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0x754f5224	do_splice_direct
++EXPORT_SYMBOL vmlinux 0x75546a6b	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x755cbb72	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x7561a5af	load_nls_default
++EXPORT_SYMBOL vmlinux 0x7567d381	__get_fiq_regs
++EXPORT_SYMBOL vmlinux 0x75709d50	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0x7573faa8	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0x75923888	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL vmlinux 0x75923dab	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0x7592eb57	generic_update_time
++EXPORT_SYMBOL vmlinux 0x7593d385	div64_s64
++EXPORT_SYMBOL vmlinux 0x75a5b44a	contig_page_data
++EXPORT_SYMBOL vmlinux 0x75afdcdd	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x75b073e9	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75c0c3ce	padata_start
++EXPORT_SYMBOL vmlinux 0x75d8811d	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0x75e18418	snd_timer_resolution
++EXPORT_SYMBOL vmlinux 0x75ee67b1	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x7611bc0f	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x76184d98	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0x7625aea7	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x7627be04	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x76478ce5	set_anon_super
++EXPORT_SYMBOL vmlinux 0x7655fd24	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x76591123	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0x767583a1	kunmap_high
++EXPORT_SYMBOL vmlinux 0x7676416b	d_make_root
++EXPORT_SYMBOL vmlinux 0x76987cbd	of_clk_get_by_name
++EXPORT_SYMBOL vmlinux 0x769a5aa6	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0x76a76414	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x76aa2d00	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x76ae215a	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x76cf47f6	__aeabi_llsl
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76d4e1e2	no_llseek
++EXPORT_SYMBOL vmlinux 0x76d9bf11	crc32_be
++EXPORT_SYMBOL vmlinux 0x76f6c5ef	kmalloc_order
++EXPORT_SYMBOL vmlinux 0x771fe434	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0x772519be	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0x772d9a0c	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0x773eec31	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0x77472eed	block_write_end
++EXPORT_SYMBOL vmlinux 0x774900eb	nand_scan
++EXPORT_SYMBOL vmlinux 0x775a130e	__sg_free_table
++EXPORT_SYMBOL vmlinux 0x775abeb5	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x7776a685	snd_jack_add_new_kctl
++EXPORT_SYMBOL vmlinux 0x7776dbf4	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0x7791193f	icst525_s2div
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x779efb21	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0x779fc45e	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0x77a0a648	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x77ba3b76	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77d3fc09	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x77d4e332	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x77e190b2	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0x77e588ca	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0x77e9e94d	of_parse_phandle_with_fixed_args
++EXPORT_SYMBOL vmlinux 0x77fa1a63	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x78003391	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x7810a88b	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0x7837ed01	phy_device_free
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x783b977a	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0x784a9a68	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0x78575272	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x7865ab18	dump_truncate
++EXPORT_SYMBOL vmlinux 0x78779c0b	set_fiq_handler
++EXPORT_SYMBOL vmlinux 0x787ad01e	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x78824ebe	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0x788fe103	iomem_resource
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78a105b1	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0x78a7abac	check_disk_change
++EXPORT_SYMBOL vmlinux 0x78b2ddd9	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78f86c3d	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0x78ff4cc1	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x79119ddb	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0x79183936	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0x791c0b89	of_mm_gpiochip_remove
++EXPORT_SYMBOL vmlinux 0x792e7a54	security_path_chmod
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x7970bc1f	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0x7981c571	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0x7984080b	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x7992b0bc	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79c5a9f0	ioremap
++EXPORT_SYMBOL vmlinux 0x79fa1deb	imx_ssi_fiq_rx_buffer
++EXPORT_SYMBOL vmlinux 0x7a122a55	dentry_open
++EXPORT_SYMBOL vmlinux 0x7a17ce97	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x7a1ca216	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0x7a1f2611	dispc_mgr_set_timings
++EXPORT_SYMBOL vmlinux 0x7a29f349	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0x7a2add7d	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0x7a41f6cd	tty_devnum
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a466173	load_nls
++EXPORT_SYMBOL vmlinux 0x7a51d717	phy_resume
++EXPORT_SYMBOL vmlinux 0x7a6c5fc1	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0x7a7510d8	module_refcount
++EXPORT_SYMBOL vmlinux 0x7a95e5ae	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7a9fb6c3	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7aa2ab55	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x7aa9538d	__scm_send
++EXPORT_SYMBOL vmlinux 0x7ab1243a	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ac60aae	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7aeb774d	dmam_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x7afa89fc	vsnprintf
++EXPORT_SYMBOL vmlinux 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b1ade38	lz4_decompress
++EXPORT_SYMBOL vmlinux 0x7b2733e2	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x7b283ce3	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0x7b35bf33	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0x7b383830	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0x7b3c27de	noop_llseek
++EXPORT_SYMBOL vmlinux 0x7b5c8440	vm_munmap
++EXPORT_SYMBOL vmlinux 0x7b635b16	iunique
++EXPORT_SYMBOL vmlinux 0x7b6ee3f6	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x7b76bbcf	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x7b8ecc99	generic_make_request
++EXPORT_SYMBOL vmlinux 0x7b8f984a	pps_register_source
++EXPORT_SYMBOL vmlinux 0x7bbd1455	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0x7bfea345	migrate_page
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c1a942d	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0x7c1dcc7e	param_array_ops
++EXPORT_SYMBOL vmlinux 0x7c271756	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0x7c2af2b0	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c46458b	input_set_capability
++EXPORT_SYMBOL vmlinux 0x7c466037	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x7c4ccf97	simple_link
++EXPORT_SYMBOL vmlinux 0x7c599225	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0x7c6bf2a9	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x7c78e9c9	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0x7c92a904	ihold
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cc035a7	__ucmpdi2
++EXPORT_SYMBOL vmlinux 0x7ccacca6	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0x7cd3caf7	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0x7cd44ed9	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7cfe8c0c	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d157c5a	sget
++EXPORT_SYMBOL vmlinux 0x7d179960	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0x7d2ed6c0	vme_slot_num
++EXPORT_SYMBOL vmlinux 0x7d3af40b	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0x7d3e11c9	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0x7d48c259	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d85dae3	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x7d9343d5	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x7da51756	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0x7dbc3c8c	of_get_property
++EXPORT_SYMBOL vmlinux 0x7dccc294	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x7dde52ad	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7df11c6b	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x7df5e557	param_get_ushort
++EXPORT_SYMBOL vmlinux 0x7dff21ee	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0x7e04562c	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x7e04da70	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x7e0865c2	mdiobus_read
++EXPORT_SYMBOL vmlinux 0x7e23b3f1	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x7e35fe5c	phy_driver_register
++EXPORT_SYMBOL vmlinux 0x7e47b4d1	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0x7e6fa3ef	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0x7e7c4d38	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0x7e927afb	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x7e9efe8e	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x7ea43958	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0x7eae30d3	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0x7eb605d5	proto_unregister
++EXPORT_SYMBOL vmlinux 0x7ed12c8c	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0x7ed7f229	get_io_context
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7ee7f093	dispc_ovl_compute_fifo_thresholds
++EXPORT_SYMBOL vmlinux 0x7ef80108	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f1400b9	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x7f17d6cd	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0x7f207ac0	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f63b31e	_memcpy_toio
++EXPORT_SYMBOL vmlinux 0x7f63e38b	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0x7f76bbe6	dev_mc_add
++EXPORT_SYMBOL vmlinux 0x7f783659	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x7f979a07	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0x7f9f70bb	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x7fa02279	of_get_pci_address
++EXPORT_SYMBOL vmlinux 0x7fa9ab13	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0x7fab82b7	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x7faf54ba	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0x7fde2edb	vme_master_read
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fe3f661	kernel_connect
++EXPORT_SYMBOL vmlinux 0x800e4ffa	__muldi3
++EXPORT_SYMBOL vmlinux 0x80298be6	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x802e66a2	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0x804aabdf	idr_is_empty
++EXPORT_SYMBOL vmlinux 0x805c4ebb	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0x80787596	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0x8086b032	dst_discard_out
++EXPORT_SYMBOL vmlinux 0x80988e26	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x809d48b6	mdiobus_free
++EXPORT_SYMBOL vmlinux 0x80c00a04	finish_no_open
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80cf4b59	tc_classify
++EXPORT_SYMBOL vmlinux 0x80d43711	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80d81308	omap_vrfb_release_ctx
++EXPORT_SYMBOL vmlinux 0x80e69eb7	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0x8102e1a6	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x810bbecb	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x812665d8	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x812c0243	single_open
++EXPORT_SYMBOL vmlinux 0x812fdca5	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0x813b6dca	bd_set_size
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x8155d1a0	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x815ddead	simple_unlink
++EXPORT_SYMBOL vmlinux 0x8164e859	genl_notify
++EXPORT_SYMBOL vmlinux 0x8168f38e	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x816bc7ac	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x81721c9f	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0x81937cd4	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x81aef16d	module_layout
++EXPORT_SYMBOL vmlinux 0x81b3d575	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL vmlinux 0x81d339ae	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x81d36e14	ps2_command
++EXPORT_SYMBOL vmlinux 0x81d8cf6c	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x82174aeb	serio_reconnect
++EXPORT_SYMBOL vmlinux 0x822137e2	arm_heavy_mb
++EXPORT_SYMBOL vmlinux 0x82217009	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0x82307e03	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x82338062	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0x8237ea9f	framebuffer_release
++EXPORT_SYMBOL vmlinux 0x824a4367	tmio_core_mmc_pwr
++EXPORT_SYMBOL vmlinux 0x824f94bd	datagram_poll
++EXPORT_SYMBOL vmlinux 0x8250be9a	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x82750eb7	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x8293dc71	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0x829b85eb	file_path
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82b5dd52	of_get_ddr_timings
++EXPORT_SYMBOL vmlinux 0x82b6a07e	dev_deactivate
++EXPORT_SYMBOL vmlinux 0x830e5560	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x831396c3	fence_signal
++EXPORT_SYMBOL vmlinux 0x8320bea8	__umodsi3
++EXPORT_SYMBOL vmlinux 0x83232ce0	genphy_update_link
++EXPORT_SYMBOL vmlinux 0x833bff44	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0x83626050	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0x8370ec4d	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0x8372cd2f	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x8375d79d	ida_destroy
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83b83b94	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83f2391a	amba_device_register
++EXPORT_SYMBOL vmlinux 0x8407da9e	empty_aops
++EXPORT_SYMBOL vmlinux 0x8436d4b3	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x843fa9ad	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0x845410c0	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x846c0a9c	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x84891257	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x8495e6fd	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0x84982054	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0x8498ea40	console_start
++EXPORT_SYMBOL vmlinux 0x84a69fdc	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x84b183ae	strncmp
++EXPORT_SYMBOL vmlinux 0x84b7755c	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x853d657a	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x85440119	mount_subtree
++EXPORT_SYMBOL vmlinux 0x85445d15	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0x854e1c0b	sg_nents
++EXPORT_SYMBOL vmlinux 0x854fec83	tegra_sku_info
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x85765fee	omap_enable_dma_irq
++EXPORT_SYMBOL vmlinux 0x85827472	ilookup
++EXPORT_SYMBOL vmlinux 0x858a2ea7	of_match_device
++EXPORT_SYMBOL vmlinux 0x8592f651	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x85ae1eb7	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85ca024e	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85edcf11	snd_ctl_add
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x85fe9fbc	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0x85ff0e4a	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0x861d90bd	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0x8636bfc4	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0x86444486	keyring_alloc
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x86535cc2	follow_pfn
++EXPORT_SYMBOL vmlinux 0x865c2c8f	request_firmware
++EXPORT_SYMBOL vmlinux 0x86615891	scmd_printk
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x867e2d37	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x86860195	dss_feat_get_supported_displays
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x868b0f83	param_ops_short
++EXPORT_SYMBOL vmlinux 0x86a17f50	rt6_lookup
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86a4889a	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0x86cb69bb	dss_mgr_set_lcd_config
++EXPORT_SYMBOL vmlinux 0x86d97175	seq_vprintf
++EXPORT_SYMBOL vmlinux 0x86dac31d	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0x86e49090	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL vmlinux 0x86ec3f7c	tegra_dfll_runtime_resume
++EXPORT_SYMBOL vmlinux 0x86f4bbd2	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x86f735c4	input_flush_device
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x87003790	fence_init
++EXPORT_SYMBOL vmlinux 0x8701e168	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0x8703f3b2	omap_dss_get_overlay_manager
++EXPORT_SYMBOL vmlinux 0x8706a7f4	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x8740b23e	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0x875f1a9e	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0x8780310a	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x87a465f8	dss_mgr_unregister_framedone_handler
++EXPORT_SYMBOL vmlinux 0x87a84376	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x87b0f2a1	downgrade_write
++EXPORT_SYMBOL vmlinux 0x87b50b72	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0x87b7bb79	shdma_request_irq
++EXPORT_SYMBOL vmlinux 0x87bd81b0	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x87c89670	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x87d12f1c	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x880f37f8	inet6_bind
++EXPORT_SYMBOL vmlinux 0x8817fc4a	__neigh_create
++EXPORT_SYMBOL vmlinux 0x883386d9	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x886bc76f	mempool_resize
++EXPORT_SYMBOL vmlinux 0x88751451	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0x887c55bc	tcp_child_process
++EXPORT_SYMBOL vmlinux 0x888fa1b5	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x88a408c1	key_unlink
++EXPORT_SYMBOL vmlinux 0x88a9cd96	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0x88ac9410	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x88b19f45	system_serial
++EXPORT_SYMBOL vmlinux 0x88c781e2	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0x88fb6f08	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0x8910658c	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0x8915a6dd	param_ops_bint
++EXPORT_SYMBOL vmlinux 0x892e161e	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x893c2689	fb_show_logo
++EXPORT_SYMBOL vmlinux 0x8946d120	new_inode
++EXPORT_SYMBOL vmlinux 0x8951b391	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x8953f0e2	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x898dd774	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x89a63b0f	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL vmlinux 0x89ab44e8	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0x89d02e9e	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89db52b5	inet6_release
++EXPORT_SYMBOL vmlinux 0x89e55ad9	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x89e72793	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0x89fc893e	neigh_update
++EXPORT_SYMBOL vmlinux 0x89fcfb46	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x8a0f4230	rename_lock
++EXPORT_SYMBOL vmlinux 0x8a12e71d	clk_get
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a290459	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0x8a2c4c95	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0x8a48156f	block_commit_write
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a4fa83b	__aeabi_llsr
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a6f3be2	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0x8a773878	install_exec_creds
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a970b84	ps2_init
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8aa6ed6c	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0x8adcf988	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0x8ae1ae8b	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0x8aeb207b	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0x8af0b3b5	snd_pcm_hw_param_last
++EXPORT_SYMBOL vmlinux 0x8b40d2f1	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b4a59fd	unregister_console
++EXPORT_SYMBOL vmlinux 0x8b4d432e	d_genocide
++EXPORT_SYMBOL vmlinux 0x8b548bee	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b820948	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0x8b89062c	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x8b9761e4	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0x8b9a68a4	get_gendisk
++EXPORT_SYMBOL vmlinux 0x8bba0d57	vfs_statfs
++EXPORT_SYMBOL vmlinux 0x8bd1f834	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0x8bdf1fa4	__sock_create
++EXPORT_SYMBOL vmlinux 0x8bf70158	snd_pcm_lib_readv
++EXPORT_SYMBOL vmlinux 0x8c0520f5	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x8c110484	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0x8c175599	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0x8c55548f	is_bad_inode
++EXPORT_SYMBOL vmlinux 0x8c560065	revalidate_disk
++EXPORT_SYMBOL vmlinux 0x8c586ae0	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0x8c5bc69e	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c7b846c	make_kprojid
++EXPORT_SYMBOL vmlinux 0x8c91cf9a	nand_calculate_ecc
++EXPORT_SYMBOL vmlinux 0x8c91dfd9	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x8c962c23	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0x8c9886fb	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x8c9ea84d	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x8ca30873	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x8ca5ad41	tty_port_init
++EXPORT_SYMBOL vmlinux 0x8cd0b064	snd_pcm_new
++EXPORT_SYMBOL vmlinux 0x8cd8c339	omap_free_dma
++EXPORT_SYMBOL vmlinux 0x8cf0284e	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL vmlinux 0x8d134c39	idr_replace
++EXPORT_SYMBOL vmlinux 0x8d2daacd	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0x8d3d4a4a	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x8d4199d4	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x8d484e77	of_phy_attach
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d64153f	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x8d64495d	of_get_next_available_child
++EXPORT_SYMBOL vmlinux 0x8d6504c1	dev_alert
++EXPORT_SYMBOL vmlinux 0x8d6b2ce1	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x8d6f81b4	__div64_32
++EXPORT_SYMBOL vmlinux 0x8d72495b	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d8b6353	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0x8d902613	sock_release
++EXPORT_SYMBOL vmlinux 0x8dcff6e2	__pv_offset
++EXPORT_SYMBOL vmlinux 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL vmlinux 0x8df484ce	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0x8e1dd6af	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0x8e2ad5e8	snd_card_register
++EXPORT_SYMBOL vmlinux 0x8e2fe890	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x8e497146	of_get_next_child
++EXPORT_SYMBOL vmlinux 0x8e5bf9ca	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0x8e6851d6	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e808986	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0x8e845e73	find_vma
++EXPORT_SYMBOL vmlinux 0x8e865d3c	arm_delay_ops
++EXPORT_SYMBOL vmlinux 0x8e95bc0f	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x8e9659b5	put_filp
++EXPORT_SYMBOL vmlinux 0x8eb593b0	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL vmlinux 0x8ee1328b	tcp_prot
++EXPORT_SYMBOL vmlinux 0x8eea9741	dma_mmap_from_coherent
++EXPORT_SYMBOL vmlinux 0x8ef4292e	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0x8f1e1ee3	dev_emerg
++EXPORT_SYMBOL vmlinux 0x8f595b11	snd_major
++EXPORT_SYMBOL vmlinux 0x8f678b07	__stack_chk_guard
++EXPORT_SYMBOL vmlinux 0x8f70c76e	snd_ctl_find_numid
++EXPORT_SYMBOL vmlinux 0x8f800052	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x8f89429f	keyring_search
++EXPORT_SYMBOL vmlinux 0x8fa4130a	omap_set_dma_callback
++EXPORT_SYMBOL vmlinux 0x8fbb7d67	of_n_size_cells
++EXPORT_SYMBOL vmlinux 0x8fc32850	of_find_all_nodes
++EXPORT_SYMBOL vmlinux 0x8fd180e7	kernel_neon_begin
++EXPORT_SYMBOL vmlinux 0x8ff40c6b	mount_single
++EXPORT_SYMBOL vmlinux 0x8ffdb3b8	crc16
++EXPORT_SYMBOL vmlinux 0x9004f74a	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x900a8b4d	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0x90182b40	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x901a1390	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0x903a1a9a	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0x903d67ff	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL vmlinux 0x904e87e3	of_parse_phandle
++EXPORT_SYMBOL vmlinux 0x90682b52	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0x907bfe7a	up_read
++EXPORT_SYMBOL vmlinux 0x9081604d	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x90873754	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x908d493f	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x909c73b4	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0x909d12db	follow_down
++EXPORT_SYMBOL vmlinux 0x90a1b7ad	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x90a93479	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0x90b29d8f	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x90c5e819	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x90f28e68	snd_timer_close
++EXPORT_SYMBOL vmlinux 0x90f3bfaf	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x911491c5	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x914aef75	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0x91585aef	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0x91621d6a	allocate_resource
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x91715406	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0x917c747b	pci_set_master
++EXPORT_SYMBOL vmlinux 0x918ed5e0	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x919029aa	__readwrite_bug
++EXPORT_SYMBOL vmlinux 0x919fd1eb	snd_component_add
++EXPORT_SYMBOL vmlinux 0x91a0ee79	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x91a598eb	try_module_get
++EXPORT_SYMBOL vmlinux 0x91b035f9	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0x91b84f13	omapdss_find_mgr_from_display
++EXPORT_SYMBOL vmlinux 0x91c0980e	icst_hz
++EXPORT_SYMBOL vmlinux 0x91cb6161	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0x91ceb15c	snd_timer_interrupt
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x91f7b14c	shdma_chan_probe
++EXPORT_SYMBOL vmlinux 0x92036327	file_remove_privs
++EXPORT_SYMBOL vmlinux 0x9222d6fa	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0x92245c9a	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0x9232130c	inet_del_offload
++EXPORT_SYMBOL vmlinux 0x92365d2a	amba_request_regions
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x923d988e	freeze_bdev
++EXPORT_SYMBOL vmlinux 0x92570464	netif_napi_add
++EXPORT_SYMBOL vmlinux 0x92606d36	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x9267456b	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0x926e9559	register_sound_dsp
++EXPORT_SYMBOL vmlinux 0x9277b830	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0x927fe691	snd_pcm_create_iec958_consumer
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92ba1dc7	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0x92c45d9f	omapdss_find_output_from_display
++EXPORT_SYMBOL vmlinux 0x92cba228	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0x92da6f29	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x92e996be	d_obtain_root
++EXPORT_SYMBOL vmlinux 0x92ec5d1b	dispc_mgr_enable
++EXPORT_SYMBOL vmlinux 0x92f4ce64	shdma_reset
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x930a6e75	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x9317195a	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x93215e1d	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0x9329d30a	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0x9330cb9f	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x934f63f3	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0x935d34ef	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0x93625bfd	cdev_init
++EXPORT_SYMBOL vmlinux 0x9364e7af	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x93771277	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x939066b0	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0x93963a85	dss_feat_get_num_mgrs
++EXPORT_SYMBOL vmlinux 0x93a79e60	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93d345ef	snd_pcm_lib_ioctl
++EXPORT_SYMBOL vmlinux 0x93e262b3	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x94061a7b	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x94095e3f	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL vmlinux 0x940f9cf6	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x94268d0f	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x943c98e7	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x943cbcb1	follow_up
++EXPORT_SYMBOL vmlinux 0x946efbfa	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94abcd34	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0x94b162b1	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0x94b2590f	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0x94cf56f2	tty_port_open
++EXPORT_SYMBOL vmlinux 0x94d3da68	rtc_lock
++EXPORT_SYMBOL vmlinux 0x94d5e91c	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x94d75b1e	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x94df6ace	dss_mgr_connect
++EXPORT_SYMBOL vmlinux 0x94eea794	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x9502572c	key_revoke
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x953d4d91	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x95622f41	down_timeout
++EXPORT_SYMBOL vmlinux 0x956e9f62	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0x95842b97	abort_creds
++EXPORT_SYMBOL vmlinux 0x95851e38	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x95990718	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x959cd942	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x95c28103	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0x95dbe078	__get_user_2
++EXPORT_SYMBOL vmlinux 0x960dfaf5	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0x96573b80	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x96575701	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0x967831cd	phy_attach
++EXPORT_SYMBOL vmlinux 0x9688f86f	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x96898769	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x96aee64c	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96dce98c	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0x96e213f0	of_device_is_big_endian
++EXPORT_SYMBOL vmlinux 0x96e30346	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x96f59cfa	dma_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x9719875e	__genl_register_family
++EXPORT_SYMBOL vmlinux 0x97255bdf	strlen
++EXPORT_SYMBOL vmlinux 0x97277390	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0x973078c5	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0x9732cabd	override_creds
++EXPORT_SYMBOL vmlinux 0x9741bf3c	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x976e700f	down_trylock
++EXPORT_SYMBOL vmlinux 0x9773caa7	omap_dss_get_device
++EXPORT_SYMBOL vmlinux 0x9774ef7e	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0x9778da06	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0x977cd975	bdi_init
++EXPORT_SYMBOL vmlinux 0x97884811	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x9793c93a	dispc_mgr_setup
++EXPORT_SYMBOL vmlinux 0x9795a7d9	do_map_probe
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x979c4190	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0x97b7e090	simple_readpage
++EXPORT_SYMBOL vmlinux 0x97bcf43b	param_set_bool
++EXPORT_SYMBOL vmlinux 0x981631a9	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x9820b644	warn_slowpath_fmt_taint
++EXPORT_SYMBOL vmlinux 0x982dcc15	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x983c396b	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0x986c5b3e	nla_append
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x987c11c7	__pv_phys_pfn_offset
++EXPORT_SYMBOL vmlinux 0x9880b465	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x988996ad	dcb_getapp
++EXPORT_SYMBOL vmlinux 0x98c78305	generic_setxattr
++EXPORT_SYMBOL vmlinux 0x98e68eca	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0x98e9695f	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x98f124fa	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0x990c280e	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x991d45ca	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x9924f41a	dump_emit
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x9964ca23	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x996c4d30	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x997d4c3b	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99a5bad1	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x99bb8806	memmove
++EXPORT_SYMBOL vmlinux 0x99c5e2bc	__get_page_tail
++EXPORT_SYMBOL vmlinux 0x99c6dd65	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99f58330	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a3a706d	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x9a5daa37	padata_free
++EXPORT_SYMBOL vmlinux 0x9a623142	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x9a6abdb4	dst_release
++EXPORT_SYMBOL vmlinux 0x9a8318ef	v7_coherent_kern_range
++EXPORT_SYMBOL vmlinux 0x9a8919a9	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x9a91d67d	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0x9aa3f1f9	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x9aab7d62	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0x9ad377a3	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9af4aa9f	of_get_next_parent
++EXPORT_SYMBOL vmlinux 0x9b0bc5be	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0x9b0caae8	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b42dd14	d_instantiate
++EXPORT_SYMBOL vmlinux 0x9b6305ca	sock_create
++EXPORT_SYMBOL vmlinux 0x9b64f4f4	param_ops_byte
++EXPORT_SYMBOL vmlinux 0x9b6ba228	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x9b6eb137	ksize
++EXPORT_SYMBOL vmlinux 0x9b8cc8fe	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x9b9314ed	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0x9b9885fa	of_graph_get_endpoint_by_regs
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bbe88b3	flex_array_put
++EXPORT_SYMBOL vmlinux 0x9bce482f	__release_region
++EXPORT_SYMBOL vmlinux 0x9bd318e3	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0x9bdc5875	snd_pcm_lib_writev
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9bf3534d	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0x9bfaa452	mntget
++EXPORT_SYMBOL vmlinux 0x9c09e7bf	__block_write_begin
++EXPORT_SYMBOL vmlinux 0x9c0bd51f	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0x9c0f4c90	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x9c2971a1	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0x9c3af856	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x9c6ccae0	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x9c7a82bd	md_check_recovery
++EXPORT_SYMBOL vmlinux 0x9c7f0db3	qcom_scm_set_warm_boot_addr
++EXPORT_SYMBOL vmlinux 0x9c8931f1	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0x9c91a1e4	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0x9c9659a9	__d_drop
++EXPORT_SYMBOL vmlinux 0x9c9ec2a0	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cad89e7	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x9cba3c37	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x9cd09275	copy_from_iter
++EXPORT_SYMBOL vmlinux 0x9d0034b0	omapdss_default_get_recommended_bpp
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d118ec4	__getblk_slow
++EXPORT_SYMBOL vmlinux 0x9d12dd7d	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0x9d1cba6c	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d591742	of_find_compatible_node
++EXPORT_SYMBOL vmlinux 0x9d5d7576	simple_statfs
++EXPORT_SYMBOL vmlinux 0x9d5dc2d2	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x9d669763	memcpy
++EXPORT_SYMBOL vmlinux 0x9d68d813	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x9d7750df	softnet_data
++EXPORT_SYMBOL vmlinux 0x9d820148	devm_memunmap
++EXPORT_SYMBOL vmlinux 0x9dabea92	pwmss_submodule_state_change
++EXPORT_SYMBOL vmlinux 0x9db6acd1	dm_register_target
++EXPORT_SYMBOL vmlinux 0x9dbfd48d	iget_failed
++EXPORT_SYMBOL vmlinux 0x9dc04593	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x9dd17ff9	dev_load
++EXPORT_SYMBOL vmlinux 0x9deca508	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x9dfe7307	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9dfe9cb9	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e0e2ba2	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x9e1bff9c	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x9e22097a	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x9e30c0a7	phy_device_register
++EXPORT_SYMBOL vmlinux 0x9e45a847	con_is_bound
++EXPORT_SYMBOL vmlinux 0x9e4c6330	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0x9e4cec0d	kernel_write
++EXPORT_SYMBOL vmlinux 0x9e4ec69c	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e57be50	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x9e58d0ed	dma_find_channel
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e672ff6	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x9e6c1f9a	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL vmlinux 0x9e7283f9	omap_dss_put_device
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e7a6cfd	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0x9e9e198d	phy_init_hw
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9ecbcf22	register_filesystem
++EXPORT_SYMBOL vmlinux 0x9eff9aab	dquot_commit
++EXPORT_SYMBOL vmlinux 0x9f0108cd	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x9f1994aa	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0x9f24b023	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x9f37a2d1	sk_alloc
++EXPORT_SYMBOL vmlinux 0x9f3bd1e2	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f5f21ba	do_truncate
++EXPORT_SYMBOL vmlinux 0x9f6566e2	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0x9f73b657	sk_free
++EXPORT_SYMBOL vmlinux 0x9f823cea	dispc_mgr_is_enabled
++EXPORT_SYMBOL vmlinux 0x9f8584f2	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9f9dab2c	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0x9f9ebbde	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x9fcc7921	arm_dma_ops
++EXPORT_SYMBOL vmlinux 0x9fd7cda1	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9fe36b45	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0x9fee2fa2	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x9ff7485e	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa0044066	kset_register
++EXPORT_SYMBOL vmlinux 0xa0053b54	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0xa00eb15b	ioremap_page
++EXPORT_SYMBOL vmlinux 0xa017942c	snd_timer_continue
++EXPORT_SYMBOL vmlinux 0xa017edca	km_policy_notify
++EXPORT_SYMBOL vmlinux 0xa02054b2	pci_pme_active
++EXPORT_SYMBOL vmlinux 0xa02f4a8a	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0xa04222f4	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa048a3d2	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa04b51f7	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa06df9e1	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0xa06fc3c4	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa08f6b47	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0xa0981f2b	phy_device_create
++EXPORT_SYMBOL vmlinux 0xa0a3b04e	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0xa0aae687	imx_ssi_fiq_end
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0c42041	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0ecd94f	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0xa0efead8	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa11b61a6	__blk_end_request
++EXPORT_SYMBOL vmlinux 0xa11b89d2	netdev_features_change
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa144582b	blk_rq_init
++EXPORT_SYMBOL vmlinux 0xa14b3f5d	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0xa17b7aa6	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0xa192813b	idr_for_each
++EXPORT_SYMBOL vmlinux 0xa1a05f52	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1bf21f7	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1d55e90	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xa1d9a252	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa1e82fd8	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0xa1f0ebea	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0xa1fdfe27	inode_init_once
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa220e5c6	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0xa2237f01	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0xa22c02ea	omapdss_default_get_timings
++EXPORT_SYMBOL vmlinux 0xa2646ebe	backlight_device_register
++EXPORT_SYMBOL vmlinux 0xa2672ba7	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa2872d57	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0xa2abc69b	__page_symlink
++EXPORT_SYMBOL vmlinux 0xa2c143dd	dev_change_flags
++EXPORT_SYMBOL vmlinux 0xa2e25e35	blk_start_queue
++EXPORT_SYMBOL vmlinux 0xa2e74536	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0xa2f0c4ea	ps2_end_command
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa31daa3e	seq_file_path
++EXPORT_SYMBOL vmlinux 0xa3211046	security_path_rename
++EXPORT_SYMBOL vmlinux 0xa3295a6b	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0xa33414bb	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL vmlinux 0xa33eb6a7	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0xa3430e74	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0xa348608c	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0xa35444e4	dispc_write_irqenable
++EXPORT_SYMBOL vmlinux 0xa37e78b6	flex_array_get
++EXPORT_SYMBOL vmlinux 0xa381944f	dql_reset
++EXPORT_SYMBOL vmlinux 0xa3855145	security_file_permission
++EXPORT_SYMBOL vmlinux 0xa38be088	param_get_byte
++EXPORT_SYMBOL vmlinux 0xa39a123a	fence_add_callback
++EXPORT_SYMBOL vmlinux 0xa3bdc245	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL vmlinux 0xa3f793dd	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0xa4058ce1	give_up_console
++EXPORT_SYMBOL vmlinux 0xa40b442e	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0xa414882d	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0xa4235263	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0xa43708e9	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0xa43b1297	vscnprintf
++EXPORT_SYMBOL vmlinux 0xa43b193c	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0xa441d6aa	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0xa448a5ca	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0xa4610bc6	omap_rev
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa47755af	d_invalidate
++EXPORT_SYMBOL vmlinux 0xa4867ced	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0xa48f5b09	omap_dma_set_global_params
++EXPORT_SYMBOL vmlinux 0xa4b42c55	omap_set_dma_priority
++EXPORT_SYMBOL vmlinux 0xa4bfd402	user_path_create
++EXPORT_SYMBOL vmlinux 0xa4c3cd86	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0xa4d02cfd	generic_writepages
++EXPORT_SYMBOL vmlinux 0xa4df06a0	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0xa4dfc145	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0xa4e805b6	of_platform_bus_probe
++EXPORT_SYMBOL vmlinux 0xa4eadcc9	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xa4f58891	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0xa50218cb	of_iomap
++EXPORT_SYMBOL vmlinux 0xa50f33cc	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0xa52bb79a	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0xa546275b	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0xa5504988	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa557cd69	current_in_userns
++EXPORT_SYMBOL vmlinux 0xa55a11ca	sk_wait_data
++EXPORT_SYMBOL vmlinux 0xa5897627	nand_scan_bbt
++EXPORT_SYMBOL vmlinux 0xa58fea9d	mempool_destroy
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa5a633b9	sg_last
++EXPORT_SYMBOL vmlinux 0xa5a84715	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0xa5b85f0e	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0xa5c3e4b1	vme_master_request
++EXPORT_SYMBOL vmlinux 0xa5c9f541	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0xa5cef8ad	release_resource
++EXPORT_SYMBOL vmlinux 0xa5da7243	vme_dma_request
++EXPORT_SYMBOL vmlinux 0xa617a8e8	of_find_node_by_name
++EXPORT_SYMBOL vmlinux 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL vmlinux 0xa61e4362	omap_request_dma
++EXPORT_SYMBOL vmlinux 0xa6394011	xfrm_input
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa652c0c6	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0xa652c4ef	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0xa65c23c9	put_tty_driver
++EXPORT_SYMBOL vmlinux 0xa6721f54	udp_seq_open
++EXPORT_SYMBOL vmlinux 0xa67374f0	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0xa6753cb8	of_mdio_find_bus
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa6970398	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0xa69c159c	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0xa6a49e9e	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0xa6b64150	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xa6bab23d	dqstats
++EXPORT_SYMBOL vmlinux 0xa6beccfb	simple_write_end
++EXPORT_SYMBOL vmlinux 0xa6c94ab9	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0xa6d27498	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0xa6efb998	tso_count_descs
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa71a0cbe	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0xa71e588b	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0xa7263f69	init_buffer
++EXPORT_SYMBOL vmlinux 0xa7322c47	dev_trans_start
++EXPORT_SYMBOL vmlinux 0xa73426ee	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0xa734a3e9	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa7426c94	blk_complete_request
++EXPORT_SYMBOL vmlinux 0xa75fc426	init_net
++EXPORT_SYMBOL vmlinux 0xa7645ca4	lock_fb_info
++EXPORT_SYMBOL vmlinux 0xa7800f19	kobject_del
++EXPORT_SYMBOL vmlinux 0xa7b1507e	d_lookup
++EXPORT_SYMBOL vmlinux 0xa7b63d62	pps_lookup_dev
++EXPORT_SYMBOL vmlinux 0xa7b89271	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0xa7d2ef80	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0xa7d4253d	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0xa7d97bbc	deactivate_super
++EXPORT_SYMBOL vmlinux 0xa7e0f4b2	input_event
++EXPORT_SYMBOL vmlinux 0xa7ec6806	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0xa7fa9d2d	phy_disconnect
++EXPORT_SYMBOL vmlinux 0xa7ffe272	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0xa8010795	simple_follow_link
++EXPORT_SYMBOL vmlinux 0xa82c8be9	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0xa82ee134	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa8580f5c	km_is_alive
++EXPORT_SYMBOL vmlinux 0xa869929f	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa875908a	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0xa889b2cc	dget_parent
++EXPORT_SYMBOL vmlinux 0xa8a8110c	kernel_neon_end
++EXPORT_SYMBOL vmlinux 0xa8d116bd	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0xa8d5669e	tcp_close
++EXPORT_SYMBOL vmlinux 0xa8de6c6b	snd_pcm_notify
++EXPORT_SYMBOL vmlinux 0xa8ecd62c	ac97_bus_type
++EXPORT_SYMBOL vmlinux 0xa8f137de	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa9389c1c	devm_iounmap
++EXPORT_SYMBOL vmlinux 0xa943f0b0	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0xa964dd13	gpmc_cs_request
++EXPORT_SYMBOL vmlinux 0xa9658cd3	kobject_add
++EXPORT_SYMBOL vmlinux 0xa96a2161	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9c953b3	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0xa9d2f3f7	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0xa9ecb9c9	phy_start
++EXPORT_SYMBOL vmlinux 0xa9ed908f	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0xaa051404	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0xaa287241	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0xaa321e15	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0xaa33e535	alloc_disk
++EXPORT_SYMBOL vmlinux 0xaa4818b5	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0xaa6901ac	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa95940f	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0xaab9e6ef	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0xaac51217	flush_kernel_dcache_page
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaae2e8d1	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0xaaeb8be8	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab00ca77	generic_readlink
++EXPORT_SYMBOL vmlinux 0xab15c91d	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0xab1f50d8	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0xab21a6ed	dss_mgr_register_framedone_handler
++EXPORT_SYMBOL vmlinux 0xab3e0ac2	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0xab4acf23	prepare_creds
++EXPORT_SYMBOL vmlinux 0xab600421	probe_irq_off
++EXPORT_SYMBOL vmlinux 0xab64cc15	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0xab694444	bsearch
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab7603e7	imx_ssi_fiq_start
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab978d8e	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0xab983f6b	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0xaba3ad0c	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xabb69347	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0xabc86cb4	vme_bus_num
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabcd7d27	netif_skb_features
++EXPORT_SYMBOL vmlinux 0xabdd6463	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xabe44430	sock_create_lite
++EXPORT_SYMBOL vmlinux 0xabf3d41d	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0xabfcb4c3	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac3498a3	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0xac390091	dev_base_lock
++EXPORT_SYMBOL vmlinux 0xac398912	flex_array_clear
++EXPORT_SYMBOL vmlinux 0xac41c428	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL vmlinux 0xac463bea	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0xac48ac97	tegra_powergate_remove_clamping
++EXPORT_SYMBOL vmlinux 0xac59b05d	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0xac59fdf3	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0xac811df3	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0xac937a86	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacbc52bf	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacceabd0	register_netdev
++EXPORT_SYMBOL vmlinux 0xacd474bd	irq_to_desc
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xacdbfaf0	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xace0a728	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xacee04f6	arp_tbl
++EXPORT_SYMBOL vmlinux 0xacefffb9	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xacfc834f	write_cache_pages
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad099d7f	shdma_cleanup
++EXPORT_SYMBOL vmlinux 0xad0dc098	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0xad442aaa	snd_device_free
++EXPORT_SYMBOL vmlinux 0xad57adb9	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xadb047e6	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0xadd01b63	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0xadd0539a	skb_pad
++EXPORT_SYMBOL vmlinux 0xadd0dfa1	generic_fillattr
++EXPORT_SYMBOL vmlinux 0xade88e76	snd_malloc_pages
++EXPORT_SYMBOL vmlinux 0xadf42bd5	__request_region
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xae003b54	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xae11f147	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0xae2d3f25	tc6393xb_lcd_mode
++EXPORT_SYMBOL vmlinux 0xae31613f	scsi_register
++EXPORT_SYMBOL vmlinux 0xae711fea	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xae77a595	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0xae7f7eb0	input_unregister_device
++EXPORT_SYMBOL vmlinux 0xae85a27e	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0xaea65429	kill_bdev
++EXPORT_SYMBOL vmlinux 0xaebc5627	pci_dev_get
++EXPORT_SYMBOL vmlinux 0xaebd6f41	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0xaec655c7	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0xaed56a27	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0xaee8e8d8	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL vmlinux 0xaf08f65c	snd_card_file_add
++EXPORT_SYMBOL vmlinux 0xaf2cf7a5	scsi_init_io
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf42ee5a	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0xaf4c71bd	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0xaf50e76d	elf_set_personality
++EXPORT_SYMBOL vmlinux 0xaf654f8b	i2c_release_client
++EXPORT_SYMBOL vmlinux 0xaf7c8367	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0xaf84865e	__get_user_8
++EXPORT_SYMBOL vmlinux 0xaf85e2dd	key_alloc
++EXPORT_SYMBOL vmlinux 0xaf8aa518	system_rev
++EXPORT_SYMBOL vmlinux 0xaf8ee9a7	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0xaf968209	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0xaf9ea96e	netif_device_attach
++EXPORT_SYMBOL vmlinux 0xafb7d40a	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0xafd5bfc4	init_special_inode
++EXPORT_SYMBOL vmlinux 0xb01ae7fc	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0xb01fe737	set_binfmt
++EXPORT_SYMBOL vmlinux 0xb04cf0fe	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0xb04e5777	fb_blank
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb066b530	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0xb081b9c3	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0xb08d4b23	dev_driver_string
++EXPORT_SYMBOL vmlinux 0xb0913303	elm_decode_bch_error_page
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0a9bbe4	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0c1d258	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0xb0d2aa8d	done_path_create
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0ffdc83	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0xb11badff	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0xb121390a	probe_irq_on
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb135e1ad	blk_register_region
++EXPORT_SYMBOL vmlinux 0xb1366e3d	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0xb146dcf8	ppp_input
++EXPORT_SYMBOL vmlinux 0xb15c988b	skb_split
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb18c2aad	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0xb1a53107	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0xb1ad28e0	__gnu_mcount_nc
++EXPORT_SYMBOL vmlinux 0xb1af49a6	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0xb1b14981	seq_dentry
++EXPORT_SYMBOL vmlinux 0xb1bb20b6	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1c9da0d	pid_task
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1d9aabd	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xb1eb0200	vfs_write
++EXPORT_SYMBOL vmlinux 0xb1fab95d	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0xb1fca84f	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0xb1ff923a	get_task_io_context
++EXPORT_SYMBOL vmlinux 0xb20bf6a0	kernel_accept
++EXPORT_SYMBOL vmlinux 0xb225e81b	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0xb2309274	genphy_config_init
++EXPORT_SYMBOL vmlinux 0xb261d4c0	security_path_link
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb29b6ef8	nf_log_unset
++EXPORT_SYMBOL vmlinux 0xb2a2b815	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0xb2b8274b	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xb2b943fc	skb_seq_read
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2c54197	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0xb2d48a2e	queue_work_on
++EXPORT_SYMBOL vmlinux 0xb2d76623	serio_interrupt
++EXPORT_SYMBOL vmlinux 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL vmlinux 0xb2ee3e91	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0xb2fa3dbf	nf_log_packet
++EXPORT_SYMBOL vmlinux 0xb324b742	get_disk
++EXPORT_SYMBOL vmlinux 0xb32d7b7e	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0xb367c984	mxc_set_irq_fiq
++EXPORT_SYMBOL vmlinux 0xb370f83d	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0xb37c6cf6	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0xb382a45a	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0xb397509f	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0xb3b3d720	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0xb3bb6744	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0xb3c4dd1f	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xb3c8bafc	fd_install
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3de5cce	dev_notice
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb41b8e19	bio_copy_data
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb428735c	param_get_int
++EXPORT_SYMBOL vmlinux 0xb4390f9a	mcount
++EXPORT_SYMBOL vmlinux 0xb4392fbf	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0xb43ae786	of_find_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0xb4519a8f	string_escape_mem
++EXPORT_SYMBOL vmlinux 0xb455768c	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0xb459468a	tty_kref_put
++EXPORT_SYMBOL vmlinux 0xb4608945	fasync_helper
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb47aa088	nand_bch_calculate_ecc
++EXPORT_SYMBOL vmlinux 0xb483395a	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0xb491d4af	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0xb4a807ef	skb_unlink
++EXPORT_SYMBOL vmlinux 0xb4b160e7	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL vmlinux 0xb4c240bf	__alloc_skb
++EXPORT_SYMBOL vmlinux 0xb4c328fa	flush_old_exec
++EXPORT_SYMBOL vmlinux 0xb4c6d967	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0xb4c8bb01	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0xb4e02242	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0xb4f141a2	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0xb4fe8b6f	d_tmpfile
++EXPORT_SYMBOL vmlinux 0xb5198b77	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0xb55a988b	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0xb55d902d	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xb5684e29	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb576c393	htc_egpio_get_wakeup_irq
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5a4bca1	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5aabef1	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0xb5abc219	of_find_i2c_device_by_node
++EXPORT_SYMBOL vmlinux 0xb5b14a20	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0xb5c00014	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb5d9454c	printk_emit
++EXPORT_SYMBOL vmlinux 0xb5d9fcba	pci_find_bus
++EXPORT_SYMBOL vmlinux 0xb5df11f4	pcibios_fixup_bus
++EXPORT_SYMBOL vmlinux 0xb5e548be	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0xb60ef030	invalidate_partition
++EXPORT_SYMBOL vmlinux 0xb62db46a	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0xb630b45a	netlink_ack
++EXPORT_SYMBOL vmlinux 0xb65e8cd8	unregister_nls
++EXPORT_SYMBOL vmlinux 0xb665368a	__ps2_command
++EXPORT_SYMBOL vmlinux 0xb6682fa4	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0xb675c645	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb6896671	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6a7175f	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0xb6ab239e	audit_log_start
++EXPORT_SYMBOL vmlinux 0xb6cae182	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0xb6d3daf1	qcom_scm_hdcp_req
++EXPORT_SYMBOL vmlinux 0xb6f78efb	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0xb714690b	drop_super
++EXPORT_SYMBOL vmlinux 0xb72da20e	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0xb73d9ec1	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb755a959	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL vmlinux 0xb7706a95	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb7823e2f	dispc_ovl_setup
++EXPORT_SYMBOL vmlinux 0xb782b951	lookup_bdev
++EXPORT_SYMBOL vmlinux 0xb78715c0	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0xb78f634d	dm_get_device
++EXPORT_SYMBOL vmlinux 0xb79eb569	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0xb79ec15d	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0xb7a6a0c5	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0xb7ba76c7	__aeabi_unwind_cpp_pr2
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7d0e97c	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0xb7d69da9	km_report
++EXPORT_SYMBOL vmlinux 0xb7fd9bd6	bio_put
++EXPORT_SYMBOL vmlinux 0xb8049542	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0xb817261c	register_framebuffer
++EXPORT_SYMBOL vmlinux 0xb81960ca	snprintf
++EXPORT_SYMBOL vmlinux 0xb83bd831	fb_get_mode
++EXPORT_SYMBOL vmlinux 0xb8452652	register_key_type
++EXPORT_SYMBOL vmlinux 0xb866ad9e	vme_irq_request
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb87831cb	neigh_table_init
++EXPORT_SYMBOL vmlinux 0xb8821c8a	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0xb8ce945a	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0xb8d23d80	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0xb8dd818e	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0xb8e877e7	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xb8e997f3	input_set_keycode
++EXPORT_SYMBOL vmlinux 0xb9019edd	cros_ec_prepare_tx
++EXPORT_SYMBOL vmlinux 0xb911cc46	snd_card_set_id
++EXPORT_SYMBOL vmlinux 0xb9154302	snd_pcm_lib_write
++EXPORT_SYMBOL vmlinux 0xb928869e	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0xb92f75c6	dquot_get_state
++EXPORT_SYMBOL vmlinux 0xb95f98d6	_memset_io
++EXPORT_SYMBOL vmlinux 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL vmlinux 0xb9673264	del_gendisk
++EXPORT_SYMBOL vmlinux 0xb97c2367	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0xb991d4ce	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0xb9937199	tcf_register_action
++EXPORT_SYMBOL vmlinux 0xb99984d4	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xb9a8f03b	omap_stop_dma
++EXPORT_SYMBOL vmlinux 0xb9acd3d9	__put_user_2
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xb9f640e5	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0xb9fddcdd	bdev_read_only
++EXPORT_SYMBOL vmlinux 0xba1e07a4	inet_listen
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba4ae097	enable_fiq
++EXPORT_SYMBOL vmlinux 0xba5157c1	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0xba52abc5	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0xba6590d4	find_get_entry
++EXPORT_SYMBOL vmlinux 0xba759401	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xba75a209	module_put
++EXPORT_SYMBOL vmlinux 0xba7d870a	__mxc_cpu_type
++EXPORT_SYMBOL vmlinux 0xbabe3a6d	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xbac3cbf2	ns_to_timespec64
++EXPORT_SYMBOL vmlinux 0xbad1b179	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0xbad52e8a	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0xbaf6cb54	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0xbaf97c32	rtnl_notify
++EXPORT_SYMBOL vmlinux 0xbafa13a2	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0xbafeee36	dispc_runtime_get
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb05ee31	snd_card_disconnect
++EXPORT_SYMBOL vmlinux 0xbb147ff1	seq_puts
++EXPORT_SYMBOL vmlinux 0xbb2b4455	shdma_chan_filter
++EXPORT_SYMBOL vmlinux 0xbb2d479d	freeze_super
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb4c9200	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0xbb4e54a0	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb5fc294	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0xbb660627	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0xbb72d4fe	__put_user_1
++EXPORT_SYMBOL vmlinux 0xbb881aaf	dev_activate
++EXPORT_SYMBOL vmlinux 0xbb8dd5ac	tegra_io_rail_power_on
++EXPORT_SYMBOL vmlinux 0xbb8e3888	register_md_personality
++EXPORT_SYMBOL vmlinux 0xbb92c7ed	set_page_dirty
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbbb834f8	unregister_netdev
++EXPORT_SYMBOL vmlinux 0xbbc59506	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0xbbc65e04	amba_driver_unregister
++EXPORT_SYMBOL vmlinux 0xbbd09580	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0xbbd1fba0	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0xbc10dd97	__put_user_4
++EXPORT_SYMBOL vmlinux 0xbc16623c	mdiobus_write
++EXPORT_SYMBOL vmlinux 0xbc18b052	flush_signals
++EXPORT_SYMBOL vmlinux 0xbc30f692	ptp_find_pin
++EXPORT_SYMBOL vmlinux 0xbc358241	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0xbc42be1c	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0xbc6329b0	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0xbc6d507e	ptp_clock_unregister
++EXPORT_SYMBOL vmlinux 0xbc7f8b39	tty_port_close
++EXPORT_SYMBOL vmlinux 0xbc883a1a	serio_open
++EXPORT_SYMBOL vmlinux 0xbc907085	dquot_drop
++EXPORT_SYMBOL vmlinux 0xbca3cb6a	phy_detach
++EXPORT_SYMBOL vmlinux 0xbca863f6	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xbca9b335	snd_pcm_suspend
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcc5be1c	md_write_end
++EXPORT_SYMBOL vmlinux 0xbd0273a5	simple_dname
++EXPORT_SYMBOL vmlinux 0xbd02ed4d	dss_install_mgr_ops
++EXPORT_SYMBOL vmlinux 0xbd0d78f8	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xbd17c6de	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0xbd2c9467	inode_change_ok
++EXPORT_SYMBOL vmlinux 0xbd64bb1d	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0xbd798e4f	twl6040_power
++EXPORT_SYMBOL vmlinux 0xbd8bbd52	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbd9f66cb	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0xbd9f7f04	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0xbda45ad5	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0xbda8eb62	path_get
++EXPORT_SYMBOL vmlinux 0xbdab3cb8	kill_anon_super
++EXPORT_SYMBOL vmlinux 0xbdbb4cb4	add_disk
++EXPORT_SYMBOL vmlinux 0xbdc4f9d7	pci_release_regions
++EXPORT_SYMBOL vmlinux 0xbdce054e	console_stop
++EXPORT_SYMBOL vmlinux 0xbdcfbd2c	devm_clk_put
++EXPORT_SYMBOL vmlinux 0xbddf0c39	netlink_set_err
++EXPORT_SYMBOL vmlinux 0xbde60e3c	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0xbdec4d08	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0xbdedb6b2	irq_stat
++EXPORT_SYMBOL vmlinux 0xbe0e5118	nla_memcmp
++EXPORT_SYMBOL vmlinux 0xbe10713e	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0xbe1a0592	icmp_send
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe3e0f99	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0xbe63ee40	request_resource
++EXPORT_SYMBOL vmlinux 0xbe7545df	kobject_init
++EXPORT_SYMBOL vmlinux 0xbe8860a8	dispc_mgr_go_busy
++EXPORT_SYMBOL vmlinux 0xbe8fb90c	dispc_mgr_get_framedone_irq
++EXPORT_SYMBOL vmlinux 0xbea6343d	tty_check_change
++EXPORT_SYMBOL vmlinux 0xbebf665f	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0xbee8c114	nf_reinject
++EXPORT_SYMBOL vmlinux 0xbee90f2f	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0xbeed92cc	redraw_screen
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf077e6f	lease_modify
++EXPORT_SYMBOL vmlinux 0xbf091150	page_symlink
++EXPORT_SYMBOL vmlinux 0xbf0c06d0	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0xbf0e50f1	phys_mem_access_prot
++EXPORT_SYMBOL vmlinux 0xbf24bca3	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0xbf2930e1	bdgrab
++EXPORT_SYMBOL vmlinux 0xbf2a093a	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0xbf2c6753	skb_tx_error
++EXPORT_SYMBOL vmlinux 0xbf3146d9	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0xbf32664f	generic_show_options
++EXPORT_SYMBOL vmlinux 0xbf3b8675	snd_ctl_make_virtual_master
++EXPORT_SYMBOL vmlinux 0xbf41ae4e	snd_timer_new
++EXPORT_SYMBOL vmlinux 0xbf436225	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0xbf486982	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xbf58afd7	vfs_unlink
++EXPORT_SYMBOL vmlinux 0xbf75ea6c	tegra114_clock_tune_cpu_trimmers_low
++EXPORT_SYMBOL vmlinux 0xbf781872	param_get_bool
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf865a65	phy_print_status
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfb89b6e	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0xbfc04219	set_security_override
++EXPORT_SYMBOL vmlinux 0xbfcbc0d2	stmp_reset_block
++EXPORT_SYMBOL vmlinux 0xbfd4be63	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xbff3826c	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0xc003bad4	release_sock
++EXPORT_SYMBOL vmlinux 0xc0056be5	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0xc006af6c	of_get_cpu_node
++EXPORT_SYMBOL vmlinux 0xc00955ae	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0xc05119fe	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xc066ac8c	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0xc068440e	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0xc06dc98b	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc08a945a	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0xc08f68ce	tty_name
++EXPORT_SYMBOL vmlinux 0xc092b2fc	pci_disable_device
++EXPORT_SYMBOL vmlinux 0xc0a6a8c5	omap_set_dma_dest_burst_mode
++EXPORT_SYMBOL vmlinux 0xc0a98385	profile_pc
++EXPORT_SYMBOL vmlinux 0xc0aa518f	inode_init_owner
++EXPORT_SYMBOL vmlinux 0xc0bc1cce	put_io_context
++EXPORT_SYMBOL vmlinux 0xc0bfd55d	tty_write_room
++EXPORT_SYMBOL vmlinux 0xc0c92537	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0xc0cf95f9	omap_vrfb_request_ctx
++EXPORT_SYMBOL vmlinux 0xc0dd6a66	register_netdevice
++EXPORT_SYMBOL vmlinux 0xc0fa0ba9	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0xc1005774	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0xc10e84b4	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0xc1134af5	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0xc117b70a	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0xc11d8093	iov_shorten
++EXPORT_SYMBOL vmlinux 0xc135b4ca	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0xc1497d05	read_code
++EXPORT_SYMBOL vmlinux 0xc14cdbb7	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0xc1648730	copy_to_iter
++EXPORT_SYMBOL vmlinux 0xc16e3610	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0xc179a596	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0xc18cfc9f	get_user_pages
++EXPORT_SYMBOL vmlinux 0xc1af8f3b	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0xc1ca91c4	thaw_bdev
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1da847c	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc1eda0e8	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0xc21c0d4f	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0xc22f6a0a	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0xc257223c	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0xc260c965	d_delete
++EXPORT_SYMBOL vmlinux 0xc268e984	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0xc269c871	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0xc27100d3	get_super_thawed
++EXPORT_SYMBOL vmlinux 0xc27dc208	dquot_destroy
++EXPORT_SYMBOL vmlinux 0xc2a050d8	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2a81c5f	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0xc2acc033	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xc2d711e1	krealloc
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc3091ba3	snd_ctl_new1
++EXPORT_SYMBOL vmlinux 0xc31753c3	tegra_powergate_power_off
++EXPORT_SYMBOL vmlinux 0xc32f1aa8	user_revoke
++EXPORT_SYMBOL vmlinux 0xc342f064	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0xc345d866	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0xc359fb65	abort
++EXPORT_SYMBOL vmlinux 0xc3729df2	block_write_full_page
++EXPORT_SYMBOL vmlinux 0xc37a0e46	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0xc3834de5	free_task
++EXPORT_SYMBOL vmlinux 0xc38e8257	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0xc394be34	netdev_change_features
++EXPORT_SYMBOL vmlinux 0xc39fb0d5	snd_pcm_hw_refine
++EXPORT_SYMBOL vmlinux 0xc3a2df3c	get_cached_acl
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3ecd584	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0xc3fe5659	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0xc40355df	elv_rb_find
++EXPORT_SYMBOL vmlinux 0xc41b7517	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0xc41f0516	node_states
++EXPORT_SYMBOL vmlinux 0xc42a9167	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0xc43f4289	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0xc447bd4f	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0xc45e760a	register_mtd_chip_driver
++EXPORT_SYMBOL vmlinux 0xc47c929c	of_dev_get
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4bb1d50	nand_bch_correct_data
++EXPORT_SYMBOL vmlinux 0xc4bbef6b	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0xc4e20fb4	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0xc5004107	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0xc5036a73	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0xc505afcf	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0xc506b53f	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0xc52da066	omap_set_dma_dest_params
++EXPORT_SYMBOL vmlinux 0xc552fa70	scsi_host_get
++EXPORT_SYMBOL vmlinux 0xc5718627	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0xc57b3171	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0xc5883313	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0xc58e0d42	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc5afd323	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0xc5c140ca	__devm_request_region
++EXPORT_SYMBOL vmlinux 0xc5d38946	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc620de8b	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc632da03	sk_capable
++EXPORT_SYMBOL vmlinux 0xc6463aca	release_firmware
++EXPORT_SYMBOL vmlinux 0xc64a26d9	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc64c41f1	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0xc65537d0	memremap
++EXPORT_SYMBOL vmlinux 0xc6699e01	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0xc66bd448	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0xc66fa6a6	ida_remove
++EXPORT_SYMBOL vmlinux 0xc672f6b8	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc67fb289	param_set_ullong
++EXPORT_SYMBOL vmlinux 0xc683b095	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0xc688d45e	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0xc68b070f	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0xc6938686	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xc6a94fdb	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6d37f29	submit_bh
++EXPORT_SYMBOL vmlinux 0xc6de77b4	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0xc6fb06af	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0xc7106199	input_free_device
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc72d22f1	d_splice_alias
++EXPORT_SYMBOL vmlinux 0xc74818b3	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0xc751e76a	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc77721a1	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc782b32d	param_ops_int
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a06332	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7ab4086	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xc7bcbc8d	add_wait_queue
++EXPORT_SYMBOL vmlinux 0xc7bf32b9	kmap_high
++EXPORT_SYMBOL vmlinux 0xc7ec6c27	strspn
++EXPORT_SYMBOL vmlinux 0xc8339e24	string_unescape
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc845bf40	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0xc846e05f	dma_pool_create
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc85384de	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0xc859aae8	sock_efree
++EXPORT_SYMBOL vmlinux 0xc8681dad	find_lock_entry
++EXPORT_SYMBOL vmlinux 0xc8687783	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0xc870ea76	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc89bb0c1	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0xc89fd7a2	get_empty_filp
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8b252d1	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8e2fe78	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0xc8e4f8d4	seq_release_private
++EXPORT_SYMBOL vmlinux 0xc900da7b	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc91bb3a1	bio_chain
++EXPORT_SYMBOL vmlinux 0xc91c6fbe	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0xc92b399f	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0xc9361e11	scsi_device_get
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc977759b	simple_rename
++EXPORT_SYMBOL vmlinux 0xc9973fba	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc9aaa9a5	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0xc9b8c308	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0xc9e60d55	omap_dss_find_device
++EXPORT_SYMBOL vmlinux 0xc9f857f5	snd_pcm_hw_rule_add
++EXPORT_SYMBOL vmlinux 0xc9f8891c	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca11ca1b	omapdss_register_output
++EXPORT_SYMBOL vmlinux 0xca3cfd3c	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0xca3e839c	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0xca410eb7	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0xca41eaa3	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0xca5d7cd4	input_register_device
++EXPORT_SYMBOL vmlinux 0xca7f222f	nf_log_set
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xca9ad655	omapdss_output_set_device
++EXPORT_SYMBOL vmlinux 0xca9f713b	blk_make_request
++EXPORT_SYMBOL vmlinux 0xca9ff827	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0xcab013b0	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0xcabcfc33	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0xcad65f13	pci_release_region
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcaff2b36	set_groups
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb0cac47	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0xcb17c41e	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xcb27d74e	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0xcb466063	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0xcb4b700a	dcache_readdir
++EXPORT_SYMBOL vmlinux 0xcb7fa822	km_query
++EXPORT_SYMBOL vmlinux 0xcb8af4f2	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0xcb92e85f	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0xcbba3adb	simple_setattr
++EXPORT_SYMBOL vmlinux 0xcbbbe065	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc01d03	unregister_key_type
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbeac4be	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcbee6439	ida_simple_get
++EXPORT_SYMBOL vmlinux 0xcc01b8c3	mtd_concat_create
++EXPORT_SYMBOL vmlinux 0xcc0748f4	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc25ec98	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0xcc4ff65a	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc5393ba	make_kgid
++EXPORT_SYMBOL vmlinux 0xcc8b48f6	rwsem_wake
++EXPORT_SYMBOL vmlinux 0xcc90f88e	pci_bus_type
++EXPORT_SYMBOL vmlinux 0xccb2f14a	kobject_get
++EXPORT_SYMBOL vmlinux 0xccb74075	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccc9aab7	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0xccfef64f	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL vmlinux 0xcd091d0c	seq_escape
++EXPORT_SYMBOL vmlinux 0xcd0a4d31	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd30b95a	tmio_core_mmc_clk_div
++EXPORT_SYMBOL vmlinux 0xcd3e0f68	security_inode_permission
++EXPORT_SYMBOL vmlinux 0xcd4f3edd	sync_blockdev
++EXPORT_SYMBOL vmlinux 0xcd5747c2	inet_ioctl
++EXPORT_SYMBOL vmlinux 0xcd63c845	__aeabi_lasr
++EXPORT_SYMBOL vmlinux 0xcd646fed	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xcd6a2c2e	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0xcd6e7449	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0xcda2a1b0	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0xcdb6e8c4	cdev_alloc
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdc49e19	lockref_get
++EXPORT_SYMBOL vmlinux 0xcdca2bbd	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0xcdcde551	bio_split
++EXPORT_SYMBOL vmlinux 0xcdd0ca9c	of_find_node_opts_by_path
++EXPORT_SYMBOL vmlinux 0xcdd30409	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0xcddf2034	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0xcdf1a259	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0xcdf216ff	kthread_stop
++EXPORT_SYMBOL vmlinux 0xce0eb7f7	dst_alloc
++EXPORT_SYMBOL vmlinux 0xce1a6aab	dev_uc_del
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce30f482	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xce3ca308	copy_from_user_toio
++EXPORT_SYMBOL vmlinux 0xce3caf88	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0xce5577c2	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce665c65	snd_pcm_mmap_data
++EXPORT_SYMBOL vmlinux 0xce79a00d	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0xce9ffdca	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0xcea1647f	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xceab1abf	i2c_master_send
++EXPORT_SYMBOL vmlinux 0xceb36696	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0xcebfa15b	kernel_read
++EXPORT_SYMBOL vmlinux 0xcec0be58	param_get_uint
++EXPORT_SYMBOL vmlinux 0xcec24a86	scsi_execute
++EXPORT_SYMBOL vmlinux 0xcecfd42e	omapdss_unregister_display
++EXPORT_SYMBOL vmlinux 0xceeb0985	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0xceed7f85	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcefdc0ed	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0xcf124e9d	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0xcf169fea	kset_unregister
++EXPORT_SYMBOL vmlinux 0xcf28b41e	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0xcf608fed	brioctl_set
++EXPORT_SYMBOL vmlinux 0xcf762aec	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xcf88625f	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xcfa6bf35	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0xcfb7d94a	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0xcfd41446	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xcfd8bfae	complete_request_key
++EXPORT_SYMBOL vmlinux 0xcfdc15c8	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0xcfecef8c	omap_dss_get_output
++EXPORT_SYMBOL vmlinux 0xcfeed8d2	amba_device_unregister
++EXPORT_SYMBOL vmlinux 0xcff0a552	nf_afinfo
++EXPORT_SYMBOL vmlinux 0xcff6b676	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0xd00f3962	processor
++EXPORT_SYMBOL vmlinux 0xd01b95fb	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0xd022e8c0	snd_pcm_release_substream
++EXPORT_SYMBOL vmlinux 0xd034105f	lockref_put_return
++EXPORT_SYMBOL vmlinux 0xd04a3f4d	vfs_read
++EXPORT_SYMBOL vmlinux 0xd053ce8e	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0xd06762da	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0xd06834ca	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd07bf237	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0xd099b090	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0bd1173	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0xd0ddc169	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0xd0e67a8f	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd100acbd	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0xd1067ba7	dispc_ovl_enabled
++EXPORT_SYMBOL vmlinux 0xd1135bb3	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0xd1157735	release_and_free_resource
++EXPORT_SYMBOL vmlinux 0xd14824a7	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd1664669	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0xd169679f	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0xd17386bb	register_sound_midi
++EXPORT_SYMBOL vmlinux 0xd18151d8	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd18e7610	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0xd1920a5c	scsi_add_device
++EXPORT_SYMBOL vmlinux 0xd194a0ca	of_phy_find_device
++EXPORT_SYMBOL vmlinux 0xd196c9be	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xd1990ce0	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0xd19a7516	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0xd19cbd4b	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0xd1a69b69	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xd1ad352a	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0xd1ad8d4e	component_match_add
++EXPORT_SYMBOL vmlinux 0xd1b89c22	snd_timer_notify
++EXPORT_SYMBOL vmlinux 0xd1bd4290	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0xd1c84dfb	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xd1c8cc4f	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0xd1cbad85	md_register_thread
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1e2c93b	__breadahead
++EXPORT_SYMBOL vmlinux 0xd1e79cae	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0xd20ad406	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd25c47f1	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd25fa572	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd2907403	page_address
++EXPORT_SYMBOL vmlinux 0xd295898a	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL vmlinux 0xd2a941d4	sg_init_table
++EXPORT_SYMBOL vmlinux 0xd2af138b	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xd2b353b4	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd3078e3d	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xd31ccb06	of_machine_is_compatible
++EXPORT_SYMBOL vmlinux 0xd343c4f8	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0xd34aa966	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0xd34de401	bioset_create
++EXPORT_SYMBOL vmlinux 0xd355787f	pci_get_slot
++EXPORT_SYMBOL vmlinux 0xd36644b8	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0xd3862c56	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0xd3a26f78	mmc_free_host
++EXPORT_SYMBOL vmlinux 0xd3a9dd53	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0xd3aa83ac	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0xd3b3dcac	param_set_long
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3c2c139	param_set_invbool
++EXPORT_SYMBOL vmlinux 0xd3dbfbc4	_find_first_zero_bit_le
++EXPORT_SYMBOL vmlinux 0xd3e6f60d	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0xd3f63f1c	bdput
++EXPORT_SYMBOL vmlinux 0xd4106339	generic_read_dir
++EXPORT_SYMBOL vmlinux 0xd41298a8	key_invalidate
++EXPORT_SYMBOL vmlinux 0xd418e1c0	adjust_resource
++EXPORT_SYMBOL vmlinux 0xd41b76d7	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0xd42eaa42	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0xd44763f3	seq_putc
++EXPORT_SYMBOL vmlinux 0xd45dda80	kill_pid
++EXPORT_SYMBOL vmlinux 0xd4669fad	complete
++EXPORT_SYMBOL vmlinux 0xd46b16a6	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0xd46f2fd4	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0xd488d8c1	of_device_is_available
++EXPORT_SYMBOL vmlinux 0xd49a7cd8	misc_register
++EXPORT_SYMBOL vmlinux 0xd4a8d164	elv_rb_del
++EXPORT_SYMBOL vmlinux 0xd4b31f50	bioset_free
++EXPORT_SYMBOL vmlinux 0xd4bd3b57	nvm_register_target
++EXPORT_SYMBOL vmlinux 0xd4c89ef1	ptp_clock_register
++EXPORT_SYMBOL vmlinux 0xd4c94205	get_phy_device
++EXPORT_SYMBOL vmlinux 0xd4fdfe60	blk_end_request
++EXPORT_SYMBOL vmlinux 0xd515394a	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0xd5476254	current_fs_time
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd572aa5d	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0xd57d9368	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0xd581a24b	set_device_ro
++EXPORT_SYMBOL vmlinux 0xd58761d3	iget_locked
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd59f5aa8	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0xd5a193d3	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0xd5b1d616	dma_release_from_coherent
++EXPORT_SYMBOL vmlinux 0xd5c4ffc3	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0xd5d2c29c	of_get_mac_address
++EXPORT_SYMBOL vmlinux 0xd5f3f31f	cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0xd5f52d4f	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0xd5f58b39	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0xd6054905	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0xd6083318	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0xd61347c6	register_sysctl
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd626702d	input_register_handle
++EXPORT_SYMBOL vmlinux 0xd627480b	strncat
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd63a05bb	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0xd640e2f7	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd66a22f1	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd68f1138	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0xd696212b	mmc_request_done
++EXPORT_SYMBOL vmlinux 0xd6cbce30	serio_close
++EXPORT_SYMBOL vmlinux 0xd6cdc71d	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0xd6e6a4b6	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd71af494	pipe_lock
++EXPORT_SYMBOL vmlinux 0xd74289f9	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0xd74ca8fe	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd797b9a5	vme_master_write
++EXPORT_SYMBOL vmlinux 0xd7b11dec	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0xd7bbd729	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0xd7c39b18	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0xd7c4edab	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0xd7daab18	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0xd7dfb244	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd7fad685	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0xd81a9727	led_blink_set
++EXPORT_SYMBOL vmlinux 0xd85cd67e	__wake_up
++EXPORT_SYMBOL vmlinux 0xd87612b0	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0xd8775014	end_page_writeback
++EXPORT_SYMBOL vmlinux 0xd8a81407	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8b07f08	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0xd8bb8f85	sock_from_file
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd8f96006	passthru_features_check
++EXPORT_SYMBOL vmlinux 0xd9070acb	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0xd91d7315	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0xd94ae173	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0xd951b1db	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0xd955d2b7	omap_set_dma_dest_data_pack
++EXPORT_SYMBOL vmlinux 0xd961e284	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xd96cf471	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0xd978c6a0	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0xd97edd47	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0xd9817728	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd98cd291	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xd98f3b7a	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0xd9a45c73	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0xd9ba8f1a	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0xd9ce8f0c	strnlen
++EXPORT_SYMBOL vmlinux 0xd9d8dd71	d_rehash
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9dace0f	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0xd9ea02b0	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0xd9ec26d4	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0xd9ff002d	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0xda032f46	ip6_xmit
++EXPORT_SYMBOL vmlinux 0xda05cebc	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0xda1167b0	filp_close
++EXPORT_SYMBOL vmlinux 0xda15a6a5	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0xda1e3685	param_set_byte
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda492afc	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0xda61f453	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0xda644845	sock_no_listen
++EXPORT_SYMBOL vmlinux 0xda65ef30	inet_frag_find
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda92eeaf	setup_new_exec
++EXPORT_SYMBOL vmlinux 0xda9b4f6a	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0xdaa57ec3	totalhigh_pages
++EXPORT_SYMBOL vmlinux 0xdaa5cebf	input_inject_event
++EXPORT_SYMBOL vmlinux 0xdaabd8ad	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0xdaafc807	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdad97f94	__raw_writesw
++EXPORT_SYMBOL vmlinux 0xdb02fc81	snd_card_free_when_closed
++EXPORT_SYMBOL vmlinux 0xdb0e969b	backlight_force_update
++EXPORT_SYMBOL vmlinux 0xdb4292e4	omap_set_dma_params
++EXPORT_SYMBOL vmlinux 0xdb562b27	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb7305a1	__stack_chk_fail
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb8faed3	md_integrity_register
++EXPORT_SYMBOL vmlinux 0xdb93b838	dispc_free_irq
++EXPORT_SYMBOL vmlinux 0xdb940d24	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0xdbb46c0b	free_buffer_head
++EXPORT_SYMBOL vmlinux 0xdbcce0c8	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0xdbd783d8	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0xdbe89a02	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0xdbf8a8fe	pcim_iomap
++EXPORT_SYMBOL vmlinux 0xdc02757f	snd_jack_set_key
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc14ab78	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc1e955c	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0xdc2c7a84	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0xdc38816d	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdc5c6297	videomode_to_omap_video_timings
++EXPORT_SYMBOL vmlinux 0xdc6928aa	of_phy_is_fixed_link
++EXPORT_SYMBOL vmlinux 0xdc6f65db	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0xdc834296	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0xdc8372a0	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL vmlinux 0xdc942659	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xdc98986b	pci_enable_device
++EXPORT_SYMBOL vmlinux 0xdca522d2	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdcb21cab	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0xdcb66a34	get_fs_type
++EXPORT_SYMBOL vmlinux 0xdcd07c69	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xdcd45758	of_graph_parse_endpoint
++EXPORT_SYMBOL vmlinux 0xdcf7aa47	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0xdcfabdfb	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0xdd056bc2	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0xdd06e4f4	keyring_clear
++EXPORT_SYMBOL vmlinux 0xdd0a2ba2	strlcat
++EXPORT_SYMBOL vmlinux 0xdd1343d8	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0xdd226fa9	__raw_readsw
++EXPORT_SYMBOL vmlinux 0xdd24aa85	free_page_put_link
++EXPORT_SYMBOL vmlinux 0xdd25f5c8	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xdd27fa87	memchr
++EXPORT_SYMBOL vmlinux 0xdd3916ac	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xdd430415	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0xdd71311f	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0xdd724fa5	PDE_DATA
++EXPORT_SYMBOL vmlinux 0xdd729f4d	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0xdd8b28d7	scsi_unregister
++EXPORT_SYMBOL vmlinux 0xdd9a48eb	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0xddb61ab0	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0xddbce3c6	inet_release
++EXPORT_SYMBOL vmlinux 0xddbe59bc	vmap
++EXPORT_SYMBOL vmlinux 0xddd99d42	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0xddea1e1a	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xde37494b	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0xde474aaf	param_get_string
++EXPORT_SYMBOL vmlinux 0xde48c665	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde948ce2	vme_register_driver
++EXPORT_SYMBOL vmlinux 0xdeacbe7a	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0xdebfd1b6	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0xdec030e5	arm_clear_user
++EXPORT_SYMBOL vmlinux 0xdecaf078	d_alloc
++EXPORT_SYMBOL vmlinux 0xdecbb295	snd_card_file_remove
++EXPORT_SYMBOL vmlinux 0xded09bb4	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0xded49cd9	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0xdf0a9762	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0xdf15587e	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0xdf1be8a1	dquot_disable
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf2c374f	input_get_keycode
++EXPORT_SYMBOL vmlinux 0xdf3a693d	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0xdf40e72f	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf5d780d	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf6ed4a6	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0xdf767310	mmc_of_parse_voltage
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdf93b9d8	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0xdf970c2c	bdevname
++EXPORT_SYMBOL vmlinux 0xdf9dcb5c	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0xdfa065fe	nand_lock
++EXPORT_SYMBOL vmlinux 0xdfa2ec71	simple_empty
++EXPORT_SYMBOL vmlinux 0xdfb2521d	tcp_connect
++EXPORT_SYMBOL vmlinux 0xdfb79a85	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0xdfc4ae08	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xdfc81cdd	ata_print_version
++EXPORT_SYMBOL vmlinux 0xdfd91ce9	omap_type
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xe001d12f	ilookup5
++EXPORT_SYMBOL vmlinux 0xe02b557e	dst_init
++EXPORT_SYMBOL vmlinux 0xe0413f66	dquot_alloc
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe063efbd	mutex_lock
++EXPORT_SYMBOL vmlinux 0xe06c764a	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0xe0740e47	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe0926100	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0xe094ef39	sg_next
++EXPORT_SYMBOL vmlinux 0xe0952200	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0xe09e64e4	file_open_root
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0b60cc6	__pagevec_release
++EXPORT_SYMBOL vmlinux 0xe0bcf275	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0xe0bef318	icst_hz_to_vco
++EXPORT_SYMBOL vmlinux 0xe0d32f49	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0xe0e9013e	snd_register_oss_device
++EXPORT_SYMBOL vmlinux 0xe0fd7b50	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0xe112d297	pci_clear_master
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe1156e28	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xe11e1f94	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0xe127fb18	down_killable
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe1368d66	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0xe13a09eb	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0xe1639adb	igrab
++EXPORT_SYMBOL vmlinux 0xe16b87b8	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe181adbe	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0xe18812e2	blkdev_put
++EXPORT_SYMBOL vmlinux 0xe1aabe11	request_key
++EXPORT_SYMBOL vmlinux 0xe1c256cc	netdev_warn
++EXPORT_SYMBOL vmlinux 0xe1e0a281	blk_run_queue
++EXPORT_SYMBOL vmlinux 0xe1f0ab3a	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe20f3688	phy_suspend
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2c12417	sock_no_poll
++EXPORT_SYMBOL vmlinux 0xe2cc96f7	__do_once_done
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2d900b2	__netif_schedule
++EXPORT_SYMBOL vmlinux 0xe2e09482	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0xe2e8065e	memdup_user
++EXPORT_SYMBOL vmlinux 0xe2eb59a2	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe2f92042	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0xe2fae716	kmemdup
++EXPORT_SYMBOL vmlinux 0xe2fb510a	kill_fasync
++EXPORT_SYMBOL vmlinux 0xe305f0e5	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0xe308e160	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0xe334717d	tcp_poll
++EXPORT_SYMBOL vmlinux 0xe339a320	from_kprojid
++EXPORT_SYMBOL vmlinux 0xe3459755	ptp_clock_event
++EXPORT_SYMBOL vmlinux 0xe361bbbb	__bread_gfp
++EXPORT_SYMBOL vmlinux 0xe36a4a73	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0xe36b0b4c	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0xe3706e34	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0xe37d10ae	omap_dispc_unregister_isr
++EXPORT_SYMBOL vmlinux 0xe3844a18	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0xe38f1f1d	touch_buffer
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3d7c440	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL vmlinux 0xe3d8781a	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0xe3e991e8	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0xe40d7762	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0xe410dc95	set_bh_page
++EXPORT_SYMBOL vmlinux 0xe4137a76	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0xe413be4a	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0xe43014db	snd_timer_global_register
++EXPORT_SYMBOL vmlinux 0xe43274bc	proc_dointvec
++EXPORT_SYMBOL vmlinux 0xe44bc265	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0xe44cadd0	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0xe45579f3	vm_mmap
++EXPORT_SYMBOL vmlinux 0xe4701a47	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0xe47992e3	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0xe48e0858	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0xe4903ebd	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0xe4c80097	cacheid
++EXPORT_SYMBOL vmlinux 0xe4ca9376	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0xe4ccfc55	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0xe4cf1ba0	iput
++EXPORT_SYMBOL vmlinux 0xe4d4693d	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0xe4e6f7ee	seq_write
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe4f4c0ac	mpage_readpage
++EXPORT_SYMBOL vmlinux 0xe50d2635	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0xe5197b20	write_one_page
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe525c1bd	of_device_unregister
++EXPORT_SYMBOL vmlinux 0xe530e2d7	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0xe533f3c6	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0xe53823e2	dev_add_offload
++EXPORT_SYMBOL vmlinux 0xe5445af6	omap_get_dma_dst_pos
++EXPORT_SYMBOL vmlinux 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe582f13f	get_mem_type
++EXPORT_SYMBOL vmlinux 0xe5840540	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe588c552	param_set_charp
++EXPORT_SYMBOL vmlinux 0xe58dc818	put_cmsg
++EXPORT_SYMBOL vmlinux 0xe5b20e6a	sync_inode
++EXPORT_SYMBOL vmlinux 0xe5bbea8d	blk_start_request
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5ec46a3	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe6087c4e	udp_del_offload
++EXPORT_SYMBOL vmlinux 0xe634dcc3	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0xe63b304a	bio_flush_dcache_pages
++EXPORT_SYMBOL vmlinux 0xe659e75f	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0xe65bb471	__frontswap_load
++EXPORT_SYMBOL vmlinux 0xe663a465	skb_make_writable
++EXPORT_SYMBOL vmlinux 0xe66452ab	dql_init
++EXPORT_SYMBOL vmlinux 0xe66ca510	blk_queue_split
++EXPORT_SYMBOL vmlinux 0xe68773bc	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0xe691ace6	irq_set_chip
++EXPORT_SYMBOL vmlinux 0xe693a6ce	vme_get_size
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe69e1a55	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0xe69e5784	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0xe6c57aaa	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0xe6dcddeb	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0xe6ebc016	key_create_or_update
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe7075b97	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0xe707d823	__aeabi_uidiv
++EXPORT_SYMBOL vmlinux 0xe70a9854	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0xe712a4ae	vfs_writev
++EXPORT_SYMBOL vmlinux 0xe738c332	nobh_write_end
++EXPORT_SYMBOL vmlinux 0xe75cf1bf	ata_port_printk
++EXPORT_SYMBOL vmlinux 0xe78240c3	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7b6315e	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7e15910	dispc_clear_irqstatus
++EXPORT_SYMBOL vmlinux 0xe7f7d83b	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0xe80c785c	netdev_alert
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe829f603	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0xe82a0cb3	netdev_info
++EXPORT_SYMBOL vmlinux 0xe82ab440	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0xe86ec444	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe87ebdae	dev_open
++EXPORT_SYMBOL vmlinux 0xe8832df4	__devm_release_region
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8a89ce0	nand_correct_data
++EXPORT_SYMBOL vmlinux 0xe8af2b0b	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0xe8b9a3d4	mx51_revision
++EXPORT_SYMBOL vmlinux 0xe8ba46a3	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8cfce09	tegra114_clock_deassert_dfll_dvco_reset
++EXPORT_SYMBOL vmlinux 0xe8f65fc9	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0xe912da6b	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe931f8e8	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0xe93de8a7	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xe93f6042	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0xe953662d	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe95e00cf	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0xe962e674	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0xe96b1505	lro_flush_all
++EXPORT_SYMBOL vmlinux 0xe9772b62	try_to_release_page
++EXPORT_SYMBOL vmlinux 0xe98993ba	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0xe98e36be	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0xe99027cd	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0xe996e8f9	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0xe9a3c951	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xe9ad2c3c	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0xe9be808d	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0xe9ccfcd3	ioremap_cache
++EXPORT_SYMBOL vmlinux 0xe9ea0ec4	of_device_is_compatible
++EXPORT_SYMBOL vmlinux 0xe9f0a704	__brelse
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea0a706d	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0xea115ab8	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0xea1f5b88	samsung_rev
++EXPORT_SYMBOL vmlinux 0xea20eafd	of_platform_device_create
++EXPORT_SYMBOL vmlinux 0xea237412	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0xea3193af	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0xea34155b	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0xea52bde6	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0xea59f9f3	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0xea5e2c9b	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0xea6690da	cad_pid
++EXPORT_SYMBOL vmlinux 0xea682de0	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0xea787144	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0xea7987f1	key_update
++EXPORT_SYMBOL vmlinux 0xea8b4d8d	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0xeac05e89	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0xeac3933d	register_qdisc
++EXPORT_SYMBOL vmlinux 0xeaf02e3e	padata_stop
++EXPORT_SYMBOL vmlinux 0xeb03b389	__raw_readsl
++EXPORT_SYMBOL vmlinux 0xeb1b120e	omap_set_dma_write_mode
++EXPORT_SYMBOL vmlinux 0xeb1f944b	wireless_send_event
++EXPORT_SYMBOL vmlinux 0xeb304bdc	up_write
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb55a931	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xeb66dfe9	km_policy_expired
++EXPORT_SYMBOL vmlinux 0xeb8a7034	sg_miter_next
++EXPORT_SYMBOL vmlinux 0xeb92fc30	inode_init_always
++EXPORT_SYMBOL vmlinux 0xebc8e418	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0xebd18deb	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0xebe163bd	dquot_transfer
++EXPORT_SYMBOL vmlinux 0xebfdcbdf	system_serial_high
++EXPORT_SYMBOL vmlinux 0xec1aa6ef	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xec2dfe61	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0xec303199	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0xec3ac437	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec4fa3eb	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0xec509520	sync_filesystem
++EXPORT_SYMBOL vmlinux 0xec8e920c	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0xeca85d90	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0xecafbb88	ip_options_compile
++EXPORT_SYMBOL vmlinux 0xecbcb8bb	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xecbda538	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0xecbf4687	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0xecd65670	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xece86a84	__module_get
++EXPORT_SYMBOL vmlinux 0xececcd1a	loop_backing_file
++EXPORT_SYMBOL vmlinux 0xecf8a3b4	__raw_writesl
++EXPORT_SYMBOL vmlinux 0xed0bc3cb	napi_complete_done
++EXPORT_SYMBOL vmlinux 0xed0e24d7	register_console
++EXPORT_SYMBOL vmlinux 0xed11e430	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0xed246101	generic_perform_write
++EXPORT_SYMBOL vmlinux 0xed41fcae	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed7055ca	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0xed710c19	down_read_trylock
++EXPORT_SYMBOL vmlinux 0xed87acef	seq_printf
++EXPORT_SYMBOL vmlinux 0xed93f29e	__kunmap_atomic
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xeda55b40	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0xedafbd3b	security_path_mknod
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedc7f4ec	dq_data_lock
++EXPORT_SYMBOL vmlinux 0xedcdd113	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xedd9106d	__ashrdi3
++EXPORT_SYMBOL vmlinux 0xedde6907	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0xede465f0	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0xede707a5	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0xedf2590b	bdget_disk
++EXPORT_SYMBOL vmlinux 0xedf3093a	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xee1069a4	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0xee150d59	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xee17e19c	udp_add_offload
++EXPORT_SYMBOL vmlinux 0xee2bc2d0	omapdss_is_initialized
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee3496c3	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0xee3ecfa1	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0xee4a3fa3	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0xee5299d8	read_cache_page
++EXPORT_SYMBOL vmlinux 0xee52dd98	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0xee5473cc	cont_write_begin
++EXPORT_SYMBOL vmlinux 0xee715ef8	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0xee747ec8	prepare_binprm
++EXPORT_SYMBOL vmlinux 0xee895930	snd_unregister_oss_device
++EXPORT_SYMBOL vmlinux 0xee8c4ddd	of_mm_gpiochip_add
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xee9c3647	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeeb206f6	bdget
++EXPORT_SYMBOL vmlinux 0xeed3635b	proc_dostring
++EXPORT_SYMBOL vmlinux 0xeedba9cb	register_quota_format
++EXPORT_SYMBOL vmlinux 0xeee3d93a	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xeef50e3e	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0xeef9d881	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0xeefa368a	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0xef000f4e	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0xef0f3eb3	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0xef122d13	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0xef14cd3a	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0xef2a5879	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0xef2fdc4f	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0xef3829d6	snd_pcm_suspend_all
++EXPORT_SYMBOL vmlinux 0xef4de22b	of_find_node_by_phandle
++EXPORT_SYMBOL vmlinux 0xef5744d7	proc_mkdir
++EXPORT_SYMBOL vmlinux 0xef587acc	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xef668ea9	dev_addr_add
++EXPORT_SYMBOL vmlinux 0xef6ccdd3	clk_add_alias
++EXPORT_SYMBOL vmlinux 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL vmlinux 0xef8b6215	scsi_device_put
++EXPORT_SYMBOL vmlinux 0xefa7cba7	udplite_prot
++EXPORT_SYMBOL vmlinux 0xefbb25bf	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0xefc0a426	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0xefcf3143	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefd1b950	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0xefd6cf06	__aeabi_unwind_cpp_pr0
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefe64a2b	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0xefec312f	omap_get_dma_active_status
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf0253936	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0xf03cdc9a	inet_select_addr
++EXPORT_SYMBOL vmlinux 0xf03f2914	set_wb_congested
++EXPORT_SYMBOL vmlinux 0xf04343b8	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf06c303c	omap_video_timings_to_videomode
++EXPORT_SYMBOL vmlinux 0xf0801ddd	neigh_for_each
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0bc1dba	__sb_end_write
++EXPORT_SYMBOL vmlinux 0xf0d3874a	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0xf0dec3b9	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0xf0ea9b92	vfs_llseek
++EXPORT_SYMBOL vmlinux 0xf0ed2ef4	__raw_writesb
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf1379aa2	input_close_device
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf155de13	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0xf16f5c9d	register_sound_mixer
++EXPORT_SYMBOL vmlinux 0xf192f0ca	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf196ec24	mem_map
++EXPORT_SYMBOL vmlinux 0xf19e9355	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0xf1a1ed95	read_cache_pages
++EXPORT_SYMBOL vmlinux 0xf1c03fa8	inet_sendpage
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1deabf2	div64_u64
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1ea6f1c	__bswapsi2
++EXPORT_SYMBOL vmlinux 0xf1f4f296	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0xf1f590c4	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xf1f709d0	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0xf1f9a722	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0xf20522aa	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf223231b	netdev_update_features
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf26e3c62	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2a4979e	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2df9c85	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0xf2e4e7cc	file_update_time
++EXPORT_SYMBOL vmlinux 0xf2e782d9	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0xf2f01808	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0xf306bc31	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0xf309e78d	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0xf3110cb7	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf31af68d	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0xf327c8c7	udp_prot
++EXPORT_SYMBOL vmlinux 0xf328e997	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf3560fa1	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0xf3584864	elevator_change
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf389fea2	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf3bf2d1e	tegra_fuse_readl
++EXPORT_SYMBOL vmlinux 0xf3c514a0	pci_save_state
++EXPORT_SYMBOL vmlinux 0xf3d75774	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0xf3dd7cf5	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf3ee9c99	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0xf3f83d75	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0xf40019c0	tegra114_clock_tune_cpu_trimmers_init
++EXPORT_SYMBOL vmlinux 0xf40b2297	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xf40fd995	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0xf413412b	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0xf421d08f	vme_slave_request
++EXPORT_SYMBOL vmlinux 0xf436f20b	of_find_net_device_by_node
++EXPORT_SYMBOL vmlinux 0xf440a71f	set_nlink
++EXPORT_SYMBOL vmlinux 0xf473ffaf	down
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf4852eb7	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xf4855d5f	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0xf4a2d0ad	dss_mgr_enable
++EXPORT_SYMBOL vmlinux 0xf4a7fc6d	omapdss_compat_init
++EXPORT_SYMBOL vmlinux 0xf4ba566c	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4befee6	kill_litter_super
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf500dbaf	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0xf50d7adf	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0xf53a5036	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0xf53c6357	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf54c51a2	dma_pool_free
++EXPORT_SYMBOL vmlinux 0xf55fcdc8	of_translate_dma_address
++EXPORT_SYMBOL vmlinux 0xf564412a	__aeabi_ulcmp
++EXPORT_SYMBOL vmlinux 0xf5bd3b5e	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5caf94f	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xf5d1b049	map_destroy
++EXPORT_SYMBOL vmlinux 0xf5d74d60	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf5ecd873	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0xf5fed497	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0xf629b12d	security_path_chown
++EXPORT_SYMBOL vmlinux 0xf629ce8e	icmpv6_send
++EXPORT_SYMBOL vmlinux 0xf632f3fa	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf66bd6fc	stop_tty
++EXPORT_SYMBOL vmlinux 0xf67397fe	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf6834dff	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0xf6851d5f	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0xf68c76bd	sk_net_capable
++EXPORT_SYMBOL vmlinux 0xf69e76f3	dcb_setapp
++EXPORT_SYMBOL vmlinux 0xf6a41096	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0xf6a44075	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0xf6ae2d02	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0xf6b39e3b	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6bb76b4	param_get_ullong
++EXPORT_SYMBOL vmlinux 0xf6c9d666	tty_port_put
++EXPORT_SYMBOL vmlinux 0xf6caa627	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6f3cef6	omap_vrfb_setup
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf6ff68e9	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0xf7020eb1	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0xf7082253	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0xf70c9098	bdi_register
++EXPORT_SYMBOL vmlinux 0xf7163ec9	__raw_readsb
++EXPORT_SYMBOL vmlinux 0xf73aa5eb	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf75d7393	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0xf7802486	__aeabi_uidivmod
++EXPORT_SYMBOL vmlinux 0xf78b76a8	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0xf78e98d9	__lock_page
++EXPORT_SYMBOL vmlinux 0xf79cf012	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xf79d81ad	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0xf7aaeddc	ida_init
++EXPORT_SYMBOL vmlinux 0xf7bc670a	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0xf7c9b248	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0xf7cfc500	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0xf7d60001	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0xf7dc384a	consume_skb
++EXPORT_SYMBOL vmlinux 0xf7e01973	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0xf7f66a2f	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0xf805dd55	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0xf80d1319	build_skb
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf8133100	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0xf8171c98	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf84d5851	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0xf853bbca	omap_vrfb_map_angle
++EXPORT_SYMBOL vmlinux 0xf8604bad	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0xf88d7099	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL vmlinux 0xf89054c7	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0xf8a0d1c0	blk_init_tags
++EXPORT_SYMBOL vmlinux 0xf8a225c5	cpu_tlb
++EXPORT_SYMBOL vmlinux 0xf8ad5755	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0xf8b1c807	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0xf8d9e769	__napi_complete
++EXPORT_SYMBOL vmlinux 0xf8ddb82a	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf91d0d30	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0xf92ba0e6	of_clk_get
++EXPORT_SYMBOL vmlinux 0xf93144b5	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0xf9348cbc	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xf9427374	dispc_request_irq
++EXPORT_SYMBOL vmlinux 0xf96e1d1c	posix_test_lock
++EXPORT_SYMBOL vmlinux 0xf977ca2c	skb_put
++EXPORT_SYMBOL vmlinux 0xf9795f41	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0xf9863cff	register_sound_special_device
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9c97013	cdev_del
++EXPORT_SYMBOL vmlinux 0xf9dcf156	of_translate_address
++EXPORT_SYMBOL vmlinux 0xf9e73082	scnprintf
++EXPORT_SYMBOL vmlinux 0xf9eba422	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0xf9ffa4d1	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0xfa3b9f66	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0xfa42810d	of_mdiobus_register
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa6abcdc	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0xfa81071c	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xfaa23a1c	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0xfabf7b18	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0xfac68eba	arm_elf_read_implies_exec
++EXPORT_SYMBOL vmlinux 0xfac7ad34	input_reset_device
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd2e14	pgprot_user
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xfae5406c	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfaf71441	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0xfafcbe0d	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0xfb0eb2fd	of_count_phandle_with_args
++EXPORT_SYMBOL vmlinux 0xfb1860f3	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0xfb27f82e	of_find_device_by_node
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb7d9c45	__udivsi3
++EXPORT_SYMBOL vmlinux 0xfb83a915	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0xfb85f97c	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0xfb895336	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfba1df28	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0xfba29584	snd_pcm_set_ops
++EXPORT_SYMBOL vmlinux 0xfba6af36	iterate_dir
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbb3dac5	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xfbc48073	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbc73edd	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0xfbcb6290	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0xfbdc5806	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0xfbe83ac4	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbfa0a9b	dma_alloc_from_coherent
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc22aa73	vga_tryget
++EXPORT_SYMBOL vmlinux 0xfc23081d	sock_wake_async
++EXPORT_SYMBOL vmlinux 0xfc32f221	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0xfc3908f5	fence_default_wait
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc46646c	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0xfc4ce4b6	param_get_short
++EXPORT_SYMBOL vmlinux 0xfc5a7668	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0xfc65459a	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0xfc69b2d6	sound_class
++EXPORT_SYMBOL vmlinux 0xfc7338ad	msm_pinctrl_remove
++EXPORT_SYMBOL vmlinux 0xfc86bb0a	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0xfc8891bf	clkdev_add
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfceab328	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcf85bff	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfd20c0ac	dump_skip
++EXPORT_SYMBOL vmlinux 0xfd2c23a8	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0xfd2e04aa	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0xfd305341	walk_stackframe
++EXPORT_SYMBOL vmlinux 0xfd30bf8d	dqget
++EXPORT_SYMBOL vmlinux 0xfd33b5fa	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xfd5683b9	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0xfd8c5afc	release_fiq
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfd9e64e3	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL vmlinux 0xfdc2f1f8	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0xfdc75cc8	kmap_atomic
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfdfd7247	led_update_brightness
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe24fdc8	security_path_truncate
++EXPORT_SYMBOL vmlinux 0xfe259120	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0xfe2c18a2	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0xfe3a07c6	of_mdio_parse_addr
++EXPORT_SYMBOL vmlinux 0xfe40bf95	dss_feat_get_num_ovls
++EXPORT_SYMBOL vmlinux 0xfe46a88d	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe6b81a0	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0xfe76dd6e	kill_block_super
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe84a4bb	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0xfea7d3ad	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0xfebbbab1	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0xfeca7590	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfedecc15	netif_device_detach
++EXPORT_SYMBOL vmlinux 0xfeed268d	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0xff0cb473	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff1eda24	iov_iter_init
++EXPORT_SYMBOL vmlinux 0xff30161a	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL vmlinux 0xff668f9f	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0xff67b37f	__lshrdi3
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff71563c	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0xff77689d	snd_jack_new
++EXPORT_SYMBOL vmlinux 0xff7d683b	tcp_req_err
++EXPORT_SYMBOL vmlinux 0xff7e7d61	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0xff88b628	genphy_suspend
++EXPORT_SYMBOL vmlinux 0xff8cbb1f	idr_destroy
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff983a0a	write_inode_now
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffa34390	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0xffa3a4bc	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xffb94ef0	_test_and_change_bit
++EXPORT_SYMBOL vmlinux 0xffbed5f7	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0xffd2cf99	omap_dss_get_num_overlay_managers
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffd6d3fb	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0xffdb82bc	sg_free_table
++EXPORT_SYMBOL vmlinux 0xffe89cc2	netdev_notice
++EXPORT_SYMBOL_GPL arch/arm/crypto/sha1-arm 0x0a37b4d1	sha1_finup_arm
++EXPORT_SYMBOL_GPL arch/arm/crypto/sha1-arm 0x2190bf94	sha1_update_arm
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x0077478a	ablk_decrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x257e181f	__ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x61091efe	ablk_set_key
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x67fcd471	ablk_exit
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xc38137b3	ablk_init_common
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xd720b3f6	ablk_init
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xe1e5f989	ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/af_alg 0x07f35f58	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x1318d7d6	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x23262537	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x3d39bad4	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x5959672c	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0x694a87ec	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0x81487745	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0x98b7d06f	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0xd954ef95	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0xec04eee1	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0xf8e8f12f	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x6feeda84	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x99c307ff	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0xc1e7a04c	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x6a60d8b4	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x8c7afade	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x5ccb0ecf	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x745b48fa	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xcb96bef9	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xe448d48b	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x784f2ba3	async_xor
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x90868a14	async_xor_val
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x870d29cf	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x7efc9b1f	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0xc826125e	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x6fe02c75	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0xd5639578	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/cryptd 0x09806951	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x1a7a9e34	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x1f5e712a	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x48d5da9b	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x4ad0cecd	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x64476cf8	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x706db0d7	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x78137f83	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xf6151c1e	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xf8abdf15	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x0ac9d067	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x14bdd4d3	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x1e46c916	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x1e55ebf3	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x2987d02c	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x418227f0	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x50b42765	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x81f94bbf	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x8aa22596	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xa003b215	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x6bef5987	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xd283a53f	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xd398eff3	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xf4acdb27	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0xb3e082f0	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x96c16215	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0xe321454e	xts_crypt
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0x7971db77	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/ata/pata_sis 0x83736eb6	sis_info133_for_sata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x4e205dc3	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x88f07c1a	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xa9ea0a8b	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xfa8a3314	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x18a3a03d	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x2e80ba76	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3e068cd3	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x428dd8ba	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x594aa2cf	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x74559ad9	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x8172f630	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x858cb027	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x8e110b84	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x94e32b2b	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xa34e1e4c	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xab44e8e4	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb59aea68	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb9053bde	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd2187255	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd4a903b8	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd7dc59df	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd932b3a4	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdec26ca6	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdf978510	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe52f3663	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf22390ed	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xfafa7430	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xff4697f8	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x25155911	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x72312fe3	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x757a67a3	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xbc63b986	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xcdb30f97	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xfdcb3b08	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x00e66336	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x27e57ac9	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x2bc02915	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x2cf44495	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x4c7a565d	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x4cda638f	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x508087aa	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x67552d0c	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x7a9a8917	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x7fc9c6fd	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xde264d3e	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xea45ee44	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x258dc0db	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x294db0c3	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x2a865b5a	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x3eb87b22	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x51abefb2	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x726297c7	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x763577cb	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xc27d0544	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xcf2f29a4	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xdef4a837	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xdf542c0f	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x4f9e333a	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0xe87685ed	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0xf2d262b1	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0xdb0c0581	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x02373dca	clk_enable_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x0558a70f	qcom_cc_probe
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x0d76ccee	qcom_find_src_index
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x1ad28e9c	clk_rcg_bypass_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x1f4159b0	clk_byte2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x1fc82dc1	qcom_cc_really_probe
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x2bbf74c5	qcom_cc_map
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x2c4a90cc	clk_is_enabled_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x3b0b58e5	clk_regmap_mux_closest_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x53f95e39	clk_pll_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x5d9c3e35	devm_clk_register_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x612214bd	clk_edp_pixel_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x669bd1fd	qcom_find_freq
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x67ae803a	clk_rcg_pixel_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x709d9cf0	clk_pll_configure_sr
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x73964fc2	clk_dyn_rcg_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x77c457fa	qcom_reset_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x8c4dbdbe	clk_branch_simple_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x8d53d96e	clk_rcg_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x90b53166	clk_pll_configure_sr_hpm_lp
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x999e1e71	clk_branch2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x99d2c773	clk_rcg2_shared_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x9e2e91a1	clk_rcg_bypass2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xa1606e61	clk_disable_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xaace56b1	clk_rcg_esc_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xc7994798	clk_branch_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xcb0c5248	clk_byte_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xcd0a83c6	clk_rcg2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xd25fd154	clk_rcg_lcc_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xe703bcad	clk_pll_vote_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xf1f136dc	clk_pixel_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xf69c2f55	clk_pll_sr2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xf93e315f	clk_regmap_div_ops
++EXPORT_SYMBOL_GPL drivers/cpufreq/arm_big_little 0x2f7dab4b	bL_cpufreq_register
++EXPORT_SYMBOL_GPL drivers/cpufreq/arm_big_little 0xeb81b998	bL_cpufreq_unregister
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x03af05c5	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x164fb89b	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x4813e10a	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x8e7432d3	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xd751e17c	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x26e9e085	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x809a0cca	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0xdb6d4e86	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x088db24a	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0ca0b981	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x1610c0a6	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x1ea2d33e	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2df97747	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x32dd9129	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3b13c8ea	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x44627cdb	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4b6f881c	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x5440f6bb	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x5866f34d	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7a53ffd9	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7cdd67ef	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x8806293a	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x981d6601	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x9f5e339f	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa215edc3	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb89b35c2	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xba0f4152	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0775fb2	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd049bafe	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd18b8896	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xfb538130	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/firmware/arm_scpi 0xe342fbf5	get_scpi_ops
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x06d6d525	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x1feb0af0	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x380b8f7a	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xa5f10091	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xb79df05f	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xd2964c7b	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x6b3d628b	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0xa9fe6d0b	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpu/drm/bridge/dw_hdmi 0x1ad49bf7	dw_hdmi_unbind
++EXPORT_SYMBOL_GPL drivers/gpu/drm/bridge/dw_hdmi 0x8dcd6f43	dw_hdmi_set_sample_rate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/bridge/dw_hdmi 0xce27012a	dw_hdmi_audio_disable
++EXPORT_SYMBOL_GPL drivers/gpu/drm/bridge/dw_hdmi 0xd8fe547b	dw_hdmi_audio_enable
++EXPORT_SYMBOL_GPL drivers/gpu/drm/bridge/dw_hdmi 0xe1e36575	dw_hdmi_bind
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x009b36ff	drm_gem_cma_mmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x00a8c185	drm_display_mode_from_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x0cf7177e	drm_gem_cma_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x19efd665	drm_gem_cma_prime_vunmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x3b93e7cb	drm_gem_cma_vm_ops
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x42a5fbb2	drm_gem_cma_describe
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x437c21ca	drm_gem_cma_prime_vmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x4c678a87	drm_gem_cma_prime_mmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x51b2f48b	of_get_drm_display_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x5bf16048	drm_gem_cma_prime_import_sg_table
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x637a7508	drm_display_mode_to_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x6f74e8df	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x812ee64a	drm_gem_cma_dumb_create_internal
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x81b3359e	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x8823d13f	drm_gem_cma_dumb_map_offset
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x8a71312f	drm_gem_cma_free_object
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xaa2712f3	drm_gem_cma_dumb_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xadbb73c9	drm_gem_cma_prime_get_sg_table
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xfdfd69d2	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x1148b623	drm_fbdev_cma_fini
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x16ee793b	drm_fb_cma_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x20b8f0a2	drm_fb_cma_debugfs_show
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x72a4b9da	drm_fb_cma_get_gem_obj
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xa992a826	drm_fbdev_cma_init
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xb2c912af	drm_fbdev_cma_hotplug_event
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xcc337fd5	drm_fbdev_cma_restore_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x0ce51606	imx_drm_encoder_get_mux_id
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x1cfe024a	imx_drm_crtc_vblank_get
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x37707c0a	imx_drm_crtc_id
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x419b08de	imx_drm_handle_vblank
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x50328df7	imx_drm_add_crtc
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x5df7326c	imx_drm_set_bus_format_pins
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x5f056ff0	imx_drm_crtc_vblank_put
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x6ef2ebf8	imx_drm_connector_destroy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x7f2b68b8	imx_drm_set_bus_format
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0xb0dc83eb	imx_drm_encoder_parse_of
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0xc92795eb	imx_drm_encoder_destroy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0xd652b5a4	imx_drm_remove_crtc
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchip_drm_vop 0x54e634e1	rockchip_drm_crtc_mode_config
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0x2e52ec4c	rockchip_register_crtc_funcs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0x5fe09b1a	rockchip_fb_get_gem_obj
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0x6f706580	rockchip_unregister_crtc_funcs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0x8ae3cdb8	rockchip_drm_dma_detach_device
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0xab56ac29	rockchip_drm_encoder_get_mux_id
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0xf0f1fb1a	rockchip_drm_dma_attach_device
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xa3524bd5	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xc3868ba0	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xe55cf491	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x04f7075a	ipu_csi_set_mipi_datatype
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x0728116a	ipu_csi_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x0c4e46b0	ipu_cpmem_set_format_passthrough
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x0c660b0b	ipu_cpmem_dump
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x0e42bd95	ipu_csi_set_dest
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x0f67337b	ipu_ic_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x118160e1	ipu_ic_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x11d8f100	ipu_stride_to_bytes
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x13952dfe	ipu_dmfc_enable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x14a0df74	ipu_cpmem_set_yuv_interleaved
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x15ec2ba5	ipu_di_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x16811185	ipu_csi_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x199bd5c8	ipu_dp_disable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x1ba497eb	ipu_pixelformat_to_colorspace
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x1c326ddf	ipu_set_ic_src_mux
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x1e913d9f	ipu_csi_get_window
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x23575f1c	ipu_idmac_buffer_is_ready
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x2424c9a6	ipu_csi_is_interlaced
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x2f92d651	ipu_ic_task_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x2f9751b4	ipu_degrees_to_rot_mode
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x30b6999c	ipu_rot_mode_to_degrees
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3166aec7	ipu_dmfc_disable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x335b8f35	ipu_dc_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x33ddb392	ipu_dp_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x34685f96	ipu_idmac_channel_busy
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3689f4b6	ipu_cpmem_set_block_mode
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x36e56737	ipu_module_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3752dc01	ipu_cpmem_set_yuv_planar
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3837a53c	ipu_dump
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3afbb44e	ipu_smfc_set_watermark
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3d3939dd	ipu_smfc_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3e86ea72	ipu_di_get_num
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3fa23281	ipu_cpmem_interlaced_scan
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x48882368	ipu_module_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x4917f47a	ipu_ic_dump
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x4bb3354c	ipu_dc_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x4c179b49	ipu_dp_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x5117a1c4	ipu_cpmem_set_rotation
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x51475e87	ipu_dmfc_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x527f3b94	ipu_smfc_set_burstsize
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x53de277c	ipu_di_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x5510f345	ipu_cpmem_set_format_rgb
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x57043a75	ipu_dmfc_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x5ac40a48	ipu_wait_interrupt
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x5bc35f5d	ipu_cpmem_set_yuv_planar_full
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x6077579b	ipu_cpmem_set_burstsize
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x60bdf2ec	ipu_csi_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x616d1a67	ipu_srm_dp_sync_update
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x623722e2	ipu_ic_task_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x66cb879f	ipu_dc_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x67893b19	ipu_idmac_enable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x6a0f6b78	ipu_cpmem_set_buffer
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x7068e939	ipu_dc_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x7121bd07	ipu_di_init_sync_panel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x76302d14	ipu_csi_set_skip_smfc
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x76456b98	ipu_idmac_disable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x881488a3	ipu_idmac_lock_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x886c35aa	ipu_smfc_map_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x9058e289	ipu_smfc_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x951a09d5	ipu_csi_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x9540bf80	ipu_ic_task_idma_init
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x99a066d1	ipu_cpmem_zero
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x99a0ef07	ipu_drm_fourcc_to_colorspace
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x9c335d85	ipu_pixelformat_is_planar
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x9f38e177	ipu_dp_enable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa11dac73	ipu_cpmem_set_axi_id
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa3a739d2	ipu_cpmem_set_stride
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa4b0cabd	ipu_dc_disable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa54a83e5	ipu_dp_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa579616b	ipu_di_adjust_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa5dda8e7	ipu_idmac_enable_watermark
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa60b144b	ipu_csi_set_window
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa7d2b9e1	ipu_cpmem_set_high_priority
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa96882d8	ipu_ic_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xb06f2189	ipu_dp_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xb228bf1e	ipu_dp_set_global_alpha
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xb59dff86	ipu_cpmem_set_image
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xb94ca95a	ipu_dmfc_init_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xba224d42	ipu_cpmem_set_fmt
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xbd810b77	ipu_idmac_get_current_buffer
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xbeccaa39	ipu_set_csi_src_mux
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc2f55c5b	ipu_idmac_set_double_buffer
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc3c2cdb0	ipu_smfc_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc6675aa9	ipu_csi_dump
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc677177d	ipu_smfc_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc848c5d7	ipu_dmfc_free_bandwidth
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc88d89a1	ipu_mbus_code_to_colorspace
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc97e7a0f	ipu_di_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc9ea7b1e	ipu_idmac_clear_buffer
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xcd7c6998	ipu_ic_task_init
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xd064a453	ipu_ic_task_graphics_init
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xd3fac499	ipu_di_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xd5055dd9	ipu_dmfc_alloc_bandwidth
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xd5566962	ipu_idmac_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xdc19270f	ipu_idmac_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xe300a959	ipu_dp_setup_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xe3b86336	ipu_csi_init_interface
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xe6243c52	ipu_dc_enable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xe7366f27	ipu_idmac_channel_irq
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xe87dfe9f	ipu_cpmem_set_resolution
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xedce876f	ipu_idmac_wait_busy
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xf1440dc1	ipu_ic_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xf69d6cb6	ipu_csi_set_test_generator
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xf70ff764	ipu_idmac_select_buffer
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xf7c92d51	ipu_map_irq
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xf7d99d69	ipu_dc_init_sync
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xf9ed222e	ipu_dp_set_window_pos
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0aefc54a	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0c1a7be4	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0eeb9ef0	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x21995e19	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2241a9b9	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x23ee69e6	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x24d96376	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x28a6c315	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3668d550	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x368a08c4	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x458c2de8	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x47b4d606	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x49059c9e	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4ee420f3	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x57c99d0a	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x598ef64f	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x639ca7a1	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7225c4e5	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x723a04d7	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x77794b38	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7cc709f0	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x871e071b	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x956a48b1	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9bef9bf5	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9e12d07e	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xab4e3d17	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xaefce62e	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb1a255be	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb59d1744	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb8fb1078	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc59ce943	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc81e43c2	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xced35836	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe45c3227	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe6aca30d	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xff11866d	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x81b2b0b5	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x039ca87a	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x1face84f	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x578a1ad0	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xba7b8534	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xbe2a32ef	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xc89c633f	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x1a8014ba	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x29e0c937	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x5d012201	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x8f47d98a	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xa22ce8b9	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xa2d9207f	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xad8bbb27	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xf1146560	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xfeaf992d	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x5f49665e	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/clients/ssi_protocol 0x19074234	ssip_slave_start_tx
++EXPORT_SYMBOL_GPL drivers/hsi/clients/ssi_protocol 0x799f5668	ssip_slave_get_master
++EXPORT_SYMBOL_GPL drivers/hsi/clients/ssi_protocol 0x81d9332d	ssip_slave_stop_tx
++EXPORT_SYMBOL_GPL drivers/hsi/clients/ssi_protocol 0xb8e989b4	ssip_slave_running
++EXPORT_SYMBOL_GPL drivers/hsi/clients/ssi_protocol 0xe9d45811	ssip_reset_event
++EXPORT_SYMBOL_GPL drivers/hsi/controllers/omap_ssi 0x1eceb763	ssi_waketest
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x0e242963	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x1cac9337	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x290103ea	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x43faa8e4	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x49a6e424	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x6424d3fe	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x6cda50fb	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x7159c800	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x724ee213	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x971d2bc4	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa9553160	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xaab93be6	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xb9565154	hsi_add_clients_from_dt
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xbcb436c6	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe1cfaa5b	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xed92490d	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xef045298	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf739ac40	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x580ea9f9	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x888b0c55	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xe587c3fe	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x0d41ef7f	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x2837a80e	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x33686291	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x3922ed7c	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x421fd14d	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x4e5d781f	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x67998243	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x6949089a	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x73211202	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x9aa13e8b	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xa91e6ac5	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xcc0e9ce6	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xdea73186	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xe750bae5	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf6fafcb3	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x031dd6f0	hwspin_lock_request
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x06d7bb9b	hwspin_lock_unregister
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x47595bfb	hwspin_lock_free
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x61a0654a	of_hwspin_lock_get_id
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x7b8de27f	__hwspin_trylock
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x99d2df37	__hwspin_lock_timeout
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x9e450860	hwspin_lock_get_id
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x9e6a17ec	__hwspin_unlock
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0xd85bdd61	hwspin_lock_register
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0xde7b3a7b	hwspin_lock_request_specific
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x49267cd7	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x5eca8178	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x7de661a1	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xd1b27e02	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xe1d991a4	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xf8e24e79	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xfd69d134	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x1b7e031c	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x65f1772e	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xce56b703	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xee5cf51c	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xf360bc6e	stm_source_write
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x143eb067	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x29a3ff46	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x2b6d038b	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x43843c9c	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x46baa894	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x3f235ac4	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xf43e237c	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xcb76f749	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xfd17d9a5	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x09ca77cb	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x0d4e03dc	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x4ec0de01	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x1000f082	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x18044bc5	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x27c29419	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x415a3673	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x78f0c61f	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x9bfef975	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xc010e67c	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xc5d00689	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xd384925d	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xdbd31c29	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x53eb6412	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0xd88981e6	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0x0f57e2fe	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xcb2903a6	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x5117dc62	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x66e3c3a0	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xe7ae7482	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x00f2d1de	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x0dfd77df	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x106c5df5	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x2bf78da4	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x306f7544	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x66d62fca	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x85bc4833	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x87535ea3	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x917cbf7f	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xef52c2b3	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xf0b00141	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xfc6eb235	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x02576021	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x037773e8	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x05649d61	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0e40187b	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0f8bf4e1	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x1d8f3ab0	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x298a91b2	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2ddaec7d	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3512728b	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x37795ec9	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x43fdf38f	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x485e61d9	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x513eb239	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5f0218d0	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x631a60f4	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6cb018b9	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6ec3ca46	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x723818c3	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9f487b82	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa5a9c429	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xaee275b7	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb3abdd39	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb99c8787	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc4c6a5a7	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc9594071	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xccd1e3e0	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe0426fcd	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe82744a0	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xea48439f	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf5a85729	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xffc5a2eb	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0xb8f8421a	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/matrix-keymap 0x702f3d0d	matrix_keypad_parse_of_params
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x7f127fc8	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x83316f6e	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xa53b3817	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xe25596dd	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x2b489d62	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xb62dc146	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xcdd3399a	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x45322b0c	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x93fa5396	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x23008a77	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x2c5b9d92	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x6ded0a90	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xe8c862a2	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x014c80c3	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x166ce333	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x1fe388fc	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x2a136e3e	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x2eba766e	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x538ce2b4	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x6101f323	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xc778fef7	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xcc96b449	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xdac6e3ad	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xeb0ec17b	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xf42329a0	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x03308fc8	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x13e51083	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x1a668aa1	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x21b7f6c5	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x844a76d9	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x8a60fab0	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xa8ae0b1b	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xe1ec567b	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xfb69dfb4	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x1515834c	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x156086b8	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x1d5b9b69	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x2ae22109	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x2c99ad5e	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x319c304a	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x4b8cdb01	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x6e7090c8	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7a2d5337	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8eff32df	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x9525defe	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa25faf37	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa4df4100	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa866194d	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc831cc43	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xe29655db	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xf3492358	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xfb769e75	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x3a9dd8fa	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x77f4dac5	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xc7cb9433	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xcebbe806	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xd93416dc	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xfd3f0162	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x07c48264	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x1c0ded40	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x27b4eb76	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x3003345f	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x314e7102	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x3973baaf	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x4cf98d2c	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x65c4513b	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xa98a877d	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xb6dd03cd	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xe7040d27	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x0138e9df	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x0e42c27f	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x15bb7af5	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x1c5fbb95	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x30e7bd1c	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x324812b8	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x3ba6b997	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x4807711b	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x564b986b	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x729f995b	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x7e860f98	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xe1bb09c2	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xf9cca8f3	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xfa4e2073	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x06628c2f	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x06b11706	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x07e2c777	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x0b1ed8cb	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1683a5f6	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x16c3fa29	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x16c8cc13	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x18d1988c	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2061620b	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x230dd380	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x29a4c5fd	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2b277945	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3ee17aab	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x402d6200	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x49c216ec	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5d1e9f82	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7930d50e	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7d597e2d	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8461608d	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x84e60671	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x92d61794	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x9415be3c	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xad2d4ca2	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb21fadc0	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb364194a	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbe406c76	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc72008a2	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd6d1aa5e	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfc24ee1e	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfcc8ed24	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xffd8c38e	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x1ef9ee81	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x28450bcd	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x4f7ba6ca	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x68f51c3a	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6b4c6190	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x98357d00	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xa65e8f70	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xc0affdd0	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xf0eca080	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x22163b69	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x3909d3a8	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x594952bd	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x5f407401	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x62a23587	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9b2b253a	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xdc69e37a	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe004ee92	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x0f4a19e4	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x26897b1e	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x71447d66	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x7504f336	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x7dd72fbb	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x7e33bd75	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xe656317b	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x8f12b0eb	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0xe7be1d24	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x09472122	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x09521698	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x433209cb	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4af0486b	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x74442a87	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa8813ad6	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xb80eab77	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc66ce277	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xcab63c3d	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xeb76d7e2	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf37a3cfe	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x11eab9fe	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x150c85ce	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2e730a21	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x33c03da6	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x619701dc	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9b4b5b29	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa2507774	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbcfdc290	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbe0497aa	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xe6e4822e	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xead1e727	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x0d481cad	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x1b994d01	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x5bf5835e	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x7fcbbb32	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x96be054d	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xb47c0008	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xc109af83	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xc2e66803	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe0410b49	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xfe324f48	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x5afb658c	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x5e9e1dbc	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x64da3ba2	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x65f1f119	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x9246c792	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xc62407d9	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xde130c97	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x00e19834	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x11934158	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x14397043	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x366f2552	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x6210f200	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x63222b29	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74837924	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7e42feda	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x859b159e	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x8a9afc3e	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x960ca37c	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xa24a496d	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc24de903	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xcda2ae1a	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xdfb917c0	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xe3fa97f8	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xe7821fc9	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xf0f92fa3	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0x356f7d29	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0x22580082	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0x3149c313	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x089dc929	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0x0c156876	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x266a2a45	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x27ff7021	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0x287915ae	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x305096ae	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x350729eb	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x7f633bc3	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x91986c9b	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/media 0x92e427ac	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/media 0xa1dc19ff	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0xa8b99f6d	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0xb188949f	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/media 0xb766c828	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/media 0xcfcd9f08	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0xdd2b099c	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/media 0xe333f8e4	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0xf6c389a5	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0x706ddb00	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x36042833	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x4a350113	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x4f49b62e	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x5810483e	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x6314b5da	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x7093f6c0	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x71b69a39	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x72f1000b	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x74f360af	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x9c9c6df1	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xada00ae6	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb817cc0d	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xceddcdb4	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd1bdf6d0	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd5dd60bf	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd66023db	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xe645836b	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf6503fb1	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xfd5ede41	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0de76d56	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x31cfc50c	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x3414dd8c	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x42d4b36d	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x5a94f050	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x6e31f9cd	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x6fa1f0a6	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x720d1268	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x742a4624	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x7e63112b	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xb3694bca	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xb395c63d	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xb9b122cc	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xbca4f36f	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xd96b4f5a	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xdf61cc71	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe5bbcbdb	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe648b113	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xf149e2af	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x27ada091	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x3de45367	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x471e625c	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x8de1341e	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xb2e31417	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xd480e5f6	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xf0c8d6e5	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/platform/omap/omap-vout 0x085d8e48	omap_vout_try_window
++EXPORT_SYMBOL_GPL drivers/media/platform/omap/omap-vout 0x1da5563e	omap_vout_default_crop
++EXPORT_SYMBOL_GPL drivers/media/platform/omap/omap-vout 0x3739df24	omap_vout_new_window
++EXPORT_SYMBOL_GPL drivers/media/platform/omap/omap-vout 0x6db65fc8	omap_vout_new_format
++EXPORT_SYMBOL_GPL drivers/media/platform/omap/omap-vout 0xc1644e97	omap_vout_new_crop
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x0b2585ce	xvip_get_format_by_fourcc
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x1e942673	xvip_cleanup_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x3c7eb685	xvip_set_format_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x490bd11c	xvip_get_format_by_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x717dc0c3	xvip_enum_frame_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x7cc0b0f5	xvip_of_get_format
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x7f2c6851	xvip_clr_and_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xa585953d	xvip_init_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xcd6a23e1	xvip_enum_mbus_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xde7ca96b	xvip_clr_or_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x3c16a6b1	xvtc_generator_stop
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x47d7900b	xvtc_generator_start
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x6ee657a4	xvtc_of_get
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0xa8a0f912	xvtc_put
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x369d1a20	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0xa6300733	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x04fe2b0e	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x0efcb516	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x109696a3	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x16f55c67	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x200c0236	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x431bdd24	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x45a32608	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x4afe7d00	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x627c016b	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x66ea4efd	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x67ec0caa	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb00d76af	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb3ab6991	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb4796862	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc306745c	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xca9ea515	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xdc195164	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xe1d16e58	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xe2d85bb2	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0xe8aeac97	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0xbfaed7ec	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0xc019dc2c	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0xe5b5a363	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0x9f11aba7	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x98ff3d84	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x4f029ac1	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x6d42a6c1	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0xed5af7d8	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x0a865599	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0xcf022aff	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x8a45590d	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xac6d4df0	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0x3dbcb6be	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x1f3032f6	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x2bfd9848	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x41128044	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x4342cf8d	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x45d4d8d9	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x51c67901	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x59990ef3	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x5c28e855	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x783081da	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x78f62ace	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x9cc80b31	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa3d39b71	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa3fb13c1	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xaa6a438b	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xb63a3cf2	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xbae0f8a7	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xbf182ee8	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xc118812d	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe9ff5143	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xea34cfc6	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0x1d4e8390	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0xc84a780b	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x059d6b67	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x22f54c8d	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2fa3df39	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x357da072	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3becce63	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3f45485e	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x55a25fb8	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x672eaf89	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6b79411e	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9515a0ec	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xb369b335	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xbec8d26f	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xc5e05b3c	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xc7c9b67f	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xe146226a	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xe1e155c9	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xed19e1f0	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xf835cee9	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x1ca5a302	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x4ec0adab	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x6afebc6b	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x84ac555b	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x0f393cb4	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x134b6009	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x27ce4c0f	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x4de8c67b	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x92cc9250	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x9978dd96	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x56b55024	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x5fdbe954	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x00bd9642	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x096315e0	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x0c5a69bc	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1457cf0b	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1c41e5ba	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1c7a4387	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x20d26cbc	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x20fa7614	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x228630a7	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x22a6df03	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x25d688d0	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x34e96637	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6eeb6cb3	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6f1c35f7	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6f31c7a3	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x864306b7	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9d3f2c0c	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xa81704eb	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xac39ed1c	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xac717869	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xafc98f19	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb22f9ec2	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb85944c0	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xbcb198b7	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc8c02ff8	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd4270947	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf665f616	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x01c1ae17	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x07535e3b	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x120d775e	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x1817269a	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x1c1aa294	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x2653cb66	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3164bdbd	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x44a200a6	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4e60c107	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x580d65ab	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6457bd58	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x652d581b	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x81f11513	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8a928c6d	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x93163e49	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x9fb6e133	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xafa38863	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb7e84a69	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xbcbd41d8	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xda3e71d9	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf0ebf296	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf0f3ba34	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf34da319	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfbc47861	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xa249432b	videobuf_dma_contig_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xd9dba661	videobuf_to_dma_contig
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xddd09f7f	videobuf_queue_dma_contig_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x19a703ec	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x6b0b581d	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x8fe6f399	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xa825c75b	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xf9ded4b0	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x3e4c628d	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x85b8b34f	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xd5ba7eef	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x03811549	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0eaae2de	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1592ebd4	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x22e3cc31	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x27b06d26	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2a049996	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x33e8e60f	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x396600da	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7d8a2d4e	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x98e243db	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x9b077e05	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xa63c2e7f	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xa94ed890	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xad44daa6	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd51eba34	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd91fbdf6	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xdc700b8d	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf78e86ce	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x9e3acc0a	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xc8568c9a	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x6549cb63	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x73ec0c4d	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0xe568d5d5	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x08347ca3	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x08f267e6	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0a2701d2	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0a90f5e1	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0f9711b0	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1a810567	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1c0570d4	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1f603c68	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x216aade1	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x2aa81c2f	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3643a761	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3b365238	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3d8db561	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3dc72ead	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x45833c55	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x4ad28c7b	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x4df21251	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x574326cf	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5a7b282d	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5c0b19a1	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5d94a534	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x767c76e2	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa1eac830	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xac369ff0	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xbd4d0284	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc79b604f	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xd0ac1cce	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xd33953ec	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xdc33fa61	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xeb4eca26	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xebbf1a31	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xeddf4cea	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0xad030314	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x023992ae	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0b1567d9	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0e2a7007	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0e8520b5	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x189a3a75	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1ebbf765	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2f828290	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3142f88c	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3c30a8c3	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3f9c3b09	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x418ba7cc	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x439c0334	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x44f52701	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x47c1260f	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4b76ee4f	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4be055fa	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5306a1ea	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x55321e47	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x556c3b7b	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5b53a71d	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5eed6ccb	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5ffee3a8	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x722e8f67	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x80598956	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x84610e42	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x94e7f302	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa1f6b9b0	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa550b5f9	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa8f919ec	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xab06e74e	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb33463dd	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc9e71aea	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd9d69cce	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe0e83c69	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe3f79943	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe53ae0aa	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x07ca00ee	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x0c9703c3	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xf57b76a0	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x2dba7d69	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x5b620619	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x80c53d27	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xa4d0fc79	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xae8a16e3	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xd2bf026d	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xf7fc8187	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x19bc74e8	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x8fb7d30b	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xb5f0b961	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xede5be00	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xf1301d2f	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xf3dd4ed2	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xfa15d3e8	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xfd770d6d	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x0b788e24	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xcae00833	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xe941e6e9	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x21e14932	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x2ae551af	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x7118dcc8	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x8f47da32	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xe2682665	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xfa40df79	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xff0ecefe	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x9099ba60	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xe94eb12b	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xffdb638f	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x11c970f1	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x8ebb75d1	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xb44c5492	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xe6f9eada	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xf4f61fb2	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xf63d3b25	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x1537351f	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x19c61a4a	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x454f3bcd	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x52d3126f	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x542e9a29	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x5a4ab639	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x5b51d515	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x700518b4	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x72542a1c	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xca840cde	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xf1913ae4	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x6778fda3	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xad450ed6	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x8b14258d	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x977d888a	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xa9984ea3	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xe42834d9	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xeb7965be	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0dc280a7	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x11276d4b	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x1ad2deda	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x1f536d5a	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x2905884f	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x39da0628	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x39f6b2a3	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x4c45f0e6	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x61b0c405	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x62a16c96	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x6c29b9b0	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x984c1f0b	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa151cbf4	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa2f2d07e	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa43508c0	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xad9cb2f4	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb52e8f80	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb9ceff80	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xbd305281	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xbe900445	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xdf7e74c6	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe939ba38	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf27fddc6	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xfee41635	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x2494db72	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x26c28b74	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x4a6e24b9	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x63adf831	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x868ecf7e	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xa8df6fe8	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xad663522	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xbffabcd5	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xc784543d	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xd5c569a9	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xe775df30	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xed7cafe6	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xf1462fc6	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0b77654e	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x15fc679a	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x209ce42b	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x21e0a1ac	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x227a883d	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2660bc7c	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2b99964d	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2d03f91d	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x33412b95	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3ce05b32	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3d1d16f8	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x477eb5a2	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4c739767	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x554b0537	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5f00ccd7	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x60049485	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7e0bf4ad	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7e46dc5d	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x81d4fc1e	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x85abd248	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x88f5bff0	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x949fda18	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x99a60866	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9e5909c4	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa38e45df	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa94a6556	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa94d1b3e	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xab711830	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb091bd27	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc5636b83	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xccee15e4	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd1b255ee	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf91fbff3	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfb14f81e	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/ssbi 0x2d16a0d2	ssbi_read
++EXPORT_SYMBOL_GPL drivers/mfd/ssbi 0x578f6150	ssbi_write
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x24df2975	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x4702ecc4	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x4ec97030	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x7bc0df30	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x0f5710f2	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x90ea0ae4	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xd60c6953	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xf6d53313	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0xfab97e92	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x26e46ec4	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xa586ef2a	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xb0f6a65d	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xf470e868	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x1cc0f05e	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x7963b531	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x8beb3baf	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xa5b12e8d	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x227e45e3	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x49cb66fe	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x715ea43c	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x790b057d	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xa576cca7	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xabe0201e	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xac2058af	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xcc3a30b3	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x3be33d5c	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x614e2b5d	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x6e8695bf	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x770283e3	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x896318a8	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x963c3c3f	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xe1f04742	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xee34ed85	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x81df6421	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xcd6e377b	st_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0x7239352e	dw_mci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0x7aefc5fe	dw_mci_pltfm_remove
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0xf0df8489	dw_mci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x12f86101	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x2dd144e9	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xefe64497	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x06c788b1	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x8b6c0ce7	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xf53e4737	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0x9cab9572	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x3bf76bdd	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x5e62ef8d	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x98a50a5b	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/nand/brcmnand/brcmnand 0x2d05fdfc	brcmnand_remove
++EXPORT_SYMBOL_GPL drivers/mtd/nand/brcmnand/brcmnand 0x909e9ce5	brcmnand_probe
++EXPORT_SYMBOL_GPL drivers/mtd/nand/brcmnand/brcmnand 0xf80e6c90	brcmnand_pm_ops
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0xb7899dcf	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0xc87802bf	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0xd6faebad	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0xd0657547	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x15b794b4	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x1ccaa5b0	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x28fda49c	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x4828beca	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x6c0032c8	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x784f55e1	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x7f387f4e	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x9a97406d	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xa09d3acc	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xa744420a	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xa74864fd	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xcadcf91a	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe802ee46	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf6ff4615	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x7a64a687	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xf39f5d78	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x130d8855	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x1bf9e3ed	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x8540f002	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x8f6e7efe	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xab5d6b5a	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xe54ce293	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x01451b15	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x2aed3d7f	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x2d9edb49	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x2e319ba6	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x4cb15814	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x7db9f257	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x85cf6142	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x89ad4b8a	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x89e17855	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x8ba850a1	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x8fcdb9e1	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x9a6b233c	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xa968fbb2	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xd730e40b	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xe1ecb794	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xedfb00c2	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xf613786b	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xffe1a54f	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x09468da4	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x2ac7ecea	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x56991f3d	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xa93227cc	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x1cefa069	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x394a37a0	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x686c7ffc	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xf6222c49	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0x9e29339a	arc_emac_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0xba7cef32	arc_emac_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x015bc8a8	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x06c5fca7	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0a1d9c25	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0f3f0ef3	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0f5e352b	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0f79e177	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x107d741b	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x121cb1f1	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x165d8083	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1673186c	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x17e60f49	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x19c0c05c	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x201fd863	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x227c95f1	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x227d49e3	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x23d54f6c	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x24419c26	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x24474b3b	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x25d79c63	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x272bfd6c	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x275639c9	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2af4747d	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2d1820a8	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2d4a7462	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x31905010	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3314b670	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x33f77a84	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x34db53af	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3fc51b98	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x40ce4070	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x44995a92	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4588c705	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x45c532da	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x476cd39e	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x478be0d7	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x480ead23	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x498d7ab3	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4aff1625	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4b0cceb1	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4cc7ce0a	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4fc90c5b	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x50f7da0c	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x52255394	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x52dc8750	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x54cb9557	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x58305a18	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5993ab9b	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5b442d5e	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5c08bfe0	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5f9e3b18	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x60f2c7cb	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x61213994	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x63595d4d	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x65a007c8	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6848e435	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6a786dd7	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6ac09411	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6c324eca	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6cda8079	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6e8e8788	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x70a750c6	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x73c51dd1	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x74535301	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x76eb8cdb	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7e92d47a	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7ff423cc	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x82434ac2	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8ece79bf	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9006ac3b	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x967e0580	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9a9db4a6	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9d527c13	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9fa6abdb	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9fd453e7	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa386710a	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa8136537	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa8eba309	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaa3e4824	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaa6547d8	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xac9127b6	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xae96bc24	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb072fb01	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb0e788ff	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb0ef3d2e	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb3083d32	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb6aa8937	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb6ccb873	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbd602047	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbf15826f	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbf65a408	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbf999ceb	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc26326fb	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc37af9ac	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc3a7c150	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc76fdf23	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc7fd1411	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc98a35ee	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcdc43566	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcde7ada4	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xce7b753b	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xce7d5f75	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd17c8c44	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd28e66cb	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd2a9ca1a	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd3fa21bc	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd64da43d	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd9994eb5	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdddbad98	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe14cd277	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe7de16b5	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe84217e5	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xead8c27e	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xeb19e4ca	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf0c9b7c7	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf137b431	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf14fc9b2	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf2e7c654	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf3373c9f	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf42d6fb2	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf9213057	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf9ff8c2c	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfc3dca20	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfc8a3c1f	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfe5f522e	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0ddd8dc9	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1d6eac6b	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x267fc2c4	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x41487703	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4857869d	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4f212a42	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x51e3c6f0	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x52375395	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x539d5342	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x55f24546	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x591482d7	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5d3b430b	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x62bfaa98	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x64e9bd02	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x668ea824	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x69bd183d	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7329a2bc	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x73bf3b3b	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x76c2f892	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7f7e5e0f	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x897b8d0c	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x967f0fcc	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa0e9ce9c	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa49108a1	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa4b1e2f8	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa80a4766	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xaebda66e	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb04058ec	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb0b449ea	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb38e5ed1	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb435e442	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb6f1cc13	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xba25698e	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbaf7dc9f	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc0643531	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc2f239cb	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc436f18b	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc8763215	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcf99c3ac	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe3408904	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe8baf1f7	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xeb6e0b7d	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xec0df642	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xecf2d5af	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf1099cfe	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf2a44f4a	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x368d3d71	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x6b432660	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xd4ab3625	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x44af3b8b	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x5356e62e	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x69dfa482	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xfa045000	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x2115e418	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x21ddf220	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x3bca3f98	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xab69f52d	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x3eae6401	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x50331fe4	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x29c22777	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x7934c23f	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xcdfde4ac	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xedf7c839	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0x72e818a6	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x26533cbb	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x5fcc7b2b	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x6b6fdd35	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x91d8c4d7	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x94c9c68c	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x979dfd57	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x99410179	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xb7703dc5	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xe51cb1ee	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xf0a0a238	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x60b683fe	mdio_mux_init
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x6318757f	mdio_mux_uninit
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x60ee88c0	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x66764311	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x9f719599	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xeec689de	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x0569c662	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x50052a32	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x66b8b6c9	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x7971f700	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x8489e0d5	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xadf4a28c	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xb4c2ce2d	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xb7649a16	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xe13e55de	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x1bbc10c8	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x1d3f0f81	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x41c97138	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x75e72362	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x7fbb5ce1	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xef0d336a	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x02345374	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0528deb0	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0824ef27	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x09aebb4e	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x157dee43	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1fd7e116	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x20a11a4c	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2ad41268	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x354d0171	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3dde26b9	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4b6f61ac	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4ccd6252	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4d3be2f7	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x643519fe	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x71bda32b	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x75f5e7a2	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x76a23e15	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7d138a82	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8da9866f	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x947547dc	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x97dc339a	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9b7a1e5e	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa57c809e	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xaa54e39f	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xadbff886	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb7ba1dda	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc0c23d37	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc7e515fd	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xdbabf73c	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe4602977	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xfbcd2adf	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xfdef3c39	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0xa3b01554	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0xb0b33446	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x0b73110e	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x0d2b85a8	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x0f8f81fe	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x18a8d4f5	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x3de83958	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x6f4e043b	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x74f07a36	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x758c1673	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x79177960	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x88a764d6	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa2b8070b	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xaf339906	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xcbc7db64	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xcc62de89	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xea07ee1d	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf55939a1	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x1b378dec	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x1de472f3	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xed58bbb4	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xf183fbef	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0x99a20705	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x81a8272f	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xa4dda2db	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xcf931b9a	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xd34a38d9	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xf265262f	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x02f7cd04	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0912c709	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0dc0bb6a	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x15617124	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x16474139	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x18011520	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x194202ee	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1fef1ce9	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x38080e25	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x49b542fb	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x55b66ee4	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5a10d898	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x81e1bed1	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8270c1f5	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x983a63f5	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9a618e5c	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9bf16097	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9c77eed0	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa8bdc85b	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb64ba910	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xbd860a26	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc8159ba0	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xcc8f0ab3	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd0a87487	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd620a55c	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe1167be0	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe2557c75	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe26af9f0	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe430cc0d	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe70071cd	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf2410a67	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x0f3e1dbf	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x1b275a41	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x1bbf52d7	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x3a860542	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x63fff179	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x758f7d06	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x7e6a89e0	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x96be7d29	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xaae60039	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xb45f22c5	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe6bd2014	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xec9a9d1d	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf4065849	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xfad61867	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xfd63e2aa	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xfdb462fe	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x2703bf69	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x66c554f9	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x695e5026	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x8a8330ad	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x99f51416	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc8125ca4	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xdfe7a673	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xe87459d9	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x1f7abc01	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x21c128a4	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2d1f3efb	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x32237e89	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x3550a5ae	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x3f8ba8f6	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x63f57bd7	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x66beb066	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x7096a42c	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x7e2d91a7	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x81a9621f	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x8458b97f	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x8c1f34b5	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x9209b948	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb94b7cbd	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc2def850	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc683ff1f	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xd050f4cb	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xffc2ff7c	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x0547de20	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x0b6bbbbb	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x25b28678	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x3a469f87	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x7dac778a	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xb9b19f4e	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xcbc67935	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xe39631cc	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xeb9d2af5	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0db6227a	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb86c8518	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd644a8e7	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xed1dd81d	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x002c8d52	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x09c2ecf2	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x0c2b7047	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x0fdb3582	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1016e75d	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1717c01f	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x35cbb234	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3c9fa3f9	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3d8a7b36	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x44fdafb1	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x51593102	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x594b8442	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x63d82853	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x708df0d8	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x93ab5712	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa224d124	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa604be12	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa8cff1cb	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xab1957f0	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xb1986b47	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xbdcc6982	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd752bb59	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xde950115	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xe8a9de90	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf8cc3d9c	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf8e86314	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xfac265e9	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x046a421a	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0fca7466	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2d882d91	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3795ba8b	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4bb74590	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4cc4b3e1	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4dc7f194	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5294efe2	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5b6b3dc2	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5db6a26b	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x606cbdf6	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x75978b13	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x84221c9b	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8798516e	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa2e64e60	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa3ea79f4	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb4752854	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc7153aa8	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc96cd103	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf8ff6add	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xfa109de1	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x9f3a0e5c	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xe0e3f3d5	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xf7ed9185	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xfebd7027	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x02ba0914	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x06b8c339	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x06f7bcaf	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0a5524c0	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x13db633e	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x23f5a0b7	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x361af6c8	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x39bd979e	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3a5145ea	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x404b0758	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x43bf4340	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4b61317b	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x529a57cb	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5acde7d4	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x61afe37f	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x69760584	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6ccac6f2	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x758aa1a3	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7917d9cc	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7d6bcb6a	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x83d4bbcf	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x85d3957b	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8aa2a9d2	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x930d1943	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa3a18f59	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xaeb80bd3	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb6a83a65	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc3a0e5c8	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc5bc0c14	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcdaa7f47	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd2f03e53	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd4586f5e	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd50c59d9	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd8682c25	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xec086f83	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf0c87921	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf58198a5	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf7d3d900	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x1ceeb164	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x250b8e21	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x3be2f7d2	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x43d3f13c	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5b51b9c8	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5d53730e	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x60d28a7b	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x772689a7	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x7cbae3a3	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xd9d99574	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe866647e	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xf3b440e2	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xfd9b3dcc	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x078c01c9	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x13e3f188	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x17e58037	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x180539ac	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1995b50a	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1e3bb041	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x20030cc8	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x21a8f814	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x355d6ebb	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x379f02a2	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x37d27f1f	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x38ad9004	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x40dc2a20	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x436b0ae6	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x56abc1b9	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5a049d3f	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5f6b10a2	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x656a187b	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6ade3ca4	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6d7142d1	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x71cad162	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x745d76a4	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x79e115a7	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8080383b	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8979a3f3	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x90bba1a5	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x90d70e1f	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x90e5bdab	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x94c987ba	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x96c14360	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9b5023db	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa6a89900	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xaf3c150a	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb074635c	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb6a6f6f7	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbfb22bc6	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc83464e8	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc842e9fc	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd0f1f6f1	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd4709204	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd9a38945	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdf00402c	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe255bd4a	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xeb2c8a22	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xeed8f8c8	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfb71fcda	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x31793a00	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x836c5cbd	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xbf463cf6	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xe80670ca	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xfe0b4a17	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x6198a8b7	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x8ce955a8	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xac7e77c3	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xc916b450	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x04f4d2cf	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1891a75b	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1b25e105	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x4e5e9250	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x522aeaa5	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6adbc3d2	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x821d0727	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x9535e97d	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xb0b62258	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xbee5f8d8	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xc2d53715	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xc8e226e3	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xda8acfe6	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xebcfeb5c	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xee26fb9a	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xf6941545	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xc651094d	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xdb0ab44e	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xdea24ad3	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x046c5880	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x04a2f495	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0a1872b6	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0c0b2e17	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0c706afe	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x175d4df6	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x19574eb2	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1e44f0bd	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2217883e	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x25f2d4dc	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2f45893f	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3294e3d4	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3310b6e7	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x360bbd27	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3d33c277	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x420096f3	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x43c72276	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4709f53d	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4a0613c1	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x51acfb5a	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5484fd7a	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5586917f	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x62f7e913	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6d563a4d	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x73d7c372	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7b7676c9	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7ce37b93	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x91da5146	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9804447b	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9de320ef	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa9023272	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc3f772cf	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc4152233	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc559581e	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc561d6f8	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd1e02643	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd6e740b1	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xdcb0807b	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xea3bd37c	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xec3e72c3	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xee2e4697	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf1ede001	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf2a32163	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf79e8e22	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfebb1dc8	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x4eb204d7	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x5c21d94e	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xaea7cf46	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xce996cba	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x1f9101a7	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x1fd7aacd	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x263bb1f4	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x6c7dc9d7	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x7574d0d2	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x85af5db2	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xa02a78bf	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xb9dff931	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x75d13908	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x76cd7b25	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x8543a7ca	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x02e09fa8	of_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x07a9466d	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x13e66ec0	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x2f79d236	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x36ec8a8a	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x68758fda	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x7134a988	of_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xa7d8dc93	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc25815f4	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc96fb674	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xcb83ad7c	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe18960ba	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe9a7fe16	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/phy/phy-omap-control 0x3fc5c69f	omap_control_pcie_pcs
++EXPORT_SYMBOL_GPL drivers/phy/phy-omap-control 0x42669c73	omap_control_phy_power
++EXPORT_SYMBOL_GPL drivers/phy/phy-omap-control 0x8610bbdf	omap_control_usb_set_mode
++EXPORT_SYMBOL_GPL drivers/phy/phy-omap-usb2 0x00d48f33	omap_usb2_set_comparator
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x14621b73	ufs_qcom_phy_init_clks
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x18f32660	ufs_qcom_phy_power_off
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x219035ec	ufs_qcom_phy_enable_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x24f6ece2	ufs_qcom_phy_is_pcs_ready
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x2811c739	ufs_qcom_phy_set_tx_lane_enable
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x292a20c4	ufs_qcom_phy_disable_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x5e166858	ufs_qcom_phy_save_controller_version
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x690fe244	ufs_qcom_phy_start_serdes
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x85f2d9fa	ufs_qcom_phy_calibrate
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x8f17d9c3	ufs_qcom_phy_exit
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x9093b5f8	ufs_qcom_phy_disable_dev_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x9d2472ae	ufs_qcom_phy_power_on
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xb39591ab	ufs_qcom_phy_init_vregulators
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xc294374a	ufs_qcom_phy_calibrate_phy
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xd04dea28	get_ufs_qcom_phy
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xd1813b94	ufs_qcom_phy_remove
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xd3c4e6ed	ufs_qcom_phy_enable_dev_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xd8de035f	ufs_qcom_phy_disable_iface_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xe85e41a4	ufs_qcom_phy_enable_iface_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xfa6a870d	ufs_qcom_phy_generic_probe
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x8b4a2298	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xbd85de82	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xe32a29ca	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x21915b68	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x835a4dab	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x91616744	mc13xxx_get_num_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xc0853b82	mc13xxx_parse_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xdb039f1a	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x4598fc21	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x4c86e691	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x5eec23f7	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x812aeee3	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xae83da5b	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xff3c8b8a	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0x920918aa	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x00f470dd	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x015131a8	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x03954677	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x099ef3b0	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x10e4999a	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1866c158	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x341f8b44	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x35c6f6d9	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3c776e05	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3e1471ec	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x45b6f8d6	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4cd9fb7a	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4e59c3d4	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5179bfe2	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x53b739f5	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x593eb7c2	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5a81115c	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x692f8ba7	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x699bfb9f	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x73328883	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x735fafff	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7d8e21b3	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7e7be29d	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x85a863d2	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x860b141b	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa0b72f6f	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa4d61f5d	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa538d448	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xaa412b41	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xab418977	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xab74ef52	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb557294c	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb7831b9c	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbb9ba346	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc2cf6468	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc5c7e359	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xca1d07c7	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xca465498	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd01891cb	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd07cc78a	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd3003a64	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd80f0bcd	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe55ed178	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xeac4a1bf	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf7413b81	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfc668e6a	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x020149c0	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0a3f4e56	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5ca69da3	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x6124a99c	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x64e95f86	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x82e2c5f3	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x8d8747e4	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x903ec949	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb2f0f2b1	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb5fe60eb	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb8ae40f7	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf2fb18c8	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf82c9b7b	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf8b5c159	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xfa9e0182	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xfe8bf89f	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x15126736	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x1c65ebf4	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x7a9cc10a	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x9d5c4988	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xd46e858f	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xfe9e54de	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x027ea5b7	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x05c9d386	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0afd43e5	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0ba72d2b	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0bec000a	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0c2f9f6d	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1327ca03	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x170502f0	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x17577779	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1a7cc5b1	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x200bde36	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x247d3972	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2cd167fb	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3d889b15	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4e64d164	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5741e572	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5a077a7b	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x63ff8ad7	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x65d42a3e	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x76252d5e	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x76bac456	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x76c2a16e	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7b62fb55	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8eabe550	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8f1ec554	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa9285a4b	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb9fbb0fe	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbdf4795a	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbe3d2499	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xca402cac	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xcf5f79fb	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd6c37ce5	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xddbda6d0	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xddfe2bd4	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe12d7701	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe29db47d	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xec2caf8b	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xeec23c59	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf39e139e	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf63c752a	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfc34b692	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfd257575	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x0708d5b3	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x0f53d821	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x1800fdf8	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x28e96d1b	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x43189916	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x623665db	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x85047aeb	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x8740890c	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x9707eae5	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x9eefb402	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xa7296ef7	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xad9c7d86	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xb3d99edb	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xccd1b534	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xcd26cd2c	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xd664edbd	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe7c3b70c	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x03594c53	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x11eff8e9	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x205b2a20	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x291d3eb6	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3421b91b	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3f208ef9	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x41ab0f05	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x44486b63	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x53434645	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6b5a22cd	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x720ff1ad	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7796b87f	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x812528cc	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8d072b18	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9b2e4dff	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xaf549e2c	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb5e6689d	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xd2b71a31	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xdc6f16d8	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xde058dca	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xde435861	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe9b4da68	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xeb3fc2e9	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfa366794	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0325ab60	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0c9b38b8	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0dd07866	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1c59b090	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1e12e279	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1f80e0c1	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2bc217b0	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x377c605d	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3bc79ecb	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3bd37f7a	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4af8d639	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x536b4a13	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x540e99fc	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5a291845	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5fdad2f8	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x62d77774	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6a3e8f7d	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x70f544ba	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7ada0372	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x80f0db6a	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x82bffe04	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x89eaee70	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8dc88928	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9836166f	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x987c9f79	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x99c98b54	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xab154b25	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xaf9ef127	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbd1c2205	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc45e9726	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc81c20c3	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xca1c2bcc	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xcc9ff414	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd47f1314	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd860a5cf	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe37ce7a7	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf1eef4b6	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf80e8690	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf9ebbff0	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xffb888cf	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x5c06233b	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x91f6e1b3	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xd221fbfb	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xe0a271d1	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x492724bb	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x4a37a781	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x4fec6807	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x8ea4d2af	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xaf758983	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xb8e9d3b9	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xd2fd4048	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x203549e5	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x26ba0b9e	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x2f6f99b6	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x9cfc58a5	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xc419693b	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xc7e2cfb2	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xd3dea9e3	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x069ae08b	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x13ce5d25	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x1d78e7d2	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x68b80f60	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x9f685675	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xa1c015b1	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xac2c1603	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x0526d8a9	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x238ccaf7	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x44cbea2a	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xb017be70	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xc8eb2a1f	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x2114f7ce	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x57dfe3d4	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x7d803b46	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x972be6a1	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x173a8e15	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x17a4c3f6	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x212bae42	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x32a4ee9b	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x3f2b1c9a	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x53d58db4	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x6034bff5	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x6f7d9742	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x78b57f3a	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8f600c55	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xadb9af0c	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xaf53f933	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xbe098083	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xcfb03e05	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xdb751026	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xe2f01bae	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xe396af8f	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xe45d6f2c	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0xf85486a2	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x01eba743	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x10f4e405	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x119abfbe	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x14453376	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1acc1fe5	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1f8b02d7	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2d3892ed	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x324d0b75	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4f6d030c	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5a4553ee	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x60306505	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x64a3f1c5	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x650c7cae	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x747734e4	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x89d4ef4c	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x95cc69e8	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xaa786e45	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb27cf164	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb2c523f2	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb8520e35	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb2c56fe	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc1bd7337	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcc831f45	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcdd4bbc3	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd101afc1	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdfb5ee07	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe0c37cd1	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe826b4ac	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe84d9313	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf121d8eb	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf2a708e3	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf5ad0281	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf6bfed24	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xfa1acd1f	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xfe4dc745	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x3175b719	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x544ca07b	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x5858e2d5	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x86738cf8	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x8cf3e892	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x94eac66f	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xd59ca868	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xeff080a3	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x33628a33	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x48ce0dd9	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x8e365419	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xc8558645	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xeca6a08e	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xef5de100	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x5609ba96	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x1e3cf33a	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x94c7adf3	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0x1b4572b3	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x090e975d	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x0ff5dcc8	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x2907e87c	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x2e5249a0	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x3e88b331	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x4c8604df	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x5176db45	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x5e76e070	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x614809d8	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x7b377f1d	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x7e382788	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb693f1be	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xc717abe3	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x21acfeaa	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x82b9b5f8	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x86f35bd8	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x8db629e5	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x03f03383	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x19bdc66a	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x37633e05	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x4e474e06	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x54fcd941	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x55d28d64	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5eed763b	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6636d2c0	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x90649ad7	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x983714f3	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa1eab684	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa9c9e69c	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xb5fd3047	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xb7d74ca7	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xb8ac5ff0	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc39d25fe	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc79e12bb	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xde9a52c4	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xebf3a4f1	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xecf13ba5	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xfb261233	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x1166be38	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0xcfee77a9	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x028e3500	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x3bb98c84	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x717965fb	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x7b90a097	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x8d59e493	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xa59f3668	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xb0d03e40	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xcf08cd40	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x0ae16b5d	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x2bb61567	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x42c962b5	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x5954388b	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xa8df04a7	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xb36f4272	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x1cdb8a6c	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x5f52f0e4	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x674de810	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x74ef481b	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xa3ee42a6	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xb70c54a0	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xce05d165	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0x2734e5d2	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x0beade5d	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x10d112bc	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x1473117b	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x2bc24747	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x3d846962	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x48c9bf9f	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x4c907673	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x86cdfac5	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xae4851d5	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xc22efdbd	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xc4f02c31	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xda67d350	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/nvec/nvec 0x00c2cf7c	nvec_register_notifier
++EXPORT_SYMBOL_GPL drivers/staging/nvec/nvec 0x33fd5e92	nvec_unregister_notifier
++EXPORT_SYMBOL_GPL drivers/staging/nvec/nvec 0xd9d9f1fc	nvec_msg_free
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x076997f8	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x2332f7ea	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x3eb2a48f	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x48b90a41	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x66b13f12	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x80d96690	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x86442336	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb2978dbc	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb97e5906	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xded8ac3a	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xea4c8536	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xeed3bd0a	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x135ccb95	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x286e5885	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x4970dc6b	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x9ba1aed1	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xb4c8b91e	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x6da096ac	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x71ab7ca5	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0x002b0945	imx_usbmisc_init_post
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xcec89fce	imx_usbmisc_init
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xdb8c1d8d	imx_usbmisc_set_wakeup
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x33f7f5cd	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x61d5398c	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xb741fde9	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xd63946e8	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xdbc3bcbb	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xed33c2fb	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x1a32338c	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x1a754001	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x1bf0a6d3	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x27fc3b64	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x303cd82f	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x55f40348	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x608098eb	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x6177187a	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x776ca5c7	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8131b80f	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x9fbf0545	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd55fb962	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xda9a36b8	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xe6abba70	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xff67a981	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x692041fb	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xda9e5e25	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xe4bf4699	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xfb39f842	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x1298ca39	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xce30ab2c	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xdc3c590c	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x12ac7db1	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5baeeb7e	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x688b6ae0	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x8b6ba5b3	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x90ca2a0a	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9554d505	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb0cc1929	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xc24fd572	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xc2afe47b	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xc4467b32	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xc8b17912	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xd9615990	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xdc293546	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xfd461fef	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xff665e01	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x1ae9814c	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x2e26c4ae	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x482cf663	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x4c3441e1	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x4f926945	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x5c045407	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x6c2b6422	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x6ccbd6bd	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x71022849	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x7bfa1491	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x7c6c6a6b	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x8294be0c	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xc9bddd79	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xd559711f	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xdaa57792	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x039d32a2	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x05f93ca6	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x1776cd60	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x1b697781	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2d1571ee	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x352bb6c4	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x39ab192c	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x48589362	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x51042363	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x52566694	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5e59eb57	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x626e3740	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x67818653	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x68167c66	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6914ea2c	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6e75977f	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6f10ace0	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7010ebed	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x726962c8	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x73296c5e	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x764f59b3	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8f856728	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x995aa720	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9a899321	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9b533cce	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9d5fd172	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9f65746d	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa7c345cf	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb709306b	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xdb3f019c	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xde9c6939	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe3a52516	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x002654e8	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0xde69ab34	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x06c98019	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x236ebb04	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x25bdc23b	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x2b6c8281	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x57fbd0d1	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x85868f35	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xe03f32a3	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xee59c61b	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xfd609341	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/musb/omap2430 0x6fb55e1f	omap_musb_mailbox
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-am335x-control 0x75eed29f	am335x_get_phy_control
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0x37eeaad0	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-tegra-usb 0x1a7f1216	tegra_ehci_phy_restore_start
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-tegra-usb 0x7bc9be66	tegra_usb_phy_preresume
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-tegra-usb 0x882233f1	tegra_ehci_phy_restore_end
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-tegra-usb 0x9add2d6c	tegra_usb_phy_postresume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x156abbbf	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x0556f843	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x0897015c	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x100347c0	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1025f70f	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x17962832	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x20853c7f	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x37648646	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x3f25eebc	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4f5c5a0c	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x70815543	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x72b3c3ec	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x87a8570e	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x9c1467e2	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x9e68fa52	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xad1cd062	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc411e36f	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc6cb1890	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe1c0feb8	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf892a974	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xfae93f1d	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xfd16edd9	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x01d1b578	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x04fe3525	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x12ec6ad7	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bdde45d	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x229940ca	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6502eba8	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6bf35cdc	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x7fbb9ffd	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x85dae0b0	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x861fe9c8	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8a99b0b5	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8e4dfa00	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x953e5bbe	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x9a692bdf	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x9ff14465	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xa6455a60	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xaaa6efe0	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xab64fbc7	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbf041d80	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc20c64b5	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc25fb0dd	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc90e2255	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xcc5382e6	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd65be87b	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x193c0116	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x2c9db9b2	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x40f4069e	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x45599af9	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x4c748cf8	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x6ae2bba4	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x8201f826	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x8d6ad1ef	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x95b067f5	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd15275b7	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd56e63fc	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xdf223e3a	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x24dc4708	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x4d039d34	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x65c64d7c	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x744387d2	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x84fea687	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x88104061	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xc09a6222	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xc543b60e	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xf4654c3f	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0499f9d9	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0c998ca4	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x2952a31e	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x300cb20c	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x437bc85c	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x4af29d72	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x4e75c959	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x56a6246f	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7eacec3e	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x97cceb3e	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb1a7d82f	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb867ac11	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf6a545d1	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf99d65dc	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x61b603d1	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x855505c1	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xee84f32b	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x0767348c	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x4baa83d7	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x740975d6	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xa2f892ca	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xc1d4eef1	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xc7e22a4f	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xccc630af	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xdb96bb39	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x01c77549	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x01fcee4d	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0223d7ca	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0b8aad57	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0dd63a0a	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0e585c65	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1b70b106	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x202a2eb5	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x266348f6	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2c209515	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3a080f42	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x43ef0af5	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x47ddfb37	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5372a303	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x570b216d	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x57ba9463	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5b324ba3	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5e4bc088	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6170b331	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7dcfcd23	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8320dd09	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x89eb57de	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8cfdbe07	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa95c7d36	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb184baca	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbe5cd754	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbebc6935	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbfaa3779	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc6978b74	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc911efc6	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd1b389de	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd48ee796	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd4e1dd04	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd938cc29	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd9ff72db	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xda0318b5	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe1716f06	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xeb48878d	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xeb5fb60c	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xeb7ce834	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xfe6c90f9	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0xe638f74e	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0x033632e3	__vfio_platform_register_reset
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0xaf5f1d2a	vfio_platform_unregister_reset
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0xcff8d273	vfio_platform_remove_common
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0xdb9ed52d	vfio_platform_probe_common
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x15a66ff2	vfio_external_group_match_file
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x2c02a037	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x2cf34c57	vfio_group_get_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x32b3c7a8	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3567743b	vfio_external_user_iommu_id
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3bbeeba0	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x602ff358	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x74227bfd	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc1d989c5	vfio_external_check_extension
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc4913442	vfio_group_put_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0x3e30bc0c	vfio_virqfd_enable
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0xde51669a	vfio_virqfd_disable
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x04e91b88	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x05608299	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x06d368e9	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0ac5a684	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0bb58340	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0e3210da	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x32bcc5e8	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x32f2a030	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x398b4245	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x40a2800f	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x547b1dce	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x60e8c8b3	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x68ca3a82	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x69931552	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x69d66677	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x70bce26e	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x72b4267d	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x76d47a75	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x77fd1166	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x7ac3be50	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x96363aa3	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xaf593aa9	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb012b4b3	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbec7bfd8	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc03cb533	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc18f7b89	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xce75e7f7	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xdc97f639	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe3f3bc04	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xebee6288	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x2fb22671	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x3ab1d2bf	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x5371eec3	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x7f3a4505	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xb2fbdd9b	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xd125bfa5	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xe355b06a	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x0edf5771	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x1eac9c8d	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x2d38886d	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x73f98eb7	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x9d6f08cb	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xa278909e	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xac557de0	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xcd5f4fb1	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xe2a3eab9	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xf6efe277	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0x979403c9	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0x12f86332	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0x58fbda78	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sh_mobile_meram 0x018cd312	sh_mobile_meram_cache_free
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sh_mobile_meram 0x0248a201	sh_mobile_meram_free
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sh_mobile_meram 0x60748177	sh_mobile_meram_cache_alloc
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sh_mobile_meram 0x9797cec1	sh_mobile_meram_alloc
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sh_mobile_meram 0xa733e8b6	sh_mobile_meram_cache_update
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x6e36d7f2	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0xcec8301d	sis_free_new
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x2753e644	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x3241c003	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x8303fcac	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x9283aeb6	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x99a41525	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x9f29ba18	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xce1aa8e2	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xe57eeb8c	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xf7ed60a1	w1_reset_resume_command
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x59fa6a02	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc0573c4c	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xe8bc1411	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x003b03e6	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x6a8695fc	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x857a148c	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xa299902b	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xa2b39b5e	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xbac22402	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xe5eafa2b	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x01287776	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x022864cf	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0a20da8d	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0c121971	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0d3e0532	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0d5635c7	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0d57b76a	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x120c7d8f	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x12592baf	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1b3b0cfb	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2081d7c6	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x22c3d373	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x24115fe6	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x269034a3	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x29d49f8d	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2cd1e57d	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2d6df02c	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2de36a31	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2e00de11	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3086387b	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x31cb0439	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x33a04d75	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x347fbc8b	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x34cc1ece	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3772aa28	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x389e97b6	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39d145c6	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3a758f68	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3aac58e7	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f589d93	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x473a41c3	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4c9092ec	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x509c1838	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x53da171d	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x53fa17ae	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x55cab894	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x562b0a12	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x58c7f3e2	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x59b90a3d	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5f021766	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5fbe7868	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x611d3e57	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x687bf3a0	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6a7d0b15	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6d554405	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6eef3ec3	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6fef91f8	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x724b58c5	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7352c85b	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x759860a1	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x79331a96	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7a307512	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7ab86e2d	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7bd24fd6	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7c3c4f7a	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7d0234fd	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7d8fb796	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7ed8a34c	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x82136794	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x88a00b69	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8919923d	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x89a024d8	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8a03eacb	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x911b57bb	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9316770f	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9443aa25	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x94633ec9	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x950c1d8c	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9543f657	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x95c69ac3	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9775e566	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x97d97ce6	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x981c80ea	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9b22394a	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9c5a954d	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9cb781f5	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9f29b443	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa24820c9	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa47722b0	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa72d139e	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa821005b	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8699d3a	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaaa14361	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaccef826	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xacd0b93a	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb0525b07	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb0a0ca8d	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb0dc97ac	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb878cbab	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xba01ae32	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbcc89f83	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbe002833	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbfef0fb3	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc0ab2ed1	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc140f96b	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc966952c	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xca78a385	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcb43e9cd	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcc64deba	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xccc588eb	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xccd4fb87	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcdf47f46	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xce2a8de5	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcf0e4267	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcf9caebf	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd00e76ce	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd03918cc	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd41ab334	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd88081fe	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd95f3bbe	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdbb6a5a0	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdc115046	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdd487446	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdffe034b	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe2820da3	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe553ba30	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe6fe3ee7	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe7dbc1f9	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe97e4692	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xee3723ea	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xee6a6877	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf2abfb87	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf84e681e	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfd459cf5	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfd4d9874	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0xd1ca88fc	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x02717741	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x04c54d69	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0c1bb5aa	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0f7ae1e7	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1299583b	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1518dffc	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x181e062d	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1ecdf798	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2825be66	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2dd783bc	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2ee24be8	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x36737539	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x39d2eda1	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x39ea5b9d	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3af491a4	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3b595038	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4096e925	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x46f11607	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x49d30da6	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4c661a68	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4d5d5558	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4d88dcb2	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4e7cba67	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x520b6f24	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x58406e44	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5ab91907	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x60bad237	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x648b1aac	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x68454d02	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x68ecd700	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x729e8cc6	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x741b39f7	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x74c9ae90	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7734118c	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x815c92fe	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x954621c0	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x99107c04	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x996a099e	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa02df320	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa10cef56	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa5609c1a	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xaafe894f	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb5c036e1	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb6bfc9ba	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb764ad90	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbb889e95	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc3132ca6	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc58fe26d	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc78ddd19	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcac6b7b8	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd71b899e	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdc77d096	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdcfae0ea	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xddcc47c1	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe16086ac	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe7af9888	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xea267e19	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xea2f7f19	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf4717472	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfcde292c	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfe924f59	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xff64e184	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x2f5e35b3	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xdf3511d1	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xebf202c9	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x76cfbce5	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x76e6cdbf	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1546a30f	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1cb231d0	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x2512c902	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x60aa1e96	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x687f6251	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x9daca2f6	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa9f5379a	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbc9a9a3e	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xce5cd2e2	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xec26d185	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x207a2b57	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x44985fc0	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x8e6f7e3b	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xa4dd542d	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xb51e1d3c	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd4080952	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x52e8eaf3	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xad61fc93	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xef4682fd	ocfs2_plock
++EXPORT_SYMBOL_GPL kernel/torture 0x1543d37e	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0x1935c37a	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x3eed46e3	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x623f1551	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x707aa277	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x021957e1	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x0f8a2742	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xd4cb6873	raid6_call
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x2d107b5e	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x41ecf87a	base_inv_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x72eb4ea9	base_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x767b8ba8	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x8d490167	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x9af6b231	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xdba4feef	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xde0e6eb2	base_old_true_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x341cfd33	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0xda449735	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/802/garp 0x03f95aa0	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0x14d05d95	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0x83b2000f	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0xaf120ffc	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0xbb131f1f	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0xc34e1b24	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x02186f47	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x0df249eb	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x5dc832b5	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x84f97876	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0xc375518c	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0xe1fef2fd	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/stp 0xae0ec4c8	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/802/stp 0xc14e9915	stp_proto_register
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x79f0e52e	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/9p/9pnet 0xa3d12247	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0x1d8276c3	ax25_register_pid
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x12f88ebf	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x6ce6d4bb	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x71f800db	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x84edbc80	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xa5778c30	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xde425c9d	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xe0156c85	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xee05b62a	bt_debugfs
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x370bc974	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x4c6ac6d1	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x4ca9a455	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x67298e95	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x73062fb9	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x9434bd0a	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xa8d5901f	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xb7355043	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x32c77ea3	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x7de596f3	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x05e2d880	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x09a123b7	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x14b80968	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x152d3263	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1bf047fb	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x273f74d6	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2e7e902e	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x36e8c1d4	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x49200931	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4a0ce015	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4a27c8ae	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x54a61cf1	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5ca486c4	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x63ee79c1	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x68555afc	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x754bfc4f	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x75989dee	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7dd25c9a	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9001d57b	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9fd6bbf7	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa20f2f9d	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa39854ec	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xaad87ef2	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb0596156	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb221551e	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb344cc6d	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb92baf26	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xce4a9c36	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd0679199	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd932d351	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe0a457bc	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe5c81367	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe6ac241c	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf149b0f2	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x505247c0	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x5131c77b	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x82fa43af	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xa15e47f6	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xaa8d55ed	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xb039466b	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x4d7aef69	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x81646e05	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xab394765	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xb1d2579b	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xba05533d	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x437a7a0a	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xeeda27ae	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x09978cda	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x43678886	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x8220db67	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x913d9eb4	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xe078baa5	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xe9df8b1e	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0x56753584	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x1d3dc27c	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x45b78202	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x55e17542	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x6ef89674	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8bb546d1	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xb88f7e9e	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xb8d58db3	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xbd63eaee	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xbdd28973	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xcf8f14ef	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd1dee4bc	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd724fd6b	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xe4991712	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xe75acd9e	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xec4281a7	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0x811c7f12	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0x22aae514	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0x8b05e9c9	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x0ab4d3ff	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x55648624	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x8caf4ce1	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x9b5c81be	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xa151621a	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x9c996be0	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x1cf7cadd	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x3b5a6560	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x67f5eb51	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x717e77b3	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xec3c393a	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0x7fb7060f	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x186a7f8a	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x65cc0fc6	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x73d1c75b	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x82e6b3f9	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xa4856287	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x22be49a6	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x87e15ea1	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xa2cde5bd	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xc8cec050	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x007bc598	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x0198beff	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x4a2041b9	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x6b5f0021	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xb15f550b	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xb46a2a2d	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xfa740b9b	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x2dbe56ea	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0xaba00cbe	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0x34941373	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x4ae620c5	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0xa2fcfa63	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0x3362eaa9	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x37009fae	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x69420b2a	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x7ec55fda	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xaa9ea397	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xb51aa90a	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0xc80cfa80	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x17f48568	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x37b76410	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x38ec72ef	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xcd581d64	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xea4f3de1	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0x060c0485	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x000146b3	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x2eb0dd88	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x39c5b055	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x52accd06	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x7a23002e	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x7bf0a76c	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8b7f885b	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8f2a9abe	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x9d56819a	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x9d6ecab0	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc39b8a6b	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xcefbab47	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd8a29886	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd9f6e2d1	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xe1130621	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xe90f5432	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x73c7a991	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x301516f5	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x310e3f0f	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x3701547c	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x3f1954a9	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x75de7c69	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x77160eec	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x912ee626	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x9145fa26	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x944dbe26	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x9d384e34	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xad0efcfd	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xb124569f	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xbf9fa8b3	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xc93034f5	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xd3bc6b1a	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe503800c	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf8a89e7c	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf9fa191d	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x7ec414e7	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xb7c55183	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xeb52ba2f	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xfe406df5	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x03133f67	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x2aae39bc	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x481945c5	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x52f18ef1	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x63007ba7	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6344eaf6	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x657e44dc	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7ce6f08d	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x84d61607	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x8f72679d	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9303c379	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x953ba1b9	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9d4d2b4a	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa8c14daf	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc4201f6f	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd79cbd4f	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xe959e0ba	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x1581ba39	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x1ee5a0ec	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x54fcdf44	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xbb717e8a	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x019ecae8	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x07cfd8c0	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x08fb3982	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0a7e7f6c	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0e6d4090	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0f2d098d	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0ff1a99e	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1a1653de	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1bab04fd	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1c2b73f9	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x21207135	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2137b450	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2b371a7a	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x32ced98b	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x33494c19	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3ce199a8	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3d1b6b0f	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x407ce2de	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x42af5c35	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x46a58ea9	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x496281f9	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4b424fa5	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4d782ec7	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4de65a15	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4fec7f20	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x506dd47b	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x542b0c66	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x589d17a6	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x691882f4	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6b618f48	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6d0dcdc7	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x72c0ba65	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7c868078	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7fe4ce4d	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8bdf7dec	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8d8787a6	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8dd333a8	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8f67e1ec	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9055b86e	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90acb432	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9130115b	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9669bc7b	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x99049bb4	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9b27c71f	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9b775043	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa2cf4109	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa44e869d	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab32f936	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaf9561b0	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb29e82e9	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb2b4e878	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb3882bd3	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb58d3086	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb865c534	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb9ca2dfc	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbe97f45c	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbf77e052	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc2abd2fd	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc5b39c11	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc7c141d1	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc81e932f	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcaace4d2	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcd6a0104	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd053d137	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd076cb5a	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd2d55540	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd418b23f	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd7ab55a2	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdba58655	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe2e0fb06	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe4db6a40	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe8f374af	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf1cfd8c5	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf58c1917	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf7a60cfe	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf9105dd6	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf92ac472	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf938c75c	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfe5fa6fc	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xff556f14	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x81ab880e	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0xb1c26838	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x3f40e16b	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x140a797f	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x593c047e	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x6676ec78	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x6b1fe8e6	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xab2c9001	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc3635a2d	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc462c9a8	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc5166bbd	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xf6dea40b	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xfabec646	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0x34ada9f4	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x4118e5fc	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x5fb185d0	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x82794eb2	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x86d9003c	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x027c9ed0	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x9a1f12e7	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x44019361	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x62f5e3c0	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x93e34944	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xa7514839	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xbfffe8ae	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xd1df87c2	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xf7b6b6fd	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0x2acb1d2c	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0x4ec17ff8	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x0d133b70	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x32ac5882	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x6dec3901	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x85c87190	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x5633582f	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x6942d4cd	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x70622d36	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x74f1c7f4	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x7a7e1d9d	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xa9610c38	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xc3a516d4	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xc7d8df90	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xff2be39e	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x5fed48d2	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xd4cf5893	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x4af5e852	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x8841d39b	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xcdf56f03	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x12261b92	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x21712499	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x47150777	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x47797de1	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x4e4dcdc1	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x55fdaaf2	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x8697fdb3	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x99beb3ba	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xa1d4fb57	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xb49d6348	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xb559ad34	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf98beba	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc1c87d1f	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc57e9cc6	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xd51455dc	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xfa805661	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xff1581c9	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x0659790f	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x4a3a310a	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x60fa8bc5	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x75a71615	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x80c086bb	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xb132c2c6	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdc124edb	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x48e69662	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x57de904d	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbdf8d839	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0xfd69b82d	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x67251f54	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x8e299cc4	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xbc72e91c	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x3aef992a	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x4546493f	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x5094a1f3	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x5a7324b9	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xac248787	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xbc02e4e2	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x5ce9d994	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x708eaaa1	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa031eccc	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x1964a677	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xc17ccc8a	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x0c51a5a6	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x37bb26d6	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3f1ef70a	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x4af5a64c	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5345cb46	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x59fe1b35	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x696f077f	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x6e78f8cb	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x7f9aa306	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8af906a2	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9dad3c62	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xb76bf412	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd900cd54	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd9f2ffdb	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x57909dc1	xt_rateest_put
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xd0f26ea3	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x05836fd4	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x0d84770c	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x9d70a683	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x5c019bbd	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x66e6be3d	nci_uart_register
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x7befa76c	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x1c7d3999	ovs_vport_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x2d8f0042	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x48740476	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x5dcbe6e8	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x793b24a5	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x7ddbcd9a	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xa2432b62	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xc6b2a2cd	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xdd76e7d5	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x084e9f0b	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x0a2de486	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x170f8f71	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x1861f428	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x274abd14	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x30af34e1	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x389d4f67	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0x3cb3916b	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0x3fa03866	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0x432d7195	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x4622b59b	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x5883619e	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0x590c37c6	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x632959b0	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x6b310271	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x814c0eea	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0x96fafe85	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x9a270ca8	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0xb15a5aec	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0xb5c8c242	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc642cc2c	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0xcca5d899	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0xcccc5904	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0xe11c8876	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xe9dd3f57	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0xea32aeb5	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x39b0747f	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xcd3a151c	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x7d02f35e	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x863af689	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf172c86f	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x01879de4	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x01c6e5c2	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0502551a	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x070e2a68	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x077b2cf8	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x091321e8	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x09b54c1a	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0bc4e567	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c1172ab	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0d67c6b5	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0e930cbc	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0fcf6ce2	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x10ff10e1	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x115036ec	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x127207a6	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x15cbabc0	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x15e91ac3	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x161da123	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x164480a0	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x16ab2bd8	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x183018b6	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1868a281	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1b0fa28e	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1b2f43cf	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1bd9e66d	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1cc75e04	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1dfa079d	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x20e70cbf	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x211640c2	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x217d574b	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x22ff1bee	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24343886	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x261cf964	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2821607d	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x28f8a98d	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2b353aef	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2bbeba3d	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2bcae62c	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c9713b6	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c9f4e9e	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f18334f	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f8ebbe0	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31179c8a	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x34200df2	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x34569874	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3511b6ce	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x35e1acca	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x36c7c29f	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x36d0ef54	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x37028d38	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3a198a29	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3be97fa1	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3d4439f7	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3ef591a6	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x405f8261	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x436df35a	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x46b30d73	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4a4b5329	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4b333b5c	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4bb1c535	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4c05d3dc	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4d1e8ae9	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x50b0411e	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x519bb04f	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5255fd98	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53387ad2	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x534661e8	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5492f0e7	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x57236291	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x578d7a15	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x58821a78	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x59afe090	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b5898be	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5bc0d723	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5be0cdcc	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5eeab87c	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x61332979	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x61a04d53	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x61cd8b08	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x61e732f6	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x637a843c	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x643fe88a	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x658a78fb	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x672f5a6b	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x67bdb39f	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6871056c	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x695446da	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6b3466f3	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6b8fa87d	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6e3a9f79	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6fb61dc6	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6ffc66b8	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71923833	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x719c3a6d	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x72851555	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x72bd9226	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7471dc1e	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x77ca6ebf	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7dd7f3be	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7fd51ab5	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x807ddf3d	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x817101eb	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x82c2e8da	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8419f01b	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x84b7094e	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x85904e0b	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x861115c0	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x86b68239	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8840214c	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8c82f99e	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8d322fa4	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8f3bdbcf	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x902b5f87	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x95c9c0d9	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x95d4cb01	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x983f1ef9	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9954c7f8	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x99d8dea1	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9a57aaab	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9d2d167d	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa1098e09	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa2b27acc	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa370c968	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa6318f00	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa6738a46	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa985c764	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa9e2d45b	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xab46d46f	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf750eb7	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb1341f4e	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb2b80197	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb50e4273	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb74b7a74	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb8765cf0	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb950e4ec	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xba387bd2	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbb46d83d	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbc040289	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbca39cbf	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbcf9aa6f	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbd46ab77	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbdc97640	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbdec2750	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbfa15892	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc295b3d0	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3991e60	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc62de92c	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc7e06aef	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8597ee4	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8665eb1	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcaba9503	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd00c292c	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd1f12e61	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd41435c7	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd5f037c6	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd5fc9349	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd660e20a	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd6ab1e9d	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd772882a	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7b18bed	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdac649a9	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdc866b30	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdcb35d7c	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdda6f4e1	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdee5310e	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdf88b335	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe0e89826	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe23dc915	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe25481d5	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe392a84b	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe4291775	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5f2bd80	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe6124a20	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe74b93fc	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe93d88f1	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe93e8810	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe991f227	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xead6755f	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xec891f8e	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeced6acd	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xee1a1391	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xee3eb24f	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef681eed	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf08092ae	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf090f378	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf124cd4e	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf1cc179c	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf2eb7c08	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf3c6b820	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf66785b3	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf74ad460	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf799daa0	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf7ddd913	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf7ea6d1b	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa6e5207	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfc7121fa	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfec5806d	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xff41d631	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xffc00365	rpc_delay
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2061d7e9	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x51e92d29	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x641fb175	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x74e91915	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7718ae70	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x77397a37	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x81085bfa	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x91511824	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa6cb9fdd	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xb3063661	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xb8549351	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbc2e121c	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xc3f6d384	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xcd1c6ed0	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf593c40a	vsock_pending_work
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x12576c4d	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x20f31851	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x20fd2fca	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x5b32dfa9	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x62e44ef4	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6d4ef5b5	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x7c5d7530	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x82aa0435	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x9e2672f7	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xabc948e8	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xb282cdf9	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xc78c0d50	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xd59578c9	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x18216937	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x2ec5b43c	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x31943a22	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x3605692a	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x384a2684	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x52901874	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x9dae84aa	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xa62120c1	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xb6dcd730	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xc4bed813	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xcca4160b	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd29763d6	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd74ed9dd	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x28cd340b	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x9cfc0508	ipcomp_destroy
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xcfd31c83	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xdc628ea5	ipcomp_output
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x2208e70a	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x4b1c231f	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x15e8406c	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x19d3c038	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x6309726b	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xa6f9d588	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xe65186fe	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xf253e5ea	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xfefadd78	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x015b62a7	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x01eb1840	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0fa5451b	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x15aa3720	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x16ba211b	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1e0d02b0	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x25941524	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2907814d	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2a1d1455	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2b433877	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2e506d7a	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2e916198	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x337ec826	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x36ea981c	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x379e78f5	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x39cf8c1a	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3a73cbac	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3af99c49	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3b4604db	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x440c202f	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x44380368	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4a590a3b	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5508fe1a	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5521cb35	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5556fd62	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5cd52beb	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5d4e64c8	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x620baef3	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6d8e418f	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7123c2a6	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7511f28d	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x753f5d8d	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7cb280b4	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x83525688	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8357e7e8	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x83be90aa	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8c200dd1	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x91357994	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x91a9e3e5	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9322b514	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x97ded8a0	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa405196a	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa47114cd	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa69002bf	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa72ff90b	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa740b46e	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa8286710	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xaaee1f4b	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xad689a23	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb01641b7	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb48de32f	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb855df15	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbac5a161	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbae99379	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe8b6118	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbf1e53b2	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc476d662	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc65860e1	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xccaa057b	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcd7f2865	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd18fea61	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd2e76006	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd6f254bf	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd9d0e260	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdacf16ae	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe0bf2c76	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe10f3a93	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe1cc261d	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xeb86544d	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf03c1f3a	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf575aff2	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x09b263df	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x18eee292	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x6cfa25ef	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x74ba468a	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x9ccd085b	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xc99335c3	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x03d0e5ed	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x052c036d	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x061adf57	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0819262e	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0c9c7a67	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0cd0afcc	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x12559392	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x16bbecc1	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1ae87ae2	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1bbec0fa	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1c468561	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1d6e55d9	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1df518dd	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1f96d71f	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2583a4c2	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x259df3f4	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x28c03d20	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2b9caf4d	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2ff7b3d5	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x30b7d28d	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x33b5a62b	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x379a0e75	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38a47cd1	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38c76490	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x39a690a0	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3b0b9bd0	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3de1a3e2	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x41193632	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x436344cf	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x45e5063a	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x46e5ad9a	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x491822e4	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4ecbcd74	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4f2ec2b1	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5064f952	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x52f2ce85	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x538a8554	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5589d8ee	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x56222699	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5795f4dd	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x592faad7	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x596513d0	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5a1b2066	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5b154b00	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5fbf42e5	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x603f7625	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x615e8e95	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x63ae1475	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x68b0f3d0	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6eccc522	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6fa59800	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6fd5b7b1	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x749019da	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x799c153b	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7be251a1	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7c00786b	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7f32064e	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7f7e36c0	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x849ddf67	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x849ecc2c	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8838dc03	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x89d403c7	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8a24e93f	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8bfb77c8	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8cf86c16	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x913529a9	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9287312a	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x95c73605	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x99b28c69	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a7c7b92	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9ac1984b	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9ad4e58a	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa3f58a39	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa52abe52	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa5a7721e	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa843b3d6	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa919af48	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa9355fb3	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xacecd729	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb0bbd244	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb18064bc	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb1c460ec	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb205e6e7	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb22ac3f4	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb3aeecd0	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb8a57640	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xba835447	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbcb5bcd0	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbdc976ba	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc06e8284	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc074961d	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc49ad679	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc69dbcec	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc9a5a1f7	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xca12ee2e	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcc8a75d1	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xccfcb325	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcd992e8d	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd0c08b52	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd37b1cb7	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd4e872f1	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd7418dd0	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd94a2293	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd9c60eb2	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd9e750ce	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdcf668ae	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe14af3ed	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe36c5403	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe4d27342	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe4d90c17	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe564ddcc	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xec9eceee	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeee946b3	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf07dd389	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf134af90	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf22979f3	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf38d7369	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf6f32ca8	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf71d0e24	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf7b0e8de	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf90ae603	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfad499a6	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfd47d6f0	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfecb7617	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x0314d10a	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x05bb6f3c	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x090401a8	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x138256d6	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x23d3da5d	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x27957b7d	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x3a90925e	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x4d0c20b1	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x4e825e91	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x5fcc61a2	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x6e3f1451	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x6f86fba9	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x799c2c69	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x7ff3c332	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x803ba509	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x94aaaace	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x9b96ff58	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xb7a16e47	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xcd3632f5	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xda8b647b	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe815efa5	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x7d05786f	cs4271_dt_ids
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x86e7ce1d	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xbb0b5c77	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xd12ce2e3	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xf4fa2ea7	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x81eea29d	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x9c18d0be	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xf5e842b4	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x8204c5aa	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x9f4e9de2	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98090 0x2eb2b410	max98090_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98095 0x86290270	max98095_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x3bc1c1a9	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x5c94ef6a	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x6aadc81d	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x9d9699f4	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x70617a04	rl6231_get_clk_info
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x7f68b24d	rl6231_pll_calc
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x8d7fa148	rl6231_get_pre_div
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0xdba4502f	rl6231_calc_dmic_clk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5640 0xdb542297	rt5640_dmic_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0xb6442ee7	rt5645_set_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0xbe108e75	rt5645_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677 0x303a9775	rt5677_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677-spi 0x952df541	rt5677_spi_read
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677-spi 0x9bfef29d	rt5677_spi_write_firmware
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677-spi 0xdc9e2327	rt5677_spi_write
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x2e25c127	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x4aec02d8	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x6057cb45	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x9d24a9d1	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xb2c32400	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0x518b3cd9	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x4edd4012	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0xe9defcb4	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x61be0f19	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xd7907e2b	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0x5cf94c39	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0x1c79ec7e	twl6040_hs_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0x77f229c7	twl6040_get_hs_step_size
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0x8de25bac	twl6040_get_dl1_gain
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0xb2c04051	twl6040_get_trim_value
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0xeb9df689	twl6040_get_clk_id
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x194e1040	wm_hubs_hpl_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x209273ab	wm_hubs_hpr_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x23d2cbe9	wm_hubs_update_class_w
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x3f6620b2	wm_hubs_vmid_ena
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x5cd7eb9b	wm_hubs_dcs_done
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x695973b4	wm_hubs_add_analogue_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x757206d5	wm_hubs_spkmix_tlv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xaa48aa4f	wm_hubs_handle_analogue_pdata
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xc8035cf4	wm_hubs_add_analogue_routes
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xda881a53	wm_hubs_set_bias_level
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x2516276a	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x47995e50	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xb0ae9442	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xbbcd37ad	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0xdd54918d	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0x5c416143	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0x1c777905	wm8958_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0xf31c1ccc	wm8994_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/davinci/snd-soc-edma 0xe9ac67bf	edma_pcm_platform_register
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0xa549afef	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0xff40b480	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/omap/snd-soc-omap-mcpdm 0x7446f149	omap_mcpdm_configure_dn_offsets
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0x3da58553	asoc_qcom_lpass_cpu_dai_probe
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0xd23c387c	asoc_qcom_lpass_cpu_platform_remove
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0xd8e7306d	asoc_qcom_lpass_cpu_dai_ops
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0xe355bb8d	asoc_qcom_lpass_cpu_platform_probe
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-platform 0x8b29c58e	asoc_qcom_lpass_platform_register
++EXPORT_SYMBOL_GPL sound/soc/samsung/snd-soc-idma 0x776c599d	idma_reg_addr_init
++EXPORT_SYMBOL_GPL sound/soc/samsung/snd-soc-s3c-dma 0x338534e9	samsung_asoc_init_dma_data
++EXPORT_SYMBOL_GPL sound/soc/samsung/snd-soc-s3c-dma 0xc29d6b10	samsung_asoc_dma_platform_register
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-pcm 0x67bc1874	tegra_pcm_platform_register
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-pcm 0xb83b7b5b	tegra_pcm_platform_unregister
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-pcm 0xe81b2273	tegra_pcm_platform_register_with_chan_names
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-utils 0x35c88e6e	tegra_asoc_utils_fini
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-utils 0x6071ab06	tegra_asoc_utils_set_ac97_rate
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-utils 0xcbf803d2	tegra_asoc_utils_init
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-utils 0xec047df5	tegra_asoc_utils_set_rate
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra20-das 0x0d54c9b9	tegra20_das_connect_dap_to_dac
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra20-das 0xb52cfca4	tegra20_das_connect_dac_to_dap
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra20-das 0xbced7431	tegra20_das_connect_dap_to_dap
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0x04ecb471	tegra30_ahub_allocate_tx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0x55a40206	tegra30_ahub_disable_rx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0x5d7237ff	tegra30_ahub_set_cif
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0x6fe20143	tegra30_ahub_set_rx_cif_source
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0x72a91a91	tegra30_ahub_allocate_rx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xb419329b	tegra30_ahub_disable_tx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xb4a9367d	tegra30_ahub_enable_tx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xb81bca9d	tegra30_ahub_free_rx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xc78c7125	tegra30_ahub_free_tx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xccb67e55	tegra124_ahub_set_cif
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xccc98372	tegra30_ahub_enable_rx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xe549513a	tegra30_ahub_unset_rx_cif_source
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x12dbae98	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x17b7428f	line6_pcm_release
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x5ff0fd4b	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x6197f527	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x644114ef	line6_pcm_acquire
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x7375fdf7	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x7e3f376a	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x88cd3407	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x91e76085	line6_init_midi
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xa6f3e48e	line6_write_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xb0a7cfe3	line6_send_sysex_message
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xc4b64531	line6_read_serial_number
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xd079ae97	line6_read_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xdf83d012	line6_version_request_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xe9ac0b86	line6_suspend
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x3fe35aea	irq_bypass_unregister_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x418873cc	irq_bypass_register_producer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x888c5be5	irq_bypass_register_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0xf6e772c3	irq_bypass_unregister_producer
++EXPORT_SYMBOL_GPL vmlinux 0x003f2f17	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x00579b29	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x00615f01	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0x00632780	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x00694882	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x00725654	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL vmlinux 0x007763c5	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x0077e410	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x0089c787	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00a1a7b9	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x00a49148	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x00cc093a	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x01301ee3	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x014270de	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x014e050c	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x014ec8c3	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL vmlinux 0x0168bce2	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x016c890d	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x01770202	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x017986b5	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x018edcce	cpdma_ctlr_dump
++EXPORT_SYMBOL_GPL vmlinux 0x019ae694	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x01bb8a38	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x01c6cb0c	cpu_cluster_pm_enter
++EXPORT_SYMBOL_GPL vmlinux 0x01c7c8ba	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x02061c9b	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0x02150c62	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0x021e1e00	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0x0240d626	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x0245ffa5	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x02a1770a	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0x02a70bd8	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0x02e0e600	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0x02e40d55	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x02ea4e43	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x02ea8741	max_gen_clk_ops
++EXPORT_SYMBOL_GPL vmlinux 0x02ec8a2f	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x02f226ce	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x02f65e96	dev_pm_opp_remove
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x0319345e	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0x0321cdbf	of_alias_get_highest_id
++EXPORT_SYMBOL_GPL vmlinux 0x032375b0	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x03369618	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x033cc699	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x035519ea	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL vmlinux 0x035beba5	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0x03719f7f	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0x03998c7e	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x0399db50	pinctrl_pm_select_sleep_state
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03af214a	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x03de4441	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x03fc6e00	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0x0402b504	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0x040449a7	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x04153cb8	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0x0422b8f6	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0x0425bf98	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x0434063b	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x0474f07e	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0x047721cf	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0x0485da10	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04be7dd3	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL vmlinux 0x04e7219d	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x04f4bd8d	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0x04f65246	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x050d8f21	of_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x052169a4	arm_iommu_release_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x052ce4b1	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x05542702	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x0557fb33	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x0587b267	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x05915e33	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x05994a74	ahci_stop_engine
++EXPORT_SYMBOL_GPL vmlinux 0x05c2dc2c	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0x05cd7ead	of_irq_parse_raw
++EXPORT_SYMBOL_GPL vmlinux 0x05e77f70	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x05ee63e2	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x05f5c819	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0x061a4232	cpsw_ale_stop
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x0625a328	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x06438115	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x065beac7	ahci_platform_suspend_host
++EXPORT_SYMBOL_GPL vmlinux 0x069bd27e	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL vmlinux 0x06af5189	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x06d549e6	pinctrl_free_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x06dd5d38	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x06f4e90a	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0x07032f9e	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x0722d5ed	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x074b95bc	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x07546c32	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x07684a40	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x078da988	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x07a6dedd	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x07a808b5	vchan_find_desc
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07cc2827	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0x07cf7d18	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x07d56b7b	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07d67c9c	omap_dm_timer_write_status
++EXPORT_SYMBOL_GPL vmlinux 0x07e36cea	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x080b3008	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x0811805d	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x083fe7dd	omapdss_of_get_next_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x087c3340	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0x087eb16c	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x088d3681	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL vmlinux 0x08a5fabe	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x08b5656a	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0952af60	fb_videomode_from_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x0961fb9c	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0x0967eaf1	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x097b747f	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL vmlinux 0x09ba92a2	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0x09bb945d	pinctrl_lookup_state
++EXPORT_SYMBOL_GPL vmlinux 0x09c367e5	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x09ce1ffa	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL vmlinux 0x09ebbbca	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL vmlinux 0x09ff18bc	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL vmlinux 0x0a075732	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0x0a2f79e7	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x0a56a482	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x0a58e3f1	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0x0a7e065a	sdhci_resume_host
++EXPORT_SYMBOL_GPL vmlinux 0x0aa5fc30	snd_soc_register_codec
++EXPORT_SYMBOL_GPL vmlinux 0x0ac015ee	mpc8xxx_spi_rx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x0ad9dc80	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x0ae8927b	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x0afc7351	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0x0afd4610	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b195fcf	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x0b1dac4f	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x0b5a3606	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0x0b6003f6	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL vmlinux 0x0b6a86fb	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x0baaf2ea	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0x0bb3e9f3	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0x0bb56eaa	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0x0bbae511	return_address
++EXPORT_SYMBOL_GPL vmlinux 0x0bcb5187	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x0bde0fa0	clkdev_create
++EXPORT_SYMBOL_GPL vmlinux 0x0be08d57	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x0bf02d60	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0bfd7575	__clk_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x0c00226d	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c0cc728	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c3bab44	mtd_is_locked
++EXPORT_SYMBOL_GPL vmlinux 0x0c509a32	clk_hw_get_num_parents
++EXPORT_SYMBOL_GPL vmlinux 0x0c634ecf	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x0c70e1bc	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x0c89f3e8	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x0c8d39bd	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x0c960e61	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0x0ca844a8	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0x0cabfad3	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0d158450	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x0d2260e3	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x0d2570e8	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0x0d3042a0	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL vmlinux 0x0d46f83c	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0d8a4ac0	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL vmlinux 0x0d8c06ca	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x0d908d95	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x0d9b7f5e	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x0d9e8754	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0x0dc641e8	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL vmlinux 0x0dd5e94b	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0de15d79	pinctrl_get_group_pins
++EXPORT_SYMBOL_GPL vmlinux 0x0deab245	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x0e083633	snd_soc_platform_read
++EXPORT_SYMBOL_GPL vmlinux 0x0e31baf4	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x0e4f5cd0	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x0e5b9f1f	mv_mbus_dram_info_nooverlap
++EXPORT_SYMBOL_GPL vmlinux 0x0e7d48a4	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x0e8a574a	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x0eb7f9a2	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x0ee87b95	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x0efe3a46	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x0f289ac1	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f49f121	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0x0f4b2f37	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0x0f5bb12e	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x0f73b376	omapdss_of_get_first_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f8a5ba0	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0x0fd644c0	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x0ff9af09	cpdma_ctlr_int_ctrl
++EXPORT_SYMBOL_GPL vmlinux 0x1009a95c	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x103259f0	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x103373a1	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0x106f9c51	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0x1073f2d6	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x10752674	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x1082b508	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x108a856f	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x10c953eb	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0x10e74e9a	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x11023b92	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0x11025677	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x110af8d4	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x11337387	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x11568563	mtd_read
++EXPORT_SYMBOL_GPL vmlinux 0x115d5fc9	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x115f88ed	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x11d7589e	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x11ed8376	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0x1218d2d9	of_dma_xlate_by_chan_id
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x124f4c6e	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0x1256c859	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x125d35e5	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x125d89cb	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x1265fbbc	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x1280a745	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x12b0d301	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x12bf6bc5	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x12df2d8e	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x12e0f630	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0x12e994c5	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0x13059625	of_dma_get_range
++EXPORT_SYMBOL_GPL vmlinux 0x13100499	vchan_init
++EXPORT_SYMBOL_GPL vmlinux 0x1318821c	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131b301f	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x1320f00e	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL vmlinux 0x13241d45	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0x13347a33	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x13354608	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0x1355d415	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0x135c6315	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x135c6b58	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x136cb3a5	of_clk_get_parent_count
++EXPORT_SYMBOL_GPL vmlinux 0x1381ac91	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0x1381d4f3	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x138bcc16	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x13984ba7	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0x13a7b075	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0x13b53f78	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x13b89dee	pinctrl_request_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x13d6ecb9	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0x13e02dc9	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0x13f19f04	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x13fc3a4a	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x140e2be2	dev_pm_opp_find_freq_exact
++EXPORT_SYMBOL_GPL vmlinux 0x1421a78d	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0x142f240e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0x144093f1	register_mtd_user
++EXPORT_SYMBOL_GPL vmlinux 0x14611525	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x14614920	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x14756950	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x14a98a21	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x14ca398b	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x14db8c6d	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL vmlinux 0x14f09e04	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x15047acd	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x150ad6ee	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x1514b45e	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0x152aef32	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x1533a7ae	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x155694a1	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x15ae2bbf	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0x15b5efa1	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0x15c72bbf	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0x15dcd870	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x15e06ef5	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0x15e666dd	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x15f41a9b	pinctrl_force_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x1628cd68	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x16529add	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x1658d218	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x165d9fa7	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0x1670f6d8	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x16730eeb	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x167b8151	of_irq_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x16831fb9	sm501_modify_reg
++EXPORT_SYMBOL_GPL vmlinux 0x168431f5	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x16ac0a63	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x16b51d5e	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x16b6cd2c	dev_pm_opp_get_max_clock_latency
++EXPORT_SYMBOL_GPL vmlinux 0x16c310d4	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x16c7674d	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0x16ed6929	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0x16f020bb	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0x16f1cd69	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x170b403a	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x170e1de1	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0x1717a05d	omap_get_plat_info
++EXPORT_SYMBOL_GPL vmlinux 0x17405494	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0x17449cf0	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x17474eaa	of_platform_default_populate
++EXPORT_SYMBOL_GPL vmlinux 0x175651c0	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL vmlinux 0x1756fe11	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x175b0cee	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x178034b3	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x1787f0f7	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0x180b2776	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0x1825bea8	dev_pm_opp_of_remove_table
++EXPORT_SYMBOL_GPL vmlinux 0x18267f24	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0x1831473f	of_prop_next_u32
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1869d087	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x189f76a0	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x18b68d2f	of_pci_get_host_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x18b9e4e7	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0x18cb1317	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x18e8cf17	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x18ef108b	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x191193c8	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0x192441c6	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x1927a4c9	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x192c07e8	mtd_device_parse_register
++EXPORT_SYMBOL_GPL vmlinux 0x1949d61e	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x1979165c	of_console_check
++EXPORT_SYMBOL_GPL vmlinux 0x1980b04f	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0x1990f8ff	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19b0e9b5	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0x19e03653	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x19f27d5b	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1a1c4082	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x1a3a3cf5	pinctrl_select_state
++EXPORT_SYMBOL_GPL vmlinux 0x1a3d97ca	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0x1a41d490	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x1a52e49f	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x1a62e046	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0x1a661ac4	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1aabe552	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x1ac3e3a7	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0x1ac6da1f	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1aea587f	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x1affbfb7	uniphier_pinctrl_probe
++EXPORT_SYMBOL_GPL vmlinux 0x1b110af9	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x1b1222a1	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0x1b2fc99b	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x1b30062b	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0x1b3261e0	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x1b52db1c	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x1b827f4a	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1b8822d8	pinctrl_gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x1b923d01	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1b9c4b9a	ahci_check_ready
++EXPORT_SYMBOL_GPL vmlinux 0x1bb5fc26	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x1bc5eebe	pinctrl_gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x1bcb9773	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x1bff9e7c	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL vmlinux 0x1c072354	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0x1c20a42e	dev_pm_opp_get_freq
++EXPORT_SYMBOL_GPL vmlinux 0x1c373c9c	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c5a7391	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c5ff742	clk_get_phase
++EXPORT_SYMBOL_GPL vmlinux 0x1c63bef8	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL vmlinux 0x1c716881	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0x1c74156b	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1c760a46	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1d08a9bc	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x1d0a396c	snd_soc_register_component
++EXPORT_SYMBOL_GPL vmlinux 0x1d20964c	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d2c664a	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x1d4d65ab	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d6a58d2	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL vmlinux 0x1d73c494	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1d7cb586	clk_register_fixed_rate_with_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x1db0f9f0	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x1dc06fe9	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0x1dda96ed	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL vmlinux 0x1debe39e	of_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x1e07ee2f	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x1e2e36be	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e65addb	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x1e66d0e1	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL vmlinux 0x1e76bb9d	of_fdt_unflatten_tree
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e7d6157	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x1e861e4a	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1ea7b2af	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x1eb520ba	pinctrl_dev_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebd7712	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ec6247a	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x1eddfdff	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0x1ee721a8	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL vmlinux 0x1eec6f22	pci_msi_create_irq_domain
++EXPORT_SYMBOL_GPL vmlinux 0x1f217a08	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x1f244d01	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL vmlinux 0x1f3b709a	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0x1f5a1b8d	snd_soc_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x1f6fad8c	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x1f774f46	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1f9ff2ff	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x1fa96f3b	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1fb41f5a	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x1fb716f2	mtd_is_partition
++EXPORT_SYMBOL_GPL vmlinux 0x1fb9cd81	of_thermal_get_ntrips
++EXPORT_SYMBOL_GPL vmlinux 0x1fcc41dc	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x1fe03744	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0x1fef430e	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0x1ff6c8b8	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL vmlinux 0x203e5322	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x205c01a5	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0x205f5dbe	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x2081f581	bgpio_remove
++EXPORT_SYMBOL_GPL vmlinux 0x20a1892b	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x20a692de	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x20befb17	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0x20e4ed1a	clk_hw_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x20f269f6	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x2101f42e	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x21091318	of_mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x210a348d	arm_iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0x2114d49a	musb_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x212335f3	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0x212d7c19	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x21395662	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x215b932d	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0x21667e6f	pinctrl_utils_reserve_map
++EXPORT_SYMBOL_GPL vmlinux 0x21693b72	usb_gadget_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x216a2dcd	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x21a563da	clk_get_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21c05b34	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21d5242c	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x21d75732	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x21f3143e	of_modalias_node
++EXPORT_SYMBOL_GPL vmlinux 0x21febf58	clk_register_mux_table
++EXPORT_SYMBOL_GPL vmlinux 0x2202bd56	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0x220a4554	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0x22120089	omap_dm_timer_read_counter
++EXPORT_SYMBOL_GPL vmlinux 0x22125c70	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL vmlinux 0x22192b48	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x222454e1	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x222bd455	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x222f0265	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x22698b5d	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x226a674d	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2277f829	snd_soc_component_read
++EXPORT_SYMBOL_GPL vmlinux 0x227a7b5b	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x2293a3df	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x229a27dd	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x22f10470	of_pci_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x22f14c10	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0x22f2eb54	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x22f42f75	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2302ea71	sm501_set_clock
++EXPORT_SYMBOL_GPL vmlinux 0x230c78ba	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x2315a82c	clk_mux_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL vmlinux 0x23456075	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x23647123	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x23756cdb	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x2383618b	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x23887df1	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0x2392f1a5	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x2396c7f0	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0x23b34307	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x23d17fb6	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x23fc94e2	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x240068dc	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x2401fdef	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x24220fc6	sdhci_free_host
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x244c1899	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0x247223cc	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x24a23a90	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24b35a39	of_get_nand_ecc_strength
++EXPORT_SYMBOL_GPL vmlinux 0x24bae359	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL vmlinux 0x24c3999b	cpsw_ale_create
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24efe2dc	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x25379e73	clk_set_min_rate
++EXPORT_SYMBOL_GPL vmlinux 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL vmlinux 0x25a69457	clk_hw_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x25a75b5a	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x25b219c6	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x25cf806e	snd_device_disconnect
++EXPORT_SYMBOL_GPL vmlinux 0x25d13a71	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x25e349e9	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0x25e4fa8c	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x25e90350	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x26085a7e	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x260d2be1	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x261098a6	of_display_timings_exist
++EXPORT_SYMBOL_GPL vmlinux 0x261917f3	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x2620e343	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x26449489	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0x2649ad84	amba_ahb_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x26997fa3	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x26adb815	thread_notify_head
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c547c0	bL_switcher_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x26c8b665	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26d9e265	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x26e02ba4	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0x26f22a53	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x27188398	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x271a2756	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x2733997b	of_get_nand_ecc_mode
++EXPORT_SYMBOL_GPL vmlinux 0x274cf5e1	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x274f7183	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x275b869f	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x275c6445	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x275d82bd	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2787db00	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x279c5a18	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x27af539f	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x27bfb84c	imx_pcm_dma_init
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x28100121	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0x2812e97d	mtd_get_device_size
++EXPORT_SYMBOL_GPL vmlinux 0x281914a0	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x281b05ff	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x2825a3e5	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x283dcb6c	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x28428026	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x2866610a	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0x2868f3ca	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0x287a029b	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x2886d374	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x288a3afb	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0x288e3683	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0x289782a2	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x28b0ed78	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x28de6ae3	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x2931479d	mpc8xxx_spi_tx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x29436b06	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL vmlinux 0x296c5ce4	mtd_block_markbad
++EXPORT_SYMBOL_GPL vmlinux 0x29715cf2	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL vmlinux 0x29740577	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL vmlinux 0x297dff57	snd_soc_platform_write
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x29d4f664	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x29de2f61	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x29e606ba	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL vmlinux 0x29ff67c6	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0x2a06b77c	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x2a1959ed	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x2a2c6254	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0x2a3e6b28	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0x2a5783c3	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2a5b5501	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x2a610fa1	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a816a05	dev_pm_opp_of_cpumask_add_table
++EXPORT_SYMBOL_GPL vmlinux 0x2aa84f52	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x2aae43f7	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x2ad52abb	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x2ad7afe7	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x2ad9d326	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x2ae04de3	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0x2ae356a7	omap_dm_timer_set_pwm
++EXPORT_SYMBOL_GPL vmlinux 0x2ae5394e	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0x2af2cd1c	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x2af9fdd0	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b2f2093	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x2b4352c8	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL vmlinux 0x2b54aa52	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x2b57d26b	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x2b639d66	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2b7a940a	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x2b92adcc	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0x2b952517	clk_has_parent
++EXPORT_SYMBOL_GPL vmlinux 0x2babe81f	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x2bd186df	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x2beaef51	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x2c144af3	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c4aef8d	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x2c6a1115	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c97f8a2	of_reconfig_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2cb3c34c	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0x2cdd580d	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0x2ce152cd	pinctrl_utils_add_map_configs
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2ce9bc45	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2ced3de3	clk_gpio_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2cf76482	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0x2d0039a6	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d1dd6ad	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0x2d29db30	arizona_of_get_named_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x2d3bdd63	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d5c3e55	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x2d6d2e54	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x2da3ecbb	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0x2dad9b05	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x2db8fd29	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0x2dcaafb7	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0x2dcc544a	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0x2de681b6	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x2df4a259	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0x2e1eb3bf	ahci_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e278f88	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0x2e29ad8b	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e5770c7	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL vmlinux 0x2e66777f	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2e742b00	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0x2e9600c3	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0x2e9670c0	pl320_ipc_transmit
++EXPORT_SYMBOL_GPL vmlinux 0x2e9ef6f1	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0x2ea1a1f2	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x2eae4a26	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ec53d99	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2ed24d49	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x2ef4d512	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x2ef6b5bf	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x2f05441c	of_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0x2f0567aa	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f11f02e	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x2f27560f	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x2f308d75	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x2f3bcdeb	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f90da7e	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0x2fc7b541	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x2fd42faf	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0x2fd715a7	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL vmlinux 0x301920aa	clk_hw_get_parent_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x301e248b	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x3033c58c	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0x303c1831	of_overlay_create
++EXPORT_SYMBOL_GPL vmlinux 0x3051984a	omap_iommu_restore_ctx
++EXPORT_SYMBOL_GPL vmlinux 0x305f2fd1	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL vmlinux 0x3086f9e3	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x308fab33	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x30911176	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x30a2b5f5	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x30a4f4ca	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0x30a7d024	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30aad433	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x30bce10c	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30d442ab	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0x30f044cc	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x3100bf02	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3122628a	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x312eaba2	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL vmlinux 0x314172aa	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x314d5b42	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x314e9318	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x3166fa65	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0x316e46f4	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0x3188b2a6	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x319d73fb	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31cfe2d6	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x31d78f73	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x31e0d4a0	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x31eda93b	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x31f6ac52	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x31f701c5	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x320d3e81	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0x321483e1	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x322b3bee	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0x3237f811	ahci_print_info
++EXPORT_SYMBOL_GPL vmlinux 0x32419fb9	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x3250e5aa	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x3264cac9	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0x327cac88	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x3282fe36	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0x328459af	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x3295ec8b	of_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32d10d43	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x32f97a8d	thermal_zone_of_sensor_register
++EXPORT_SYMBOL_GPL vmlinux 0x3300387a	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x331f420e	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0x3320f8eb	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3341dcee	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x3349089c	mtd_read_oob
++EXPORT_SYMBOL_GPL vmlinux 0x33567f82	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x335b3d76	clk_hw_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x3398c670	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0x33993b2b	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0x339f0020	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0x33ba0509	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0x33fc6ef4	dev_pm_opp_of_cpumask_remove_table
++EXPORT_SYMBOL_GPL vmlinux 0x33fefed6	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x341643ba	omap_dm_timer_modify_idlect_mask
++EXPORT_SYMBOL_GPL vmlinux 0x3432f510	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x3445f4ba	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0x34725681	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x347682ce	snmp_fold_field64
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x349aba94	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34a9e866	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0x34aa3d08	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x34ac50a4	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x34c710dd	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x34ce1c26	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0x34ef5738	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3529f03a	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x353aab28	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x35410ec6	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL vmlinux 0x356853c0	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x356be80d	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x357745a0	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x357c0f5a	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x35817268	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x35a01f05	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0x35ac128a	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x35dcd1f7	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x35e0f118	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0x35f3b0c0	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x362c03b8	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x362f8627	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x363eadb1	of_irq_get_byname
++EXPORT_SYMBOL_GPL vmlinux 0x364ada5a	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0x364e0044	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0x36740b27	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x36783070	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x368a2604	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36ad2f87	snd_soc_component_write
++EXPORT_SYMBOL_GPL vmlinux 0x36ad5cfa	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x36de0ca0	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x36e26658	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x36fb7480	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x371f658a	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0x372c18e3	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x37302958	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0x374d9a27	of_property_read_u64
++EXPORT_SYMBOL_GPL vmlinux 0x3776d6c1	tegra_pinctrl_remove
++EXPORT_SYMBOL_GPL vmlinux 0x378edb3d	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL vmlinux 0x37df0e23	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x380f825f	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x382602f3	omap_dm_timer_set_prescaler
++EXPORT_SYMBOL_GPL vmlinux 0x382aad29	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x382e57f5	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0x38618cb0	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x38639300	of_overlay_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x38697f6a	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x386b6a44	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0x387f3aca	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL vmlinux 0x38a4ebae	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x38a9c2c7	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x38b527e9	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x38cb0c38	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x38dfb3f4	omapdss_of_find_source_for_first_ep
++EXPORT_SYMBOL_GPL vmlinux 0x38e372d0	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x38e5bc5a	clk_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x38f784e2	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0x390dd184	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0x39290e1c	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x392aae93	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x394496da	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x394972bb	sdhci_alloc_host
++EXPORT_SYMBOL_GPL vmlinux 0x396c8d2c	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x398c6b5a	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x398e67e5	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x39a5ef2f	of_irq_find_parent
++EXPORT_SYMBOL_GPL vmlinux 0x39b598d1	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39d14265	mtd_block_isreserved
++EXPORT_SYMBOL_GPL vmlinux 0x39d1d043	of_pci_find_msi_chip_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x39d672fa	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0x39e1fc59	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x39e73ec9	of_get_nand_on_flash_bbt
++EXPORT_SYMBOL_GPL vmlinux 0x3a02c870	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x3a15a2b5	of_pci_range_parser_one
++EXPORT_SYMBOL_GPL vmlinux 0x3a16417f	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a2f53e1	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3a394b4c	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0x3a39f91a	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x3a3db234	divider_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x3a42dfe1	sm501_find_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a59f629	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0x3a5f8095	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x3a712d22	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x3a926a47	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3a9d93e1	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3aeeccc4	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0x3b0ebb12	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x3b1831fe	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x3b20453e	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x3b2a2c8a	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0x3b3f4d6d	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0x3b47df8f	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0x3b547bc9	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x3b76f97f	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x3b87394b	__tracepoint_detach_device_from_domain
++EXPORT_SYMBOL_GPL vmlinux 0x3b96be7a	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3ba6651e	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0x3bb1c026	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x3bc6b0ac	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x3bca2eb0	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0x3bdaf384	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0x3be26f7b	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x3bf67789	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0x3bfa6694	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x3c09c859	mtd_table_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x3c20efd4	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x3c2a202e	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3c5157fe	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL vmlinux 0x3c5fa08b	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x3c831441	arm_check_condition
++EXPORT_SYMBOL_GPL vmlinux 0x3c8c9015	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3c93ea25	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x3c956d10	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x3cbb9752	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0x3cbd4e81	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x3cbf7803	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x3cc0ffa9	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0x3cc50447	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cf5625a	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x3cf637c8	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3d15dc6f	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x3d16f4d0	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0x3d2118d8	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x3d314491	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d44f84a	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3d732c4c	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0x3d75fcbf	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0x3d817adc	ahci_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0x3db1674b	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0x3dc526a9	arizona_of_match
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3dd4d3a7	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3debd974	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0x3e2d6df3	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3e31d9c3	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x3e37ffe4	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0x3e38c3bc	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x3e410620	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e836e58	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x3e98aad3	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x3e9e4c1e	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x3ebee169	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x3ee37432	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f25ff7b	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3f298cef	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x3f4bb005	rq_flush_dcache_pages
++EXPORT_SYMBOL_GPL vmlinux 0x3f664fa5	__tracepoint_map
++EXPORT_SYMBOL_GPL vmlinux 0x3f8af5c2	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0x3fa9bfdc	of_alias_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x3fab4f23	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL vmlinux 0x3fc5fdbb	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x3fdc4046	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0x3ff16a52	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0x3ffdc1a4	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x40189e47	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x401adc60	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0x401d6bd6	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x402a1330	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4044dc1e	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x4058b88b	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x407acff1	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0x407ff12f	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0x408085fa	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x40947605	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x40a09493	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x40a2ff53	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0x40abfa54	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x40f350e9	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x40f85c76	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x40ff92ad	omap_dm_timer_start
++EXPORT_SYMBOL_GPL vmlinux 0x4112cecc	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x413ffd27	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0x414c89cf	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x415d5705	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x418de6b8	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x4194f554	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0x41961fec	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0x41c5274c	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x41fb747d	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL vmlinux 0x42025883	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x4205ad24	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x421b438a	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x4223be60	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x423b0dbc	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x42423bb9	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x42583f1b	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x42635d55	pm_suspend_global_flags
++EXPORT_SYMBOL_GPL vmlinux 0x426ecf79	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42909a02	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x4292c50d	mtd_add_partition
++EXPORT_SYMBOL_GPL vmlinux 0x42a5f282	snd_soc_register_platform
++EXPORT_SYMBOL_GPL vmlinux 0x42a8cc91	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x42ababa1	omap_dm_timer_get_fclk
++EXPORT_SYMBOL_GPL vmlinux 0x42ac8612	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x42b364ef	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x42b77fec	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x42d8e1b4	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x42e80724	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x430fcba0	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x43227dc3	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL vmlinux 0x432f16d7	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x436bc995	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x436dbf6d	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0x437487c0	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x43876e57	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43b0cdc0	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x43ccd344	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x43f81957	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x44020321	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x44088a5e	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0x441d8ef5	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x444f1735	cpu_pm_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4452ecff	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x4463545e	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x44694817	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0x4474aeee	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x44811ab6	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x448c6f58	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44bfe36d	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0x44cce7f8	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x44e2e6bc	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x44f1cd1d	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x44f442ae	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x450e7e58	omap_dm_timer_request_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x451e435b	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0x4525f69b	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x452f0de3	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0x453b20e6	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x45692e2e	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL vmlinux 0x45699f36	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x45970d82	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x45a1a0ae	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0x45adbe71	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x45ba1367	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45e8fe1c	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x46066e5b	perf_pmu_name
++EXPORT_SYMBOL_GPL vmlinux 0x4608f58e	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x4641d4c7	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x465bf04b	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0x4663ec5b	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x466e5342	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x46776174	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x469cc2ca	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x46bfa772	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x46cd261e	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x46d0f2e4	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0x46d88039	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x46ddac59	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x46e2e153	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x472b086d	dev_pm_opp_find_freq_floor
++EXPORT_SYMBOL_GPL vmlinux 0x4744b9fd	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x476498ce	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x47797937	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x477a8e4f	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47acf6e1	dev_pm_opp_init_cpufreq_table
++EXPORT_SYMBOL_GPL vmlinux 0x47b0d809	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x47c783d9	iommu_capable
++EXPORT_SYMBOL_GPL vmlinux 0x47d9f8dd	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0x47de0dc7	clk_unregister_mux
++EXPORT_SYMBOL_GPL vmlinux 0x4813fda2	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4828638c	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0x48475a27	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x485d6f76	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x4871fb7c	__tracepoint_io_page_fault
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x48d1f4af	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0x48f677cb	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x491f1e1d	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4977013b	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL vmlinux 0x4982a57f	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x4986b12a	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x49ae817e	pm_genpd_syscore_poweron
++EXPORT_SYMBOL_GPL vmlinux 0x49be82c1	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x49ed8401	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0x49ededab	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x49fcd405	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x4a1984cb	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x4a1eee12	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x4a268288	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a63f3b2	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x4a663f49	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x4a69fc58	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4a8119fb	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x4a8e1546	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x4a965300	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL vmlinux 0x4a987367	fsl8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4ab1a16b	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x4ab97728	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0x4abfc42b	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0x4aeb3558	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0x4b721776	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0x4b7c8e00	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0x4b8625ac	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0x4b991631	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL vmlinux 0x4bafcdd8	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0x4bb61ad6	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0x4bd369e1	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4bd5e6ae	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x4bea2953	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x4beb4bbc	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x4bf1debc	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4c00747f	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x4c120e92	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0x4c3d11ef	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0x4c45f4e9	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0x4c47ec15	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x4c5353f0	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4c5c98f8	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c6ff881	pinctrl_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x4c78f7a8	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x4c7e2bce	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL vmlinux 0x4c94e6fd	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x4c9b40ae	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL vmlinux 0x4c9e2011	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x4ca2d78e	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0x4cadc915	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x4cc594e2	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x4cd72083	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x4ce40c43	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0x4ce79375	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d21ad08	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x4d24e475	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4d26c955	irq_of_parse_and_map
++EXPORT_SYMBOL_GPL vmlinux 0x4d38f1e0	bL_switcher_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4d912616	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x4d968513	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0x4d981315	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x4d98b3ff	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4d9d1f4b	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0x4dbe8d71	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4de5cea3	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x4e060d9b	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4e0d016c	of_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x4e0e359f	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e134a5d	omap_dm_timer_set_source
++EXPORT_SYMBOL_GPL vmlinux 0x4e1560c3	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e2c2dd2	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x4e2e838d	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x4e329ff8	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4e32f117	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x4e6f100d	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0x4eb520a8	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0x4eb813bf	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x4ee261bd	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5a2a3	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f17318a	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f3a379d	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4f459792	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4f54c694	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL vmlinux 0x4f5b52f1	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4f7200c9	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4f80f88d	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0x4f848ba7	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x4f8849d4	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x4f97a2b0	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x4f98d766	cpu_pm_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4fa6bb98	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0x4fd158f3	of_clk_del_provider
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fde1d42	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4ffa5bf3	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x5010b816	otg_ulpi_create
++EXPORT_SYMBOL_GPL vmlinux 0x50271d7a	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0x50362600	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x5044f31f	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x50567edb	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x505b1fd9	dev_pm_opp_disable
++EXPORT_SYMBOL_GPL vmlinux 0x506ac0e2	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0x5074734d	of_css
++EXPORT_SYMBOL_GPL vmlinux 0x50806149	pinctrl_dev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x5080c352	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x50a7914c	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x50b04760	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x50b27706	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x50b536c5	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL vmlinux 0x50b8fa35	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x50b92a15	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x50c89f23	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x510e2cff	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x511fa67c	of_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x5131e6bd	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL vmlinux 0x51472217	snd_soc_test_bits
++EXPORT_SYMBOL_GPL vmlinux 0x514a4b02	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x514e9875	divider_get_val
++EXPORT_SYMBOL_GPL vmlinux 0x51855f81	__tracepoint_remove_device_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x518a6562	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0x51ac102f	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x51b7db52	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x51c0ad41	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL vmlinux 0x51e75d3d	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x51f37e85	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x5200c3b4	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x5208e43b	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0x5209e713	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x5213ef4f	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0x521655b7	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x52192216	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x522dea6b	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0x526280c7	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0x5272d8bc	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0x5289745a	max_gen_clk_probe
++EXPORT_SYMBOL_GPL vmlinux 0x52906617	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL vmlinux 0x52a30a8d	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0x52a41251	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x52b549c4	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x52b92206	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x52c0d5d8	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x52cee151	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0x52d46a51	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x52d569cf	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x52f26e97	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x52f94fe3	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x5317d310	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x538e84bb	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x53ae589b	i2c_slave_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x53ceec13	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0x53ea310f	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x53ee0c2e	pinctrl_find_gpio_range_from_pin
++EXPORT_SYMBOL_GPL vmlinux 0x53f93344	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0x53fb67a6	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x54085b8d	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x544aab61	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0x545fec86	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x54763681	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x547b70fe	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x548c65c1	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54b60b4b	__clk_mux_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x54b82227	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x54c25417	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x54d468f1	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x54eb144e	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x54ed8414	mtd_erase_callback
++EXPORT_SYMBOL_GPL vmlinux 0x55014f8b	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x55076506	of_thermal_is_trip_valid
++EXPORT_SYMBOL_GPL vmlinux 0x551398ed	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x55145f4a	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x551e2197	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0x552728f6	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x55467007	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x556398e6	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x556e4390	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x557474c7	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x557b60cf	pl08x_filter_id
++EXPORT_SYMBOL_GPL vmlinux 0x55a66f1a	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x55cfbe63	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0x55dd149b	pm_genpd_init
++EXPORT_SYMBOL_GPL vmlinux 0x55e023e2	devm_pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0x55e6347b	mtd_del_partition
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x55fcf8ac	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0x5601b2b1	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0x561af04c	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x562df030	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x5652a0fd	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x5699dbcc	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x56a94123	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL vmlinux 0x56b63670	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56e9103b	cpu_pm_enter
++EXPORT_SYMBOL_GPL vmlinux 0x56ed29a9	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x56fcc49e	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x5712e484	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x573dc48e	of_dma_configure
++EXPORT_SYMBOL_GPL vmlinux 0x57557406	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x575c540e	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0x5777e456	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x577f975a	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0x57833c3f	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x57962c46	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57b8d13d	irq_chip_ack_parent
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x57e796d9	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x58063ede	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x580d7bd3	omap_dma_filter_fn
++EXPORT_SYMBOL_GPL vmlinux 0x584964af	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x584e89f5	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0x58500404	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL vmlinux 0x5882eae8	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x5894f8ad	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58a87d7d	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0x58ade16c	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x58b2878f	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0x58bd4836	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x58c0f833	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x58d5e7b7	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x590e1f09	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL vmlinux 0x59129a74	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x5919e8af	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x591d44ce	pinctrl_pm_select_idle_state
++EXPORT_SYMBOL_GPL vmlinux 0x5925cc80	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0x5929e21a	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x594cde67	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0x594dee1c	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x5955d0e8	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x595d002e	mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x595ec5d4	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x59638113	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0x59740ba7	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x5975866a	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x5983768b	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0x5986a0d1	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0x599b41f2	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0x59ae74b0	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x59d4fe58	component_add
++EXPORT_SYMBOL_GPL vmlinux 0x59d711dc	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x59eb3303	phy_pm_runtime_put
++EXPORT_SYMBOL_GPL vmlinux 0x5a0780fe	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL vmlinux 0x5a1e89b9	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x5a220b8d	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0x5a25c676	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x5a49af25	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x5a5ad32a	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0x5a6f0314	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a8f213c	cpdma_ctlr_eoi
++EXPORT_SYMBOL_GPL vmlinux 0x5aa81d35	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0x5acf6567	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x5ad670a4	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5b09b8ea	of_genpd_del_provider
++EXPORT_SYMBOL_GPL vmlinux 0x5b295df5	user_update
++EXPORT_SYMBOL_GPL vmlinux 0x5b3da68a	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x5b4b56be	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x5b5104fd	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x5b623d88	omap_dm_timer_free
++EXPORT_SYMBOL_GPL vmlinux 0x5b6362c0	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x5b8fd0e9	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5b9bfb71	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x5bb415bd	of_devfreq_cooling_register_power
++EXPORT_SYMBOL_GPL vmlinux 0x5bbd00b1	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bd29d7c	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x5bd7e7a3	snd_soc_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5c021739	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x5c0c06d4	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0x5c14bfc0	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0x5c2fe4a5	cpdma_chan_stop
++EXPORT_SYMBOL_GPL vmlinux 0x5c397b2b	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0x5c5904cc	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c5f3bbe	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0x5c604f0c	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0x5c724709	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x5c84364b	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x5c910743	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0x5c98285e	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cb0b843	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x5cc31ee1	of_prop_next_string
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5cc8bc0a	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x5cc9ecfd	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x5cd44320	of_pci_get_devfn
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d153a7a	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0x5d19c3e3	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0x5d1e4ec7	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0x5d22f320	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x5d51bcf7	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0x5d5ee71c	nand_release
++EXPORT_SYMBOL_GPL vmlinux 0x5d8fd7dd	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x5d911686	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x5d921cfe	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5db6ad1c	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0x5ded83de	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0x5dff6fda	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x5e0a4f23	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0x5e134147	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5e271037	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5e515be6	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5ea20b6b	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x5eacee6b	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x5ec37258	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0x5ef2f2f2	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0x5eff8f7f	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5f01bee4	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0x5f050c03	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x5f0ca236	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0x5f22400f	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x5f36cb29	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5f39cb4e	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0x5f460f28	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x5fae2c8c	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x5fd59024	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0x5fe70002	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0x60091316	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x6029e9a9	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x60351573	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0x6035b78e	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x603c0313	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x6045581b	mpc8xxx_spi_rx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x6046c07e	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x60583fa3	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0x60603d5e	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x60688e4f	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x6075d0c7	omap_tll_init
++EXPORT_SYMBOL_GPL vmlinux 0x608ace20	tegra_pinctrl_probe
++EXPORT_SYMBOL_GPL vmlinux 0x609a607e	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x60a08300	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60abe362	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x60dc0b84	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0x60e99147	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x60f6e6d4	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x60fec0f2	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0x610eae4f	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0x6150b4ed	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x61539990	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x6172a6be	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x6184006a	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x6187a54a	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x618df166	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0x61a40dc3	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0x61c6ab11	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x61df953f	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0x61e30030	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0x61e44c15	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0x61ebf268	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x61effa8f	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x61fecd86	of_resolve_phandles
++EXPORT_SYMBOL_GPL vmlinux 0x61ff3859	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0x6210299e	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x62159ca9	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x621ed51d	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x623ae58d	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x62452a61	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0x62590ff8	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0x6276fc5b	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL vmlinux 0x62b78d26	of_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x62c7280b	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0x62db8bff	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0x63150e06	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x631eaab7	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x6327194a	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x632756e4	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x634cdfbb	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0x635ee8a0	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x6374ae28	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0x6375b87f	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x63a6199a	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0x63a77a30	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x63b81816	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0x63c04985	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x63c1c14c	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x63e17b86	divider_recalc_rate
++EXPORT_SYMBOL_GPL vmlinux 0x63f023aa	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x64087c73	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x64154792	of_thermal_get_trip_points
++EXPORT_SYMBOL_GPL vmlinux 0x64256424	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0x6425b243	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x6427956b	ahci_shost_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x643476eb	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x64426ed8	omap_dm_timer_write_counter
++EXPORT_SYMBOL_GPL vmlinux 0x64600633	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0x647537f3	pl320_ipc_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x649f0259	pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0x64a9e840	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x64b88b0f	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0x64d36333	__of_genpd_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0x64eb76ae	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0x64edceb3	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x64efc38b	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL vmlinux 0x64fd0ae5	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0x64fe581d	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x65217a47	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0x65409a67	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL vmlinux 0x65427d72	__tracepoint_attach_device_to_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6543258d	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x65537437	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x655fcb8c	icst_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x657c58c9	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x65806f89	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x65889e08	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65c04970	imx_pcm_fiq_exit
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65e73808	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0x66017ed5	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x66033f5f	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x66133e9d	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x66353103	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x663d9e9a	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x664730bd	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0x6661763c	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x667fe5f3	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x66a299af	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x66b21840	snd_device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66ee0ad7	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x66f1cb4b	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0x670ba98e	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0x670e2d64	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x67283407	ahci_reset_controller
++EXPORT_SYMBOL_GPL vmlinux 0x67386c58	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6756695e	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0x6761a62f	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x679a6c99	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x67b491f4	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0x67b6af02	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x67c1ae2d	of_irq_to_resource_table
++EXPORT_SYMBOL_GPL vmlinux 0x67c5dffd	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0x67e4be68	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x67e8ddbc	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL vmlinux 0x680c3168	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x68194e52	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6838faee	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0x684d2c2b	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6866a75c	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0x68857f45	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0x689140b5	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL vmlinux 0x689ee539	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0x68bff004	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x68db3ab9	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x68e47b2c	cpdma_ctlr_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x68f0be19	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x690216de	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x6906338e	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0x6908ad71	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0x690be653	cci_ace_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x69244f55	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x693ed7ee	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x6945725e	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0x694be42a	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0x697a398e	ahci_platform_resume
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x699caa17	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0x69aeef06	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x69f664fc	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x69fa0b5c	snd_soc_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6a04a554	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x6a1074df	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x6a16db09	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a1914b3	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0x6a333d53	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x6a41e14f	omap_dm_timer_set_int_disable
++EXPORT_SYMBOL_GPL vmlinux 0x6a425c91	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0x6a42b519	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a6a50d7	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0x6a995fe1	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x6a99f5b4	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0x6a9e8feb	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0x6aad295a	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x6ac3ef7f	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x6adacaff	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x6b27a99c	sdhci_set_clock
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b2f8cc5	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0x6b5933c7	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x6b596d77	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL vmlinux 0x6b612ea2	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0x6b75c2eb	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0x6b76df34	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6b8366fb	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6b8b8efa	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x6b902093	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x6b92e7f3	of_dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x6bbda7fd	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0x6bc78f50	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0x6be265ad	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x6beb826e	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x6c030e63	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c1f4475	omapdss_of_get_next_port
++EXPORT_SYMBOL_GPL vmlinux 0x6c209eab	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x6c32ee3e	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c60b9af	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0x6c73cac2	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6c8e1463	sdhci_suspend_host
++EXPORT_SYMBOL_GPL vmlinux 0x6c9e133f	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cc5b393	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6cd937b3	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x6cdf0883	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x6cf6bc38	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d424356	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x6d595707	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0x6d5b4f56	cpsw_ale_dump
++EXPORT_SYMBOL_GPL vmlinux 0x6d8312a0	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6d99e9f0	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0x6de79f76	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e076e88	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL vmlinux 0x6e26bc3f	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0x6e30207e	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x6e37d20f	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x6e4942af	ahci_do_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x6e51afc8	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e7ad4e4	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x6e84bd55	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0x6e85f6be	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6e99c04b	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0x6e9c825c	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x6e9f25ac	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x6ea7dc2b	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0x6eac4329	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0x6ead705e	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x6eb944f4	of_usb_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x6ecd6934	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x6ed9f20a	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL vmlinux 0x6ee7469d	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL vmlinux 0x6efa830d	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0x6efd7e88	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0x6f067d21	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x6f0d167b	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x6f12afe2	of_property_count_elems_of_size
++EXPORT_SYMBOL_GPL vmlinux 0x6f174350	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ae0e5	power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f26e5b7	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x6f2b03ce	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6f5a03f4	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x6f5c638f	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x6f5db668	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL vmlinux 0x6f6db608	of_usb_host_tpl_support
++EXPORT_SYMBOL_GPL vmlinux 0x6f7c3288	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6f92f237	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0x6f9f5be7	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL vmlinux 0x6fc760e4	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x6fdebc3c	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6ff1e860	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x706ecc39	genpd_dev_pm_attach
++EXPORT_SYMBOL_GPL vmlinux 0x707abc69	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x708695f8	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x70bd1d49	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70daac81	arm_iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x70f14fdb	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x71008581	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x711048b2	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL vmlinux 0x7118d9a6	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0x71405316	arizona_of_get_type
++EXPORT_SYMBOL_GPL vmlinux 0x71422be6	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x714eae11	clk_register_gpio_mux
++EXPORT_SYMBOL_GPL vmlinux 0x714fc419	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x7156f021	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x715b815e	of_pci_msi_chip_add
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x7164982f	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x719e17ff	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x71a4e474	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x71a602da	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71dd1f25	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0x71e427ca	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0x71f38e7d	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0x71f89768	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0x7215ad31	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL vmlinux 0x72263238	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0x72387e4e	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x7246777c	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x724b1f37	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x724e0e1b	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0x72515d5a	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x7252365e	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL vmlinux 0x726fc5f7	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x7291019b	__cci_control_port_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x72935ddf	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0x72b61d4a	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x72b69d03	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x72bb4afd	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x72c2a689	dev_pm_opp_free_cpufreq_table
++EXPORT_SYMBOL_GPL vmlinux 0x72d4a115	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0x72e3f569	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x72e64095	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x72e6578c	ahci_platform_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x72f40b23	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0x730bd0c7	asic3_write_register
++EXPORT_SYMBOL_GPL vmlinux 0x731dc79c	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x73252296	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0x73305274	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x733da5c4	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x733f57b6	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x734f73f1	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x735e0e95	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x737d7f4a	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0x738f208f	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73ab628d	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x73ad1eee	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0x73af9acd	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x73b98231	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73e1dbd8	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x73f40f65	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0x7427cb76	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x742bd64c	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x743311de	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x743ac286	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x748b8ef3	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x749aca6a	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0x74a22c30	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0x74b30e3b	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74eabb01	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x7512551b	mtd_writev
++EXPORT_SYMBOL_GPL vmlinux 0x75197df4	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x7558dd88	omap_dm_timer_request_specific
++EXPORT_SYMBOL_GPL vmlinux 0x755c5839	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0x75602d54	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0x7579613e	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x7580bca6	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0x758618f9	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x759139cb	of_pci_check_probe_only
++EXPORT_SYMBOL_GPL vmlinux 0x75b81638	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x75ba3dd5	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x75c8c41c	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x761e0aca	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0x76276207	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0x762b0d27	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0x764928a2	cpdma_chan_create
++EXPORT_SYMBOL_GPL vmlinux 0x764a81fe	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0x764c9b67	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x764e7307	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x765a0e89	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x76755195	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x7676979a	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x767e4510	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x769df890	of_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x76bd3278	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x76ca7a6b	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0x76d9b876	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0x770cf981	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x7726ee0c	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x772b2fc1	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x7743ca23	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x7750aefe	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x7757b51a	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x77840b00	devm_pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0x7789acd1	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0x77ad7199	input_class
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x77b993ba	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0x77de990b	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x77fe4332	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x780a1edf	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x784e9275	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x7857f77c	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x7867b878	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0x78761bc5	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78ce9431	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0x78d43a11	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x790e1fb0	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x79106383	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x79185154	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x79206150	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x792f5c0e	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7933f172	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x793b4742	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0x7941bab2	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x79511e0d	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0x7951d92e	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x7977f231	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL vmlinux 0x797e0bec	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0x79982e08	of_clk_src_simple_get
++EXPORT_SYMBOL_GPL vmlinux 0x799bac52	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0x79c2ea9f	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0x79d47795	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x79f659ac	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x79f94237	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x7a02ff31	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0x7a075973	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x7a14d1fd	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0x7a24c300	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x7a2bb0fd	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a319404	clk_register_fixed_rate
++EXPORT_SYMBOL_GPL vmlinux 0x7a3831f4	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0x7a4276d3	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7a9119c4	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7a9958b7	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0x7aa92980	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0x7ab3ca18	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x7b07c027	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b147267	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0x7b1586e3	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x7b1b58cb	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0x7b1cebc6	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b2dae3b	of_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x7b48ff53	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0x7b526a6f	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x7b6485a2	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b9bf2db	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x7bd923a6	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL vmlinux 0x7be2fe03	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x7bf17922	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0x7bf58e3d	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x7c11ec9a	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0x7c189abe	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x7c18dd3b	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0x7c26e33f	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x7c477fe6	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7c6146c6	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7c6a49ce	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7c6ac8ec	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x7c7c640d	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x7c8f7cd9	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x7c9a7371	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x7ca38bcd	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x7cabe163	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x7cd477c9	kill_mtd_super
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7cde296a	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cf499ce	of_fixed_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0x7cf78574	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0x7cfec3c4	mtd_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7d06df08	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0x7d2d9261	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x7d328059	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0x7d4a72a0	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d69d375	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x7d7177b2	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x7d776e72	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0x7d8abf99	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL vmlinux 0x7d9c69ce	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7dab2aa0	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL vmlinux 0x7db18500	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0x7dbe6de8	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x7dc20933	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x7dcec434	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0x7dd2cd45	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7de3b2db	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0x7df0cc85	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0x7e3ec44c	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x7e4b300c	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7ecb9c6a	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x7ed68941	asic3_read_register
++EXPORT_SYMBOL_GPL vmlinux 0x7eef0047	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f5d38cf	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x7f63c7e7	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7fa484d2	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x7fbb5711	probes_decode_arm_table
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7fcb95fc	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0x7ffb078e	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x8000b681	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0x8010d2c6	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0x8015b29f	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x801b5316	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x805b204e	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x80733d88	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x807fbcc2	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x80a9ed55	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x80b6c1c0	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80cb2e7d	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80de2a15	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x80ebd1b0	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0x80ed9310	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x80f8589f	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0x810441be	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x81078670	sdhci_remove_host
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x8121f89b	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x812e3d9a	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x813648f2	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0x8138e2f1	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0x813cf714	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x81419bc7	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x814e3943	dev_pm_opp_of_add_table
++EXPORT_SYMBOL_GPL vmlinux 0x8151b99b	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x815588a6	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x81563838	pinconf_generic_dt_subnode_to_map
++EXPORT_SYMBOL_GPL vmlinux 0x815dc806	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x8161e149	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x816f0d04	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0x81719d26	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x819402d1	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x81a59ee8	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0x81ce53b5	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x81e526ba	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0x81f610e1	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x820b4891	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x822ad4c7	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0x823e0278	of_clk_add_provider
++EXPORT_SYMBOL_GPL vmlinux 0x82482b1a	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8256788f	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0x8268779c	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x826f244f	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL vmlinux 0x82b07288	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0x82b285fa	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x82c9a50f	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0x82d13312	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82dd6e42	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x82f72f2c	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x83068cec	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x8311797f	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x831a1acd	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x8323983d	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0x833629d8	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0x83363e19	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x8359803f	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0x836d0e60	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x8381972c	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x83b19129	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0x83bc9278	devfreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x83d69b52	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8414847b	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x844712df	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x8465f990	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0x8475f8f1	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x848bd0fb	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x84a358ee	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x85064f73	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0x8506baa8	clk_unregister_gate
++EXPORT_SYMBOL_GPL vmlinux 0x850df8b9	clk_divider_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x85200327	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x8544920f	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x854c607c	register_mtd_blktrans
++EXPORT_SYMBOL_GPL vmlinux 0x854d459e	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0x8560e463	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x8574ca40	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x8574ca6c	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x858737ec	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x85967d3d	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0x859dd40c	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x85b16181	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x85b98c51	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0x85c6168e	clk_debugfs_add_file
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85cb0ada	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0x85d1f1aa	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x85d9fb0d	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x861f153d	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0x862b9816	cpu_topology
++EXPORT_SYMBOL_GPL vmlinux 0x8652110e	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0x86597e4e	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x8694e88d	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x86c7ac25	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0x86ea8198	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8909f	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8708ebad	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8717df8b	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x87221ccb	of_get_fb_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x877cebc2	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0x87915e7f	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x879371aa	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x87b75e2d	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x87bad614	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0x87d1fd9b	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0x87ebcd85	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x8803a833	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x8807f269	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x88136838	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x881b4d84	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x8826051a	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x883c2740	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x884c5d72	snd_ac97_reset
++EXPORT_SYMBOL_GPL vmlinux 0x887f9ba8	dev_pm_opp_of_get_sharing_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x88805174	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0x8882cfd3	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88b20e88	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88b90c1b	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x88c8da9a	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0x88d23274	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0x88df3a01	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x88f0bd26	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0x89074516	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8912d3e9	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x89386e3c	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0x8944b828	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x89510823	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x89754397	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0x89762d96	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x89900124	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x899a64f4	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0x89a1c677	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0x89aecffc	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89efdfb6	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x89f4f079	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0x8a014045	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0x8a25aeee	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x8a43379d	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8a54a013	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x8a554a36	mpc8xxx_spi_strmode
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a570b7c	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x8a58780a	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0x8a5f86ce	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x8a652f30	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0x8a76c52f	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0x8a7b35df	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8a81de3a	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL vmlinux 0x8a878729	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x8a8b0410	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8a952326	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0x8a9a43f8	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8ab8bd0d	__mtd_next_device
++EXPORT_SYMBOL_GPL vmlinux 0x8ab9759f	devm_power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8b149c36	clk_is_match
++EXPORT_SYMBOL_GPL vmlinux 0x8b19ffaa	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x8b348d29	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8b383891	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x8b533d28	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x8b6717b8	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0x8b6db9a1	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0x8b775d3a	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8b91f7a7	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL vmlinux 0x8bafb41c	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8bb3fab5	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0x8bc749bc	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x8bc9e4c9	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c1e2084	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x8c3926d7	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x8c4103f4	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x8c421067	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0x8c4584eb	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL vmlinux 0x8c52734f	of_irq_parse_and_map_pci
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c71eb8f	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c957620	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x8cb0e715	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0x8cc3b0d5	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x8cd5f73a	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8cea3a45	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0x8cfe779d	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x8d19c44c	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d31a848	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x8d323deb	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0x8d329327	snd_soc_cnew
++EXPORT_SYMBOL_GPL vmlinux 0x8d4ca0cb	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8d5ba048	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL vmlinux 0x8d74c039	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x8d80068a	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0x8d953345	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x8da17b42	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x8da2bd1b	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8da4d563	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0x8da52c52	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8db57487	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL vmlinux 0x8dbcabc3	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0x8dc1feed	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0x8dc91436	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0x8dd80691	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x8df5e27b	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x8e051ed8	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0x8e21e6a4	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x8e2b25c2	videomode_from_timings
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e42e821	__tracepoint_add_device_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x8e54bf0f	pinctrl_utils_add_map_mux
++EXPORT_SYMBOL_GPL vmlinux 0x8e54ffcc	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x8e74b358	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x8e77d547	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0x8e7894bd	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x8e93380d	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL vmlinux 0x8e9efbd6	ti_cm_get_macid
++EXPORT_SYMBOL_GPL vmlinux 0x8ea6955a	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x8eb4cdad	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0x8ec049c7	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL vmlinux 0x8ec27e12	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x8ec2a04f	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f0ccc09	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x8f0d9488	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x8f18a165	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x8f6b2a73	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f94541d	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0x8f9a1bd5	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x8faaa519	snd_soc_write
++EXPORT_SYMBOL_GPL vmlinux 0x8fb2a5a8	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0x8fc9cf27	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x8fdafbff	of_irq_parse_pci
++EXPORT_SYMBOL_GPL vmlinux 0x8fe03100	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0x8ffd9f53	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x901602ab	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0x90230e99	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x9023484f	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x9023b312	__get_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0x902e7c5e	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x9047c11a	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x904efb78	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x9054e7a8	mtd_erase
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x90884f53	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90b1db59	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0x90b9e056	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0x90faea69	get_device
++EXPORT_SYMBOL_GPL vmlinux 0x90fe94d1	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0x9102af8b	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0x915d65d2	pinctrl_register
++EXPORT_SYMBOL_GPL vmlinux 0x916cb812	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x91714846	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0x91897bff	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x918b6a5f	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x91ae6efe	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91e6e9ae	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x920c17b4	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL vmlinux 0x92220b65	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0x92265022	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0x92400d72	iommu_get_domain_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x925d2815	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x92652448	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x926530de	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x92699d47	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x9295c27f	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0x929aa808	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0x92accbf3	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0x92b57248	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x92cb3461	mpc8xxx_spi_tx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x92d09289	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92f6e4b6	__ktime_divns
++EXPORT_SYMBOL_GPL vmlinux 0x92fd6a34	dev_pm_opp_add
++EXPORT_SYMBOL_GPL vmlinux 0x930b1055	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x931ebcd1	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x93278656	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0x9329b92c	pm_genpd_syscore_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x9342f50a	omap_dm_timer_stop
++EXPORT_SYMBOL_GPL vmlinux 0x935519ce	clk_multiplier_ops
++EXPORT_SYMBOL_GPL vmlinux 0x93636034	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9387992c	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x9387f0f7	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0x9396e461	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x939db2f5	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x93b11f81	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x93c93b12	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x93d3b951	of_fixed_factor_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0x93d47d59	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0x93e97e76	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0x93ec0885	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0x93f7bb2f	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0x93f862c2	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x94077f3a	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x94421d3e	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0x9454a461	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x94925434	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x949334db	cpdma_ctlr_start
++EXPORT_SYMBOL_GPL vmlinux 0x94964783	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0x94abb745	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0x94ac571a	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0x94c96f3b	bgpio_init
++EXPORT_SYMBOL_GPL vmlinux 0x94fb94ed	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x9526e077	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x95332bfc	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x953b9ad8	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x95409e33	dev_pm_opp_find_freq_ceil
++EXPORT_SYMBOL_GPL vmlinux 0x955af1eb	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x9586a6ed	cpdma_chan_get_stats
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x95b5133e	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x95bbb758	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95c578a0	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x95ea34d7	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x95f4a058	device_register
++EXPORT_SYMBOL_GPL vmlinux 0x95fbcbda	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x96491f3a	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0x9653f5a7	cpsw_ale_start
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x96711e14	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0x967f5194	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x9683a162	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL vmlinux 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL vmlinux 0x96c6f7df	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x96efc63f	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0x97161491	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x9755b8e6	of_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x975736a2	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL vmlinux 0x977e64e6	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x981f5896	cpsw_phy_sel
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833059d	usb_gadget_map_request
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x98391433	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x9846bf25	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0x984af527	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x98539ef3	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x9867b30f	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x986c4794	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x98725423	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x988319cd	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x98991e8a	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0x989eb047	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x98b32824	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x98c4a888	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL vmlinux 0x98c9f584	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcbbdc	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x990967d7	i2c_slave_register
++EXPORT_SYMBOL_GPL vmlinux 0x991afac6	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x99272a65	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x996ed0b6	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x9973add9	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x9990bb2f	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x9990f20e	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x999344b3	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x999bfaf3	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99c0db48	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x99d35e5b	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x99f16697	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x9a02f3eb	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a16d209	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0x9a2f6447	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0x9a39206e	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0x9a3e0d69	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0x9a70c678	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL vmlinux 0x9a7c10f0	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9a9796be	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0x9aa6dd3e	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x9abf7508	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9ac64bc3	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0x9ad314c5	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x9adf24ba	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9aee731f	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0x9b0fe8e6	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x9b119680	md_run
++EXPORT_SYMBOL_GPL vmlinux 0x9b14500a	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0x9b1c88a6	get_mtd_device_nm
++EXPORT_SYMBOL_GPL vmlinux 0x9b6075ab	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9b675c41	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x9b8b1765	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9b9b8287	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9ba1d84f	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x9bb62e4d	mtd_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c3b7a2e	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0x9c3e5b59	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9c40e6ca	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x9c7fe5b4	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9c938642	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x9c957e57	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0x9cb1d373	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x9cb83f1d	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x9cc0a15c	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cdc9867	cpdma_ctlr_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9ce139a5	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0x9cecc5ad	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x9d27375c	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x9d27a127	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x9d29c366	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x9d6503d2	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9d6a70d0	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x9d746094	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0x9d7dd716	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x9d7eed9a	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x9d804bd3	pinconf_generic_dt_node_to_map
++EXPORT_SYMBOL_GPL vmlinux 0x9d819260	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0x9d822e49	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9d8331c0	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x9d8604d4	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9da0d949	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x9da297df	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9dadcacb	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0x9dcf661c	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0x9dfdf722	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0x9e0ea42c	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL vmlinux 0x9e19a4e6	of_clk_src_onecell_get
++EXPORT_SYMBOL_GPL vmlinux 0x9e210071	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x9e27a103	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x9e3530a2	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e5a9259	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0x9e5b0ad2	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0x9e5e6fb2	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x9e8525a8	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x9e9548a6	dev_pm_opp_enable
++EXPORT_SYMBOL_GPL vmlinux 0x9e980a06	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x9e9f0204	omap_dm_timer_set_load
++EXPORT_SYMBOL_GPL vmlinux 0x9ea556f8	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9eb30520	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9f0a83fb	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x9f0e76fe	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0x9f1860f7	clk_register_fractional_divider
++EXPORT_SYMBOL_GPL vmlinux 0x9f2d173e	pinctrl_pm_select_default_state
++EXPORT_SYMBOL_GPL vmlinux 0x9f632021	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0x9faf36e3	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fd5792c	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x9fdb1681	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9fea7af6	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x9ff1e5c8	of_get_nand_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0xa00c4754	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0xa013a9cf	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xa01d1b6d	cpufreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa0203800	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL vmlinux 0xa033df40	clk_register_divider
++EXPORT_SYMBOL_GPL vmlinux 0xa05f2f2d	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0xa061ddb2	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0xa089fecb	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xa092cb64	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xa0af19c2	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xa0c9e64d	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0xa10263c1	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0xa126d5bf	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0xa12fd379	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0xa1351e07	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0xa13a63e6	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xa1494036	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xa14a1817	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0xa176efde	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xa1850546	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa1a3fb7a	of_pci_msi_chip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xa1fbf41c	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xa2035eb7	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa223f7ce	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0xa235a30a	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa23b0ec0	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL vmlinux 0xa26d39e1	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL vmlinux 0xa29474b6	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0xa295ba9d	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0xa2a32418	__of_genpd_xlate_simple
++EXPORT_SYMBOL_GPL vmlinux 0xa2a44228	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xa2af2818	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xa2b9c993	clk_register_fixed_factor
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2c2f654	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xa2caa36a	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xa2e195bc	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0xa30bf4f6	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xa31743ba	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0xa3259139	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0xa357b9b6	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0xa36ecfdf	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0xa3758849	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0xa378399a	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xa382b6ad	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xa3836523	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa39cd74b	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3a4e18a	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xa3b5e7b7	dt_init_idle_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3c2005a	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0xa3d1189e	pinctrl_add_gpio_ranges
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa3f26a2a	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0xa3f3fbf0	component_del
++EXPORT_SYMBOL_GPL vmlinux 0xa4110081	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0xa412f205	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0xa41b7f07	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xa4253262	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0xa42d2076	dev_pm_opp_get_suspend_opp
++EXPORT_SYMBOL_GPL vmlinux 0xa435b1af	put_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0xa4421e8c	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0xa446db31	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xa44890ee	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0xa45a9bf4	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0xa45f337d	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa490571e	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xa4923b56	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0xa49298aa	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0xa4b139ca	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0xa4c4d41b	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0xa4c795f6	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa4de4e15	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xa4e18668	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xa4f3f095	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xa4f759c6	get_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0xa526f5d1	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0xa53b7aaf	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0xa53c6958	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xa53fe33a	pinctrl_dev_get_devname
++EXPORT_SYMBOL_GPL vmlinux 0xa547da62	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xa54facc7	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0xa577f67a	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0xa5935d6a	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xa5a2849f	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xa5ad9c82	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xa5bf138b	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xa5d30995	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xa5dc1842	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5f8854a	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa63b1de1	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xa6713caf	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xa6953768	__put_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6bebd5f	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xa6c79ca1	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0xa6c834b3	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa6e7c976	snd_soc_add_platform
++EXPORT_SYMBOL_GPL vmlinux 0xa70aa793	dapm_clock_event
++EXPORT_SYMBOL_GPL vmlinux 0xa73e9930	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0xa799b9c0	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xa7af6c2a	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0xa7b12a7b	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xa7b7f77e	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xa7c2448f	register_mtd_parser
++EXPORT_SYMBOL_GPL vmlinux 0xa7d8ea75	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xa80f58e8	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xa83e1aea	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa857152a	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa862187e	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xa869bc43	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0xa86e11db	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0xa87b9337	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0xa87f8da7	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xa8843bfe	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xa887336c	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8bc717e	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0xa8d75c14	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xa8da5c9a	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0xa8e4cb25	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0xa8e98132	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xa8f73ffd	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0xa9244942	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa9484b53	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0xa94e7855	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0xa9716463	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0xa975073c	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa976bce4	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0xa992c0c4	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0xa9ae69a1	imx_pcm_fiq_init
++EXPORT_SYMBOL_GPL vmlinux 0xa9c67f5e	omap_dm_timer_request
++EXPORT_SYMBOL_GPL vmlinux 0xa9d17476	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0xa9dc8f80	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0xa9e05660	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9e59bf7	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xaa112db7	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xaa142ce5	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0xaa22390b	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0xaa2a72bf	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0xaa2e1dec	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xaa3ce204	clk_register_gpio_gate
++EXPORT_SYMBOL_GPL vmlinux 0xaa44acff	omap_tll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xaa49e8ab	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xaa4a407f	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xaa767d66	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0xaa79aa15	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xaa82441c	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0xaa91aab2	pin_is_valid
++EXPORT_SYMBOL_GPL vmlinux 0xaa93dc94	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaaba3b70	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0xaac95fb5	omap_iommu_save_ctx
++EXPORT_SYMBOL_GPL vmlinux 0xaacbde52	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0xaace04f8	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xaae6d4cf	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xaaed4d2c	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0xaafdb0d5	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0xab15d4da	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xab22bc67	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0xab2bd290	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL vmlinux 0xab38f3cc	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab657db5	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL vmlinux 0xab945a16	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xab9a6d58	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xab9ae96a	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xabb973da	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL vmlinux 0xabfab303	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xabfb18dc	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0xac178eca	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0xac1f24d8	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xac573ffe	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL vmlinux 0xac651ce0	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0xac686205	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0xac6fb271	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xac756a2a	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0xac913d33	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0xacaacf39	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xaceb9d99	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0xad0b561d	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xad1bee4c	of_clk_get_parent_name
++EXPORT_SYMBOL_GPL vmlinux 0xad25723d	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0xad36c9df	ahci_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xad72c1f1	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0xad9faa4b	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xadbdcd18	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0xadc641a3	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xae287f22	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0xae42ff69	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0xae5d5d1f	clk_hw_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae81922b	of_overlay_destroy_all
++EXPORT_SYMBOL_GPL vmlinux 0xae9f9d59	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0xaeb4043d	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0xaec524af	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xaed7f220	cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xaeec4b36	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xaef0f39c	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0xaf01c31e	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0xaf040b5c	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0xaf12bfb3	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0xaf348da7	cpu_pm_exit
++EXPORT_SYMBOL_GPL vmlinux 0xaf7cb6a2	mtd_block_isbad
++EXPORT_SYMBOL_GPL vmlinux 0xaf7fbf7d	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xaf9396fa	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xafd3de4e	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0xb0004363	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0xb00048b3	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xb0128a78	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0xb01353cd	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0xb01ed923	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0xb0268218	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xb0385c6c	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0xb03a31d2	ahci_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb04d1f7b	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL vmlinux 0xb077e70a	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0bce4f0	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xb0c0d106	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xb0c3fb1b	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0xb0d48bea	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0xb0eac602	sdhci_send_command
++EXPORT_SYMBOL_GPL vmlinux 0xb0f46072	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xb10d59e1	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0xb11625b9	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xb11bf7d8	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0xb121a6d3	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0xb125ceb2	cpdma_control_set
++EXPORT_SYMBOL_GPL vmlinux 0xb135f540	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb14be9ca	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0xb153fbd2	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb18cd599	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0xb19b1322	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xb19c002d	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1b2c60d	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0xb1b2da0d	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1e467d6	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0xb1e70a5c	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xb1eb462d	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0xb1ed19c5	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0xb1fe34b8	nand_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0xb2080257	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb23006d0	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0xb26a1add	elfcorehdr_addr
++EXPORT_SYMBOL_GPL vmlinux 0xb26c0bdd	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xb27ea468	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb295a2af	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xb29ed786	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xb2ac0eb1	to_of_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0xb2c136c0	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb2dba411	uniphier_pinctrl_remove
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb30bb69a	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0xb310b4c1	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0xb310e837	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0xb31386c3	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0xb328a9db	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xb36076b8	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xb386cb41	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0xb386cbf6	sdhci_add_host
++EXPORT_SYMBOL_GPL vmlinux 0xb3bdc624	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0xb3bf46b8	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0xb3d2c6e3	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL vmlinux 0xb3dac94f	ahci_start_engine
++EXPORT_SYMBOL_GPL vmlinux 0xb3e84a68	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0xb401e132	amba_ahb_device_add_res
++EXPORT_SYMBOL_GPL vmlinux 0xb402dd21	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0xb40c6376	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xb41a3f00	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xb433958d	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0xb43ce764	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0xb47095c9	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0xb490c243	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xb490ced3	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0xb49af70d	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xb4a3273c	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4c63783	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL vmlinux 0xb4cf0322	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xb4d57edc	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb5953f77	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0xb595a793	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL vmlinux 0xb59b505c	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5c7a88c	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xb5cba789	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0xb5d02398	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0xb5e31551	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb5e896fb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb5ff475a	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xb608e93c	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0xb6178e58	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb654f05a	of_dma_router_register
++EXPORT_SYMBOL_GPL vmlinux 0xb6930e02	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb696e1f9	deregister_mtd_parser
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6d2481a	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xb6e6d99d	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb6f345b5	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL vmlinux 0xb6fa3696	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0xb7055e97	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0xb70a0454	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb7329c06	clk_set_phase
++EXPORT_SYMBOL_GPL vmlinux 0xb73e94b7	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0xb74bfae0	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xb7566065	pci_fixup_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb757b9ba	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0xb76317b2	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb76d26ed	omap_dm_timer_set_load_start
++EXPORT_SYMBOL_GPL vmlinux 0xb771e6b7	bL_switch_request_cb
++EXPORT_SYMBOL_GPL vmlinux 0xb776d561	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb77cb0a8	cpdma_chan_submit
++EXPORT_SYMBOL_GPL vmlinux 0xb793f2bf	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xb7b9ae1c	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb7c342db	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0xb7c4142d	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0xb7c582c1	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL vmlinux 0xb7c8346e	of_platform_populate
++EXPORT_SYMBOL_GPL vmlinux 0xb7d3d2f8	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0xb7dec471	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0xb7e07fd6	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb80b06f4	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb813d380	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0xb819e48b	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xb82566eb	omap_tll_enable
++EXPORT_SYMBOL_GPL vmlinux 0xb82e3433	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0xb8346aeb	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb84afa05	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0xb8628379	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0xb8773267	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0xb882411f	of_dma_is_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xb886d872	mtd_point
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb8ba00be	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb8ba7904	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xb8beb45a	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL vmlinux 0xb8c45e4c	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0xb8c8cca4	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8d0b19d	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xb8e7daa2	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL vmlinux 0xb9176155	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0xb91c2cb7	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xb92427b4	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb928bd43	of_regulator_match
++EXPORT_SYMBOL_GPL vmlinux 0xb928fad4	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xb93b5ac5	ahci_init_controller
++EXPORT_SYMBOL_GPL vmlinux 0xb94dd60e	max_gen_clk_remove
++EXPORT_SYMBOL_GPL vmlinux 0xb952991e	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xb96a8471	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0xb974af1f	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0xb992a03d	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0xb9b205c0	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9c80111	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9d1b0fc	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb9e61fd0	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL vmlinux 0xb9e87b94	bL_switcher_trace_trigger
++EXPORT_SYMBOL_GPL vmlinux 0xba0308ba	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0xba1f3eb9	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba2e9ac4	cpdma_ctlr_create
++EXPORT_SYMBOL_GPL vmlinux 0xba52c3b6	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xba5afffd	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0xba5bd06a	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xba6723d3	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0xba8929ea	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xba8ecef6	dapm_regulator_event
++EXPORT_SYMBOL_GPL vmlinux 0xbaabf313	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbabed3a6	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0xbacb8f01	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0xbae1a3d7	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0xbaedca2c	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb03bf74	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0cf5b0	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbb11cfba	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xbb1dc9ba	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0xbb203afa	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL vmlinux 0xbb4c7570	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xbb6bf6ce	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0xbb76735b	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xbb9e2ab5	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0xbbaa4e44	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0xbbc85dbe	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0xbbd711f0	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0xbbfd82c5	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0xbbfe4a14	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbbff6ea7	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbc0f4662	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0xbc21655d	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0xbc370c23	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xbc62657b	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc8b84fe	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcb45e39	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xbcb989f5	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0xbcbaa80a	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0xbcc381c0	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL vmlinux 0xbcc5380d	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xbcce4cfb	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbceb2941	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0xbcf89ab6	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0xbd10369e	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0xbd16dd97	mpc8xxx_spi_tx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0xbd18fb04	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd4c7d8b	pci_ioremap_io
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8c1	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0xbd6d0f8f	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0xbd78c34f	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0xbd91ce3d	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xbd969349	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xbdc66504	dummy_con
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbddb13dd	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0xbdf2e24d	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL vmlinux 0xbe0cd664	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe24b3d2	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbe3c6dbc	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe6a342b	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0xbe96dfd8	of_reconfig_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbec85820	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0xbed746ac	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL vmlinux 0xbed929eb	dev_pm_opp_set_sharing_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf2956c0	find_module
++EXPORT_SYMBOL_GPL vmlinux 0xbf476fa4	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0xbf49ac6c	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xbf75fbfd	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0xbf818595	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0xbfaded22	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfbcddf8	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xbfd5279b	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0xbfd8faaf	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xbffe0535	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0xc00131cf	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0xc0262eac	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0xc03827df	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xc03a654b	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0xc03d4163	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc065258a	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xc065478a	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0xc066d298	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0xc074adad	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0xc081c246	bL_switcher_put_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0b70b0b	gpiochip_add_pingroup_range
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0e75cec	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc0f7cd76	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc13c64d8	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xc1485283	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0xc1539f7d	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc1678b04	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc18578ed	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xc18725ff	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0xc187e6f6	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xc1984688	of_get_dma_window
++EXPORT_SYMBOL_GPL vmlinux 0xc1a18615	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xc1a5414e	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0xc1b42da6	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0xc1b8cfa6	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xc1bced6a	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xc1c61b59	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0xc1d00501	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xc20c8a67	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0xc2156c25	of_platform_depopulate
++EXPORT_SYMBOL_GPL vmlinux 0xc21b3cca	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc2294873	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc24a65e1	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL vmlinux 0xc24e6a7a	ahci_reset_em
++EXPORT_SYMBOL_GPL vmlinux 0xc24ea97f	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc264f72b	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc272e659	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc2941966	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0xc29f0c0e	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xc2c1490d	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL vmlinux 0xc2d69341	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0xc2e728dc	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0xc2f07df8	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc2fcafc7	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc30b3a36	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0xc32b6974	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0xc32e7067	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xc32e7129	of_get_videomode
++EXPORT_SYMBOL_GPL vmlinux 0xc32f81f6	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0xc331de2f	of_clk_parent_fill
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc3572755	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0xc357e9cb	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xc3647854	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0xc3655b26	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc3729a1b	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc37baecf	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0xc3833e54	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0xc385cb58	perf_num_counters
++EXPORT_SYMBOL_GPL vmlinux 0xc3885989	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0xc388fe79	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0xc38f70f3	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0xc39f4976	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc3a8abc4	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xc3ae66e3	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xc3b93bba	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0xc3b9d14a	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0xc3bbefff	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL vmlinux 0xc3c10209	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0xc3c5d1e9	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0xc3c7744f	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xc3d41806	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xc3f9ea78	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xc3fece9c	of_genpd_get_from_provider
++EXPORT_SYMBOL_GPL vmlinux 0xc404db02	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0xc40efacd	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc41e0178	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0xc41ffd62	put_device
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc428ac08	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0xc42ef93e	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc4403a61	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0xc4437ab3	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc4622df3	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc48aa3cb	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc4922605	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc4b5cef4	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xc4c72e4a	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4d6eff9	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0xc4e65bc9	mtd_write
++EXPORT_SYMBOL_GPL vmlinux 0xc515f583	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0xc52bf3fe	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0xc52da40d	of_reserved_mem_device_release
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc54d8fa7	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0xc5550fee	arm_iommu_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xc559ce4d	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0xc563635d	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xc569d8ce	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc58ad582	omap_dm_timer_request_by_cap
++EXPORT_SYMBOL_GPL vmlinux 0xc5c14716	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0xc5d5513e	cpdma_chan_process
++EXPORT_SYMBOL_GPL vmlinux 0xc5d681f2	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc5e0dd66	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0xc5ed74d0	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0xc5ee4148	of_get_nand_ecc_step_size
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc6437476	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0xc649229a	clk_register_gate
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc6697d9d	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc685c037	cpdma_check_free_tx_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc6922131	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6a4a872	__clk_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc6c550cd	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xc6d701df	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xc6e0b644	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xc6ef98fe	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0xc6fcf89c	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0xc7287aec	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc7303ddb	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0xc74630c1	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0xc74a2d0b	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0xc75520dc	of_pci_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0xc75beb9e	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7abdcda	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xc7b8893b	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7c92655	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0xc7cb7ef5	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0xc7d1ec5a	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7f4fe40	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0xc813e245	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL vmlinux 0xc83a2d47	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0xc872ea3c	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xc875d487	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc87e2d7a	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xc88faa6c	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0xc8964a24	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xc897bfb6	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8d5be83	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc8e048a7	omap_dm_timer_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc8e92275	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc948d924	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc963b82d	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0xc968081e	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0xc968e7df	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0xc96ec70f	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0xc971be40	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0xc97d1140	cpufreq_cooling_get_level
++EXPORT_SYMBOL_GPL vmlinux 0xc994d512	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc9a06e19	ahci_kick_engine
++EXPORT_SYMBOL_GPL vmlinux 0xc9a2ab6e	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc9d8c016	of_pci_range_parser_init
++EXPORT_SYMBOL_GPL vmlinux 0xc9d91268	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xc9dd6312	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xc9e08fe0	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc9f0687b	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0xca06322f	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0xca1b5e11	unregister_mtd_user
++EXPORT_SYMBOL_GPL vmlinux 0xca1bb9c5	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0xca28e1d2	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0xca56f5d8	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xca5a1601	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca80ca29	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL vmlinux 0xca899ca0	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xcaa477f5	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL vmlinux 0xcaa4a99c	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcad357c4	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0xcad4fe6e	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0xcaf613bf	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xcaf9f9dd	clk_fractional_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0xcb048658	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb2d505a	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xcb42e1a3	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xcb43943c	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb4b3fd6	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0xcb5bb04c	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0xcb5fdb0b	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcb70ff46	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xcb7c94e0	of_reserved_mem_device_init
++EXPORT_SYMBOL_GPL vmlinux 0xcb814533	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xcb85cc28	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0xcbb647f8	omap_dm_timer_read_status
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcc0cbf42	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0xcc2a738b	omap_mcbsp_st_add_controls
++EXPORT_SYMBOL_GPL vmlinux 0xcc2a96c6	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0xcc325772	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL vmlinux 0xcc416e9d	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0xcc53eb3f	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xcc561b2d	__of_genpd_add_provider
++EXPORT_SYMBOL_GPL vmlinux 0xcc71fb69	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0xcc7b96af	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcc7f13b5	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc8cdc86	pinctrl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcca1d2e6	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0xccb5155d	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xccbe5de8	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL vmlinux 0xccbf4b69	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccde28a9	user_read
++EXPORT_SYMBOL_GPL vmlinux 0xcce92396	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xcd0cb1fa	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xcd0d8a9d	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0xcd296e17	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xcd31e04d	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0xcd5c7b16	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xcd794991	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9b68e5	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcdca9edb	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0xcdddd6d0	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0xcdfb3496	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcdfe08ce	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xce229fa8	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0xce3223b1	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL vmlinux 0xce3f0c6b	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce6f7c16	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0xce6fdfba	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0xce772dda	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL vmlinux 0xce8adc8d	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0xceb25035	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xcecacb35	clk_hw_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0xced28f3a	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcee6f42c	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0xcef7b00d	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0xcf2e751a	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0xcf34ae34	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xcf4b4a47	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf5a3e75	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0xcf8f8d56	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0xcfaf44fe	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfb93e43	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xcfc126f6	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xcfc12bac	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfcf4154	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xd004c417	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xd017c545	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd01992db	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd0407173	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0xd04a6e02	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xd050c21f	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd05cf2ac	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd07bb93e	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0c26e7a	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0xd0e23a73	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0xd0e9e803	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xd0f1b5cd	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xd103f320	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL vmlinux 0xd10b2ce0	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0xd124c7e9	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0xd133efbb	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xd139c4da	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0xd146dd49	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xd15583b5	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd16546d1	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xd16694c2	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd1723135	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0xd1822f0b	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd183c96e	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL vmlinux 0xd18ee2fb	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xd19d2124	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xd1a02181	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0xd1bf9753	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0xd1cb5d38	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd1de6a20	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0xd1e2c607	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0xd1f0a011	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd20389ef	omap_dm_timer_disable
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd231e63d	omap_pcm_platform_register
++EXPORT_SYMBOL_GPL vmlinux 0xd2411ead	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd28db21f	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd2aaeb4e	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xd2d07ad1	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0xd2de7533	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xd2decdc1	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd3272284	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0xd32df826	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xd33ada8b	cci_probed
++EXPORT_SYMBOL_GPL vmlinux 0xd340ddba	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0xd3566893	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd376f44d	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd37c6682	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL vmlinux 0xd3926165	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0xd3a15910	ahci_platform_resume_host
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3c0be7e	of_property_read_string_helper
++EXPORT_SYMBOL_GPL vmlinux 0xd3ce38c6	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0xd3ff1a20	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xd401336e	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0xd402f96c	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd440a1f2	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0xd448816b	mpc8xxx_spi_rx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd44c2f38	cci_disable_port_by_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd44c3437	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0xd44d3e1a	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xd46032a5	devfreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xd46e0261	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4d48b56	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0xd4ddfb89	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0xd4ed1943	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL vmlinux 0xd50d3965	__cci_control_port_by_device
++EXPORT_SYMBOL_GPL vmlinux 0xd5133d5e	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0xd5134aa0	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd51c7f9a	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xd538515b	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xd53da4e3	omap_dm_timers_active
++EXPORT_SYMBOL_GPL vmlinux 0xd54dd6dd	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd55b3598	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xd57c4012	ahci_platform_ops
++EXPORT_SYMBOL_GPL vmlinux 0xd58048a1	dev_pm_opp_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xd591b004	of_device_get_modalias
++EXPORT_SYMBOL_GPL vmlinux 0xd5937b72	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5d76982	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd5e57170	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd5ec2eca	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0xd604f626	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd61340a7	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xd6155386	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0xd628877b	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0xd6349f83	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd635534d	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xd637eefc	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0xd63bb40c	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0xd65ad250	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0xd6684827	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd6c43478	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xd6c72e44	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xd6c94425	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0xd6facf3d	dev_pm_opp_get_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd6faf631	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd72473f4	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0xd74c1c26	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd788dd29	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xd7892f81	amba_apb_device_add_res
++EXPORT_SYMBOL_GPL vmlinux 0xd78a237d	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0xd796f072	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0xd79ec23e	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xd7a4d429	snd_pcm_hw_constraint_eld
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7d9349e	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0xd7e3117d	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0xd7e6adc6	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd7eb6738	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xd81303fe	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd83e4293	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0xd859c69f	mtd_panic_write
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd8a28462	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0xd8ac5a36	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0xd8c3176c	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0xd8ed8ac1	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd91e023d	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xd933ce6e	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94553f5	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xd94aa457	display_timings_release
++EXPORT_SYMBOL_GPL vmlinux 0xd94dc97c	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0xd967628e	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0xd968ca0b	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd97f38e8	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xd98d2c2f	of_clk_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0xd98ea9be	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xd98f3ce6	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd9d50b12	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xd9e6362c	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xd9ee5b37	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0xda01e309	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xda090ee1	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xda13dab5	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0xda1dc991	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xda23623e	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0xda49e43a	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0xda630761	of_get_regulator_init_data
++EXPORT_SYMBOL_GPL vmlinux 0xda74489c	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0xda876191	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xdaa22cc9	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0xdab82014	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0xdad6a168	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0xdad85bf6	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0xdadfa095	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0xdae715e0	videomode_from_timing
++EXPORT_SYMBOL_GPL vmlinux 0xdae83b29	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdaf761ea	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL vmlinux 0xdb088cb1	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0xdb2e2de1	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb511857	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xdb729038	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xdb72d260	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xdb744d5d	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0xdb7d984f	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb98254f	amba_apb_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xdbce2421	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0xdbdcb406	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc096147	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xdc2a4bf3	mv_mbus_dram_info
++EXPORT_SYMBOL_GPL vmlinux 0xdc2a6c21	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL vmlinux 0xdc461430	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xdc58dc9c	default_iommu_map_sg
++EXPORT_SYMBOL_GPL vmlinux 0xdc66e596	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0xdc7b251a	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc855fbd	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdcb68a14	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0xdcc19045	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0xdccdb96e	of_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xdcd1d068	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xdcf76e0e	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd3dd6e3	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0xdd512356	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xdd62818e	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0xdd6953bd	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0xdd743030	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0xdd957809	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0xdda258bf	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xddb60dc6	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xddd6a7be	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xde07c816	pm_genpd_remove_subdomain
++EXPORT_SYMBOL_GPL vmlinux 0xde0a73b6	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0xde0c42cc	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0xde13a21a	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0xde169871	ahci_platform_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xde42b39c	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xde46e353	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xde549c08	sm501_unit_power
++EXPORT_SYMBOL_GPL vmlinux 0xde5acabf	ahci_set_em_messages
++EXPORT_SYMBOL_GPL vmlinux 0xde651f98	__tracepoint_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xde7469a8	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xde7f57cf	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xde810a0b	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xde8e8a2b	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0xdead0467	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xdebbabe0	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0xdedb8bbb	pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf1e1840	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0xdf255dcf	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xdf26ef83	of_irq_parse_one
++EXPORT_SYMBOL_GPL vmlinux 0xdf27859d	of_devfreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xdf4408e4	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0xdf5c2ba5	dev_pm_opp_is_turbo
++EXPORT_SYMBOL_GPL vmlinux 0xdf5c8468	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0xdf680a23	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xdf6c81e1	snd_soc_resume
++EXPORT_SYMBOL_GPL vmlinux 0xdf6cf36e	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0xdf70aa1a	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xdf85c543	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xdf9d3ae8	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0xdfc2c12a	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0xdfc390a8	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xdfe98c10	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe00c604a	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xe02200aa	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe03dd802	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL vmlinux 0xe0467acd	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0xe0559ba5	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0xe0572f5a	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0xe05b6981	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL vmlinux 0xe06e4157	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe07ca631	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0xe07cb617	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xe08629ca	pinctrl_force_default
++EXPORT_SYMBOL_GPL vmlinux 0xe08b680a	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0xe09374a2	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0xe0b1c103	clk_set_max_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe0c17bc0	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0xe0d02055	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0xe0ff818b	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL vmlinux 0xe1079cad	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0xe10910f6	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0xe10be6b1	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0xe1194773	clk_hw_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0xe11e7e45	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0xe1415523	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe180d0e8	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe1873036	__clk_get_hw
++EXPORT_SYMBOL_GPL vmlinux 0xe191c839	thermal_zone_of_sensor_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe1a1cc4f	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xe1ac8da3	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL vmlinux 0xe1bc3499	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0xe1d14ed4	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0xe1de3808	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xe1ef4305	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0xe213d43a	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0xe21dd022	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0xe237f314	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xe243d8b1	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xe2484b98	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0xe25fdf83	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe265314e	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0xe2668031	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe26a4cf3	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0xe28310b7	pinctrl_remove_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0xe288250a	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe2c60152	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0xe2d1a48a	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL vmlinux 0xe2dbacbf	ahci_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0xe2f2dbc5	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xe2fcb581	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe30bbb73	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0xe3294ff5	device_move
++EXPORT_SYMBOL_GPL vmlinux 0xe340a819	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0xe3596204	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe380675f	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0xe3877f89	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xe3c88ec8	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0xe3ca227d	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xe3cd631f	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0xe3e272ef	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0xe3ee9469	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xe3f953b1	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xe40628fb	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe410fd27	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0xe412990d	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xe42caad5	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe42dcb85	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0xe42e1f70	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe43ed97e	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0xe4418720	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL vmlinux 0xe46615ab	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0xe467f594	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe4c1aba9	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0xe4c22565	cpdma_chan_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe4c4f75e	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4e46d40	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0xe4ed4673	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe50b6247	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0xe50d3447	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe52fc25f	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0xe55625cb	clk_gpio_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe56f77a7	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5929d9c	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL vmlinux 0xe5c2e2a4	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5ffd587	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xe6383283	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0xe645075d	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0xe64cd8ef	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe66b5945	clk_register_mux
++EXPORT_SYMBOL_GPL vmlinux 0xe698c8f6	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0xe6c4a80e	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6d4d0f7	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe6f2c880	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0xe712c5ab	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe7282648	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xe73878f7	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0xe73cab21	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0xe740a22a	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0xe7437ad1	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xe74a69de	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe75f1a29	pinctrl_utils_dt_free_map
++EXPORT_SYMBOL_GPL vmlinux 0xe7622fe2	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe79337a6	of_get_display_timings
++EXPORT_SYMBOL_GPL vmlinux 0xe797f0e7	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0xe79f9cd5	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0xe7ab2c3a	omap_dm_timer_trigger
++EXPORT_SYMBOL_GPL vmlinux 0xe7b88396	mount_mtd
++EXPORT_SYMBOL_GPL vmlinux 0xe7d61fb2	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xe7ea40e2	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0xe7ebd12e	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xe7ec1299	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0xe7f504d2	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe80bee40	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe81f09c6	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0xe8267305	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe850bdcc	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0xe85a9fd3	cpu_cluster_pm_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe8801cce	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0xe899f633	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xe8b31787	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0xe8b91788	sm501_misc_control
++EXPORT_SYMBOL_GPL vmlinux 0xe8bb7f4d	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL vmlinux 0xe8fe7f15	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0xe903a3b6	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xe90fc5a2	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe91265cf	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xe91b9ef7	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe949b13a	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xe94fde82	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xe956a75c	pl320_ipc_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe9640d94	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xe98420f3	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xe9923d00	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0xe997a768	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xe9aa7d6e	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0xe9aecbd5	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe9b17a2c	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xe9be9511	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xe9dd66b4	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0xe9f16eb9	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xe9fcad4c	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL vmlinux 0xea0ec6df	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea1bb291	bL_switcher_get_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xea1e8be6	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL vmlinux 0xea24e9bc	snd_soc_read
++EXPORT_SYMBOL_GPL vmlinux 0xea25f4a3	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xea314bb6	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea440f00	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0xea4d6912	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL vmlinux 0xea55a8ae	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xeaa0e926	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xeaacba9c	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0xeab91c3f	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xeae6d200	of_usb_update_otg_caps
++EXPORT_SYMBOL_GPL vmlinux 0xeaf7f139	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0xeb103a91	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xeb2c65c7	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0xeb4422a1	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0xeb5fae4d	vchan_tx_submit
++EXPORT_SYMBOL_GPL vmlinux 0xeb699989	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL vmlinux 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL vmlinux 0xeb793ee6	of_cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xeb7e0acf	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0xeb8f2ce9	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL vmlinux 0xeb9a819a	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0xeb9abbee	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xebb3592b	snmp_get_cpu_field64
++EXPORT_SYMBOL_GPL vmlinux 0xebb43b51	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xebb7e578	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0xebbe1622	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xec0debfe	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec29ae07	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0xec3951bc	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xec53ca9a	omap_dm_timer_set_int_enable
++EXPORT_SYMBOL_GPL vmlinux 0xec5a9fbf	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0xec5fdf9e	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL vmlinux 0xec67cc59	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xec7af62b	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0xec883634	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0xec944198	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0xeca44a19	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xecc5ad2f	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0xecd73a21	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0xecd96245	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0xececdf2c	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0xecf82718	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xecf8d1a4	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0xecfd8761	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xed12f9a5	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xed165c72	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xed1c99ab	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xed241950	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xed6b8633	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xed70521d	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xed720022	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0xed7f47f9	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0xed840bfa	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xeda291fb	amba_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xedc09c26	omap_dm_timer_set_match
++EXPORT_SYMBOL_GPL vmlinux 0xedc75d33	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0xee0271e7	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0xee04ccb2	pinctrl_utils_add_config
++EXPORT_SYMBOL_GPL vmlinux 0xee18a349	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xee69e328	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee7238e0	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0xee8d7539	cpdma_chan_start
++EXPORT_SYMBOL_GPL vmlinux 0xee938c3b	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xeeb1d829	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0xeed6c213	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xeef2d2dc	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xef07c449	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0xef1ee410	mmput
++EXPORT_SYMBOL_GPL vmlinux 0xef409b74	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0xef464c28	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0xef55bdf1	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xef66075c	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6cd5e0	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0xef84e245	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xef8fdaaa	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0xef9142b2	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xef9f4b34	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefa85c25	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL vmlinux 0xefb892e2	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0xefbf9e7c	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0xefef1e1d	cpsw_ale_add_vlan
++EXPORT_SYMBOL_GPL vmlinux 0xeffd46e2	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf049ca2d	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0xf0696d9a	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf070759d	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf07ed7df	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0xf07f3a8e	ahci_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf0843146	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0xf091a7c3	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL vmlinux 0xf0926e47	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xf09ccf2f	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0xf0a5c09f	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL vmlinux 0xf0bb7b58	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0cb8191	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xf0d4c72d	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf11db8a2	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0xf127795d	soc_ac97_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf12caf22	clk_register_divider_table
++EXPORT_SYMBOL_GPL vmlinux 0xf13d09b9	gpiochip_remove_pin_ranges
++EXPORT_SYMBOL_GPL vmlinux 0xf14310b6	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0xf145eadc	of_property_read_u32_index
++EXPORT_SYMBOL_GPL vmlinux 0xf1595369	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf193aa17	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1b3198b	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xf1e94b23	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0xf1ea73f6	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0xf1f16c9e	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf1fa1c98	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf2137b52	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf223db8e	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf22a3450	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0xf22b0753	sdhci_reset
++EXPORT_SYMBOL_GPL vmlinux 0xf22ceffa	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0xf26b8f76	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf2884eb8	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0xf28dd784	device_create
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2ad0973	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xf2bf352a	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xf2c78c70	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0xf2d395fb	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xf2d954c6	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0xf2e6e726	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xf2fb49e1	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf30fda27	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf3314492	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL vmlinux 0xf355dbef	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0xf3642dc8	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL vmlinux 0xf3657e46	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf3803bdc	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3b4d0ff	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xf3b8c5b0	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3bdf6f6	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0xf3c17d55	devm_regmap_init_vexpress_config
++EXPORT_SYMBOL_GPL vmlinux 0xf3c3d282	of_get_display_timing
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf3feb86c	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xf40860a5	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0xf41c3d99	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0xf41e1858	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0xf458c2d1	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0xf4607614	gpiochip_add_pin_range
++EXPORT_SYMBOL_GPL vmlinux 0xf467ec23	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xf473748b	__clk_mux_determine_rate_closest
++EXPORT_SYMBOL_GPL vmlinux 0xf48ceebd	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf496c010	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4a9252e	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL vmlinux 0xf4c43e32	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xf4d8f868	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf4f92821	ahci_save_initial_config
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf50d4a50	pm_genpd_add_subdomain
++EXPORT_SYMBOL_GPL vmlinux 0xf50dc832	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf541b68c	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf54cadaf	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf56636fb	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5fab209	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0xf5fe94d4	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf6108447	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0xf61baa65	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xf61d5c48	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0xf634d689	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0xf638ce3b	pinctrl_find_and_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0xf671877d	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0xf6880ac6	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0xf69bee13	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0xf69e8192	snd_soc_register_card
++EXPORT_SYMBOL_GPL vmlinux 0xf6a8d08e	pinconf_generic_dump_config
++EXPORT_SYMBOL_GPL vmlinux 0xf6b60222	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xf6c636ce	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6d77f66	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xf6e41890	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf6ef36f7	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0xf6f04545	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0xf6f5077b	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xf73414c9	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xf75dc4ca	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0xf766025e	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL vmlinux 0xf76b0a59	read_current_timer
++EXPORT_SYMBOL_GPL vmlinux 0xf7847db8	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0xf787d4ac	amba_device_put
++EXPORT_SYMBOL_GPL vmlinux 0xf792c2f0	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0xf7b8aae0	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xf7c9a73a	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0xf7e6e6a5	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0xf7e8aa6e	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf82f16b3	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf846506f	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf85e5502	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0xf8666519	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0xf873b247	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf8917078	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0xf8a5f468	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0xf8e6b564	hibernation_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8eabb06	of_gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8f6e34c	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf917f64d	omap_dm_timer_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf961763b	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9b3e6bc	of_get_pci_domain_nr
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9f57625	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf9f7492a	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0xf9fbda83	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xf9fd6839	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa26f622	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0xfa373bc9	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xfa3a903b	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0xfa3ea101	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0xfa413a01	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xfad98409	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0xfaee27c0	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xfafb22a9	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0xfb0228a6	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xfb0bff54	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0xfb30a5a5	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb48c052	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0xfb682e4c	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb76b910	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xfb7a3d10	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0xfb80ee77	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0xfb86dafb	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0xfb94f014	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xfb9a313b	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfbc6c6ee	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0xfbdcd6d4	amba_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xfbe5bb0a	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc057074	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xfc248c89	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0xfc251c74	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xfc2f0f70	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0xfc3fc977	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0xfc4407d5	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0xfc523f29	of_pci_parse_bus_range
++EXPORT_SYMBOL_GPL vmlinux 0xfc5d23f4	of_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xfc64cae0	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xfc95943a	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xfca2465f	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0xfcb2723d	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0xfcb6191d	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0xfcb711fc	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xfcf100e1	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xfcfa8771	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0xfd088a27	of_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xfd0f9a21	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL vmlinux 0xfd14ada8	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xfd1950c7	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xfd21baf5	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL vmlinux 0xfd2507b4	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0xfd41c7ce	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0xfd586bae	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xfd5bf95c	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xfd647228	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0xfd64cc32	snd_soc_jack_report
++EXPORT_SYMBOL_GPL vmlinux 0xfd78eebf	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd7cf9c6	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xfd8c6e71	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0xfda1aebc	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xfda670bd	dev_pm_opp_get_opp_count
++EXPORT_SYMBOL_GPL vmlinux 0xfdb7f111	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0xfdc18059	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0xfdcae422	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0xfde1a33e	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0xfe009c06	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0xfe18dfde	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xfe2a1c2f	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0xfe2ddf9e	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0xfe67a7f2	sdhci_get_of_property
++EXPORT_SYMBOL_GPL vmlinux 0xfe715b66	ulpi_viewport_access_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfe814eba	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xfe82e722	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0xfe8efb6b	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0xfe929b2d	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfe9f0b34	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0xfeaf78a8	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xfed0402e	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfee5b3a5	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff1863bf	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0xff21355e	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xff291ecf	clk_unregister_divider
++EXPORT_SYMBOL_GPL vmlinux 0xff3ae651	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0xff56ca09	mtd_unpoint
++EXPORT_SYMBOL_GPL vmlinux 0xff58938c	mtd_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff6c1e0e	of_reconfig_get_state_change
++EXPORT_SYMBOL_GPL vmlinux 0xff711567	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xffa7f3c9	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffba4dfb	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfff50afe	inet6_destroy_sock
+diff --git a/debian.master/abi/4.4.0-111.134/armhf/generic-lpae b/debian.master/abi/4.4.0-111.134/armhf/generic-lpae
+new file mode 100644
+index 0000000..894fb8f
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/armhf/generic-lpae
+@@ -0,0 +1,17641 @@
++EXPORT_SYMBOL arch/arm/crypto/aes-arm 0x276b2f72	private_AES_set_encrypt_key
++EXPORT_SYMBOL arch/arm/crypto/aes-arm 0x6c62e582	AES_decrypt
++EXPORT_SYMBOL arch/arm/crypto/aes-arm 0xc30fcbed	AES_encrypt
++EXPORT_SYMBOL arch/arm/crypto/aes-arm 0xcf024ae9	private_AES_set_decrypt_key
++EXPORT_SYMBOL arch/arm/crypto/sha256-arm 0x1a807da1	crypto_sha256_arm_finup
++EXPORT_SYMBOL arch/arm/crypto/sha256-arm 0x93d99eb7	crypto_sha256_arm_update
++EXPORT_SYMBOL arch/arm/lib/xor-neon 0x0f051164	xor_block_neon_inner
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0x28865246	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/atm/suni 0xb05a3222	suni_init
++EXPORT_SYMBOL drivers/bcma/bcma 0x010ba288	bcma_core_irq
++EXPORT_SYMBOL drivers/bcma/bcma 0x2caa8811	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x210cf7e5	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0x26d1a0e1	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0x372c7a72	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x4267110a	pi_register_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0x568fb4a8	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x97b36e59	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0x9d8b9926	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xa04847c2	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xb21ba07d	pi_unregister_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0xb8de1e5c	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xc49d9b5e	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xe23b0940	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0xf681ffdd	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xf9e56965	pi_release
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0x957749b5	btbcm_patchram
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1cf185ea	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x24adc9b1	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x2ace6bfd	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5738453c	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa3bddb88	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/nvram 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x17ff2c1d	__nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x2adec1e0	__nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x7da28f12	nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL drivers/char/nvram 0xa8813189	__nvram_write_byte
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x31d5617f	st33zp24_pm_resume
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x71664ca8	st33zp24_pm_suspend
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xdde5900a	st33zp24_probe
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xf09cd45c	st33zp24_remove
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x3c28b9e4	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x6ed57d38	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xcd23bca7	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x42bb89f9	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x555adcb1	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x71ba0daa	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xdea5c5fc	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xe2cfffff	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xea7e56c7	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/pl330 0x9402e670	pl330_filter
++EXPORT_SYMBOL drivers/edac/edac_core 0x4dd95c59	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04dd92ce	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0fbee909	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x11a6254a	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x23dc3b5e	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2df468b9	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x33f17e33	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x34372ac6	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x38f67fa5	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4411737c	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4d5d4eca	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4ef4e06d	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x54c80d47	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x55a9af33	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x576300d1	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x5cdf7ba8	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x6942c934	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x770e9f08	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7aaa7a5a	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7cee8048	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7e431b14	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x892d2aff	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8bcce267	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8e3e8b6c	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x982ff170	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa712eb88	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xc724d824	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd644578d	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xdf2b81f6	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xe7cbaaf8	fw_send_request
++EXPORT_SYMBOL drivers/fmc/fmc 0x1c5dd5d2	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x217af28f	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0x49282c21	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0x4f4e2e6d	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x73769209	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x76687a6d	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x9d231fdc	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xb68d3298	fmc_driver_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xd2b212cd	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xfbd2b46b	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xfed999ca	fmc_device_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x00d753f1	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x01600f8a	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02365dcc	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02be3bca	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0392e1fd	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0669e641	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x070240fb	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0754c56d	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0826d43f	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0846f18b	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x095419e6	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x09d23bc4	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a92fc4e	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ac603e8	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0c006f51	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0e4df14e	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fc831ad	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fccafb1	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x10f0903d	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11b0d42e	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11bee170	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12d4f884	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13a3911f	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1457c601	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x17011422	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x17cdfe78	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1ab8eab1	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c9a36c1	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1cdeb544	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1d49a707	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x200a6c33	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x209144d4	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22779c4f	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22c1d7a0	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22cb3e42	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x24de41b4	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x263b422c	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x270884a4	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x27287626	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2744688b	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x275eced6	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2873bb7d	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x28be489d	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29bf967c	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2b2859ce	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c99f0e7	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2caf4826	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ce0d918	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d575b90	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3260bb1c	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x32ba2bca	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x33457b92	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x346127a7	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x35ddf4ce	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x360c1ab6	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x36b78a8a	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x376e27cc	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37e8cce6	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x384530e9	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38b95e90	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3aebb20f	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b182d1a	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b7a8f6b	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3bbd5b1a	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x404501fd	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x412e6fd8	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x420deda7	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4362e6bf	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43b0b34d	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4562f9fa	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x46098801	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x469375ef	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48ca539b	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4909b612	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4b30b00e	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4b92edf3	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c19fd8c	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4dd552ff	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4e2a2db8	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50c10dcb	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5122949e	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51a65f91	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x53621673	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x53c475ca	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54125206	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54541cfc	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54dae810	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54e07e37	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54ff21bc	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x56ad8c98	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57453894	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x579593db	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x58bb15e7	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5b62920e	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d97ffff	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e7c8b7b	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5f55ccd3	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5fbc7bbf	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x60b2fe32	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x61642e5e	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x624e55ea	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x62cd85f8	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x64879284	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x658c05fd	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x65a5a281	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6696a7f6	of_drm_find_panel
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67c279b2	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6840e6b2	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68ca319c	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68d4548d	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69547e4a	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6989d18f	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69bf3a58	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6a02bafb	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6a21cda7	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6af2d74f	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6de0cd96	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f4fe790	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6fdf8861	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70448907	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72257a44	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7483277b	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x755dc051	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x758766a5	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x75ddbbb5	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x78fa2c7f	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x790d2bf0	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a2f8ce9	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7aeba706	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b64b55c	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b9fbf85	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c5fc0ab	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7d001777	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7d081e67	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7dd0ac23	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7eae4c72	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x81f26e74	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x823812a7	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x826ba3c8	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x828e0e5a	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x83700ca1	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x84f8b80b	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x850ea466	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x869ed37a	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x87013bb9	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x873c7ae1	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x894d8e8c	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x89890681	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x899abfa7	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8bf40c91	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d692903	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e105c2b	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e48187f	drm_of_component_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ec64cc7	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x90cd16d2	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9187c02a	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91aac234	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x936bbe72	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x940df991	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x946e9fa6	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x96ec8b19	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9848212b	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x98ccdb2e	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x98fda5be	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x995919b1	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a11a6d9	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a4f81fd	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9dcc2e37	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9de7f190	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ed1b612	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f2fcf11	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f62f992	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f66aa90	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9fd3c352	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa142614c	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1ebef41	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1ef7c68	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa287dd62	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa3dd45f4	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4204c45	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4c9eeec	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa5220c1c	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa6e9588d	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa73941d9	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xabf1cfa0	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae03ed4f	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaf2f13f3	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaff10573	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb0b6fd6e	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb0e93343	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb12f2f75	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb2431bab	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb2bcf154	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb2d046e4	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3bfd57a	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb4f9817a	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5039be9	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb602e86d	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb68de687	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xba92b9b0	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbb4dfc5d	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbbf6b1db	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbc2227f1	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbeb13bc3	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbec3c887	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbfea5292	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc084b7f7	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc0a24fe3	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2d15dd1	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc3e6193a	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc57e1471	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc9a22fa0	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca127680	of_drm_find_bridge
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcab23df0	drm_of_find_possible_crtcs
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcae156f2	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcba96d97	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcbac9fcb	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcbe94ce1	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcc8451d9	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd06cde4	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd4779a5	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd7b5176	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcdc83a13	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf8a4d6d	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcfaa28ca	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd167429b	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd229e133	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd254c018	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2831bb6	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2ecc9da	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd47d81a4	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd4b1ddb6	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd4f2a484	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd5e43478	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd64afb6f	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd6babc6c	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd7822e9f	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd8c8f163	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdae69b02	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdb633358	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc552e5a	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdccb757b	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd209de1	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd606d12	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xde670353	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xde6cfe57	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe0fdde82	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2f409ee	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe3f1b4ef	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe4850135	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe50c671e	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe53021fc	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6e31999	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe820dbf4	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe9286a7c	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe997598f	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe99a4808	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea04c68d	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xebc7177b	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xebd99527	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xecbc53c6	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeeab60c2	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef4d85f3	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef56f865	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0ba5d77	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0c3e446	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf175c681	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf2433774	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf4dd5380	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf50ba3ef	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf5336fe9	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf5da09b6	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf7dc9e5b	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf84c5a04	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb0971b4	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbdb1d43	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf03088	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfda7dad5	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x02e700b9	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x053df867	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x09e952a5	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0ae30f5b	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0c844ffe	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x137d69a7	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1610c41b	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x18b69ba9	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x198afa8a	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1bc115b4	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1d79b6e8	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1ff9cb4c	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2034ac53	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x23524f67	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x25ef0bed	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2a27cf9a	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2a35185e	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2dec9834	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2e1d4f65	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3319ee9f	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3420a56d	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3590ec8b	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x37ac28f9	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x386d6c03	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3cacbec4	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3d42328e	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3da0e535	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3e71295c	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4105683a	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x41424b89	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x41aef5fe	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x43b73d3c	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x43be56b1	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x45219017	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x45f946a4	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4610f019	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4a21da8b	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4d55c3d3	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5081d25f	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x529a01a8	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x58772646	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x598bf2cd	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x59a54828	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5a6074db	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5f0beee6	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6104246f	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x667b1185	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x676cf8fc	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x68e170e7	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6a105538	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6e52fee3	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6ee93d19	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6f3270a2	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x737586ba	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x74347cae	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x759b7b3a	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x76026b6d	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x76795e21	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x77a53e81	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7a5a6124	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7bb5d28a	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7e885b00	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7f27aa59	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x82dac41d	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8411f290	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8719df8c	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x89e585a7	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x90953006	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x918d0966	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x93af2e07	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x966554e2	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x97b91fe6	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9907b2bb	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9a054d93	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa09959d0	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa1310c2c	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa1b70170	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa2cade7a	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa3d5d7c8	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa40bb66f	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa5d700d0	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa5fc0a7c	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa6ba0601	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d37cfb	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaa81293c	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab3256bf	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xacba5aa9	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xade37900	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb00fbb2a	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb1668e7c	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb23ca67e	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb4012038	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb407cd00	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb4cfcbf9	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb761e36e	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb843ad5d	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb9bc45a4	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbc3c7137	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbd23b23f	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbd30d445	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc0fe7105	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc51ea815	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc7239f8d	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc7cf33e0	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc937ca4a	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc9b8d4de	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcc3b58dc	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcd64b165	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xce002973	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd0e43234	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd2702566	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd4216368	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd43dda8c	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd4ca1369	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd513b8b2	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd7c2448a	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd82574ec	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd8630c02	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd8a7c5d4	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd92efccc	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xda0049da	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xda18e5c0	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdb0c70b6	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdcf0e891	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe229b06d	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe2431560	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe3ac01fd	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe410d82c	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe42103d1	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe459b7c1	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe7d6d0d1	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe821d47d	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xec1066b6	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xedda695e	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf12b8c5e	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf12e578e	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf2e10995	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf6d4bf55	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf913d1b7	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfd21786e	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfdb784a1	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfdc7dbee	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x01974b3f	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x028a06d9	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x02ede84b	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x10400f6d	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x132b05be	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x136ec7fa	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x14b5d09f	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x16a284d2	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1c52691b	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x20825d54	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x265e69e7	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x266aee17	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b7f8204	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x34d03536	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x37dbec1b	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3a754079	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3c3133a7	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4628b006	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4e8e9a71	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5438e484	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x572db514	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5790bac6	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5bc540b8	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5cf59609	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x60965229	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x67b1d568	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6c0ec969	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x783092ca	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x78528bbd	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7bb92603	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x81f1f3ae	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8589758d	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x86bb8a6c	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x87c69531	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x898d0b54	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x89af0aef	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8b6f0aca	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8f4b7911	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9a6ae888	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xae87b61d	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb586641e	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xba2071d0	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xba633325	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbe2c2dbf	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc12a1903	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc38cf2e1	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc7a8fe01	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc7f1faef	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc968d68f	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcd54977a	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd59ded30	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8a8f43e	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe14a6562	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe2bdce24	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe3e1e1bf	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe49b779e	ttm_prime_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe568e6d0	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe5bd3181	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe8295649	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe8db4648	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xea8db07f	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xefc4df0d	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf56de0e3	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf58dcf85	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfd7484d3	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfe8cc064	ttm_vt_unlock
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0e2a6864	sch56xx_read_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0f5877d4	sch56xx_read_virtual_reg16
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x28b22c6e	sch56xx_watchdog_register
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x34257f35	sch56xx_watchdog_unregister
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xe5022f95	sch56xx_read_virtual_reg12
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xed1d2a08	sch56xx_write_virtual_reg
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x383a9032	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x38801942	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xf927ea1f	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x3aaaa1c4	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0xf7acd4db	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0x38fcdf7f	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x0e2ea72e	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x1e265e20	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x2f71a79b	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x3707c223	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x538c1749	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x5c5e6361	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x6a980ab9	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x7958b71e	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x7a57d493	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x7d2448b5	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x85b6d2ad	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x9ef61c8a	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xb06bb8d4	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xb10aa82e	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xb63b16de	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xc353a8db	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0xdae305c0	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0xe18eafe1	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0xb047b8c1	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0xfa7c5b2f	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x38050a97	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x6a197baa	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x9d4acb6b	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xb39bdc81	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x03ecc66c	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x22a2dfef	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x4c055a56	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xa4c195a2	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xad623a52	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xb749afc5	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x0050d7ac	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x66206304	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x7986fa2d	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xb84ab6f8	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x00711c87	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x3251594b	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x32d754e4	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x97b1e2c0	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xa03924aa	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xa40562c6	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc4272da0	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xcbfb75ef	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xf4c617ed	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x33371b24	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x4c8a4748	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x72a35952	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xb0ac9b00	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xfb9928df	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x2ea50856	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x550e3d16	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xc59459a1	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x0720f746	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x0ad49710	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x11254cb7	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x1bd58a19	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x30991f11	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x553129de	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x65e5267e	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x868c90ff	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x877763a8	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x902c0521	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x999f3a11	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xac2696ea	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb9fd34dc	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xbcfc40b9	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xe7ec5690	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xee0f7e08	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf33477c0	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xcd0db4dc	st_sensors_of_i2c_probe
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xf0b25b85	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0xb94d0640	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x4ce1430e	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x4fe4eced	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0x61c2b0a9	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x54d54462	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x5ccb3a91	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/industrialio 0x03a331db	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0x07578186	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x404a7783	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x417353cf	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x4cc92fb6	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0x4f98af00	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0x5242ddf3	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x591f5460	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0x8e9a1070	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x9ff7c0a6	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xa8c9ff2e	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xab34f688	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xb47a8d2e	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xbe315bca	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xe7406fe3	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0xefac081a	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xf99686d8	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x6d53afb0	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0xcdc11e4d	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x2066758d	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x7e0fc2d8	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0x1ba92718	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x38c99494	st_press_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x4b82ac29	st_press_common_probe
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1765b6fb	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x5347cc38	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x582667fe	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x7df81f32	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x91b3e9d4	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x9cf23610	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x0ad23eb9	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x154daf27	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1aa49215	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x209a9811	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x5bfe6684	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x6d56823c	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x72dd81cd	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x7fc31aa0	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x87f831cb	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x88cdf4e4	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x8e5d7a68	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa17e73d8	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xada3b728	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xb5bde182	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xbbc961e0	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xcb7d0564	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xcfeed953	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xde50a101	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x01e5cbdd	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x02d4d576	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x031077af	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x05e45864	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0a59e0c3	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0a777ee8	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0b1b07cb	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0b2710a1	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0dc3d4af	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0e6b1f35	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1310aebb	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x162f0450	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1671984c	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x16db468e	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1b4de43c	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1c46ec2b	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1c763323	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x21e39516	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x26d36c2a	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x26f2f944	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x288b2d53	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x28d74c1d	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2bce4a9f	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2dae76eb	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x30ec413a	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x34f9d9c2	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x408a41b0	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x44a13519	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4e000112	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x510dd617	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x520b2638	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x532bb025	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x55ede31c	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5b38083a	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5f20caf1	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x64d87fec	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6524b220	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x654fab64	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x65e9282f	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x66041227	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x66279fc7	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x677a4694	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6ae6bd98	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6b5e0bb8	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6c300e54	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x70bed0b9	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x70fee2f6	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x73bd801b	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x78ca8aba	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae5dc09	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7d86a90a	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7fb6086b	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x86d95dff	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8860d92e	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x89b047d7	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x90af052c	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x90e26b80	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x91316dd5	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x964b43a0	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9d10e48c	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9e88b86c	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9f579924	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa1d68cb8	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6ea014a	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xac7958a3	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb17e9326	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb1a312e1	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb1c7c15d	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb4461686	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb69df86a	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb889014d	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbdc97f33	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc1a8bdea	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc2391cf7	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd00367ce	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd85603b5	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd8e39c98	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd8fab244	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe15b3097	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe50acddd	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xeb9516b4	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xec78488a	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf3951360	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf71f6efd	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf885effd	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x1a9b3b3a	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x23b865b3	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x268868b5	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x40f14423	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x64df68fb	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x656dd589	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x71903d0a	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x78e0af20	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7eaf55b3	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x885a3415	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xcf180f31	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xcf56788d	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xeb9f817d	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x05f4881f	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x3b880218	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x45f838d8	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x611ada85	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x9e7aad54	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xa7c95d89	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xb1d6fdec	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xcca494e4	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xd3d7b81f	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xd67a69ae	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xde9e1b2c	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xd5ca0801	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xf4732348	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x1bd0d307	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x3cfa49ae	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x441893cd	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x544c41f1	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6eb2b5a1	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x7308c6fb	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x8e00af29	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x96004cd3	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9d60eb95	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xa60bf3cc	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb047f931	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb2c66897	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd190a153	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xe254d41f	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xff5632eb	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x1485b35d	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x21f69344	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x22f9f7fc	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x261987dc	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x2e7c3e3f	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x37694570	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x56d99e61	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x650e10a3	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x720f75e2	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7c0d8c71	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7f352f91	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x838b6ee0	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x88709a85	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x9faff31e	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xb125d3fc	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xbb2d7e9a	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xc0a4d6e6	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xcdba86d7	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xdd589c5c	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xe6dc217b	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xec835d51	rdma_destroy_qp
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x05166a8e	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x19ad4f05	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x54fc7470	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x67974a07	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x8180b95a	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x8ecc4788	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xd016a4d5	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xde88a3c1	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xf0246c1c	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/input-polldev 0x11a17587	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x6ecfc24c	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x6f2c4d4f	input_register_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x7ce98e98	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x8531fe21	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0xf5a96ac7	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x44ce1b0c	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x80a6210f	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xf26a8ffa	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x15358af5	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x60293371	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xa6264e54	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xde5547c7	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xfbb69827	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xfd3c095e	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xfde208b2	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x34e25706	ad7879_pm_ops
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xceee204f	ad7879_probe
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x18993499	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x25eea4be	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2e067ce4	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x4c44d523	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50ffb87e	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x55a40608	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8698025b	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa7c4fd6c	capi_message2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc10fe128	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc9744b4d	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xd58c737d	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe8ad9bd1	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xfd542522	capi20_register
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x0c9ec0ad	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x19c289b3	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x2cd1b666	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x36137460	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x495208a2	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x4b3e4cef	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x4ef7fcb6	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x7841a25d	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x86797f43	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xb17a5a4c	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xb9c996a9	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xbb19a518	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xe21a575b	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfb77d231	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xff315458	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x22ee98c1	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x3ea98d6b	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x4ecd4d68	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x838804c9	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xb27c4f04	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xb5a0a0c9	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xc8d3db8f	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xe33c996d	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xf63219cd	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x472852c9	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x94bdff8e	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x9fd9a54d	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xa301ef20	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x0199d9d3	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0xe0f7fb3f	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x461c5a09	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x50777e09	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x80e49a9c	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xa6eb596b	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xabd3030f	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xdb734a99	isac_irq
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x17f627d0	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xb5f46ecd	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xd806285a	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x19e9ee7f	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x22a72f82	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2fd69622	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3a750900	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x40fc3751	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4a974e9c	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4ba03279	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x518aaea7	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x5a0b002a	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x5d19cd27	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6bc14c1f	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6e4ef000	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7542d380	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x75e0cc46	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a19a053	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8abba832	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x99d64904	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa11ef19a	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa98c66c6	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xabb1fad1	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc1cb6d91	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd1c33e26	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xed936117	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x18466234	omap_mbox_restore_ctx
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x1b6507a6	omap_mbox_disable_irq
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x1ec5a141	omap_mbox_enable_irq
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x33866b54	omap_mbox_request_channel
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x8099d7d0	omap_mbox_save_ctx
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x10dc0d06	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x21c7828c	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x2bf2cf95	closure_put
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x3361c614	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x4d2fddc6	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x66d28e22	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x6969b5d8	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7b55ca4f	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x9e8b3cee	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xab2d2b84	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xad29a6f5	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaec09a2b	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaf77343c	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xb4ccf7a0	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xb8b6357c	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xc04554f7	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca580595	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe47e0829	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xf8fd4bac	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-bufio 0xa7978f56	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-log 0x1fbae3ed	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0x99fbe31c	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0xa1b8bdc3	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-log 0xc4ecb78e	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x3f6108a4	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x92ec269d	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xa4b54081	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xaa84b31b	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xba3b7465	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xbb340f19	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/raid456 0x4390fb12	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x0159642b	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x2db7f119	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x3ede648a	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x4e9b2f5b	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x55c29736	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x5d80d5c6	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x6d63364d	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x8ee70d58	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x9328ff6d	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x9e2a9d3a	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xa582b63f	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xa6ecb7aa	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xed2a0622	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x11dbd485	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x72cc826e	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x8ce88bdd	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc0b753c5	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0xef8cf916	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x93103dfc	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/common/tveeprom 0xf39374af	tveeprom_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0c777d9f	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1ad6fb27	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x23056281	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2c26329b	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x33edac1b	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x344908d4	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x346d8495	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x34d5eadb	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3656cb10	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x40c0d66b	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x46493299	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4b45569e	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5b521b6e	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5d7951e4	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5e8a94c9	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x629f9d31	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6e49396b	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x71d8a19c	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x72180695	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x789100c8	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x819cf7fb	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8633f37b	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x91325431	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x96a0e538	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9850cb88	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9c19040b	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa49a87f8	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xab729e01	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc0158331	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd5757859	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd942c3fe	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdb1a8bd4	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdc094c39	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xedc2cdcb	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf4364619	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf48116c6	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf7a115cf	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfd459c8b	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0xa978901a	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0x5c44f719	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0x958d43ab	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x1ba18017	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x35670499	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x4e474749	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x668257a2	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x7789c489	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x77b7fe0e	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xb3841f1d	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xbba9c517	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xdcebd219	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0x92c5efa8	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0x56e97049	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0xa38be2da	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0xd50f3207	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0x9c5e05e8	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x196f364e	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x719131b5	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0x3b3a3d16	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0x256c2db0	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x4cb36cb8	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x7bd9ad4b	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0x91906c01	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x4e37a943	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x8ae19318	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xe1042fd0	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x423e79e6	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xd48456f3	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xf03b6cf3	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xf1173172	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xf3e6e383	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x11ea8a53	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x406fe2ae	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x4431685a	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7172c207	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7233f10a	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7f00515c	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7f386117	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x9c1dcb97	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xa082abb9	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xabb92b65	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xb1f7fb30	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xcdd24989	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xdf2bae59	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf8508580	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xfa91151d	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0xfb65866d	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x160030a1	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x4cb49851	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x5a52f1cc	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x5d8d7a0b	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x6cebe16e	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x85f29671	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x4e5b94db	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x67472724	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xe6df5ea5	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xf348714d	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x7edaff32	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xabc5789c	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x5a851709	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x75f7983f	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x76bf218e	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x8b054c39	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xd0f50e7e	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0x30199880	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0xbe1775f3	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0x5c04ba79	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0xdaf5e26e	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0x3ba32a2a	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0xaa0005f8	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0xabf13343	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x97c123b9	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x0c12db00	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0xef3f6b8f	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0x6709501c	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0xb280aa9e	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0xa0363bb4	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0xdcea9b2c	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0x0d21bbee	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0xe1443cd5	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x1c2b7886	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0x359dacab	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0xb680c19b	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x0bd3eda3	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0xa8ade0f8	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0xa36665ca	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x3a632678	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x52ac2fef	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0x6f9d99f6	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0xe62b6e6f	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x5599c2b2	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0xc4f019df	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0x9c73c947	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0x56664882	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0x408c91cb	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0xf87db8fd	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0xf40046c3	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x656cc6a3	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0xc67d8871	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x609a5de7	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xabb76d69	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x95f15f0f	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0x450f31d5	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x391f8e86	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0xbda1f3fe	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0x9c8a729f	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0xd092d08b	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x26a49231	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0x8180ccb6	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0xd319f4cd	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0x0838a449	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x804fb58e	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x3b84c5d9	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0xed66c03e	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0x991c7d16	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0xddf23914	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x39ce19cf	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0x02a79977	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0x83281a19	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0xa1b82096	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0x2c4f234a	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x4e45709d	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x5cbbe3d7	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0x711a1d3c	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x1c9f260a	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x7a88e28d	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0x7e35855d	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0x1da4867a	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0xc44a030b	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0x6ec28ee4	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0x9f251da2	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0xf22370c3	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0xd01205de	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0x6a1a36a6	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0xc7852324	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x19c6c69e	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x466725b7	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x5d1fbb6d	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x6b72d163	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xa00e6acb	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xaf385268	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xcba3c4a7	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x0d29358f	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x29f1418e	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x720d9151	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x7b27b9d5	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x6e38e74b	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x7fa96d2a	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xd3aca3a0	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x032c3946	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x37783d9b	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x45f86a69	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x7eab8819	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x9499e36d	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x9f224fee	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xb1a5c5e4	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xcde39524	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xd5272fc6	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0xb0617fa3	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x460616a1	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x60528d34	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x65e176ab	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xc2bb4f90	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xf946bad1	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x3031832b	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x0adc7d99	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x17c06790	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x61eb2e70	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x62baaae1	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x9baf189c	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xa98ff392	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xfe034edc	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x67595809	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xf475abe5	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x6472ba09	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xc379d6cd	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xea684ff1	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xfcbe97f2	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x13709f46	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x28894f3b	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xa7d95da1	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xc329b994	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xc95a7fb5	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xd1fe254a	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xe6ba59ab	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x12e2d8ec	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x166e40b7	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x1b16c5dd	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x2c957196	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x38411917	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x40bf7b73	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x41760ab9	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x54913e1c	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x5c93c429	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6c538af4	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7013000b	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xa39db13b	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb910ce41	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc9943c64	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xcaeb150d	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xcde6b838	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe31578c9	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xebbd3581	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xecb5580e	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf652f57d	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x18e0857f	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x28b6dc4d	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2afc4328	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x4c1c78ed	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x6277e6ad	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x721c139b	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x852e4d0f	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x94c0d6cd	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x9b790b0c	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xaec08e8f	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xb24b97c8	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xc485fb6f	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xc77e8eae	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xef54a07c	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xf4d49b8e	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xf76bbc44	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xff4d74c7	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x301c1d37	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x43e99de6	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x547b4b9f	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x5dee9471	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x6c26e2a4	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7195b41f	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7cdc941a	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x8c693a0a	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x9ae2a0e3	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x9fa9aa33	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xeb54f731	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xf887ba8e	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x2c92e220	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x05a970c5	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x180c2860	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x1878a491	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x1fae058a	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x689b394f	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x90f00602	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xa68e8ae6	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x24194b6f	soc_camera_client_s_crop
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x28aed4f6	soc_camera_calc_client_output
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x959f9775	soc_camera_client_scale
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0xb9be7be0	soc_camera_client_g_rect
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x66f25b50	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x6f1960bb	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x7c137f76	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x8289204e	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x95a3c08d	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xbc1954f1	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xe2f92fa6	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x0c2d00cb	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x1b825012	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x2910fca5	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x3b4a37e8	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x3ce9f018	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x5bc10f3e	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xa5294569	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xf463c42d	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x25bd6175	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xcb0f0663	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0xca3e4868	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0x4297ba90	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x010863ed	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x2cbab599	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x37f09b2e	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/max2165 0xb9a6310b	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0xcb2a651e	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0x9e2ebac0	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0x1de6bc34	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0x169f356e	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0xd02f980e	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0xa3226246	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0xcd66e0ed	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0xe5311dd1	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0x25995fc4	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0xbab66665	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x0711b717	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x7bffb2ac	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x43534054	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x5ee785d4	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x6fb0456e	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x8e1bb7b9	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x90c32d66	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x9c3b002e	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x9d6366d8	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xc697f3e6	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xdf1a3bcb	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x0186e332	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x0b01d64f	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x21d93a0e	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x6ae39365	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xb44e453d	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xd48b1072	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xd7a2dd26	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x1dfcc473	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x136bd681	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x154a34e8	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x308e1398	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x5364f8bb	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x67b60a8a	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x6eb3f02d	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x7d6d98c5	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xa3b8d904	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb63a33dd	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xe444daab	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xf5c6ec91	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x920083df	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xd32b3bf5	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x2aeb1ffa	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x37f8ab5c	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x47471ff5	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x7b8d927d	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x8c52b264	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xa84373db	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xbf7d5c99	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xfb086cb1	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xfb10a0c9	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x372bbaf3	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x3dc25117	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x6e7f47c3	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x76e5b439	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xb05c0772	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xbcdb707f	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xc2487087	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xe8fb87de	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x181e3f3a	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xf191821a	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xfc0ef623	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x9f2d5c19	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0xb4ea5dd3	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x9f77c08d	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xc84ed450	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xdafadb54	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x2d3accb2	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x2ec18838	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x4f5c87f7	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x5225172a	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x7a76aeb9	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xcce0c1c4	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x137d14e4	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x284abfae	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x21bda55b	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x426ec53c	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x55e43388	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xb9350200	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xc4320b09	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xe6766e98	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0x1cf5104b	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0073c603	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0195ff84	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x049171b1	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x082f41a3	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0d60a3bc	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0dd202cf	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0eba63a4	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x13aead98	v4l2_of_free_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x25cdfe11	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2bb495e6	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x315da6bf	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x357b46eb	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x35e22155	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36d7dbe4	v4l2_of_alloc_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x38efd0e2	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3a523282	v4l2_of_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3c706d65	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3d10ad18	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3fd1cd5e	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x40cd6e31	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x449c1733	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x46a3ce77	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4c13394e	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x53e83ffd	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5628b6e4	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x56b47187	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5edc9d52	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5f2227f1	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5f89b24e	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6390e6ce	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x641f5322	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x64a2ff55	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x65214fc0	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x658e4a20	v4l2_of_parse_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x73cd6705	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7505fe7d	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x772b3308	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x78a526d0	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x799b38e5	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7c80415c	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7d73ba77	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7f8943b2	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x80a3a8da	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x816c3c34	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x879b0e96	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x88da4650	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8c1d5107	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8c80ed03	v4l2_of_put_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9453b3d0	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9885029c	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9d157c9b	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9fcfbb24	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa0238369	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa163d219	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa1a3be1b	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa82bab9c	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xab626805	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb0f63d42	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb0f7acf6	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb69fbe6e	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb806ed37	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc122101	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbeabe536	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc016f0e7	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc3f757ff	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc521f858	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc8940646	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd05a20a7	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd4ee6f2e	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xed78dc18	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf46fc39c	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf490f004	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf62b408a	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x1d598e42	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x2c666fff	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x58ef2e4e	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x62793614	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x64aaaf8a	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x7448e7cf	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x7a9f7812	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa5987a36	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa5a89715	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xab557183	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xb5d8ba7f	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xb7e18111	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xd6b3707d	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x0d88779d	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x19328249	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x32f89349	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x39131239	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x42d5697e	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x432643d8	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4942d708	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4f87bdd4	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x58a34978	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x62004496	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6b4a181e	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6ff5efd5	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x7420dea3	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x979c18ce	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x9a852e52	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa27e0411	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xacdf3994	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xadf0ca36	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb311784e	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb3249fab	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc4e20b51	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc6e27b51	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc9589656	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9c56bde	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe7638b87	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xeb209263	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf2c95d77	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf645c44c	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xff496904	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0a2b5318	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0ad751ce	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0ae68dc6	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0b9ea57a	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x16f2a9c9	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2304a802	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x431c9113	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4980c857	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4e97e103	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x59852da1	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x5d584f00	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x684774f3	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x69b2f62e	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x75c3c468	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x874aae6c	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9a289284	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xae773243	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb7d86e1b	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc74de26c	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc8a9dfe7	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe1abb61c	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe1ebab9d	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe918e963	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf35fa74a	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf7362208	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xfd0b8dc2	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xfddcbc0e	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x2ac405dd	cros_ec_register
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xa7805423	cros_ec_remove
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xa82273fd	cros_ec_resume
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xe6f49cd9	cros_ec_suspend
++EXPORT_SYMBOL drivers/mfd/dln2 0x581b9b0b	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/dln2 0x86709209	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0xd18c84ec	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x705464df	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xc21b8bab	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x1922df45	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x1e09e9b9	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x499d858f	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x6d344121	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x7afb0986	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xae357bea	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xb261b124	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xbcabc5cb	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xbccdbd3a	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xe3f68599	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf11c8317	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/qcom_rpm 0xd042c9be	qcom_rpm_write
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x3096860c	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x822f06e1	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x0659ec9e	wm8994_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x34635707	wm8958_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xa17571c8	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xab01552a	wm1811_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x6204713c	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x757bdbcf	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x8a05ed90	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0x1a2834f0	c2port_device_register
++EXPORT_SYMBOL drivers/misc/c2port/core 0x3eaff2f2	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/ioc4 0x72d52c30	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xe5b2ac6c	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/tifm_core 0x164d20de	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x18603a1e	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x1dfcaab7	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x317998da	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x39f86aa1	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0x4b5fcf4c	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0x5089d7e7	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x6f6aaff9	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x73fb8a5b	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0x7b0e3058	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x8ec139c4	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xb5f1264b	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xe0e1d6fc	tifm_add_adapter
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x470751eb	dw_mci_probe
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x5229daa2	dw_mci_resume
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0xb69fdd05	dw_mci_remove
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0xf70ff5a1	dw_mci_suspend
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x17477eff	tmio_mmc_host_runtime_resume
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x378f2335	tmio_mmc_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x3aed3912	tmio_mmc_host_probe
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x6757b177	tmio_mmc_host_remove
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x6d3deee9	tmio_mmc_sdcard_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x7a6fd700	tmio_mmc_sdio_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x94cf8580	tmio_mmc_host_free
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xa1c2c55a	tmio_mmc_host_alloc
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xc8d0ffb0	tmio_mmc_host_runtime_suspend
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xf02062dd	tmio_mmc_card_detect_irq
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x29821cac	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x75a6ce50	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xd936bccb	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xe3b5c141	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xe69275de	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xe9e63969	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xeb2d7a9f	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0x4e51284e	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0x5efee554	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x492d0e91	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x669768eb	denali_remove
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x6a6ed5b1	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x840f1d83	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x8bf00fc6	onenand_default_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x915d7fa8	onenand_scan_bbt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x0085a808	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x75aedf8d	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x8912979a	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x8e83ba24	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x910bcd7a	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xcc0cbdac	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xd15c100e	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xdb85f010	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xee7ce8a0	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xf26371f1	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x358f26ab	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x7532e232	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x8a875b91	com20020_found
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x13f962cb	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x162d1b00	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x178b9d2d	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x3165adf3	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x36a5b055	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x52bd24e2	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x6a9b2c40	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xa2a94e02	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xd71572b3	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xf9eef9fb	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0x531a8925	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x093726c8	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x25308432	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x4623c666	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x62b1952c	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x67c0f8fc	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x75235ec5	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x7ea36e19	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x9df8ec4c	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xa188ff03	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xa568a397	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xb964b2fd	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xc95368fd	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xcc6fcd53	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd7a8b115	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xe06fca0f	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xe3b62e82	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xf6ff9718	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0a11526c	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0ec3aa1a	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1d799fd8	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3aa1bc3e	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3bb205e7	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3f120369	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x448f3b34	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4ac0847b	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4bc6d869	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4de31aaf	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4fcbcd70	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x5e4df5c8	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7343a65b	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x81bafa80	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x82aa0cf5	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x86566d56	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9a779947	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa370a7f5	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xafb9bfc1	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xbdf3aac1	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xbe6095a9	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc43e42ff	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc531fffc	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00a4f2f	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd2df5bb3	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd2f2e067	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd78fc54b	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd83a989c	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe3395e84	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe6d1f913	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe74f3899	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xeea14738	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf3585404	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf9feedff	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x10a028dd	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x1edb79ce	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x400e904b	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x709f26cd	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xaf8a4b09	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xf2d1f0d6	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x3ae57bd2	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbd944340	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0x073f349e	hnae_put_handle
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0x4aad0bcc	hnae_get_handle
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xb1266858	hnae_register_notifier
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xc981b48f	hnae_reinit_handle
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xdf24adef	hnae_unregister_notifier
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xe476bd0b	hnae_ae_unregister
++EXPORT_SYMBOL drivers/net/ethernet/hisilicon/hns/hnae 0xf80315b1	hnae_ae_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x07bf039d	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x18215d6a	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1a1661f0	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1d7cb1f3	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x20fb42e9	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x28c24a73	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2b4e31f2	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x38ec0d37	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4b4fca13	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6384ce69	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x683b7060	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6f03116f	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x78e6ef59	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x85a989b0	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x85d3a0b9	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8ea5a480	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x94dfe4d3	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9824dfcf	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x998bf21d	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9a20dda0	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9ec61b4c	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa4688053	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa6719350	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb7a680f7	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbce8c240	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc6c88a0d	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xca07e763	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd081184c	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd10c6276	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd67a654e	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd9ce4ab2	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdfa4d463	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe69cbe65	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xebcad11b	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xee05e380	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf0fb39f2	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf22cca70	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf7694e54	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x076f0cef	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x152c0d12	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1571f4d2	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x164a813e	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x17cf72ed	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x21b63333	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x28db16c6	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3413f88f	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x50e87426	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x607cad8f	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x64e438a8	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x70e26e1e	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7d87e40f	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x84ac028e	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x851e8c1e	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8b5d4be8	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8dc24464	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8e72edca	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x97313ae3	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa054f27e	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa70ae220	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa7ab257b	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa8ca91f5	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xac6cfff9	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb31bb78d	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb347a16e	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb79246a8	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcb78edc1	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd266e63f	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd5c5fe11	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd5f00854	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd88479ee	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdb1bfe51	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe79ba788	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe94822c7	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xeb219faf	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf8a2aab0	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfde87586	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x32801879	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x32f2818d	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x863c432d	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xa13d7233	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xacfbf8b4	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xc14ca46d	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xc8a7a5ba	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xcb5c8545	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xe681790e	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x0090bcec	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x670010f5	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x9d810ed6	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xddf530dc	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xfab1ce42	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x08973055	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x13737898	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x2232b6d9	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x66ed313c	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x6e6d79a7	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xa3767495	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xcabbb61b	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xd3d729d2	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xdf1e14c5	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xfae3bb7d	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x0cfffad0	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0x1869d8cc	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0x53cfd78a	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0x576688f1	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0x7cd8fb71	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0x920812a7	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0x96151080	mii_link_ok
++EXPORT_SYMBOL drivers/net/mii 0xa0f0c4e7	mii_check_media
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x05dd7fa2	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xf61234bc	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xa4766f41	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xdd36de31	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xed06e362	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/vitesse 0x67039810	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x67ebdbc4	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xb64781a4	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe91b3e5d	pppox_ioctl
++EXPORT_SYMBOL drivers/net/sungem_phy 0xd8aa26fa	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x3d6f61b6	team_mode_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x515e23a1	team_options_register
++EXPORT_SYMBOL drivers/net/team/team 0x52940ed8	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0x6be4735c	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0x6c609ff4	team_mode_register
++EXPORT_SYMBOL drivers/net/team/team 0xd95e9747	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0xdde5b966	team_options_unregister
++EXPORT_SYMBOL drivers/net/team/team 0xeff82cad	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x55cc13ef	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x57221c9c	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x70d9442d	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xde93a3f8	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x01ea258f	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x12c5c736	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x487a8dde	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x529a9c98	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x5b8c83b9	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x72016996	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x95f42efa	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xde657b48	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe2edd7c4	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xf11c9bbe	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xf3b27549	hdlc_open
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0xe5a4b48f	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x3745dbc3	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x380b039b	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x3ac8ce95	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x47e5c077	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x5ebc9388	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x8030c4d0	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x94f61c97	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb477234d	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb79f276a	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xbe95f53b	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb0c9d50	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb6b2380	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x0ecae3b7	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x111b1c91	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x1ff4bd70	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x205a05d0	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x23fc1e33	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x44e4a550	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x55484869	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x68d94d81	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x6c7c3450	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x7c2313e8	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x83ae4d1d	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xba714f1a	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xd33f666b	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xd6b78f83	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xf9ab021f	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x577c0cc1	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x6955dad2	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x69c796ff	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x77a65d0a	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x861077ce	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x9d3dfcf1	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa9d7efcc	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xbd058199	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xdbadf826	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xe5998e91	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xf810464b	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x08197c72	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x0ac1c46f	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1bcae4ab	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1d889072	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x284d3a57	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x31ba8acd	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x415800d9	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x70fd4e9d	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x72cc7f5e	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x748d964f	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x756243d6	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x825ce54f	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x92347298	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9834eedb	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xa3c65c74	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xaa88f75c	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xad7a3ed6	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb216f0dd	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xcbbc0cdb	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xcd178818	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd07f538d	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd0a199bc	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe8aa42db	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x042f27b1	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0590da09	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x06b38757	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x08068cc0	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x08ab0b8d	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x092c8887	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x09541b1f	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0aeebf41	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0af4c23e	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0c8eee2f	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0d253009	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0dd7af37	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0ed71ce5	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0f02c75f	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0f3d51d9	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x10f658bd	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x129444d7	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x15a0beab	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x17cb8d02	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1db24cbe	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x200988bd	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x221b49ce	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2514371c	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2ba79247	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2c66db6c	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2d566e14	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2d86ff3f	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x33b11624	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3c6dd259	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3fc9e40e	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x40880f89	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x40a6b8c9	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x40dcacbf	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4423634f	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x44964036	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4ec8e5cb	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5009ce38	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x513f250f	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x526d8aea	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x52c059a8	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x52dd8cce	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5b436b8d	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5f6980b6	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5fbd8829	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x60835e26	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x61f86bbc	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x665ac0ed	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6fad3fde	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6ff6534b	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x73212dfe	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7cddc13c	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7f192d04	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8228c731	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8a1af5bb	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8a59917f	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8d1c7d89	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x90c2ead5	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x90f1b2e6	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x913e03dd	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x92e38b56	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x983e64f5	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9d5b82c8	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa0865e83	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa14d4a1d	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa28f6a47	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa3d6cb40	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa7915370	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa7ae3701	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xab86921d	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb569d72e	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb7286c97	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb91d23a2	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb97a9a17	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xba3ab7d8	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc29b0a85	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc2bf87fe	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc729e359	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc77db7bf	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xca31fbab	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcb978463	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcd530a68	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd3a0fd9a	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd4051850	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd89ffad1	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd9c59b7c	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdc2d9bf7	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdd15f070	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdf300948	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe309cd81	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe472e764	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe4e71df2	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe6394dda	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe689edbd	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe6c1e722	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe7b4c59a	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe7fa08b5	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xec1dc347	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xecb25ac5	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xee9ddbf8	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf098832a	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf17688fd	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf459d6c1	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfd2fa01a	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfd501e2e	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xff6893ea	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x2302a50c	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x591d88a7	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x59b6df7d	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x11b8cb23	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x13802948	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x1bb2663b	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x518f376a	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x75d6dca9	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x775c5919	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x77ee74d5	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x82a818c8	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9eccdb0c	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9fb71dcd	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xb4439a48	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xdfebc6d4	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xe2e4b035	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x077d260a	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0ad69602	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x211813b2	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x22b5f02a	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x31b5078a	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x3c7d6911	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x41ba1b04	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x4bde21e3	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x59fbaed0	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x65f1096c	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x6a5f65ad	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x6b796908	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x6db2b70d	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7423fc1e	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x78b88d9d	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7a49f544	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8895310d	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8f278364	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xaab2f7fb	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xabb0cc19	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xbbacd1cc	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe3ea909a	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe545abae	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe687e275	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xea688131	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf686e4fe	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x093643a3	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x09a12c07	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x0a753052	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x18b8fd94	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x1e8abdd0	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x23375432	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x43b9c9b6	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x489f9a84	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x56cc76c8	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x585ab3f0	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x6b2106d0	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x6d46cbdf	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x77fe63c2	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x7bba628e	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x901310a6	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa3c02924	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xadf5ecbb	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb64df587	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xbcbc61b2	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xbd0fe3c6	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd00ad61d	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0509b8a7	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x05561026	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x05aed295	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x06aa68fa	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x074176d1	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x08284dde	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x086af0f9	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0b9142e1	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0be83c6e	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0ca7bf81	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0ff31b5d	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x10d53b97	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x118619cd	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x132d5579	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x18400b9b	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1a76f270	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x216c95aa	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x22686672	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x24d859ad	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2543ef35	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x29462e88	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2a8f6479	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2bb93550	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x335eedda	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3d7db616	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3f24eee9	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x41aae7af	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x423e1dc7	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x482e6b80	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4bcb2e1d	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4cbc7b5b	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x556634ea	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x560a90e0	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x570b54b5	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5713dcb3	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5b26700e	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5e0a0de4	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5ec4a863	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x63ff0e18	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6a2799bd	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6b6ed2b2	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x72dd3dac	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x72e36824	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x78ba6133	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x78d8e78f	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7948ffa2	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7aa8ac84	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7e723eac	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x80f440c4	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x833e39db	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8386d924	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8389d4a5	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x84b19b74	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x85bfd27e	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x86f4dacc	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8c497b5a	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x901955a5	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x917edd6c	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x920316d7	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9c07bafd	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9c6e7d5a	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9e041b31	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa08e4e57	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa9eded7b	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb470f0c0	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb478247a	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb8a3d41e	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xba190e60	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbb4bb7e9	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbdd97c58	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbfe83dc2	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc056f9e7	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc86d0967	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcc48f54d	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcc918d60	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcd48400a	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xce3b4dd9	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd1ad53aa	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd459e20f	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd47ed60e	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd48c5c33	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd549b679	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd7708dc5	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd803213a	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd83cd1e7	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xda7432aa	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdbacb30f	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xde14ad15	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe34973f4	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe784e760	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xeb7512a8	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xec1d7896	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xee1e612b	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xef89cff3	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf608ac8d	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf7fc0068	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf8319efe	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfd3b3f54	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x180d7a46	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x208d96c4	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x26bb7eb8	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x436814a2	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x496d7aef	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x8f81067c	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xfd34aff0	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x05e75df5	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x1895d817	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x2fc78091	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x3f5877cd	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x54004a62	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5bfb0c47	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x7888b564	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x82df8c21	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x83387adc	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x9deecd4a	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb599ed9f	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb6049ff7	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xcd15706f	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xd141f5b0	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xdbcfd9f2	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xe72d4773	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xeb6fcedb	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0x4ebb31f4	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0a1af356	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0a48b408	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0a4e4881	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0fe107a6	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x11cdd62d	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1398e26c	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x15262804	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1688f523	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2089cd73	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x209c9ef3	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x226e6b50	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2471ad47	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2542b673	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x34ff2a85	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x38618040	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x41d12344	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4efeb7df	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5e897d07	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x63a7d10b	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x644d0635	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6a72f8cd	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6d3c968c	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7193dd65	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x71e086e2	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7d4029e8	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7ebedbcb	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x89de299f	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x91944ac5	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa92ddfab	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xad9bf687	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xafa8e33d	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb0d15f87	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc0529006	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc6bd9b20	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc71cd0d0	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd74e4993	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe327f794	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe8047ab8	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf851be37	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xfe983c1a	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xffc97eac	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x097e692e	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x6687a6b0	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x875bce09	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xaf4c7a79	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x510ee89d	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x8fd22572	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xa9d125bc	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xe86a3860	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x153c7a92	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x196a068b	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x19efe3c5	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x26363a75	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2d29bf32	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x332d29d4	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5424fa7b	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x71c539a5	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8139513f	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9b1b7ca0	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa71b1e7e	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa82bec57	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa94136fa	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xac7564d3	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb0693ecb	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb6809500	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbacc7f57	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbf6cf898	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc2c46364	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc7717e2c	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc8acb998	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd554506a	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd6a20a95	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdcaf74f9	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xefd1eb9f	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf609615e	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xfb9529da	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xfe876d34	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x79e02999	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x8473f690	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x9eb9e53e	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xc50a2b78	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x37d863ad	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x592e4dc0	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xd28599f7	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x1c24b499	microread_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x2e281838	microread_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x2ef32c0c	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x975386b6	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xc2e51b54	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x241fa825	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x92adfd23	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x670bbecd	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xba7b4a31	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xc455f88f	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x2f40d1bc	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x388c9d73	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x4ee85b1c	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x5c8d4f42	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x5ca7967a	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x777fc620	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x77c41215	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x8c0a583c	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xabd0ca94	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xc60bd602	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xc7e15afe	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x000ac5c9	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x0bbfda1a	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x19966d62	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3b32cbb9	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x536fab1c	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x58cdac16	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x5ea8a720	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x6da8fd63	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x728118e9	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x746c4be6	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x7749b999	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x7e1381e4	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x851f93df	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x8db023d4	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xa3c7b243	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xa6f63974	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xc1875f90	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xc6c8b669	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/ntb/ntb 0x8936c435	ntb_db_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x8ca0687e	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xb5db7a2f	ntb_clear_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0xba421d06	ntb_link_event
++EXPORT_SYMBOL drivers/ntb/ntb 0xc6b05bbe	ntb_set_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0xc9633466	ntb_register_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xea9bf1f7	ntb_unregister_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xf3a94966	__ntb_register_client
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0xbf52466b	nvdimm_namespace_attach_btt
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0xec6daaa7	nvdimm_namespace_detach_btt
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0xdb6e5b0a	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x00da692d	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0x045655de	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0x10c4157d	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x1dafdb96	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x232830b6	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0x2bda3b16	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0x33e32cb5	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0x3f20e274	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0x40a32223	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x42a1351b	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x4c5dcdbf	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x54dd4a19	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0x591f2f74	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0x5981a684	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0x5c2007ad	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x62ceff7b	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0x67858a13	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0x6b570d9a	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0x79e4e11f	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x8037fcfb	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0x88162085	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0x911e3492	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x9e5f5a2e	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xa01b98a2	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport 0xa2779c31	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0xc0b56ccc	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0xc353a39b	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xc3891aef	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0xd709074d	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0xd99738c3	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0xda786039	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0xfeeadd4f	parport_release
++EXPORT_SYMBOL drivers/parport/parport_pc 0x01d2e122	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0xf98ffe61	parport_pc_probe_port
++EXPORT_SYMBOL drivers/pci/host/pcie-iproc 0x5673d761	iproc_pcie_setup
++EXPORT_SYMBOL drivers/pci/host/pcie-iproc 0xd76b6c5a	iproc_pcie_remove
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x1683dba7	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x4a980b00	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x6bdf0ce8	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xa931d6f0	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xc31f53a8	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xd2222007	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xd5337d76	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xdb031b11	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xdf5785f3	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xf99c01c6	rproc_shutdown
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0x5288ffa2	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x254fb09a	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xc04f12ba	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xc4a1afa2	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xdfb564dc	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x1400d004	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x17699211	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x1eab907d	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x2a5357f2	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x319cab3c	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x6cab4fdb	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x6da4d432	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x9d0574e4	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xa846d7d8	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xc805e8e9	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xd4d4124c	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xdbcca1aa	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x06ca172d	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0be1aec5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0cc58896	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x14718517	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x19db9851	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1bd300d2	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x209f06f1	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x23710e1c	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x23be2f57	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2799bc36	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2b110724	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2be59ced	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2cd55081	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3aceeb11	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3ed15b95	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3ff965bc	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4933a59f	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4bbd3ff8	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4cb7fb3e	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4d862d7c	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x577b5ed5	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5c054f81	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x617dcc39	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6df4dec1	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6edcf11f	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6f6e9a7b	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x777c7737	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7c8f8d80	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x883673ee	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8a0d6b98	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8a8bcc4c	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8ab81dfb	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8f3d0d6b	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x90f44984	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9193752c	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x926ca39e	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x98be50a6	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9e59ca72	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa40d9efd	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa5663b8d	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb2599a82	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb894bfbf	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd0a5964c	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd3a03483	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd716dbf1	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd88369a5	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd9481456	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xeead52c6	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf3839acb	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf8dcad6b	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x05405bb9	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x6468798f	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x7d087d94	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xf95f7d83	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x9f4ad9c6	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x15adde2e	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x16208310	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1a8c63bf	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x209fbc28	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x25e59296	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3a44be6f	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4cb2ed89	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x62f35391	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6b0fdc84	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6d20a1d5	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7682c2a7	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x76fdc9e0	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7aefca50	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7d6b3c29	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7d832ec6	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x80aa2d4c	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8f41d1ad	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa1ae5eb6	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa50c7e0d	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xac828ae0	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xae95cbfd	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb7ab9213	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb91db840	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbb7a4fdb	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbfdd9afa	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc75f63fa	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcc252f46	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcccea8a5	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd39adb94	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdb81b884	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdfdc1076	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe5ce5c81	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xedafdcd5	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf93e2c91	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfd92e206	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xffb98ba8	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x4683da55	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x74e7de44	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x7e54bd8f	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xe8c43b06	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xeec2e840	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xfddfeb0b	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x26ea5ccc	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x31100d3b	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x328cfc60	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xad20720e	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xbda6e92d	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xbe1e7cc7	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xbe4b737f	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xcb170752	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xce16c76d	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xdf05f95f	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xf5301542	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xf9503e7b	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/raid_class 0x151b462b	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/raid_class 0x3f552b4c	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0x986396ad	raid_component_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x0cc49d6d	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x0d15dd7c	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x223b1257	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x4002c201	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x6f6cffa5	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x778bd3a1	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7d2900c3	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x85d77472	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xb7188e50	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xb7bb5406	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd6d6d0e8	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd992768b	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xe8fa196d	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x05b55671	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x0b24a9fa	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x11e1fb09	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x26e34ef3	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x30010248	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x39bf5bac	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x481b5498	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x497d9c0a	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x57fdf5e2	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x788da5ef	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7ab8b117	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9f29593f	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa30e0e12	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa33972e7	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xae27781e	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xae8f0ffd	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb18b0ab8	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb443e7a9	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xbe53bb85	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc8166d29	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xcf3e0a58	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd009d6c4	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xdc8ac73d	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe0506069	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe56224aa	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe5a4b806	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xef86e5d7	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf47b3ce3	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xffa2d2d6	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x0e11e012	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x624a75a8	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x62c5bbc5	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x809f84e1	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xcb0347dd	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x12e489b8	srp_rport_put
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x37acfbbe	srp_reconnect_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x5f5c74bf	srp_rport_get
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xe143976e	srp_start_tl_fail_timers
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x2fdbb2df	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x3839e3e8	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x67793c69	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x6ee534d0	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xa8b098eb	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xf83cf992	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xfb45d23a	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/soc/qcom/smd 0x6b8bb219	qcom_smd_driver_register
++EXPORT_SYMBOL drivers/soc/qcom/smd 0xeda44e54	qcom_smd_send
++EXPORT_SYMBOL drivers/soc/qcom/smd 0xef60b38a	qcom_smd_driver_unregister
++EXPORT_SYMBOL drivers/soc/qcom/smd-rpm 0x2f5501c0	qcom_rpm_smd_write
++EXPORT_SYMBOL drivers/soc/qcom/smem 0x5a710273	qcom_smem_get_free_space
++EXPORT_SYMBOL drivers/soc/qcom/smem 0x63ef36e3	qcom_smem_alloc
++EXPORT_SYMBOL drivers/soc/qcom/smem 0x932eb0e3	qcom_smem_get
++EXPORT_SYMBOL drivers/ssb/ssb 0x0ccc8874	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0x120af44b	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0x14907238	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0x1e568e55	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0x3601c39d	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0x3be030da	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0x5fee53a6	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x6283ebad	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x67b0da7d	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0x7ce35175	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0x913807c6	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0x9412761d	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0xa70b73f4	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0xaca35e36	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0xb6ea6253	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xdaac3159	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xdcbf5f30	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0xe0002cd7	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0xe1e6b26e	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xf8e93b68	ssb_clockspeed
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0aee6576	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0fd1690b	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1c7029f1	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1f1673a1	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x230410d6	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x35c1faad	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x38b49d6b	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x58738c86	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x5a5105d6	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x70961501	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x79792ad7	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x9e4e231a	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa6191690	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xb710f74d	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xc4e4ed28	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xca5349ed	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xd26df791	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xde3f8c5e	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe3ecff00	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe49617d4	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xeadc716a	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xede7298c	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xfceafee8	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xfd018f5a	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xb86b890e	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xd8e03c6e	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0xf084c792	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x183aabca	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x89e19161	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xd16c5e70	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xebde9eda	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x24f77508	ade7854_remove
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x2692755b	ade7854_probe
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0x6f790726	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0x4e3c9cb1	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x01eddd09	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x04f6041f	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0b9cd234	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x24e9146e	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2b299554	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2c517aef	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2d1878b4	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x384c53cc	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3a07669d	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3d237fc5	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x46e6a40f	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4c5d0892	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x51b4e9c4	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x56367f49	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5b5e0a91	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x659090d9	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6affc0c5	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6e3105f3	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6f6710eb	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7089292f	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x76f173fd	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x84a8325a	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x84f97e06	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8dbb6ee4	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9585b897	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x95a16990	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa329c494	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xad78cae2	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb0c0647c	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbd40aa71	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe5c94be	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc572183a	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcee30b64	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcf266e7d	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd1bf86b3	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd73626d0	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd81985eb	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd8d71bd7	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xda36802b	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdaa604b4	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdb6fafd8	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe002bcd9	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe4c642fc	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe67dfe1c	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf4cc878d	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf57995ff	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf5c8421c	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf803afa7	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf8ec8fb6	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfdcc7252	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x041ee992	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x10a7da1d	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x123cfc2d	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1581f7d6	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x19f61df2	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x29dc112e	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2c422b5a	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x37e93e85	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3a40c8a7	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3d951ddd	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x444b5599	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x481d7ae4	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4f0f5441	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x567a961d	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5bb6670a	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x61fb6a3d	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6532efea	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6dadd2f7	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x72c0cb6c	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x732500c2	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7af9c64f	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8762513c	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x96cdedd2	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9a1ec9ae	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9a9bc2af	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9dcc4ada	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa41f821c	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb1218b6c	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb37dd276	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb79fcdbc	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbb231c06	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbc179b74	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbcd488a3	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbda4685f	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbeb3d99c	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc3a89061	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcda44ee6	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xce152621	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcf4c2491	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd988447d	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdc49037d	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdd47203b	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdecf9842	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe30ca983	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe5464562	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe74e9f47	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe8c670ec	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xed9961ce	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xef096a16	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf088f9e7	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf17bc4bd	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf284bf31	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf3a8709b	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfa62ba1f	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xffeb6ed8	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x00532f52	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x055472f3	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0dae4681	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0ff796a3	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x2f064fe2	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x31aedcab	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3235ffbe	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3547666e	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x370a72cb	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3ceee932	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3ef034dd	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x482c1ee9	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x53ce1301	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x61ef57d0	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x648ca4d5	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x66daabe8	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x7c9b42d8	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x81972447	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x9f1fe01c	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa58a51fe	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xaf335d3b	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb139c977	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xbb700c2f	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xbd14bcf0	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc7f158db	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xce695376	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xfce46721	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xfdeffde2	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x043ba4f0	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x05cd0e3f	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x10e461a6	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x12972325	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1754c8a0	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1bc9c7f6	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0x20f8ca29	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2171c75f	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x21bdae09	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0x23c545f5	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0x241e614f	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0x27cd59f2	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2de12f91	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2e382108	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3174a5d4	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0x31b22073	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0x373110f7	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x39ed1138	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0x400a9eaa	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x404c79a3	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5404bd3d	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0x56a41228	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x57881f34	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x57e054b5	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5b9e6b18	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x604a0923	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0x66016074	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6c1be0a8	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x73583365	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8174a2c3	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x82671e63	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0x84cbab29	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x88b19802	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8e42ae74	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x923c0cdb	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x94b461b6	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9d74a5de	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9f0a908d	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa0b4f45b	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa602b766	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa9c8990a	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xaa2ef95c	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xad867e28	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb0a3fdcd	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb2f3d54a	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb3c8eea9	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb4027781	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbba00b2a	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc556492a	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc78c37cd	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcb5d381e	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcc136b6e	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd5c6f1ac	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd7270dc0	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd7277641	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd87eb229	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdae866f6	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdf6a2bae	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdff6f509	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe1a77b01	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe438c2e6	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe4cacbf8	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf0c4ac76	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf0d42416	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf2acaf73	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf567b742	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf5c24dd6	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf6517453	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf872bfa5	transport_init_session_tags
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0xee1500b1	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0x56f1e528	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0xde201828	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x020f63b2	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x2b24d85f	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x49c0db61	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x59618a7a	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x7150a84f	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x7f9190e0	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x8d197790	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xb2abfcdf	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xb48c2df8	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xc8259459	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xd913574d	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xf0670561	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x49a98da0	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x69a66b75	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x2e91ca97	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x367ce26a	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x59f824d9	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x7bda5e6d	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x821e9390	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x937e412c	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x38b49618	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x81f7c778	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x8be3cca0	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xab0b42fc	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x08cc2911	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x0a5e2db4	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x7321e5c5	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x96d04c47	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xa36f0633	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xc85b2e09	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xfc3fd803	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/syscopyarea 0x2f78fbe5	sys_copyarea
++EXPORT_SYMBOL drivers/video/fbdev/core/sysfillrect 0x71d37295	sys_fillrect
++EXPORT_SYMBOL drivers/video/fbdev/core/sysimgblt 0x6051f21e	sys_imageblit
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x6035ca1a	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0xde206d16	mac_find_mode
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x4ec00938	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0xa7221dc1	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0xc422a64d	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x125f1fbd	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x5f799362	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x7063bf78	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xb124764c	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0xb6764b65	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0x36444120	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x48df3370	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xb8af293b	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xbf383c8a	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xc5516ce4	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0x825fd3b4	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xc909e152	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x07a31650	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x41f7da7a	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x4c00d7eb	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x807dac6b	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xa610607f	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0xa66b01f4	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x1618bed3	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x25dd31bf	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x2c9dbd6f	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xf2ce9350	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x2406d401	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x9b547eb3	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x5e98963c	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x842f751c	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/wire 0x00708233	w1_register_family
++EXPORT_SYMBOL drivers/w1/wire 0x42f6bc1a	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0x94da4dc0	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xbe5637bb	w1_add_master_device
++EXPORT_SYMBOL fs/configfs/configfs 0x05ff8d88	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x1cadb62e	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x1e7b9a8a	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x2a702015	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0x30cc25d5	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0x34bea5d1	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x428804c1	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x4fdf250d	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0x68e68da0	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0x693134d1	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0x74958d33	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0xd2a7f61a	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0xe4132d8f	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xf5cdb856	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0xfede5146	configfs_unregister_default_group
++EXPORT_SYMBOL fs/exofs/libore 0x01386c00	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0x079e28b9	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0x14e58ff5	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x3cb01434	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x4da98c24	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0xa20061f8	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xa8c5ec22	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0xb59dd021	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0xb8b5cf70	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0xbb08fc46	ore_read
++EXPORT_SYMBOL fs/fscache/fscache 0x0347c993	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x05ae7775	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x086d1a1a	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x093e1f05	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0x10163241	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x12a6d75e	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x248c5365	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0x24f7f6be	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x25631afd	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x377c8c47	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x39f8ceff	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0x3fffb606	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0x4250308c	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0x456f6aaf	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x480855e3	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x4e402319	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x545e39b9	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0x54886285	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x6b08d316	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x71dcf11b	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0x71df2f9b	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x7905623f	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x7b2e54e8	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0x7b520f8d	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x808a5ccd	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x88819c7d	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x9c099405	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0xab3ee03f	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xb86cc703	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0xbaa3f49b	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0xc463d75b	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xc4abeeec	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0xc8a3ba0e	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0xcc3c6161	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xe91cdb47	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xf03681af	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xf60e164b	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0xfdcc9865	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0xffce5fde	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0xffea9cde	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x1b708e28	qtree_read_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x305ab4c1	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0x3dbdc8c5	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xc1ab07b1	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xcbc7ef53	qtree_write_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x3771b461	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc-itu-t 0xf5b4a948	crc_itu_t
++EXPORT_SYMBOL lib/crc7 0x66213969	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0x41248eaf	crc8
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x03f599c7	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0x22ee90d9	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x4feade4b	lc_create
++EXPORT_SYMBOL lib/lru_cache 0x56fc3ea0	lc_put
++EXPORT_SYMBOL lib/lru_cache 0x619ed575	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x84e0214b	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0xb673970e	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0xbbe7c23c	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0xc48fa976	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xc6e4cd46	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0xcb990a55	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcea6747e	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0xd212c9f0	lc_get
++EXPORT_SYMBOL lib/lru_cache 0xeb13128b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0xf460a486	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0xf5ea5f5c	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0xf6acec20	lc_find
++EXPORT_SYMBOL lib/lz4/lz4_compress 0xcbc5d521	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x26c3aa22	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x47b757a2	lowpan_nhc_add
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x82acb7be	lowpan_netdev_setup
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x916f9125	lowpan_nhc_del
++EXPORT_SYMBOL net/802/p8022 0xd06f9f28	register_8022_client
++EXPORT_SYMBOL net/802/p8022 0xeafd816e	unregister_8022_client
++EXPORT_SYMBOL net/802/p8023 0x1c4a33f3	make_8023_client
++EXPORT_SYMBOL net/802/p8023 0x8739cdf9	destroy_8023_client
++EXPORT_SYMBOL net/802/psnap 0x0906b9bb	unregister_snap_client
++EXPORT_SYMBOL net/802/psnap 0x813ae009	register_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x055ca679	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0x0d8ed6f6	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0x18d076cd	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0x1a37c7e9	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x29cbf4bd	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x2b446276	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0x30e3d642	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x35a82660	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x375fbdfc	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x3a6cac4a	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x3d3747a5	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x407cf23f	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0x4435bb40	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0x44b919bf	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x45946329	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0x52a2b953	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0x53307357	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0x533a7da3	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x5fe65717	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x62400f0d	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x6e7b78d0	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0x737a251c	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0x7cdbb1b2	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x7f495da2	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0x8dde8d7d	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0x8fad9a5b	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0x8fc9109b	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x999ee01c	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0x9ce58e4f	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x9dc5993c	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0xa800bee0	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xaa4b4192	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0xafe40697	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xb43a917a	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0xb5b5d2a1	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0xb83e3ba0	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xb877a86a	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0xbdef93e1	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xd2b50920	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0xd605f6ef	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0xde54e2dc	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfa50b4da	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x4784c80e	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0x9736a8df	aarp_send_ddp
++EXPORT_SYMBOL net/appletalk/appletalk 0xef5c84e2	atrtr_get_dev
++EXPORT_SYMBOL net/appletalk/appletalk 0xfa890169	alloc_ltalkdev
++EXPORT_SYMBOL net/atm/atm 0x04f5e98a	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0x1d592aed	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x1e721e99	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x2ec1cdbf	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x6f716014	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x88274872	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0x8daa3356	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0x93fe73fb	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0x95072a21	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x9e85f3db	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xa8300ad7	atm_charge
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xca15e3c2	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xe10d8865	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0xf1774b53	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x3b76aebd	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x503368a4	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x7829156e	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0x89291213	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xb3211ba2	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xde699d11	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0xeb63ee44	ax25_ip_xmit
++EXPORT_SYMBOL net/ax25/ax25 0xeb865cdb	ax25_send_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x003191e7	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x041a4dc5	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x06784174	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0c9ec97b	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0e514423	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0fb0e6cd	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0fd71703	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2773d24e	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2a242e9b	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2b28d64d	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3055781d	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3d07f04a	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x52fe6365	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x624514ff	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x67b5dbb4	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6cb97509	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7e6f0012	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x88462725	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9b23f14a	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9d0f507e	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa2efdd94	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0614619	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb1153fbf	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb60574b7	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbaf81e41	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbc0ee21d	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc142958f	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc1946344	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc87aeeee	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc897263e	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc94a9b6f	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcfbebd90	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd1f2a35d	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xdbdfff8c	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xdc304a40	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe0fe1341	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xefd0802c	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf7b7a917	bt_sock_wait_ready
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xfc94cc1c	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xfcf14869	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xfea2739f	bt_sock_wait_state
++EXPORT_SYMBOL net/bridge/bridge 0x47262f14	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x6fe8ed1b	ebt_do_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xc5d6fa90	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xe2fb03a6	ebt_register_table
++EXPORT_SYMBOL net/caif/caif 0x04d5a824	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x95cee590	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xb05a56c8	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xce35a4f8	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0xf9cff536	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/can/can 0x37bea197	can_proto_unregister
++EXPORT_SYMBOL net/can/can 0x3f380841	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0x425e63e7	can_proto_register
++EXPORT_SYMBOL net/can/can 0x60919fcd	can_ioctl
++EXPORT_SYMBOL net/can/can 0x83076f38	can_send
++EXPORT_SYMBOL net/can/can 0xae44940d	can_rx_register
++EXPORT_SYMBOL net/ceph/libceph 0x00a5d9b1	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x0281b4fe	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x072f3087	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0bc510c9	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0x0d6113e0	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x0fa5eda7	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x18077a3d	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0x1af9dc5b	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x1f558184	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x20b126d2	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x21a83e30	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x2c9d1c24	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x31a69789	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0x34731276	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x35366279	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x38279a96	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0x39c78c66	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x39cb0c19	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3d0dd31c	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x416cb29e	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x41704f93	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x43caf840	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x478700b9	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0x47a9920e	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x49a0442d	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x4b504810	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x4c33f64b	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0x4d9a62f1	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x531286aa	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x569ba3c5	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x5b23fac6	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x60fe37db	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0x61643c2b	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x67f06737	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0x68ef6a32	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x6a5463ef	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6bd4fbfc	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0x73fab509	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x75cbb1ee	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x75e544cb	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0x799cf782	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0x82b4294f	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0x8814ccd2	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0x8872dc00	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x8d096c2d	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x8d34f552	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0x8d85df49	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0x915e47f0	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9b622c42	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x9b998a22	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x9d8d26f7	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0x9f43facb	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0x9f5ecbed	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0xa1ebde8f	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0xa6a9a4f1	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0xa9f25a84	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xaa9b73ff	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafacffe7	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb19dc152	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xb4947fe3	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6039791	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb727973b	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0xbc1dedfa	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0xbdf68690	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xbe1c1706	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0xbec523c0	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0xc092a353	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xc24c4c59	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xc41438f7	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xcc01d384	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xcc55c820	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0xcd29b118	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0xcddb4d9b	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd5383217	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xd813625e	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xdad44647	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0xdb9477cb	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0xdd4793b6	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0xde0eb6ba	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xe170013c	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0xe3ea89bb	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0xe55d9bcd	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0xeacb10df	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0xeb36a695	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0xeee16dec	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xf3c54412	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0xf477d116	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xff34c2c5	ceph_alloc_page_vector
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x82f55be5	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0xee0987ea	dccp_req_err
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x2676a958	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x29fd1b31	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x56cd6f44	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x6eba1238	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x999349a3	wpan_phy_new
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xb01bbe4c	wpan_phy_find
++EXPORT_SYMBOL net/ipv4/fou 0x057a5b13	gue_build_header
++EXPORT_SYMBOL net/ipv4/fou 0x0c07b4a3	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0x8319e9b0	fou_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xed741d6f	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x1ba3de5c	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x2d0d3e87	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x94dcca57	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xb08f23ec	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xe6de4d3b	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xed9f10f6	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x56a8c625	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xbee2a77e	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xd3cc573f	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x233d47c3	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x6208b4cd	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x6ca4daf1	ipt_do_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x339b2fbe	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/tunnel4 0x47654a50	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0x0964ae38	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x0c1e15b0	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x53942a6b	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x5829134f	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xf863fb7f	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x5751acf2	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x9526b6f6	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xf6ae4362	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x2b67bffe	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/tunnel6 0x5ca714f8	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x140b36e1	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x7a249463	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x2a0f170a	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x2f7f5337	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x43856446	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x6f7431ba	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x703d652f	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x916dbbd4	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xa859fee3	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xcec2c8ef	ircomm_connect_request
++EXPORT_SYMBOL net/irda/irda 0x0004ca00	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x17a491c5	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0x1ad09295	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0x25e138c6	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x2aa3b4ea	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0x2c4bd36b	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x36cad55b	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0x37791344	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0x432ef77c	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x48560905	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x5bbade9e	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x6492e28c	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6b76aa70	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0x6e83d591	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x731cec71	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7e67ca6e	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x8982c8d9	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x8a44dd5e	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0x90ddb6bd	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x9240cec1	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x97703750	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x9c1ddc5d	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0x9ffda243	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0xa599dab4	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0xaf6cdd3f	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xb3c13d7f	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbca106b3	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xbf7dd554	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xbfa7c08d	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0xc477368d	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0xcab4f7b9	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0xccc16d6e	iriap_open
++EXPORT_SYMBOL net/irda/irda 0xce9f5a43	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0xcf479c73	iriap_close
++EXPORT_SYMBOL net/irda/irda 0xd6936448	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0xd946356e	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xda15dcc3	irlap_close
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe7c7dd3a	irlap_open
++EXPORT_SYMBOL net/irda/irda 0xe85d365d	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0xe8b37c58	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xf199cba4	irias_insert_object
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x27faeaa5	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0x93d28364	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x0b8e62f3	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0x0c7fb1e4	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0x1549076f	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0x581eb052	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0x82944c84	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0x94e94e47	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0xc73edf5a	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0xe3aea6bf	lapb_register
++EXPORT_SYMBOL net/llc/llc 0x112204b4	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x475128e3	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x5a3bc99d	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0xb04b262d	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0xb47ffe83	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0xbfebe7b8	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0xcc6a1c10	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/mac80211/mac80211 0x02166686	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x0fac5394	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x165280e7	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x1692bce3	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0x16ea7fc6	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x1b1dba57	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x20794943	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0x23605fef	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x28331126	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x29ef4249	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x2e264680	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x30f27908	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0x31df9944	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x361bdd2d	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x36fabdd8	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0x3738d8ef	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x393c7317	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0x3cc12398	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x3f254ea1	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0x43169924	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x44772eb3	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x51eaf728	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x57b25cc8	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x5cea9b1e	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x5e6e0256	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac80211/mac80211 0x5efcb424	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0x61788bc3	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x6192bd1a	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x65fe5f77	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0x69de096c	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0x6a6f2f21	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0x6ce8f959	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x6d7a74eb	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x72009e6a	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x738fcacd	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x76b9ef28	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x7a45cea4	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x7f63a3f7	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0x8069d63c	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x8430cd4b	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x85d589ab	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x8bbe4050	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x8bd52b67	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x9574a745	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0x9b28c06c	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x9c068326	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0x9dd5d591	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x9e3ee521	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x9e8c6475	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xa4365677	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0xa453fa6a	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xa45c4e8e	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xa98b92f1	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0xa9dbf05c	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0xabb34546	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0xac2709f9	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0xb1aaef91	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xb37174c0	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0xb37fa148	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0xb469eb82	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0xb862395e	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xbd046ace	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xbf4952ae	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0xc0150d1d	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xc479a106	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xc88d30a9	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0xd0dd8b8a	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0xd5d8f4ec	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xd830ec8c	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xdbe707ac	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0xe4e95f20	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xec541efe	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xef0408a8	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0xf02c143a	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xf2bf216b	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xf3da1f6c	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0xf6634f0c	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xf74fef91	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xfd13e017	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xfe43f46f	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac80211/mac80211 0xfed1869d	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xfeed3dca	ieee80211_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x099ea108	ieee802154_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x10736679	ieee802154_unregister_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x449a2dc5	ieee802154_register_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x673b8fa3	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0x6b642e39	ieee802154_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x6f848224	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0xdf1f86df	ieee802154_xmit_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0xe948f72c	ieee802154_alloc_hw
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x13da0c02	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x17e690e7	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x368669e5	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x4e073688	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x60d1eded	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x7895941e	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x95a1f551	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x9a1a0599	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xa4bca752	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb398748f	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xbbf17719	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xc38bc0ee	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xf35dd131	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xf675bd96	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x4cd2ec76	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x724973e5	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x90625478	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x4f34a759	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/nf_nat 0x5a7a1c23	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x603d5e6c	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x94dec02d	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0xc63f892c	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0xd768616f	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x16ea6dc7	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x4078b8c5	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x4b64526c	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x5f887eff	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x72464735	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xa9d1dda8	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xb4716354	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xd24d383f	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xf57d07ad	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xf5b561d3	xt_unregister_match
++EXPORT_SYMBOL net/nfc/hci/hci 0x0322ba73	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0x1a8b070a	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0x20fd912f	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x264095ff	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x3ba1afa1	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x40534fe1	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x42b88ddb	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x48116917	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0x7edf4944	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/hci/hci 0x830c42b1	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x91cb7286	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0xa33c9d1c	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0xbbe2c2e5	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xc1abf73c	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0xcbe9229c	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0xd0d92c7c	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xe1461c02	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0xe151f2d0	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xef0b4a06	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xf193c704	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0xf4b9591f	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x09ad255d	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0x0b95f36d	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x11b440f4	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0x1af8324f	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x2e159fba	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x2ec065c8	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x30558594	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0x40a5dc4c	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x415e40b4	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x483dccd3	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x677dbc91	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0x6eff3ed9	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0x9272e604	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x96e678f6	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x9806d892	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x9deabe55	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x9f238204	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0xaa1c08fd	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xb0d63cb4	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xc0671e8c	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xc11d1a99	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0xc2028c61	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0xcde82906	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0xd0ee5038	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0xdde88159	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0xe2d72040	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0xe4163f0b	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0xfdd68350	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nfc 0x09ebe29d	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0x11955cbc	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0x1657f5e5	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0x2b2a1b63	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0x300bc3e2	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0x3df4edc5	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0x3f682aaa	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0x47388a31	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x4834de19	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0x5f519eb1	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0x686e9eae	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0x7485dc78	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x769061e2	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0x78ca9ec7	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0x9ecb1952	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0xa618bdd1	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0xb60e6a07	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0xc5e6ca35	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc 0xd57212ac	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0xda3fb517	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xdc5cf522	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0xea8f7c0b	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0xee6b9e52	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0xfd23157a	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc_digital 0x3cb4e6b0	nfc_digital_register_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x72571f18	nfc_digital_allocate_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xe76a73fb	nfc_digital_unregister_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xf288e2e8	nfc_digital_free_device
++EXPORT_SYMBOL net/phonet/phonet 0x0be8f34e	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0x1900be39	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0x20fa8ee3	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0x49cca74e	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0x57c75df9	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0xa43f6997	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0xb52de437	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0xd5128a58	phonet_header_ops
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x06e46571	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x06f8e617	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x383c23c9	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x4b373110	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x565eb21b	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x5a49eba4	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x742d00cf	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x7b9c15e8	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8882ead2	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8c4bc8ee	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x99c9a928	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xc4a7939c	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe627f7f6	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xea5e4157	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf0e835d9	key_type_rxrpc
++EXPORT_SYMBOL net/sctp/sctp 0x1acd03b1	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x07aa2bfe	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xc5d3689a	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xd2e245da	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x03488738	svc_pool_stats_open
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x3478777e	xdr_truncate_encode
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x7abe5dae	xdr_restrict_buflen
++EXPORT_SYMBOL net/wimax/wimax 0x015b33f8	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0x93da446f	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x0200bdb0	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x08191563	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x08e6b220	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0a38660a	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x0c404a89	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x10f92da6	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x14bcb052	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0x15120103	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x1a6f4e94	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x1c52cad3	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0x21fff31c	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x22c87551	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x23e14a49	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x2636dc50	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x26ed7f34	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x2bdc314c	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x2d18dfb8	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0x2d5aed80	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x319af015	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0x3af7c677	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0x3b435bb1	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3daf8f66	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x3f5da723	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x42291517	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0x43aa9f08	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x441657aa	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x468c49e9	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x491bc520	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x5ec5a01e	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x61258041	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x61f32ad1	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6a3f0ecc	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0x6b1eeccb	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x6c404946	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x6c83a091	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x6da934b4	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x80d858b8	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0x8408738d	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x8512e4c8	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x89093c9d	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x8ac9a636	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x8ba831c8	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x907b5db9	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0x923ce32c	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x9325c3df	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x9474b1c2	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0x966ff54d	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x96978e4f	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x985f7416	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0x9c5412fe	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x9cbfdb43	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa2dac44e	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0xa8d7d7f5	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0xaeac2494	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0xb13835ec	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0xb2169f02	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0xb9c00976	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0xbc478a77	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0xbdeff2af	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xc01c285a	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xca9b6f05	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0xcd067995	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0xcd29b758	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xcdd039d9	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xdc624fcc	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0xdf8bb0ab	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xe078216e	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xe1a61ca1	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0xe1e2c5a8	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0xe3cc8a7e	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe46790f7	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe6a583f0	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xea89defd	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0xeb38d2ed	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0xeb6d7c6c	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xedbd19b6	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/cfg80211 0xee096893	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xef8ddc24	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xf5189672	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0xf58679c5	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0xf5fbba6f	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0xf682ca2f	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xf763ddbf	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xfd4843c5	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/lib80211 0x48d977b1	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x691b7fe5	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x760a44fc	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0x7617d7f3	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x7d98e108	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0xb4c57bf2	lib80211_crypt_info_free
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0xe63d1870	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x09b18dbe	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1f2fd4e5	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x25b3947a	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x55f5fbad	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x9e3d824e	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x127b30fb	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x1cdc0812	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x59eb74ae	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x8102ed2f	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xb11ba32d	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xb2c7f684	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xea0e5748	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xed42580b	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0x5d00a803	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd-hwdep 0x81867e51	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x085cc5fb	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x185639a6	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x1a0d3127	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x30c3748c	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x32725f40	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x3af630e6	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x6e7cb107	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x725393d1	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7286afcd	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x73837f9f	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x89520e1c	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x915856b3	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x9f27c123	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb6f5b238	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xbbbe6fd5	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xbe872fba	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xc15c730a	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd1abd68d	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xea3d1dad	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x624bea4a	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x09177441	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x0d9626da	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x229b7436	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x2b79703c	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x34928891	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x52d0679f	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x549a6578	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x7517feb2	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xf8d3a56d	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x02baf1c6	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x3f83aae9	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x52670dcc	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x714c831a	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x72070534	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x8ad70471	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x95fe5218	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xc67763f3	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xd92ceabc	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1991870d	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1b4b83a0	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x2ece502d	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x386c0e3d	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3f689d6b	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x410e28e1	amdtp_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4ece2401	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x51d44e96	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53751a27	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x59572be6	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x63651f73	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x6af3588a	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x718fad31	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7caccb10	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x81e54492	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x85a343ca	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8d810c23	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x906db1cf	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x94b349fd	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9da9f11f	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9f701fd5	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa69de865	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xab3eef17	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xacc49fd4	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc636a42e	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc7bb0d22	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xcbd902ca	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xcd243cfe	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe229caf9	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe79f760e	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf7cddc3a	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf8d6f3ff	fw_iso_resources_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x2e2be60a	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0xacc05d4f	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x370932d3	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x812ef63e	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xa13593f9	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xa768f863	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xb3dd3a49	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xda8cdb83	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xde0cc3f2	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xf287da0c	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x30f6974c	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x3d6319bb	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x866736c6	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xd7071a61	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x47be92d2	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0xa68577dd	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x2144292f	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x490c17ef	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x8eb0b585	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xb48da292	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xc5efb968	snd_cs8427_init
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xe8147d18	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x19aaf768	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x230ab8ac	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x34b8dbc0	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x3bad3f9e	snd_i2c_device_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x9733a981	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xec5d117f	snd_i2c_readbytes
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x25397fa2	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3c375ea1	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x491fce53	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x51b18cc0	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5935365b	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x7d52f19b	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x874c7f1d	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x9bb8eddd	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x9f980765	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xa241fa76	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xa8f0081b	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xc073f3f1	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xd09271b8	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xd5f46ac2	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xdca58af7	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xe259f03e	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xf5e786a1	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x0e48a6e8	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x1e4be959	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x398cbc5e	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x48eda683	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x545fd99a	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x613f6b87	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x7bf9d917	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xcf352cae	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xddba1152	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x3bb33d1f	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x5656f21f	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xf3a0b6a5	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x03a6a02f	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x08df4e3d	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0f7b5b4c	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x159ff3bb	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x1f0f05a6	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x2656eac2	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x2eb9262a	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x33321a10	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x3d55358b	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x421a72b4	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x48af1d1d	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x4b0af003	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x58667e49	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x6ffececb	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x7abdfe22	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x9025aae1	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa17c1237	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xacec84e6	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb4029af1	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xbbdda46a	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xdf111df9	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x88b627ca	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x8fd96b24	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xa77557e1	snd_trident_free_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xd37a9eb0	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xd8ea92ef	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x2c2c6ca8	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0xee99e5be	tlv320aic23_probe
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x1b50f931	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x53e56f7d	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x8ea75246	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xa85591cb	snd_emux_register
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xf796778f	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xff4427d6	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x00df2f56	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x157a2487	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x44787729	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x7b9c2a34	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x859edcff	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xa82e93c5	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xbcb8a4fb	__snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xc1a8f72d	snd_util_memhdr_free
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x02cc8b3e	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL vmlinux 0x00148097	bio_endio
++EXPORT_SYMBOL vmlinux 0x001ecd11	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0x002989f4	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0x002af2ee	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0x003ada97	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x005a2f1a	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x005e5ab4	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x00634729	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x00696c7f	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0x008584b2	of_find_property
++EXPORT_SYMBOL vmlinux 0x0089d4b1	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x008eb47e	sk_dst_check
++EXPORT_SYMBOL vmlinux 0x009d84fb	mount_ns
++EXPORT_SYMBOL vmlinux 0x009e2567	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x00ce497c	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x00f06d13	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0x00fa7e0a	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x01139ffc	max_mapnr
++EXPORT_SYMBOL vmlinux 0x011a9e53	elf_hwcap2
++EXPORT_SYMBOL vmlinux 0x013e0a75	of_get_min_tck
++EXPORT_SYMBOL vmlinux 0x01670977	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x016ff440	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0x017d3890	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0x017d922b	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x0186e2de	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x01a3d310	omap_set_dma_channel_mode
++EXPORT_SYMBOL vmlinux 0x01ac60fd	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0x01b604f9	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x01b7fd59	dispc_read_irqstatus
++EXPORT_SYMBOL vmlinux 0x01d0286c	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x01d1d07d	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x01dad93d	nand_unlock
++EXPORT_SYMBOL vmlinux 0x01e31149	dquot_drop
++EXPORT_SYMBOL vmlinux 0x01ea132e	dispc_runtime_put
++EXPORT_SYMBOL vmlinux 0x01eebf2f	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x02196324	__aeabi_idiv
++EXPORT_SYMBOL vmlinux 0x022667d8	of_platform_bus_probe
++EXPORT_SYMBOL vmlinux 0x023eb724	security_path_mknod
++EXPORT_SYMBOL vmlinux 0x024f3cb8	fb_set_var
++EXPORT_SYMBOL vmlinux 0x02573b36	omap_disable_dma_irq
++EXPORT_SYMBOL vmlinux 0x02627eb3	of_gpio_simple_xlate
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x027920a1	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0x0280e683	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL vmlinux 0x02883a30	pci_request_region
++EXPORT_SYMBOL vmlinux 0x02a0c18a	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x02ee26c1	free_pages_exact
++EXPORT_SYMBOL vmlinux 0x02ef742b	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x02fbe43f	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0x03005606	omapdss_get_version
++EXPORT_SYMBOL vmlinux 0x03013ded	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x03026722	mempool_alloc
++EXPORT_SYMBOL vmlinux 0x0316fdaa	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x033199db	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x0334795d	icst307_s2div
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x03362637	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x03547c5f	audit_log_start
++EXPORT_SYMBOL vmlinux 0x035818c7	security_path_symlink
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x036819ca	of_phy_find_device
++EXPORT_SYMBOL vmlinux 0x036e28c5	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x03709c21	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x0385c8e2	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x03900728	snd_timer_global_new
++EXPORT_SYMBOL vmlinux 0x03937301	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0x03a8a092	iunique
++EXPORT_SYMBOL vmlinux 0x03a8a482	elevator_change
++EXPORT_SYMBOL vmlinux 0x03ba39b0	v7_flush_user_cache_all
++EXPORT_SYMBOL vmlinux 0x03ea27fe	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x03f99288	skb_split
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x0412f5c7	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x0415c2ca	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0x04190126	netdev_crit
++EXPORT_SYMBOL vmlinux 0x041d1dc6	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x0435d572	amba_find_device
++EXPORT_SYMBOL vmlinux 0x043adeaa	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x046cfde5	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x0488bcc3	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0x048d1b9f	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0x04a1a942	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0x04a6adc5	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0x04afd4fb	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x04c451a4	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL vmlinux 0x04d567e9	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x04d99cc7	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x04e037f2	mmc_start_req
++EXPORT_SYMBOL vmlinux 0x04e56db9	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04ec64b7	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0x04ee4c61	snd_pcm_set_sync
++EXPORT_SYMBOL vmlinux 0x04f9a5c6	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0x05004223	unload_nls
++EXPORT_SYMBOL vmlinux 0x051a3e06	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x0529fe55	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x053123e5	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x054b7798	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0x055c5ddf	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0x055dcaa2	of_device_unregister
++EXPORT_SYMBOL vmlinux 0x0569d369	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0x057f6c6b	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0x05a19f0c	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0x05a28065	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x05b1d3e5	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x05f1ef3f	__scm_send
++EXPORT_SYMBOL vmlinux 0x05f566e7	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x05f8791d	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x0629f6dd	md_register_thread
++EXPORT_SYMBOL vmlinux 0x062ce5b8	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x0639347e	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0x0649094a	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x064ef694	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0x065f2374	omapdss_default_get_resolution
++EXPORT_SYMBOL vmlinux 0x06607f92	dss_feat_get_supported_outputs
++EXPORT_SYMBOL vmlinux 0x067beec6	seq_printf
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x069d862f	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0x069dccb2	of_mdio_parse_addr
++EXPORT_SYMBOL vmlinux 0x069e7404	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL vmlinux 0x06ab6667	input_register_handler
++EXPORT_SYMBOL vmlinux 0x06e88eb9	iterate_mounts
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x0700e334	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0x0701f2ac	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x0708acfa	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x072fcdce	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL vmlinux 0x073ff079	of_graph_get_port_by_id
++EXPORT_SYMBOL vmlinux 0x076b2dc3	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0x07759bc9	kmap_high
++EXPORT_SYMBOL vmlinux 0x0783162b	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0x07a4b576	flex_array_free
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07c9eea3	netdev_update_features
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07cf9099	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0x0800e9d6	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0x08023c4b	md_error
++EXPORT_SYMBOL vmlinux 0x08029de1	scmd_printk
++EXPORT_SYMBOL vmlinux 0x0802f3a7	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x081f3afb	complete_all
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x082f8221	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x084983e6	ps2_drain
++EXPORT_SYMBOL vmlinux 0x085470a6	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0x085e4715	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x088a26b6	devm_memunmap
++EXPORT_SYMBOL vmlinux 0x08ad6c7d	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0x08ae047c	omapdss_output_unset_device
++EXPORT_SYMBOL vmlinux 0x08d8b6cc	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x08fcf3a1	d_splice_alias
++EXPORT_SYMBOL vmlinux 0x09018cc9	lock_fb_info
++EXPORT_SYMBOL vmlinux 0x0933a2ee	snd_timer_pause
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x0960be97	of_n_addr_cells
++EXPORT_SYMBOL vmlinux 0x09729c41	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0x097ec1ff	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x0982551c	nla_put
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x09c0a74f	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09cf1b46	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09df7c6d	d_path
++EXPORT_SYMBOL vmlinux 0x09fc8091	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0x0a0786de	udplite_table
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a3131f6	strnchr
++EXPORT_SYMBOL vmlinux 0x0a33f164	passthru_features_check
++EXPORT_SYMBOL vmlinux 0x0a373226	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0x0a469d23	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0x0a6b4036	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x0a7596b5	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0x0a7b8423	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0x0a7bbefd	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0ac08b33	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x0ac32dcc	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0ad7c0ce	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0x0adb2285	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0x0b0080d8	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b2d425c	of_node_put
++EXPORT_SYMBOL vmlinux 0x0b48677a	__kfifo_init
++EXPORT_SYMBOL vmlinux 0x0b5efe3c	save_mount_options
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0ba92431	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0x0bad26c4	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bc5b27f	snd_ctl_add
++EXPORT_SYMBOL vmlinux 0x0bcfc771	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x0bdb02a5	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0x0c14d3d5	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x0c38cd41	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x0c38f861	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x0c3e81b7	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c549551	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0x0c58130f	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c594bf7	write_cache_pages
++EXPORT_SYMBOL vmlinux 0x0c85fd58	nd_device_register
++EXPORT_SYMBOL vmlinux 0x0c884c55	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0ca54fee	_test_and_set_bit
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0ce1ec47	xattr_full_name
++EXPORT_SYMBOL vmlinux 0x0ce78030	dump_emit
++EXPORT_SYMBOL vmlinux 0x0cf19975	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x0cf85302	netdev_state_change
++EXPORT_SYMBOL vmlinux 0x0cfefe1e	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x0d1d824b	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x0d3f57a2	_find_next_bit_le
++EXPORT_SYMBOL vmlinux 0x0d4d7a32	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d5636de	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d7797c2	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL vmlinux 0x0d85c0f8	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x0d87d3ee	d_rehash
++EXPORT_SYMBOL vmlinux 0x0d98e829	may_umount
++EXPORT_SYMBOL vmlinux 0x0d9f617b	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0db9f160	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x0dc1a78c	bin2hex
++EXPORT_SYMBOL vmlinux 0x0df49381	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x0df545f7	dst_discard_out
++EXPORT_SYMBOL vmlinux 0x0dfdd052	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x0e05bf12	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x0e073542	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x0e0a3e8c	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e7566a1	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0x0e778918	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x0ea5743b	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0x0ea60522	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x0eaf451e	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x0ec590ef	__inet_hash
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0eea0399	strscpy
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f097c5e	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x0f36b3b3	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f4f91a5	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0x0f5a5c8b	of_graph_get_remote_port
++EXPORT_SYMBOL vmlinux 0x0f5fc9fb	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x0f666961	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x0f667836	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f7e3b0e	try_module_get
++EXPORT_SYMBOL vmlinux 0x0f848910	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x0fa2a45e	__memzero
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb13362	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fbf369d	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x0fd55ad2	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0x0fdf485e	nand_scan_tail
++EXPORT_SYMBOL vmlinux 0x0ff178f6	__aeabi_idivmod
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x101d648f	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0x10418c28	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x1069c035	of_find_backlight_by_node
++EXPORT_SYMBOL vmlinux 0x106c2615	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0x106f13ab	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x1072a394	csum_partial_copy_from_user
++EXPORT_SYMBOL vmlinux 0x1075fa06	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x109c97b6	generic_file_open
++EXPORT_SYMBOL vmlinux 0x10a128e9	snd_pcm_period_elapsed
++EXPORT_SYMBOL vmlinux 0x10ae62e6	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0x10b66907	backlight_device_register
++EXPORT_SYMBOL vmlinux 0x10e83136	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x110647a3	generic_permission
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x11145431	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0x1146ba7d	neigh_destroy
++EXPORT_SYMBOL vmlinux 0x11599a1d	account_page_redirty
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x116e57b5	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x1176bd7f	file_update_time
++EXPORT_SYMBOL vmlinux 0x1188cfdb	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0x119b50e7	elf_check_arch
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11bdb55b	dmam_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x11e73286	snd_pcm_lib_readv
++EXPORT_SYMBOL vmlinux 0x11edfc52	of_parse_phandle_with_args
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x121b4e4b	memremap
++EXPORT_SYMBOL vmlinux 0x12352666	complete_request_key
++EXPORT_SYMBOL vmlinux 0x12366901	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x125af295	d_invalidate
++EXPORT_SYMBOL vmlinux 0x1298459d	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x1299449c	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12c7176d	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0x12da5bb2	__kmalloc
++EXPORT_SYMBOL vmlinux 0x12e32277	path_nosuid
++EXPORT_SYMBOL vmlinux 0x12fc7188	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x13016cd6	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x131387c5	install_exec_creds
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x132306ec	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x13315729	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0x1339951a	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0x13606413	vmap
++EXPORT_SYMBOL vmlinux 0x1364d55f	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0x137269a5	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0x13764cf6	set_user_nice
++EXPORT_SYMBOL vmlinux 0x13a4958f	cros_ec_cmd_xfer
++EXPORT_SYMBOL vmlinux 0x13b74c0a	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x13bf3abe	dquot_operations
++EXPORT_SYMBOL vmlinux 0x13cd58e0	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13da54b5	of_phy_attach
++EXPORT_SYMBOL vmlinux 0x13ef6467	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x14138aa3	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x1420b379	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0x143023b6	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x1441cc2b	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x149526e5	fsync_bdev
++EXPORT_SYMBOL vmlinux 0x14a41e88	of_root
++EXPORT_SYMBOL vmlinux 0x14c9a70e	empty_aops
++EXPORT_SYMBOL vmlinux 0x14cbc4da	genphy_suspend
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x14d0fc39	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x14d4a9c5	_change_bit
++EXPORT_SYMBOL vmlinux 0x14dc3c40	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0x14f3fa0a	of_find_node_with_property
++EXPORT_SYMBOL vmlinux 0x1527d284	follow_down_one
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x157bd58f	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0x15820916	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x1592e542	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0x1598f608	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0x15a51cef	omap_dss_find_output_by_port_node
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x16040a2d	md_done_sync
++EXPORT_SYMBOL vmlinux 0x160e975f	freeze_super
++EXPORT_SYMBOL vmlinux 0x1612bbb1	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x16174643	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0x162ccc0c	lg_local_lock
++EXPORT_SYMBOL vmlinux 0x16305289	warn_slowpath_null
++EXPORT_SYMBOL vmlinux 0x163259d9	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0x164789b0	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0x165cd738	cpu_tlb
++EXPORT_SYMBOL vmlinux 0x16766435	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x1683a50b	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x16856f54	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0x168cf911	nla_reserve
++EXPORT_SYMBOL vmlinux 0x16a860bc	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0x16b8fac9	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x16bdd7b3	snd_dma_alloc_pages
++EXPORT_SYMBOL vmlinux 0x16d2dfec	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0x16da83a1	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x16f62448	datagram_poll
++EXPORT_SYMBOL vmlinux 0x1700fd03	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0x17268b18	vfs_create
++EXPORT_SYMBOL vmlinux 0x173b207d	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0x174ba930	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0x1750a3a0	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0x17615297	dss_mgr_start_update
++EXPORT_SYMBOL vmlinux 0x17775c50	make_kgid
++EXPORT_SYMBOL vmlinux 0x177a6543	invalidate_partition
++EXPORT_SYMBOL vmlinux 0x1782e099	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0x1784f057	dispc_ovl_set_fifo_threshold
++EXPORT_SYMBOL vmlinux 0x17894404	inet_getname
++EXPORT_SYMBOL vmlinux 0x17a1eaa1	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0x17aa0b2c	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17cb7b36	dev_crit
++EXPORT_SYMBOL vmlinux 0x181c9680	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x1830e248	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x184f3c5c	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x185107d9	tso_start
++EXPORT_SYMBOL vmlinux 0x185f3b43	__genl_register_family
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x188c4c36	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0x188ea314	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x189b120d	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x189c5980	arm_copy_to_user
++EXPORT_SYMBOL vmlinux 0x18a0ae75	inode_init_once
++EXPORT_SYMBOL vmlinux 0x18adea9b	put_io_context
++EXPORT_SYMBOL vmlinux 0x18b6d498	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0x18b959c7	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0x18bd76a4	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x18c2227f	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x18e2f08f	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x18ee8f81	get_super_thawed
++EXPORT_SYMBOL vmlinux 0x18f50e6a	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x19275b56	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0x192f07e1	arp_xmit
++EXPORT_SYMBOL vmlinux 0x195af4fc	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0x19610e1f	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0x1968c75f	sync_filesystem
++EXPORT_SYMBOL vmlinux 0x1970a11d	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0x197dc3b3	omap_set_dma_src_burst_mode
++EXPORT_SYMBOL vmlinux 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL vmlinux 0x198c2cc3	d_delete
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19d9dd34	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0x19e4e5ee	_snd_ctl_add_slave
++EXPORT_SYMBOL vmlinux 0x19ea0fa8	bio_copy_data
++EXPORT_SYMBOL vmlinux 0x19f5809b	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0x1a05c568	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0x1a08dd70	snd_device_register
++EXPORT_SYMBOL vmlinux 0x1a130b4a	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0x1a16fd55	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0x1a1ff8ad	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0x1a435d7a	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0x1a454bec	release_sock
++EXPORT_SYMBOL vmlinux 0x1a4ad900	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0x1a555967	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x1a65f4ad	__arm_ioremap_pfn
++EXPORT_SYMBOL vmlinux 0x1a6dddf4	__d_drop
++EXPORT_SYMBOL vmlinux 0x1a81ff97	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x1a9ea048	elevator_exit
++EXPORT_SYMBOL vmlinux 0x1aadaf64	deactivate_super
++EXPORT_SYMBOL vmlinux 0x1abbd226	cros_ec_check_result
++EXPORT_SYMBOL vmlinux 0x1ad1f2e7	_memcpy_fromio
++EXPORT_SYMBOL vmlinux 0x1aec91b8	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x1af65223	elv_add_request
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b1dc0e7	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b2d6d2c	qcom_scm_cpu_power_down
++EXPORT_SYMBOL vmlinux 0x1b569d73	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0x1b581fd1	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x1b5caa62	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b76df9c	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0x1b7b4c61	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1ba7807b	alloc_disk
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bc01a00	dquot_release
++EXPORT_SYMBOL vmlinux 0x1bc0cd49	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0x1bd4b828	simple_rename
++EXPORT_SYMBOL vmlinux 0x1beac064	tso_build_data
++EXPORT_SYMBOL vmlinux 0x1bf92d29	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0x1c05cbea	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x1c113626	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x1c114a6a	vm_event_states
++EXPORT_SYMBOL vmlinux 0x1c151755	unregister_key_type
++EXPORT_SYMBOL vmlinux 0x1c23bee1	up_write
++EXPORT_SYMBOL vmlinux 0x1c311c4c	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0x1c3f2009	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0x1c58938b	md_write_start
++EXPORT_SYMBOL vmlinux 0x1c5e3878	icst525_idx2s
++EXPORT_SYMBOL vmlinux 0x1c730bdf	skb_append
++EXPORT_SYMBOL vmlinux 0x1c843d9d	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0x1c907bcf	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x1c956347	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0x1c9fb44c	pci_bus_put
++EXPORT_SYMBOL vmlinux 0x1cb0269b	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x1cc0736f	dma_alloc_from_coherent
++EXPORT_SYMBOL vmlinux 0x1ce76302	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0x1cfb04fa	finish_wait
++EXPORT_SYMBOL vmlinux 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL vmlinux 0x1d14237c	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0x1d1758fd	__nla_put
++EXPORT_SYMBOL vmlinux 0x1d704600	ptp_find_pin
++EXPORT_SYMBOL vmlinux 0x1d847ced	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dc7a0c4	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x1dceffbf	path_is_under
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1dd806b0	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x1defd6f5	d_genocide
++EXPORT_SYMBOL vmlinux 0x1df78c94	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x1e047854	warn_slowpath_fmt
++EXPORT_SYMBOL vmlinux 0x1e10631d	ip_options_compile
++EXPORT_SYMBOL vmlinux 0x1e161bac	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0x1e1d2618	address_space_init_once
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e2c7b82	elevator_init
++EXPORT_SYMBOL vmlinux 0x1e314c97	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x1e4417b4	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0x1e5375a6	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e725f33	vme_bus_type
++EXPORT_SYMBOL vmlinux 0x1e7ad7a0	tcp_filter
++EXPORT_SYMBOL vmlinux 0x1e7ca095	netdev_change_features
++EXPORT_SYMBOL vmlinux 0x1e9e5c82	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ee6fb29	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x1eeb848e	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0x1ef1344a	secpath_dup
++EXPORT_SYMBOL vmlinux 0x1f06dd4f	seq_pad
++EXPORT_SYMBOL vmlinux 0x1f15949f	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x1f1b15be	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x1f2ebb2e	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0x1f461466	filemap_fault
++EXPORT_SYMBOL vmlinux 0x1f471f3b	misc_deregister
++EXPORT_SYMBOL vmlinux 0x1f597ff8	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x1f5cf310	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0x1f5f5068	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x1f66cb16	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0x1f721c88	__bread_gfp
++EXPORT_SYMBOL vmlinux 0x1f72edc6	md_flush_request
++EXPORT_SYMBOL vmlinux 0x1f7e807f	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x1f8b43a0	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0x1f9401a5	security_mmap_file
++EXPORT_SYMBOL vmlinux 0x1f9f5bf9	snd_unregister_oss_device
++EXPORT_SYMBOL vmlinux 0x1fab5905	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x1fb9965e	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x1fb9bcc6	snd_component_add
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fc4cfde	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fe0c240	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1feab4bf	generic_setxattr
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x1ff469c7	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x200bcbe2	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x200ca532	devm_clk_get
++EXPORT_SYMBOL vmlinux 0x200ccd88	snd_timer_continue
++EXPORT_SYMBOL vmlinux 0x2018631a	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0x20205f64	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0x2030bbc2	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0x2032cac7	param_set_bint
++EXPORT_SYMBOL vmlinux 0x20421305	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x2048d4e2	dquot_disable
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x205005f4	finish_open
++EXPORT_SYMBOL vmlinux 0x205ec8de	omap_dispc_register_isr
++EXPORT_SYMBOL vmlinux 0x20661022	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0x206e00cd	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0x20723c27	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x20929c8f	nd_device_unregister
++EXPORT_SYMBOL vmlinux 0x20a17765	nvdimm_bus_unlock
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20b00659	param_set_int
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20ddf7ab	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x20e0134b	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x20e5a8c2	thaw_bdev
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20ee820b	of_get_named_gpio_flags
++EXPORT_SYMBOL vmlinux 0x20fb9cba	pci_release_regions
++EXPORT_SYMBOL vmlinux 0x210861d1	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x21110dbf	mmioset
++EXPORT_SYMBOL vmlinux 0x211331fa	__divsi3
++EXPORT_SYMBOL vmlinux 0x21168bdf	dma_find_channel
++EXPORT_SYMBOL vmlinux 0x211f86ce	snd_ctl_find_numid
++EXPORT_SYMBOL vmlinux 0x21321b04	tty_port_init
++EXPORT_SYMBOL vmlinux 0x2135d034	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0x213bc7c6	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0x216d759a	mmiocpy
++EXPORT_SYMBOL vmlinux 0x21782146	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x2192b692	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0x21c2a5d2	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0x21c6e24f	vfs_readf
++EXPORT_SYMBOL vmlinux 0x21c821ac	__getblk_slow
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21e5c149	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0x21fa2b07	key_validate
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x222f3359	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0x222fa684	lg_global_lock
++EXPORT_SYMBOL vmlinux 0x2232a8a5	mempool_free
++EXPORT_SYMBOL vmlinux 0x22442f32	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0x224bae15	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0x2252cb88	dss_mgr_disable
++EXPORT_SYMBOL vmlinux 0x2256fafa	div64_u64_rem
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x22743e17	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0x22764671	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x2279ca74	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x22819e4e	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0x22950b36	nd_dev_to_uuid
++EXPORT_SYMBOL vmlinux 0x22ab00ab	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0x22b2e251	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22ba4a01	ip6_xmit
++EXPORT_SYMBOL vmlinux 0x22bcd172	bioset_free
++EXPORT_SYMBOL vmlinux 0x22dfdd06	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x22e62e4a	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x22fc4f3a	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x22fe20e4	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0x230178a1	nd_integrity_init
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x232ff0a5	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0x234dafe8	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0x23521c25	arm_dma_ops
++EXPORT_SYMBOL vmlinux 0x236b7476	dev_change_flags
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23aa49d3	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23ce0041	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL vmlinux 0x23f40e2a	__napi_complete
++EXPORT_SYMBOL vmlinux 0x23f5c468	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x23fa5b86	nand_lock
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x24223014	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x242805dc	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x243570c8	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x2439ad4a	touch_atime
++EXPORT_SYMBOL vmlinux 0x243db9f9	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x2460e626	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x2466944c	notify_change
++EXPORT_SYMBOL vmlinux 0x246df1be	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0x2477386a	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x24997a3b	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x24a36dea	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL vmlinux 0x24ac3223	pci_set_master
++EXPORT_SYMBOL vmlinux 0x24b0da54	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0x24b71461	snd_ctl_rename_id
++EXPORT_SYMBOL vmlinux 0x24d32fee	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0x24eafd28	security_path_truncate
++EXPORT_SYMBOL vmlinux 0x24f5ab45	sock_i_uid
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x250113b4	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x25067d6d	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0x25069b97	prepare_creds
++EXPORT_SYMBOL vmlinux 0x2507ddf8	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x250cf843	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0x251bda95	snd_pcm_new_internal
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x2559949b	blk_get_request
++EXPORT_SYMBOL vmlinux 0x25708302	iget_locked
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x2578a911	of_find_node_by_type
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x25ae2413	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0x25aeedcc	force_sig
++EXPORT_SYMBOL vmlinux 0x25b5d921	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0x25d745a0	__dst_free
++EXPORT_SYMBOL vmlinux 0x25e8ed29	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x2642e451	clkdev_drop
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x26611443	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x266191dc	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0x2664b633	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0x26b0cd09	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0x26b3d649	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0x26ba6f77	shdma_cleanup
++EXPORT_SYMBOL vmlinux 0x26bb950b	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0x26be5442	vm_mmap
++EXPORT_SYMBOL vmlinux 0x26c2128c	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0x26c2b059	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26f3c18c	vc_resize
++EXPORT_SYMBOL vmlinux 0x26f6ede7	snd_pcm_stop
++EXPORT_SYMBOL vmlinux 0x26fd2584	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x2704c027	param_set_ulong
++EXPORT_SYMBOL vmlinux 0x270b236a	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x272c31ef	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x2732dd24	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0x273ad0f8	nvdimm_namespace_capacity
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x274d086b	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x274fd021	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x275ef902	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0x276f84ef	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x278d97ec	inet_release
++EXPORT_SYMBOL vmlinux 0x2790e766	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27be5048	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x27d90139	tty_throttle
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x28118cb6	__get_user_1
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x281bb9f8	nand_correct_data
++EXPORT_SYMBOL vmlinux 0x28403f94	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0x28616182	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0x287597bc	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x287a4cfe	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0x288ca925	sock_create_lite
++EXPORT_SYMBOL vmlinux 0x289ba6d7	of_phy_is_fixed_link
++EXPORT_SYMBOL vmlinux 0x289e4dd8	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL vmlinux 0x28a24337	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28a503f5	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x28fc3037	keyring_clear
++EXPORT_SYMBOL vmlinux 0x2901daa7	abort_creds
++EXPORT_SYMBOL vmlinux 0x2907be57	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0x29087180	register_qdisc
++EXPORT_SYMBOL vmlinux 0x290935cb	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x2927db6d	loop_backing_file
++EXPORT_SYMBOL vmlinux 0x29351977	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0x29419d6c	neigh_update
++EXPORT_SYMBOL vmlinux 0x294e035e	to_nd_btt
++EXPORT_SYMBOL vmlinux 0x294efa44	single_open_size
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x29551e5b	omap_dss_find_output
++EXPORT_SYMBOL vmlinux 0x296870cd	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x29687ac2	ns_capable
++EXPORT_SYMBOL vmlinux 0x297060e0	of_graph_get_next_endpoint
++EXPORT_SYMBOL vmlinux 0x299bd769	uart_match_port
++EXPORT_SYMBOL vmlinux 0x29c96427	_dev_info
++EXPORT_SYMBOL vmlinux 0x29ccb335	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0x29cde03c	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x29d09c4f	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0x29e1b020	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0x29fdda53	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0x2a138926	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a38a47d	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0x2a3aa678	_test_and_clear_bit
++EXPORT_SYMBOL vmlinux 0x2a49ddb1	generic_read_dir
++EXPORT_SYMBOL vmlinux 0x2a523dc4	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x2a5b560f	of_find_matching_node_and_match
++EXPORT_SYMBOL vmlinux 0x2a6511e4	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0x2a678973	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0x2a6f3d81	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x2a750cab	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x2a826795	nand_bch_correct_data
++EXPORT_SYMBOL vmlinux 0x2aa0e4fc	strncasecmp
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2ab30d87	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x2ab387e9	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x2acd2c49	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL vmlinux 0x2ae60e82	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0x2ae93cbe	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0x2af05377	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b10e5e9	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0x2b12925d	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x2b181a1a	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0x2b18300f	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0x2b240b2e	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b3c488e	key_put
++EXPORT_SYMBOL vmlinux 0x2b4e956e	mempool_create
++EXPORT_SYMBOL vmlinux 0x2b74e19b	input_open_device
++EXPORT_SYMBOL vmlinux 0x2b7be498	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL vmlinux 0x2b7c9170	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x2b7de1fe	tcp_close
++EXPORT_SYMBOL vmlinux 0x2b7e32aa	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2baeb9dd	snd_info_register
++EXPORT_SYMBOL vmlinux 0x2bc71f4b	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0x2bd2e554	phy_start
++EXPORT_SYMBOL vmlinux 0x2bd37f3b	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0x2bdd3300	do_truncate
++EXPORT_SYMBOL vmlinux 0x2be0f12d	dql_completed
++EXPORT_SYMBOL vmlinux 0x2bff3fbe	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0x2c122d43	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x2c14323a	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x2c214260	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x2c245ae0	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c3cb0be	param_set_short
++EXPORT_SYMBOL vmlinux 0x2c440e0f	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x2c4ef71a	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0x2c7c8e9a	pcibios_min_mem
++EXPORT_SYMBOL vmlinux 0x2c81ec75	__irq_regs
++EXPORT_SYMBOL vmlinux 0x2c988955	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x2c9b54ba	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0x2ca1dc9b	kernel_connect
++EXPORT_SYMBOL vmlinux 0x2ca51650	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0x2cc24f61	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0x2cf60385	__mutex_init
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d3a33b1	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x2d558cbd	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0x2d55cc68	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0x2d5dab25	nf_log_unset
++EXPORT_SYMBOL vmlinux 0x2d6507b5	_find_next_zero_bit_le
++EXPORT_SYMBOL vmlinux 0x2d770676	dispc_mgr_go
++EXPORT_SYMBOL vmlinux 0x2da79731	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0x2da9a2d3	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x2daed56b	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0x2dcf70ab	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x2dcfe9b4	dump_truncate
++EXPORT_SYMBOL vmlinux 0x2dd56b3d	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0x2dd9a36b	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x2dfacf28	snd_card_new
++EXPORT_SYMBOL vmlinux 0x2e12b95a	mmc_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e2ab42b	sget
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e3d3ca4	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0x2e40eb0a	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0x2e56ae7d	bio_advance
++EXPORT_SYMBOL vmlinux 0x2e5810c6	__aeabi_unwind_cpp_pr1
++EXPORT_SYMBOL vmlinux 0x2e77534f	seq_vprintf
++EXPORT_SYMBOL vmlinux 0x2ea63a15	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0x2eb48c02	km_report
++EXPORT_SYMBOL vmlinux 0x2ebae93f	devm_free_irq
++EXPORT_SYMBOL vmlinux 0x2ec524ad	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x2ec87ce0	dqget
++EXPORT_SYMBOL vmlinux 0x2ec9be5a	of_platform_device_create
++EXPORT_SYMBOL vmlinux 0x2ecd441b	fence_free
++EXPORT_SYMBOL vmlinux 0x2ef16e4b	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f0c1b97	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0x2f3ea1c8	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2f59a43e	dquot_enable
++EXPORT_SYMBOL vmlinux 0x2f5f2a57	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0x2f6c72b9	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0x2f6d8963	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0x2f75dc4e	cdev_init
++EXPORT_SYMBOL vmlinux 0x2f7e67c2	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0x2f918f39	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0x2f97749b	kobject_put
++EXPORT_SYMBOL vmlinux 0x2f9871ed	cpu_user
++EXPORT_SYMBOL vmlinux 0x2f9f6484	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x2fa70b6f	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2fe307b7	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x2fec4ae5	pci_restore_state
++EXPORT_SYMBOL vmlinux 0x300e3e30	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x303d8ae5	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0x307bc269	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x3082a0b3	dss_feat_get_supported_color_modes
++EXPORT_SYMBOL vmlinux 0x30937014	__find_get_block
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30c3ba90	proc_remove
++EXPORT_SYMBOL vmlinux 0x30c4cc3c	of_get_address
++EXPORT_SYMBOL vmlinux 0x30e0670c	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x30e99155	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310917fe	sort
++EXPORT_SYMBOL vmlinux 0x31289c44	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL vmlinux 0x31380354	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x315780c5	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0x315a4c3d	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x318333e4	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0x318d8ece	register_sound_dsp
++EXPORT_SYMBOL vmlinux 0x3191f109	__krealloc
++EXPORT_SYMBOL vmlinux 0x3192d5bd	simple_link
++EXPORT_SYMBOL vmlinux 0x319f2896	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x31a4767f	qcom_scm_hdcp_available
++EXPORT_SYMBOL vmlinux 0x31af9231	mmc_request_done
++EXPORT_SYMBOL vmlinux 0x31b31f5c	csum_partial_copy_nocheck
++EXPORT_SYMBOL vmlinux 0x31f04892	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0x31f0bb78	__kmap_atomic_idx
++EXPORT_SYMBOL vmlinux 0x31fb6950	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0x323501f4	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x3254c5b3	kfree_skb
++EXPORT_SYMBOL vmlinux 0x3260f8df	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x328a05f1	strncpy
++EXPORT_SYMBOL vmlinux 0x328a0755	get_user_pages
++EXPORT_SYMBOL vmlinux 0x32907b91	idr_remove
++EXPORT_SYMBOL vmlinux 0x329c3d53	netlink_set_err
++EXPORT_SYMBOL vmlinux 0x32b7ccfe	get_mem_type
++EXPORT_SYMBOL vmlinux 0x32c5f231	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0x32ddc69b	nd_sb_checksum
++EXPORT_SYMBOL vmlinux 0x32deffb4	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0x32f32c8a	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x3316845e	idr_get_next
++EXPORT_SYMBOL vmlinux 0x331d3f8c	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0x3333c10b	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x3343cec1	phy_device_create
++EXPORT_SYMBOL vmlinux 0x3363b490	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0x336df54e	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0x3377737f	serio_bus
++EXPORT_SYMBOL vmlinux 0x33879b17	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33dbfd93	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x33ea4e86	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x340238d0	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x341dbfa3	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x34365d7d	open_exec
++EXPORT_SYMBOL vmlinux 0x343d6597	phy_print_status
++EXPORT_SYMBOL vmlinux 0x344b7739	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x345ec708	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0x34623fd0	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x346694ec	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0x346d389b	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x34895d2b	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34c0d31c	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x34c501c1	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x34e7c3ef	pci_iomap
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x3507a132	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x35247117	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0x352acb1f	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0x35390773	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0x353de98f	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x353e3fa5	__get_user_4
++EXPORT_SYMBOL vmlinux 0x353e4cd8	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x356f8c04	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0x3582045e	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL vmlinux 0x35a5739a	key_alloc
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35cdcd05	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0x35d69ab4	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x360b1afe	probe_irq_mask
++EXPORT_SYMBOL vmlinux 0x360de884	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0x3612c10f	tmio_core_mmc_enable
++EXPORT_SYMBOL vmlinux 0x3623e2ba	cros_ec_query_all
++EXPORT_SYMBOL vmlinux 0x362bba4a	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0x3646f65e	serio_interrupt
++EXPORT_SYMBOL vmlinux 0x36492281	snd_pcm_notify
++EXPORT_SYMBOL vmlinux 0x364f0602	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x36630ee6	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0x3675db6d	kmap
++EXPORT_SYMBOL vmlinux 0x36771e3d	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x367ba856	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0x36935fad	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0x36b78c95	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0x36bb7fc0	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36e9ecaf	tc6393xb_lcd_mode
++EXPORT_SYMBOL vmlinux 0x36fdda67	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x370e2c95	__devm_release_region
++EXPORT_SYMBOL vmlinux 0x37267d5a	snd_card_register
++EXPORT_SYMBOL vmlinux 0x372f4bcf	nf_log_set
++EXPORT_SYMBOL vmlinux 0x3736964a	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x3744c020	console_start
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x377014ac	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x378fdc75	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL vmlinux 0x379dee5f	trace_print_symbols_seq_u64
++EXPORT_SYMBOL vmlinux 0x37a59bd5	udp_del_offload
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37c35ca6	devm_memremap
++EXPORT_SYMBOL vmlinux 0x37e74642	get_jiffies_64
++EXPORT_SYMBOL vmlinux 0x37ed8d97	input_free_device
++EXPORT_SYMBOL vmlinux 0x37f027cd	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x37f06263	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x37f614b7	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x3809f6da	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x38152f81	ac97_bus_type
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x381ccc13	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x3821ef3f	set_security_override
++EXPORT_SYMBOL vmlinux 0x383a07db	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0x385c0bbc	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0x388163ba	ps2_command
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x389acf0c	gpmc_configure
++EXPORT_SYMBOL vmlinux 0x389ecf9e	__bswapdi2
++EXPORT_SYMBOL vmlinux 0x38a161b3	dev_uc_init
++EXPORT_SYMBOL vmlinux 0x38a5c63b	simple_unlink
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a868b5	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38c3fcec	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0x38f20732	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x3910a612	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0x3911d706	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0x3924dd56	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0x392e93dd	cdrom_release
++EXPORT_SYMBOL vmlinux 0x39334822	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x396f7265	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL vmlinux 0x39730d06	atomic_io_modify
++EXPORT_SYMBOL vmlinux 0x3975e903	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0x397a062d	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x397a14a6	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0x398004f8	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0x3991a270	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0x3996613f	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x399b58c5	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39bb87de	nvdimm_bus_lock
++EXPORT_SYMBOL vmlinux 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL vmlinux 0x39c98bf4	input_event
++EXPORT_SYMBOL vmlinux 0x39ec122b	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x39f3242f	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0x39f384b7	skb_pull
++EXPORT_SYMBOL vmlinux 0x39f49133	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0x3a053d56	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL vmlinux 0x3a19899d	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0x3a1ac054	set_normalized_timespec64
++EXPORT_SYMBOL vmlinux 0x3a1fe359	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x3a334c69	netif_device_attach
++EXPORT_SYMBOL vmlinux 0x3a416f06	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0x3a499984	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0x3a9371a9	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0x3a9649b6	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0x3a977fb5	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3a9d24ba	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x3a9da2db	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x3aafecee	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0x3ac7cd4b	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x3ace678c	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0x3acec888	bdget_disk
++EXPORT_SYMBOL vmlinux 0x3b14e253	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x3b2c2015	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0x3b355820	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0x3b4c2fe0	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x3b52feeb	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0x3b5be1df	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b83e931	snd_card_disconnect
++EXPORT_SYMBOL vmlinux 0x3b8cbba5	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x3b91f3af	snd_free_pages
++EXPORT_SYMBOL vmlinux 0x3b96f139	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x3b9eabe0	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0x3bac444b	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0x3bb6df4a	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x3bb811a1	tcp_connect
++EXPORT_SYMBOL vmlinux 0x3bb955c7	napi_complete_done
++EXPORT_SYMBOL vmlinux 0x3bbf46ea	vga_base
++EXPORT_SYMBOL vmlinux 0x3bc462db	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0x3bd74f0b	omap_dss_get_overlay
++EXPORT_SYMBOL vmlinux 0x3be80ed6	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0x3bf00d19	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x3bfd1392	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x3c24647c	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0x3c342423	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0x3c3462c0	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0x3c393574	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c566a81	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0x3c6e978f	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c8e07e1	dev_err
++EXPORT_SYMBOL vmlinux 0x3c9c23b0	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x3c9c25c8	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x3c9c5ce6	kthread_stop
++EXPORT_SYMBOL vmlinux 0x3cb3931b	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3cfa969a	proc_douintvec
++EXPORT_SYMBOL vmlinux 0x3d30409d	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0x3d3c540f	elf_hwcap
++EXPORT_SYMBOL vmlinux 0x3d49bfde	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0x3d5a2386	kern_path_create
++EXPORT_SYMBOL vmlinux 0x3d6bafb3	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0x3d6d8095	__nd_iostat_start
++EXPORT_SYMBOL vmlinux 0x3d8009a2	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0x3d9e39d5	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0x3dbed65d	nd_iostat_end
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3dd5dc61	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0x3ddd40d0	snd_ctl_make_virtual_master
++EXPORT_SYMBOL vmlinux 0x3df01acf	md_write_end
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e0319f1	blkdev_get
++EXPORT_SYMBOL vmlinux 0x3e0afa4f	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x3e15cbd3	vfs_getattr
++EXPORT_SYMBOL vmlinux 0x3e47b83c	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x3e54586e	nobh_write_end
++EXPORT_SYMBOL vmlinux 0x3e55d216	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x3e564374	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x3e9dbf31	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x3e9f6966	down_write
++EXPORT_SYMBOL vmlinux 0x3eb0338c	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0x3eb09833	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0x3ece8f92	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0x3ed7ae9c	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x3eeb994d	genl_notify
++EXPORT_SYMBOL vmlinux 0x3f063971	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0x3f102d94	write_one_page
++EXPORT_SYMBOL vmlinux 0x3f335508	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x3f3b292c	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0x3f3c2a25	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f46bba6	dss_mgr_disconnect
++EXPORT_SYMBOL vmlinux 0x3f5b67d5	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x3f616ce2	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x3f6fe87e	snd_device_free
++EXPORT_SYMBOL vmlinux 0x3f781666	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x3f7dbc5c	textsearch_register
++EXPORT_SYMBOL vmlinux 0x3f8a9df7	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0x3f948cfc	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0x3fa3c1bb	sync_blockdev
++EXPORT_SYMBOL vmlinux 0x3fab3ca9	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0x3fbad455	register_cdrom
++EXPORT_SYMBOL vmlinux 0x3fc99f79	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x3fefaa98	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0x3ff9a7bf	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x400e708b	sock_register
++EXPORT_SYMBOL vmlinux 0x400f96df	acl_by_type
++EXPORT_SYMBOL vmlinux 0x402a7a05	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4039918a	clk_register_clkdev
++EXPORT_SYMBOL vmlinux 0x403fb152	pci_request_regions
++EXPORT_SYMBOL vmlinux 0x4059792f	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x407136b1	__put_user_8
++EXPORT_SYMBOL vmlinux 0x4071d0a9	dm_put_device
++EXPORT_SYMBOL vmlinux 0x407a3275	omap_start_dma
++EXPORT_SYMBOL vmlinux 0x408b2d2b	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a2d1dd	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40ad3abc	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x40b57e4f	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c705a3	fget_raw
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40c77fd4	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40e28bd6	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0x40e88c97	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x40eca8b3	input_set_capability
++EXPORT_SYMBOL vmlinux 0x40ed524a	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x40f07981	__ashldi3
++EXPORT_SYMBOL vmlinux 0x4112ae39	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0x411acc07	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x4141973b	of_find_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x416c9f3e	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x417cb01d	vga_put
++EXPORT_SYMBOL vmlinux 0x417f72e5	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0x41862ad4	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x418a5367	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x419ec3fb	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x41a01961	pps_lookup_dev
++EXPORT_SYMBOL vmlinux 0x41a79395	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x41a85ee0	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0x41a8e118	sk_capable
++EXPORT_SYMBOL vmlinux 0x41b165c9	tty_set_operations
++EXPORT_SYMBOL vmlinux 0x41c9dde7	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0x41d8a382	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0x41d9acf8	nvm_register
++EXPORT_SYMBOL vmlinux 0x42079548	__check_sticky
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x42253677	mutex_lock
++EXPORT_SYMBOL vmlinux 0x422cc94b	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0x422f59e8	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x42385902	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0x423c1ba7	iterate_dir
++EXPORT_SYMBOL vmlinux 0x423c4641	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x423d81ed	ida_pre_get
++EXPORT_SYMBOL vmlinux 0x4241e0fd	d_obtain_root
++EXPORT_SYMBOL vmlinux 0x42472e88	mtd_concat_destroy
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x4248e669	tty_write_room
++EXPORT_SYMBOL vmlinux 0x424b44f7	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x425a5c1d	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x425b3fe9	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0x425d216b	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0x4266391f	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0x42690299	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0x428c5b86	__register_nls
++EXPORT_SYMBOL vmlinux 0x429435cc	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0x4298b775	v7_flush_kern_cache_all
++EXPORT_SYMBOL vmlinux 0x4298f94b	dev_mc_add
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42b1bd70	block_read_full_page
++EXPORT_SYMBOL vmlinux 0x42b65c6d	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x42d7c45f	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0x42eb1d0e	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0x42ecf546	ioremap
++EXPORT_SYMBOL vmlinux 0x42edb35d	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x4319dc4f	param_set_uint
++EXPORT_SYMBOL vmlinux 0x4333d1f9	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x436ee9be	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x43a3962a	of_cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0x43a7b503	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x43ee2132	of_get_mac_address
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x43f8316c	snd_info_free_entry
++EXPORT_SYMBOL vmlinux 0x440674ae	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x44126a14	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0x442495c9	tmio_core_mmc_resume
++EXPORT_SYMBOL vmlinux 0x44271fbd	consume_skb
++EXPORT_SYMBOL vmlinux 0x44366cfc	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0x44438b96	hex2bin
++EXPORT_SYMBOL vmlinux 0x44643b93	__aeabi_lmul
++EXPORT_SYMBOL vmlinux 0x446cd530	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0x4492b61f	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL vmlinux 0x44a84738	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44bb4591	phy_disconnect
++EXPORT_SYMBOL vmlinux 0x44bfed00	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x44da5d0f	__csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0x44dd3d8d	completion_done
++EXPORT_SYMBOL vmlinux 0x44dd460a	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x44e67085	iput
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44f002fc	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x450ccd5b	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0x4520c841	mdiobus_write
++EXPORT_SYMBOL vmlinux 0x4529991d	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0x4530ce39	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x4549ad4d	__quota_error
++EXPORT_SYMBOL vmlinux 0x45577213	skb_find_text
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x45803901	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x4586b578	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0x4598d9ca	devm_request_resource
++EXPORT_SYMBOL vmlinux 0x45a0d9c3	snd_ctl_remove
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45bda0d5	system_serial_low
++EXPORT_SYMBOL vmlinux 0x45c17b30	__lock_page
++EXPORT_SYMBOL vmlinux 0x45cb1fe0	init_task
++EXPORT_SYMBOL vmlinux 0x462a2e75	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x464770ec	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x465757c3	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x46588471	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x4669e9f1	set_posix_acl
++EXPORT_SYMBOL vmlinux 0x466bb1a5	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0x4670b577	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0x467ddde6	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x467efc93	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0x468f433b	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x46b3a093	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x46ca246c	omap_get_dma_src_pos
++EXPORT_SYMBOL vmlinux 0x46d3b28c	__div0
++EXPORT_SYMBOL vmlinux 0x46d494aa	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0x46e98136	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x46f4cba4	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x471b5bb0	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0x471b7a87	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x4722f6b7	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0x47401ef5	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x47434420	path_get
++EXPORT_SYMBOL vmlinux 0x475762c5	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0x4766c098	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0x478f79f6	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x4790bef9	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x47acf829	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0x47bfa0b6	vc_cons
++EXPORT_SYMBOL vmlinux 0x47e70229	v7_flush_user_cache_range
++EXPORT_SYMBOL vmlinux 0x47f757de	elf_platform
++EXPORT_SYMBOL vmlinux 0x480da304	sock_i_ino
++EXPORT_SYMBOL vmlinux 0x48116d9e	simple_readpage
++EXPORT_SYMBOL vmlinux 0x481ce6ce	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x481fb8f3	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x481fe6b1	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x482703d2	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0x48310a73	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x48448a79	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x485db003	rt6_lookup
++EXPORT_SYMBOL vmlinux 0x487bb229	vme_slave_request
++EXPORT_SYMBOL vmlinux 0x487bb85d	blk_register_region
++EXPORT_SYMBOL vmlinux 0x48808fbe	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x488abac3	kill_bdev
++EXPORT_SYMBOL vmlinux 0x48909ac9	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x4892a942	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x48a5b067	__machine_arch_type
++EXPORT_SYMBOL vmlinux 0x48acd559	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0x48ad5720	arm_coherent_dma_ops
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48e658df	dss_mgr_set_timings
++EXPORT_SYMBOL vmlinux 0x48eca817	inet_frag_find
++EXPORT_SYMBOL vmlinux 0x48eddc1f	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0x48f8d51c	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x4918d1b8	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x491c7dc6	inode_permission
++EXPORT_SYMBOL vmlinux 0x4930b066	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x493489e2	key_link
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x49621a8c	snd_timer_notify
++EXPORT_SYMBOL vmlinux 0x497b45e0	snd_timer_global_register
++EXPORT_SYMBOL vmlinux 0x4980a627	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0x498815c7	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0x498d2722	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0x499cb58c	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x49a41b82	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b5c219	fs_bio_set
++EXPORT_SYMBOL vmlinux 0x49b77ed2	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0x49c899fb	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x49ebacbd	_clear_bit
++EXPORT_SYMBOL vmlinux 0x49f5ce64	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x4a184c1b	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0x4a28acbc	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0x4a29b38a	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x4a39e5a1	omap_set_dma_src_params
++EXPORT_SYMBOL vmlinux 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL vmlinux 0x4a401f72	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x4a57b339	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x4a59030a	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0x4a6a91f6	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x4a8c74e5	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0x4a8fa947	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0x4a904619	setattr_copy
++EXPORT_SYMBOL vmlinux 0x4a96d7cf	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x4aa5a0da	page_address
++EXPORT_SYMBOL vmlinux 0x4aa95be3	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4aca2024	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0x4acc683c	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4afaab89	pci_bus_get
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b1cfca7	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0x4b1ec3e2	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x4b33ff75	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b73de06	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0x4b78933c	qcom_scm_set_cold_boot_addr
++EXPORT_SYMBOL vmlinux 0x4b983543	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4bafd021	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x4bb4c23e	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0x4bc9bb42	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x4bce0f36	gen_pool_create
++EXPORT_SYMBOL vmlinux 0x4bcf03a4	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x4be7fb63	up
++EXPORT_SYMBOL vmlinux 0x4be85a03	memweight
++EXPORT_SYMBOL vmlinux 0x4c233a44	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0x4c29dcbf	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x4c2ae700	strnstr
++EXPORT_SYMBOL vmlinux 0x4c2c43fa	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x4c33081d	omapdss_compat_uninit
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c3492a7	of_get_parent
++EXPORT_SYMBOL vmlinux 0x4c5fc58c	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0x4c6c59df	sock_no_poll
++EXPORT_SYMBOL vmlinux 0x4c6e5b04	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0x4c7871da	blk_run_queue
++EXPORT_SYMBOL vmlinux 0x4c799ed2	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x4c86184b	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x4cac26c9	inet6_release
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4cf8a7c0	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x4d08bb2a	rwsem_wake
++EXPORT_SYMBOL vmlinux 0x4d0d163d	copy_page
++EXPORT_SYMBOL vmlinux 0x4d209542	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0x4d21599d	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x4d272917	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0x4d3ac3b6	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0x4d3b0f33	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0x4d3c153f	sigprocmask
++EXPORT_SYMBOL vmlinux 0x4d45d89e	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x4d4ce6f7	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x4d4f150f	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0x4d55a8a4	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4d9b6d35	snd_pcm_format_size
++EXPORT_SYMBOL vmlinux 0x4da8a291	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x4dae8a00	input_register_device
++EXPORT_SYMBOL vmlinux 0x4daf9d44	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0x4dc69370	snd_timer_new
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4dec6038	memscan
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4df1766f	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x4dff1d9d	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x4e026d50	tc_classify
++EXPORT_SYMBOL vmlinux 0x4e10081e	do_splice_to
++EXPORT_SYMBOL vmlinux 0x4e1562f1	of_get_child_by_name
++EXPORT_SYMBOL vmlinux 0x4e1c4cda	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0x4e237e68	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e3a8fe7	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x4e3fc408	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0x4e44cdd5	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0x4e506013	omap_dma_link_lch
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e936c56	__f_setown
++EXPORT_SYMBOL vmlinux 0x4e998999	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0x4e9f2d5b	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x4eaf5f91	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0x4eb226a7	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x4eb35824	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0x4ecec992	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0x4ecf4a8d	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0x4ef9f80b	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x4efc8216	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0x4efe5273	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x4f071c7a	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f1f719b	to_ndd
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f2bae78	snd_pcm_suspend_all
++EXPORT_SYMBOL vmlinux 0x4f3882a7	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f54d508	vm_map_ram
++EXPORT_SYMBOL vmlinux 0x4f6041ef	dns_query
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f6d9ca5	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0x4f7882c8	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL vmlinux 0x4f843fe0	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x4f89c9de	gpmc_cs_free
++EXPORT_SYMBOL vmlinux 0x4fda4ff4	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0x4fe2f14e	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x50252ac4	devm_release_resource
++EXPORT_SYMBOL vmlinux 0x50347b95	netlink_capable
++EXPORT_SYMBOL vmlinux 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL vmlinux 0x505c383f	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x5079d1d4	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0x5080725e	input_inject_event
++EXPORT_SYMBOL vmlinux 0x50831fe3	drop_super
++EXPORT_SYMBOL vmlinux 0x509232b1	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x509817cf	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x50a1c1df	skb_store_bits
++EXPORT_SYMBOL vmlinux 0x50b194dc	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0x50b66bcb	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x50bec8d8	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x50d5612e	dispc_mgr_get_sync_lost_irq
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x50e1d265	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x50ed71ef	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0x510f7816	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0x511269ee	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0x511746c1	dump_fpu
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x512be4f3	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x512c18e6	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0x514cc273	arm_copy_from_user
++EXPORT_SYMBOL vmlinux 0x515cf2af	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0x51671ec3	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x516ad155	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0x5175daca	fb_pan_display
++EXPORT_SYMBOL vmlinux 0x517a75f5	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0x51892f6d	dst_init
++EXPORT_SYMBOL vmlinux 0x518ad419	genphy_update_link
++EXPORT_SYMBOL vmlinux 0x51c02731	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x51d559d1	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x51e29f7d	register_mtd_chip_driver
++EXPORT_SYMBOL vmlinux 0x51e77c97	pfn_valid
++EXPORT_SYMBOL vmlinux 0x51e9de1c	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x51ef33b8	kstrndup
++EXPORT_SYMBOL vmlinux 0x51ff450e	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x5203449f	inet6_getname
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x5220b5e7	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0x52569df4	led_set_brightness
++EXPORT_SYMBOL vmlinux 0x527be0d8	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x528c709d	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x528d0c14	idr_init
++EXPORT_SYMBOL vmlinux 0x528f79c9	fasync_helper
++EXPORT_SYMBOL vmlinux 0x52906371	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x52acc1e8	neigh_table_init
++EXPORT_SYMBOL vmlinux 0x52af562a	__crc32c_le
++EXPORT_SYMBOL vmlinux 0x52b863e8	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0x52bb841c	atomic_io_modify_relaxed
++EXPORT_SYMBOL vmlinux 0x52cdd8a0	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x530ed428	d_drop
++EXPORT_SYMBOL vmlinux 0x5312d28e	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x5359a2c1	of_device_alloc
++EXPORT_SYMBOL vmlinux 0x535b379f	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x536f36b0	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0x537f562d	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0x5380e0b6	netdev_alert
++EXPORT_SYMBOL vmlinux 0x539af73c	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x53a1070b	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0x53e81b0d	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0x53ea75b4	send_sig_info
++EXPORT_SYMBOL vmlinux 0x53ef24ad	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0x53fc8bc5	flush_old_exec
++EXPORT_SYMBOL vmlinux 0x540064d0	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0x5408575f	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x5448acbb	of_find_net_device_by_node
++EXPORT_SYMBOL vmlinux 0x5451be94	drop_nlink
++EXPORT_SYMBOL vmlinux 0x547077ec	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x547526f5	processor
++EXPORT_SYMBOL vmlinux 0x5476cfe2	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x547ce898	dispc_read_irqenable
++EXPORT_SYMBOL vmlinux 0x548dc7b2	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0x549e4e35	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54c1fd16	udplite_prot
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54c592d9	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x54c72e84	cdev_alloc
++EXPORT_SYMBOL vmlinux 0x54caccf8	netdev_emerg
++EXPORT_SYMBOL vmlinux 0x54da34af	kernel_accept
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54ef3a23	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0x54f1b998	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x54f6830a	omapdss_get_default_display_name
++EXPORT_SYMBOL vmlinux 0x550eb59e	snd_card_free_when_closed
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x5539f385	skb_insert
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x556e85bd	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0x55bbb757	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0x55c85353	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x55fea2d8	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0x560385fc	vfs_read
++EXPORT_SYMBOL vmlinux 0x5605b2ed	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0x5607c494	tty_hangup
++EXPORT_SYMBOL vmlinux 0x560a5a77	vfs_unlink
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x563952a3	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x563db486	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x563e9cfa	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0x563f518e	genphy_read_status
++EXPORT_SYMBOL vmlinux 0x5662ebe4	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0x566bc7a9	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0x5674a3bc	skb_copy
++EXPORT_SYMBOL vmlinux 0x5689afe7	dispc_ovl_enable
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x56a026bb	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0x56a25d0a	param_set_ushort
++EXPORT_SYMBOL vmlinux 0x56a3e8d9	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x56aba243	seq_read
++EXPORT_SYMBOL vmlinux 0x56abb38f	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x56b73a0c	dmam_release_declared_memory
++EXPORT_SYMBOL vmlinux 0x56bc2f15	dispc_ovl_set_channel_out
++EXPORT_SYMBOL vmlinux 0x56c5ec62	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56f5292f	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x56f9050b	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0x56facdbd	tty_free_termios
++EXPORT_SYMBOL vmlinux 0x571462bc	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0x571ce75a	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x5746f94a	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x5750ed91	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x5774d28b	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x5779d3fa	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x57802025	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0x578fd612	dev_set_group
++EXPORT_SYMBOL vmlinux 0x57a9de52	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0x57b157e0	of_node_get
++EXPORT_SYMBOL vmlinux 0x57b304c4	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0x57bda74d	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x57be17a7	of_device_get_match_data
++EXPORT_SYMBOL vmlinux 0x57c51a6b	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x57d448b8	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x57d4d25e	revert_creds
++EXPORT_SYMBOL vmlinux 0x57e6fdc8	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x57e7278a	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x57fd2756	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0x5802b297	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL vmlinux 0x58088728	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x58516557	omap_set_dma_src_data_pack
++EXPORT_SYMBOL vmlinux 0x5857b7cd	pgprot_kernel
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x58769651	param_get_charp
++EXPORT_SYMBOL vmlinux 0x588120de	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0x58888dbb	input_grab_device
++EXPORT_SYMBOL vmlinux 0x588d0178	put_cmsg
++EXPORT_SYMBOL vmlinux 0x58976fe2	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0x58ae28f9	param_ops_string
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58c277ff	cros_ec_cmd_xfer_status
++EXPORT_SYMBOL vmlinux 0x58d633c7	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x58e2cdb3	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x58e48675	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x5905d860	vm_stat
++EXPORT_SYMBOL vmlinux 0x59211c1a	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x594e1317	__modsi3
++EXPORT_SYMBOL vmlinux 0x5959de6c	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0x59773f7d	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x598542b2	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x598cd828	udp_table
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x59a6c5d9	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59c6756a	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0x59d29dab	v7_flush_kern_dcache_area
++EXPORT_SYMBOL vmlinux 0x59d603c6	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0x59e5070d	__do_div64
++EXPORT_SYMBOL vmlinux 0x59fef453	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a145b94	tcf_register_action
++EXPORT_SYMBOL vmlinux 0x5a3005bd	submit_bh
++EXPORT_SYMBOL vmlinux 0x5a4c4166	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0x5a68d79f	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x5a968601	ps2_end_command
++EXPORT_SYMBOL vmlinux 0x5aa3dc7c	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x5aa69201	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x5acd0f94	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x5ad72fda	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0x5adccb98	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0x5ae5be44	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x5ae72aed	icmp_send
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5b19634d	div_s64_rem
++EXPORT_SYMBOL vmlinux 0x5b253e57	skb_checksum
++EXPORT_SYMBOL vmlinux 0x5b50ad7c	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x5b6cd0a1	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x5b6ec417	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0x5b777eee	seq_release
++EXPORT_SYMBOL vmlinux 0x5b89c8c2	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x5b922f80	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0x5b9a33d0	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0x5bc15a7d	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0x5bd5ed4f	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x5be5c84d	ptp_clock_event
++EXPORT_SYMBOL vmlinux 0x5bead40e	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0x5beeeb99	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0x5bfdda1d	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0x5c1a5b37	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0x5c2271ee	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x5c2f2b42	mtd_concat_create
++EXPORT_SYMBOL vmlinux 0x5c397b1d	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x5c608da1	pci_get_class
++EXPORT_SYMBOL vmlinux 0x5c77c972	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0x5c7ea4b3	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0x5c9284a0	processor_id
++EXPORT_SYMBOL vmlinux 0x5c98fa86	vga_get
++EXPORT_SYMBOL vmlinux 0x5ca0595e	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x5cbce5b7	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x5cdcf53a	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0x5cdddddb	kern_unmount
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5cfdcacf	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0x5d2fdb12	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0x5d33e6fb	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x5d4edd18	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d92c2e3	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0x5d938ebb	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x5d93e602	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x5d9ba425	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0x5da2ab4a	inet_select_addr
++EXPORT_SYMBOL vmlinux 0x5daf6902	snd_pcm_hw_refine
++EXPORT_SYMBOL vmlinux 0x5db108ad	seq_dentry
++EXPORT_SYMBOL vmlinux 0x5dc1eaf3	submit_bio
++EXPORT_SYMBOL vmlinux 0x5dcf6341	outer_cache
++EXPORT_SYMBOL vmlinux 0x5dd11142	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0x5de1169c	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0x5deef4a7	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x5e0f0dc9	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0x5e1a9203	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x5e2faef6	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0x5e6f8ae4	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL vmlinux 0x5e866d85	prandom_bytes
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5ea6ecbc	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5ed4294b	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0x5ee033bc	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0x5ee20bc8	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x5ee6c2cb	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0x5ee9162e	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x5efa14a2	kernel_bind
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f199d55	omapdss_unregister_output
++EXPORT_SYMBOL vmlinux 0x5f1fa9ee	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x5f22e72e	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x5f27323c	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x5f3eb0ee	omapdss_register_display
++EXPORT_SYMBOL vmlinux 0x5f4f6f72	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0x5f51e586	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x5f52c7b4	get_io_context
++EXPORT_SYMBOL vmlinux 0x5f66ac59	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0x5f68c805	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x5f754e5a	memset
++EXPORT_SYMBOL vmlinux 0x5f755380	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0x5f816b6a	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0x5f85148b	snd_power_wait
++EXPORT_SYMBOL vmlinux 0x5fcef69f	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x5fd268cb	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x5fe188af	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x5ff11cc3	pcibios_min_io
++EXPORT_SYMBOL vmlinux 0x6003e794	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0x60055baa	dispc_mgr_get_vsync_irq
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x600e3968	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x601bb6b0	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x602c96f0	copy_to_user_fromio
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x603be610	vfs_readv
++EXPORT_SYMBOL vmlinux 0x604206c8	flush_dcache_page
++EXPORT_SYMBOL vmlinux 0x60561c5f	write_inode_now
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x60867deb	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x6091f6e5	__serio_register_port
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL vmlinux 0x60b1e74a	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0x60b86f61	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x60b98460	set_cached_acl
++EXPORT_SYMBOL vmlinux 0x60c6930d	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0x60cddb9f	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x60d10504	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x60e90629	dget_parent
++EXPORT_SYMBOL vmlinux 0x60f4d478	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0x6122dbb2	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x61271d88	dquot_file_open
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x61448fcc	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x61594c9a	of_graph_get_remote_port_parent
++EXPORT_SYMBOL vmlinux 0x6162af77	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0x617a218d	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0x617c2a07	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0x619e966a	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x61b3560c	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61c0858f	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x61d6f57a	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0x61e8e48e	netdev_features_change
++EXPORT_SYMBOL vmlinux 0x620b78ea	omap_dss_get_next_device
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x6218a824	md_integrity_register
++EXPORT_SYMBOL vmlinux 0x6220b4a2	crc32_le
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x62296be1	qcom_scm_get_version
++EXPORT_SYMBOL vmlinux 0x6239ce7b	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0x623d016f	phy_suspend
++EXPORT_SYMBOL vmlinux 0x6269240d	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x6279a648	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x627b4b0f	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x628cab23	mpage_readpage
++EXPORT_SYMBOL vmlinux 0x6292be40	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0x6299fb2d	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0x62a5f067	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x62aa7ae9	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x62b2e44c	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x62cae6b1	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0x630dcd4a	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x630dcf1d	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x6340d809	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x63440f63	snd_ctl_remove_id
++EXPORT_SYMBOL vmlinux 0x63479c32	inet6_offloads
++EXPORT_SYMBOL vmlinux 0x63570723	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0x636b3461	omap_dss_get_num_overlays
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63b0d14b	update_region
++EXPORT_SYMBOL vmlinux 0x63b6016d	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63dad91b	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x63e0ac9c	bio_split
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63f10ca6	nf_log_trace
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x64010ab6	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x64355be0	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0x6437c78a	dev_add_offload
++EXPORT_SYMBOL vmlinux 0x643b698a	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0x64465e0e	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0x645a2251	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0x647ccd0d	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL vmlinux 0x64818665	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0x6482c3d4	d_move
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64a22ff0	dispc_mgr_set_lcd_config
++EXPORT_SYMBOL vmlinux 0x64b0dfb0	get_disk
++EXPORT_SYMBOL vmlinux 0x64bbfd84	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL vmlinux 0x64cde322	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x652bf25a	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0x65348710	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x653685c9	kernel_write
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x65466939	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x6546a550	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0x655acac6	phy_find_first
++EXPORT_SYMBOL vmlinux 0x6563864c	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x6565d33f	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x65ad2568	blk_init_queue
++EXPORT_SYMBOL vmlinux 0x65bc8ab4	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x65bcbb15	con_is_bound
++EXPORT_SYMBOL vmlinux 0x65ce253f	generic_perform_write
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65e16f77	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x65f0be68	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x65f0ea89	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x65f9065f	dma_release_declared_memory
++EXPORT_SYMBOL vmlinux 0x66117419	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL vmlinux 0x661bd737	snd_pcm_suspend
++EXPORT_SYMBOL vmlinux 0x6637c709	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0x663e9c08	key_task_permission
++EXPORT_SYMBOL vmlinux 0x66419cb2	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0x66422829	nd_btt_arena_is_valid
++EXPORT_SYMBOL vmlinux 0x664b2cb3	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x665e1b2b	of_get_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0x66654836	backlight_force_update
++EXPORT_SYMBOL vmlinux 0x667d70db	downgrade_write
++EXPORT_SYMBOL vmlinux 0x6687f372	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x66bd52fd	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0x66c59841	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x66d19682	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0x66d3f309	path_put
++EXPORT_SYMBOL vmlinux 0x6701589a	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x67297e1b	clear_nlink
++EXPORT_SYMBOL vmlinux 0x6745291e	snd_timer_open
++EXPORT_SYMBOL vmlinux 0x676bbc0f	_set_bit
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x67a37882	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0x67b1496e	input_flush_device
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67bb503e	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x67d7ada1	read_cache_page
++EXPORT_SYMBOL vmlinux 0x67d8e4bb	pci_clear_master
++EXPORT_SYMBOL vmlinux 0x67e02294	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x67f41643	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0x67f704af	get_task_io_context
++EXPORT_SYMBOL vmlinux 0x68078e0b	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x68182a69	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x6832d7bf	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0x683b5f71	stop_tty
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x6885ce8d	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0x68869bae	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0x6894b11a	of_io_request_and_map
++EXPORT_SYMBOL vmlinux 0x68993d42	fput
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68c85f5d	audit_log
++EXPORT_SYMBOL vmlinux 0x68fb581a	icst307_idx2s
++EXPORT_SYMBOL vmlinux 0x6905ddff	bio_chain
++EXPORT_SYMBOL vmlinux 0x690aeca2	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0x690e25d9	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0x6915eb38	down_interruptible
++EXPORT_SYMBOL vmlinux 0x69225e35	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0x6930362c	neigh_xmit
++EXPORT_SYMBOL vmlinux 0x6930ddb4	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x693e64b1	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x694b4b05	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x69636cec	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x6971543a	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x6976852f	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x698ad1cb	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL vmlinux 0x69914e79	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0x69a0fe64	snd_pcm_lib_write
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69a537dc	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69ae0be6	input_register_handle
++EXPORT_SYMBOL vmlinux 0x69b6f8d9	omap_set_dma_transfer_params
++EXPORT_SYMBOL vmlinux 0x69e05360	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x69e3bb92	ether_setup
++EXPORT_SYMBOL vmlinux 0x69ebbc60	vme_dma_request
++EXPORT_SYMBOL vmlinux 0x69eeb2d8	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a15d95b	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x6a1f067d	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0x6a3854c1	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x6a3bc7b9	mem_map
++EXPORT_SYMBOL vmlinux 0x6a4803a1	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x6a567b22	scsi_execute
++EXPORT_SYMBOL vmlinux 0x6a57f909	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a689794	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0x6a75c1a9	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x6a76536e	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a89044d	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0x6ab44184	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0x6abdf965	blk_rq_init
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b0cce87	__brelse
++EXPORT_SYMBOL vmlinux 0x6b149790	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0x6b160e96	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b3d3b55	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0x6b48b7bf	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x6b5e112f	keyring_alloc
++EXPORT_SYMBOL vmlinux 0x6b6ded79	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0x6b6ea0a6	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x6b722d47	free_netdev
++EXPORT_SYMBOL vmlinux 0x6b7a1e16	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0x6b9525b0	sock_rfree
++EXPORT_SYMBOL vmlinux 0x6b95daf3	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0x6bbbf01b	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bc8f104	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c1ce5ce	strcspn
++EXPORT_SYMBOL vmlinux 0x6c2b7a2a	phy_device_remove
++EXPORT_SYMBOL vmlinux 0x6c3accb4	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0x6c411065	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c6cdd4d	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6cdbc8af	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0x6cdc5c6b	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6cedadd8	elm_decode_bch_error_page
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d1c44dd	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d4e4a57	input_reset_device
++EXPORT_SYMBOL vmlinux 0x6d508746	file_remove_privs
++EXPORT_SYMBOL vmlinux 0x6d57bf70	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x6d603369	generic_make_request
++EXPORT_SYMBOL vmlinux 0x6d662533	_find_first_bit_le
++EXPORT_SYMBOL vmlinux 0x6d6ad5ba	freeze_bdev
++EXPORT_SYMBOL vmlinux 0x6d7aa464	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x6d84a28c	is_nd_btt
++EXPORT_SYMBOL vmlinux 0x6d8787f8	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x6d8ff308	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x6dafbfb8	register_console
++EXPORT_SYMBOL vmlinux 0x6db3eb85	mount_single
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6e19f7a6	inc_nlink
++EXPORT_SYMBOL vmlinux 0x6e29a7a3	up_read
++EXPORT_SYMBOL vmlinux 0x6e2a4502	mmc_release_host
++EXPORT_SYMBOL vmlinux 0x6e4c909d	kdb_current_task
++EXPORT_SYMBOL vmlinux 0x6e5e22fe	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0x6e60ecbd	blk_queue_split
++EXPORT_SYMBOL vmlinux 0x6e61ece7	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0x6e6514ed	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e949a22	tc6393xb_lcd_set_power
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6ec9ccdb	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0x6ed89c21	pcibios_fixup_bus
++EXPORT_SYMBOL vmlinux 0x6ede03f9	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x6ef07ba0	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x6ef62bb0	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL vmlinux 0x6f07b988	eth_header_cache
++EXPORT_SYMBOL vmlinux 0x6f0f06bd	param_get_long
++EXPORT_SYMBOL vmlinux 0x6f13130c	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0x6f1a6a22	snd_dma_free_pages
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f299527	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0x6f49254c	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0x6f4d52d2	phys_mem_access_prot
++EXPORT_SYMBOL vmlinux 0x6f5edff9	generic_setlease
++EXPORT_SYMBOL vmlinux 0x6f716c49	lookup_one_len
++EXPORT_SYMBOL vmlinux 0x6f8116dd	read_cache_pages
++EXPORT_SYMBOL vmlinux 0x6f887876	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6f9a1f5f	kunmap
++EXPORT_SYMBOL vmlinux 0x6fa493d5	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0x6fb8ce6b	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fc2bfbd	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6ff3862a	fb_blank
++EXPORT_SYMBOL vmlinux 0x6ffb5c22	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x706115b9	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0x7062b4cd	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0x70696fbb	override_creds
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x70704552	amba_driver_unregister
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x70876ec8	snd_ctl_find_id
++EXPORT_SYMBOL vmlinux 0x70ae913e	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x70b9e12b	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0x70bbf7f2	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL vmlinux 0x70e39dae	dss_uninstall_mgr_ops
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x70fd5fdc	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0x70fde331	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x710afa69	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x7119b085	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0x7119db7f	omap_dss_pal_timings
++EXPORT_SYMBOL vmlinux 0x7129798c	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x712ed37b	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x7136245b	do_splice_direct
++EXPORT_SYMBOL vmlinux 0x71524195	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0x7169102e	omap_dss_ntsc_timings
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x71930c65	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0x71973c7e	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0x7197d565	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71b59546	dm_register_target
++EXPORT_SYMBOL vmlinux 0x71c15e65	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0x71c3b84e	find_lock_entry
++EXPORT_SYMBOL vmlinux 0x71c4dcc6	seq_puts
++EXPORT_SYMBOL vmlinux 0x71c90087	memcmp
++EXPORT_SYMBOL vmlinux 0x71e68278	netlink_ack
++EXPORT_SYMBOL vmlinux 0x71ebedaa	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0x71f65175	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x721b9ba2	simple_lookup
++EXPORT_SYMBOL vmlinux 0x722e8060	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0x72350130	___ratelimit
++EXPORT_SYMBOL vmlinux 0x7238ae50	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x72405373	netdev_notice
++EXPORT_SYMBOL vmlinux 0x7255b6d0	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0x72619f34	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x72802a76	padata_stop
++EXPORT_SYMBOL vmlinux 0x7296d8a2	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x72a106f2	param_ops_long
++EXPORT_SYMBOL vmlinux 0x72b0b5dd	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x72b9492b	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x72d58de9	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x72da2336	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x72f4cab9	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x72f6f432	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x72f7927e	vga_client_register
++EXPORT_SYMBOL vmlinux 0x73158440	of_match_node
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x73235cf6	from_kprojid
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x73405874	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x734687d4	noop_llseek
++EXPORT_SYMBOL vmlinux 0x73730acd	shdma_request_irq
++EXPORT_SYMBOL vmlinux 0x7390eca1	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x73a88564	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x73bf42ce	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0x73d81818	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0x73e20c1c	strlcpy
++EXPORT_SYMBOL vmlinux 0x73f5ea9f	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x73fdc937	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0x73fe439f	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0x7406b944	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x742e1421	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x743260ed	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x7449f2b6	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x74599212	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0x74645129	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x749788de	snd_register_oss_device
++EXPORT_SYMBOL vmlinux 0x749948a2	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74c2c50c	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0x74d18788	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0x74e3a6d6	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74eac2f8	key_unlink
++EXPORT_SYMBOL vmlinux 0x7505bdef	memchr_inv
++EXPORT_SYMBOL vmlinux 0x751fac3f	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x75254049	page_readlink
++EXPORT_SYMBOL vmlinux 0x75275322	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x753652a9	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x754bfc91	d_tmpfile
++EXPORT_SYMBOL vmlinux 0x754edf09	inet6_bind
++EXPORT_SYMBOL vmlinux 0x7561a5af	load_nls_default
++EXPORT_SYMBOL vmlinux 0x7568e6c7	kernel_listen
++EXPORT_SYMBOL vmlinux 0x7570e021	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x75734b1e	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0x75850ab0	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0x75850d01	__vmalloc
++EXPORT_SYMBOL vmlinux 0x758af084	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0x7593d385	div64_s64
++EXPORT_SYMBOL vmlinux 0x75a21b32	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75cbf219	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x75e901eb	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x75f93143	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0x7601e74d	pid_task
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x761418da	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0x76176bb0	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0x76256dfb	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0x763237b9	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL vmlinux 0x76345456	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764b5044	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x7657c8a4	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0x76945bee	redraw_screen
++EXPORT_SYMBOL vmlinux 0x76987cbd	of_clk_get_by_name
++EXPORT_SYMBOL vmlinux 0x76ae215a	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x76c97e5c	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x76cc35f3	nf_log_register
++EXPORT_SYMBOL vmlinux 0x76cf47f6	__aeabi_llsl
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76d9bf11	crc32_be
++EXPORT_SYMBOL vmlinux 0x76e8257c	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0x76f6c5ef	kmalloc_order
++EXPORT_SYMBOL vmlinux 0x76f8f022	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0x770e89ff	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0x77114062	migrate_page
++EXPORT_SYMBOL vmlinux 0x77147aa2	find_get_entry
++EXPORT_SYMBOL vmlinux 0x77154a38	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x772519be	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0x773eec31	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0x7759478d	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x778cc5f5	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0x7791193f	icst525_s2div
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77ba35fe	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77d85d4d	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0x77dd6979	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0x77e9e94d	of_parse_phandle_with_fixed_args
++EXPORT_SYMBOL vmlinux 0x77fa1a63	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x77faa5f7	inet_listen
++EXPORT_SYMBOL vmlinux 0x7810a88b	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0x7815032d	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0x782c5373	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0x7833deb2	pgprot_user
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x783b977a	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0x784b3310	poll_freewait
++EXPORT_SYMBOL vmlinux 0x784e8a25	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x787ad01e	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78ca7155	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0x78d55b6f	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78f3f6da	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x78fdeaa4	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0x791c0b89	of_mm_gpiochip_remove
++EXPORT_SYMBOL vmlinux 0x7934536c	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0x79503318	filp_open
++EXPORT_SYMBOL vmlinux 0x795108aa	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0x79556f36	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x796f13dd	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x797c7b56	nd_region_to_nstype
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79ca00d6	serio_open
++EXPORT_SYMBOL vmlinux 0x79d3c1ca	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0x79ee19f4	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0x79fa8439	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0x7a1f2611	dispc_mgr_set_timings
++EXPORT_SYMBOL vmlinux 0x7a2754d5	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x7a2add7d	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0x7a372ff1	ptp_clock_unregister
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a466173	load_nls
++EXPORT_SYMBOL vmlinux 0x7a5563f4	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0x7a5c8a3b	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x7a64b6fd	twl6040_power
++EXPORT_SYMBOL vmlinux 0x7a95e5ae	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7aa45cdb	page_symlink
++EXPORT_SYMBOL vmlinux 0x7ab604bf	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ad03b2d	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7ad202eb	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0x7af976bc	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x7afa89fc	vsnprintf
++EXPORT_SYMBOL vmlinux 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL vmlinux 0x7b012caf	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0x7b0739ee	mntput
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b1ade38	lz4_decompress
++EXPORT_SYMBOL vmlinux 0x7b215773	blk_make_request
++EXPORT_SYMBOL vmlinux 0x7b222a9f	snd_card_set_id
++EXPORT_SYMBOL vmlinux 0x7b262d26	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0x7b283ce3	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0x7b2e0dbb	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0x7b383830	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0x7b5c8440	vm_munmap
++EXPORT_SYMBOL vmlinux 0x7b81c8bf	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0x7b836a05	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x7b8f0885	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0x7b91125f	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x7b999108	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0x7ba31020	seq_open_private
++EXPORT_SYMBOL vmlinux 0x7ba3f5a0	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0x7bae2748	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x7bb2a48e	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x7bc12a4e	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c1dcc7e	param_array_ops
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c49200b	noop_fsync
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c758d12	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0x7c83c634	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0x7c8a83b8	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7c9e798e	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0x7c9f79c8	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cc035a7	__ucmpdi2
++EXPORT_SYMBOL vmlinux 0x7cc9d163	sound_class
++EXPORT_SYMBOL vmlinux 0x7ccd66e8	d_instantiate
++EXPORT_SYMBOL vmlinux 0x7cd6155d	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7ce36679	dev_open
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d2c89d7	d_add_ci
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d975274	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0x7d9a5e8e	__skb_checksum
++EXPORT_SYMBOL vmlinux 0x7dbc3c8c	of_get_property
++EXPORT_SYMBOL vmlinux 0x7dcad061	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x7dccc294	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7df5e557	param_get_ushort
++EXPORT_SYMBOL vmlinux 0x7df91847	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0x7dfffba0	snd_register_device
++EXPORT_SYMBOL vmlinux 0x7e1a47be	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x7e1fa05f	vfs_statfs
++EXPORT_SYMBOL vmlinux 0x7e237b42	igrab
++EXPORT_SYMBOL vmlinux 0x7e39735f	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x7e6fa3ef	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0x7e9c0e43	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x7e9efe8e	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x7eb48d46	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0x7eb5a48d	amba_device_unregister
++EXPORT_SYMBOL vmlinux 0x7ec113a1	mapping_tagged
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7ee7f093	dispc_ovl_compute_fifo_thresholds
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f0a7e41	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0x7f0ccb20	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0x7f18e5cf	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f306e9d	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0x7f465e3d	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f63b31e	_memcpy_toio
++EXPORT_SYMBOL vmlinux 0x7f845873	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x7f979a07	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0x7fa02279	of_get_pci_address
++EXPORT_SYMBOL vmlinux 0x7fa9ab13	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0x7fb87e51	do_SAK
++EXPORT_SYMBOL vmlinux 0x7fde2edb	vme_master_read
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7ff27bca	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0x7ff724ab	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x7ffe933e	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x80038d7b	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0x80077513	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0x800e4ffa	__muldi3
++EXPORT_SYMBOL vmlinux 0x8047cd32	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0x804aabdf	idr_is_empty
++EXPORT_SYMBOL vmlinux 0x804de3fe	f_setown
++EXPORT_SYMBOL vmlinux 0x805112c3	free_task
++EXPORT_SYMBOL vmlinux 0x8056406e	seq_path
++EXPORT_SYMBOL vmlinux 0x805ba299	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x805bcca0	__inode_permission
++EXPORT_SYMBOL vmlinux 0x8061d6d3	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x806a30d8	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x806ceeae	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0x808986ad	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x8097da79	__vfs_read
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80d664cd	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80ec5d59	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x80f3dce8	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0x810e4599	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0x813a4d99	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x814c5d5e	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x81665e99	proc_symlink
++EXPORT_SYMBOL vmlinux 0x819535c2	file_path
++EXPORT_SYMBOL vmlinux 0x81a13ea6	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0x81a5167d	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x81a5794d	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81e73e87	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0x81e818d9	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x81f56e9a	phy_detach
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x822137e2	arm_heavy_mb
++EXPORT_SYMBOL vmlinux 0x823034f7	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x824a4367	tmio_core_mmc_pwr
++EXPORT_SYMBOL vmlinux 0x824d0edc	tty_port_put
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x82948b96	page_put_link
++EXPORT_SYMBOL vmlinux 0x8294ffc3	would_dump
++EXPORT_SYMBOL vmlinux 0x8297c038	pci_save_state
++EXPORT_SYMBOL vmlinux 0x829b30b2	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0x82ab0806	ppp_input
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82ae0d01	init_net
++EXPORT_SYMBOL vmlinux 0x82b5dd52	of_get_ddr_timings
++EXPORT_SYMBOL vmlinux 0x82bd644b	module_put
++EXPORT_SYMBOL vmlinux 0x82e03f0c	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x82ec2202	request_key
++EXPORT_SYMBOL vmlinux 0x82fe04f2	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0x8309707d	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0x831396c3	fence_signal
++EXPORT_SYMBOL vmlinux 0x8315044c	free_user_ns
++EXPORT_SYMBOL vmlinux 0x8320bea8	__umodsi3
++EXPORT_SYMBOL vmlinux 0x833c9002	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x8363b25e	phy_stop
++EXPORT_SYMBOL vmlinux 0x836be02c	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x8372cd2f	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x8375d79d	ida_destroy
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83dbcb60	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0x840d405b	phy_device_free
++EXPORT_SYMBOL vmlinux 0x842b6c85	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x84a6ee6c	bio_add_page
++EXPORT_SYMBOL vmlinux 0x84aa272b	sget_userns
++EXPORT_SYMBOL vmlinux 0x84b183ae	strncmp
++EXPORT_SYMBOL vmlinux 0x84b9c536	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0x84bf22b9	down_read_trylock
++EXPORT_SYMBOL vmlinux 0x84c1b118	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0x84c27416	locks_init_lock
++EXPORT_SYMBOL vmlinux 0x84cfb43a	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x85029267	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0x8527b043	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x8541c40e	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x85765fee	omap_enable_dma_irq
++EXPORT_SYMBOL vmlinux 0x857e2e04	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x8592f651	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x859911c1	copy_to_iter
++EXPORT_SYMBOL vmlinux 0x85a02898	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0x85b27594	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85e1ec7f	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0x85e37046	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x861d432a	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0x862a5106	register_netdevice
++EXPORT_SYMBOL vmlinux 0x863f4ffe	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x86860195	dss_feat_get_supported_displays
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x868b0f83	param_ops_short
++EXPORT_SYMBOL vmlinux 0x86968dae	__breadahead
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86a4889a	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0x86a7b4d5	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x86aba0bd	dma_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x86cb69bb	dss_mgr_set_lcd_config
++EXPORT_SYMBOL vmlinux 0x86d3daf8	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0x86e078d2	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0x86f8d886	block_write_begin
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x86fe53cd	snd_pcm_lib_ioctl
++EXPORT_SYMBOL vmlinux 0x87003790	fence_init
++EXPORT_SYMBOL vmlinux 0x8703f3b2	omap_dss_get_overlay_manager
++EXPORT_SYMBOL vmlinux 0x870f2a6a	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x872707e7	bioset_create
++EXPORT_SYMBOL vmlinux 0x87383013	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0x873e3c5f	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x873f0046	put_page
++EXPORT_SYMBOL vmlinux 0x875996c6	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x87a465f8	dss_mgr_unregister_framedone_handler
++EXPORT_SYMBOL vmlinux 0x87ac70f8	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0x87dae2c1	build_skb
++EXPORT_SYMBOL vmlinux 0x87dbd7dc	generic_fillattr
++EXPORT_SYMBOL vmlinux 0x87fc6beb	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0x881e0e06	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0x88221005	fb_find_mode
++EXPORT_SYMBOL vmlinux 0x88328665	proto_register
++EXPORT_SYMBOL vmlinux 0x88370d35	amba_driver_register
++EXPORT_SYMBOL vmlinux 0x88417223	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0x884cdb68	clear_inode
++EXPORT_SYMBOL vmlinux 0x886bc76f	mempool_resize
++EXPORT_SYMBOL vmlinux 0x886ef448	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x887ad2bc	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x8889f1ea	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0x88a55e40	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0x88adb2af	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0x88b19f45	system_serial
++EXPORT_SYMBOL vmlinux 0x890c57b5	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x8915a6dd	param_ops_bint
++EXPORT_SYMBOL vmlinux 0x8916b32d	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0x891b05ba	pps_register_source
++EXPORT_SYMBOL vmlinux 0x8929372e	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x8951fa58	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0x895918ce	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x895c60a6	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x899a66ba	security_path_link
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89b5c5b4	amba_request_regions
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89f7fbf4	vfs_rename
++EXPORT_SYMBOL vmlinux 0x89fc85ee	netif_device_detach
++EXPORT_SYMBOL vmlinux 0x8a0f4230	rename_lock
++EXPORT_SYMBOL vmlinux 0x8a12e71d	clk_get
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a263082	pci_dev_get
++EXPORT_SYMBOL vmlinux 0x8a2c4c95	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a4fa83b	__aeabi_llsr
++EXPORT_SYMBOL vmlinux 0x8a50659d	blk_put_request
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a62ae94	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8aa1a4cf	snd_timer_interrupt
++EXPORT_SYMBOL vmlinux 0x8aa4be4f	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x8ac1b86a	filp_close
++EXPORT_SYMBOL vmlinux 0x8ac6fca5	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0x8b19619e	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0x8b25fb74	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b3a5d30	nvm_register_target
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b4e835c	fb_show_logo
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b637b2b	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0x8b7134d0	d_walk
++EXPORT_SYMBOL vmlinux 0x8b7eeeb0	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8bc7a57a	dma_supported
++EXPORT_SYMBOL vmlinux 0x8bca4561	dev_deactivate
++EXPORT_SYMBOL vmlinux 0x8c0a5986	sk_common_release
++EXPORT_SYMBOL vmlinux 0x8c131d3e	from_kuid
++EXPORT_SYMBOL vmlinux 0x8c2c6db5	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0x8c3b0bb1	free_page_put_link
++EXPORT_SYMBOL vmlinux 0x8c46ba84	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0x8c4a6c91	set_wb_congested
++EXPORT_SYMBOL vmlinux 0x8c50d7f5	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x8c55548f	is_bad_inode
++EXPORT_SYMBOL vmlinux 0x8c5cfa7b	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c643c43	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0x8c76712b	proc_create_data
++EXPORT_SYMBOL vmlinux 0x8c90a4a2	inet_frags_init
++EXPORT_SYMBOL vmlinux 0x8cbc177d	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x8cbc4906	ilookup
++EXPORT_SYMBOL vmlinux 0x8cbdb024	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0x8ccc37fd	vme_irq_free
++EXPORT_SYMBOL vmlinux 0x8cd1d6d6	dqput
++EXPORT_SYMBOL vmlinux 0x8cd8c339	omap_free_dma
++EXPORT_SYMBOL vmlinux 0x8ced3710	nvdimm_namespace_common_probe
++EXPORT_SYMBOL vmlinux 0x8cfc6bc3	snd_pcm_new_stream
++EXPORT_SYMBOL vmlinux 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL vmlinux 0x8d129f44	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x8d134c39	idr_replace
++EXPORT_SYMBOL vmlinux 0x8d18331c	register_shrinker
++EXPORT_SYMBOL vmlinux 0x8d1b04a7	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0x8d2c3d93	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x8d2daacd	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0x8d403936	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d5fc115	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0x8d64495d	of_get_next_available_child
++EXPORT_SYMBOL vmlinux 0x8d6b2ce1	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x8d6f81b4	__div64_32
++EXPORT_SYMBOL vmlinux 0x8d72495b	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d7637ef	get_empty_filp
++EXPORT_SYMBOL vmlinux 0x8d836c5b	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0x8d89267b	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0x8d8b6353	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0x8d8e6f07	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0x8da86730	snd_ctl_register_ioctl
++EXPORT_SYMBOL vmlinux 0x8dcff6e2	__pv_offset
++EXPORT_SYMBOL vmlinux 0x8ddfcdb2	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x8deefe9b	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL vmlinux 0x8e136509	bio_reset
++EXPORT_SYMBOL vmlinux 0x8e170a6d	mntget
++EXPORT_SYMBOL vmlinux 0x8e3555e5	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x8e497146	of_get_next_child
++EXPORT_SYMBOL vmlinux 0x8e66f382	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e79263a	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x8e865d3c	arm_delay_ops
++EXPORT_SYMBOL vmlinux 0x8e9ded2b	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0x8ec32c67	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL vmlinux 0x8ecf8cb2	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0x8f20b911	iget5_locked
++EXPORT_SYMBOL vmlinux 0x8f27fb8f	simple_getattr
++EXPORT_SYMBOL vmlinux 0x8f329968	__lock_buffer
++EXPORT_SYMBOL vmlinux 0x8f3c7743	block_write_end
++EXPORT_SYMBOL vmlinux 0x8f595b11	snd_major
++EXPORT_SYMBOL vmlinux 0x8f678b07	__stack_chk_guard
++EXPORT_SYMBOL vmlinux 0x8f680e35	bd_set_size
++EXPORT_SYMBOL vmlinux 0x8fa4130a	omap_set_dma_callback
++EXPORT_SYMBOL vmlinux 0x8fa4c9c7	phy_init_hw
++EXPORT_SYMBOL vmlinux 0x8fbb7d67	of_n_size_cells
++EXPORT_SYMBOL vmlinux 0x8fc2d73e	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x8fc32850	of_find_all_nodes
++EXPORT_SYMBOL vmlinux 0x8fd06ad6	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0x8fd180e7	kernel_neon_begin
++EXPORT_SYMBOL vmlinux 0x8fe06915	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x8ffdb3b8	crc16
++EXPORT_SYMBOL vmlinux 0x90072a64	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0x902e1545	set_blocksize
++EXPORT_SYMBOL vmlinux 0x904e87e3	of_parse_phandle
++EXPORT_SYMBOL vmlinux 0x906718b4	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0x90695906	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0x906b2eac	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0x908194e6	snd_pcm_mmap_data
++EXPORT_SYMBOL vmlinux 0x908adc06	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x90be3acd	inet_del_offload
++EXPORT_SYMBOL vmlinux 0x90c5e819	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x90cf3c6e	set_groups
++EXPORT_SYMBOL vmlinux 0x90fd1d0d	msm_pinctrl_remove
++EXPORT_SYMBOL vmlinux 0x9103ab5e	blk_start_request
++EXPORT_SYMBOL vmlinux 0x912b8c98	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x91347f64	dump_skip
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x915238f6	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x915ec03e	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0x916c44f8	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x919029aa	__readwrite_bug
++EXPORT_SYMBOL vmlinux 0x9197bfd1	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0x91b6a00c	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0x91b84f13	omapdss_find_mgr_from_display
++EXPORT_SYMBOL vmlinux 0x91bb8a3a	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0x91bdcc55	inet_offloads
++EXPORT_SYMBOL vmlinux 0x91c0980e	icst_hz
++EXPORT_SYMBOL vmlinux 0x91cfd7dc	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0x91e0da56	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0x91e9d919	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x920cdfcd	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x9212fc01	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x9236c957	pipe_lock
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x929d7555	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92ad3ac2	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0x92ae0ad5	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0x92bcf493	tty_devnum
++EXPORT_SYMBOL vmlinux 0x92c45d9f	omapdss_find_output_from_display
++EXPORT_SYMBOL vmlinux 0x92d3b44d	finish_no_open
++EXPORT_SYMBOL vmlinux 0x92e56fff	padata_alloc
++EXPORT_SYMBOL vmlinux 0x92ec5d1b	dispc_mgr_enable
++EXPORT_SYMBOL vmlinux 0x92ed0ec5	__bforget
++EXPORT_SYMBOL vmlinux 0x92f40122	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x930d9a80	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0x93215e1d	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0x93238e34	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x933e8d30	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL vmlinux 0x934abbf7	snd_jack_add_new_kctl
++EXPORT_SYMBOL vmlinux 0x934c4b49	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0x93715391	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x9378b1a8	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0x93963a85	dss_feat_get_num_mgrs
++EXPORT_SYMBOL vmlinux 0x93a41a93	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93be3a49	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x93d12430	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x93eb3aa1	arp_tbl
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL vmlinux 0x940f44b7	read_code
++EXPORT_SYMBOL vmlinux 0x940f9cf6	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x9413393d	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x941e1292	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x942f72e4	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0x945b90a7	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0x946efbfa	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0x94874bfc	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0x948839a8	cdev_add
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x9496d7e1	set_page_dirty
++EXPORT_SYMBOL vmlinux 0x949cdd2b	snd_ctl_replace
++EXPORT_SYMBOL vmlinux 0x949e2684	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x94b1d52f	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0x94d3da68	rtc_lock
++EXPORT_SYMBOL vmlinux 0x94dbe79a	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x94df6ace	dss_mgr_connect
++EXPORT_SYMBOL vmlinux 0x94e514ce	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x94eea794	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x951cb39c	scsi_print_result
++EXPORT_SYMBOL vmlinux 0x954273d5	register_md_personality
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x95593506	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x95622f41	down_timeout
++EXPORT_SYMBOL vmlinux 0x9564251f	simple_dname
++EXPORT_SYMBOL vmlinux 0x956e9f62	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0x957adcde	skb_make_writable
++EXPORT_SYMBOL vmlinux 0x95894dc5	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0x95a303ca	snd_timer_global_free
++EXPORT_SYMBOL vmlinux 0x95a7cfb6	of_dev_put
++EXPORT_SYMBOL vmlinux 0x95bbe053	md_reload_sb
++EXPORT_SYMBOL vmlinux 0x95c2595f	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x95c92340	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0x95dbe078	__get_user_2
++EXPORT_SYMBOL vmlinux 0x95f7b4e5	snd_ctl_notify
++EXPORT_SYMBOL vmlinux 0x95fef8c6	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0x9607625d	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0x960dfaf5	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0x961961ce	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x964d3ab5	phy_resume
++EXPORT_SYMBOL vmlinux 0x96573b80	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x965b3a36	km_is_alive
++EXPORT_SYMBOL vmlinux 0x968228a8	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x96898769	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x96a2e889	__get_page_tail
++EXPORT_SYMBOL vmlinux 0x96cbf850	ptp_clock_index
++EXPORT_SYMBOL vmlinux 0x96cc8979	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96d80b2e	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x96e213f0	of_device_is_big_endian
++EXPORT_SYMBOL vmlinux 0x96fa209f	dispc_ovl_check
++EXPORT_SYMBOL vmlinux 0x96fec631	dquot_get_state
++EXPORT_SYMBOL vmlinux 0x97093f32	edma_filter_fn
++EXPORT_SYMBOL vmlinux 0x970eeee7	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0x971372a7	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x97255bdf	strlen
++EXPORT_SYMBOL vmlinux 0x9743e750	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x976e700f	down_trylock
++EXPORT_SYMBOL vmlinux 0x9773caa7	omap_dss_get_device
++EXPORT_SYMBOL vmlinux 0x9793c93a	dispc_mgr_setup
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x979c4190	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0x97bcf43b	param_set_bool
++EXPORT_SYMBOL vmlinux 0x97ecec21	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0x97f99fd4	dispc_ovl_setup
++EXPORT_SYMBOL vmlinux 0x980d63b2	input_set_keycode
++EXPORT_SYMBOL vmlinux 0x9820b644	warn_slowpath_fmt_taint
++EXPORT_SYMBOL vmlinux 0x98238afa	mmc_of_parse_voltage
++EXPORT_SYMBOL vmlinux 0x9832250d	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0x9838aa96	snd_timer_stop
++EXPORT_SYMBOL vmlinux 0x983e1058	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0x9846e238	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0x986a7612	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x986c5b3e	nla_append
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x987c11c7	__pv_phys_pfn_offset
++EXPORT_SYMBOL vmlinux 0x987d1125	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x987dee92	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0x9880718f	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0x98889125	__frontswap_test
++EXPORT_SYMBOL vmlinux 0x9891bcd7	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0x989216cd	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x9899db87	snd_device_new
++EXPORT_SYMBOL vmlinux 0x989d23ab	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x98ad373e	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0x98becab8	inet_accept
++EXPORT_SYMBOL vmlinux 0x98e68eca	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0x98f893c9	cdrom_open
++EXPORT_SYMBOL vmlinux 0x9923465d	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0x9935319a	register_filesystem
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x993bb4e2	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0x993c201f	vme_lm_request
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x995d3ca7	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0x995f0564	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x99679232	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x996c4d30	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x996f818c	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0x998c2d3b	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x9995dda3	nf_reinject
++EXPORT_SYMBOL vmlinux 0x999a2648	netlink_unicast
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99a9febf	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0x99aa6e53	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x99bb8806	memmove
++EXPORT_SYMBOL vmlinux 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d148bf	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0x99da71d8	get_phy_device
++EXPORT_SYMBOL vmlinux 0x99f58330	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0x9a0d9843	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a20c1ff	ps2_init
++EXPORT_SYMBOL vmlinux 0x9a47ee32	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0x9a490f5c	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x9a4a732c	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x9a623142	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x9a6cc5a5	snd_ctl_free_one
++EXPORT_SYMBOL vmlinux 0x9a8318ef	v7_coherent_kern_range
++EXPORT_SYMBOL vmlinux 0x9a8919a9	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x9a8b534e	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x9a9de1ee	snd_card_free
++EXPORT_SYMBOL vmlinux 0x9aa1364a	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x9aa218e3	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0x9ae46094	sk_wait_data
++EXPORT_SYMBOL vmlinux 0x9ae7130f	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0x9ae94f1b	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9af4aa9f	of_get_next_parent
++EXPORT_SYMBOL vmlinux 0x9b2000d5	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b381723	irq_set_chip
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b3f7e0b	input_release_device
++EXPORT_SYMBOL vmlinux 0x9b557338	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0x9b557629	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0x9b5ffba5	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x9b64f4f4	param_ops_byte
++EXPORT_SYMBOL vmlinux 0x9b6eb137	ksize
++EXPORT_SYMBOL vmlinux 0x9b9885fa	of_graph_get_endpoint_by_regs
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bbe88b3	flex_array_put
++EXPORT_SYMBOL vmlinux 0x9bc996c1	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x9bd261b4	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x9bd318e3	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0x9bd4d12e	put_filp
++EXPORT_SYMBOL vmlinux 0x9bdbbb6f	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9bfcc406	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0x9bfe1f64	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x9c0bd51f	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0x9c0f4c90	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x9c148a6d	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c5b58fd	prepare_binprm
++EXPORT_SYMBOL vmlinux 0x9c68234a	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x9c6a8d1f	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x9c74abad	make_kprojid
++EXPORT_SYMBOL vmlinux 0x9c75c4a4	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0x9c7dd32c	seq_file_path
++EXPORT_SYMBOL vmlinux 0x9c7f0db3	qcom_scm_set_warm_boot_addr
++EXPORT_SYMBOL vmlinux 0x9c997f31	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0x9c9ec2a0	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cba3c37	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x9cca80ce	udp_ioctl
++EXPORT_SYMBOL vmlinux 0x9cd335fa	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0x9d0034b0	omapdss_default_get_recommended_bpp
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d0d7afc	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0x9d253b9f	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0x9d3159b2	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0x9d326cc2	user_revoke
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d591742	of_find_compatible_node
++EXPORT_SYMBOL vmlinux 0x9d669763	memcpy
++EXPORT_SYMBOL vmlinux 0x9d6cb568	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0x9dabea92	pwmss_submodule_state_change
++EXPORT_SYMBOL vmlinux 0x9dbfd48d	iget_failed
++EXPORT_SYMBOL vmlinux 0x9dd42f49	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x9dfaea51	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x9dfe7307	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9dfe9cb9	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0x9e06dfd6	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x9e07764d	__neigh_create
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e1c00d7	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0x9e22097a	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x9e2aaab8	sock_no_listen
++EXPORT_SYMBOL vmlinux 0x9e33b2cc	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0x9e3f7b3a	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e5cd9c5	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e68e400	mount_nodev
++EXPORT_SYMBOL vmlinux 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL vmlinux 0x9e7283f9	omap_dss_put_device
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e7b5d1f	pci_iounmap
++EXPORT_SYMBOL vmlinux 0x9e9c84bc	proto_unregister
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9f1ca1b5	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0x9f203155	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0x9f37cebb	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f501c61	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0x9f823cea	dispc_mgr_is_enabled
++EXPORT_SYMBOL vmlinux 0x9f87b590	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0x9f94e190	phy_attach
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9f99a3cc	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x9f9a6ee1	eth_header_parse
++EXPORT_SYMBOL vmlinux 0x9fbd6bdc	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x9fd22315	bio_init
++EXPORT_SYMBOL vmlinux 0x9fd7cda1	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9feda519	dentry_open
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0x9ffd0f3a	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0xa0044066	kset_register
++EXPORT_SYMBOL vmlinux 0xa0158414	snd_pcm_hw_rule_add
++EXPORT_SYMBOL vmlinux 0xa021248b	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0xa0226d0b	flush_signals
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa06df9e1	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa08a5379	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0xa08ff604	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0xa090ae92	put_disk
++EXPORT_SYMBOL vmlinux 0xa0aa2b81	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0b3f8f9	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0xa0c064ac	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0xa0c2667c	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0xa0c8b284	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0xa0c920c3	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0xa0cb059e	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0f7d8db	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL vmlinux 0xa1013597	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa10fbe93	make_kuid
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa13170ab	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0xa13b056f	of_mdiobus_register
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa14b3f5d	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0xa1539bab	skb_trim
++EXPORT_SYMBOL vmlinux 0xa15f98db	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0xa192813b	idr_for_each
++EXPORT_SYMBOL vmlinux 0xa197bd52	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0xa19a3b93	snd_pcm_lib_free_pages
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1bacac0	kernel_read
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1d55e90	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa1e67eb2	generic_show_options
++EXPORT_SYMBOL vmlinux 0xa1ebb215	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0xa1f0ebea	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa20d514c	seq_lseek
++EXPORT_SYMBOL vmlinux 0xa21e7771	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0xa2250f51	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0xa22c02ea	omapdss_default_get_timings
++EXPORT_SYMBOL vmlinux 0xa246765a	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0xa24a2600	sk_net_capable
++EXPORT_SYMBOL vmlinux 0xa26bf57d	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa2b652f4	snd_pci_quirk_lookup
++EXPORT_SYMBOL vmlinux 0xa2bd8423	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xa2f6933e	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa32e88e0	inet_add_offload
++EXPORT_SYMBOL vmlinux 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL vmlinux 0xa34003d8	page_waitqueue
++EXPORT_SYMBOL vmlinux 0xa35444e4	dispc_write_irqenable
++EXPORT_SYMBOL vmlinux 0xa37e78b6	flex_array_get
++EXPORT_SYMBOL vmlinux 0xa381944f	dql_reset
++EXPORT_SYMBOL vmlinux 0xa3833a5e	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0xa38be088	param_get_byte
++EXPORT_SYMBOL vmlinux 0xa397a881	dev_warn
++EXPORT_SYMBOL vmlinux 0xa39a123a	fence_add_callback
++EXPORT_SYMBOL vmlinux 0xa3d54de2	__frontswap_store
++EXPORT_SYMBOL vmlinux 0xa3dfe746	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0xa3e2150a	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0xa3f48acb	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0xa3f96827	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0xa4089571	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0xa414882d	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0xa42ae476	key_type_keyring
++EXPORT_SYMBOL vmlinux 0xa43b1297	vscnprintf
++EXPORT_SYMBOL vmlinux 0xa45e02a7	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0xa4610bc6	omap_rev
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa47cae11	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0xa48f5b09	omap_dma_set_global_params
++EXPORT_SYMBOL vmlinux 0xa48fa7b2	inet_addr_type
++EXPORT_SYMBOL vmlinux 0xa49b5e6d	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0xa4b42c55	omap_set_dma_priority
++EXPORT_SYMBOL vmlinux 0xa4ca4b62	__nd_driver_register
++EXPORT_SYMBOL vmlinux 0xa4eb67c1	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0xa50218cb	of_iomap
++EXPORT_SYMBOL vmlinux 0xa50778bb	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0xa508414c	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0xa50c8878	scsi_print_command
++EXPORT_SYMBOL vmlinux 0xa551eaa0	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa556909a	dm_io
++EXPORT_SYMBOL vmlinux 0xa58fea9d	mempool_destroy
++EXPORT_SYMBOL vmlinux 0xa5971dd2	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa599a735	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0xa5aaae44	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0xa5bd4d03	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0xa5df7768	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0xa5e6dd47	vfs_llseek
++EXPORT_SYMBOL vmlinux 0xa617a8e8	of_find_node_by_name
++EXPORT_SYMBOL vmlinux 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL vmlinux 0xa61e4362	omap_request_dma
++EXPORT_SYMBOL vmlinux 0xa62f444d	file_open_root
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa65d7e35	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0xa66f06f6	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0xa67374f0	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa6970398	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0xa6a738dd	dev_uc_add
++EXPORT_SYMBOL vmlinux 0xa6bab23d	dqstats
++EXPORT_SYMBOL vmlinux 0xa6e0dbc8	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0xa6f2179c	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa70354b7	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0xa71de488	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0xa734a3e9	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa75dcc7b	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0xa773f87d	mdiobus_read
++EXPORT_SYMBOL vmlinux 0xa77cc34c	scsi_unregister
++EXPORT_SYMBOL vmlinux 0xa7800f19	kobject_del
++EXPORT_SYMBOL vmlinux 0xa7ac1137	__page_symlink
++EXPORT_SYMBOL vmlinux 0xa7d2450e	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0xa7d5b07b	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0xa7e5f24b	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0xa7eec48f	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0xa81b0a8d	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0xa82c6f8e	skb_clone
++EXPORT_SYMBOL vmlinux 0xa8397757	simple_statfs
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa86da456	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa87db305	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0xa881a451	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0xa8a8110c	kernel_neon_end
++EXPORT_SYMBOL vmlinux 0xa8e23674	of_mdio_find_bus
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa90e222c	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa9174e4a	vme_irq_request
++EXPORT_SYMBOL vmlinux 0xa91ba84d	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0xa92ecf05	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0xa952b78c	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0xa964dd13	gpmc_cs_request
++EXPORT_SYMBOL vmlinux 0xa9658cd3	kobject_add
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa98d4ae8	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0xa999083c	skb_push
++EXPORT_SYMBOL vmlinux 0xa9a82393	new_inode
++EXPORT_SYMBOL vmlinux 0xa9b69576	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0xa9b981f4	flush_kernel_dcache_page
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9cb5142	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0xa9cd1e76	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0xa9d2f3f7	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0xa9e80559	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0xaa013da1	bdput
++EXPORT_SYMBOL vmlinux 0xaa0b1094	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0xaa0da5ca	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0xaa12b503	__free_pages
++EXPORT_SYMBOL vmlinux 0xaa3dccae	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0xaa55a2ea	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0xaa5fc9dd	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0xaa6901ac	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa763704	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0xaa80b7c9	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0xaa82370f	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0xaa91adfa	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL vmlinux 0xaa9d4331	current_in_userns
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaae2e8d1	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab1f50d8	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0xab21a6ed	dss_mgr_register_framedone_handler
++EXPORT_SYMBOL vmlinux 0xab3ebc8d	mmc_free_host
++EXPORT_SYMBOL vmlinux 0xab600421	probe_irq_off
++EXPORT_SYMBOL vmlinux 0xab60dc83	of_find_i2c_device_by_node
++EXPORT_SYMBOL vmlinux 0xab63d7ac	register_framebuffer
++EXPORT_SYMBOL vmlinux 0xab694444	bsearch
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab7b13a2	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0xaba3ad0c	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xaba68d9a	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0xaba958e6	tty_name
++EXPORT_SYMBOL vmlinux 0xabc430c0	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabcb2fe6	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0xabd5ebdd	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0xabdd6463	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xabfcb4c3	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0xac09226d	dquot_acquire
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac0be260	end_page_writeback
++EXPORT_SYMBOL vmlinux 0xac164e85	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL vmlinux 0xac1774f0	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac1cb40a	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0xac25d169	snd_pcm_new
++EXPORT_SYMBOL vmlinux 0xac34a0b6	vfs_write
++EXPORT_SYMBOL vmlinux 0xac390091	dev_base_lock
++EXPORT_SYMBOL vmlinux 0xac398912	flex_array_clear
++EXPORT_SYMBOL vmlinux 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL vmlinux 0xac463bea	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0xac7bb854	__vfs_write
++EXPORT_SYMBOL vmlinux 0xac811df3	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0xac97a48c	import_iovec
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad2033e2	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0xad3660e0	snd_pcm_lib_read
++EXPORT_SYMBOL vmlinux 0xad3c159a	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0xad5acd17	mount_bdev
++EXPORT_SYMBOL vmlinux 0xad694162	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0xad7a7ad9	udp_set_csum
++EXPORT_SYMBOL vmlinux 0xad7ab0f0	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0xad80d220	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad8b76e9	dquot_resume
++EXPORT_SYMBOL vmlinux 0xadad108e	empty_zero_page
++EXPORT_SYMBOL vmlinux 0xadb5e1d7	blk_finish_request
++EXPORT_SYMBOL vmlinux 0xadd74ec5	elevator_alloc
++EXPORT_SYMBOL vmlinux 0xaddb4ffc	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xade76d22	touch_buffer
++EXPORT_SYMBOL vmlinux 0xade88e76	snd_malloc_pages
++EXPORT_SYMBOL vmlinux 0xadf8ad09	kill_pid
++EXPORT_SYMBOL vmlinux 0xadfcda5e	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xae0cef09	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0xae1f240c	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0xae378c99	i2c_master_send
++EXPORT_SYMBOL vmlinux 0xae6f3182	simple_follow_link
++EXPORT_SYMBOL vmlinux 0xae77a595	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0xae85a27e	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0xae9d6c86	simple_open
++EXPORT_SYMBOL vmlinux 0xaec655c7	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0xaef72d74	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0xaef87f09	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0xaf0a12d4	genphy_config_init
++EXPORT_SYMBOL vmlinux 0xaf3d0478	bmap
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf461aef	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0xaf50e76d	elf_set_personality
++EXPORT_SYMBOL vmlinux 0xaf5fd42a	dma_mmap_from_coherent
++EXPORT_SYMBOL vmlinux 0xaf6d32b5	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0xaf6ed340	give_up_console
++EXPORT_SYMBOL vmlinux 0xaf768b7e	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0xaf84865e	__get_user_8
++EXPORT_SYMBOL vmlinux 0xaf890719	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0xaf8aa518	system_rev
++EXPORT_SYMBOL vmlinux 0xaf9ee5ff	__blk_end_request
++EXPORT_SYMBOL vmlinux 0xafbf4fba	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0xafc20065	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0xafd8792e	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0xb0036aa8	snd_jack_set_parent
++EXPORT_SYMBOL vmlinux 0xb01a3731	input_close_device
++EXPORT_SYMBOL vmlinux 0xb01ae7fc	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0xb01ea692	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0xb02a8e3c	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0xb0331580	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0xb0477526	netdev_info
++EXPORT_SYMBOL vmlinux 0xb04cf0fe	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0xb056368b	ptp_clock_register
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb0648085	__block_write_begin
++EXPORT_SYMBOL vmlinux 0xb0663583	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0xb066b530	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0xb06951e2	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0xb079171b	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0xb081b9c3	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0xb08cc810	elv_rb_del
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0aa832d	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0xb0b1ebaf	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0ca22ac	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0xb0d72946	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0ee49b6	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0xb0f9d2c0	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0xb10451fd	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0xb1071873	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0xb111d24f	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0xb11bf034	inet_bind
++EXPORT_SYMBOL vmlinux 0xb121390a	probe_irq_on
++EXPORT_SYMBOL vmlinux 0xb127dea8	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb13dff3f	init_special_inode
++EXPORT_SYMBOL vmlinux 0xb156be60	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0xb15c540f	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb161d6ae	tty_check_change
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb19e3443	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0xb1ad28e0	__gnu_mcount_nc
++EXPORT_SYMBOL vmlinux 0xb1bff499	snd_pcm_open_substream
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1cf2db5	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1d87f8c	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0xb1d9aabd	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xb1e73677	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xb1fab95d	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0xb1fbb439	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0xb235bb8e	setup_new_exec
++EXPORT_SYMBOL vmlinux 0xb23828b2	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0xb242e1d0	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0xb24dc6b4	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xb257fe9f	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb26e5138	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0xb276abd7	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0xb27c0233	nd_namespace_blk_validate
++EXPORT_SYMBOL vmlinux 0xb28c3352	dev_emerg
++EXPORT_SYMBOL vmlinux 0xb2a3fcdc	simple_map_init
++EXPORT_SYMBOL vmlinux 0xb2aae6b3	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0xb2ab7a66	seq_putc
++EXPORT_SYMBOL vmlinux 0xb2bc5a42	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0xb2bca652	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2d48a2e	queue_work_on
++EXPORT_SYMBOL vmlinux 0xb2d4b1a8	arm_dma_zone_size
++EXPORT_SYMBOL vmlinux 0xb2d7d012	registered_fb
++EXPORT_SYMBOL vmlinux 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL vmlinux 0xb32d7b7e	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0xb32f19dc	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0xb3359281	scsi_init_io
++EXPORT_SYMBOL vmlinux 0xb33c351f	ioremap_cache
++EXPORT_SYMBOL vmlinux 0xb33c88d7	set_disk_ro
++EXPORT_SYMBOL vmlinux 0xb340f171	mmc_get_card
++EXPORT_SYMBOL vmlinux 0xb39e47e0	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0xb3a5a71b	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0xb3a9fce6	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3d657bf	vme_slot_num
++EXPORT_SYMBOL vmlinux 0xb3f3cc99	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0xb3f4f47f	sock_from_file
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb405dfa4	seq_escape
++EXPORT_SYMBOL vmlinux 0xb4223dfb	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb42777e3	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0xb428735c	param_get_int
++EXPORT_SYMBOL vmlinux 0xb4390f9a	mcount
++EXPORT_SYMBOL vmlinux 0xb44300fb	nf_afinfo
++EXPORT_SYMBOL vmlinux 0xb4519a8f	string_escape_mem
++EXPORT_SYMBOL vmlinux 0xb461edf7	unlock_page
++EXPORT_SYMBOL vmlinux 0xb46b4b8b	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb4742560	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0xb49482cb	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0xb4a6f468	phy_device_register
++EXPORT_SYMBOL vmlinux 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL vmlinux 0xb4b9622c	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0xb4c14e44	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0xb4e047aa	nvdimm_namespace_disk_name
++EXPORT_SYMBOL vmlinux 0xb4e215ce	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0xb51247f9	lease_modify
++EXPORT_SYMBOL vmlinux 0xb5198b77	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0xb51f7dda	snd_timer_start
++EXPORT_SYMBOL vmlinux 0xb524b94e	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0xb5301d3e	of_phy_connect
++EXPORT_SYMBOL vmlinux 0xb548487d	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0xb54f5072	get_gendisk
++EXPORT_SYMBOL vmlinux 0xb552df1d	dcb_getapp
++EXPORT_SYMBOL vmlinux 0xb5684e29	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb576c393	htc_egpio_get_wakeup_irq
++EXPORT_SYMBOL vmlinux 0xb5861116	search_binary_handler
++EXPORT_SYMBOL vmlinux 0xb590c743	I_BDEV
++EXPORT_SYMBOL vmlinux 0xb5951f82	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5b20288	padata_do_serial
++EXPORT_SYMBOL vmlinux 0xb5bff79e	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xb5c00014	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb5d28875	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0xb5d9454c	printk_emit
++EXPORT_SYMBOL vmlinux 0xb5ec4df9	scsi_add_device
++EXPORT_SYMBOL vmlinux 0xb5f5700e	tcp_prot
++EXPORT_SYMBOL vmlinux 0xb61e1135	framebuffer_release
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb6493198	genlmsg_put
++EXPORT_SYMBOL vmlinux 0xb64f409b	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0xb65e8cd8	unregister_nls
++EXPORT_SYMBOL vmlinux 0xb67434bc	register_key_type
++EXPORT_SYMBOL vmlinux 0xb675c645	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb6896671	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6bf7181	get_super
++EXPORT_SYMBOL vmlinux 0xb6c557fd	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0xb6d3daf1	qcom_scm_hdcp_req
++EXPORT_SYMBOL vmlinux 0xb738ab48	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb755f240	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb79ec15d	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0xb7af2a7d	unregister_netdev
++EXPORT_SYMBOL vmlinux 0xb7b65a26	cdev_del
++EXPORT_SYMBOL vmlinux 0xb7ba76c7	__aeabi_unwind_cpp_pr2
++EXPORT_SYMBOL vmlinux 0xb7c45bc6	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7cc33d2	cont_write_begin
++EXPORT_SYMBOL vmlinux 0xb7eb63ea	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0xb81960ca	snprintf
++EXPORT_SYMBOL vmlinux 0xb8370414	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0xb858b564	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb87c6ea2	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0xb87d9640	skb_tx_error
++EXPORT_SYMBOL vmlinux 0xb8854ac8	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xb8acabda	ata_port_printk
++EXPORT_SYMBOL vmlinux 0xb8e1f665	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0xb8e877e7	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xb9019edd	cros_ec_prepare_tx
++EXPORT_SYMBOL vmlinux 0xb91edc84	read_dev_sector
++EXPORT_SYMBOL vmlinux 0xb92f00e2	__alloc_skb
++EXPORT_SYMBOL vmlinux 0xb95696b7	pci_release_region
++EXPORT_SYMBOL vmlinux 0xb95f98d6	_memset_io
++EXPORT_SYMBOL vmlinux 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL vmlinux 0xb990524b	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0xb99dfbf7	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0xb99e5c6d	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0xb9a8f03b	omap_stop_dma
++EXPORT_SYMBOL vmlinux 0xb9acd3d9	__put_user_2
++EXPORT_SYMBOL vmlinux 0xb9ae5c17	pci_find_bus
++EXPORT_SYMBOL vmlinux 0xb9ba2109	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0xb9d02f35	request_firmware
++EXPORT_SYMBOL vmlinux 0xb9e58163	nand_scan_bbt
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xb9f460c9	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0xb9f6770b	snd_jack_set_key
++EXPORT_SYMBOL vmlinux 0xba3cff39	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba5326c4	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0xbab8e997	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0xbac3cbf2	ns_to_timespec64
++EXPORT_SYMBOL vmlinux 0xbadd29bb	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0xbadfe1a7	keyring_search
++EXPORT_SYMBOL vmlinux 0xbaf94d32	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0xbafeee36	dispc_runtime_get
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb1ba9f3	softnet_data
++EXPORT_SYMBOL vmlinux 0xbb255a05	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xbb27bd39	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb380f27	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0xbb440824	sock_create_kern
++EXPORT_SYMBOL vmlinux 0xbb50d47b	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0xbb558392	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0xbb570993	dev_mc_del
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb6352ef	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0xbb72d4fe	__put_user_1
++EXPORT_SYMBOL vmlinux 0xbb79c6f4	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0xbb7fca2e	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0xbb9449f2	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0xbb97ba1b	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbb992ac5	follow_pfn
++EXPORT_SYMBOL vmlinux 0xbbad917a	sync_inode
++EXPORT_SYMBOL vmlinux 0xbbaf8454	shdma_chan_filter
++EXPORT_SYMBOL vmlinux 0xbbb60c0a	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0xbbb78c47	nand_calculate_ecc
++EXPORT_SYMBOL vmlinux 0xbbbf7c79	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0xbbc3b29f	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0xbbea6091	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0xbbf7eb82	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0xbc10dd97	__put_user_4
++EXPORT_SYMBOL vmlinux 0xbc2cdca5	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0xbc6329b0	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0xbc736142	bio_map_kern
++EXPORT_SYMBOL vmlinux 0xbc8836eb	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0xbc88b639	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0xbc9db043	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0xbca80f2b	dm_get_device
++EXPORT_SYMBOL vmlinux 0xbca83808	vfs_mknod
++EXPORT_SYMBOL vmlinux 0xbca85ea6	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0xbcaa0974	netif_skb_features
++EXPORT_SYMBOL vmlinux 0xbcac15ea	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0xbcb80e36	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0xbcbe6a84	snd_ctl_new1
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcc91ff5	genphy_resume
++EXPORT_SYMBOL vmlinux 0xbcd89754	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0xbce76509	sock_wfree
++EXPORT_SYMBOL vmlinux 0xbcf05951	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0xbd000d3f	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0xbd02ed4d	dss_install_mgr_ops
++EXPORT_SYMBOL vmlinux 0xbd132c25	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0xbd17c6de	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0xbd47e618	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0xbd4a4ccb	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0xbd510472	tcp_req_err
++EXPORT_SYMBOL vmlinux 0xbd6cddfb	key_revoke
++EXPORT_SYMBOL vmlinux 0xbd76b6d2	copy_from_iter
++EXPORT_SYMBOL vmlinux 0xbd846616	tty_unlock
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbda150aa	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0xbdb1f9be	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0xbdb59d0a	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0xbdbae6f4	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xbdcfbd2c	devm_clk_put
++EXPORT_SYMBOL vmlinux 0xbdeabf7e	elm_config
++EXPORT_SYMBOL vmlinux 0xbdec4d08	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0xbdedb6b2	irq_stat
++EXPORT_SYMBOL vmlinux 0xbe0e5118	nla_memcmp
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe1cc5de	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xbe31e167	skb_put
++EXPORT_SYMBOL vmlinux 0xbe3dde23	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0xbe6650cf	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0xbe6d74d9	inode_init_owner
++EXPORT_SYMBOL vmlinux 0xbe7545df	kobject_init
++EXPORT_SYMBOL vmlinux 0xbe8860a8	dispc_mgr_go_busy
++EXPORT_SYMBOL vmlinux 0xbe8fb90c	dispc_mgr_get_framedone_irq
++EXPORT_SYMBOL vmlinux 0xbe9cafd8	blk_start_queue
++EXPORT_SYMBOL vmlinux 0xbeb29587	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0xbeb54339	alloc_file
++EXPORT_SYMBOL vmlinux 0xbed4bfd2	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0xbee90f2f	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf04ab4d	__sb_end_write
++EXPORT_SYMBOL vmlinux 0xbf0c06d0	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0xbf12e6df	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0xbf2471ae	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0xbf486982	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xbf57afd8	snd_pcm_create_iec958_consumer
++EXPORT_SYMBOL vmlinux 0xbf781872	param_get_bool
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf857d94	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf916ad3	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfa7b2e7	register_sound_special
++EXPORT_SYMBOL vmlinux 0xbfc2c66f	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0xbfddfccd	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0xbfe14b5b	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xbfee439c	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0xbff3826c	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0xbff65abc	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0xc0056be5	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0xc006af6c	of_get_cpu_node
++EXPORT_SYMBOL vmlinux 0xc00a141f	cad_pid
++EXPORT_SYMBOL vmlinux 0xc0164015	seq_open
++EXPORT_SYMBOL vmlinux 0xc045d75e	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0xc068440e	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc0a6a8c5	omap_set_dma_dest_burst_mode
++EXPORT_SYMBOL vmlinux 0xc0a98385	profile_pc
++EXPORT_SYMBOL vmlinux 0xc0c6bd12	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0xc0d209f0	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0xc0da0fa1	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0xc0e7f1a9	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0xc11d8093	iov_shorten
++EXPORT_SYMBOL vmlinux 0xc1283d25	locks_free_lock
++EXPORT_SYMBOL vmlinux 0xc163d5cf	d_lookup
++EXPORT_SYMBOL vmlinux 0xc1841e9f	security_path_chown
++EXPORT_SYMBOL vmlinux 0xc18837f2	dst_destroy
++EXPORT_SYMBOL vmlinux 0xc189e70e	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0xc1932459	d_make_root
++EXPORT_SYMBOL vmlinux 0xc19a4a0b	unlock_rename
++EXPORT_SYMBOL vmlinux 0xc19e8711	set_nlink
++EXPORT_SYMBOL vmlinux 0xc1b04168	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0xc1c5f483	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0xc1c8cc95	tty_port_open
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1e0e035	__register_chrdev
++EXPORT_SYMBOL vmlinux 0xc1e3d78b	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc1e9ab2b	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xc1ec8e71	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0xc1eca654	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0xc1ee4299	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0xc204e68d	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0xc2438da8	inet_put_port
++EXPORT_SYMBOL vmlinux 0xc244f556	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0xc260209f	ilookup5
++EXPORT_SYMBOL vmlinux 0xc2684070	sk_stream_error
++EXPORT_SYMBOL vmlinux 0xc26d4bb2	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xc2787009	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0xc2a22cf6	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2a98c77	snd_jack_new
++EXPORT_SYMBOL vmlinux 0xc2acc033	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xc2ae54d3	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0xc2b137f0	follow_up
++EXPORT_SYMBOL vmlinux 0xc2d711e1	krealloc
++EXPORT_SYMBOL vmlinux 0xc2e12259	pci_pme_active
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc31140f5	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0xc316e8a8	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0xc328f54b	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0xc330ed73	serio_close
++EXPORT_SYMBOL vmlinux 0xc33267fe	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0xc3388ca3	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0xc342f51c	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xc349bac0	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0xc359fb65	abort
++EXPORT_SYMBOL vmlinux 0xc367bdbf	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0xc38fd8ad	dev_activate
++EXPORT_SYMBOL vmlinux 0xc3999b13	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0xc3ac7aa3	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0xc3ad780a	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0xc3c04f20	mpage_readpages
++EXPORT_SYMBOL vmlinux 0xc3c0fd23	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3c67106	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0xc3c9fc85	__napi_schedule
++EXPORT_SYMBOL vmlinux 0xc3d2596d	nand_bch_calculate_ecc
++EXPORT_SYMBOL vmlinux 0xc3dfb3ea	proc_set_size
++EXPORT_SYMBOL vmlinux 0xc3ecf750	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0xc41f0516	node_states
++EXPORT_SYMBOL vmlinux 0xc4254276	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0xc42ffe07	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0xc44acc78	pps_unregister_source
++EXPORT_SYMBOL vmlinux 0xc45cbdcb	generic_update_time
++EXPORT_SYMBOL vmlinux 0xc4725551	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0xc47f1a12	dev_printk
++EXPORT_SYMBOL vmlinux 0xc4839969	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0xc48bbfb6	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc49b1467	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0xc49bb83e	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0xc4ab1417	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0xc4b9f2d8	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0xc4bde8a3	tty_register_device
++EXPORT_SYMBOL vmlinux 0xc4ce1bd7	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0xc4ce58de	fget
++EXPORT_SYMBOL vmlinux 0xc4e3bd3d	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0xc4eb0dc2	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0xc4eda017	register_gifconf
++EXPORT_SYMBOL vmlinux 0xc503ac3b	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0xc51af666	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0xc51d7105	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0xc52da066	omap_set_dma_dest_params
++EXPORT_SYMBOL vmlinux 0xc52e3628	console_stop
++EXPORT_SYMBOL vmlinux 0xc52eb380	kmap_to_page
++EXPORT_SYMBOL vmlinux 0xc55fe348	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0xc56571d2	mdiobus_free
++EXPORT_SYMBOL vmlinux 0xc57417c1	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0xc582d279	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc5b131c7	simple_rmdir
++EXPORT_SYMBOL vmlinux 0xc5c8ee24	truncate_setsize
++EXPORT_SYMBOL vmlinux 0xc5fa3d8e	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0xc5fbd6a4	start_tty
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc61200f2	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc63f6118	single_open
++EXPORT_SYMBOL vmlinux 0xc641a55e	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0xc64a26d9	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc64f4cf2	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0xc66fa6a6	ida_remove
++EXPORT_SYMBOL vmlinux 0xc672f6b8	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc67e436d	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xc67fb289	param_set_ullong
++EXPORT_SYMBOL vmlinux 0xc6938686	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xc6a3aa0f	__module_get
++EXPORT_SYMBOL vmlinux 0xc6b5f7fe	del_gendisk
++EXPORT_SYMBOL vmlinux 0xc6c77529	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6de77b4	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0xc6ed350d	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL vmlinux 0xc6f2fa59	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0xc70d90dd	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc76d0187	set_binfmt
++EXPORT_SYMBOL vmlinux 0xc76dde0f	nonseekable_open
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc782b32d	param_ops_int
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc796fb2b	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc79dfb7b	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0xc7a06332	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7ab4086	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xc7bad225	d_set_d_op
++EXPORT_SYMBOL vmlinux 0xc7bcbc8d	add_wait_queue
++EXPORT_SYMBOL vmlinux 0xc7e31912	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0xc7ec6c27	strspn
++EXPORT_SYMBOL vmlinux 0xc7f936ea	nand_scan_ident
++EXPORT_SYMBOL vmlinux 0xc8316530	bdi_destroy
++EXPORT_SYMBOL vmlinux 0xc8339e24	string_unescape
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc84018f9	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0xc8472696	get_fs_type
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc871904d	shdma_chan_probe
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc874782c	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc89badbd	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8af2cde	kfree_put_link
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8c75442	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0xc8d547a6	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0xc904e37b	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0xc90ecb75	set_anon_super
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc9153aaa	nd_btt_probe
++EXPORT_SYMBOL vmlinux 0xc926af3b	do_splice_from
++EXPORT_SYMBOL vmlinux 0xc93f6ee9	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0xc9476d24	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0xc9537925	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0xc95770f6	filemap_flush
++EXPORT_SYMBOL vmlinux 0xc95bfd4e	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0xc95f5a8f	udp_add_offload
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc9648610	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0xc964e445	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0xc9775291	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0xc98adfb0	shdma_reset
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc9a5d55d	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0xc9b79172	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0xc9cfff07	icmpv6_send
++EXPORT_SYMBOL vmlinux 0xc9d2950e	tty_kref_put
++EXPORT_SYMBOL vmlinux 0xc9d8c987	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0xc9e60d55	omap_dss_find_device
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca11ca1b	omapdss_register_output
++EXPORT_SYMBOL vmlinux 0xca1f23c3	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0xca41eaa3	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0xca450282	dquot_initialize
++EXPORT_SYMBOL vmlinux 0xca531806	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0xca58de37	pci_bus_type
++EXPORT_SYMBOL vmlinux 0xca5e3281	generic_getxattr
++EXPORT_SYMBOL vmlinux 0xca91a75f	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xca93c260	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0xca9ad655	omapdss_output_set_device
++EXPORT_SYMBOL vmlinux 0xca9fa2b6	of_match_device
++EXPORT_SYMBOL vmlinux 0xcaf0667f	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb0abcce	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0xcb13d278	kthread_bind
++EXPORT_SYMBOL vmlinux 0xcb1dc269	tty_lock
++EXPORT_SYMBOL vmlinux 0xcb1ffaf9	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0xcb3264c7	km_state_notify
++EXPORT_SYMBOL vmlinux 0xcb3f23da	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0xcb466063	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0xcb491345	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbbf94f6	i2c_release_client
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbcf2505	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0xcbdb0049	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0xcbeac4be	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcbeb5b00	km_query
++EXPORT_SYMBOL vmlinux 0xcbee6439	ida_simple_get
++EXPORT_SYMBOL vmlinux 0xcc12e4ee	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0xcc15835e	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0xcc173ea3	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0xcc1b5f6e	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc643cfe	seq_release_private
++EXPORT_SYMBOL vmlinux 0xcc6ecbf8	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0xcc7d36fe	find_vma
++EXPORT_SYMBOL vmlinux 0xcc90a433	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0xcc90f579	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0xcc940390	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0xccb2f14a	kobject_get
++EXPORT_SYMBOL vmlinux 0xccb894b2	snd_pcm_hw_param_last
++EXPORT_SYMBOL vmlinux 0xccba28b5	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccc290cc	kill_fasync
++EXPORT_SYMBOL vmlinux 0xccf0b6a5	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0xccfef64f	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd30b95a	tmio_core_mmc_clk_div
++EXPORT_SYMBOL vmlinux 0xcd4c1f2b	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0xcd4ed039	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0xcd63c845	__aeabi_lasr
++EXPORT_SYMBOL vmlinux 0xcd7693c0	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0xcd7bd32d	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0xcd8137e9	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xcd8ec638	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0xcd901441	sock_efree
++EXPORT_SYMBOL vmlinux 0xcd945440	mmc_erase
++EXPORT_SYMBOL vmlinux 0xcd9953c2	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0xcd9d7d29	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0xcda2efa7	tso_count_descs
++EXPORT_SYMBOL vmlinux 0xcdb9eaf0	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdc3af86	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0xcdc49e19	lockref_get
++EXPORT_SYMBOL vmlinux 0xcdc51809	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0xcdcaa5f5	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0xcdcdc089	pps_event
++EXPORT_SYMBOL vmlinux 0xcdd0ca9c	of_find_node_opts_by_path
++EXPORT_SYMBOL vmlinux 0xcdd2d3c3	ip_defrag
++EXPORT_SYMBOL vmlinux 0xcde39944	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0xcdec0aab	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0xcdf64744	PDE_DATA
++EXPORT_SYMBOL vmlinux 0xce0f6335	mpage_writepage
++EXPORT_SYMBOL vmlinux 0xce0fdbcc	sock_edemux
++EXPORT_SYMBOL vmlinux 0xce2760e9	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce2bddb5	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0xce2ede12	sock_release
++EXPORT_SYMBOL vmlinux 0xce30f482	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xce3ca308	copy_from_user_toio
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xcec0be58	param_get_uint
++EXPORT_SYMBOL vmlinux 0xcecfd42e	omapdss_unregister_display
++EXPORT_SYMBOL vmlinux 0xced68fbd	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0xcee07029	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0xceeb0985	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0xceed7f85	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefc1b83	dev_load
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf0a2b3f	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xcf10034a	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0xcf169fea	kset_unregister
++EXPORT_SYMBOL vmlinux 0xcf55560b	soft_cursor
++EXPORT_SYMBOL vmlinux 0xcf6dfce5	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0xcf859ea5	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0xcf88625f	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xcf97c22b	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0xcf98c983	serio_rescan
++EXPORT_SYMBOL vmlinux 0xcfa0e8cb	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0xcfab43fd	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0xcfb2f430	seq_write
++EXPORT_SYMBOL vmlinux 0xcfcd2119	generic_readlink
++EXPORT_SYMBOL vmlinux 0xcfdfc083	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0xcfecef8c	omap_dss_get_output
++EXPORT_SYMBOL vmlinux 0xcff18df3	phy_init_eee
++EXPORT_SYMBOL vmlinux 0xcff4939f	dquot_destroy
++EXPORT_SYMBOL vmlinux 0xcff6b676	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0xd0045971	mmc_add_host
++EXPORT_SYMBOL vmlinux 0xd00d150d	phy_connect
++EXPORT_SYMBOL vmlinux 0xd00efc01	i2c_use_client
++EXPORT_SYMBOL vmlinux 0xd0113cc4	netdev_warn
++EXPORT_SYMBOL vmlinux 0xd027686c	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xd034105f	lockref_put_return
++EXPORT_SYMBOL vmlinux 0xd04027ac	sock_init_data
++EXPORT_SYMBOL vmlinux 0xd04231a8	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0xd05d4469	eth_header
++EXPORT_SYMBOL vmlinux 0xd06b0a7b	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd098a0b9	skb_unlink
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0aa10bf	simple_write_end
++EXPORT_SYMBOL vmlinux 0xd0c16e94	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0xd0c6c003	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0xd0e89915	down_read
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd100acbd	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0xd1067ba7	dispc_ovl_enabled
++EXPORT_SYMBOL vmlinux 0xd12ec037	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0xd1386c40	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0xd1457d96	down_write_trylock
++EXPORT_SYMBOL vmlinux 0xd14c79f2	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0xd15e10da	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd162c0b5	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0xd18151d8	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd196c9be	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xd19cbd4b	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0xd1ad8d4e	component_match_add
++EXPORT_SYMBOL vmlinux 0xd1b7d071	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0xd1bd096a	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0xd1c84dfb	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1e79cae	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0xd1eefc34	request_key_async
++EXPORT_SYMBOL vmlinux 0xd22927e6	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xd23a26ab	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd2af138b	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xd2ce7792	thaw_super
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd3024bad	default_llseek
++EXPORT_SYMBOL vmlinux 0xd306d1f9	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0xd30edd9c	da903x_query_status
++EXPORT_SYMBOL vmlinux 0xd3124827	mount_subtree
++EXPORT_SYMBOL vmlinux 0xd31ccb06	of_machine_is_compatible
++EXPORT_SYMBOL vmlinux 0xd329396f	d_find_alias
++EXPORT_SYMBOL vmlinux 0xd33be7de	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0xd347ed52	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0xd3890326	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0xd39bbe44	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0xd39fc2d6	snd_jack_report
++EXPORT_SYMBOL vmlinux 0xd3aa88df	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0xd3ac7d68	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0xd3b3dcac	param_set_long
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3c2c139	param_set_invbool
++EXPORT_SYMBOL vmlinux 0xd3c89906	vfs_writef
++EXPORT_SYMBOL vmlinux 0xd3dab093	__kernel_write
++EXPORT_SYMBOL vmlinux 0xd3dbfbc4	_find_first_zero_bit_le
++EXPORT_SYMBOL vmlinux 0xd3e6f60d	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0xd3e7d88f	xfrm_input
++EXPORT_SYMBOL vmlinux 0xd3f5be1f	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0xd4026b1e	ata_print_version
++EXPORT_SYMBOL vmlinux 0xd4126781	km_state_expired
++EXPORT_SYMBOL vmlinux 0xd42936e7	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0xd43954f1	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0xd460aec4	map_destroy
++EXPORT_SYMBOL vmlinux 0xd4669fad	complete
++EXPORT_SYMBOL vmlinux 0xd46fdfba	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0xd488d8c1	of_device_is_available
++EXPORT_SYMBOL vmlinux 0xd48ce7a6	arp_create
++EXPORT_SYMBOL vmlinux 0xd49a7cd8	misc_register
++EXPORT_SYMBOL vmlinux 0xd4db3a01	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0xd4e806d4	vfs_writev
++EXPORT_SYMBOL vmlinux 0xd5096b94	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0xd50ed405	posix_test_lock
++EXPORT_SYMBOL vmlinux 0xd51b17d4	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd553f4bd	padata_free
++EXPORT_SYMBOL vmlinux 0xd55a5b39	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0xd55aa540	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0xd5642412	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0xd56433a2	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0xd56f00bf	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd5f3f31f	cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0xd5f52d4f	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0xd5fa2f8d	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0xd61347c6	register_sysctl
++EXPORT_SYMBOL vmlinux 0xd614b1e8	bh_submit_read
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd626ac3f	snd_card_file_remove
++EXPORT_SYMBOL vmlinux 0xd627480b	strncat
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd62cbf16	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0xd648c9d1	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd66a2e73	add_disk
++EXPORT_SYMBOL vmlinux 0xd66ec4e9	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0xd6885771	dump_page
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd6c46ee8	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd6efc9c3	iterate_fd
++EXPORT_SYMBOL vmlinux 0xd6f2b8f7	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0xd71fd77a	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0xd74289f9	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0xd74ce039	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0xd7597ae2	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd76126bf	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0xd778ef26	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0xd797b9a5	vme_master_write
++EXPORT_SYMBOL vmlinux 0xd7a53e4d	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0xd7af91cf	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd806bec6	blk_end_request
++EXPORT_SYMBOL vmlinux 0xd8179d10	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0xd81a9727	led_blink_set
++EXPORT_SYMBOL vmlinux 0xd81bd33b	inet6_protos
++EXPORT_SYMBOL vmlinux 0xd82cc29d	napi_get_frags
++EXPORT_SYMBOL vmlinux 0xd8337ce8	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0xd85833cb	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0xd85cd67e	__wake_up
++EXPORT_SYMBOL vmlinux 0xd8677ea0	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0xd86ab8e7	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0xd88144e0	vme_master_request
++EXPORT_SYMBOL vmlinux 0xd88660c4	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8b8ed8f	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0xd8bf0c07	register_quota_format
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd90e6640	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0xd93b2e8b	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0xd93f1e06	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0xd955d2b7	omap_set_dma_dest_data_pack
++EXPORT_SYMBOL vmlinux 0xd970cf25	vga_tryget
++EXPORT_SYMBOL vmlinux 0xd97edd47	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd99f836e	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0xd9b43765	inode_init_always
++EXPORT_SYMBOL vmlinux 0xd9b7134d	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xd9c297fe	ping_prot
++EXPORT_SYMBOL vmlinux 0xd9cc7727	security_path_unlink
++EXPORT_SYMBOL vmlinux 0xd9ce8f0c	strnlen
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9defa97	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0xd9e432c3	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0xd9e59b9f	netdev_printk
++EXPORT_SYMBOL vmlinux 0xd9f492bf	put_tty_driver
++EXPORT_SYMBOL vmlinux 0xd9ff3951	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0xda0f4024	kern_path
++EXPORT_SYMBOL vmlinux 0xda1e3685	param_set_byte
++EXPORT_SYMBOL vmlinux 0xda34e484	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda3da3d2	send_sig
++EXPORT_SYMBOL vmlinux 0xda4f0f3f	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0xda5332ef	vfs_link
++EXPORT_SYMBOL vmlinux 0xda61eed3	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0xda66260b	blkdev_put
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda89aa6f	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xdaa57ec3	totalhigh_pages
++EXPORT_SYMBOL vmlinux 0xdaafc807	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0xdac08516	pci_map_rom
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdad97f94	__raw_writesw
++EXPORT_SYMBOL vmlinux 0xdb0787c3	commit_creds
++EXPORT_SYMBOL vmlinux 0xdb0e855b	serio_reconnect
++EXPORT_SYMBOL vmlinux 0xdb304974	dst_alloc
++EXPORT_SYMBOL vmlinux 0xdb4292e4	omap_set_dma_params
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb7305a1	__stack_chk_fail
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb8113c1	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0xdb8b9dcb	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0xdb93b838	dispc_free_irq
++EXPORT_SYMBOL vmlinux 0xdbc5dbc6	contig_page_data
++EXPORT_SYMBOL vmlinux 0xdbcaace3	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0xdbd1f9bf	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0xdbf54142	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0xdbf83a9e	should_remove_suid
++EXPORT_SYMBOL vmlinux 0xdc002c70	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc196d38	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0xdc32f31c	__seq_open_private
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc484109	posix_lock_file
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdc5c6297	videomode_to_omap_video_timings
++EXPORT_SYMBOL vmlinux 0xdc5e6c14	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0xdc774661	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0xdc834296	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0xdc893f8f	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xdc8ac759	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0xdc90ae4f	dput
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdcd45758	of_graph_parse_endpoint
++EXPORT_SYMBOL vmlinux 0xdcd6c344	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0xdcdbf598	snd_info_create_module_entry
++EXPORT_SYMBOL vmlinux 0xdce5ad15	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0xdcf0a875	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0xdd02fe85	register_sound_special_device
++EXPORT_SYMBOL vmlinux 0xdd08e288	vfs_setpos
++EXPORT_SYMBOL vmlinux 0xdd0a2ba2	strlcat
++EXPORT_SYMBOL vmlinux 0xdd0bb98e	nvdimm_revalidate_disk
++EXPORT_SYMBOL vmlinux 0xdd226fa9	__raw_readsw
++EXPORT_SYMBOL vmlinux 0xdd27fa87	memchr
++EXPORT_SYMBOL vmlinux 0xdd3916ac	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xdd3e3589	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0xdd568d29	tty_mutex
++EXPORT_SYMBOL vmlinux 0xdd5c21d3	ppp_input_error
++EXPORT_SYMBOL vmlinux 0xdd62775f	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0xdd7f16d4	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0xdd89e52c	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0xdd93e364	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0xdde58228	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0xde0640fb	register_sound_mixer
++EXPORT_SYMBOL vmlinux 0xde1243bd	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0xde1e63bb	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0xde3c8b21	dev_alert
++EXPORT_SYMBOL vmlinux 0xde474aaf	param_get_string
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xdeaa0951	iov_iter_init
++EXPORT_SYMBOL vmlinux 0xdec030e5	arm_clear_user
++EXPORT_SYMBOL vmlinux 0xdecddb0e	unlock_buffer
++EXPORT_SYMBOL vmlinux 0xded931f3	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0xdede3c8c	check_disk_change
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf2fdae4	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0xdf3a693d	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf6fc8cd	wake_up_process
++EXPORT_SYMBOL vmlinux 0xdf750763	amba_device_register
++EXPORT_SYMBOL vmlinux 0xdf770622	nand_bch_init
++EXPORT_SYMBOL vmlinux 0xdf796a46	unregister_mtd_chip_driver
++EXPORT_SYMBOL vmlinux 0xdf7cd4d0	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0xdf905788	udp_prot
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdf93b9d8	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0xdf9ff5ec	dev_close
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xdfd91ce9	omap_type
++EXPORT_SYMBOL vmlinux 0xdfdab9c4	shdma_init
++EXPORT_SYMBOL vmlinux 0xdff06d61	irq_to_desc
++EXPORT_SYMBOL vmlinux 0xdff0f276	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xdffbb293	napi_disable
++EXPORT_SYMBOL vmlinux 0xe0107c62	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0xe03937b6	kill_anon_super
++EXPORT_SYMBOL vmlinux 0xe03d8062	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe091617d	tty_port_close
++EXPORT_SYMBOL vmlinux 0xe09fd959	of_dev_get
++EXPORT_SYMBOL vmlinux 0xe0a2b23e	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0xe0a864c5	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0b52a5c	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0xe0bef318	icst_hz_to_vco
++EXPORT_SYMBOL vmlinux 0xe0fdfa50	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0xe1080d59	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xe111178d	set_bh_page
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe127fb18	down_killable
++EXPORT_SYMBOL vmlinux 0xe12f138b	pci_select_bars
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe14395ca	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xe16d258c	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0xe170836b	ihold
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe18b26e5	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0xe196778c	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0xe1d1f4d2	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0xe1f0ab3a	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xe1f6f65b	snd_pcm_release_substream
++EXPORT_SYMBOL vmlinux 0xe1fcb922	snd_seq_root
++EXPORT_SYMBOL vmlinux 0xe1fd1614	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe2028147	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0xe21669a7	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0xe21c4ba5	sock_wake_async
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe28d9065	module_layout
++EXPORT_SYMBOL vmlinux 0xe29523c8	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2b20144	__put_cred
++EXPORT_SYMBOL vmlinux 0xe2cc96f7	__do_once_done
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2d79074	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0xe2e09482	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0xe2e8065e	memdup_user
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe2fae716	kmemdup
++EXPORT_SYMBOL vmlinux 0xe330f7ec	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0xe33c91ee	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xe33ea462	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0xe344b915	release_firmware
++EXPORT_SYMBOL vmlinux 0xe36c41e4	__netif_schedule
++EXPORT_SYMBOL vmlinux 0xe37d10ae	omap_dispc_unregister_isr
++EXPORT_SYMBOL vmlinux 0xe3b45e27	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0xe3b8bfeb	fb_get_mode
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3f14a3c	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xe40e46a6	init_buffer
++EXPORT_SYMBOL vmlinux 0xe413be4a	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0xe4185865	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0xe430d6fd	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0xe43274bc	proc_dointvec
++EXPORT_SYMBOL vmlinux 0xe44ad011	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0xe44bc265	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0xe47815d4	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xe4989987	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0xe4a3b23b	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0xe4b918ea	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0xe4c80097	cacheid
++EXPORT_SYMBOL vmlinux 0xe4de10c6	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe4f40948	ata_link_printk
++EXPORT_SYMBOL vmlinux 0xe503547b	revalidate_disk
++EXPORT_SYMBOL vmlinux 0xe5040aed	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe55f5ab6	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL vmlinux 0xe56f096a	d_alloc_name
++EXPORT_SYMBOL vmlinux 0xe571e0a5	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe57e2ddd	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe588c552	param_set_charp
++EXPORT_SYMBOL vmlinux 0xe598d9e4	snd_timer_resolution
++EXPORT_SYMBOL vmlinux 0xe5b08d8d	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0xe5b18759	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0xe5b5bce9	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5d7012f	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0xe5ddebdd	security_path_rename
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe601c36a	from_kgid
++EXPORT_SYMBOL vmlinux 0xe62f0e4a	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0xe6375555	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0xe64686ad	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0xe64f2dfe	dump_align
++EXPORT_SYMBOL vmlinux 0xe654def3	__ps2_command
++EXPORT_SYMBOL vmlinux 0xe663cfc8	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0xe66452ab	dql_init
++EXPORT_SYMBOL vmlinux 0xe693a6ce	vme_get_size
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe6a61bd7	tcp_child_process
++EXPORT_SYMBOL vmlinux 0xe6a7ccea	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xe6b826b5	snd_card_file_add
++EXPORT_SYMBOL vmlinux 0xe6bb929e	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0xe6e25aed	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0xe6ebc016	key_create_or_update
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe7075b97	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0xe707d823	__aeabi_uidiv
++EXPORT_SYMBOL vmlinux 0xe70a9854	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0xe74b4b4f	__sock_create
++EXPORT_SYMBOL vmlinux 0xe78c5350	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xe78f3282	replace_mount_options
++EXPORT_SYMBOL vmlinux 0xe790afc3	omap_get_dma_dst_pos
++EXPORT_SYMBOL vmlinux 0xe79e8891	snd_cards
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7b4ce2a	dma_mark_declared_memory_occupied
++EXPORT_SYMBOL vmlinux 0xe7b6315e	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7dadef8	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0xe7e15910	dispc_clear_irqstatus
++EXPORT_SYMBOL vmlinux 0xe7e7d3a4	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0xe8159d25	msm_pinctrl_probe
++EXPORT_SYMBOL vmlinux 0xe81ef1dd	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe83f2b6c	km_new_mapping
++EXPORT_SYMBOL vmlinux 0xe85006cb	unregister_console
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe87b2edd	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0xe893a406	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8cfd00d	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0xe8eade0f	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0xe8ee5b14	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0xe8f4219d	blk_peek_request
++EXPORT_SYMBOL vmlinux 0xe903caf8	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0xe912da6b	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe91bfdd2	dcb_setapp
++EXPORT_SYMBOL vmlinux 0xe92798f9	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0xe9394405	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0xe93d5410	single_release
++EXPORT_SYMBOL vmlinux 0xe93f6042	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0xe94d62e2	snd_unregister_device
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe95993e6	tcp_poll
++EXPORT_SYMBOL vmlinux 0xe95e00cf	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0xe96e3eb4	nd_region_acquire_lane
++EXPORT_SYMBOL vmlinux 0xe9777f12	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0xe9937247	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xe997a31a	generic_writepages
++EXPORT_SYMBOL vmlinux 0xe998c829	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0xe99f2571	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0xe9bcd874	snd_timer_close
++EXPORT_SYMBOL vmlinux 0xe9be808d	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0xe9ea0ec4	of_device_is_compatible
++EXPORT_SYMBOL vmlinux 0xe9efe8b2	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea0c63bc	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0xea0c8ff9	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0xea0ce26b	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0xea183d7e	flow_cache_init
++EXPORT_SYMBOL vmlinux 0xea1f5b88	samsung_rev
++EXPORT_SYMBOL vmlinux 0xea25a405	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0xea53462b	nand_scan
++EXPORT_SYMBOL vmlinux 0xea688c30	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL vmlinux 0xea68d8ad	bdi_init
++EXPORT_SYMBOL vmlinux 0xea71cca7	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0xea795ca0	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0xea7987f1	key_update
++EXPORT_SYMBOL vmlinux 0xea7a42f9	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xea8f26d1	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0xea9b5c30	simple_setattr
++EXPORT_SYMBOL vmlinux 0xeaa0484b	nd_region_release_lane
++EXPORT_SYMBOL vmlinux 0xeaa6d547	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0xeab1a412	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0xeab7e688	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0xeac70185	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0xeae36619	of_device_register
++EXPORT_SYMBOL vmlinux 0xeb03b389	__raw_readsl
++EXPORT_SYMBOL vmlinux 0xeb04f028	register_netdev
++EXPORT_SYMBOL vmlinux 0xeb0f7772	md_check_recovery
++EXPORT_SYMBOL vmlinux 0xeb1b120e	omap_set_dma_write_mode
++EXPORT_SYMBOL vmlinux 0xeb28d843	generic_write_checks
++EXPORT_SYMBOL vmlinux 0xeb2b5b84	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb53d554	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0xeb55a931	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xeb57624d	get_cached_acl
++EXPORT_SYMBOL vmlinux 0xeb629cb7	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0xeb8911f7	udp_disconnect
++EXPORT_SYMBOL vmlinux 0xeb976574	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0xebaef709	km_policy_expired
++EXPORT_SYMBOL vmlinux 0xebaf3dac	phy_driver_register
++EXPORT_SYMBOL vmlinux 0xebb5da48	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0xebba78a7	dst_release
++EXPORT_SYMBOL vmlinux 0xebbd6ebf	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0xebbf17c8	udp_poll
++EXPORT_SYMBOL vmlinux 0xebd496fb	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xebfdcbdf	system_serial_high
++EXPORT_SYMBOL vmlinux 0xec028009	dev_notice
++EXPORT_SYMBOL vmlinux 0xec1aa6ef	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xec27715b	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0xec3f9467	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec539f72	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0xec561258	kmap_atomic
++EXPORT_SYMBOL vmlinux 0xec6070ed	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0xec8554a0	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0xec90532a	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0xeca85d90	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0xecaaafa3	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0xecb4c67d	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0xecbcb8bb	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xeccee364	dev_trans_start
++EXPORT_SYMBOL vmlinux 0xecdb434f	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xeceff434	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0xecf8a3b4	__raw_writesl
++EXPORT_SYMBOL vmlinux 0xed05ed59	register_sound_midi
++EXPORT_SYMBOL vmlinux 0xed09e4a4	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0xed16aa28	bdi_register
++EXPORT_SYMBOL vmlinux 0xed36088c	snd_pcm_hw_param_first
++EXPORT_SYMBOL vmlinux 0xed3c43ae	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0xed444aae	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed727140	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0xed78c9d9	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0xed9193b0	do_map_probe
++EXPORT_SYMBOL vmlinux 0xed93f29e	__kunmap_atomic
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedabd0c5	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedbc3d06	fd_install
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedc7f4ec	dq_data_lock
++EXPORT_SYMBOL vmlinux 0xedd0b943	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0xedd5befd	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0xedd9106d	__ashrdi3
++EXPORT_SYMBOL vmlinux 0xede7e8f0	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0xedebe02f	no_llseek
++EXPORT_SYMBOL vmlinux 0xedec3213	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xedfcd4b0	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0xee0d4459	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0xee2bc2d0	omapdss_is_initialized
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee3ab8e8	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0xee6a908f	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0xee6c6dc4	pmem_should_map_pages
++EXPORT_SYMBOL vmlinux 0xee6fe3c3	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0xee715ef8	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0xee8c4ddd	of_mm_gpiochip_add
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xee93f42c	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0xee9c3647	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0xee9cf5bf	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0xee9fa53e	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeed3635b	proc_dostring
++EXPORT_SYMBOL vmlinux 0xeed54710	pci_match_id
++EXPORT_SYMBOL vmlinux 0xeee44490	module_refcount
++EXPORT_SYMBOL vmlinux 0xeeeb6041	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xeef670ef	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0xef04c0d3	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0xef0a7fa8	is_nvdimm_bus_locked
++EXPORT_SYMBOL vmlinux 0xef0f3eb3	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0xef2a5879	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0xef2fdc4f	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0xef458a8c	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0xef4bff9c	scsi_register
++EXPORT_SYMBOL vmlinux 0xef4de22b	of_find_node_by_phandle
++EXPORT_SYMBOL vmlinux 0xef61c155	bio_put
++EXPORT_SYMBOL vmlinux 0xef658b5f	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0xef6ccdd3	clk_add_alias
++EXPORT_SYMBOL vmlinux 0xef6e13bf	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0xef70b445	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0xef79f7f9	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL vmlinux 0xef8c1bde	noop_qdisc
++EXPORT_SYMBOL vmlinux 0xefcf3143	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefd17c8d	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0xefd1b950	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0xefd6cf06	__aeabi_unwind_cpp_pr0
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefe56b3c	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0xefe64a2b	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0xefec312f	omap_get_dma_active_status
++EXPORT_SYMBOL vmlinux 0xeffc883f	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf00813be	arp_send
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf0260fae	i2c_transfer
++EXPORT_SYMBOL vmlinux 0xf05e193e	scsi_device_get
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf0650d9e	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0xf06c303c	omap_video_timings_to_videomode
++EXPORT_SYMBOL vmlinux 0xf07b9cab	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf096adf0	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0xf09a31d8	dquot_commit
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0aa53cd	nobh_writepage
++EXPORT_SYMBOL vmlinux 0xf0c0cf01	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0xf0ccfc86	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0xf0d6deb6	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0xf0ed2ef4	__raw_writesb
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf104e7dc	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf140bcac	dev_addr_add
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf14cdca1	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0xf1523228	d_alloc
++EXPORT_SYMBOL vmlinux 0xf157dbe6	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0xf168f566	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0xf17afce5	vme_bus_num
++EXPORT_SYMBOL vmlinux 0xf18b9209	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0xf19165b5	user_path_create
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf198e4ff	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0xf19e9355	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0xf19f29d6	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0xf1a048cf	padata_start
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1deabf2	div64_u64
++EXPORT_SYMBOL vmlinux 0xf1df4714	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1ea6f1c	__bswapsi2
++EXPORT_SYMBOL vmlinux 0xf1f0905f	snd_pcm_set_ops
++EXPORT_SYMBOL vmlinux 0xf1f2dfcf	wireless_send_event
++EXPORT_SYMBOL vmlinux 0xf1fa13db	netif_rx
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf216adeb	elv_rb_find
++EXPORT_SYMBOL vmlinux 0xf235f9f7	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf24c005c	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0xf259f01c	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0xf272c757	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0xf29492ca	uart_resume_port
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2ce4f7c	bdevname
++EXPORT_SYMBOL vmlinux 0xf2d999e9	sock_create
++EXPORT_SYMBOL vmlinux 0xf2dd40ba	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0xf30c6ac2	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf3229baf	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0xf33963bc	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf35a14b5	dma_release_from_coherent
++EXPORT_SYMBOL vmlinux 0xf36ea43b	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0xf3798ec9	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0xf386ba7e	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf3902b6a	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf40b2297	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xf43a6f0d	pipe_unlock
++EXPORT_SYMBOL vmlinux 0xf455ac0b	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0xf4628d12	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0xf473ffaf	down
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf482ffc4	follow_down
++EXPORT_SYMBOL vmlinux 0xf49194e6	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0xf4a2d0ad	dss_mgr_enable
++EXPORT_SYMBOL vmlinux 0xf4a7fc6d	omapdss_compat_init
++EXPORT_SYMBOL vmlinux 0xf4bd8710	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4c81fb0	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0xf4e103bb	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xf4e3da52	tty_do_resize
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf4fb5402	skb_dequeue
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf5514ce0	ioremap_page
++EXPORT_SYMBOL vmlinux 0xf5555a33	blk_complete_request
++EXPORT_SYMBOL vmlinux 0xf55fcdc8	of_translate_dma_address
++EXPORT_SYMBOL vmlinux 0xf564412a	__aeabi_ulcmp
++EXPORT_SYMBOL vmlinux 0xf580219e	snd_info_create_card_entry
++EXPORT_SYMBOL vmlinux 0xf58737b0	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL vmlinux 0xf5ab9f43	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0xf5c12280	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5e2b7c2	__invalidate_device
++EXPORT_SYMBOL vmlinux 0xf5eaf63a	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf6048cac	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf6625d94	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0xf669c8e8	block_commit_write
++EXPORT_SYMBOL vmlinux 0xf6706110	have_submounts
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf681dba2	netdev_err
++EXPORT_SYMBOL vmlinux 0xf6824a2c	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf6851d5f	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf68d56b1	fb_class
++EXPORT_SYMBOL vmlinux 0xf6922c6b	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0xf6b9dbdf	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6bb76b4	param_get_ullong
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf7019bc0	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0xf703a3c1	pci_get_device
++EXPORT_SYMBOL vmlinux 0xf7163ec9	__raw_readsb
++EXPORT_SYMBOL vmlinux 0xf737dd90	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xf7457f21	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0xf750e80e	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf7802486	__aeabi_uidivmod
++EXPORT_SYMBOL vmlinux 0xf788b424	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL vmlinux 0xf78e6145	vme_register_driver
++EXPORT_SYMBOL vmlinux 0xf7a6f10a	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0xf7aaeddc	ida_init
++EXPORT_SYMBOL vmlinux 0xf7ab6a71	key_invalidate
++EXPORT_SYMBOL vmlinux 0xf7c31d81	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0xf7dd6757	input_unregister_device
++EXPORT_SYMBOL vmlinux 0xf7e7ea73	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0xf80a8478	kunmap_high
++EXPORT_SYMBOL vmlinux 0xf80d1fa5	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf81c1156	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf84d5287	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0xf866273f	pci_disable_device
++EXPORT_SYMBOL vmlinux 0xf867de35	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0xf8722dac	kill_block_super
++EXPORT_SYMBOL vmlinux 0xf875a1ac	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0xf8963589	get_acl
++EXPORT_SYMBOL vmlinux 0xf8972e2e	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0xf8aa734c	update_devfreq
++EXPORT_SYMBOL vmlinux 0xf8b3c8ed	proc_set_user
++EXPORT_SYMBOL vmlinux 0xf8b4b821	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0xf8d0da44	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0xf8d5d9c7	done_path_create
++EXPORT_SYMBOL vmlinux 0xf8e179b3	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf8fcd74f	skb_pad
++EXPORT_SYMBOL vmlinux 0xf92ba0e6	of_clk_get
++EXPORT_SYMBOL vmlinux 0xf92e1d51	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0xf9348cbc	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xf9427374	dispc_request_irq
++EXPORT_SYMBOL vmlinux 0xf95e92d5	set_device_ro
++EXPORT_SYMBOL vmlinux 0xf964b8c3	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0xf97003f7	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0xf97b05e6	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0xf9882318	nf_register_hook
++EXPORT_SYMBOL vmlinux 0xf98c034e	inet_ioctl
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9a5fe1e	dquot_transfer
++EXPORT_SYMBOL vmlinux 0xf9cd560e	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0xf9dcf156	of_translate_address
++EXPORT_SYMBOL vmlinux 0xf9df5ecf	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0xf9e324e1	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0xf9e4111e	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0xf9e73082	scnprintf
++EXPORT_SYMBOL vmlinux 0xf9eae00c	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0xf9eb94b3	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0xf9f0756b	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0xfa0169a7	bdgrab
++EXPORT_SYMBOL vmlinux 0xfa1de769	amba_release_regions
++EXPORT_SYMBOL vmlinux 0xfa50f39f	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa58b7f1	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa69051b	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0xfa7d98bf	sk_free
++EXPORT_SYMBOL vmlinux 0xfa8154a0	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0xfa843bd8	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0xfa8f778a	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0xfaaf5e42	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0xfaba059f	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0xfac68eba	arm_elf_read_implies_exec
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfaca1d3a	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xfad29923	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xfad5f8eb	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0xfae067d8	of_phy_register_fixed_link
++EXPORT_SYMBOL vmlinux 0xfae5394b	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfae685c0	current_fs_time
++EXPORT_SYMBOL vmlinux 0xfafae409	path_noexec
++EXPORT_SYMBOL vmlinux 0xfb0eb2fd	of_count_phandle_with_args
++EXPORT_SYMBOL vmlinux 0xfb200cca	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0xfb25965b	bio_flush_dcache_pages
++EXPORT_SYMBOL vmlinux 0xfb33af01	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0xfb3775de	security_file_permission
++EXPORT_SYMBOL vmlinux 0xfb3d2dd8	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0xfb48063e	netif_napi_add
++EXPORT_SYMBOL vmlinux 0xfb5175a4	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0xfb5edd68	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb7d0744	block_write_full_page
++EXPORT_SYMBOL vmlinux 0xfb7d9c45	__udivsi3
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfb9e46e8	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbb61e48	neigh_for_each
++EXPORT_SYMBOL vmlinux 0xfbc07c50	brioctl_set
++EXPORT_SYMBOL vmlinux 0xfbc48073	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbd51901	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0xfbe9a40b	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc1b00e6	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xfc2914e7	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0xfc3908f5	fence_default_wait
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc4ce4b6	param_get_short
++EXPORT_SYMBOL vmlinux 0xfc65459a	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0xfc84689d	simple_empty
++EXPORT_SYMBOL vmlinux 0xfc86d58b	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0xfc8891bf	clkdev_add
++EXPORT_SYMBOL vmlinux 0xfc8e0c64	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0xfc9f4245	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0xfcb7ca60	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfccd36bb	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0xfcd8ebe0	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfce35ac6	inet_sendpage
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfceda2b4	md_update_sb
++EXPORT_SYMBOL vmlinux 0xfcee192b	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfd0d5f12	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0xfd2e04aa	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0xfd305341	walk_stackframe
++EXPORT_SYMBOL vmlinux 0xfd33b5fa	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xfd35208c	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0xfd5513c5	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0xfd5683b9	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0xfd5cce86	lro_flush_all
++EXPORT_SYMBOL vmlinux 0xfd7e4df9	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0xfd84714e	snd_pcm_lib_writev
++EXPORT_SYMBOL vmlinux 0xfd8930ef	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0xfd93950b	__scm_destroy
++EXPORT_SYMBOL vmlinux 0xfd9496a5	poll_initwait
++EXPORT_SYMBOL vmlinux 0xfd96b585	shdma_chan_remove
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfd9e64e3	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL vmlinux 0xfdb6c749	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfdf1f67a	of_find_device_by_node
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfdfd7247	led_update_brightness
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe068775	generic_write_end
++EXPORT_SYMBOL vmlinux 0xfe18e877	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0xfe2ec36d	dup_iter
++EXPORT_SYMBOL vmlinux 0xfe351e05	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0xfe358811	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0xfe360d17	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0xfe40bf95	dss_feat_get_num_ovls
++EXPORT_SYMBOL vmlinux 0xfe420d36	release_pages
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe7309e7	bdget
++EXPORT_SYMBOL vmlinux 0xfe761859	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfea1885f	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0xfeb6b7fe	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0xfec77b76	lock_rename
++EXPORT_SYMBOL vmlinux 0xfeca7590	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0xfedbf606	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfef14027	sk_alloc
++EXPORT_SYMBOL vmlinux 0xff0abf20	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0xff1da463	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff2782bc	scsi_host_get
++EXPORT_SYMBOL vmlinux 0xff30161a	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL vmlinux 0xff67b37f	__lshrdi3
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff86a271	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0xff8cbb1f	idr_destroy
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff990761	__break_lease
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffa662e7	nvm_end_io
++EXPORT_SYMBOL vmlinux 0xffb03f58	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0xffb94ef0	_test_and_change_bit
++EXPORT_SYMBOL vmlinux 0xffcfd8d3	udp_seq_open
++EXPORT_SYMBOL vmlinux 0xffd2cf99	omap_dss_get_num_overlay_managers
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffdc9569	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0xffe00352	file_ns_capable
++EXPORT_SYMBOL vmlinux 0xffec6dac	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0xfff5da14	sg_miter_next
++EXPORT_SYMBOL_GPL arch/arm/crypto/sha1-arm 0x66525dc1	sha1_finup_arm
++EXPORT_SYMBOL_GPL arch/arm/crypto/sha1-arm 0x72777368	sha1_update_arm
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x5de7d640	ablk_set_key
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x877fe714	ablk_decrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x9457b186	__ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xc0310729	ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xcb52a733	ablk_init_common
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xf95b88f7	ablk_init
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xffa88a99	ablk_exit
++EXPORT_SYMBOL_GPL crypto/af_alg 0x175fbe40	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x369d70fc	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x4fbb4541	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0x753beb71	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xa09ba38a	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xc20d474a	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0xc73e7325	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xd954ef95	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0xdb8d2b7e	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0xe1e86f8d	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0xf5aea419	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0xed573b30	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x15a0336a	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0xd13190d3	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x5c7a4c71	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x9d9d4f2f	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x030479c5	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x21ead2ca	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x87f71546	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x9c54d3c0	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0xa8a3f822	async_xor
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0xaf11d5ee	async_xor_val
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x64ba4238	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x00652074	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x4079b02c	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x141f8d18	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0xb9f652dc	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/cryptd 0x069b26cf	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x198e667d	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x62b2f760	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x69a0b2dc	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x818b0c3d	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x979215dd	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xa9ff6c6d	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xb15316df	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xd92d8a11	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xf55125d9	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0x5a1a070d	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x11f2babc	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x14bdd4d3	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x87a47ecd	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x91a29f62	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x9346eccb	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xa6c44f09	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xc6d8a87f	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xec23e0b8	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xed87163b	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x8f5a6fa6	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xb7d692cc	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xcee7e8a5	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xe36cfda6	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0xace9eae0	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x1664e339	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0xd0eb640f	xts_crypt
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0x6a2d37b0	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/ata/pata_sis 0x1153b921	sis_info133_for_sata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x4e205dc3	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x88f07c1a	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xa9ea0a8b	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xfa8a3314	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x06f656fc	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x0fff66de	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x103b95d2	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x281da6c1	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x2ee80fb6	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x4698c640	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x4924b03f	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x4fd81759	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x51ae3564	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x57a5eee8	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x5c81345e	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x67c56d13	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6afee484	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x99f35fdc	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x9ef3a7f2	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xa1a81363	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xac695fee	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xba97743d	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe82efa2b	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xec13776a	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xee818be4	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf2639694	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf4712074	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xfb0db692	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x05902cf3	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x63c5d9b9	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x6feec3f5	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x934f709b	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xa39ab178	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xb877c1d1	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x07c36969	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x23e33e88	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x3afbaaba	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x3b3aceeb	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x5c6d0447	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x8f62cee7	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xa426e06e	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xac089a80	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xcc3be41f	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xe01668db	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xeff5df49	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xf62d5489	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x0180159f	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x05b24ebf	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x06bceeb6	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x26316e62	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x4ffce4ea	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x5225ed88	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x68200ad8	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x837d07ff	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xb7b99507	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xeace36b9	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xfd1be0a3	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x05bf361b	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x23f701a3	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0xda713cd3	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0xa935b128	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x02373dca	clk_enable_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x0d76ccee	qcom_find_src_index
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x198af31b	qcom_cc_map
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x1ad28e9c	clk_rcg_bypass_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x1f4159b0	clk_byte2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x2c4a90cc	clk_is_enabled_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x3b0b58e5	clk_regmap_mux_closest_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x53f95e39	clk_pll_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x5d9c3e35	devm_clk_register_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x6012c0c9	qcom_cc_probe
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x612214bd	clk_edp_pixel_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x669bd1fd	qcom_find_freq
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x67ae803a	clk_rcg_pixel_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x709d9cf0	clk_pll_configure_sr
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x73964fc2	clk_dyn_rcg_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x77c457fa	qcom_reset_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x8c4dbdbe	clk_branch_simple_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x8d53d96e	clk_rcg_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x90b53166	clk_pll_configure_sr_hpm_lp
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x999e1e71	clk_branch2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x99d2c773	clk_rcg2_shared_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0x9e2e91a1	clk_rcg_bypass2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xa1606e61	clk_disable_regmap
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xaace56b1	clk_rcg_esc_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xc7994798	clk_branch_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xcb0c5248	clk_byte_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xcd0a83c6	clk_rcg2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xd25fd154	clk_rcg_lcc_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xe703bcad	clk_pll_vote_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xf1f136dc	clk_pixel_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xf69c2f55	clk_pll_sr2_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xf93e315f	clk_regmap_div_ops
++EXPORT_SYMBOL_GPL drivers/clk/qcom/clk-qcom 0xfd519b5e	qcom_cc_really_probe
++EXPORT_SYMBOL_GPL drivers/cpufreq/arm_big_little 0x2f7dab4b	bL_cpufreq_register
++EXPORT_SYMBOL_GPL drivers/cpufreq/arm_big_little 0xeb81b998	bL_cpufreq_unregister
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x1dbe6af1	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x51e4cf97	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xc678a47e	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xc98a3abc	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xdce3690a	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x22b6c7af	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x519d5efc	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x64746a03	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0382550d	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0af17ad7	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x1048d799	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x251c1b5e	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x264e8a46	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x39b3123c	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4328c374	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4bd5e851	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6189707f	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x713007cd	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x76045014	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x8c532a5f	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x8f2cbf03	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x945b3630	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa1507e15	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xaf8bbde1	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb12fbf2f	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc29ad514	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xca7df20d	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd21263ba	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe1f31cb5	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe74adbeb	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf62f5b24	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/firmware/arm_scpi 0xe342fbf5	get_scpi_ops
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x06d6d525	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x1feb0af0	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x380b8f7a	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xa5f10091	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xb79df05f	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xd2964c7b	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x6b3d628b	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0xa9fe6d0b	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpu/drm/bridge/dw_hdmi 0x3ff6a321	dw_hdmi_bind
++EXPORT_SYMBOL_GPL drivers/gpu/drm/bridge/dw_hdmi 0x8dcd6f43	dw_hdmi_set_sample_rate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/bridge/dw_hdmi 0xce27012a	dw_hdmi_audio_disable
++EXPORT_SYMBOL_GPL drivers/gpu/drm/bridge/dw_hdmi 0xd8fe547b	dw_hdmi_audio_enable
++EXPORT_SYMBOL_GPL drivers/gpu/drm/bridge/dw_hdmi 0xe6090181	dw_hdmi_unbind
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x07dcb6e6	drm_gem_cma_vm_ops
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x0a5f5bf3	drm_gem_cma_free_object
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x13948658	drm_gem_cma_prime_import_sg_table
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x36b7ba9b	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x453b20fb	drm_gem_cma_dumb_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x57d8a8f2	drm_gem_cma_describe
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x7484870c	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x7eac1fbb	drm_gem_cma_dumb_map_offset
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xa6066bc7	of_get_drm_display_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xb00d88af	drm_gem_cma_prime_get_sg_table
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xb14084fe	drm_gem_cma_prime_vmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xc8399f5d	drm_gem_cma_prime_mmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xcc5e130f	drm_display_mode_to_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xd558e400	drm_gem_cma_dumb_create_internal
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xd942d304	drm_gem_cma_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xe1426a6c	drm_display_mode_from_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xe64d4734	drm_gem_cma_mmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xee30e0d0	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xf232c895	drm_gem_cma_prime_vunmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x1148b623	drm_fbdev_cma_fini
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x3eda4204	drm_fb_cma_get_gem_obj
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x976aa177	drm_fb_cma_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xac0dd2c2	drm_fbdev_cma_init
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xb2c912af	drm_fbdev_cma_hotplug_event
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xcc337fd5	drm_fbdev_cma_restore_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xfd1c9bee	drm_fb_cma_debugfs_show
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x04a4053f	imx_drm_encoder_get_mux_id
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x1cfe024a	imx_drm_crtc_vblank_get
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x27076f8e	imx_drm_encoder_destroy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x37707c0a	imx_drm_crtc_id
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x419b08de	imx_drm_handle_vblank
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x562fae92	imx_drm_set_bus_format_pins
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x5f056ff0	imx_drm_crtc_vblank_put
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0x96ed503b	imx_drm_set_bus_format
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0xa952bbe4	imx_drm_connector_destroy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0xc75d6724	imx_drm_encoder_parse_of
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0xd652b5a4	imx_drm_remove_crtc
++EXPORT_SYMBOL_GPL drivers/gpu/drm/imx/imxdrm 0xf2f94003	imx_drm_add_crtc
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchip_drm_vop 0x5e01d76b	rockchip_drm_crtc_mode_config
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0x43717425	rockchip_unregister_crtc_funcs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0x5fa6fc31	rockchip_fb_get_gem_obj
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0x6e554eba	rockchip_register_crtc_funcs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0xa555830c	rockchip_drm_encoder_get_mux_id
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0xd98fe6fe	rockchip_drm_dma_detach_device
++EXPORT_SYMBOL_GPL drivers/gpu/drm/rockchip/rockchipdrm 0xdac6001a	rockchip_drm_dma_attach_device
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x34adda25	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x643be18d	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xeb982be7	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x04f7075a	ipu_csi_set_mipi_datatype
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x0728116a	ipu_csi_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x0ac62e4a	ipu_set_ic_src_mux
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x0e42bd95	ipu_csi_set_dest
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x1080007b	ipu_smfc_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x118160e1	ipu_ic_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x11d8f100	ipu_stride_to_bytes
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x13952dfe	ipu_dmfc_enable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x15ec2ba5	ipu_di_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x199bd5c8	ipu_dp_disable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x1b5f8907	ipu_cpmem_zero
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x1b7e59c2	ipu_idmac_wait_busy
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x1ba497eb	ipu_pixelformat_to_colorspace
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x1e913d9f	ipu_csi_get_window
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x2424c9a6	ipu_csi_is_interlaced
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x27c8cf7d	ipu_idmac_set_double_buffer
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x2d6f8248	ipu_srm_dp_sync_update
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x2f92d651	ipu_ic_task_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x2f9751b4	ipu_degrees_to_rot_mode
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3054923f	ipu_cpmem_set_format_rgb
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x30b6999c	ipu_rot_mode_to_degrees
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3166aec7	ipu_dmfc_disable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x348cb7db	ipu_cpmem_set_yuv_interleaved
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3afbb44e	ipu_smfc_set_watermark
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x3e86ea72	ipu_di_get_num
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x434e2dc8	ipu_dp_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x459eceb9	ipu_idmac_channel_irq
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x479a8eee	ipu_dc_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x47f6cfdb	ipu_idmac_select_buffer
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x4917f47a	ipu_ic_dump
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x4aba4f30	ipu_cpmem_set_yuv_planar
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x4c179b49	ipu_dp_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x4d7eaa07	ipu_csi_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x4fe217b8	ipu_cpmem_set_buffer
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x50de8670	ipu_ic_task_idma_init
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x51475e87	ipu_dmfc_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x5228880f	ipu_idmac_get_current_buffer
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x527f3b94	ipu_smfc_set_burstsize
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x53ddf3c5	ipu_module_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x53de277c	ipu_di_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x598f28f5	ipu_map_irq
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x5a3d39af	ipu_ic_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x5cf820a1	ipu_cpmem_set_yuv_planar_full
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x5f1cd674	ipu_cpmem_interlaced_scan
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x60bdf2ec	ipu_csi_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x61976f06	ipu_idmac_channel_busy
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x623722e2	ipu_ic_task_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x63573204	ipu_set_csi_src_mux
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x66cce6f2	ipu_cpmem_dump
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x66edf15e	ipu_dmfc_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x7068e939	ipu_dc_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x7121bd07	ipu_di_init_sync_panel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x7570d9ac	ipu_module_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x76302d14	ipu_csi_set_skip_smfc
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x78b355ca	ipu_cpmem_set_fmt
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x7c90c46b	ipu_dp_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x80f239e4	ipu_dp_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x8329bc3f	ipu_cpmem_set_rotation
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x886c35aa	ipu_smfc_map_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x894aa787	ipu_idmac_lock_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x9058e289	ipu_smfc_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x94860a6e	ipu_cpmem_set_burstsize
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x951a09d5	ipu_csi_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x9631866f	ipu_cpmem_set_stride
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x99a0ef07	ipu_drm_fourcc_to_colorspace
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x9c335d85	ipu_pixelformat_is_planar
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x9cf4e7af	ipu_dc_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0x9f38e177	ipu_dp_enable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa4b0cabd	ipu_dc_disable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa57770c9	ipu_cpmem_set_high_priority
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa579616b	ipu_di_adjust_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa60b144b	ipu_csi_set_window
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa802e8c8	ipu_idmac_disable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xa96882d8	ipu_ic_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xac27f55d	ipu_cpmem_set_image
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xadaafcfc	ipu_idmac_clear_buffer
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xb228bf1e	ipu_dp_set_global_alpha
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xb2ad16cf	ipu_dump
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xb51c726b	ipu_idmac_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xb55dbb1f	ipu_idmac_buffer_is_ready
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xb94ca95a	ipu_dmfc_init_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xbab82127	ipu_cpmem_set_block_mode
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xbf5bf882	ipu_idmac_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc21913c3	ipu_dc_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc3c2cdb0	ipu_smfc_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc6675aa9	ipu_csi_dump
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc677177d	ipu_smfc_enable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc848c5d7	ipu_dmfc_free_bandwidth
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc85f7809	ipu_cpmem_set_axi_id
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc88d89a1	ipu_mbus_code_to_colorspace
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xc97e7a0f	ipu_di_disable
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xcd7c6998	ipu_ic_task_init
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xd064a453	ipu_ic_task_graphics_init
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xd109dea9	ipu_idmac_enable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xd5055dd9	ipu_dmfc_alloc_bandwidth
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xd9d7e3b1	ipu_wait_interrupt
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xe300a959	ipu_dp_setup_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xe3b86336	ipu_csi_init_interface
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xe3bb174f	ipu_di_get
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xe5875274	ipu_cpmem_set_resolution
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xe6243c52	ipu_dc_enable_channel
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xeed4c54b	ipu_cpmem_set_format_passthrough
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xf1440dc1	ipu_ic_put
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xf69d6cb6	ipu_csi_set_test_generator
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xf7d99d69	ipu_dc_init_sync
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xf9ed222e	ipu_dp_set_window_pos
++EXPORT_SYMBOL_GPL drivers/gpu/ipu-v3/imx-ipu-v3 0xfab0d1ef	ipu_idmac_enable_watermark
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0c1a7be4	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x114b0471	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x162f3180	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x1d170480	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2514f6b2	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2bbd0fab	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2ed2c588	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x340e5715	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3668d550	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x40620148	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4b984fde	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x502d9f4e	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x559e4090	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x598ef64f	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5a0895c2	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5f05976a	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5f07d755	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x871e071b	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x877c0b95	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x87ddfc5d	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x884ee007	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x8ae5cbaf	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9bef9bf5	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa259d2e5	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xad346ada	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xaefce62e	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb25a9d36	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbd1063fa	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc0a15da2	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc997c994	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc9df7b19	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xced35836	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xdd098ad4	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xef9e0623	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf9e2b438	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfe1b1e78	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0xe3a0ad2a	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x7fd9e560	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x85ebbfc2	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x9b7984ff	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xcb9ace99	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xcf1f9eb2	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xe2fec2dc	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x02b473f5	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x1a8014ba	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x29e0c937	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x5d012201	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x8f47d98a	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xa22ce8b9	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xad8bbb27	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xf1146560	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xfeaf992d	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x7b6c25b5	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x0173e85b	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x0aac20c8	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x1f82b723	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x254b2b2a	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x30bd27c9	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x55f519b2	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x6cd03919	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x6fe020e4	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x830544f2	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x887ea15d	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa270ccbb	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa8a5a8d5	hsi_add_clients_from_dt
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xb40c525c	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xbf9adbf6	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xd0f58466	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf5ffec02	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf8994669	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xff8c3375	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x580ea9f9	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x888b0c55	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xe587c3fe	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x24f5167d	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x2637fe35	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x3929bd99	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x3f36b649	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x4c060ec3	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x4df7c7b3	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x5ca6f1db	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x618abf1b	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x6a8891f5	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x7d729e38	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x816bd3e8	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x9b4ab454	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xbcc01b65	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xc2a4ea92	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xc34d3a07	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x05efc4b0	__hwspin_unlock
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x2980b633	hwspin_lock_unregister
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x2b25678a	hwspin_lock_request_specific
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x3ef63923	hwspin_lock_register
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0x8da0ef5c	__hwspin_trylock
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0xa0e7d08e	__hwspin_lock_timeout
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0xa9569ba4	of_hwspin_lock_get_id
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0xc8ef2b4a	hwspin_lock_free
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0xd5f4f9c4	hwspin_lock_request
++EXPORT_SYMBOL_GPL drivers/hwspinlock/hwspinlock_core 0xeb611902	hwspin_lock_get_id
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x266da005	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x78cae62c	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xaad153af	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xab65cdcf	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xd9c3d410	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xdec60dc9	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xe5419c70	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x285a3c9a	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x3dec58d2	stm_source_write
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x7637a92e	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xad18b0bb	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xe83b83dc	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x11755c06	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x92719488	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xac4f65b1	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xdaf52c7e	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xdd1a5062	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x299d884a	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x30fd5653	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xabf2e45c	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xe3e8e9fa	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x1aa3283f	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x80b692b2	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xabe322ea	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x12a361c0	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x1a4e79a6	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x299a8de4	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x2c77b4e7	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x31758f82	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x3d67a0cf	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x4dc52bfb	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x526e7f54	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x5e4c6d1f	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x83e419ce	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x53eb6412	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0xd88981e6	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0x0f57e2fe	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xcb2903a6	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x9a8ec81c	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xc07d0dea	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xe068d316	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x314df1d8	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x3d7f7029	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x3f12f6a6	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x52e43962	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x917875d8	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x96147c4b	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x9e8db88c	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xa27abb73	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xa3f9a07f	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xa8fff6fc	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xce60b293	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xe630c01d	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x02576021	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x07de5366	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0e40187b	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x11909023	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x14532389	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x1d8f3ab0	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2a1dd232	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2d45c580	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3512728b	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x37795ec9	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x43fdf38f	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x44fd2418	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x485e61d9	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x513eb239	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6c5c92dc	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6cb018b9	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x723818c3	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x83fb6337	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9e908f61	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa5a9c429	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xaee275b7	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xafdad1a3	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb1a2cfb4	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb3abdd39	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xbec5954a	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc9594071	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe0426fcd	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe61caa1f	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe82744a0	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf0e39ae6	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf5a85729	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0xb8f8421a	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/matrix-keymap 0x702f3d0d	matrix_keypad_parse_of_params
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x7f127fc8	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xb64d24be	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xd3a76f5b	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xf7f6ff76	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x2b489d62	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xb62dc146	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xcdd3399a	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x0bb2ba8b	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x7fae0044	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x23008a77	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x2c5b9d92	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x6ded0a90	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xe8c862a2	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x2594782b	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x3c95d63b	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x5e0d76f4	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x6a3fff8f	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x79eb448a	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x7aa078af	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x8599402e	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x8f196b30	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x92a7766a	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xa63dd01b	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xadbb97af	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xb1201e1a	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x22ff6d7b	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x2e7104a5	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x4ecb3fd9	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x673359c5	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x6743d522	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x7db6d00a	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x85ef8076	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xa768f97b	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xdb4440a2	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x18fff6e3	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x19e67686	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x2a404070	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x543131a5	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x69e6cf19	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7975e536	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7b08457e	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7cdf2072	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8eff32df	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa77da4b4	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xaa67ee9d	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xb247c12c	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xb8c31ad6	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc2f6eb31	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc5a0835e	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xdf110b1b	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xec0a4133	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xf221b988	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x3a9dd8fa	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x77f4dac5	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xc7cb9433	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xcebbe806	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xd93416dc	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xfd3f0162	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x0961c7b1	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x0b0e2183	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x39f5ea1c	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x53250ed2	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x54d1b239	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x94237252	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x9eb249e8	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xa61a4766	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xc31f99e7	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xd473e2bd	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xf30be52c	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x082f165c	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x13e642ab	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x1867794e	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x23d461d1	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x7ee0facd	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x84ce3c87	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8bf52ac0	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xa798fa47	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xaf00c5ee	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xb77ce7fa	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xcaad87cb	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xe639e522	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xefd74e0d	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xfb70dac0	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x06628c2f	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x06b11706	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x07e2c777	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x0b1ed8cb	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1683a5f6	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x16c3fa29	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x16c8cc13	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x18d1988c	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2061620b	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x230dd380	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x29a4c5fd	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2b277945	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3ee17aab	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x402d6200	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x49c216ec	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5d1e9f82	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7930d50e	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7d597e2d	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8461608d	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x84e60671	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x92d61794	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x9415be3c	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xad2d4ca2	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb21fadc0	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb364194a	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbe406c76	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc72008a2	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd6d1aa5e	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfc24ee1e	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfcc8ed24	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xffd8c38e	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2a12429c	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2c7d956d	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x50219258	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x749b76f0	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x897b1e61	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xad3a0305	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xf108d89f	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xf3b21d9a	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xfc881628	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x22163b69	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x3909d3a8	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x594952bd	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x62a23587	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9b2b253a	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc8eae880	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xdc69e37a	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe004ee92	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x1380464b	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x2acb434a	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x3283eb33	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x63659ec8	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x68fa14c2	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x7e016c43	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xa35c1c66	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x43851616	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x83be5d3a	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x02e98da7	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x09472122	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x6a650a06	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x829af9f5	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x88b0335e	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa8813ad6	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe6bc9f5	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc1a79c27	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc66ce277	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xcab63c3d	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf37a3cfe	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x11eab9fe	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x150c85ce	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2e730a21	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x33c03da6	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5a8d7eec	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x619701dc	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9b4b5b29	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa2507774	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbcfdc290	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbe0497aa	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xead1e727	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x040220d6	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x2c627da1	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x369af8bb	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x90420366	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x9ae08a38	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xa4b4c8f1	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xb627673e	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xc00cc341	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xcfd16d7c	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe92ad8d7	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x253c73ba	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x3d6d7f20	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x67224181	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x6c584d68	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x74febc98	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xf36d4184	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xfc2b753d	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x04a4ad27	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x099f7930	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x120e9639	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x1f8a7160	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x235028be	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45b40c84	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x4b5047c4	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x4d9d9410	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x63222b29	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x6715d724	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x8ff8f485	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x991f6c19	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x99e963d7	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xb2355aa9	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xb4558450	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc195b731	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc75ce26f	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xeaa74d1e	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0xb2e291ce	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0x674363a6	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0x0bb577fe	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x089dc929	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0x0c156876	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x266a2a45	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x27ff7021	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0x287915ae	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x305096ae	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x350729eb	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x7f633bc3	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x91986c9b	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/media 0x92e427ac	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/media 0xa1dc19ff	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0xa8b99f6d	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0xb188949f	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/media 0xb766c828	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/media 0xcfcd9f08	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0xdd2b099c	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/media 0xe333f8e4	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0xf6c389a5	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0x543d8989	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x0235af37	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x1368e6ce	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x172323da	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x184d3eb3	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x2222e2ee	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x3536c9e0	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x43af07bd	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x581c7323	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x6bd8cea7	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x6d2e4587	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x7267eb1c	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x7566af31	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x75cc25ce	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x902f519a	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x99ef8084	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xaeece653	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb9f8cd5d	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xc3e2c3ef	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf285fd28	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x012a747d	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0a31565e	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0db7eca9	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x14450ca7	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x16c1f05b	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x3346ab81	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x3f063e40	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x67ad7370	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x6815ffa3	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x97a57768	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa1c41bdb	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xb7bfa097	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc22bdefd	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc31eb085	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xd9d2cc8e	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe22f8d03	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe6a80905	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xecf1d6bc	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xff3ff7ad	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x0d7e8436	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x18d910ea	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x36653bae	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x40a6d5b2	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7010c07d	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xd634febc	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xd8181d9a	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x0b2585ce	xvip_get_format_by_fourcc
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x0bf3dcf1	xvip_clr_and_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x2fecb173	xvip_of_get_format
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x3c7eb685	xvip_set_format_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x490bd11c	xvip_get_format_by_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x546681a1	xvip_enum_frame_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x82aa77b8	xvip_cleanup_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xd6434781	xvip_enum_mbus_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xe91189bd	xvip_init_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xf8ab047d	xvip_clr_or_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x3c16a6b1	xvtc_generator_stop
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x47d7900b	xvtc_generator_start
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0xa8a0f912	xvtc_put
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0xfa2bec63	xvtc_of_get
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x758d15e8	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0xd1744a91	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x1244a231	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x38fcc1b4	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x445de52d	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x4ab7e971	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x5320474f	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x61728815	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x63fb3fd4	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x7de07073	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x8c3c1eeb	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x982315d7	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x99cd6b92	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9a8a10c0	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xbd262796	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xca9ea515	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xd2b2242a	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xe1d16e58	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xe2d85bb2	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xf6ec08bd	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xfa4ac827	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0x8e04d505	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0x08fec2b2	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0x0565bd3d	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0x79501fe9	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0xf1e19822	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x6d8411b8	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x5e6dd387	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xdf3870c3	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x9d63b5e7	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x3ee4747f	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x67793147	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x7ba3078d	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xe115110d	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0x6df7e5de	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x01741458	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x07a345c1	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x13076c73	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x192964bc	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x212e06ea	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x46de834c	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x5313e68e	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x67a94b88	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6d62f2cb	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6f479ccd	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x774afc0b	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x7843ddc1	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x906243e9	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x98c591f7	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xc96e91f0	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xc9c66a00	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xcd25428b	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd5b43dff	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd927373b	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf300527b	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0xfee0ad84	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x2aa3edcd	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x0de2733e	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x12e1e236	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2551681d	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2db0075f	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2e0c2713	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x648c680e	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6bf672db	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d5ac5dd	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x75e06dc2	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7d9f676a	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9a057bec	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9e3e3011	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xab79ca4d	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xbc4a9703	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xc6f41849	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xda37662e	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xdb413925	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xe3587949	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x0fa664b9	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xd8392ec9	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xe225d897	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xfea36956	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x8403e0cf	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xa40581e3	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xa66d33d2	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xadb07545	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xd6611c63	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xde8f879d	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x07f89d7b	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x12570357	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x12ec10cf	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1449b8b6	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1472408c	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x14f18049	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17278837	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x29149663	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x316073c1	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x40586571	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x4a9ee68f	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x54e7bbed	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x59a83ba6	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x600cc1a2	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6886b35a	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x71ac69fd	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x81661457	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x81b09c4d	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x835a482c	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x904ee188	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x91f29bdb	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9ef7533b	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xa4b571e6	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xaedad5e0	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb1e2cab6	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb33c166e	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf3cd252b	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xfd193407	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xfffb0b1a	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x00697c24	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x20795fdf	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x544409fb	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x63361717	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6a61f71f	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6f7aebd7	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x76375f7e	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x7813f6a5	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x79ed4e43	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8249c091	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x91238cd6	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x979fe243	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x99b96b92	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa016bd0c	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa244c1a5	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa4e97ea5	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa99f6d20	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xc137422d	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xcba929c7	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xdf840ccc	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe62849c8	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xeec6e204	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf777a1f0	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfa7fa315	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0x579f2938	videobuf_queue_dma_contig_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xac1864ac	videobuf_dma_contig_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xeed9fa29	videobuf_to_dma_contig
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x16841c5a	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xa825c75b	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xc5240ce4	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xd79e77c5	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xf87bc2ef	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x55ede9b1	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x9db67d1e	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xaa4c65f6	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x04f64144	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x25212dfe	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x33aeba73	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x39e94d64	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x4eb291f3	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x50a34a1e	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x50c49b47	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x69a245bd	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x76a5c21f	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8ae20c58	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x93976fc3	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xa3b9bc6c	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xba6d0531	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xca2d011a	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xcbb32a05	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xecaf8ce2	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xed42aaa3	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xefa2efed	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x9dec262f	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xbee5620b	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x02935f74	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xaa4de2fb	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x583f613b	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0c470e1e	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0d92a527	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x17f9292f	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1cc4c5dd	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1eab4c30	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x33b0f0ba	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x37a347dc	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3b3be822	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x4cb99a6b	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x50ad7290	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x58d81e45	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x61371432	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x67732672	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x681222dd	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x74b3f898	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x786de2fb	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x7bac8731	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x87483df1	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8b8f0f5e	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8c2f67cd	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x91e61985	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x990a1275	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa40aace6	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xaadd375c	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xbdb475ce	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xbeb2233a	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xdb8b9515	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xdc902063	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf31a9113	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xfd19180d	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xfebf5206	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xfefd3292	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x53181c4b	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x023992ae	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0e2a7007	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0e8520b5	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x189a3a75	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x24ff3d7a	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2ad437f6	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2ebd9959	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2f828290	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3dc82b9a	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x44f52701	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x47c1260f	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4d65fa16	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x556c3b7b	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5be3aa14	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x64658b54	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x6508e19a	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7bb9f419	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x80575923	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8b7b2182	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x91f57604	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x94e7f302	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa1f6b9b0	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa36830e8	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa499e47d	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xab06e74e	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb251823f	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb3917c89	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd9d69cce	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xda16691c	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xdba8404b	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe039da79	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe0e83c69	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe3f79943	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe53229fc	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe53ae0aa	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xee4d0195	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x888c5c9c	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xb48dd344	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xdf487dae	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x0a9e3e5f	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x18fb35d7	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x9a51ed65	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xaa24023d	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xafc39238	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xc91b3bc2	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xf18c52f1	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x19bc74e8	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x8fb7d30b	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xb5f0b961	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xede5be00	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xf1301d2f	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xf3dd4ed2	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xfa15d3e8	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xfd770d6d	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x6a4dbc2a	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xdea6f6ef	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xe019a697	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x21e14932	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x2ae551af	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x7118dcc8	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x8f47da32	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xe2682665	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xfa40df79	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xff0ecefe	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xdee328a3	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xe3609fb5	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xfd2da049	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x11c970f1	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x8ebb75d1	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xb44c5492	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xe6f9eada	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xf4f61fb2	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xf63d3b25	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x28ea6632	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x2e02f305	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x5704489b	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x7d5bd782	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x9921137f	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xa27c0150	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xb447f5e4	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xc7247691	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xe1f2a582	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xe442e2f0	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xf316464b	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x68b5b8fb	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x86e4aaed	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x4432c7b5	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x47ea8e99	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x50f709b8	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xcafa425c	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xe289e9e9	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x04f797ca	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0be5c123	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x1a0a4368	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x24ff01ff	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x255a6a3e	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3ac2e939	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x456bb403	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x508890b4	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x610fb1bd	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x61457cc4	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x74b093c6	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x8294b2cc	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9060b664	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x950b3e4f	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xadd2e904	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xbb58c0f8	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xc7e9a0d9	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd6df49d9	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd7049abb	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe5541907	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf1bf1ff2	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf321c180	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf61d294b	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf6d425f6	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x06fc1bd5	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x0efe71ff	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x122e111e	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x1f904f00	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x4160ceb5	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x46bff0f8	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x6c754856	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x78f264bf	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x7e514e6b	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x85d246bb	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xb2e4b266	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xc10a4ee2	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xc85918f1	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0bf545e6	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0f11ab4f	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x13ee0075	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1a3af584	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1dcf1823	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x27f8582e	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3b5935c9	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4463611a	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x527a1c28	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x56e850d5	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x59a933a9	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5bda6982	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x60f40346	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7503f507	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x79f6b33a	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x86c299ed	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9068bd03	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x999e1b1d	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9dacce85	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xabdfd2be	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb5e0ee1b	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbb7a4861	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbc9dd31b	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbd71bdfb	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbe6a28b0	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd6c67d2a	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe3fca0d9	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe68fbc9f	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe7236d76	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xee8c4352	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf0e1fc20	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf2f01ca2	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf55ced0e	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfdecab67	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/ssbi 0x2d16a0d2	ssbi_read
++EXPORT_SYMBOL_GPL drivers/mfd/ssbi 0x578f6150	ssbi_write
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x56786138	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xc8d94f62	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xcc742104	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xd8fa20bd	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x01b8e081	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x6aacb89c	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x7167f38d	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xe48f20b8	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0x2223b19a	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x26e46ec4	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xa586ef2a	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xb0f6a65d	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xf470e868	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x1e1a6b45	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x2c4c2277	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x32a76574	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x8e985f31	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x227e45e3	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x49cb66fe	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x715ea43c	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x790b057d	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xa576cca7	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xabe0201e	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xac2058af	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xcc3a30b3	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x0585f67b	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x0688dba5	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x56bb835e	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x5730311c	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x5b6e82f6	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xa5f8541f	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xb0d85d93	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xbb31afdd	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x81df6421	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xcd6e377b	st_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0x4aca6003	dw_mci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0xa7a6f865	dw_mci_pltfm_remove
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0xd2cb45c7	dw_mci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x4ac8068a	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x88ff06f4	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xb7d6231c	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x2b6cf715	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xa6c77343	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xd8953893	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0x3985d76f	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x0031b780	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x0fdcd765	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x6d29ab8a	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/nand/brcmnand/brcmnand 0x77b647c0	brcmnand_pm_ops
++EXPORT_SYMBOL_GPL drivers/mtd/nand/brcmnand/brcmnand 0x85ad4589	brcmnand_probe
++EXPORT_SYMBOL_GPL drivers/mtd/nand/brcmnand/brcmnand 0xd5f09e88	brcmnand_remove
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0x9d59acc6	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x62d745a2	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x70f79132	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0x239d9994	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x01ebd63e	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x162bc0bd	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x1d9a6244	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5187046e	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x58ab2a12	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x6e3bab26	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xa0b873b3	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xaa472ec8	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xaf90c1f9	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xb8695d10	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xbdee322d	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xc164a882	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe0f06a03	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf758af8c	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xc0063d27	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xc1d9fc72	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x4edbfe08	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x8093753c	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x9609076e	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xbda3a91c	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xdfe4b36a	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xe074c978	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x08a3dfef	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x44461935	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x5aeba5bb	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x7b05de38	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x7d026371	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x864b33ab	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x9c33a7d0	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xa2a235e5	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xaa045761	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xac65d019	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xafdbad60	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xca6d9c2d	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xe93e0172	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xf0311935	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xf74e074c	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xf98c7ce1	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xfb1f9a7c	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xffb24cef	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xa1d5ebbd	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xb79c3c81	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xed4313a4	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xf9ae296e	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x14fe45d7	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x3cf992db	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xcb8128ec	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xe3e7b74c	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0x3a2e475e	arc_emac_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0x9160a7bb	arc_emac_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x02e4c894	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0a9015fc	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0e0ce0c9	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0f082b95	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0f3fa08f	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0ff784c3	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x10afeb5f	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1672f8e3	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x18d9e030	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1c36df29	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1d4bdd44	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1d696756	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1f7b9065	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x22355dcf	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x24de5c4c	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x258cb205	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x25f04a2e	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x28355c3f	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2bf9fca5	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2ff6ad33	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x32231207	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3c844568	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x40800622	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x409bbdfa	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x46e2db4c	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x46e79c59	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4ba74cd2	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x513c77d1	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x51ccccb3	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x538c49a3	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x566c4b73	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x58b4c171	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5cca77f2	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5de0ef50	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5e3b2b07	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5ea40210	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x604e60f3	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x60a4d0db	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x61994178	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x63714e05	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6371af75	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x64327347	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x65433dc1	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6739c65c	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x67b29fca	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x67e361ea	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6d76d269	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6e24f51a	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6f6a6adc	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x72ecf5f5	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x74811fe9	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x74f6519c	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x784bce23	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7a041cbb	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7ac08307	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8085c8bf	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8094bcea	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8289f028	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8a272711	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8cf40257	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8d060716	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8f3b2319	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x90e73d1b	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x919e1fc4	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x976fad8a	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x97f9db76	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x99d50ce0	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x99eb5487	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9a1910dc	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9b36bbef	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa12b6efa	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa136ed33	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa1a4f4d2	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa22841b4	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa357ea02	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa49efc10	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa579a34b	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa7c53574	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa817f2ce	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xae6cb029	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb06fdd8a	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb248ed1e	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb28d7160	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb4470eab	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb5fe8b46	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb6832102	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb8d837a6	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb93df8a8	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb99acf5d	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbc0dec67	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbeb956d4	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc656814c	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc6b2afb2	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc70c613b	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc7a049dd	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc8001a38	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xca002ec8	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcc1a0b2f	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcc7dcfaa	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcd855a96	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcdc10c3f	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcefead3e	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcf9cd0ac	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd069e09c	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd27ecf6d	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd879179b	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xda02acbe	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdaceb498	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdbe621ba	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdf3af7eb	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe09b617c	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe20830dd	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe689843b	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe6ec6aec	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe6f8ccd0	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe719ffc6	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe824ef67	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe9479742	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xed61b679	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf073ba1c	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf7b519d0	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf889fd1a	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfbc0903e	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfcecb025	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0072b792	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x00fe5362	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09543b3d	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0abbf765	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0c31d3f7	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0d0cf0ae	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0e4fa545	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x12f83c4a	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x138672f3	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1b1b6217	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2b9162c7	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2bd4e143	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2c7870b9	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x31fc9989	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x36acfa0d	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x37d19806	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3841e756	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x62674b7a	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x698eca90	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7582576b	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x77e9220a	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x79f60285	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8324b092	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x886405c3	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x88b0bf89	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x894d99f8	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8b26912f	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8b951d7e	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8e2c35b4	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8fc4a0a0	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9635554d	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9d3c4454	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa05cad0e	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa2250d54	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa4e0881a	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa5d67c92	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb2ada22c	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc5e21074	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd35011a4	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd37b95a8	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd3c80bef	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd3f3784c	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd3f50c6e	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd92fb32c	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe95a4124	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xee773ea6	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x2d0467f7	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x368d3d71	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xd4ab3625	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x835d77f6	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xcc424993	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xe3d8278e	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xfc86f5a4	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xa8c4b9e4	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xd61f696f	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xdb0769eb	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xe324bec2	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x63eb8f37	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/geneve 0xb25ce39e	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x3ad20f05	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x631818dc	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xaa03670c	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xe639c6a0	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0xd6440aa3	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x0d515191	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x1064c879	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x36db9fb1	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x4318256a	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x641ae069	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x6accc2a4	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x70c99f15	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x8efcab41	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xb852171f	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xe256d7f6	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x37d7e42c	mdio_mux_init
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x6318757f	mdio_mux_uninit
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x0365241a	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x67d716e0	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x8988f314	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xf6b5ad41	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x0bb51575	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x15b2c886	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x3fcd2f6c	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x6bab0f77	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x7ce2faba	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xb06c1b4a	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xc2d25230	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xd5193732	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xf33032c1	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x4501c2d2	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x4cdee205	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x63ef03eb	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x8bf75953	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xac8ca91a	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xb746fbef	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x026b458f	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0974cc2e	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x17b858aa	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x190e1dc3	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1c16a1ce	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2116c36b	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x219ef854	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x24b47630	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2c1f633c	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2e128a99	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x45a6e5b6	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x50a9080a	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x56034202	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x698c015f	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6badd138	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x70c3f869	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7993150d	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x831a4bad	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9158ea5f	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x930ca25d	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x94d1d5fe	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9b6364a3	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa474352c	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xac6e7d3d	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xae9a14e7	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb9c51ce4	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc02aa850	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc58b9c69	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc8db1d6d	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xdc917067	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xde19b8a9	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xedaa87fe	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x7cbaf909	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x9c5ffc94	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x0c22a9c3	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x0ef4f906	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x22119f15	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x23c26f8d	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x4f1cc357	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x5d5899d5	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x60ca24b5	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x6d788371	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x716d01ac	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x88ab4fab	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x9762e18b	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x98229dd1	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xae06f3ca	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xcb1ea242	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xe92e8d42	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xed949ebc	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xa1b9de3c	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xc95d8ce2	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xd878ba65	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xffdd62c0	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0xa2bc87ac	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x2a96de42	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x39903201	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x51cbe90c	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x86b591c4	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xa7baf9ba	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0c0b2d53	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x16474139	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x18cea784	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x194202ee	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1eebf841	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x24937408	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x45c962c4	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x488a9ac0	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x49b542fb	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5256e3a8	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x57ebcf0c	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5a10d898	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x66855284	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x6e415368	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x725bdd1c	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x761554c9	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x88dae553	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x892f879c	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9bf16097	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9c77eed0	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xae95beae	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb0d6ab80	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc0ac6d38	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc52a3fe8	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc726a88d	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd485a673	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd540668f	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe635ebd7	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe72b9045	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe84d8c55	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf69ba80e	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x04edd7b4	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x24936bde	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5a85ad58	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5bfaf476	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x6fb82c66	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x762b3e08	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x7c77a5de	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x82a6f457	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x87f77e86	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x8f4b40cd	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x90b3cdad	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa94255b1	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xad176eeb	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xb89dfa2b	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xbeac52bd	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe337a15f	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x0503537a	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x449e69b3	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xb4965407	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xb96c7dff	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc6d3a572	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xe74a7174	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xf118adbf	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xfd306d56	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x238d2d2e	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x23a320a2	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2dbfbb48	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x40b37bae	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x442424ec	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x4488cf65	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x5ee92e19	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x65214868	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x6b28f3c9	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x6b4f9217	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x6fbacf16	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x7abbf867	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x81c89a90	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x86b94f45	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb6458caa	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb728b7e7	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc84270c6	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xcc02dfd5	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf23626d6	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x07327d9e	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x3cb4a406	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x5411f8c5	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x551b3ff1	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x7c969b4e	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x87ff1caf	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xc90f5315	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xd91aa1f9	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xfbde3c72	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3c518978	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x59779537	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7fcfc92a	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe48ae2da	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x06ada1bf	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x09b77be0	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x0c48f33e	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x156519b8	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1678569f	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1864a757	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1f043523	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x235cdf8b	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x271d9a12	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x28db4a7c	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x33190552	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3953edd7	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3a2f3401	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3c00dc89	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x63636d56	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x78148f6f	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7b11d809	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x8f2e4a5a	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf0ae77d	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xb2d2888e	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xb50bcaab	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xbfa507b0	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xc0213d74	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xcc03afc9	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xdb2ba43f	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf4448a46	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xfe569f06	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0b20578b	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0ceb4881	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1cca4559	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2899a023	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2c2c1528	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2d882d91	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3440cee8	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4365f839	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x48d427d5	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x525f29aa	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x593b2585	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6f6fe975	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x82508d9b	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8505f514	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x90c1ee02	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xce86044c	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd3a99b49	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe9f3ab17	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xee1745c4	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf5388985	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf8ff6add	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x0b1daa25	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x116a9215	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x58ada524	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7b2a9a7a	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x01553fde	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x031ac62e	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x03738ab5	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0abdb554	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x17a7658a	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x30a00812	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x30e9ac76	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3d37e00f	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x43856ef2	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x47f1afc6	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x49c6d622	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4c30eb27	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4e22ba54	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5e86d3ce	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6611821b	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6c6c9d90	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x700a4f47	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x817d7cc3	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x870afc9f	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x87e51ee5	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8dea37f1	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8fde94c3	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x9071eab4	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x993070a0	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x9bd146e4	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa62a887e	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb31410c9	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb5fc7fc7	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb7d2226c	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xccdf262f	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd121819b	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd2e5b881	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xdec3b18d	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe01045bb	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe4068f04	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe7f17e9e	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf7ff9fb2	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xffda8131	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0b42059d	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0c999d9c	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0cd2a208	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x12d0d5c8	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x204b8bea	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x41ed40cd	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x4b176d73	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x4c0c6ba9	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x65744a03	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x6bb53b1a	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xacdd81ee	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xd9b99e38	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xf5178bec	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x04690a92	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x066f746f	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x15a56352	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1e47b078	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x20d0625b	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x25ef5bed	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3a5cadee	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3b453028	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x51f00e67	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5b76b71d	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5e275357	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x608a116a	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x673a2ead	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6b867890	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x71ed21fa	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x78e9fe48	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x79daf8f5	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7affc20c	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x82d2137c	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x840c5d56	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8606cc38	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8ecd34b2	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x97fad915	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x984499bd	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9e64f893	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9f7b7d59	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xaa7f31e1	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xac54df9c	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xafa02a2f	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb42631b9	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb4f979d9	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xca289ba9	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdf2b70fb	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe0283d3b	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe05505ea	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe3e6c3ac	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe74cef35	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe7c0be4e	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe911e7d7	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xecf565bb	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xed032107	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf0c46228	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf7acf939	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf9858a58	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfc825a9c	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfd19187e	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x2b8c577f	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x4c1a7c49	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x851785fb	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x99115c62	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xcb3e24b7	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x43e647f4	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x7260ecb8	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xca506934	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xf17a582b	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x00e08d16	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x0de7ccba	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x144e2069	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1e532867	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x33b61e16	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x74608b23	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x7bdbd994	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x7c70567a	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x7ca5e09a	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x9e73df2d	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xa34e94fe	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xa5c2de52	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xd26c9342	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xd628fa46	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xdf1e61ae	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xf2528be0	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x2f31d6b5	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x7f70b0b0	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xc09257cd	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x02c96266	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0670efa2	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x14717e5f	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1d144ba0	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2d7c4bef	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2f7ae406	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x308ec46f	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x35371f82	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x35d0684b	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x36ca00d0	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x371a1dbc	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x405d742c	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4443b825	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x476ca3e7	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x47caa72e	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4cb04c14	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x56949a0d	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x583c22ae	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6bca3b23	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6e777fa9	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x73241ff3	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x888c3b82	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8b4a9874	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x905fabcf	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x909b5393	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x90d59dbf	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x91da5146	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x977fc847	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x991fd571	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9caf8372	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa066fe0a	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xafa64b05	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbbfe0b7d	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xca7fed8b	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xccbe9615	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd23262af	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd5291329	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xdb0f0caf	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe8db45c1	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf10110bb	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf4b99c69	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf86850aa	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf9e85cd6	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfa9b8025	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfc0a27f7	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x1bbb8d05	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x348915cf	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x6ceaa499	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xb9f17d58	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x1294677b	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x5730625f	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x67cb0e5d	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x6ea2ce32	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x9491857c	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xb51d5368	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xc181b248	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xc779df8d	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x4f6e7f2f	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x8f2e710a	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xdd242b78	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x02e09fa8	of_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x07a9466d	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x13e66ec0	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x2f79d236	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x36ec8a8a	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x68758fda	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x7134a988	of_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xa7d8dc93	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc25815f4	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc96fb674	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xcb83ad7c	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe18960ba	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe9a7fe16	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/phy/phy-omap-control 0x3fc5c69f	omap_control_pcie_pcs
++EXPORT_SYMBOL_GPL drivers/phy/phy-omap-control 0x42669c73	omap_control_phy_power
++EXPORT_SYMBOL_GPL drivers/phy/phy-omap-control 0x8610bbdf	omap_control_usb_set_mode
++EXPORT_SYMBOL_GPL drivers/phy/phy-omap-usb2 0x00d48f33	omap_usb2_set_comparator
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x14621b73	ufs_qcom_phy_init_clks
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x18f32660	ufs_qcom_phy_power_off
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x219035ec	ufs_qcom_phy_enable_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x24f6ece2	ufs_qcom_phy_is_pcs_ready
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x2811c739	ufs_qcom_phy_set_tx_lane_enable
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x292a20c4	ufs_qcom_phy_disable_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x5e166858	ufs_qcom_phy_save_controller_version
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x690fe244	ufs_qcom_phy_start_serdes
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x7b0952aa	ufs_qcom_phy_generic_probe
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x85f2d9fa	ufs_qcom_phy_calibrate
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x8f17d9c3	ufs_qcom_phy_exit
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x9093b5f8	ufs_qcom_phy_disable_dev_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0x9d2472ae	ufs_qcom_phy_power_on
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xb39591ab	ufs_qcom_phy_init_vregulators
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xc294374a	ufs_qcom_phy_calibrate_phy
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xd04dea28	get_ufs_qcom_phy
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xd1813b94	ufs_qcom_phy_remove
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xd3c4e6ed	ufs_qcom_phy_enable_dev_ref_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xd8de035f	ufs_qcom_phy_disable_iface_clk
++EXPORT_SYMBOL_GPL drivers/phy/phy-qcom-ufs 0xe85e41a4	ufs_qcom_phy_enable_iface_clk
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x178a341d	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x599dd35a	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x76a1d10d	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x027b5b1d	mc13xxx_parse_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x49971f5a	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xa960e9ed	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xf36b9f63	mc13xxx_get_num_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xfb256676	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x3e096f37	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x5a9caf84	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x9313eef4	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xe5a5e98a	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xea573335	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xf03ae79b	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0x0554ed49	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0617f0d7	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x06eea751	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0a6404f8	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0abd3b4e	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x111cc98c	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x116c9263	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1e5e5343	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1ebb7321	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2bc9eb5d	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2fa7d943	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3436d99f	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x347e5532	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3d7596e8	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3debc876	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x435e9d0c	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4e5eced3	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x55debbe6	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x56a948de	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x57595b5a	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x65ea40df	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7e70b359	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7ef9bc45	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x80deb5f1	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x854f7dba	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x86c7bd5c	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x88167166	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x886db563	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x91fcce9e	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x943f19b4	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x97eb64d2	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9e614d96	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa4b35242	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xac00c081	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb086026d	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb9a9d5f2	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbab0dd87	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbbb1405f	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xcf4ef9e4	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd306d660	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdfd32f73	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe36f3c66	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe7f85c31	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe80b91e9	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe869f7e6	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf367fe21	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf7acf34d	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x2b5cad97	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x3c2eee8e	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x47494b1d	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x85a6851e	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x8874036e	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x96c9b285	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x97dfc35e	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x9ee104e0	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa6824ca2	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb635d78f	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xc1b3b1cc	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xca4189ca	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xd71d534a	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xdf9d498e	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xec01754e	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xfde2be2a	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x15126736	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x1c65ebf4	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x7a9cc10a	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x9d5c4988	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xd46e858f	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xfe9e54de	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x04385d6e	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0483ee16	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x04a58d51	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x059d8abb	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0878693f	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x11394468	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x151e6065	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3be57a8b	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x43b75d50	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x46330dff	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4b4a4d91	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x58a706c8	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5fb2d6e0	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x64bc21b6	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6a16ee3e	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7ce8fc9d	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x84045b27	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x85dd7c2a	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8984589d	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8ce295ef	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d581546	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9160650c	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x959e2af8	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x96a662d7	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9edffb0c	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa3d0ed66	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa3e5f640	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa48302c9	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa6284373	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa64718e6	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa918266d	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xab301a45	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xadd7336b	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb18d7eeb	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xcbd29f16	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd201a469	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd7cee27f	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xda6efe53	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xdec6eb75	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe15b0e05	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf5630ef4	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xff2e2902	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x1ee7dff7	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2cbcf373	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x31802076	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x41578e0b	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4837f234	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4d673d76	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x67c0d23a	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x75189837	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x837420bc	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x98a9c5ed	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xa348aa81	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xbc26c457	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xbe5e54c6	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xc1061ec2	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xc43dee10	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xeb07424a	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xebd74a3b	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x14a83d84	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1da7e2bf	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x47c49ec1	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6ab61fc1	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x74066f07	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7642567e	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x766dbc44	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x863b8e8c	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x89f49bbc	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x951f8f76	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9fb010d5	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa927c373	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xabbb9b07	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb389226f	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xbb0b0bad	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xbb92543d	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xbe154669	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xc7872e78	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xce5d9dc5	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe9427ca2	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xea8c31c4	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfa89d4f2	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfdda96a7	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfe192c53	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x06d65953	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x097e13a4	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0b78239d	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x12176667	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x16d9e38d	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x17ee9ebb	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x22d565aa	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x27785bcb	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3463cff7	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3ba293ec	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3e3d59f5	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4b2a8fe7	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x50a61852	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x55783066	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5de5e985	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5e5c5a0a	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5e5fafe3	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x61647348	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x656451f5	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x732fbb77	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x80926ab6	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8396e89e	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x955662af	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa2cd94e4	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa7c59f43	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa9e15033	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa9ea4204	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xab6e95d4	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb72d55fe	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbf79d3de	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc0814653	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc8aa7620	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd18b9c70	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd800c15a	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd81e0818	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xdc6892ff	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe5460c25	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe7299ef0	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfd770995	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfecdf203	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x2c7edf85	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x96f46b63	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x9f53f11a	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xe80dfb19	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x117dfb5c	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x0ab3df0a	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x3e38f429	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x59542ac8	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x6cd1c0cb	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x717f7c88	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x9e803c7f	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x3bceb880	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x421425a4	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x64bcdf3d	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x9a867397	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xb37cd79d	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xed5c1466	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xf963d256	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x0d68f4c6	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x1b235611	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x5532b02a	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x8598ae7e	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x9d39a2ab	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xb0437b9c	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xef860b05	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x60d0cc92	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x7056ed49	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x70b25117	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xc3858805	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xe9eb80d4	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x0226242f	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x4d3034aa	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x76bdeea3	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xae0a87fb	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x0058ed4b	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x01f18775	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x16af4f73	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1a3f857e	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1da67ada	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x2632c04a	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x37a695cc	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x4c0c3efa	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x5ef2e03e	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x7a4db1f6	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x82b24bd4	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x88a09273	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x913fa4fb	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xb118658f	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xb6b7d836	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xcc3ea25d	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xed91a9fe	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xf1dc73b3	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0xd33f1da5	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x01000aa5	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x04b022db	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0e7eed3f	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4538e8ab	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5482e3ed	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x57a38444	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x593e845e	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5be85dd7	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5c3302b4	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x67774861	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x689d3629	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x70dfa265	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x718678a3	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x759d5c2b	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x7fd5e449	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x92de5bee	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x96a494e6	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x97c87eb9	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb3db056f	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb847b1c5	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb871dcd0	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb878c680	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xba328f4c	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbbc48aa1	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbd150796	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc0bd3256	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc18ba246	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc3434446	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd888cee5	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdf19abbb	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe58f3067	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe8bb79f4	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xfcfcda3d	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xfd5c2e5a	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xfe3a4fe4	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x415e93e3	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x55d5abc2	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x5f978503	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x8ecf8dec	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x99e684a8	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xa0cc62ee	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xc9e1ff08	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xd92b6248	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x01b3ea18	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x0d582576	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x121590d6	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x6a9de528	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x719da48d	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x9a78a20f	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0xaa3190a1	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0xcb6335a4	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0xefd2f2a7	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0x0421f401	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x02f6496f	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x0cd040a2	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x503ef92d	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x55b5f998	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x5f06d89a	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x7cce8b1e	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x7cf6fa98	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb492413b	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xc8fd8b9a	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xcfe26acb	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xe73934bc	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xeb2c4669	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xf27731cf	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x399a9c3b	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xe367a7ab	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xf8894b4b	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x742b71c8	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x0259b5b7	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x0e6891b6	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x0ea14b11	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x2da82d83	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x31177899	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x39b9750b	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x4713e2db	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x48d1802a	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x54686892	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x66ca39dc	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x67bf5fb0	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6bb7cecc	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x8c77cce5	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x95493c90	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x95bec172	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa7da4abb	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xcfdca849	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xde354e28	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xee2311f2	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf780ba31	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf8c49653	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x7fbb19d9	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0xe7ec17cd	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x1344c881	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x312977d2	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x366c48f6	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x850de1b7	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x923bb6e4	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x9eb0e132	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xa48ac618	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xa9fcbea8	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x1bf20530	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x1c73e49e	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x2c20c221	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x310aa323	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x8d1356c1	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xe47ef667	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x33da01ae	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x59716da5	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x63b3b70d	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x72ff269f	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xaaf19d1d	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xd631fdda	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xf87cd200	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0xc3137ada	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x17e0bd0b	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x254dbef8	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x25abac99	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x50b1d348	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x5598a1d2	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x99632d95	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xa4cdbe46	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xb7310887	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xcc59a03a	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xd005190b	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xd38474d1	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xf6a0ab9d	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x5b6b590c	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x64f15142	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x75a0594b	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x86442336	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xa786dc4a	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xad8d59a7	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb2978dbc	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbe216c86	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd3baf5d1	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd40a37f1	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe0c8c395	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xf7cb71d2	synth_add
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x217ddcc4	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x7ef7acab	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xcfa431e2	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x72a595e3	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x8b0ced20	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x6f9ad0ff	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0xb9b14bd1	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0x002b0945	imx_usbmisc_init_post
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xcec89fce	imx_usbmisc_init
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xdb8c1d8d	imx_usbmisc_set_wakeup
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x5bf5ffcf	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x6e9222d4	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x9aad7483	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xa4d1b8db	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xdb728b5f	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xfe581cc5	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x117d6cc0	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x3b993b21	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x40cde819	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x4b58b7ec	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x68fd61d4	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x6f6c30eb	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x852119be	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xaf9ee439	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xb3880e67	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xbdd84b9e	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xcc574989	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd36a5f24	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xe38109ae	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xe87b3012	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xf7cba0d2	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x159e1e87	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x89ca818c	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xbb7ba380	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xd371dd12	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x1681c7c9	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x851a8897	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xafd09e14	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x3862ba3f	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x52c79bce	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x69c2fae9	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x769cfe5d	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7f15d857	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7f5108fa	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x82019079	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x94cf243a	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa20689d0	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xdd996f40	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xde6144e9	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xe342406a	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xe480e968	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf08894f7	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf1f8ed83	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x0c03b8f7	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x0e31dfc4	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x1581c6ca	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x19ed0601	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x207c64ca	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x414ba742	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x42cddeab	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x4998039d	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x57c59050	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x8c48bc83	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x8d9de576	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x8e2a5585	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xba8fdeb3	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xc02cbd94	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xc3bfa664	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0085c49e	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0ab4ed6b	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x16a41c00	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x1c491058	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2362bc18	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2bd7d6d4	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2cb5d701	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x3587e109	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x3dd5d8cd	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x459ba287	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x46707292	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x51956c7f	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x55d6da4d	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x58857860	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x68494784	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7a53ecf3	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7b9264af	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8cde4270	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa0baf6b3	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa14978db	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa82e93f8	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb4046f4b	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb9ed7b16	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xbb8e2612	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xbccd7844	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc57ffb54	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xce85858f	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd6b5e22b	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xdc91d477	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xef03bdb9	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf2cd28ba	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfab4b992	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x43a73c4f	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x5475695f	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x17eaec35	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x1b0145e5	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x378d65d4	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x3a61ea1f	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x577c0ab0	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x774b12ce	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x846be380	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xe25611ff	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xf532c099	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/musb/omap2430 0x6fb55e1f	omap_musb_mailbox
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-am335x-control 0x75eed29f	am335x_get_phy_control
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0xdb02f8f3	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x43949577	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1b51a989	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1bc47920	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1f15446e	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x36cc7b73	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x458d32d6	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4e450cd4	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x6215170d	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x68dc596a	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7020ff73	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7118a0c1	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x733002f6	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x82fbdf10	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x86aabff2	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x93c9d293	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xaef49397	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xb33e8164	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd36d4340	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xdf896778	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe2c82781	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe49d1524	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf5a98950	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x0b4aa6f7	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1fa9b183	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x20442104	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x23e84458	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x2c794cad	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3adf7052	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3ea5e532	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4243c242	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4361dd01	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4930fd84	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x59f525aa	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x725eb27b	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x88d2101e	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8a98242a	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8fc16888	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xabe90ecc	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb2e67601	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb5ff15f3	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbabc43d2	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbef12590	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xdf8630e5	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf0661472	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf51fd8a2	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf8cbb2c0	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x077e9943	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x3d6b3f7f	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x45f2bbf5	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x51a8d4a8	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x7bc3a268	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x9aa21059	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xa62e9484	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xac2802ef	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xac814c9a	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xc65c7681	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xdfbe508b	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe57db387	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x21f93db3	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x2c3e6776	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x2d7bd1ee	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x728e9b41	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x7d8342bc	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x8003c489	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xb1a8cb87	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xc543b60e	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xf4654c3f	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x1938bfd0	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x36c89708	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x49141971	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x5fa55689	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x6371666b	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x6e78d40b	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x77bc8024	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x9eedb3c3	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xa913651f	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xad798ed2	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb5348ca5	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xba10fb7f	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xd60df768	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xd8269a9a	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x1234e4ff	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x40cc7911	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x417df92c	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x4a6f3142	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x87b4df63	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xa3ba7064	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xb35ef8d8	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xb84b267f	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xde18043e	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xf2ec867e	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xf8a369e8	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x014e7b88	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x08f8b998	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0b12c8bb	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0b8aad57	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0d4761e3	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0f5a2f87	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0fef5f8c	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x10051458	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x15943863	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x19673573	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1cc6f1a6	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1d716d7b	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x203094bc	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2b0b7fdb	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x38af4760	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x563a465c	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x57cc99a9	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x58499f42	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5c4c8332	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5e4bc088	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6979a67b	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x74ebcaeb	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x75eedf0a	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7dcfcd23	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7f60569d	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x86c66706	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8aeac208	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa1d89044	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb7908d7b	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc0f52a5c	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc29f1da6	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc6f2da72	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc81096a4	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xcab07a4e	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xcb4777e3	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xcbc8a4f3	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd9fa9acf	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe0be67f6	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe1716f06	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xeceec331	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf326dc51	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0x262c6050	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0x527cad12	vfio_platform_unregister_reset
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0x612fac5c	vfio_platform_remove_common
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0x7af7d0e9	vfio_platform_probe_common
++EXPORT_SYMBOL_GPL drivers/vfio/platform/vfio-platform-base 0xd20a3bdb	__vfio_platform_register_reset
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x172676e7	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3567743b	vfio_external_user_iommu_id
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x36ab6bb6	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x4c956b43	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x9640a863	vfio_external_group_match_file
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc1d989c5	vfio_external_check_extension
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc4913442	vfio_group_put_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xd5626683	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xd6a04b4c	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xe53f4eef	vfio_group_get_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0x3361fec3	vfio_virqfd_disable
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0xfccad7c7	vfio_virqfd_enable
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0007793d	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0e31ee3c	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1614658b	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x17583894	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1a01c95f	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x20bc8361	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x293e3966	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x32bcc5e8	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3d427a83	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x54af12ca	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5da66b51	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x64ec3318	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x68363287	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x705893e4	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x72264608	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x74e0ca64	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8a7f66f5	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x926afc2e	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9301f0a8	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa4f72e71	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xade89bd9	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb46ef2b7	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbfe24982	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc0970b45	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc181c437	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd2087814	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe4761c5f	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xf50bb02b	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xf6c12ff5	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfe5a7ef6	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x476ad842	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x4f172a51	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x6ee1c183	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x889208a7	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xdaee62ab	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xeeffd97e	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xf1ecfdbc	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x02887f85	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x2fc30d7b	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x54efdffa	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x8c769f25	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xbcce5fe0	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xd41c3fa8	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xd4d6a854	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xeab8bedb	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xf6d0528b	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xfe20c727	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0xe2e05b56	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0x6af223ec	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0xfc518467	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sh_mobile_meram 0x0b30b5b0	sh_mobile_meram_cache_alloc
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sh_mobile_meram 0x3934f3cc	sh_mobile_meram_cache_free
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sh_mobile_meram 0x40d8323e	sh_mobile_meram_cache_update
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sh_mobile_meram 0x782dc486	sh_mobile_meram_free
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sh_mobile_meram 0xaf2fee1f	sh_mobile_meram_alloc
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x842378f4	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0xcb55486b	sis_free_new
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x2753e644	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x3241c003	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x8303fcac	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x9283aeb6	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x99a41525	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x9f29ba18	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xce1aa8e2	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xe57eeb8c	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xf7ed60a1	w1_reset_resume_command
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x2196d91e	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x25e88e02	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xa591c83b	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x23bbe4f5	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x331f5bca	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x4e7300f1	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x8023513e	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xbf4170b8	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xc2da2f92	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xd953462c	lockd_down
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x004b3002	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0f85b721	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x12386a21	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x12a6e4c5	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x16376f41	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1c30a3a9	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1d3105e3	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1e7867fe	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1edb70f0	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x24c07bc4	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x272ef622	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x279df7f2	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x283083ee	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x29515817	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2a129c8d	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2d2603f7	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x304a6e5e	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x32484e70	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x35a4a463	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x366a9ac6	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3847acfb	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x423f4652	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4291ed1f	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4456364c	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x47379cfb	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4895dcaf	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x48b8d1ba	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4a7b77c0	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4a91d404	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4ac7c938	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4dedcb8c	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5102978d	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5286b52b	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x52e62708	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x53ce8612	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x545a954e	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x558140d8	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5613dc6e	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x570f7ffd	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5d083057	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5fed5ade	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6208758f	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6286d5ad	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x645470bb	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x68376727	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6a15b597	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6ccfab0d	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6ed26cc3	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x728f5517	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x72d92042	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x74437f35	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x751f1869	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x75f3ecbf	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x766536fe	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7883a8d9	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x78a1b23e	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x79bde2f7	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7d5946ff	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7ea36dc6	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x83126356	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x84ac95ab	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x874853c2	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x88347501	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8bc8371c	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8cfad6e9	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8e53d1f0	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8ed7721b	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9030be90	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x93694eaa	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x981a3e5f	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9a4ec22f	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9a50005f	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9dffface	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa36be473	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa66d59a2	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa71bf968	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa758d678	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa7cbc812	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa993f24c	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaa16f551	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaaa14361	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xab0b56b8	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xab90cc6c	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xabafe911	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xac7963d6	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb01a4f94	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb2d5359a	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb35f6e10	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb7c4533e	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbc8083a9	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbd5ef640	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbe162596	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc0330434	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc092ec40	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc430fd6a	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc68cb70a	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc6a9ab0b	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xca16ee37	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xca1950cb	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcdfa3e09	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2520d0e	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd5139a9e	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd7d2c45c	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd890c06e	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xda916d6f	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdbb6a5a0	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdf678b41	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdf9be9c0	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe049b85f	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe146610c	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe3d61da8	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe3dbeabc	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe7dbc1f9	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe81d23a6	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeab31e22	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeabd664e	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xecaddc72	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeef480c8	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf186ab27	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf1fc72a1	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf49f5dc2	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf4cec7d3	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf5a93a00	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfdf7f3c0	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xffd400db	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0x7a27ff96	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0299bdac	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x042cf4e6	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x13faabc0	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1d13431b	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x215d0f8f	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x238250d5	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x269b9377	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x29c2a35b	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2c2720e5	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3458644d	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x35e42d5c	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x367f06f5	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x39c5d43c	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3e0f32a9	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x405269de	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4128ea41	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x45d741c4	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4d88dcb2	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4e8d6e62	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4efea45b	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x50ccd86f	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x51bc5912	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6135232e	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x61afe5df	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x65222085	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6aed884d	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6bbfbc99	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6e18b355	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x729e8cc6	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x730625a1	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x79fadb7e	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7b5435b9	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x804179d9	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8085905c	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8708f74d	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x90d38100	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x999c7fcf	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9c54fe82	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9f6dfe06	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa02df320	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa1ec3c26	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xab69f062	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb3721336	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb4859dba	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb5c036e1	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb684df92	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb95e7e64	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbdbfe55d	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbed68ae1	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc1ee0f92	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc4b61790	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc7ec8d3b	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcbdae495	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xda87f974	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdc9f34d4	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe01b8f73	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe5e8854a	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe7af00a6	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe98eae72	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfb9d7e57	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfc761e4d	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfdcd16c7	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x59092a0a	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x880bcec9	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xfd7fb54e	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x6b20bc1f	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x9b1f66b2	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x0ee1e090	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x164f0b9e	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x18b17d47	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1cb231d0	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x425c1c07	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x687f6251	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa31cef37	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa9f5379a	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xb5427c91	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xeaf08a8a	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x315dce8b	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x45245667	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7b025c11	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x9e3d363a	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xbc556351	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xeb5bfb87	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x52e8eaf3	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xad61fc93	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xef4682fd	ocfs2_plock
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x327d22b4	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0xaa39ca63	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xed269c07	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x623f1551	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x707aa277	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x021957e1	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x0f8a2742	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xd4cb6873	raid6_call
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x2d107b5e	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x41ecf87a	base_inv_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x72eb4ea9	base_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x767b8ba8	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x8d490167	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x9af6b231	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xdba4feef	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xde0e6eb2	base_old_true_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x548bf73c	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x9c831476	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/802/garp 0x418dad1f	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x7b62aaee	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0xb64e9100	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0xc4bd9097	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0xc5724ac3	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0xdadc7a7c	garp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x133ce58c	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x295ff796	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x35e9b75d	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x8ba17058	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0xa5ca56e2	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xa6f3e973	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/stp 0x4e35a361	stp_proto_register
++EXPORT_SYMBOL_GPL net/802/stp 0xa6872b92	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x16c1a9c7	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x930ece34	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0x46d032fb	ax25_register_pid
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x219aa73f	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x3751f607	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x4ba263a7	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x542a5714	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x69fa0b17	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xeadb2585	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xeb2c0f56	bt_debugfs
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xfe5ef828	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x0e8b5532	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x52ae6f4d	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x79e0e984	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x8a2010ed	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xa5efc48b	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xa7641ef3	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xd9944e7f	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xf2516a59	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x2d518dac	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x5d8e1ffb	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x09953bef	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x09a123b7	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0da3fed1	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x14b80968	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x15cee9f6	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x164e8bf2	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1a9060eb	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1f84c833	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1f9a5492	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x280be5eb	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2bf773ac	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x37feba7d	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x42745a9d	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x566b4e23	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5b759783	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6377717c	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x68cccd01	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6bdb31d1	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x74fe2d5e	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x78369420	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7c41e236	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7d049bed	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7e8f2d3f	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x929bdda1	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa704aca3	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb0596156	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb98ceaa3	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xbd9a3102	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc1f023bc	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xcbd1fbaa	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd827946a	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xdacda849	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xddc151e2	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf1ba6f38	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x21695288	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x6b14dab8	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x83d47d16	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x8f647d72	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xdf1c2b37	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xf568b4b6	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x4d7aef69	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x77c856ed	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x8212ce37	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x93533487	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xca6633c5	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x271e9bd1	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xcf54cbfb	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x431a5611	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x590d2c5c	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x79e7b4dd	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x9bdabfe0	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xa8ee46f2	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xcd6074d8	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0x83873088	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x150da021	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x3eb667a9	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x4ab90ec0	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x51629979	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x6541c5b1	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x7a985e61	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x886b04fb	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x9dab101a	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xa25ac273	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc08d7d2e	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc0ae72bd	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc10be10b	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd4a902cf	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xdefaaf8e	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xe3f905bd	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0xb46e17cf	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0x266f7e3e	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0x792f6c88	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x4b30d8b0	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x5a434244	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x5cbd5ffd	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x6fb83c98	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x830d2665	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x74456c56	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x4c17169b	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x5a44bbf7	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xa786c373	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xdb950896	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xf04f9bc4	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0xc924f0de	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x2bdf6655	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x4befabdd	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x8e89d92a	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xa1b74200	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xadc08c17	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x44b85e07	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x4e22921c	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xd363c653	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xdfb066f9	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x282d6c68	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x84a94375	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xa7c4d7a5	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xb2e07d28	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xbf0226e6	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xbf0e69d9	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xc24490a0	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x255404ef	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x7d306cea	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0xc6aabd14	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x0d711673	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x75049f2b	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0x18079b25	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x09d2a22e	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x1184c767	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x2bb56c01	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x5849fca9	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xc124b0fd	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x89062db9	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x827c0f67	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xab1df80a	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xbace97f8	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xbecc60fc	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xddfdebd9	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0x86cb6139	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x149cb460	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x183ef4c7	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x2dd90fef	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x3310c814	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x4f238167	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x607cd679	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8be03b1d	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8e221188	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x965a1e36	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xa933b1e3	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc8813d6b	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xcf3359c7	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xdc8ebc3a	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xee8b7a31	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xfb2d5b9b	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xff0eeffa	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x4c83ae5b	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x0fc17f81	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x1bca9d9e	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x29d0ecb2	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x301516f5	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x63aee9ac	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x65e55c68	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x67765c0d	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x6d0c33e8	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x72bd93ba	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x75b5af79	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x876657e1	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x88f039a0	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xad0efcfd	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xb40a0a27	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xcfe97116	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe4d206b0	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf06db9c9	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf9fa191d	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x3e9fab43	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x3f92d92f	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x79fc9f64	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x85d17073	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x01523129	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x047bf075	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3131941a	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x37994899	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x38f204ce	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3bed5cf4	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4a572642	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6344eaf6	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x645fdfc7	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6a171301	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x78de9115	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xaabdfb0e	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xb23b3c48	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xb9276d46	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcff4fc0f	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd82bdbf6	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xfe446aed	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x09456bf7	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x78b6e2bb	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x9fee4fb9	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xb451a4fe	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0087779a	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0212263f	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x03d72f50	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x05af1378	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x064a90e5	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0726d531	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x07cfd8c0	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x07fed797	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0cb73bae	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1020f1eb	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x18adce34	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1a08037c	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1edffade	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x21dd82cc	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2379a316	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x293df54b	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2ce9985c	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2e585b5e	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3222f339	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x39615f79	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3a3d315e	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3cf4baa6	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3fb751c3	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4187dbdf	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x44e13dea	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x47da57be	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4b0e67df	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4e2db5a9	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4e9aed8d	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x550e7bcc	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x603ec0f8	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x626103c8	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6738194e	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x686f0a61	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6bdcccf8	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6d6620c0	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7141d70b	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x715fc626	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7457d87b	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x786fed39	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x790003a3	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7a09abb6	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7ed65393	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x808f3b35	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x82922946	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x84576630	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x887f03b8	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x89a63cd2	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x89f0a977	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8bdbfca3	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8fb5f10a	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x93cdcb97	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x946eb72b	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9975c0f7	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9b2686d0	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa7366ada	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb23f95fe	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb630a382	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb9c0e2a8	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc14a442f	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc2abd2fd	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc3a2be65	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcbaaba8f	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcc1372fe	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcead3503	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd1fb1118	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd7438106	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe3075cbc	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe8311684	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe836e12b	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe8ccdb02	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xeb306a3e	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xef00f611	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf041211d	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf0a3bc89	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf645a9a6	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf75db4d4	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf9c8d842	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf9d19551	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfc8a137d	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x9f7aa943	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0x924e5eb9	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0xa5f05632	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x0110de61	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x01766a4e	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x1409ab04	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x15b2ca1f	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x379d976c	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x55020467	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xa797aef3	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xa996f523	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xbb0eddf9	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xd1b671fd	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0xb76c1ab1	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x115d0bd3	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x7e3fbc56	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x9252bb1b	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xce9bcd94	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x223e9dae	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xd1e2d589	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x19173e6e	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x33233a42	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x39093fa4	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xa4e9c909	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xd2b9d3a4	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xdda2a1a6	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xf344335c	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0xe682a730	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0xee569760	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x3817a3d1	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x839e0343	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xa943f60c	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xd97be5f6	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d0e99da	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x111d5f96	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x593f2548	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x5c187aac	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x6d043ec7	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x71bb7795	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x7732a4f5	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x929faca5	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xa27173ed	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x9cc8da7c	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xeaeee43c	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x09c75246	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x8841d39b	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xc61febdb	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x08e0ad08	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x0ac2b475	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x13137648	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x2c8bd72f	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x2ef9819d	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x325d8759	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x434624f4	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x6e7c4c53	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x75c335a0	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x8326cb78	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x9d351b1f	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xa2a26820	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc308f897	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc8536759	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe0db5ee7	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe43db6ef	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xfece4287	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x2dfb1f6c	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5c3e113b	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x6ea3781d	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xac192d10	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xad8f508f	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xebedde9a	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xf513df40	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x7e84f48e	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x932a242c	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xf68f254d	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0x6eb0d024	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x27873483	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xc41e18ee	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xfe7b7d18	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x19254a16	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x63df60ef	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xa73e6bcd	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xbe8f1e6a	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xc48e85a2	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xec7baa7c	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x6c154d5b	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x7cc82a95	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x8f2b2d28	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x00adf10d	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x25c5bbe0	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x0996cb77	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x13632bbf	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x1c66d509	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3f1ef70a	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x6295013f	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x7f553790	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x86f2d2bb	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8b7cd618	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xa0f6f862	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xa142aead	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc1eeb5a6	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xcdfbdb17	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe2f788bd	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe3f56cff	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x57909dc1	xt_rateest_put
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xd0f26ea3	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x58294b7a	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x68982e0b	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x9bd7561c	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x6b3cc296	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0xb5469bd6	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0xd5a2fcf0	nci_uart_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x03c5e7e1	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x062ee3cc	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x0f0a0745	ovs_vport_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x2858bcd6	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x2d95b96b	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x3b4ed361	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x50ee6ba3	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x59b9542b	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xbd28e5ab	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x29590f49	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3555ebda	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x3d375fac	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0x4a2e7c1c	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x4aa56443	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x4b209685	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x55b7cee4	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0x60c0f009	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x7d182692	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0x8ec43834	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0x92bcb54e	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0x96fafe85	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xab07843e	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0xb69952a6	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0xb89d7a34	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0xbf2d3d5a	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc642cc2c	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0xd543dd40	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xd66c45eb	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0xe6f08ee0	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0xe7295737	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0xecffa972	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0xef2086d1	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xf1b59533	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0xfb3623ce	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x569d1201	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xf89849ff	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x691b45c5	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xe44d558d	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xebd0ebe4	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x010f05d1	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x02673e6b	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x056721f3	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x061de60a	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0860bf07	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0905938c	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b3e97be	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b44ffbe	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0bc67ba7	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c28be36	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0d796e19	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0e34ce9f	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0ee7b024	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f35a7af	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f898f37	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x11cd822b	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x14c87bc5	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1521d2a6	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x15bb43c7	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x15f017b2	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x19fa3bb3	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1b29bb4d	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1c9acaae	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1d39a3a9	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2088fb80	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x214e2bc3	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x23d52956	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24f0efba	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x252fe6aa	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2531f135	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x261b5094	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x281421bf	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x294cc907	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2974c611	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2a13dd58	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2b0bb171	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c749b88	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2cb28c05	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f8ebbe0	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x301fe55d	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3060b97b	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x30ef8298	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x33476fa3	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x37b3c3a6	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3978611b	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3be97fa1	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3cdfa5fb	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f13c0c7	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f747bc7	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x410a71d9	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x422d10e5	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x427eedcd	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x430694bd	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x439ec6d1	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4411eaec	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4556a2c9	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x458120cd	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x48dbf091	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x49380a89	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4a4b5329	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4e06b6b5	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4e1b784d	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4e2f18b7	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4e3b577a	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x50bbcc7f	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x50ca882e	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x51409443	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x51e653a8	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53dc47f9	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x54193e45	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x571995e8	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x574c62f0	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x57aee2e7	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5810e6d2	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x58821a78	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x591a4990	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b5898be	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5dc20588	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5e0ece47	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5e385205	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6026afe4	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x61ea87b0	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6261c0e4	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x65e97f7d	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x66b5b1a7	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x670d4244	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6796c2a0	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x683c19be	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6a76c42f	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6a83747f	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x73d0036f	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x74f99933	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x765ca817	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x76a42bc2	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x77ca6ebf	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7912af76	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x79cf4e78	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7ba530eb	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7d0b8f1d	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7d1e1501	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x830b3f22	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x83260453	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x87c3a8f6	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x88e875fe	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8ceb14dd	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8f1f190c	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8f24b119	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8fc464bf	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x912e39ca	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9194301f	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x93d7e5b8	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x971e9203	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x992aa88a	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9a14f130	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9abb2c5c	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9bebc3e6	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9d0faee5	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9e0b42d3	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa14da319	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa1a4cd72	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa1fb340c	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa4000ce3	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa4a4d79f	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa72ce9c5	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa82d9d22	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa8eb9139	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa8f3b699	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa90d1050	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa91053f9	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa95c930b	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa9e2d45b	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa72ebd2	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaaf6671a	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xad0a97c1	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb036f2d2	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb22fea5b	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb48e9f13	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb4e3764b	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb5198b2b	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb5c88349	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb5e14d53	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb633e8cd	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb744de03	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb8b1307d	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb8f5f647	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbae6f0e0	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbb22cf1e	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbb2c834d	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbb5e373f	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbbf98aa3	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbc4e7d14	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbeed812d	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc22a7401	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc290a8aa	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc2b70c36	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc512aaf5	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc55f6683	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc59093ac	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc5dfbca3	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xca6afdf8	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcc3cc3a7	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xceaf5e22	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd1e6a2ab	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd2c5fccb	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd2cca29d	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd49b49b4	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd49ed0d0	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd6f81ffb	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdadce699	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdb40641e	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdb4692ce	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdc41e5ff	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xde6ab921	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdf7944d6	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe14d1e36	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe2a7ebfc	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe3735b8a	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe4c55d3c	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5cb0680	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe772ed82	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe8a53d67	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe8ac3ae4	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe9733a87	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe9f9435f	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xea98b7b1	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xee27b7e6	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf15af360	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf15d8d20	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf3091122	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf5b8594f	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf5d55789	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf7cd3ac5	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf8841fb6	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa3adb56	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa75e45f	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfd0c3e93	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfd162dcb	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfea744c0	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xff31268f	rpc_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x00ff5a72	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x24ca3d33	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2d518f69	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x37924b4c	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x4bdfd13f	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x54c60943	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x57dddcd0	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x74e91915	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7a935e1f	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa2e28269	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xe6285309	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xeceb7331	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf145581d	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf593c40a	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xfe9bfbbb	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x0a718ac0	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x1f400039	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x2cf8577f	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x3b065a2b	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x417b8dc5	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x55dc6bcb	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x5b0fe8d9	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x7a846eed	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x7afd2394	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xa89d358d	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xdb034a05	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xdb825856	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xdd6ccab1	wimax_state_change
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x104333b5	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x28721f51	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x3040b35e	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x41294551	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x4141fde6	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x63bc099a	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x68c0ff56	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x6f4fab37	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x78dd4e61	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x94591d38	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x9f780db5	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xc4c177e2	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xf357ee2c	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x762913fb	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xbef97495	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xe2a99918	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xed5dee2d	ipcomp_destroy
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x08e33de6	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x789e004c	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x0cfd1714	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x3497f1d3	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x3f7dcd96	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x65a0bc51	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x8b3fa7b9	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x99d638e5	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xa9904e05	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x024bcf92	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0630fd14	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0685c2f9	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0846e318	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x09e1dbb8	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0af56590	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0b590a6d	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0fb51d5f	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1db1ea93	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1f572920	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x222aeb4f	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2c682703	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2ee6061c	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x38579415	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3a993453	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x40fa0a4f	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x43cb8f0e	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x455f3bed	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x49e3470a	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4a26115d	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4e0e9a7e	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x50a6012b	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x532915c9	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x550e75f4	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5a77dcb4	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x605ae747	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x63b2b384	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x64213f94	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x652ad89b	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6e2ee814	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7a9115e1	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x816c9eae	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x81fe2a82	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x84668194	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8d7e1ad2	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8ec07846	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9035a219	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x90aaea0e	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x928032f7	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9e12f2a8	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa166ba92	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa194b3bd	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa2eca765	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa5086a73	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa85deec9	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa8f36247	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa9d31a8e	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xac221959	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb29bff76	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb674398f	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb85ba0ac	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbc62354a	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc046e6ed	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc55fdeb1	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc652c59b	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xccf3a437	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd8d45c2b	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xda1e85a0	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdec0d861	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe4553bdd	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe63d1a89	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xeb98c275	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xefccb8b3	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf5c21e7b	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf5dc3ce2	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf7792fd9	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfae108e9	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfb40211c	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfbc7f9d4	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfe16fde2	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfec1c06c	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x0ea17bed	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x22cc019b	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x50f2ea62	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x6d815740	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xbcd766cf	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xeefba90f	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x02cc826f	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x03b006ba	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x043b71f3	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x04f8b64b	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x05805aee	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x07a87f97	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x09b68d97	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0cf0dc85	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0f7cebbe	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x10af9891	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x112ea0aa	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x12c43b6b	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x13301921	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x14a4bcae	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x174feff5	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1823b69d	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x18441dd0	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x192582ae	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1fde2f09	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x23c27bc3	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3127317d	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x32d663f9	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x34511f66	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x34bd6821	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x359819a5	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x35c93cf7	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x37fa23c0	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3877c817	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3bf1d320	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3ca11914	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3e3a8d31	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4052ee91	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x42e0321a	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x44d521c6	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4641ba81	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x479440f2	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4fed1f28	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x50c0cc6c	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5911e88f	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5bbac394	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5c2d3545	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x613ec9c9	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x616d46cc	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x61f23812	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x62cf5d13	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6723b43d	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x680fa4f7	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6c31feb8	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6c3bc401	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7990074f	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x81210bb4	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x825c2112	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8600799d	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x88ebc188	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x898aa481	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x89bcba1b	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8adc7f01	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8cdd661d	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8d6cf097	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8e71d06f	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8f5b2163	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8fdf471e	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x91a14f35	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x92c64bfc	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x92e8403a	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9cb4e0a5	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9cc2735d	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9e23ca59	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9e7321c4	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9f0779a4	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa179a573	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa1f6e6a0	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa4b4bcf1	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa9af176d	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa9fb14a4	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaa7074a6	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaca4bd80	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xad3f1705	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xadd39fb1	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb0af2b2b	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb2051827	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb3de8300	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb93d43cd	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbd6fb5a1	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbe6c30a4	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc1b24ac9	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc62ef922	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc7b93db8	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc9d096d4	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcdac3576	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcdcdb2b2	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd0369207	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd0d139c9	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd2ac9a6c	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd58f7c91	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd5a9cad6	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd66ef446	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd759f1de	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdacd112f	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xded1281e	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe00f2c74	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe2dd02d5	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe2dd884b	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe3beb324	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe400bf7f	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe6583350	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe87e119a	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xea187a11	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xea3319ad	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xebbca26c	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xedc8eeab	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf3026145	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf4293b51	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf49349bc	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf4a5de4a	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf5386158	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf5e59503	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf8af3550	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf8b0a878	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf9ecd007	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfbb3aef3	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfd3e7c22	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfe75fe57	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xffd2e801	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x24ba6211	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x28761e0a	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x2a067032	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x3d2384a4	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x62b8f08e	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x7ee447a9	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x814be012	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x893fab31	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x985bd638	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xa7f3a81d	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xa97c3b0c	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xa9b2d988	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xaa55d362	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xbf137608	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xc5ea82aa	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xc8fec7b4	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xde02172b	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xdef078d5	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe3dabfd1	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xf224d0c3	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xf98d6700	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x7d05786f	cs4271_dt_ids
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xdf0f3324	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xe44bfe1a	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x42a0b8f2	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xea6a2612	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x39071d1b	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x92040f47	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xd1695525	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0xcb5414d5	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0xfa2bbc08	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98090 0x24853aa5	max98090_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98095 0xd2cb8d13	max98095_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x00870558	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x574f5200	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x717f5a8a	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xd95b0249	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x70617a04	rl6231_get_clk_info
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x7f68b24d	rl6231_pll_calc
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x8d7fa148	rl6231_get_pre_div
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0xdba4502f	rl6231_calc_dmic_clk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0x6ac3a3ee	rt5645_set_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0xeaaa3f28	rt5645_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677 0x112d3a35	rt5677_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677-spi 0x41b38492	rt5677_spi_write_firmware
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677-spi 0x952df541	rt5677_spi_read
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5677-spi 0xdc9e2327	rt5677_spi_write
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x38c81cdb	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x462d0531	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x9067aab9	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x9aca6276	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xaa7cb2c0	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0x317e452c	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x3e6bcd3d	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x51374332	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x098ee49e	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x593f0d7c	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0x53ba39cd	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x14007263	wm_hubs_add_analogue_routes
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x1840ada9	wm_hubs_hpr_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x219cce42	wm_hubs_hpl_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x2c10026d	wm_hubs_set_bias_level
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x445aee17	wm_hubs_add_analogue_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x5cd7eb9b	wm_hubs_dcs_done
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x757206d5	wm_hubs_spkmix_tlv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xbd8f5a05	wm_hubs_vmid_ena
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xd26a92e9	wm_hubs_update_class_w
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xe8c9114e	wm_hubs_handle_analogue_pdata
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x1383d767	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x6ef75ff4	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x7829f4cd	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x9be5bb5b	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0x1a4a2dce	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0x59991778	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0xc3ab165d	wm8958_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0xf60b5830	wm8994_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x0e976eff	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x27cc5d57	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0x1868b0b1	asoc_qcom_lpass_cpu_dai_probe
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0x7ceb64d7	asoc_qcom_lpass_cpu_platform_probe
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0xb962960d	asoc_qcom_lpass_cpu_dai_ops
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-cpu 0xfee2f76f	asoc_qcom_lpass_cpu_platform_remove
++EXPORT_SYMBOL_GPL sound/soc/qcom/snd-soc-lpass-platform 0x6a8e6181	asoc_qcom_lpass_platform_register
++EXPORT_SYMBOL_GPL sound/soc/samsung/snd-soc-idma 0xade84e1d	idma_reg_addr_init
++EXPORT_SYMBOL_GPL sound/soc/samsung/snd-soc-s3c-dma 0xb43351b0	samsung_asoc_init_dma_data
++EXPORT_SYMBOL_GPL sound/soc/samsung/snd-soc-s3c-dma 0xfab131b9	samsung_asoc_dma_platform_register
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x1ce81c04	line6_pcm_release
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x2deb4a22	line6_suspend
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x35c8573f	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x3b6aa42a	line6_read_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x3fd55948	line6_pcm_acquire
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x65a68569	line6_init_midi
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x6e528ad2	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x92094e94	line6_version_request_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x9769ce4f	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x9e209629	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x9f7155c1	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xb3fb5f6a	line6_write_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xdbd7a0f2	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xe438fddd	line6_send_sysex_message
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xfceeb007	line6_read_serial_number
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x3fe35aea	irq_bypass_unregister_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x418873cc	irq_bypass_register_producer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x888c5be5	irq_bypass_register_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0xf6e772c3	irq_bypass_unregister_producer
++EXPORT_SYMBOL_GPL vmlinux 0x0003e8cb	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0x0013e097	kvm_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x001b76bf	gfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0x00228a45	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x003000d9	ahci_platform_suspend_host
++EXPORT_SYMBOL_GPL vmlinux 0x00306b94	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0x003f2f17	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x00632780	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x007763c5	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x0077e410	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00cb0342	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0x00dc50b3	snd_device_disconnect
++EXPORT_SYMBOL_GPL vmlinux 0x00e11368	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x0102b187	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x0111d24c	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x011cbeb6	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x01239e39	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x012f78c6	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x01301ee3	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x014e050c	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x015100df	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0x018edcce	cpdma_ctlr_dump
++EXPORT_SYMBOL_GPL vmlinux 0x019e8340	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x01a458a1	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x01aa17e1	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0x01be387b	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0x01c6cb0c	cpu_cluster_pm_enter
++EXPORT_SYMBOL_GPL vmlinux 0x01c910fe	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x01e054bc	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x021e1e00	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0x023f8fa6	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL vmlinux 0x0245ffa5	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x024ed110	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x0257635a	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x0273fec6	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x02a34218	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x02df2c9a	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x02ea8741	max_gen_clk_ops
++EXPORT_SYMBOL_GPL vmlinux 0x02f65e96	dev_pm_opp_remove
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x0321cdbf	of_alias_get_highest_id
++EXPORT_SYMBOL_GPL vmlinux 0x032375b0	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x032c058f	clk_hw_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x0345555a	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x0399db50	pinctrl_pm_select_sleep_state
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03cb6438	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x0402b504	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0x0402cbbf	preempt_notifier_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0415dd15	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0x0422b8f6	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x0480f430	of_usb_host_tpl_support
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04b64b89	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04c71d36	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x04c81cb9	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL vmlinux 0x04f4bd8d	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0x04f65246	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x050d8f21	of_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x0518ecec	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0x052ad5ff	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x05542702	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x057c6bf7	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x05b34990	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x05cd7ead	of_irq_parse_raw
++EXPORT_SYMBOL_GPL vmlinux 0x05da8d1a	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0x05ecffb4	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x06438115	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x064cfda6	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x06645834	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x066aa19f	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x06820e8d	to_nvdimm
++EXPORT_SYMBOL_GPL vmlinux 0x0695ad2a	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x06c214cb	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0x06d29592	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x06d549e6	pinctrl_free_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x06d583a0	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0x06f4e90a	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0x07032f9e	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x0714afab	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x073db655	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x075286c0	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x075ab4be	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x07684a40	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x07725329	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x078da988	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x079e0086	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x07a4dc3b	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0x07a6dedd	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07e36cea	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x07ef5849	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0x080a606f	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0811102c	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x08221d41	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x083fe7dd	omapdss_of_get_next_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x0845bbc1	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x0854a42b	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0x0856710b	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL vmlinux 0x0880af67	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x08879b54	omap_dm_timer_set_int_enable
++EXPORT_SYMBOL_GPL vmlinux 0x0891d854	kvm_write_guest
++EXPORT_SYMBOL_GPL vmlinux 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL vmlinux 0x08a44367	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x08a71183	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x08a9ccda	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x08b5656a	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0x08bb7e02	mtd_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0952af60	fb_videomode_from_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x097b8d46	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0x098ad6be	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x09a3f7f0	mtd_get_device_size
++EXPORT_SYMBOL_GPL vmlinux 0x09b9731b	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x09ba92a2	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0x09bb945d	pinctrl_lookup_state
++EXPORT_SYMBOL_GPL vmlinux 0x09c367e5	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x09c6133e	of_device_get_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x09c71abd	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL vmlinux 0x09f14039	of_irq_parse_and_map_pci
++EXPORT_SYMBOL_GPL vmlinux 0x09f8a38e	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0x09f9cafb	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0a0111c8	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x0a0e11ca	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x0a4e57c1	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0x0a550f2c	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0x0a58e3f1	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0x0a5b92b4	mark_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x0a7d7a1c	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x0a85ea2a	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x0aa52085	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0aac96e6	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0x0ac4862c	of_mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x0acf6170	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0x0ad9e282	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x0af9304d	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x0afd4610	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b1dac4f	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x0b49a2b5	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x0b5f0f0c	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0x0b6a86fb	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x0bb3e9f3	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0x0bbae511	return_address
++EXPORT_SYMBOL_GPL vmlinux 0x0bbeb0e9	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x0bde0fa0	clkdev_create
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c28d057	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c4393da	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0x0c450e10	kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0x0c611f71	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0x0c6dab5e	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0x0c70865f	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0x0c70e1bc	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x0c71ae41	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0x0c8d39bd	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x0c99151e	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL vmlinux 0x0cabfad3	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0cd66eab	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x0cd6a4bb	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0x0cee06cc	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0x0cf3b1d8	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x0cf462c7	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x0cf6e2f3	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0x0d2260e3	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x0d3b0ae6	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d4e2b49	genpd_dev_pm_attach
++EXPORT_SYMBOL_GPL vmlinux 0x0d4f6187	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x0d522b9a	mtd_block_isreserved
++EXPORT_SYMBOL_GPL vmlinux 0x0d589aba	clk_hw_get_num_parents
++EXPORT_SYMBOL_GPL vmlinux 0x0d5923ca	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0d80bf40	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL vmlinux 0x0d9766fd	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x0d9e8754	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0x0dc929dd	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0de15d79	pinctrl_get_group_pins
++EXPORT_SYMBOL_GPL vmlinux 0x0e5b9f1f	mv_mbus_dram_info_nooverlap
++EXPORT_SYMBOL_GPL vmlinux 0x0e5e6d99	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x0e607d5b	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x0e667631	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0e687037	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL vmlinux 0x0e7d48a4	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x0e7e201d	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x0e8a574a	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x0e946c1b	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0x0ea55a83	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x0ee24537	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL vmlinux 0x0ef0517c	nd_device_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x0ef9790d	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0x0f12be19	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x0f20a5bb	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0x0f27a6cb	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0x0f289ac1	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f49ec7b	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x0f49f121	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0x0f60dc7f	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0x0f68b8ad	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x0f73b376	omapdss_of_get_first_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0fc8fc16	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x0fdb9d75	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x0ff9af09	cpdma_ctlr_int_ctrl
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x103259f0	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1034b45d	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x1047381d	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x1047a55f	ti_cm_get_macid
++EXPORT_SYMBOL_GPL vmlinux 0x104c9b69	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL vmlinux 0x104f346a	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x105991e8	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0x106ef757	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0x106f9c51	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0x1073f2d6	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x1093d196	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x109444ca	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL vmlinux 0x10b0bb3a	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x10d89835	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x11025677	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x110a83e1	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0x11211dc4	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x112d9b15	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x112f96f0	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x115d5fc9	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x116eadae	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x118285a4	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL vmlinux 0x118b8b9b	nvdimm_bus_check_dimm_count
++EXPORT_SYMBOL_GPL vmlinux 0x11b07b38	pm_genpd_add_subdomain
++EXPORT_SYMBOL_GPL vmlinux 0x11c55df5	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0x11c916b6	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x11d7589e	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x11f09ad2	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x125d89cb	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x126defbe	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x127de08d	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x127e0572	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x128a4e38	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x12cf9bd5	__clk_mux_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x13059625	of_dma_get_range
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131b301f	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x131ea56f	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0x13219e49	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0x134e95ec	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1381d4f3	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x1386d6c4	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x13984ba7	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0x13ad647f	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x13b53f78	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x13b89dee	pinctrl_request_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x13ca3649	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x13d6ecb9	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0x13fc2f8d	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0x140e2be2	dev_pm_opp_find_freq_exact
++EXPORT_SYMBOL_GPL vmlinux 0x14113b48	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x142f240e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0x14451d31	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0x14611525	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x146fda6c	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0x14a98a21	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x14ca398b	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x14d7535a	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0x14d9282a	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0x14f09e04	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x14feea4f	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0x150ad6ee	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x152dc323	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0x154f6f8a	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x15702fe9	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x157833eb	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0x15837d07	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x1591e4ed	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0x159c92ae	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0x15b29973	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0x15eddbde	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0x15eec147	of_irq_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x15f41a9b	pinctrl_force_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x15fb77bc	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x161eacf9	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0x1621b6bf	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x1652d8ca	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x165d9fa7	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0x1680cd35	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0x16859fbd	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL vmlinux 0x168d1159	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0x16af2e27	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x16b6cd2c	dev_pm_opp_get_max_clock_latency
++EXPORT_SYMBOL_GPL vmlinux 0x16d45cdc	snd_soc_resume
++EXPORT_SYMBOL_GPL vmlinux 0x16f020bb	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0x16f9cd52	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x1707f752	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x1717a05d	omap_get_plat_info
++EXPORT_SYMBOL_GPL vmlinux 0x17228b2c	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL vmlinux 0x172d0a9e	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x1761fbbe	dapm_clock_event
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x177f6c95	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL vmlinux 0x178034b3	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x17b4c5d4	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL vmlinux 0x17d97f44	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x17db45bb	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1825bea8	dev_pm_opp_of_remove_table
++EXPORT_SYMBOL_GPL vmlinux 0x1831473f	of_prop_next_u32
++EXPORT_SYMBOL_GPL vmlinux 0x18344a1b	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x18775a01	sm501_set_clock
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x1897f28c	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0x18aa890b	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0x18baf690	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0x18d55483	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x18e6cb3d	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0x18ef0ce7	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x18fcb215	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0x19017911	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x190f14b0	mtd_device_parse_register
++EXPORT_SYMBOL_GPL vmlinux 0x192441c6	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x1927a4c9	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x19343b68	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x194f124f	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x195dc417	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x1970827c	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL vmlinux 0x1977af96	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL vmlinux 0x1979165c	of_console_check
++EXPORT_SYMBOL_GPL vmlinux 0x197f830b	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x1990f8ff	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19af0597	omap_pcm_platform_register
++EXPORT_SYMBOL_GPL vmlinux 0x19b61808	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x19b8783d	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x19c1d455	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0x19e6a978	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0x19f164eb	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL vmlinux 0x19f34261	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x19f6e136	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0x19f991e8	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0x1a0d7480	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x1a1c4082	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x1a3a3cf5	pinctrl_select_state
++EXPORT_SYMBOL_GPL vmlinux 0x1a4416b5	i2c_slave_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1a4a628e	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x1a5f6e49	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1a7cb267	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x1a8b0523	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1aabe552	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1ae43f07	__mtd_next_device
++EXPORT_SYMBOL_GPL vmlinux 0x1ae556ca	of_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x1b21ea2c	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1b3261e0	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x1b3af596	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0x1b52db1c	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x1b8822d8	pinctrl_gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1bb5fc26	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x1bc5eebe	pinctrl_gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x1bd0ddf5	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0x1bd96369	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0x1be5abc8	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0x1be6791c	musb_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x1bf960c3	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0x1bfe3408	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0x1c0ad03c	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x1c12c627	sm501_misc_control
++EXPORT_SYMBOL_GPL vmlinux 0x1c20a42e	dev_pm_opp_get_freq
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c5a7391	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c5ff742	clk_get_phase
++EXPORT_SYMBOL_GPL vmlinux 0x1c716881	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0x1c73b82d	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1cc42df1	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0x1d084215	ahci_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x1d0c2aab	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d2e8081	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0x1d409c5d	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0x1d45f8d2	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0x1d4d65ab	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1d7cb586	clk_register_fixed_rate_with_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x1d96f842	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x1da61f63	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x1dc0eec2	kvm_io_bus_write
++EXPORT_SYMBOL_GPL vmlinux 0x1dcce6ac	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL vmlinux 0x1dcf75cc	iommu_capable
++EXPORT_SYMBOL_GPL vmlinux 0x1de3c028	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0x1dea470d	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1debe39e	of_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x1dfceff2	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x1e0313ad	mtd_block_markbad
++EXPORT_SYMBOL_GPL vmlinux 0x1e1de161	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1e30e8e1	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0x1e4a1f23	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e60a213	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e7d6157	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1eb520ba	pinctrl_dev_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ed06793	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0x1eddfdff	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0x1eea89c9	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1efd3519	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL vmlinux 0x1f13dcc2	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x1f3799cd	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0x1f47a447	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x1f5a0c88	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0x1f63a4b2	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0x1f6dfa63	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1f774f46	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x1f7cd2d3	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1fb9cd81	of_thermal_get_ntrips
++EXPORT_SYMBOL_GPL vmlinux 0x1fc5a76f	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x1fcb272f	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x1fce24d9	vchan_init
++EXPORT_SYMBOL_GPL vmlinux 0x1fd5bcbb	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL vmlinux 0x1fda30b9	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x1fea3e33	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x1ff6c8b8	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x1ffa27b1	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x200a7ebe	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x200d4c9d	sdhci_set_clock
++EXPORT_SYMBOL_GPL vmlinux 0x201cf71a	snd_soc_component_read
++EXPORT_SYMBOL_GPL vmlinux 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL vmlinux 0x203e5322	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x204a30b5	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x205c01a5	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0x205f1c8b	kvm_read_guest_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x205f5dbe	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x20672c1d	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0x20797db0	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0x2081f581	bgpio_remove
++EXPORT_SYMBOL_GPL vmlinux 0x209469e1	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x209a0d1e	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x20aa179b	usb_gadget_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x20b4c52e	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x20ddded6	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL vmlinux 0x20e51e80	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0x20e70ad2	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x20f269f6	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x210e604f	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x21180eab	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0x21233c34	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0x212d7c19	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x21301cca	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x21395662	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x21644466	of_pci_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x21667e6f	pinctrl_utils_reserve_map
++EXPORT_SYMBOL_GPL vmlinux 0x216b90cb	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0x216e28a0	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0x21933754	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x21a563da	clk_get_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21c05b34	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21d9fb14	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0x21e42e7d	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x21f3143e	of_modalias_node
++EXPORT_SYMBOL_GPL vmlinux 0x21febf58	clk_register_mux_table
++EXPORT_SYMBOL_GPL vmlinux 0x220bba9d	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL vmlinux 0x223a5911	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x226a674d	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2274e9ac	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x2296d59d	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL vmlinux 0x22d31632	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0x22dc37a8	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x22f1b035	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x22f2097a	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0x22f2eb54	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x2315a82c	clk_mux_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL vmlinux 0x233997a1	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x235d37c7	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x236c32b5	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x23756cdb	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x2383618b	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x2392f1a5	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x2396c7f0	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0x23a440f3	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0x23af318c	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0x23b21505	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x23b34307	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x23b667fa	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x23d2189a	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0x23d6e708	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x24002676	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x240dc25b	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x24452f53	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x244c1899	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0x24577519	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24cd53c6	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x24e8e69a	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24efe2dc	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x2517807c	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x25208417	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x25379e73	clk_set_min_rate
++EXPORT_SYMBOL_GPL vmlinux 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL vmlinux 0x2561399e	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0x2573287d	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x25820163	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x25c59929	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x25e4fa8c	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x25e64405	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x26025146	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0x26085a7e	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x261098a6	of_display_timings_exist
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x2635ef7e	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x2651b860	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x2665cbd0	mtd_add_partition
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x267aa372	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x268ccb27	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x26adb815	thread_notify_head
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c547c0	bL_switcher_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x26c8b665	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26cc97e9	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x26e02ba4	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL vmlinux 0x270a642f	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0x270fa97e	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x2725aa52	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0x27356469	of_get_nand_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0x273dd22b	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x274cf5e1	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x274f9f9c	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0x27526c33	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x2757afb0	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x275b869f	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x2764a786	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0x2766d6ee	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0x2787518f	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL vmlinux 0x2787db00	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x279ceaca	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x279d925b	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x27a82a23	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27ca7a1c	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x27d5815f	snd_soc_platform_read
++EXPORT_SYMBOL_GPL vmlinux 0x27d6ce6a	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL vmlinux 0x27dcbd91	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x27e2024e	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x27fdaf94	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0x280a609b	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0x281914a0	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x281b05ff	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x2841362f	of_usb_update_otg_caps
++EXPORT_SYMBOL_GPL vmlinux 0x28428026	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x286abb55	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x287e0e8a	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x28953f61	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0x28b0ed78	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x28cb2b0b	of_platform_depopulate
++EXPORT_SYMBOL_GPL vmlinux 0x28e898f2	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x28ecba9b	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x290dab1f	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x293b89f1	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x29855651	of_pci_parse_bus_range
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x299a0069	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0x29a5c27d	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x29c4bb79	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x29cb35a7	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x29cd97c4	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x29ec27c6	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL vmlinux 0x2a095036	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x2a1959ed	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x2a2c212b	ahci_set_em_messages
++EXPORT_SYMBOL_GPL vmlinux 0x2a59f946	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x2a610fa1	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0x2a63df2e	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a816a05	dev_pm_opp_of_cpumask_add_table
++EXPORT_SYMBOL_GPL vmlinux 0x2a8c66d6	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x2aa77e56	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x2aa9e2fb	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x2aaabe63	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x2aae43f7	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x2ac762fb	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x2ad52abb	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x2ad9d326	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x2af95b62	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b3fd87e	__put_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0x2b54aa52	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x2b57d26b	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x2b588a5d	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0x2b639d66	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2b695c17	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x2b70216b	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x2b7d260d	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0x2b880747	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0x2b8b924f	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL vmlinux 0x2b8c6988	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x2b905d1c	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x2b952517	clk_has_parent
++EXPORT_SYMBOL_GPL vmlinux 0x2b9964c8	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0x2ba9f68f	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0x2babe81f	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x2bad9c6a	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x2bb2c6ef	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x2bdabd76	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL vmlinux 0x2bdb1788	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x2bea1833	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa985e	nd_cmd_dimm_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2bfaeb23	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x2c144892	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x2c179d23	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c21320d	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL vmlinux 0x2c278592	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0x2c2c11ab	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c634655	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c97f8a2	of_reconfig_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2c990b99	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x2ca67bc8	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x2cac2409	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x2cd1f822	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x2cd357d1	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x2ce152cd	pinctrl_utils_add_map_configs
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2ced3de3	clk_gpio_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d2e2f02	omap_dm_timer_read_counter
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d4279fd	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d5cfb4e	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x2d6d2e54	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x2d831a7a	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL vmlinux 0x2da3ecbb	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0x2dad9b05	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x2db1161d	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x2dcc544a	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0x2de681b6	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x2defbd9f	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x2df42a92	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x2e015688	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0x2e0bd101	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL vmlinux 0x2e10ee08	mtd_erase_callback
++EXPORT_SYMBOL_GPL vmlinux 0x2e220e41	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e278f88	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e728db6	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x2e742b00	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0x2e7928c6	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0x2e7b2850	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x2e7dae0d	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0x2e9670c0	pl320_ipc_transmit
++EXPORT_SYMBOL_GPL vmlinux 0x2ea1d373	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0x2ea2496a	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2ea61fef	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ec53d99	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2ece9a5d	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x2ef4d512	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x2ef6b5bf	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x2f05441c	of_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f1842f4	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0x2f1e39a4	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x2f216306	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x2f27560f	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x2f2c4ac2	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0x2f308d75	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x2f319bb0	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f5ace35	mpc8xxx_spi_tx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x2f5ddece	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x2f61f86f	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x2f632918	of_pci_get_devfn
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f781546	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x2f8e74c5	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x2f90da7e	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0x2fc713b8	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x2fc7b541	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x2fffca24	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL vmlinux 0x300edce9	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x301d717b	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x3023968c	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x3035af8d	otg_ulpi_create
++EXPORT_SYMBOL_GPL vmlinux 0x303c1831	of_overlay_create
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x3064ecce	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0x3070002a	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x308d7ccf	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0x308fea6d	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x30966a3f	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x309b4c33	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x30a295de	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x30a2b5f5	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x30a4f4ca	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0x30ae4bd5	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30d442ab	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0x30f18c9d	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0x30fa0f0a	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL vmlinux 0x30fba1c8	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x3100bf02	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3119e15f	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x311d2903	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x313fa316	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x31449015	sdhci_add_host
++EXPORT_SYMBOL_GPL vmlinux 0x315aae23	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x3166fa65	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0x317bc1e8	kvm_read_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x31b86180	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31ddadce	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0x31e89a10	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0x31f701c5	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x31fd1d0e	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x3213831b	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x321b2e20	find_module
++EXPORT_SYMBOL_GPL vmlinux 0x322729f9	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0x3248fab7	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x3250e5aa	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x325169c5	kvm_init
++EXPORT_SYMBOL_GPL vmlinux 0x3252fb6e	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x3264cac9	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0x32802c4c	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x32806de4	kvm_vcpu_gfn_to_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x328a2ba1	amba_apb_device_add_res
++EXPORT_SYMBOL_GPL vmlinux 0x32924a4d	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x32959917	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL vmlinux 0x3295ec8b	of_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0x32bc0fcf	preempt_notifier_dec
++EXPORT_SYMBOL_GPL vmlinux 0x32c2e9b0	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32cd4c08	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0x32d4e5b7	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0x32f97a8d	thermal_zone_of_sensor_register
++EXPORT_SYMBOL_GPL vmlinux 0x3315e038	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0x331cd0e9	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0x333e0819	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3360c3e0	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x336a4b69	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x3377e95d	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x338f9601	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x33aa7e1b	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x33cd8089	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0x33fc6ef4	dev_pm_opp_of_cpumask_remove_table
++EXPORT_SYMBOL_GPL vmlinux 0x33fc9851	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0x33fefed6	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x340a1c98	kvm_vcpu_block
++EXPORT_SYMBOL_GPL vmlinux 0x341643ba	omap_dm_timer_modify_idlect_mask
++EXPORT_SYMBOL_GPL vmlinux 0x3432f510	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x34331d5e	nd_fletcher64
++EXPORT_SYMBOL_GPL vmlinux 0x345f8e4f	irq_chip_ack_parent
++EXPORT_SYMBOL_GPL vmlinux 0x347682ce	snmp_fold_field64
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x34814037	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34ac50a4	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x34bb4580	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x34c5bfb5	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0x34d2415d	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3529c221	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x352a5c84	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0x353b8c58	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0x357745a0	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x357c0f5a	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x35a49b54	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x35ac128a	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x35b9ba51	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0x35dcd1f7	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x361886fe	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x362f8627	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x363eadb1	of_irq_get_byname
++EXPORT_SYMBOL_GPL vmlinux 0x3667bd1c	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL vmlinux 0x3669496a	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x36723b0b	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x36728cac	gpiochip_add_pin_range
++EXPORT_SYMBOL_GPL vmlinux 0x368a2604	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36b195f6	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0x36c4c780	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x36c6dc7b	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x36de0ca0	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x36fb7480	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x37096aaf	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0x37198b2f	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0x371dbd7c	gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x37302958	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0x374d9a27	of_property_read_u64
++EXPORT_SYMBOL_GPL vmlinux 0x377bf2f8	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x37b4acd3	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x37c7b1af	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x37df0e23	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x38168e41	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x3825e424	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x38277010	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0x38295c34	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x382aad29	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x382e57f5	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0x382e6a03	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0x384a6981	__gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x38639300	of_overlay_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x386b6a44	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0x38704d8b	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x3879a04d	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x38843bce	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x38a9c2c7	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x38c2ecce	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x38d1d48b	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x38dfb3f4	omapdss_of_find_source_for_first_ep
++EXPORT_SYMBOL_GPL vmlinux 0x38e5bc5a	clk_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x38f784e2	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0x39056c80	nd_cmd_in_size
++EXPORT_SYMBOL_GPL vmlinux 0x39243718	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x3933e066	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0x396c9747	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0x396efb80	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0x3988ecda	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x398a93d0	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0x399e7871	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0x39a5ef2f	of_irq_find_parent
++EXPORT_SYMBOL_GPL vmlinux 0x39c705a4	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0x39c91bde	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39d672fa	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x39f38e38	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0x3a146390	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x3a14e0ee	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x3a15a2b5	of_pci_range_parser_one
++EXPORT_SYMBOL_GPL vmlinux 0x3a15da00	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a2f53e1	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3a3db234	divider_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x3a4938a1	user_read
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a7897ba	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3abbb53a	mtd_table_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x3ac2c59e	of_clk_add_provider
++EXPORT_SYMBOL_GPL vmlinux 0x3acc3cd8	kvm_vcpu_init
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3ae93636	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3af0eb02	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3b2a191e	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0x3b3f4d6d	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0x3b525151	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x3b547bc9	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x3b696a56	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0x3b6df45b	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x3b86556c	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x3b87394b	__tracepoint_detach_device_from_domain
++EXPORT_SYMBOL_GPL vmlinux 0x3bb6fbe7	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0x3bc6b0ac	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x3bdaf384	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0x3becb6c1	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x3bfa6694	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x3c460f1d	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x3c46dbe3	snd_soc_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x3c69bd85	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0x3c7c3323	snd_soc_read
++EXPORT_SYMBOL_GPL vmlinux 0x3c831441	arm_check_condition
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3c93ea25	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x3ca6f434	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x3caab1cc	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0x3cc8fba8	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL vmlinux 0x3ccbbad0	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cd37be7	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x3cdb4fd7	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x3ceb10bf	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL vmlinux 0x3cf637c8	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3cff5f30	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x3d0dd39b	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x3d16f4d0	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0x3d35ec4b	iommu_get_domain_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d38976c	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0x3d3d7f9c	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x3d6cbf2e	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0x3d7940da	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3d7dd329	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x3d815b5b	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x3d9573aa	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d9a80a5	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3da378f5	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x3dc264f7	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0x3dc526a9	arizona_of_match
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1182c	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3dd4d3a7	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3e06087f	mtd_is_partition
++EXPORT_SYMBOL_GPL vmlinux 0x3e1f72e0	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL vmlinux 0x3e2d6df3	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3e31d9c3	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x3e410620	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e68089c	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0x3e69377a	sdhci_alloc_host
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e719862	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL vmlinux 0x3e8f20f8	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0x3e9e4c1e	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x3eb8fd66	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0x3ebee169	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x3ef502ce	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f0e2941	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL vmlinux 0x3f231773	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0x3f29cb03	to_nd_region
++EXPORT_SYMBOL_GPL vmlinux 0x3f2db59d	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x3f489732	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x3f664fa5	__tracepoint_map
++EXPORT_SYMBOL_GPL vmlinux 0x3f736d50	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x3f9028d7	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL vmlinux 0x3fa5af9c	nd_cmd_bus_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3fa9bfdc	of_alias_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x3fdcc3b1	of_get_regulator_init_data
++EXPORT_SYMBOL_GPL vmlinux 0x3fe2313d	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0x3fe9f665	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0x40059e4a	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x401efcf6	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0x402774be	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x402a1330	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0x402eaaaf	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x406e8d0c	amba_ahb_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x408085fa	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4094fda5	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x409f12e4	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x40a50b02	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0x40abfa54	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x40aecc10	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40b119e1	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x40c494c7	md_run
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40d741ad	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x40f8b582	pm_genpd_syscore_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x4115db6e	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x4127f09a	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x413889f6	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x414cadd4	get_device
++EXPORT_SYMBOL_GPL vmlinux 0x41525bed	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x419dcb9d	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL vmlinux 0x41c5274c	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x41ca2af0	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x41dcb534	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x41ede885	of_clk_get_parent_name
++EXPORT_SYMBOL_GPL vmlinux 0x41eef2c7	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0x4205ad24	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x42141100	of_pci_msi_chip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x421d89b7	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x42618eb0	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x426203d7	nvdimm_blk_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x42635d55	pm_suspend_global_flags
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42884cfc	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x428a8775	sdhci_get_of_property
++EXPORT_SYMBOL_GPL vmlinux 0x42a660cc	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x42ba5376	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0x42e5feb7	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x42f5871f	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x43002d21	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0x4300976d	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4318c5bc	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x4337cc02	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0x43436969	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x434864d4	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0x434d3586	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0x4353b267	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0x43619e1a	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x4363ff57	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x43772e71	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x43797b99	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x438b17af	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43b466b0	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43ea400e	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x43f19b53	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x43f81957	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x44020321	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x441b4e5a	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x442e5567	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x443fa49f	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0x444f1735	cpu_pm_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4450f1ff	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x445b4889	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x445d8df9	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x445f2fe8	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0x44680073	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x4482a5c4	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x4496f109	kvm_vcpu_read_guest_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x449e7e75	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0x44af6314	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44c130b1	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0x44cce7f8	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x44f1cd1d	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x45076d7a	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x45586a4f	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0x457267f1	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x45947066	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0x45aec56f	omap_iommu_save_ctx
++EXPORT_SYMBOL_GPL vmlinux 0x45ba1367	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45f1044c	mtd_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x45fb14c4	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x46066e5b	perf_pmu_name
++EXPORT_SYMBOL_GPL vmlinux 0x460b07ac	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0x46157ef9	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x4624f87a	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x462a125d	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x4638ffec	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x466e5342	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4689fb6d	device_register
++EXPORT_SYMBOL_GPL vmlinux 0x468fd6a4	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x46ab43a7	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0x46ba3e92	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL vmlinux 0x46c89986	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0x46c8b0b6	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0x46cd261e	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x46d81da3	snd_device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x46d88039	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x46dca8f3	amba_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x46f94eb5	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x4715ffcf	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x472b086d	dev_pm_opp_find_freq_floor
++EXPORT_SYMBOL_GPL vmlinux 0x4744b9fd	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x474d46ab	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x477b3845	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x4785131d	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x4793391e	ahci_platform_resume_host
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47acf6e1	dev_pm_opp_init_cpufreq_table
++EXPORT_SYMBOL_GPL vmlinux 0x47b0d809	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x47b7ba5e	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL vmlinux 0x47de0dc7	clk_unregister_mux
++EXPORT_SYMBOL_GPL vmlinux 0x47ecbcfa	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x47f2166f	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0x48068121	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0x482873b3	mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x482a7f0f	deregister_mtd_parser
++EXPORT_SYMBOL_GPL vmlinux 0x483d6826	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x484b38c8	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x48591f65	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL vmlinux 0x486040de	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x4871fb7c	__tracepoint_io_page_fault
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x487eebaa	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x48b1a4ae	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x48c08c21	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x48f7dc74	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x48f8e48c	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0x490a183d	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0x4911c3b8	of_regulator_match
++EXPORT_SYMBOL_GPL vmlinux 0x49360275	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x4947e66c	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x494b7154	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL vmlinux 0x4982a57f	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x49c3c708	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x49d16e13	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x49d85db0	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x49e7aed4	gfn_to_hva
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4a160060	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x4a2fbb20	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x4a365e30	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x4a371044	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a53db2e	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0x4a5f914b	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0x4a63f3b2	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x4aa540ab	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0x4aa80b37	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4ab1a16b	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x4aef096b	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0x4b114ee6	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x4b1b764e	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x4b3a507d	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x4b3d72e7	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x4b42a33a	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4b4bf0e7	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x4b4fda43	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x4b52bcb6	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x4b567231	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0x4b7c8e00	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0x4b96a515	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x4b9e5c21	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0x4bafcdd8	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0x4bba85aa	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0x4bd369e1	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4be810e3	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL vmlinux 0x4bed7645	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x4bf4b4a7	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0x4c0809ab	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0x4c0b1077	of_dma_configure
++EXPORT_SYMBOL_GPL vmlinux 0x4c189442	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x4c19cd0b	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x4c3d11ef	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0x4c442f13	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0x4c45c55f	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0x4c45f4e9	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0x4c47ec15	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x4c599055	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x4c5c98f8	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c6ff881	pinctrl_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x4c772c32	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0x4c80ebf9	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0x4c82cdd3	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x4c8464be	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4ceee4ef	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d1c2489	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x4d26c955	irq_of_parse_and_map
++EXPORT_SYMBOL_GPL vmlinux 0x4d38f1e0	bL_switcher_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4d506578	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0x4d75422d	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0x4d97842a	omap_dm_timer_get_fclk
++EXPORT_SYMBOL_GPL vmlinux 0x4d98b3ff	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4dbbad50	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4dbe8d71	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x4dc1c0df	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0x4ddca622	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4df2e5be	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x4e014593	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0x4e0d016c	of_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e1443fa	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0x4e239671	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e2c2dd2	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x4e376b96	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x4e45b5f7	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0x4e4c371f	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0x4e4d2dd4	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0x4e96ce34	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0x4ec95ab9	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x4ecc4d28	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x4ecce09b	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f03fc3e	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0x4f1fbb29	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f5b52f1	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x4f677e28	ahci_print_info
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4f7200c9	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4f98d766	cpu_pm_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4f9c7dca	nvdimm_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x4fa5db8c	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x4fae1633	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4fc3bd26	omap_dm_timer_start
++EXPORT_SYMBOL_GPL vmlinux 0x4fd8e696	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x50019d0f	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x50337384	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL vmlinux 0x50531396	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0x505b1fd9	dev_pm_opp_disable
++EXPORT_SYMBOL_GPL vmlinux 0x506ac0e2	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0x50806149	pinctrl_dev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x5080c352	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x50a20527	ahci_reset_controller
++EXPORT_SYMBOL_GPL vmlinux 0x50b92a15	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x50c89f23	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x5102e512	amba_ahb_device_add_res
++EXPORT_SYMBOL_GPL vmlinux 0x510e2cff	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x5111ccb6	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0x5129731a	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x5140e0c3	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0x5145abaa	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x514a4b02	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x514e9875	divider_get_val
++EXPORT_SYMBOL_GPL vmlinux 0x514ed70d	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x5183470d	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0x51855f81	__tracepoint_remove_device_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x519951c0	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x51b7db52	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x51dfd03a	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x51f37e85	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x5200c3b4	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x5208e43b	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x52198152	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0x5227143b	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0x524af102	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0x525510b8	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x525f3068	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x526280c7	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0x5272d8bc	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0x5273d6d3	ahci_kick_engine
++EXPORT_SYMBOL_GPL vmlinux 0x528ae66a	of_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x528d6511	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0x5293e294	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0x52a0a7b2	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x52a30a8d	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0x52a41251	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x52b00d70	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x52b1dedd	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x52eda1f1	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x52f26e97	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x5301d42c	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x5324e32b	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0x532fd61e	ahci_platform_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x536723bb	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x536af4b6	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x536d78a6	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x537373ef	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x538a89fc	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x538e84bb	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x53bc5739	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x53c02743	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0x53c2d08a	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x53ce5d85	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x53e92279	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL vmlinux 0x53ee0c2e	pinctrl_find_gpio_range_from_pin
++EXPORT_SYMBOL_GPL vmlinux 0x53fb67a6	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x540f2c28	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x54221bf9	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x5434a263	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x544aab61	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0x544d29e7	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x545e1203	omap_dm_timer_free
++EXPORT_SYMBOL_GPL vmlinux 0x545fec86	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x5475681b	kvm_vcpu_gfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0x547900ff	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x5492204c	__clk_mux_determine_rate_closest
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54994dd8	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0x54aa00b1	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x54ac53ae	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x54d468f1	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x54e2b803	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x54eb144e	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x55016fa8	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x55076506	of_thermal_is_trip_valid
++EXPORT_SYMBOL_GPL vmlinux 0x5511afd0	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x55145f4a	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x552728f6	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0x55291253	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x55526743	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x556e4390	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x55b25570	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0x55d6d6cd	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL vmlinux 0x55e023e2	devm_pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x55f3a45a	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0x55fcf8ac	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0x56137ae8	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x5623d21c	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x5628b12d	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x5661cede	soc_ac97_ops
++EXPORT_SYMBOL_GPL vmlinux 0x566c7212	of_genpd_get_from_provider
++EXPORT_SYMBOL_GPL vmlinux 0x566cc7a0	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x56728b8c	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0x567e6195	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x5699dbcc	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x569c78b1	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0x56b63670	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56e66583	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56e9103b	cpu_pm_enter
++EXPORT_SYMBOL_GPL vmlinux 0x56eeedfc	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x56f3291e	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x56fcf5b0	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0x5711a311	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0x5712e484	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x57293fd1	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0x572a585e	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0x5732661a	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x573de960	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x57528e80	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x579643f7	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x57d32233	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x58063ede	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x580ef1a0	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL vmlinux 0x582db89f	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0x583a7e9b	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x583e644f	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x58500404	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x58727fb5	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x58971a26	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58bf10d1	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x58d42149	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0x591d44ce	pinctrl_pm_select_idle_state
++EXPORT_SYMBOL_GPL vmlinux 0x591f3795	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL vmlinux 0x593f687c	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x5948240a	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0x594cde67	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0x59682233	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0x596b27af	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x596c8eb4	dapm_regulator_event
++EXPORT_SYMBOL_GPL vmlinux 0x597eda79	register_mtd_parser
++EXPORT_SYMBOL_GPL vmlinux 0x599cffaf	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x59a013a0	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL vmlinux 0x59c5c6f4	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x59d4fe58	component_add
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x59eaf979	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x59eb3303	phy_pm_runtime_put
++EXPORT_SYMBOL_GPL vmlinux 0x5a1e89b9	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x5a2021a5	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x5a220bfa	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0x5a25a8e5	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x5a3271b4	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x5a46d264	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0x5a55683a	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x5a568037	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a82a62d	gpiochip_remove_pin_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x5a8f213c	cpdma_ctlr_eoi
++EXPORT_SYMBOL_GPL vmlinux 0x5a976a7e	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x5a988335	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0x5a9badf1	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x5aa81d35	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0x5ab00526	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0x5ac858ad	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x5acf6567	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x5adc4c38	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0x5ae67d3f	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0x5b07bf30	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0x5b36cb6a	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x5b4b56be	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x5b52187d	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x5b580c0c	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5b6362c0	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x5b73c04e	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5b9bfb71	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x5bb415bd	of_devfreq_cooling_register_power
++EXPORT_SYMBOL_GPL vmlinux 0x5bc857c6	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5bdff13e	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x5beba81d	clk_hw_get_parent_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x5c0e2999	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0x5c2fe4a5	cpdma_chan_stop
++EXPORT_SYMBOL_GPL vmlinux 0x5c3c9313	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0x5c42dd7e	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c632dfb	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0x5c643e2f	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x5c724709	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x5c744f0a	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x5c9e661f	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cb0b843	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x5cc31ee1	of_prop_next_string
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5cd5cec2	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0x5cd73e28	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL vmlinux 0x5cecbc93	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0x5cf55b15	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x5d0caaeb	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d153a7a	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0x5d2d1646	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x5d4e7297	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5d589f92	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x5d859088	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL vmlinux 0x5d911453	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x5d914ffe	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0x5d994936	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5dff6fda	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x5e0389d9	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5e04920d	input_class
++EXPORT_SYMBOL_GPL vmlinux 0x5e0496a8	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0x5e10ea8c	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL vmlinux 0x5e1dd66d	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x5e221aba	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x5e271037	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5e515be6	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e53b2b4	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x5e7119f5	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x5e817d88	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x5eb079d9	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0x5ec95927	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0x5eda24d0	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x5ee49601	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x5efa4a8a	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0x5eff8f7f	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5f1f888b	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x5f22400f	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x5f36cb29	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5f416cb0	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0x5f56cce3	of_css
++EXPORT_SYMBOL_GPL vmlinux 0x5f6d62db	cpsw_phy_sel
++EXPORT_SYMBOL_GPL vmlinux 0x5f6f30dd	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x5f834a40	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x5f8b13db	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0x5fa924ab	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x5fce6e75	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x5fec298b	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0x6003ad81	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0x60091316	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x60110d94	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL vmlinux 0x6035b78e	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x60603d5e	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x6075d0c7	omap_tll_init
++EXPORT_SYMBOL_GPL vmlinux 0x609a607e	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60b37a53	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x60bc2817	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0x60cf1bc8	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL vmlinux 0x60d80633	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x60f11a5e	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x60f52dde	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x610ff330	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0x612c3cc7	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x614dafe7	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x615286cc	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL vmlinux 0x61828a42	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x6184006a	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x618df166	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0x6193778a	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0x61a40dc3	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0x61b17023	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x61f4fd49	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x61fe6f8e	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x61fecd86	of_resolve_phandles
++EXPORT_SYMBOL_GPL vmlinux 0x61ff3859	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0x62153f50	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x624fb1fc	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0x62603c96	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6265b82d	of_irq_to_resource_table
++EXPORT_SYMBOL_GPL vmlinux 0x627bc4fe	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0x628f1439	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x6299e241	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x62a0d2b0	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0x62b3ca3d	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL vmlinux 0x62bd384b	to_nvdimm_bus
++EXPORT_SYMBOL_GPL vmlinux 0x62fda225	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0x6303a81b	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x6304e2de	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x63128661	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x63150e06	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x631bec24	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0x632bd050	get_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0x63380096	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL vmlinux 0x633b45d2	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x635ee8a0	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x637f35c4	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x6398dd2c	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0x63daf8c1	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0x63ddf1c4	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x63e17b86	divider_recalc_rate
++EXPORT_SYMBOL_GPL vmlinux 0x63ef4e12	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x64154792	of_thermal_get_trip_points
++EXPORT_SYMBOL_GPL vmlinux 0x64256424	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0x64262697	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x642ea09d	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x64348592	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x643e23a0	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x647537f3	pl320_ipc_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x648c7ea3	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0x649f0259	pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0x64a58b8e	cci_ace_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x64c80ebe	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x64edceb3	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x650015d6	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x653e5617	mmput
++EXPORT_SYMBOL_GPL vmlinux 0x65427d72	__tracepoint_attach_device_to_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6543258d	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x65537437	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x655c0b96	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x655e8a4b	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x655fcb8c	icst_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x657c58c9	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x65b79aa1	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65fb4796	nd_mapping_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x65fe0be6	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0x660e64d6	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6612597e	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x66150b1c	mtd_panic_write
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x66241b3c	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x66278cd4	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x664730bd	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0x665a7aa5	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x6698e5f6	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x66b3b95c	mtd_is_locked
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66cf494c	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66dec9ac	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x66e1cbb5	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0x66f25737	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0x6716a75a	mtd_erase
++EXPORT_SYMBOL_GPL vmlinux 0x671c151d	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0x671ec237	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x67246327	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0x672d6cce	ahci_stop_engine
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x675f90b2	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL vmlinux 0x677d9d9e	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x67836326	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x67a185b0	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x67d79b06	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0x67e351cf	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x6807c54a	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x681c126b	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0x681c5b4e	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0x683ec6ff	mtd_read
++EXPORT_SYMBOL_GPL vmlinux 0x6861aa4f	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x68729cd4	nd_blk_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x68ad02f7	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x68d6b859	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x68dead90	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x68e47b2c	cpdma_ctlr_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x69080880	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x69085501	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x691c90e5	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x69381d5e	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x6945725e	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0x694be42a	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0x695e7177	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0x6961148a	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6964b725	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x6993f45a	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x699caa17	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0x69afe92b	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x69cf103e	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x69f664fc	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x69fd877a	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a531bc7	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL vmlinux 0x6a5c92ed	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0x6a5f57ef	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a653bb1	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6a6fc0f8	vchan_find_desc
++EXPORT_SYMBOL_GPL vmlinux 0x6a79a2f5	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x6a79dcab	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x6a80c38a	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x6a9382a2	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x6aaef616	ahci_save_initial_config
++EXPORT_SYMBOL_GPL vmlinux 0x6ab26f5e	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0x6ab59ae3	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6abd4a45	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0x6ad66267	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0x6aecced8	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0x6aefca67	kvm_read_guest
++EXPORT_SYMBOL_GPL vmlinux 0x6b03b25a	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0x6b0466b2	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b41e75e	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0x6b6c57dd	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0x6b76df34	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6b95e900	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0x6bc68544	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0x6bc78f50	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0x6bc8e6eb	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6bc8ecbc	ahci_init_controller
++EXPORT_SYMBOL_GPL vmlinux 0x6be28f0a	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x6bef476e	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x6bf09579	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x6c04ca49	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c1c6038	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x6c1e9f72	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0x6c1f4475	omapdss_of_get_next_port
++EXPORT_SYMBOL_GPL vmlinux 0x6c209eab	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x6c2cb894	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0x6c32ee3e	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0x6c363743	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x6c41fe66	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6c4a3773	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c64f886	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0x6c6d3e21	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0x6c6f8747	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x6c73cac2	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0x6c767a57	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6c906f4e	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cb37c66	ahci_platform_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6cc78d88	of_get_pci_domain_nr
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6cd6edcc	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x6cee693a	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6cfeb98c	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x6d24f235	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d315499	clk_hw_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x6d424356	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x6d585dd8	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0x6d5f28e4	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0x6d61e45e	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0x6d62ab7c	kvm_clear_guest
++EXPORT_SYMBOL_GPL vmlinux 0x6d744796	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6d8166eb	snd_pcm_hw_constraint_eld
++EXPORT_SYMBOL_GPL vmlinux 0x6d99e9f0	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0x6da87fc2	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x6dce091e	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0x6dd5cfc7	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x6dda2622	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0x6ddc42f2	ahci_check_ready
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e102977	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL vmlinux 0x6e1801f4	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0x6e2842fc	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL vmlinux 0x6e300482	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0x6e31ad7d	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0x6e3faea9	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0x6e42b3bf	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x6e51afc8	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x6e6e16dd	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6e78e340	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6e9f25ac	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x6ec974a8	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x6f015e6b	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x6f01fce2	mount_mtd
++EXPORT_SYMBOL_GPL vmlinux 0x6f046506	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x6f0d167b	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x6f12afe2	of_property_count_elems_of_size
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ae0e5	power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f23ed1b	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0x6f26e5b7	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x6f2b03ce	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6f318afa	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x6f3a746e	vchan_tx_submit
++EXPORT_SYMBOL_GPL vmlinux 0x6f50d60c	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x6f5c638f	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x6f65c26c	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0x6f76c1f3	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6f806896	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL vmlinux 0x6fd39226	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x6fde4559	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6feb94db	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x6ffde44b	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x702837c7	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0x702d1a28	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x7038cf28	nvdimm_create
++EXPORT_SYMBOL_GPL vmlinux 0x7040b4cc	device_create
++EXPORT_SYMBOL_GPL vmlinux 0x704d5ab0	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x705a89c9	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x709af3b2	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0x709eacdf	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70e6ecda	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x70efdd70	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x71008581	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x7102f7df	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x71031b41	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x713510c0	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x71387211	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x714aa194	max_gen_clk_probe
++EXPORT_SYMBOL_GPL vmlinux 0x714bae0b	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL vmlinux 0x714eae11	clk_register_gpio_mux
++EXPORT_SYMBOL_GPL vmlinux 0x714f0ae6	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0x7152bb56	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x71738a83	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0x719e17ff	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x71a602da	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x71a82b6e	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL vmlinux 0x71c88aba	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x71d99d6e	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71ea38be	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL vmlinux 0x72387e4e	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x7246777c	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x724b1f37	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x72515d5a	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x725ed72c	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0x725f76f0	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7274c394	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x7291019b	__cci_control_port_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x72ac11e0	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x72c2a689	dev_pm_opp_free_cpufreq_table
++EXPORT_SYMBOL_GPL vmlinux 0x72d423d1	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x72d4a115	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0x730bd0c7	asic3_write_register
++EXPORT_SYMBOL_GPL vmlinux 0x731dc79c	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x732a30d9	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL vmlinux 0x733da5c4	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x7348616e	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL vmlinux 0x736f0508	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x73825de9	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x7397f752	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73a9649b	nvdimm_name
++EXPORT_SYMBOL_GPL vmlinux 0x73b61628	arizona_of_get_named_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x73b98231	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0x73bce536	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x73c63f84	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73e1dbd8	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x73f87afe	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x742bd64c	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x743073cf	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x743f9192	sdhci_resume_host
++EXPORT_SYMBOL_GPL vmlinux 0x7446b9be	of_get_nand_on_flash_bbt
++EXPORT_SYMBOL_GPL vmlinux 0x744dd58b	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x744fa546	cpsw_ale_dump
++EXPORT_SYMBOL_GPL vmlinux 0x7463989a	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x747740b6	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0x74822ae2	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x748b8ef3	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x752eac53	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL vmlinux 0x754861fa	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x75490de3	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x7559ff3e	of_get_nand_ecc_step_size
++EXPORT_SYMBOL_GPL vmlinux 0x755f0528	ahci_platform_ops
++EXPORT_SYMBOL_GPL vmlinux 0x7573c011	of_clk_del_provider
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x759139cb	of_pci_check_probe_only
++EXPORT_SYMBOL_GPL vmlinux 0x7592a7e0	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0x75a16305	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0x75aa97f0	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x75ca6a02	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75e0a627	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0x75f51050	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x760d93d6	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x761e0aca	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0x76250380	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL vmlinux 0x762b684c	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0x764928a2	cpdma_chan_create
++EXPORT_SYMBOL_GPL vmlinux 0x7649c16a	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x7653e10a	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0x765e6c3c	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x767e4510	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x768bf6b0	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0x76a8e543	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0x76bd3278	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x76bd96d1	ahci_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x76d9b876	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0x76f99dd9	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x770cf981	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x770eab5e	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x7743a85e	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x7757b51a	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7780f44b	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0x77840b00	devm_pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0x7788b5e1	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x779c54ae	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x77a7c1d2	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x780c0b68	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL vmlinux 0x78373050	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x783dae95	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x783f6bce	sm501_unit_power
++EXPORT_SYMBOL_GPL vmlinux 0x78423bb3	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x78628a16	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL vmlinux 0x787723ad	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0x787f5b69	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x78852e17	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0x78882cb5	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0x788b74bf	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78b41990	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x78d43a11	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x79234b93	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0x7924ba57	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x792f5c0e	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x793b4742	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0x7941bab2	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794612ee	pl08x_filter_id
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x7952a58f	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0x795598db	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7956edd2	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x79596515	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x795f99f0	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x796b0da7	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x79874af3	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL vmlinux 0x799bac52	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0x799d2b0e	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0x79c0ad8b	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0x79c2ea9f	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0x79c6f3f0	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x79c936f9	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0x79cec19e	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x79d05632	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x79d20c0f	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x79ec9da5	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x79edd0ef	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x79f659ac	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x79f77e59	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7a1ae419	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x7a2c9d38	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a319404	clk_register_fixed_rate
++EXPORT_SYMBOL_GPL vmlinux 0x7a3831f4	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0x7a44a21d	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0x7a54b53b	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x7a8e5a33	of_pci_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7a98add8	omap_mcbsp_st_add_controls
++EXPORT_SYMBOL_GPL vmlinux 0x7aa55483	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL vmlinux 0x7ab3ca18	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x7ab84223	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL vmlinux 0x7b0a9dd6	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1586e3	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b35a20a	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0x7b444a8d	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0x7b509ef8	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x7b58c1b0	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0x7b6b503e	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0x7b7e55d5	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7bbd214b	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x7be08ff3	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0x7be2fe03	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x7be9afa6	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x7bf0c03b	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0x7bf7d2b3	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x7c20a09d	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x7c36567e	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x7c6a49ce	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7c9a7371	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x7ca38bcd	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x7cabe163	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x7cae28c9	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0x7cc04d4b	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7cdc90af	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cebeeff	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0x7cf499ce	of_fixed_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0x7d00c65b	nd_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x7d05eaa5	kvm_get_dirty_log_protect
++EXPORT_SYMBOL_GPL vmlinux 0x7d06df08	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d5b578f	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0x7d63e4eb	of_pci_find_msi_chip_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x7d776e72	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0x7d9750f7	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7ddcdcac	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0x7de3b2db	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0x7e1791f4	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL vmlinux 0x7e32df5a	of_get_nand_ecc_strength
++EXPORT_SYMBOL_GPL vmlinux 0x7e3f80d2	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e697b98	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7ea608ba	snd_soc_write
++EXPORT_SYMBOL_GPL vmlinux 0x7eb494c7	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0x7ec349c6	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0x7ed68941	asic3_read_register
++EXPORT_SYMBOL_GPL vmlinux 0x7ee7ce5a	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0x7f1ceed5	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f301662	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7f538b0e	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x7f7609b8	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7fb41eae	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0x7fbb5711	probes_decode_arm_table
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7fc06493	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0x7fec4ee7	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x7feebe85	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x8000b681	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0x8010d2c6	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0x803f6e24	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x804a08c7	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x805524dd	gpiochip_add_pingroup_range
++EXPORT_SYMBOL_GPL vmlinux 0x805e4688	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x805f8f73	omap_dm_timer_request_by_cap
++EXPORT_SYMBOL_GPL vmlinux 0x8062a68c	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x80698a68	pci_ioremap_io
++EXPORT_SYMBOL_GPL vmlinux 0x806f8f62	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x8084889d	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x80963f16	omap_dm_timer_write_counter
++EXPORT_SYMBOL_GPL vmlinux 0x80adb954	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80cb2e7d	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0x80cd9205	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80d85d5e	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x80e9d926	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x80f8589f	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x811da7fd	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x814e3943	dev_pm_opp_of_add_table
++EXPORT_SYMBOL_GPL vmlinux 0x815588a6	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x81563838	pinconf_generic_dt_subnode_to_map
++EXPORT_SYMBOL_GPL vmlinux 0x815a188d	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0x81782986	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x81812b5a	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x8189d9d3	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x819aa39a	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0x81b8c849	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x81bf1d6f	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0x81d58ab8	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x81dbe3bf	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x81e74571	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x81ea9167	of_fdt_unflatten_tree
++EXPORT_SYMBOL_GPL vmlinux 0x81f1f6b0	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x820010d9	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x822ad4c7	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0x8237ea80	ahci_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x8240d316	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x82482b1a	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x82502ab4	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x826224bc	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL vmlinux 0x826daec5	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x8275b47b	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL vmlinux 0x82875704	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x829781da	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0x82a19bcc	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x82a46076	snd_soc_register_platform
++EXPORT_SYMBOL_GPL vmlinux 0x82b285fa	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82dd6e42	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x82ea0d04	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x82f2f7bc	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x831ccbad	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0x833629d8	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0x83596db1	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0x8359b683	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x836d0e60	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x8394433a	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0x83b19129	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0x83bc9278	devfreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x83d69b52	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x844712df	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x845bfb19	amba_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x845c9b7b	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x848bd0fb	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x84912335	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x84a358ee	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x84a44407	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x8506baa8	clk_unregister_gate
++EXPORT_SYMBOL_GPL vmlinux 0x8507a367	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0x850df8b9	clk_divider_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x851aa409	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x85472756	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x854be0a8	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0x855387a1	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x8574ca6c	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x858737ec	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x8591cb94	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL vmlinux 0x85a0e9e5	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x85b98c51	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0x85c22ace	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85cc86b4	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0x85d9fb0d	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0x85efaa49	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0x860c681a	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x862b9816	cpu_topology
++EXPORT_SYMBOL_GPL vmlinux 0x86391ad0	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0x8652110e	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0x8652aa49	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0x8669cb39	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x868a6f18	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x8698aec0	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x86ccbb56	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0x86d6b850	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x86dd3457	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x86dda770	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0x86e04ca2	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0x86eddeaf	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x86fd5d67	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0x8717df8b	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x873227c1	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x87516917	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL vmlinux 0x876471e7	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x877cebc2	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0x877e9a15	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x87a0d82c	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0x87b1fdb4	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0x87b75e2d	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x87bc32c5	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x87e8a719	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x87f32c09	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0x87f895f4	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x88136838	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x883c2740	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x884fc316	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0x8861ff6a	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0x88658396	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x8878fab4	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0x887f9ba8	dev_pm_opp_of_get_sharing_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x88a8333d	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88b90c1b	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x88c4f765	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x88c8da9a	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0x88c8fdb0	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0x88df3a01	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x88f0d274	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0x89074516	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x89185b2d	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x89259e28	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x89510823	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x8966da55	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0x896ada08	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0x89754397	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0x8983de05	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0x899d3f0b	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89c0fb2e	of_get_fb_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x89efdfb6	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x8a00b1f2	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x8a1e3264	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x8a2ad9dc	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0x8a46a378	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x8a54a013	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x8a554a36	mpc8xxx_spi_strmode
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a5df957	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0x8a5f86ce	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x8a79195c	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x8a7b35df	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8a8b0410	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8a989f67	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x8a99f081	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0x8a9a43f8	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8ab9759f	devm_power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8ac4853a	to_nd_blk_region
++EXPORT_SYMBOL_GPL vmlinux 0x8b11c9f6	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x8b149c36	clk_is_match
++EXPORT_SYMBOL_GPL vmlinux 0x8b242dcb	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8b348d29	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8b539e6a	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0x8b6717b8	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0x8b775d3a	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8b89dac6	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL vmlinux 0x8b91f7a7	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL vmlinux 0x8ba97c6f	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x8baa6377	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x8bb3fab5	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0x8bb7ec54	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0x8bcbd63f	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c02471a	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c0f86b9	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0x8c1e2084	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x8c3926d7	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x8c3bd530	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c66a4fe	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL vmlinux 0x8c68158f	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8ca275dc	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8ce0e597	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL vmlinux 0x8d01a787	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x8d027def	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x8d057149	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0x8d13cd99	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d323deb	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0x8d33d8a9	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x8d3cc8ce	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x8d43a7ba	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0x8d4b3af4	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8d4ca0cb	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8d676a4b	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0x8d91d2d9	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0x8d953345	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x8dbbdaf7	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0x8dd527b5	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8de4f0ac	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x8df5d0fe	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0x8e0259bc	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0x8e026055	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL vmlinux 0x8e289b82	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x8e2b25c2	videomode_from_timings
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e42e821	__tracepoint_add_device_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x8e45d76d	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x8e4ec8cf	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8e54bf0f	pinctrl_utils_add_map_mux
++EXPORT_SYMBOL_GPL vmlinux 0x8e6e001d	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0x8e74a5d8	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8e786fb7	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x8e7894bd	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x8ebb1911	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x8ec27e12	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x8ec54f30	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x8ee93b15	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL vmlinux 0x8ef5abea	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL vmlinux 0x8f02eaa2	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f3c7fc5	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x8f5c32fa	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL vmlinux 0x8f6b2a73	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f743e59	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x8f8bd544	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x8f8f1de6	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x8f97aea4	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0x8fa1196b	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x8fa139d3	arm_iommu_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8fb2a5a8	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0x8fb9ecff	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0x8fc5c8d5	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x8fd22de3	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x8fed7fad	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0x900e5606	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x9047c11a	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x904857fa	kvm_vcpu_gfn_to_hva
++EXPORT_SYMBOL_GPL vmlinux 0x904efb78	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90aa2eb8	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x90ddff5f	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x90f711ad	nand_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x9116a3e7	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL vmlinux 0x91237fbd	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x913af2ea	mtd_lock
++EXPORT_SYMBOL_GPL vmlinux 0x915d65d2	pinctrl_register
++EXPORT_SYMBOL_GPL vmlinux 0x915fe361	nvdimm_pmem_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x9175fe97	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x919a2ab3	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x91b77ce6	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91cfe9af	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x923ad842	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x9256e88f	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0x9257667c	mpc8xxx_spi_tx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0x92652448	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x927b9932	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0x929a2833	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL vmlinux 0x929c9744	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x92accbf3	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0x92acd03c	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x92b57248	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x92b74098	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0x92b97967	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x92c894ca	kvm_get_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x92d13699	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92e06ac1	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0x92ea2a61	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x92f6e4b6	__ktime_divns
++EXPORT_SYMBOL_GPL vmlinux 0x92fd6a34	dev_pm_opp_add
++EXPORT_SYMBOL_GPL vmlinux 0x930f7ce6	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x931ebcd1	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x931f1bb3	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x93328bf5	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x934d9591	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x935519ce	clk_multiplier_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9396e461	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x93cc97d1	omap_dm_timer_set_pwm
++EXPORT_SYMBOL_GPL vmlinux 0x93d3b951	of_fixed_factor_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0x94077f3a	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0x941e8b8c	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x943ddbd0	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL vmlinux 0x9467b19e	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0x9480af77	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x948f45cc	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x949334db	cpdma_ctlr_start
++EXPORT_SYMBOL_GPL vmlinux 0x94abb745	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0x94c96f3b	bgpio_init
++EXPORT_SYMBOL_GPL vmlinux 0x94cda151	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0x94e971fd	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL vmlinux 0x94ec0df1	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x94fc1967	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x9503d528	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x950b7326	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x9525418d	kvm_write_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x952ad6f3	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x952cbef2	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0x9530d080	mtd_unpoint
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x95409e33	dev_pm_opp_find_freq_ceil
++EXPORT_SYMBOL_GPL vmlinux 0x9546e96d	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0x955af1eb	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x955b9a41	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x9574370c	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x957b598f	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x95856a00	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x9586a6ed	cpdma_chan_get_stats
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x959121fb	of_genpd_del_provider
++EXPORT_SYMBOL_GPL vmlinux 0x959dda43	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x95b5133e	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x95bbb758	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95c05faf	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x95c09318	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0x95d67a9e	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0x96103611	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x9610545a	nvdimm_volatile_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x9628378b	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0x9629f0d0	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x9648a200	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x966121c1	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0x96765c3e	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x968608ad	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL vmlinux 0x96976d74	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0x96b20c65	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0x96b5f4d0	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x96ccd76c	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0x96d68d11	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9725e8ca	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x973fb2cb	__get_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x9755b8e6	of_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x975dd944	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x976c73b5	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x978ad14d	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0x9792539d	of_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x97cab891	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL vmlinux 0x97cd02ed	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x97d38090	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x980b284e	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x983dd2b6	mtd_writev
++EXPORT_SYMBOL_GPL vmlinux 0x984af527	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x986c4794	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x98725423	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9886241c	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL vmlinux 0x989eb047	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x989fac45	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0x98b1b229	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0x98c2a5c9	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x98c34c77	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x98c9f584	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0x98d008cd	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL vmlinux 0x98e553d8	clk_hw_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x98e6f962	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x98f2c1fc	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x991afac6	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x9925a115	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0x993ca633	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x9954b5eb	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x9973add9	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x9985aee1	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x99a6633e	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x99b62ad0	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99cb3f61	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0x99cc7229	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9a02763b	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a1a0155	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x9a45b3b5	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0x9a5c7ed7	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9aa03a62	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9ac790a9	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x9acaafd7	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9aed02c8	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x9b083539	of_pci_get_host_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x9b0c6b74	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x9b0fe8e6	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x9b265d01	of_dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x9b567b5a	of_dma_xlate_by_chan_id
++EXPORT_SYMBOL_GPL vmlinux 0x9b68de23	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL vmlinux 0x9bc6bc83	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9bf5c3e8	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x9c049c18	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x9c23cee9	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0x9c3e5b59	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9c40e6ca	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x9c7eda81	omap_dm_timer_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9cb08184	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x9cb50617	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cc8d8f9	snd_soc_register_card
++EXPORT_SYMBOL_GPL vmlinux 0x9cdc9867	cpdma_ctlr_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9cde581c	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0x9cea55ff	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x9d37e2f6	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0x9d61090d	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL vmlinux 0x9d6cc5a4	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0x9d6d02e6	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0x9d746094	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0x9d804bd3	pinconf_generic_dt_node_to_map
++EXPORT_SYMBOL_GPL vmlinux 0x9d819260	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0x9d8331c0	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x9d8c621e	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x9da8cb0d	ahci_platform_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9dc92f5d	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x9df7569e	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x9dfdf722	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0x9e21e9e0	omap_dm_timer_set_load_start
++EXPORT_SYMBOL_GPL vmlinux 0x9e359e31	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e50a4bd	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x9e9548a6	dev_pm_opp_enable
++EXPORT_SYMBOL_GPL vmlinux 0x9e9773fe	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x9ea26d3c	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x9ea556f8	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ed89b5e	snd_soc_test_bits
++EXPORT_SYMBOL_GPL vmlinux 0x9ed9b9a2	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x9efcff9a	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x9efd149c	omap_iommu_restore_ctx
++EXPORT_SYMBOL_GPL vmlinux 0x9f1860f7	clk_register_fractional_divider
++EXPORT_SYMBOL_GPL vmlinux 0x9f1dee2d	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x9f279b7b	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x9f2d173e	pinctrl_pm_select_default_state
++EXPORT_SYMBOL_GPL vmlinux 0x9f33b1a5	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x9f59710c	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0x9f632021	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0x9f63551a	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x9f689e3a	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0x9fa5702d	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fdbd225	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9ff9a494	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0xa013a9cf	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xa01d1b6d	cpufreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa0254981	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0xa033df40	clk_register_divider
++EXPORT_SYMBOL_GPL vmlinux 0xa0412968	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0xa071e884	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0xa085308f	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0xa094335c	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xa0ac1f72	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xa10001ac	mpc8xxx_spi_rx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0xa10250b0	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa10f0ac6	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0xa11343e1	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xa113fb0b	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xa11e5ce8	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xa1229bfd	clk_debugfs_add_file
++EXPORT_SYMBOL_GPL vmlinux 0xa13a63e6	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xa13cc55d	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0xa1494036	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xa14a1817	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0xa1583c5f	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xa176efde	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xa1850546	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa1910530	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xa19a6183	of_reserved_mem_device_release
++EXPORT_SYMBOL_GPL vmlinux 0xa1eb60d4	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xa202c6d3	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0xa21e3e03	nd_blk_region_to_dimm
++EXPORT_SYMBOL_GPL vmlinux 0xa21f3717	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL vmlinux 0xa223f7ce	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0xa259f68e	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0xa263ebb3	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0xa2649e08	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa2816e45	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL vmlinux 0xa2a44228	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xa2afcabc	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xa2b9c993	clk_register_fixed_factor
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2c53804	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0xa2e195bc	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0xa2e5a4d0	omap_dm_timer_request_by_node
++EXPORT_SYMBOL_GPL vmlinux 0xa34b44a8	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL vmlinux 0xa3668745	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0xa37b82aa	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL vmlinux 0xa37d2cd0	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa38d1433	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0xa3998283	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa39afc7f	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3a9d9ec	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0xa3b5e7b7	dt_init_idle_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3c1d0aa	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL vmlinux 0xa3cc7120	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0xa3d1189e	pinctrl_add_gpio_ranges
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa3f3fbf0	component_del
++EXPORT_SYMBOL_GPL vmlinux 0xa41b7f07	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xa42b8f40	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0xa42d2076	dev_pm_opp_get_suspend_opp
++EXPORT_SYMBOL_GPL vmlinux 0xa44142fc	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa446db31	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xa44807db	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xa44890ee	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0xa45a9bf4	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0xa45d0ee5	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL vmlinux 0xa45f337d	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa464e531	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0xa472a6da	sm501_find_clock
++EXPORT_SYMBOL_GPL vmlinux 0xa4744dba	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL vmlinux 0xa47f8d3d	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa4a0c327	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0xa4a7a275	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL vmlinux 0xa4ac4466	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0xa4ad5202	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0xa4cfd910	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xa53f0efa	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xa53fe33a	pinctrl_dev_get_devname
++EXPORT_SYMBOL_GPL vmlinux 0xa541d38d	mpc8xxx_spi_rx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0xa55ba337	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0xa55e3752	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL vmlinux 0xa566a2fe	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0xa58d6fb4	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0xa5a2101f	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0xa5a2849f	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xa5b40d84	sdhci_free_host
++EXPORT_SYMBOL_GPL vmlinux 0xa5bf138b	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xa5bf506f	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL vmlinux 0xa5ceb825	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0xa5dc1842	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa5e74c89	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5f8854a	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xa60848e1	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xa6175d12	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa64f77df	sdhci_remove_host
++EXPORT_SYMBOL_GPL vmlinux 0xa65e006b	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL vmlinux 0xa6704089	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0xa69cd78a	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6c84890	omap_dma_filter_fn
++EXPORT_SYMBOL_GPL vmlinux 0xa6cfcc36	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0xa6d1b1c4	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa74f5c82	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0xa75f50ea	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xa766f1ed	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0xa7744664	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL vmlinux 0xa78746a6	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL vmlinux 0xa79b9bed	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xa79ba01a	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0xa7d8ea75	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa862187e	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xa871165c	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0xa87f3899	ulpi_viewport_access_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa87f8da7	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xa88fbfc3	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xa8a8ced9	unregister_mtd_user
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8b8cac9	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0xa8bc717e	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0xa8c0ace3	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0xa8d48b09	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0xa8e98132	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xa8f38fb0	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xa90cfa6c	snd_ac97_reset
++EXPORT_SYMBOL_GPL vmlinux 0xa916e0fc	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0xa91db3af	arm_iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa940e21e	kvm_release_page_clean
++EXPORT_SYMBOL_GPL vmlinux 0xa942ddbb	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0xa952216d	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xa96071ad	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xa9614c12	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0xa975073c	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa976bce4	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0xa9848267	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0xa992c0c4	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0xa99ca729	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0xa99f67f3	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0xa9a52cc8	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0xa9aef2e1	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL vmlinux 0xa9b5e4f4	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xa9ba8b05	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0xa9c66cbd	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0xa9d17476	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0xa9e05660	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9e59bf7	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xa9edffba	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0xa9fe0a3b	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0xaa12e74f	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0xaa23f3d7	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0xaa2a72bf	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0xaa2e1dec	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xaa3ce204	clk_register_gpio_gate
++EXPORT_SYMBOL_GPL vmlinux 0xaa44acff	omap_tll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xaa66420a	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xaa91aab2	pin_is_valid
++EXPORT_SYMBOL_GPL vmlinux 0xaa9bb7cb	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaaba3b70	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0xaabcd229	kvm_vcpu_write_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xaaf1fa0e	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0xab1d8a75	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xab22bc67	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0xab47cccc	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab79d015	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL vmlinux 0xab945a16	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xaba66f3e	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xabaab7a5	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0xabc14080	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL vmlinux 0xabfac7ba	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0xac16e6de	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xac1c9abd	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0xac2e707c	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0xac50260d	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL vmlinux 0xac65cf24	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xac6b7401	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0xac95c9e1	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0xacb7401c	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0xacc38865	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0xacd2990d	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0xacd4ea59	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xace587c0	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xaceb9d99	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0xacf76395	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0xacf79fda	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xad0fa875	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0xad432a70	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0xad782c36	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0xad85f611	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0xad89bcbd	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0xad921e62	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadcf2168	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xade3bac6	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xae15722b	kvm_vcpu_read_guest
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae81922b	of_overlay_destroy_all
++EXPORT_SYMBOL_GPL vmlinux 0xae9f9d59	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0xaebb0cc5	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xaed7f220	cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xaee6ebd3	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0xaee9fdcc	snd_soc_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0xaeec4b36	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xaf1127fc	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xaf12bfb3	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0xaf26c614	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL vmlinux 0xaf348da7	cpu_pm_exit
++EXPORT_SYMBOL_GPL vmlinux 0xaf36393a	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xafa5e154	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0xafd4d257	__of_genpd_add_provider
++EXPORT_SYMBOL_GPL vmlinux 0xb010600a	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xb0128a78	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0xb0268218	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xb03d6c85	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb04d1f7b	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL vmlinux 0xb05623d0	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xb063fe9d	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0xb077e70a	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xb09fbd63	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0xb0b15e93	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0bce4f0	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xb0c3fb1b	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0xb0f8b4f0	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0xb11625b9	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xb125af82	amba_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xb125ceb2	cpdma_control_set
++EXPORT_SYMBOL_GPL vmlinux 0xb135f540	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb156befc	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0xb16c27db	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL vmlinux 0xb174056a	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb1aaa22d	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1b17705	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1d27236	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1e70a5c	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xb1eb8765	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xb2018331	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb219a1c0	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xb21b0b0c	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb23541f5	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xb2587d32	snd_soc_register_codec
++EXPORT_SYMBOL_GPL vmlinux 0xb26a1add	elfcorehdr_addr
++EXPORT_SYMBOL_GPL vmlinux 0xb27c3b31	usb_gadget_map_request
++EXPORT_SYMBOL_GPL vmlinux 0xb27ea468	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb2a220e6	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0xb2a758c2	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb2d00094	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb2f42a32	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0xb310e837	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0xb31ca89b	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb34e20d9	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0xb3550aff	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL vmlinux 0xb393c8a7	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0xb3b7bfe3	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb3c08c60	vcpu_put
++EXPORT_SYMBOL_GPL vmlinux 0xb3d62424	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xb3d6c871	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0xb3ea8d95	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0xb3f98119	mtd_point
++EXPORT_SYMBOL_GPL vmlinux 0xb40c6376	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xb412130b	ahci_do_softreset
++EXPORT_SYMBOL_GPL vmlinux 0xb4147cdd	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xb41a3f00	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xb43ce764	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0xb450031d	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0xb4591fb6	mtd_del_partition
++EXPORT_SYMBOL_GPL vmlinux 0xb46b2987	sm501_modify_reg
++EXPORT_SYMBOL_GPL vmlinux 0xb490a243	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0xb490ced3	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4bbcb5a	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0xb4c8e8e1	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0xb4cf0322	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb5013de7	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb5206099	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL vmlinux 0xb523ab41	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0xb53497b6	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb53b2a82	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0xb54c8439	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0xb5542879	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xb55c1dd6	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0xb5801c06	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xb589c641	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5a3c45c	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xb5cba789	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0xb5d0139c	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xb5e31551	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb5e896fb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0xb5e95f9e	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0xb5ef9d83	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb5ff475a	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xb6023246	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb608e93c	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0xb60a753a	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0xb61d29e2	ahci_shost_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb62e5cd3	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0xb65dc440	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0xb66de615	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0xb69a2f5d	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6c2558e	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xb6d6649e	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0xb6e6d99d	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb6e75a5c	cpsw_ale_create
++EXPORT_SYMBOL_GPL vmlinux 0xb7055e97	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0xb7329c06	clk_set_phase
++EXPORT_SYMBOL_GPL vmlinux 0xb74ae7ca	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0xb74bfae0	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xb771e6b7	bL_switch_request_cb
++EXPORT_SYMBOL_GPL vmlinux 0xb77cb0a8	cpdma_chan_submit
++EXPORT_SYMBOL_GPL vmlinux 0xb7b32ddc	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb7b9ae1c	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb7d3cd09	omap_dm_timer_set_load
++EXPORT_SYMBOL_GPL vmlinux 0xb7e07fd6	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb7e56f14	clk_hw_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0xb7f492ae	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb80b06f4	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb8172903	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xb82566eb	omap_tll_enable
++EXPORT_SYMBOL_GPL vmlinux 0xb8346aeb	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb84837fb	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0xb84a29ab	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0xb85e51b4	mtd_read_oob
++EXPORT_SYMBOL_GPL vmlinux 0xb882411f	of_dma_is_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb899fc1a	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0xb89c5530	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0xb8a863db	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xb8b56731	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8d4cd93	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0xb8dee1ff	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb9176155	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0xb91b3462	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0xb91c2cb7	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xb92427b4	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb92f0f6c	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0xb935064c	snd_soc_component_write
++EXPORT_SYMBOL_GPL vmlinux 0xb944f4e8	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0xb979cb4d	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0xb98024f9	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0xb9901c2a	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0xb992a03d	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0xb9b08ab8	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xb9b205c0	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9d1b0fc	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb9e07125	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xb9e87b94	bL_switcher_trace_trigger
++EXPORT_SYMBOL_GPL vmlinux 0xb9e892af	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb9f878c6	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0xba10a67a	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0xba270396	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba435884	cpsw_ale_stop
++EXPORT_SYMBOL_GPL vmlinux 0xba5b46ec	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xba5bd06a	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xba649819	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xba853cb9	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0xba86201a	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xba8929ea	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xba8bda67	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xba8d9ed3	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbac3f72c	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xbad2a6df	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xbad678b2	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0xbaebf82e	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL vmlinux 0xbaf6d630	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xbaff7fe9	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb05e839	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb11cfba	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xbb33ba91	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0xbb387bae	snd_soc_jack_report
++EXPORT_SYMBOL_GPL vmlinux 0xbb4c7570	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xbb5513c0	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xbb64e522	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbb68cfb8	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0xbb84afc9	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xbb90b621	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0xbb9e2ab5	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0xbbaa4e44	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0xbbbaa6fc	of_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xbbf6d63e	kvm_put_kvm
++EXPORT_SYMBOL_GPL vmlinux 0xbc5d1eb9	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc8725f1	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xbca3fa6d	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0xbca43149	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0xbca9cd07	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcbaa80a	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0xbccbe19b	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0xbccdbeff	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcd56429	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0xbcdc8547	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd028f	omap_dm_timer_request
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd9469	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0xbce52ede	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0xbcf89ab6	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0xbcfa50c2	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0xbcfad33f	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0xbd140c38	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xbd3cdd03	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd583e90	of_get_dma_window
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd78e280	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0xbd7fd389	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0xbd911332	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0xbd91ce3d	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xbdbf05c7	amba_apb_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbdd3eabe	kill_mtd_super
++EXPORT_SYMBOL_GPL vmlinux 0xbddfefb5	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbde11233	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL vmlinux 0xbe09005e	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe1a57dc	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0xbe1c84c9	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL vmlinux 0xbe24d426	nd_cmd_out_size
++EXPORT_SYMBOL_GPL vmlinux 0xbe320c21	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xbe476d92	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xbe615e19	omap_dm_timer_set_prescaler
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe6fbbf6	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xbe96dfd8	of_reconfig_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbea27261	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbeaf81a9	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0xbeb7987b	ahci_ops
++EXPORT_SYMBOL_GPL vmlinux 0xbeca98ba	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xbed929eb	dev_pm_opp_set_sharing_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf19ed46	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xbf2d580e	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xbf2e0a92	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xbf6d26e5	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0xbf778375	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xbf7eca8f	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0xbf92effa	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xbfa869dd	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0xbfb6fd39	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0xbfbb18b7	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfbcddf8	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xbfbfe791	__of_genpd_xlate_simple
++EXPORT_SYMBOL_GPL vmlinux 0xbfd7215e	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xbfd8faaf	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xbfde3dea	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xc00131cf	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0xc00257bd	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0xc023df49	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0xc03a654b	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0xc046ef3d	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0xc065258a	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xc081c246	bL_switcher_put_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0b48bfe	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0d5f6e6	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0e75cec	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc112859c	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0xc150d2c2	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0xc16524e6	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc18578ed	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xc18725ff	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0xc1947351	of_clk_get_parent_count
++EXPORT_SYMBOL_GPL vmlinux 0xc1a18615	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xc1bced6a	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xc1fe562b	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xc21604ae	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xc219c80d	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xc21b3cca	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc2294873	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc23487f5	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0xc23b25c6	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc2406601	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0xc240d761	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0xc257f3e2	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0xc25e6e7c	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xc26d8eb7	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xc27de1e3	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc2a1442a	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0xc2a96179	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0xc2e01cb2	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc2e728dc	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0xc2f07df8	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc3059d66	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc32e7129	of_get_videomode
++EXPORT_SYMBOL_GPL vmlinux 0xc32f81f6	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc37cbb8a	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xc385cb58	perf_num_counters
++EXPORT_SYMBOL_GPL vmlinux 0xc39c1d29	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xc3aa5319	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0xc3b93bba	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0xc3c3dbf4	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0xc3c5d1e9	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0xc3c7744f	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xc3d3739e	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xc3f9ea78	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xc41e0178	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc4461945	ahci_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0xc44d83af	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc45dd2db	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0xc467c184	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0xc46a7fbe	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc48a6873	omap_dm_timer_read_status
++EXPORT_SYMBOL_GPL vmlinux 0xc48aa3cb	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc48c532b	omap_dm_timer_set_match
++EXPORT_SYMBOL_GPL vmlinux 0xc48c9182	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0xc4a527c0	clk_hw_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0xc4a8210f	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0xc4ad840e	nd_region_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xc4b9e053	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4e000a0	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xc50a0ff8	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0xc50d18a7	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0xc51eff2f	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xc530cfcd	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc54d3084	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc54d8fa7	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0xc5546615	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xc569d8ce	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc57b4a09	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL vmlinux 0xc5d5513e	cpdma_chan_process
++EXPORT_SYMBOL_GPL vmlinux 0xc5d681f2	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc5df159a	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xc5e0dd66	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0xc6053efe	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc645eca6	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0xc649229a	clk_register_gate
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc66e0ff6	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0xc685c037	cpdma_check_free_tx_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6a4a872	__clk_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc6aae9e0	put_device
++EXPORT_SYMBOL_GPL vmlinux 0xc6fcb357	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xc7083873	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0xc71b47da	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0xc724f66d	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc7327676	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7a90f09	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0xc7b8893b	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0xc7ba9ebc	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0xc7c47aff	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7ceb5db	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc7dc672c	omap_dm_timer_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7e3efff	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0xc7f4fe40	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0xc80e5c36	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL vmlinux 0xc829441f	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0xc834ddc5	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0xc85416b7	omap_dm_timer_set_source
++EXPORT_SYMBOL_GPL vmlinux 0xc85a1bf2	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc8689204	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xc86de894	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc86f9ab0	ahci_start_engine
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc87e2d7a	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xc8945fac	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0xc897bfb6	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0xc89d5018	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0xc8a31a43	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8bef166	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc8e9db4d	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc90165c7	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc922033a	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xc930f958	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL vmlinux 0xc940c95d	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0xc95385ff	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc968081e	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0xc968e7df	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0xc96ec70f	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0xc97d1140	cpufreq_cooling_get_level
++EXPORT_SYMBOL_GPL vmlinux 0xc9c8c56f	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0xc9d8c016	of_pci_range_parser_init
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc9ee5940	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0xc9fa3f58	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0xca01dd90	clk_hw_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0xca3a1c4a	snd_soc_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xca3aaab7	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xca3ff747	ahci_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0xca4251f4	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0xca4d0efc	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0xca4e7b39	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca911293	pm_genpd_syscore_poweron
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcabe1081	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0xcac86bf8	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0xcad19a56	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xcad8d717	to_nd_desc
++EXPORT_SYMBOL_GPL vmlinux 0xcadf0be6	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xcaf9f9dd	clk_fractional_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0xcb038bce	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0xcb067787	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0xcb0d3f53	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xcb0eced6	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb200ecb	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0xcb24c99b	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb4986a7	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xcb4b3fd6	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0xcb5759dc	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xcb5b7c9a	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0xcb70ff46	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xcb7461c8	snd_soc_platform_write
++EXPORT_SYMBOL_GPL vmlinux 0xcb814533	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xcb83c974	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0xcb8618ee	gfn_to_pfn
++EXPORT_SYMBOL_GPL vmlinux 0xcb94685a	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL vmlinux 0xcba1f2fd	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0xcba49d42	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xcbcddf13	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbe9603f	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcc061537	to_of_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0xcc1417d7	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0xcc53eb3f	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xcc613595	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0xcc82e4a8	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc871f90	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0xcc8cdc86	pinctrl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcc8d50f3	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xccaefbba	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xccb5155d	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xccc6f1ae	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xcccdcc7c	of_irq_parse_pci
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xcce1aeba	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0xccfbc767	device_move
++EXPORT_SYMBOL_GPL vmlinux 0xcd0d8a9d	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0xcd16b8ca	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xcd3ab50d	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0xcd40b387	nand_release
++EXPORT_SYMBOL_GPL vmlinux 0xcd59aac6	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcd5c7b16	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xcd6ccfc5	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0xcd794991	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0xcd86a50a	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0xcd914475	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcdd062e2	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xcdd6a479	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0xce03c971	cpsw_ale_start
++EXPORT_SYMBOL_GPL vmlinux 0xce494af5	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xce5b4c04	sdhci_suspend_host
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce7d98cf	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0xce85e107	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0xce8d067c	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xce9a0411	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xcebb5c95	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xcebd0bbb	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xcec912b8	kvm_vcpu_write_guest
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcef828da	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xcf1a293a	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf588477	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xcf5b9428	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xcf83de47	uniphier_pinctrl_probe
++EXPORT_SYMBOL_GPL vmlinux 0xcf83e5e9	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL vmlinux 0xcf877821	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xcf8c2049	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0xcf8f8d56	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0xcf9b6ea7	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL vmlinux 0xcfa773ab	of_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xcfa8e0f8	device_del
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfb93e43	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xcfc2e7ac	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfeaea50	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0xd007354b	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xd017c545	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd035e5c7	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd0407173	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0xd04c6451	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0xd059e227	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xd05cf2ac	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0xd061e893	of_pci_msi_chip_add
++EXPORT_SYMBOL_GPL vmlinux 0xd064cb8a	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd0950c12	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0xd0bb83a3	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0c1c8c5	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xd0c25f7c	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0xd0e8171e	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xd0e9e803	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xd0f405b9	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xd124c7e9	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0xd133efbb	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xd1441e17	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0xd149a813	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd1822f0b	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd19d4555	mpc8xxx_spi_rx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0xd1b3cce4	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0xd1b6ece5	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0xd1c37f5d	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0xd1c72d28	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0xd1cef649	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0xd1d2f0d8	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL vmlinux 0xd1e2c607	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0xd1f0a011	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd1fa7afe	default_iommu_map_sg
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd2127537	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0xd217783c	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd21ca8b7	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0xd2411ead	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0xd24bfcff	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd256b927	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd27c742b	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0xd282c713	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0xd28fea2e	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xd2953997	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xd29686d1	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd29efe6a	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0xd2a2622d	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0xd2aaeb4e	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xd2c6e419	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xd2de7533	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd2f0c29d	of_clk_src_onecell_get
++EXPORT_SYMBOL_GPL vmlinux 0xd2ff7716	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0xd30503c5	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0xd311bc48	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0xd33ada8b	cci_probed
++EXPORT_SYMBOL_GPL vmlinux 0xd340ddba	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0xd34e441f	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0xd3566893	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd387cb85	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0xd3ae207e	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3b5ad48	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL vmlinux 0xd3c0be7e	of_property_read_string_helper
++EXPORT_SYMBOL_GPL vmlinux 0xd3c495ab	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xd3d36cff	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0xd3d9bc2b	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0xd3e2b392	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xd3e97c21	hugetlb_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd401336e	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd437825d	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0xd4434a5b	ahci_reset_em
++EXPORT_SYMBOL_GPL vmlinux 0xd445095f	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd44c2f38	cci_disable_port_by_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd44c3437	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0xd45d042c	of_get_nand_ecc_mode
++EXPORT_SYMBOL_GPL vmlinux 0xd46032a5	devfreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xd46e190a	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0xd475d8d9	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0xd4a1c11d	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xd4b5bd89	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4fbe793	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd503034e	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0xd51068bf	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0xd51bdb5d	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0xd52739c2	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd53da4e3	omap_dm_timers_active
++EXPORT_SYMBOL_GPL vmlinux 0xd54dd6dd	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xd55239c9	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd57f2089	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xd58048a1	dev_pm_opp_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xd581fe7b	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xd58eff13	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL vmlinux 0xd5ba07de	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0xd5bbcf30	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5e1ef29	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xd5e57170	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd5ec2eca	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0xd604f626	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd60e11ed	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0xd6144af4	vcpu_load
++EXPORT_SYMBOL_GPL vmlinux 0xd6155386	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0xd618a852	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xd6349f83	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd635534d	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xd6365277	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0xd63bb40c	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0xd64a01eb	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0xd667e3f3	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd67bd08a	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0xd6a2502e	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0xd6a31eb3	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL vmlinux 0xd6c43478	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xd6c62732	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0xd6f00226	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0xd6facf3d	dev_pm_opp_get_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd7017acb	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd70c078a	of_clk_src_simple_get
++EXPORT_SYMBOL_GPL vmlinux 0xd720c14d	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0xd7479ef6	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd7a656d9	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7d9349e	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0xd7de057e	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0xd7fe068b	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0xd80baa48	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd81edc72	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd847506b	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd84bcdae	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd87ad5f3	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd8804af3	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL vmlinux 0xd894b63f	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xd8c3176c	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0xd8d79a3e	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xd8e1fac0	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL vmlinux 0xd8e58dad	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd8e8cfcf	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0xd915705e	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0xd91fd425	__clk_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0xd92c9238	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94aa457	display_timings_release
++EXPORT_SYMBOL_GPL vmlinux 0xd950b7ab	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0xd961e7dd	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd98d2c2f	of_clk_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0xd98f3ce6	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd9d8844e	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0xd9eb3c27	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xda01e309	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xda20e817	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0xda21a301	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0xda2dc391	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL vmlinux 0xda3b8720	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0xda41bc1d	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xda5d47e6	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xda6e307b	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0xda74489c	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0xda7a0ee4	nvdimm_bus_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xda876191	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xdab01f27	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0xdae715e0	videomode_from_timing
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdb02608b	arizona_of_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xdb088cb1	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0xdb246a69	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0xdb28e635	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0xdb3c0794	put_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb450dd0	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0xdb4b6827	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xdb52fe2c	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0xdb7eb226	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb905e9a	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0xdba45f74	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xdbbb95eb	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xdbdcb406	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0xdbe1d36c	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdbf87ad5	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xdbfd1530	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xdc096147	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xdc2a4bf3	mv_mbus_dram_info
++EXPORT_SYMBOL_GPL vmlinux 0xdc2f7466	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xdc3c4572	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xdc461430	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xdc465fe4	of_platform_populate
++EXPORT_SYMBOL_GPL vmlinux 0xdc638675	__clk_get_hw
++EXPORT_SYMBOL_GPL vmlinux 0xdc66e002	of_clk_parent_fill
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc98469f	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdca1eb5b	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0xdcb9d444	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0xdcc61a32	arm_iommu_release_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xdccdb96e	of_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xdcfc54d5	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd2ed92b	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd3dd6e3	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0xdd3fa664	omap_dm_timer_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdd45519f	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0xdd512356	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xdd56bc32	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xdd7f2bc0	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0xdd9e1851	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0xdda258bf	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xddd6a7be	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xddeb75c9	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xddf74095	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0xde0c42cc	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0xde46e353	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xde5581b1	uniphier_pinctrl_remove
++EXPORT_SYMBOL_GPL vmlinux 0xde651f98	__tracepoint_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xde6b2eaa	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0xde7c90c9	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0xde7f57cf	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xde8e8a2b	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0xde93b2e7	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xdead0467	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xdec6b5c3	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0xdec85c45	gfn_to_memslot
++EXPORT_SYMBOL_GPL vmlinux 0xdedb8bbb	pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0xdee8902f	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf130b2c	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0xdf255dcf	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xdf2691d8	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0xdf26ef83	of_irq_parse_one
++EXPORT_SYMBOL_GPL vmlinux 0xdf27859d	of_devfreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xdf4408e4	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0xdf5c2ba5	dev_pm_opp_is_turbo
++EXPORT_SYMBOL_GPL vmlinux 0xdf784580	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0xdf8eecc5	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0xdfaf8f60	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0xdfba4ac8	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0xdfc192fd	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0xdfcb15cd	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe00967f8	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe0382e83	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0xe04fb8bd	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0xe0572f5a	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0xe0686c6b	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xe0697ca7	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0xe06e4157	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe07ca631	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0xe08629ca	pinctrl_force_default
++EXPORT_SYMBOL_GPL vmlinux 0xe09a7594	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xe0b1c103	clk_set_max_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe0b61344	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0xe0c17bc0	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0xe0dea1e0	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0xe0f835a0	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xe11e7e45	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0xe120420d	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0xe12a42f3	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe133d4bc	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xe13861d0	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0xe13ff46a	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe181a4a5	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL vmlinux 0xe181acb9	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xe185f442	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL vmlinux 0xe19068e6	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe191c839	thermal_zone_of_sensor_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe1b9229d	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe1d14ed4	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0xe213d43a	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0xe22e899a	__cci_control_port_by_device
++EXPORT_SYMBOL_GPL vmlinux 0xe237376d	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xe243d8b1	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xe274b9a9	dummy_con
++EXPORT_SYMBOL_GPL vmlinux 0xe27eb2f6	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0xe28310b7	pinctrl_remove_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe28f2ad6	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe29d258d	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0xe2bd80b3	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xe2bfd86b	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0xe2c7699c	of_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xe2fcb581	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0xe3022d52	omap_dm_timer_write_status
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe323c9f2	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0xe32bb240	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xe33a6b62	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe3b0db37	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xe3b2d20f	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe3b39812	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0xe3ba92ef	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xe3ca227d	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xe3de070a	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL vmlinux 0xe3e4da2e	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0xe3f953b1	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xe41a15d0	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0xe42e1f70	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe442a7d1	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0xe4617126	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe4791bf0	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xe4877957	pm_genpd_init
++EXPORT_SYMBOL_GPL vmlinux 0xe493fa7f	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe4a39b6b	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0xe4c22565	cpdma_chan_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4c9cb05	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0xe4d060bd	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0xe4deba56	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0xe4e46d40	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0xe4f74b5c	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL vmlinux 0xe504be21	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0xe50d3447	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5250950	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0xe53b94d8	max_gen_clk_remove
++EXPORT_SYMBOL_GPL vmlinux 0xe55625cb	clk_gpio_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe5592568	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xe5596441	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xe55e360b	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe5627b23	of_usb_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xe569941c	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58e8916	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5a888cb	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0xe5c80981	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL vmlinux 0xe5db8edd	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xe60d151b	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0xe6100ac4	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL vmlinux 0xe626e432	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0xe63f151f	get_mtd_device_nm
++EXPORT_SYMBOL_GPL vmlinux 0xe645075d	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0xe64cd8ef	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe65a86be	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0xe667168f	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xe66b5945	clk_register_mux
++EXPORT_SYMBOL_GPL vmlinux 0xe69e189c	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0xe6b5ec2d	snd_soc_cnew
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6cc1e74	nd_numa_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe7397ca5	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0xe73de9fe	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0xe740a22a	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0xe7437ad1	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe75b75de	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0xe75f1a29	pinctrl_utils_dt_free_map
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe79337a6	of_get_display_timings
++EXPORT_SYMBOL_GPL vmlinux 0xe7eea48c	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xe7ff3efe	mpc8xxx_spi_tx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe81596b0	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe818cd83	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0xe81c47f7	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xe82e35d8	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL vmlinux 0xe84a458a	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe85a9fd3	cpu_cluster_pm_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe878dae7	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0xe87b60ff	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xe87f00a6	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0xe880d33e	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xe896c4e4	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0xe89703b1	omap_dm_timer_trigger
++EXPORT_SYMBOL_GPL vmlinux 0xe8b78b8c	register_mtd_blktrans
++EXPORT_SYMBOL_GPL vmlinux 0xe8e13e7e	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0xe8e60f73	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xe8fe7f15	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0xe90a3783	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0xe90f64b4	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xe91063ca	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0xe91b1ae1	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0xe933a279	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0xe93d84ba	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe9452187	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL vmlinux 0xe949b13a	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xe94fde82	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xe956a75c	pl320_ipc_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe95ab720	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xe9640d94	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xe98fb73f	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xe996301b	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0xe99740e9	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0xe997a768	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xe998ae50	mtd_block_isbad
++EXPORT_SYMBOL_GPL vmlinux 0xe9af4fde	snd_soc_add_platform
++EXPORT_SYMBOL_GPL vmlinux 0xe9bb4b7e	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0xe9c4a81d	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xe9d8efb9	register_mtd_user
++EXPORT_SYMBOL_GPL vmlinux 0xe9dc21e8	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xe9dd66b4	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0xe9e0beb3	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0xea123e56	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea1bb291	bL_switcher_get_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xea1f6e0e	hugetlb_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xea2d4733	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL vmlinux 0xea7703e7	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xeaa0e926	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xeaacba9c	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0xeabfa07c	of_platform_default_populate
++EXPORT_SYMBOL_GPL vmlinux 0xead07813	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xeae17cfe	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xeaf7f139	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0xeb3ead0e	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0xeb431f22	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0xeb4422a1	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0xeb442a1c	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0xeb6d1d21	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL vmlinux 0xeb793ee6	of_cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xeb9940ba	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0xeb9abbee	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xeb9c3e60	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0xebb3592b	snmp_get_cpu_field64
++EXPORT_SYMBOL_GPL vmlinux 0xebb7e578	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0xebbe1622	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xebc7594f	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0xebcd590f	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0xebe58a6a	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xebf752d5	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xec06bda5	omap_dm_timer_set_int_disable
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec6434eb	kvm_vcpu_gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xec6fa80d	cpdma_ctlr_create
++EXPORT_SYMBOL_GPL vmlinux 0xec9ed46d	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0xeca44a19	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xecb4f35d	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0xecc5ad2f	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0xecf26f64	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xecfd8761	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xed24fae9	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xed6a6663	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0xed6b8404	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xed70521d	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xed94b994	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0xed9b6872	snd_soc_register_component
++EXPORT_SYMBOL_GPL vmlinux 0xedaf4d69	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0xedb57133	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0xedbbfb0e	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xedc2e9bb	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xedc82769	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL vmlinux 0xedd69113	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL vmlinux 0xedd887bc	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0xede8d84d	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0xee04ccb2	pinctrl_utils_add_config
++EXPORT_SYMBOL_GPL vmlinux 0xee0b89e4	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0xee13b3c1	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL vmlinux 0xee18a349	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xee1d9e16	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0xee2300d5	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xee3a0a34	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xee59b8c3	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee70d159	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xee7b94e5	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xee8d7539	cpdma_chan_start
++EXPORT_SYMBOL_GPL vmlinux 0xeea3d22d	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0xeea8a81a	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0xeeb0a12a	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xeeb93ecb	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0xeed7903a	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL vmlinux 0xeef61eb6	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0xef006b24	rq_flush_dcache_pages
++EXPORT_SYMBOL_GPL vmlinux 0xef01d994	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xef0a54cd	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL vmlinux 0xef35ff85	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0xef409b74	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0xef423bda	kvm_get_dirty_log
++EXPORT_SYMBOL_GPL vmlinux 0xef464c28	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0xef54604e	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0xef5f470e	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xef66075c	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef847621	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xef9f4b34	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefd8492d	kvm_vcpu_read_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xefe4d669	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0xeff0ebad	__nvdimm_bus_register
++EXPORT_SYMBOL_GPL vmlinux 0xeff3dc1e	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0xf0230abf	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf06026e5	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xf0696d9a	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf070759d	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf08f639b	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0xf0926e47	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xf09c1a33	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0xf0a17ca0	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xf0aa4474	__of_genpd_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0c598f0	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0xf0d67586	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0xf0f12782	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf108c18c	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0xf11a77c2	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0xf11db8a2	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0xf12caf22	clk_register_divider_table
++EXPORT_SYMBOL_GPL vmlinux 0xf139941f	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0xf13cafce	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf145eadc	of_property_read_u32_index
++EXPORT_SYMBOL_GPL vmlinux 0xf1564d47	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0xf175e6c2	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf19a6109	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0xf19d955e	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1b7ac6f	nd_blk_region_set_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0xf1c05702	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xf1c15305	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0xf1f16c9e	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf1ff8b38	arm_iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xf2137b52	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf22448ae	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0xf22899c3	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0xf22a3450	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0xf22d7278	user_update
++EXPORT_SYMBOL_GPL vmlinux 0xf2524e83	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0xf25ae4ce	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xf25e51b0	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0xf2655000	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf28297ac	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0xf2a0b4fe	pm_genpd_remove_subdomain
++EXPORT_SYMBOL_GPL vmlinux 0xf2a59ca8	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2b2b62e	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0xf2e6e726	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xf2e813bf	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30a888f	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf30fda27	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf31801b0	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf3207246	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf341f04b	omap_dm_timer_request_specific
++EXPORT_SYMBOL_GPL vmlinux 0xf34df19d	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf3a2cf25	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xf3a5875b	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0xf3a5f6df	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3baedec	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3bdf6f6	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0xf3c17d55	devm_regmap_init_vexpress_config
++EXPORT_SYMBOL_GPL vmlinux 0xf3c3d282	of_get_display_timing
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf40b4ba1	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xf42ac688	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xf438f8a0	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0xf4469c9d	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf467ec23	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xf474f1da	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0xf489a6f8	kvm_vcpu_mark_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0xf48ceebd	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xf49195e4	sdhci_reset
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4bc2fc8	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0xf4f104be	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0xf4f1ba6f	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf50dc832	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf5289fe6	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0xf549375c	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf54bf307	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf56ac2cc	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0xf579a4d3	sdhci_send_command
++EXPORT_SYMBOL_GPL vmlinux 0xf58c43ce	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5ac3ec7	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0xf5bd65d2	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf5ddd7b4	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0xf61baa65	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xf620c9bf	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0xf62af61d	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0xf62bd9c6	omap_dm_timer_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf635b2e6	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0xf638ce3b	pinctrl_find_and_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0xf63e69ff	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xf64a6156	mtd_write
++EXPORT_SYMBOL_GPL vmlinux 0xf65410fb	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf671877d	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0xf6a8d08e	pinconf_generic_dump_config
++EXPORT_SYMBOL_GPL vmlinux 0xf6b36a2e	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xf6b7a695	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xf6bf215c	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0xf6c4df8f	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6cb6598	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xf6cc2236	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xf6dc5549	nvdimm_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf7189c0d	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xf72770bd	nvdimm_bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf73de2e0	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0xf745d446	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0xf757ecfe	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0xf7591cf6	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xf76b0a59	read_current_timer
++EXPORT_SYMBOL_GPL vmlinux 0xf7711938	i2c_slave_register
++EXPORT_SYMBOL_GPL vmlinux 0xf785cff9	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0xf799fb6e	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xf7a2d06e	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0xf7a5f2a9	pci_msi_create_irq_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf7b8aae0	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xf7bd225b	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xf7c68a2b	of_dma_router_register
++EXPORT_SYMBOL_GPL vmlinux 0xf7d3f24f	pci_fixup_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xf7e8aa6e	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf80ebb65	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0xf813bf93	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0xf8293768	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0xf82e9dd4	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xf82f16b3	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf835b3d1	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xf846506f	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf8578e4c	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL vmlinux 0xf873b247	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf885bc98	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf88d1353	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xf897996d	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xf898eac4	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0xf8a2f0cc	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xf8a8a5c6	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0xf8bde9c5	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xf8cc0740	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL vmlinux 0xf8e6b564	hibernation_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8eabb06	of_gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xf8eb75ec	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf90def59	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf9384b94	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xf94406db	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf953f090	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0xf9574058	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0xf965ab3a	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xf96839ad	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0xf969baa9	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9ceb435	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0xf9d47382	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0xf9f04dac	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xf9f14f5c	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0xfa157fdd	fsl8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa21d713	of_reserved_mem_device_init
++EXPORT_SYMBOL_GPL vmlinux 0xfa26f622	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0xfa271dd6	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0xfa274fea	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xfa413a01	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xfa9b33a1	nd_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0xfa9ca123	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0xfabd676f	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0xfaee27c0	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xfaf9ad76	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0xfb0228a6	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xfb11cf1b	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0xfb30a5a5	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0xfb3283e5	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb40174c	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xfb45dd10	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb76b910	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xfb94f014	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xfb963e16	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0xfb9eb237	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfbdae864	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xfbdd86e0	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0xfbe09834	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc057074	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xfc0a44f4	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xfc1880ce	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfc214cd3	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xfc251c74	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xfc2f0f70	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0xfc44e4c5	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0xfc45aaa7	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0xfc74bdc4	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xfc7e5e85	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0xfc95943a	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xfc9ace9d	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xfcbfc0fb	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xfccb486d	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xfcd64a2b	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL vmlinux 0xfd1950c7	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xfd259718	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xfd36a6b5	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0xfd41c7ce	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0xfd586bae	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xfd647228	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0xfd66860b	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd89e285	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0xfd8b33e5	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xfd8be4c8	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfd967b2c	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xfda670bd	dev_pm_opp_get_opp_count
++EXPORT_SYMBOL_GPL vmlinux 0xfdcae422	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0xfdcc7ecd	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0xfde156f1	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xfde1a33e	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0xfe009c06	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0xfe56d278	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0xfe635a9a	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL vmlinux 0xfe6be49a	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfea13ad6	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0xfecab969	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfed887ac	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0xfed8a192	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xfedc4152	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xfeef1e56	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff07c8c2	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0xff291ecf	clk_unregister_divider
++EXPORT_SYMBOL_GPL vmlinux 0xff3ae651	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0xff4d1eb0	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0xff581e73	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff6c1e0e	of_reconfig_get_state_change
++EXPORT_SYMBOL_GPL vmlinux 0xff794747	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0xffaed360	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffb8f67f	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xffba4dfb	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xffe59400	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xffffe2ef	cpsw_ale_add_vlan
+diff --git a/debian.master/abi/4.4.0-111.134/armhf/generic-lpae.compiler b/debian.master/abi/4.4.0-111.134/armhf/generic-lpae.compiler
+new file mode 100644
+index 0000000..33e5508
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/armhf/generic-lpae.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu/Linaro 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/armhf/generic-lpae.modules b/debian.master/abi/4.4.0-111.134/armhf/generic-lpae.modules
+new file mode 100644
+index 0000000..9bddffd
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/armhf/generic-lpae.modules
+@@ -0,0 +1,4539 @@
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_dw
++8250_mid
++8250_omap
++8250_uniphier
++8255
++8255_pci
++8390
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++DAC960
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++ablk_helper
++acard-ahci
++acecad
++acenic
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++aes-arm
++aes-arm-bs
++aes-arm-ce
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++afs
++ah4
++ah6
++ahci
++ahci_ceva
++ahci_mvebu
++ahci_qoriq
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am35x
++am53c974
++amba-pl010
++ambakmi
++amc6821
++amd
++amd5536udc
++amd8111e
++amdgpu
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apbps2
++apds9300
++apds9802als
++apds990x
++apds9960
++appledisplay
++appletalk
++appletouch
++applicom
++aquantia
++ar1021_i2c
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_emac
++arc_ps2
++arc_uart
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arm_big_little
++arm_big_little_dt
++arm_mhu
++arm_scpi
++armada
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3722-regulator
++as3935
++as5011
++asc7621
++ascot2e
++asix
++ast
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++ata_generic
++ata_piix
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atm
++atmel
++atmel-flexcom
++atmel-hlcdc
++atmel-hlcdc-dc
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp870u
++atusb
++atxp1
++aty128fb
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avmfritz
++ax25
++ax88179_178a
++ax88796
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1pci
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bL_switcher_dummy_if
++bas_gigaset
++batman-adv
++baycom_epp
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bcm-keypad
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm63138_nand
++bcm63xx_uart
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcma
++bcmsysport
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++berlin2-adc
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpck
++bpck6
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmnand
++brcmsmac
++brcmstb_nand
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++cap11xx
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc10001_adc
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipone_icn8318
++chnl_net
++ci_hdrc
++ci_hdrc_imx
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++clip
++clk-cdce706
++clk-cdce925
++clk-max77686
++clk-max77802
++clk-palmas
++clk-pwm
++clk-qcom
++clk-rk808
++clk-s2mps11
++clk-scpi
++clk-si514
++clk-si5351
++clk-si570
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmtp
++cnic
++cobalt
++cobra
++coda
++colibri-vf50-ts
++com20020
++com20020-pci
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_parport
++comedi_pci
++comedi_test
++comedi_usb
++comm
++configfs
++connector-analog-tv
++connector-dvi
++contec_pci_dio
++cordic
++core
++cp210x
++cpia2
++cppi41
++cpu-notifier-error-inject
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc7
++crc8
++cros_ec
++cros_ec_devs
++cros_ec_i2c
++cros_ec_keyb
++cros_ec_spi
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++cs89x0
++csiostor
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++db9
++dc395x
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++ddbridge
++de2104x
++decnet
++deflate
++defxx
++denali
++denali_dt
++denali_pci
++des_generic
++designware_i2s
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++digicolor-usart
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9000
++dm9601
++dme1737
++dmfe
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++dove_thermal
++dp83848
++dp83867
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_hdmi
++dw_hdmi-ahb-audio
++dw_hdmi-imx
++dw_hdmi-rockchip
++dw_mmc
++dw_mmc-exynos
++dw_mmc-k3
++dw_mmc-pci
++dw_mmc-pltfm
++dw_mmc-rockchip
++dw_wdt
++dwc3
++dwc3-exynos
++dwc3-omap
++dwc3-pci
++dwc3-qcom
++dwc_eth_qos
++dwmac-generic
++dwmac-ipq806x
++dwmac-lpc18xx
++dwmac-meson
++dwmac-rk
++dwmac-socfpga
++dwmac-sti
++dwmac-sunxi
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++earth-pt1
++earth-pt3
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++echainiv
++echo
++edac_core
++edt-ft5x06
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efs
++egalax_ts
++ehci-msm
++ehci-omap
++ehset
++elan_i2c
++elo
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emac_arc
++emac_rockchip
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++emif
++empeg
++ems_pci
++ems_usb
++emu10k1-gp
++enc28j60
++enclosure
++encoder-opa362
++encoder-tfp410
++encx24j600
++encx24j600-regmap
++eni
++enic
++epat
++epia
++epic100
++eql
++esas2r
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++exynos-gsc
++exynos-rng
++exynos_adc
++exynosdrm
++ezusb
++f2fs
++f71805f
++f71882fg
++f75375s
++f81232
++fakelb
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_sys_fops
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdp
++fdp_i2c
++fealnx
++ff-memless
++firedtv
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fl512
++flexcan
++flexfb
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fsl-dcu-drm
++fsl-edma
++fsl_lpuart
++ft6236
++ftdi-elan
++ftdi_sio
++ftgmac100
++ftl
++ftmac100
++fujitsu_ts
++g450_pll
++g760a
++g762
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_multi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcc-apq8084
++gcc-ipq806x
++gcc-msm8660
++gcc-msm8916
++gcc-msm8960
++gcc-msm8974
++gcm
++gdmtty
++gdmulte
++gdmwm
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++gf128mul
++gf2k
++gfs2
++ghash-arm-ce
++ghash-generic
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-74x164
++gpio-74xx-mmio
++gpio-addr-flash
++gpio-adnp
++gpio-adp5520
++gpio-adp5588
++gpio-altera
++gpio-amd8111
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-fan
++gpio-grgpio
++gpio-ir-recv
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-rcar
++gpio-rdc321x
++gpio-regulator
++gpio-syscon
++gpio-tps65912
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mouse
++gpio_tilt_polled
++gpio_wdt
++gr_udc
++grace
++grcan
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++gxt4500
++hackrf
++hamachi
++hampshire
++hanwang
++hci
++hci_uart
++hci_vhci
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfs
++hfsplus
++hi6421-pmic-core
++hi6421-regulator
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++highbank-cpufreq
++highbank_l2_edac
++highbank_mc_edac
++hih6130
++hip04_eth
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi-acpu-cpufreq
++hisi504_nand
++hisi_thermal
++hix5hd2_gmac
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hnae
++hns_dsaf
++hns_enet_drv
++hns_mdio
++hopper
++horus3a
++hostap
++hostap_pci
++hostap_plx
++hp100
++hpfs
++hpilo
++hpsa
++hptiop
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++htc-pasic3
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hwa-hc
++hwa-rc
++hwmon-vid
++hwspinlock_core
++hx8357
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd8111
++i2c-arb-gpio-challenge
++i2c-axxia
++i2c-cbus-gpio
++i2c-cros-ec-tunnel
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-emev2
++i2c-exynos5
++i2c-gpio
++i2c-hid
++i2c-hix5hd2
++i2c-i801
++i2c-isch
++i2c-kempld
++i2c-matroxfb
++i2c-meson
++i2c-mt65xx
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-pinctrl
++i2c-mux-reg
++i2c-mv64xxx
++i2c-nforce2
++i2c-nomadik
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-piix4
++i2c-qup
++i2c-rcar
++i2c-riic
++i2c-rk3x
++i2c-robotfuzz-osif
++i2c-sh_mobile
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-slave-eeprom
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-uniphier
++i2c-uniphier-f
++i2c-versatile
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i40e
++i40evf
++i5k_amb
++i6300esb
++i740fb
++ib_addr
++ib_cm
++ib_core
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibmaem
++ibmpex
++icp_multi
++icplus
++ics932s401
++idma64
++idmouse
++idt77252
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imm
++imon
++impa7
++ims-pcu
++imx-ipu-v3
++imx-ipuv3-crtc
++imx-ldb
++imx-tve
++imx074
++imx6ul_tsc
++imx_thermal
++imxdrm
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int51x1
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++iproc_nand
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++irlan
++irnet
++irqbypass
++irtty-sir
++iscsi_boot_sysfs
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it87
++it913x
++itd1000
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++k3dma
++kafs
++kalmia
++kaweth
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks0108
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l4f00242t03
++l64781
++lan78xx
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcc-ipq806x
++lcc-msm8960
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-aat1290
++leds-adp5520
++leds-bcm6328
++leds-bcm6358
++leds-bd2802
++leds-blinkm
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-ktd2692
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max77693
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-ns2
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-pwm
++leds-regulator
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++lis3lv02d_spi
++litelink-sir
++lkkbd
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr2_nvm
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac80211
++mac80211_hwsim
++mac802154
++macb
++macmodes
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mailbox-test
++mantis
++mantis_core
++map_absent
++map_ram
++map_rom
++marvell
++marvell-cesa
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max5821
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max77693-haptic
++max77693_charger
++max77802
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++mdc800
++mdio
++mdio-bcm-unimac
++mdio-bitbang
++mdio-gpio
++mdio-mux
++mdio-mux-gpio
++mdio-mux-mmioreg
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++meson-ir
++meson_uart
++meson_wdt
++metro-usb
++metronomefb
++mf6x4
++mg_disk
++mga
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microtek
++mii
++minix
++mip6
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmcc-apq8084
++mmcc-msm8960
++mmcc-msm8974
++mmci_qcom_dml
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi001
++msi2500
++msm
++msm-rng
++msp3400
++mspro_block
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt8173-max98090
++mt8173-rt5650-rt5676
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd_dataflash
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-afe-pcm
++mtk-pmic-wrap
++mtk-sd
++mtk_wdt
++mtouch
++multipath
++multiq3
++musb_am335x
++musb_dsps
++mv643xx_eth
++mv_cesa
++mv_u3d_core
++mv_udc
++mvmdio
++mvneta
++mvpp2
++mvsas
++mvsdio
++mvumi
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxc4005
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxser
++mxuport
++myri10ge
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nbpfaxi
++nci
++nci_spi
++nci_uart
++ncpfs
++nct6683
++nct6775
++nct7802
++nct7904
++nd_blk
++nd_btt
++nd_pmem
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_labpc
++ni_labpc_common
++ni_labpc_pci
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicstar
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nosy
++notifier-error-inject
++nouveau
++nozomi
++nps_enet
++ns558
++ns83820
++nsp32
++ntb
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nvidiafb
++nvme
++nvmem_core
++nvmem_qfprom
++nvmem_rockchip_efuse
++nvram
++nxp-nci
++nxp-nci_i2c
++nxp-ptn3460
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_xilinx_wdt
++old_belkin-sir
++omap
++omap-aes
++omap-des
++omap-mailbox
++omap-ocp2scp
++omap-rng
++omap-sham
++omap2430
++omap4-keypad
++omap_hdq
++omap_hwspinlock
++omap_wdt
++omapfb
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++orion_nand
++orion_wdt
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++palmas-pwrbutton
++palmas-regulator
++pandora_bl
++panel
++panel-dpi
++panel-dsi-cm
++panel-lg-lg4573
++panel-lgphilips-lb035q02
++panel-nec-nl8048hl11
++panel-samsung-ld9040
++panel-samsung-s6e8aa0
++panel-sharp-lq101r1sx01
++panel-sharp-ls037v7dw01
++panel-simple
++panel-sony-acx565akm
++panel-tpo-td028ttec1
++panel-tpo-td043mtea1
++parade-ps8622
++parallel-display
++paride
++parkbd
++parport
++parport_ax88796
++parport_pc
++parport_serial
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_of_platform
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sis
++pata_sl82c105
++pata_triflex
++pata_via
++pbias-regulator
++pc300too
++pc87360
++pc87427
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_udc
++pci
++pci-stub
++pci200syn
++pcie-iproc
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcrypt
++pcwd_pci
++pcwd_usb
++pd
++pda_power
++pdc_adma
++peak_pci
++peak_usb
++pegasus
++penmount
++percpu_test
++pf
++pfuze100-regulator
++pg
++phantom
++phonet
++phram
++phy-am335x
++phy-am335x-control
++phy-bcm-kona-usb2
++phy-berlin-sata
++phy-berlin-usb
++phy-dm816x-usb
++phy-exynos-usb2
++phy-exynos5-usbdrd
++phy-gpio-vbus-usb
++phy-hix5hd2-sata
++phy-isp1301
++phy-msm-usb
++phy-mt65xx-usb3
++phy-omap-control
++phy-omap-usb2
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-qcom-8x16-usb
++phy-qcom-apq8064-sata
++phy-qcom-ipq806x-sata
++phy-qcom-ufs
++phy-qcom-ufs-qmp-14nm
++phy-qcom-ufs-qmp-20nm
++phy-rcar-gen2
++phy-rcar-usb
++phy-rockchip-usb
++phy-tahvo
++phy-ti-pipe3
++phy-tusb1210
++phy-twl4030-usb
++phy-twl6030-usb
++physmap
++physmap_of
++pinctrl-apq8064
++pinctrl-apq8084
++pinctrl-ipq8064
++pinctrl-msm8660
++pinctrl-msm8916
++pinctrl-msm8960
++pinctrl-msm8x74
++pinctrl-ph1-ld4
++pinctrl-ph1-ld6b
++pinctrl-ph1-pro4
++pinctrl-ph1-pro5
++pinctrl-ph1-sld8
++pinctrl-proxstream2
++pinctrl-spmi-gpio
++pinctrl-spmi-mpp
++pinctrl-ssbi-gpio
++pinctrl-ssbi-mpp
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl172
++pl2303
++pl330
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8921-core
++pm8941-pwrkey
++pm8941-wled
++pm8xxx-vibrator
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pmic8xxx-keypad
++pmic8xxx-pwrkey
++pn533
++pn544
++pn544_i2c
++pn_pep
++poly1305_generic
++port100
++powermate
++powr1220
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_parport
++pptp
++prism2_usb
++ps2mult
++psmouse
++psnap
++pt
++pulsedlight-lidar-lite-v2
++pvrusb2
++pwc
++pwm-atmel-hlcdc
++pwm-beeper
++pwm-berlin
++pwm-fan
++pwm-fsl-ftm
++pwm-lp3943
++pwm-mtk-disp
++pwm-omap-dmtimer
++pwm-pca9685
++pwm-rcar
++pwm-regulator
++pwm-renesas-tpu
++pwm-rockchip
++pwm-samsung
++pwm-tiecap
++pwm-tiehrpwm
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa168_eth
++pxa27x_udc
++pxa3xx_nand
++qcaspi
++qcaux
++qcom-coincell
++qcom-spmi-iadc
++qcom-spmi-pmic
++qcom-spmi-temp-alarm
++qcom-spmi-vadc
++qcom-wdt
++qcom_bam_dma
++qcom_gsbi
++qcom_hwspinlock
++qcom_rpm
++qcom_rpm-regulator
++qcom_smbb
++qcom_smd-regulator
++qcom_spmi-regulator
++qcrypto
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qoriq-cpufreq
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-bcm2048
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-shark
++radio-si476x
++radio-tea5764
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ravb
++raw
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rcar-dmac
++rcar-du-drm
++rcar-hpbdma
++rcar_can
++rcar_jpu
++rcar_thermal
++rcar_vin
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++renesas_usbhs
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio500
++rivafb
++rj54n1cb0c
++rk808
++rk808-regulator
++rmd128
++rmd160
++rmd256
++rmd320
++rmobile-reset
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rockchip-io-domain
++rockchip_drm_vop
++rockchip_saradc
++rockchip_thermal
++rockchipdrm
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-armada38x
++rtc-as3722
++rtc-bq32k
++rtc-bq4802
++rtc-cmos
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-hid-sensor-time
++rtc-hym8563
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max77802
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-msm6242
++rtc-mt6397
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-pl030
++rtc-pm8xxx
++rtc-r9701
++rtc-rc5t583
++rtc-rk808
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-snvs
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtc-zynqmp
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3c-fb
++s3c2410_wdt
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s5p-g2d
++s5p-hdmi
++s5p-hdmiphy
++s5p-jpeg
++s5p-mfc
++s5p-mixer
++s5p-sdo
++s5p-sii9234
++s5p-sss
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7706h
++safe_serial
++salsa20_generic
++samsung
++samsung-keypad
++samsung-sxgbe
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_rcar
++sata_sil
++sata_sil24
++sata_sis
++sata_svw
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sbp_target
++sbs-battery
++sc16is7xx
++sc92031
++sca3000
++sch5627
++sch5636
++sch56xx-common
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scpi-cpufreq
++scpi-hwmon
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++sdhci-dove
++sdhci-msm
++sdhci-of-arasan
++sdhci-of-at91
++sdhci-pci
++sdhci-pxav3
++sdhci-s3c
++sdhci_f_sdh30
++sdio_uart
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial2002
++serio_raw
++sermouse
++serpent_generic
++serport
++ses
++sfc
++sh-sci
++sh_eth
++sh_flctl
++sh_irda
++sh_keysc
++sh_mmcif
++sh_mobile_ceu_camera
++sh_mobile_csi2
++sh_mobile_hdmi
++sh_mobile_lcdcfb
++sh_mobile_meram
++sh_mobile_sdhi
++sh_veu
++sh_vou
++sha1-arm
++sha1-arm-ce
++sha1-arm-neon
++sha2-arm-ce
++sha256-arm
++sha512-arm
++shark2
++shdma
++shmob-drm
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sir-dev
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skfp
++skge
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++slcan
++slip
++slram
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smc911x
++smc91x
++smd
++smd-rpm
++smem
++smipcie
++smm665
++smsc
++smsc47b397
++smsc47m1
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd-aaci
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als300
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt3328
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-cs4281
++snd-cs46xx
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1938
++snd-es1968
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-maestro3
++snd-mia
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm-oss
++snd-pcxhr
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-apq8016-sbc
++snd-soc-armada-370-db
++snd-soc-arndale-rt5631
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-davinci-mcasp
++snd-soc-es8328
++snd-soc-fsi
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-ssi
++snd-soc-gtm601
++snd-soc-i2s
++snd-soc-idma
++snd-soc-imx-audmux
++snd-soc-kirkwood
++snd-soc-lpass-apq8016
++snd-soc-lpass-cpu
++snd-soc-lpass-ipq806x
++snd-soc-lpass-platform
++snd-soc-max98090
++snd-soc-max98095
++snd-soc-max98357a
++snd-soc-odroidx2-max98090
++snd-soc-omap-hdmi-audio
++snd-soc-pcm
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rcar
++snd-soc-rl6231
++snd-soc-rockchip-i2s
++snd-soc-rockchip-max98090
++snd-soc-rockchip-rt5645
++snd-soc-rockchip-spdif
++snd-soc-rsrc-card
++snd-soc-rt5631
++snd-soc-rt5645
++snd-soc-rt5677
++snd-soc-rt5677-spi
++snd-soc-rx51
++snd-soc-s3c-dma
++snd-soc-samsung-spdif
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-smdk-spdif
++snd-soc-smdk-wm8994
++snd-soc-smdk-wm8994pcm
++snd-soc-snow
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-storm
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-wm-hubs
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-wm8994
++snd-soc-xtfpga-i2s
++snd-sonicvibes
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-variax
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-ymfpci
++snic
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++soc_scale_crop
++softdog
++softing
++solo6x10
++solos-pci
++sony-btf-mpx
++sp2
++sp805_wdt
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_dectlk
++speakup_dummy
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi-lm70llp
++spi-meson-spifc
++spi-mt65xx
++spi-nor
++spi-oc-tiny
++spi-orion
++spi-pl022
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-qup
++spi-rockchip
++spi-rspi
++spi-s3c64xx
++spi-sc18is602
++spi-sh-hspi
++spi-sh-msiof
++spi-ti-qspi
++spi-tle62x0
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spmi
++spmi-pmic-arb
++sr9700
++sr9800
++ssb
++ssbi
++ssd1307fb
++ssfdc
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++sstfb
++ssu100
++st
++st-asc
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm32-usart
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sudmac
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++svgalib
++sx8
++sx8654
++sx9500
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink_gt
++synclinkmp
++syscopyarea
++sysfillrect
++sysimgblt
++sysv
++t1pci
++t5403
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc3589x-keypad
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tehuti
++tekram-sir
++teranetics
++test-hexdump
++test-kprobes
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tg3
++tgr192
++thmc50
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti-soc-thermal
++ti-vpe
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_hecc
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++tilcdc
++timeriomem-rng
++tipc
++tlan
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmio_mmc
++tmio_mmc_core
++tmio_nand
++tmiofb
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++torture
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps65218-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tusb6010
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl-regulator
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-xilinx
++udf
++udl
++udlfb
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-dmac
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmisc_imx
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vcan
++vcnl4000
++ves1820
++ves1x93
++veth
++vexpress
++vexpress-spc-cpufreq
++vf610_adc
++vfio
++vfio-amba
++vfio-pci
++vfio-platform
++vfio-platform-amdxgbe
++vfio-platform-base
++vfio-platform-calxedaxgmac
++vfio_virqfd
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-rhine
++via-sdmmc
++via-velocity
++via686a
++videobuf-core
++videobuf-dma-contig
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videodev
++vim2m
++viperboard
++viperboard_adc
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_scsi
++virtual
++visor
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vrf
++vringh
++vsock
++vsp1
++vsxxxaa
++vt1211
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83627ehf
++w83627hf
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++walkera0701
++wanxl
++warrior
++wcn36xx
++wd719x
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x_tables
++xc4000
++xc5000
++xcbc
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xgmac
++xhci-plat-hcd
++xilinx-tpg
++xilinx-video
++xilinx-vtc
++xilinx_uartps
++xillybus_core
++xillybus_of
++xillybus_pcie
++xor
++xor-neon
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yurex
++zaurus
++zd1201
++zd1211rw
++zforce_ts
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++zr364xx
++zram
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/armhf/generic.compiler b/debian.master/abi/4.4.0-111.134/armhf/generic.compiler
+new file mode 100644
+index 0000000..33e5508
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/armhf/generic.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu/Linaro 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/armhf/generic.modules b/debian.master/abi/4.4.0-111.134/armhf/generic.modules
+new file mode 100644
+index 0000000..1fa2312
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/armhf/generic.modules
+@@ -0,0 +1,4631 @@
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_dw
++8250_mid
++8250_omap
++8250_uniphier
++8255
++8255_pci
++8390
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++DAC960
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++ablk_helper
++acard-ahci
++acecad
++acenic
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++aes-arm
++aes-arm-bs
++aes-arm-ce
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++afs
++ah4
++ah6
++ahci
++ahci_ceva
++ahci_mvebu
++ahci_qoriq
++ahci_tegra
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am35x
++am53c974
++amba-pl010
++ambakmi
++amc6821
++amd
++amd5536udc
++amd8111e
++amdgpu
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apbps2
++apds9300
++apds9802als
++apds990x
++apds9960
++appledisplay
++appletalk
++appletouch
++applicom
++aquantia
++ar1021_i2c
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_emac
++arc_ps2
++arc_uart
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arm_big_little
++arm_big_little_dt
++arm_mhu
++arm_scpi
++armada
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3722-regulator
++as3935
++as5011
++asc7621
++ascot2e
++asix
++ast
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++ata_generic
++ata_piix
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atm
++atmel
++atmel-flexcom
++atmel-hlcdc
++atmel-hlcdc-dc
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp870u
++atusb
++atxp1
++aty128fb
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avmfritz
++ax25
++ax88179_178a
++ax88796
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1pci
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bL_switcher_dummy_if
++bas_gigaset
++batman-adv
++baycom_epp
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bcm-keypad
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm63138_nand
++bcm63xx_uart
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcma
++bcmsysport
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++berlin2-adc
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpck
++bpck6
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmnand
++brcmsmac
++brcmstb_nand
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++caam
++caam_jr
++caamalg
++caamhash
++caamrng
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++cap11xx
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc10001_adc
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipone_icn8318
++chnl_net
++ci_hdrc
++ci_hdrc_imx
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++clip
++clk-cdce706
++clk-cdce925
++clk-max77686
++clk-max77802
++clk-palmas
++clk-pwm
++clk-qcom
++clk-rk808
++clk-s2mps11
++clk-scpi
++clk-si514
++clk-si5351
++clk-si570
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmt_speech
++cmtp
++cnic
++cobalt
++cobra
++coda
++colibri-vf50-ts
++com20020
++com20020-pci
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_parport
++comedi_pci
++comedi_test
++comedi_usb
++comm
++configfs
++connector-analog-tv
++connector-dvi
++contec_pci_dio
++cordic
++core
++cp210x
++cpia2
++cppi41
++cpu-notifier-error-inject
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc7
++crc8
++cros_ec
++cros_ec_devs
++cros_ec_i2c
++cros_ec_keyb
++cros_ec_spi
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++cs89x0
++csiostor
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da8xx-fb
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++davinci_emac
++db9
++dc395x
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++ddbridge
++de2104x
++decnet
++deflate
++defxx
++denali
++denali_dt
++denali_pci
++des_generic
++designware_i2s
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++digicolor-usart
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9000
++dm9601
++dme1737
++dmfe
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++dove_thermal
++dp83848
++dp83867
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_hdmi
++dw_hdmi-ahb-audio
++dw_hdmi-imx
++dw_hdmi-rockchip
++dw_mmc
++dw_mmc-exynos
++dw_mmc-k3
++dw_mmc-pci
++dw_mmc-pltfm
++dw_mmc-rockchip
++dw_wdt
++dwc3
++dwc3-exynos
++dwc3-omap
++dwc3-pci
++dwc3-qcom
++dwc_eth_qos
++dwmac-generic
++dwmac-ipq806x
++dwmac-lpc18xx
++dwmac-meson
++dwmac-rk
++dwmac-socfpga
++dwmac-sti
++dwmac-sunxi
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++earth-pt1
++earth-pt3
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++echainiv
++echo
++edac_core
++edt-ft5x06
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efs
++egalax_ts
++ehci-msm
++ehci-mxc
++ehci-omap
++ehci-tegra
++ehset
++elan_i2c
++elo
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emac_arc
++emac_rockchip
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++emif
++empeg
++ems_pci
++ems_usb
++emu10k1-gp
++enc28j60
++enclosure
++encoder-opa362
++encoder-tfp410
++encx24j600
++encx24j600-regmap
++eni
++enic
++epat
++epia
++epic100
++eql
++esas2r
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++exynos-gsc
++exynos-rng
++exynos_adc
++exynosdrm
++ezusb
++f2fs
++f71805f
++f71882fg
++f75375s
++f81232
++fakelb
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_sys_fops
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdp
++fdp_i2c
++fealnx
++ff-memless
++firedtv
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fl512
++flexcan
++flexfb
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fsl-dcu-drm
++fsl-edma
++fsl-mph-dr-of
++fsl-quadspi
++fsl_lpuart
++fsl_pq_mdio
++fsl_usb2_udc
++ft6236
++ftdi-elan
++ftdi_sio
++ftgmac100
++ftl
++ftmac100
++fujitsu_ts
++fusb300_udc
++g450_pll
++g760a
++g762
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_multi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcc-apq8084
++gcc-ipq806x
++gcc-msm8660
++gcc-msm8916
++gcc-msm8960
++gcc-msm8974
++gcm
++gdmtty
++gdmulte
++gdmwm
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++gf128mul
++gf2k
++gfs2
++ghash-arm-ce
++ghash-generic
++gianfar_driver
++gianfar_ptp
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-74x164
++gpio-74xx-mmio
++gpio-addr-flash
++gpio-adnp
++gpio-adp5520
++gpio-adp5588
++gpio-altera
++gpio-amd8111
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-fan
++gpio-grgpio
++gpio-ir-recv
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-rcar
++gpio-rdc321x
++gpio-regulator
++gpio-syscon
++gpio-tps65912
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mouse
++gpio_tilt_polled
++gpio_wdt
++gpmi_nand
++gr_udc
++grace
++grcan
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++gxt4500
++hackrf
++hamachi
++hampshire
++hanwang
++hci
++hci_uart
++hci_vhci
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfs
++hfsplus
++hi6421-pmic-core
++hi6421-regulator
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++hifn_795x
++highbank-cpufreq
++highbank_l2_edac
++highbank_mc_edac
++hih6130
++hip04_eth
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi-acpu-cpufreq
++hisi504_nand
++hisi_thermal
++hix5hd2_gmac
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hnae
++hns_dsaf
++hns_enet_drv
++hns_mdio
++hopper
++horus3a
++host1x
++hostap
++hostap_pci
++hostap_plx
++hp100
++hpfs
++hpilo
++hpsa
++hptiop
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++htc-pasic3
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hwa-hc
++hwa-rc
++hwmon-vid
++hwspinlock_core
++hx8357
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd8111
++i2c-arb-gpio-challenge
++i2c-cbus-gpio
++i2c-cros-ec-tunnel
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-emev2
++i2c-exynos5
++i2c-gpio
++i2c-hid
++i2c-hix5hd2
++i2c-i801
++i2c-isch
++i2c-kempld
++i2c-matroxfb
++i2c-meson
++i2c-mt65xx
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-pinctrl
++i2c-mux-reg
++i2c-mv64xxx
++i2c-nforce2
++i2c-nomadik
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-piix4
++i2c-qup
++i2c-rcar
++i2c-riic
++i2c-rk3x
++i2c-robotfuzz-osif
++i2c-sh_mobile
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-slave-eeprom
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tegra
++i2c-tiny-usb
++i2c-uniphier
++i2c-uniphier-f
++i2c-versatile
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i40e
++i40evf
++i5k_amb
++i6300esb
++i740fb
++ib_addr
++ib_cm
++ib_core
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibmaem
++ibmpex
++icp_multi
++icplus
++ics932s401
++idma64
++idmouse
++idt77252
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imm
++imon
++impa7
++ims-pcu
++imx-dma
++imx-ipu-v3
++imx-ipuv3-crtc
++imx-ldb
++imx-sdma
++imx-tve
++imx074
++imx21-hcd
++imx2_wdt
++imx6q-cpufreq
++imx6ul_tsc
++imx_keypad
++imx_thermal
++imxdrm
++imxfb
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int51x1
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++iproc_nand
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++irlan
++irnet
++irqbypass
++irtty-sir
++iscsi_boot_sysfs
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it87
++it913x
++itd1000
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++k3dma
++kafs
++kalmia
++kaweth
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks0108
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l4f00242t03
++l64781
++lan78xx
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcc-ipq806x
++lcc-msm8960
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-aat1290
++leds-adp5520
++leds-bcm6328
++leds-bcm6358
++leds-bd2802
++leds-blinkm
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-ktd2692
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max77693
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-ns2
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-pwm
++leds-regulator
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++lis3lv02d_spi
++litelink-sir
++lkkbd
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr2_nvm
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac80211
++mac80211_hwsim
++mac802154
++macb
++macmodes
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mailbox-test
++mantis
++mantis_core
++map_absent
++map_ram
++map_rom
++marvell
++marvell-cesa
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max5821
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max77693-haptic
++max77693_charger
++max77802
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++mdc800
++mdio
++mdio-bcm-unimac
++mdio-bitbang
++mdio-gpio
++mdio-mux
++mdio-mux-gpio
++mdio-mux-mmioreg
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++meson-ir
++meson_uart
++meson_wdt
++metro-usb
++metronomefb
++mf6x4
++mg_disk
++mga
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microtek
++mii
++minix
++mip6
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmcc-apq8084
++mmcc-msm8960
++mmcc-msm8974
++mmci_qcom_dml
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi001
++msi2500
++msm
++msm-rng
++msp3400
++mspro_block
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt8173-max98090
++mt8173-rt5650-rt5676
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd_dataflash
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-afe-pcm
++mtk-pmic-wrap
++mtk-sd
++mtk_wdt
++mtouch
++multipath
++multiq3
++musb_am335x
++musb_dsps
++mv643xx_eth
++mv_cesa
++mv_u3d_core
++mv_udc
++mvmdio
++mvneta
++mvpp2
++mvsas
++mvsdio
++mvumi
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mx3_camera
++mxb
++mxc4005
++mxc_nand
++mxc_w1
++mxcmmc
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxs-dcp
++mxser
++mxsfb
++mxuport
++myri10ge
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nbpfaxi
++nci
++nci_spi
++nci_uart
++ncpfs
++nct6683
++nct6775
++nct7802
++nct7904
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_labpc
++ni_labpc_common
++ni_labpc_pci
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicstar
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nokia-modem
++nosy
++notifier-error-inject
++nouveau
++nozomi
++nps_enet
++ns558
++ns83820
++nsp32
++ntb
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nvec
++nvec_kbd
++nvec_paz00
++nvec_power
++nvec_ps2
++nvidiafb
++nvme
++nvmem-imx-ocotp
++nvmem-vf610-ocotp
++nvmem_core
++nvmem_qfprom
++nvmem_rockchip_efuse
++nvram
++nxp-nci
++nxp-nci_i2c
++nxp-ptn3460
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_xilinx_wdt
++ohci-omap3
++old_belkin-sir
++omap
++omap-aes
++omap-des
++omap-mailbox
++omap-ocp2scp
++omap-rng
++omap-sham
++omap-vout
++omap2
++omap2430
++omap3-isp
++omap3-rom-rng
++omap4-keypad
++omap_hdq
++omap_hwspinlock
++omap_remoteproc
++omap_ssi
++omap_ssi_port
++omap_wdt
++omapfb
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++orion_nand
++orion_wdt
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++palmas-pwrbutton
++palmas-regulator
++pandora_bl
++panel
++panel-dpi
++panel-dsi-cm
++panel-lg-lg4573
++panel-lgphilips-lb035q02
++panel-nec-nl8048hl11
++panel-samsung-ld9040
++panel-samsung-s6e8aa0
++panel-sharp-lq101r1sx01
++panel-sharp-ls037v7dw01
++panel-simple
++panel-sony-acx565akm
++panel-tpo-td028ttec1
++panel-tpo-td043mtea1
++parade-ps8622
++parallel-display
++paride
++parkbd
++parport
++parport_ax88796
++parport_pc
++parport_serial
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_imx
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_of_platform
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sis
++pata_sl82c105
++pata_triflex
++pata_via
++pbias-regulator
++pc300too
++pc87360
++pc87427
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_udc
++pci
++pci-stub
++pci200syn
++pcie-iproc
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcrypt
++pcwd_pci
++pcwd_usb
++pd
++pda_power
++pdc_adma
++peak_pci
++peak_usb
++pegasus
++penmount
++percpu_test
++pf
++pfuze100-regulator
++pg
++phantom
++phonet
++phram
++phy-am335x
++phy-am335x-control
++phy-bcm-kona-usb2
++phy-berlin-sata
++phy-berlin-usb
++phy-dm816x-usb
++phy-exynos-usb2
++phy-exynos5-usbdrd
++phy-gpio-vbus-usb
++phy-hix5hd2-sata
++phy-isp1301
++phy-msm-usb
++phy-mt65xx-usb3
++phy-omap-control
++phy-omap-usb2
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-qcom-8x16-usb
++phy-qcom-apq8064-sata
++phy-qcom-ipq806x-sata
++phy-qcom-ufs
++phy-qcom-ufs-qmp-14nm
++phy-qcom-ufs-qmp-20nm
++phy-rcar-gen2
++phy-rcar-usb
++phy-rockchip-usb
++phy-tahvo
++phy-tegra-usb
++phy-ti-pipe3
++phy-tusb1210
++phy-twl4030-usb
++phy-twl6030-usb
++physmap
++physmap_of
++pinctrl-apq8064
++pinctrl-apq8084
++pinctrl-ipq8064
++pinctrl-msm8660
++pinctrl-msm8916
++pinctrl-msm8960
++pinctrl-msm8x74
++pinctrl-ph1-ld4
++pinctrl-ph1-ld6b
++pinctrl-ph1-pro4
++pinctrl-ph1-pro5
++pinctrl-ph1-sld8
++pinctrl-proxstream2
++pinctrl-spmi-gpio
++pinctrl-spmi-mpp
++pinctrl-ssbi-gpio
++pinctrl-ssbi-mpp
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl172
++pl2303
++pl330
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8921-core
++pm8941-pwrkey
++pm8941-wled
++pm8xxx-vibrator
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pmic8xxx-keypad
++pmic8xxx-pwrkey
++pn533
++pn544
++pn544_i2c
++pn_pep
++poly1305_generic
++port100
++powermate
++powr1220
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_parport
++pptp
++prism2_usb
++ps2mult
++psmouse
++psnap
++pt
++pulsedlight-lidar-lite-v2
++pvrusb2
++pwc
++pwm-atmel-hlcdc
++pwm-beeper
++pwm-berlin
++pwm-fan
++pwm-fsl-ftm
++pwm-imx
++pwm-lp3943
++pwm-mtk-disp
++pwm-omap-dmtimer
++pwm-pca9685
++pwm-rcar
++pwm-regulator
++pwm-renesas-tpu
++pwm-rockchip
++pwm-samsung
++pwm-tegra
++pwm-tiecap
++pwm-tiehrpwm
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa168_eth
++pxa27x_udc
++pxa3xx_nand
++qcaspi
++qcaux
++qcom-coincell
++qcom-spmi-iadc
++qcom-spmi-pmic
++qcom-spmi-temp-alarm
++qcom-spmi-vadc
++qcom-wdt
++qcom_bam_dma
++qcom_gsbi
++qcom_hwspinlock
++qcom_rpm
++qcom_rpm-regulator
++qcom_smbb
++qcom_smd-regulator
++qcom_spmi-regulator
++qcrypto
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qoriq-cpufreq
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-bcm2048
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-shark
++radio-si476x
++radio-tea5764
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ravb
++raw
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rcar-dmac
++rcar-du-drm
++rcar-hpbdma
++rcar_can
++rcar_jpu
++rcar_thermal
++rcar_vin
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++renesas_usbhs
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio500
++rivafb
++rj54n1cb0c
++rk808
++rk808-regulator
++rmd128
++rmd160
++rmd256
++rmd320
++rmobile-reset
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rockchip-io-domain
++rockchip_drm_vop
++rockchip_saradc
++rockchip_thermal
++rockchipdrm
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-armada38x
++rtc-as3722
++rtc-bq32k
++rtc-bq4802
++rtc-cmos
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-hid-sensor-time
++rtc-hym8563
++rtc-imxdi
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max77802
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-msm6242
++rtc-mt6397
++rtc-mxc
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8563
++rtc-pcf8583
++rtc-pl030
++rtc-pm8xxx
++rtc-r9701
++rtc-rc5t583
++rtc-rk808
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-snvs
++rtc-stk17ta8
++rtc-tegra
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtc-zynqmp
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3c-fb
++s3c2410_wdt
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s5p-g2d
++s5p-hdmi
++s5p-hdmiphy
++s5p-jpeg
++s5p-mfc
++s5p-mixer
++s5p-sdo
++s5p-sii9234
++s5p-sss
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7706h
++safe_serial
++sahara
++salsa20_generic
++samsung
++samsung-keypad
++samsung-sxgbe
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_rcar
++sata_sil
++sata_sil24
++sata_sis
++sata_svw
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sbp_target
++sbs-battery
++sc16is7xx
++sc92031
++sca3000
++sch5627
++sch5636
++sch56xx-common
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scpi-cpufreq
++scpi-hwmon
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++sdhci-dove
++sdhci-msm
++sdhci-of-arasan
++sdhci-of-at91
++sdhci-of-esdhc
++sdhci-pci
++sdhci-pxav3
++sdhci-s3c
++sdhci-tegra
++sdhci_f_sdh30
++sdio_uart
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial-tegra
++serial2002
++serio_raw
++sermouse
++serpent_generic
++serport
++ses
++sfc
++sh-sci
++sh_eth
++sh_flctl
++sh_irda
++sh_keysc
++sh_mmcif
++sh_mobile_ceu_camera
++sh_mobile_csi2
++sh_mobile_hdmi
++sh_mobile_lcdcfb
++sh_mobile_meram
++sh_mobile_sdhi
++sh_veu
++sh_vou
++sha1-arm
++sha1-arm-ce
++sha1-arm-neon
++sha2-arm-ce
++sha256-arm
++sha512-arm
++shark2
++shdma
++shmob-drm
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sir-dev
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skfp
++skge
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++slcan
++slip
++slram
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smc911x
++smc91x
++smd
++smd-rpm
++smem
++smipcie
++smm665
++smsc
++smsc47b397
++smsc47m1
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd-aaci
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4xxx-adda
++snd-aloop
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-cs4281
++snd-cs46xx
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-ens1370
++snd-ens1371
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-intel
++snd-hda-tegra
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-mia
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm-oss
++snd-pcxhr
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-alc5632
++snd-soc-apq8016-sbc
++snd-soc-armada-370-db
++snd-soc-arndale-rt5631
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-davinci-mcasp
++snd-soc-dmic
++snd-soc-edma
++snd-soc-es8328
++snd-soc-es8328-i2c
++snd-soc-es8328-spi
++snd-soc-eukrea-tlv320
++snd-soc-evm
++snd-soc-fsi
++snd-soc-fsl-asoc-card
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-utils
++snd-soc-gtm601
++snd-soc-i2s
++snd-soc-idma
++snd-soc-imx-es8328
++snd-soc-imx-mc13783
++snd-soc-imx-spdif
++snd-soc-imx-ssi
++snd-soc-imx-wm8962
++snd-soc-kirkwood
++snd-soc-lpass-apq8016
++snd-soc-lpass-cpu
++snd-soc-lpass-ipq806x
++snd-soc-lpass-platform
++snd-soc-max98090
++snd-soc-max98095
++snd-soc-max98357a
++snd-soc-mc13783
++snd-soc-odroidx2-max98090
++snd-soc-omap-abe-twl6040
++snd-soc-omap-dmic
++snd-soc-omap-hdmi-audio
++snd-soc-omap-mcpdm
++snd-soc-omap3pandora
++snd-soc-pcm
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rcar
++snd-soc-rl6231
++snd-soc-rockchip-i2s
++snd-soc-rockchip-max98090
++snd-soc-rockchip-rt5645
++snd-soc-rockchip-spdif
++snd-soc-rsrc-card
++snd-soc-rt5631
++snd-soc-rt5640
++snd-soc-rt5645
++snd-soc-rt5677
++snd-soc-rt5677-spi
++snd-soc-rx51
++snd-soc-s3c-dma
++snd-soc-samsung-spdif
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-smdk-spdif
++snd-soc-smdk-wm8994
++snd-soc-smdk-wm8994pcm
++snd-soc-snow
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-storm
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tegra-alc5632
++snd-soc-tegra-max98090
++snd-soc-tegra-pcm
++snd-soc-tegra-rt5640
++snd-soc-tegra-rt5677
++snd-soc-tegra-trimslice
++snd-soc-tegra-utils
++snd-soc-tegra-wm8753
++snd-soc-tegra-wm8903
++snd-soc-tegra-wm9712
++snd-soc-tegra20-ac97
++snd-soc-tegra20-das
++snd-soc-tegra20-i2s
++snd-soc-tegra20-spdif
++snd-soc-tegra30-ahub
++snd-soc-tegra30-i2s
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-twl6040
++snd-soc-wm-hubs
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-wm8994
++snd-soc-wm9712
++snd-soc-xtfpga-i2s
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-variax
++snd-usbmidi-lib
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-ymfpci
++snic
++snvs_pwrkey
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++soc_scale_crop
++softdog
++softing
++solo6x10
++solos-pci
++sony-btf-mpx
++sp2
++sp805_wdt
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_dectlk
++speakup_dummy
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-fsl-dspi
++spi-gpio
++spi-imx
++spi-lm70llp
++spi-meson-spifc
++spi-mt65xx
++spi-nor
++spi-oc-tiny
++spi-orion
++spi-pl022
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-qup
++spi-rockchip
++spi-rspi
++spi-s3c64xx
++spi-sc18is602
++spi-sh-hspi
++spi-sh-msiof
++spi-tegra114
++spi-tegra20-sflash
++spi-tegra20-slink
++spi-ti-qspi
++spi-tle62x0
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spmi
++spmi-pmic-arb
++sr9700
++sr9800
++ssb
++ssbi
++ssd1307fb
++ssfdc
++ssi_protocol
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++sstfb
++ssu100
++st
++st-asc
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm32-usart
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sudmac
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++svgalib
++sx8
++sx8654
++sx9500
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink_gt
++synclinkmp
++syscopyarea
++sysfillrect
++sysimgblt
++sysv
++t1pci
++t5403
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc3589x-keypad
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tegra-devfreq
++tegra-drm
++tegra-kbc
++tegra124-cpufreq
++tegra_wdt
++tehuti
++tekram-sir
++teranetics
++test-hexdump
++test-kprobes
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tg3
++tgr192
++thmc50
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti-soc-thermal
++ti-vpe
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_hecc
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++tilcdc
++timeriomem-rng
++tipc
++tlan
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmio_mmc
++tmio_mmc_core
++tmio_nand
++tmiofb
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++torture
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps65218-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tusb6010
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-xilinx
++udf
++udl
++udlfb
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-dmac
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmisc_imx
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vcan
++vcnl4000
++ves1820
++ves1x93
++veth
++vexpress
++vexpress-spc-cpufreq
++vf610_adc
++vf610_nfc
++vfio
++vfio-amba
++vfio-pci
++vfio-platform
++vfio-platform-amdxgbe
++vfio-platform-base
++vfio-platform-calxedaxgmac
++vfio_virqfd
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-rhine
++via-sdmmc
++via-velocity
++via686a
++videobuf-core
++videobuf-dma-contig
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videodev
++vim2m
++viperboard
++viperboard_adc
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_rpmsg_bus
++virtio_scsi
++virtual
++visor
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vrf
++vringh
++vsock
++vsp1
++vsxxxaa
++vt1211
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83627ehf
++w83627hf
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++walkera0701
++wanxl
++warrior
++wcn36xx
++wd719x
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++wire
++wishbone-serial
++wkup_m3_rproc
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x_tables
++xc4000
++xc5000
++xcbc
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xgmac
++xhci-plat-hcd
++xilinx-tpg
++xilinx-video
++xilinx-vtc
++xilinx_uartps
++xillybus_core
++xillybus_of
++xillybus_pcie
++xor
++xor-neon
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yurex
++zaurus
++zd1201
++zd1211rw
++zforce_ts
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++zr364xx
++zram
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/fwinfo b/debian.master/abi/4.4.0-111.134/fwinfo
+new file mode 100644
+index 0000000..506cf7f
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/fwinfo
+@@ -0,0 +1,998 @@
++firmware:       3826.arm
++firmware:       3com/typhoon.bin
++firmware:       6fire/dmx6fireap.ihx
++firmware:       6fire/dmx6firecf.bin
++firmware:       6fire/dmx6firel2.ihx
++firmware:       BCM2033-FW.bin
++firmware:       BCM2033-MD.hex
++firmware:       BT3CPCC.bin
++firmware:       RTL8192E/boot.img
++firmware:       RTL8192E/data.img
++firmware:       RTL8192E/main.img
++firmware:       RTL8192U/boot.img
++firmware:       RTL8192U/data.img
++firmware:       RTL8192U/main.img
++firmware:       a300_pfp.fw
++firmware:       a300_pm4.fw
++firmware:       a330_pfp.fw
++firmware:       a330_pm4.fw
++firmware:       a420_pfp.fw
++firmware:       a420_pm4.fw
++firmware:       acenic/tg1.bin
++firmware:       acenic/tg2.bin
++firmware:       adaptec/starfire_rx.bin
++firmware:       adaptec/starfire_tx.bin
++firmware:       advansys/3550.bin
++firmware:       advansys/38C0800.bin
++firmware:       advansys/38C1600.bin
++firmware:       advansys/mcode.bin
++firmware:       agere_ap_fw.bin
++firmware:       agere_sta_fw.bin
++firmware:       aic94xx-seq.fw
++firmware:       amdgpu/carrizo_ce.bin
++firmware:       amdgpu/carrizo_me.bin
++firmware:       amdgpu/carrizo_mec.bin
++firmware:       amdgpu/carrizo_mec2.bin
++firmware:       amdgpu/carrizo_pfp.bin
++firmware:       amdgpu/carrizo_rlc.bin
++firmware:       amdgpu/carrizo_sdma.bin
++firmware:       amdgpu/carrizo_sdma1.bin
++firmware:       amdgpu/carrizo_uvd.bin
++firmware:       amdgpu/carrizo_vce.bin
++firmware:       amdgpu/fiji_ce.bin
++firmware:       amdgpu/fiji_me.bin
++firmware:       amdgpu/fiji_mec.bin
++firmware:       amdgpu/fiji_mec2.bin
++firmware:       amdgpu/fiji_pfp.bin
++firmware:       amdgpu/fiji_rlc.bin
++firmware:       amdgpu/fiji_sdma.bin
++firmware:       amdgpu/fiji_sdma1.bin
++firmware:       amdgpu/fiji_smc.bin
++firmware:       amdgpu/fiji_uvd.bin
++firmware:       amdgpu/fiji_vce.bin
++firmware:       amdgpu/stoney_ce.bin
++firmware:       amdgpu/stoney_me.bin
++firmware:       amdgpu/stoney_mec.bin
++firmware:       amdgpu/stoney_pfp.bin
++firmware:       amdgpu/stoney_rlc.bin
++firmware:       amdgpu/stoney_sdma.bin
++firmware:       amdgpu/stoney_uvd.bin
++firmware:       amdgpu/stoney_vce.bin
++firmware:       amdgpu/tonga_ce.bin
++firmware:       amdgpu/tonga_mc.bin
++firmware:       amdgpu/tonga_me.bin
++firmware:       amdgpu/tonga_mec.bin
++firmware:       amdgpu/tonga_mec2.bin
++firmware:       amdgpu/tonga_pfp.bin
++firmware:       amdgpu/tonga_rlc.bin
++firmware:       amdgpu/tonga_sdma.bin
++firmware:       amdgpu/tonga_sdma1.bin
++firmware:       amdgpu/tonga_smc.bin
++firmware:       amdgpu/tonga_uvd.bin
++firmware:       amdgpu/tonga_vce.bin
++firmware:       amdgpu/topaz_ce.bin
++firmware:       amdgpu/topaz_mc.bin
++firmware:       amdgpu/topaz_me.bin
++firmware:       amdgpu/topaz_mec.bin
++firmware:       amdgpu/topaz_pfp.bin
++firmware:       amdgpu/topaz_rlc.bin
++firmware:       amdgpu/topaz_sdma.bin
++firmware:       amdgpu/topaz_sdma1.bin
++firmware:       amdgpu/topaz_smc.bin
++firmware:       ar5523.bin
++firmware:       asihpi/dsp5000.bin
++firmware:       asihpi/dsp6200.bin
++firmware:       asihpi/dsp6205.bin
++firmware:       asihpi/dsp6400.bin
++firmware:       asihpi/dsp6600.bin
++firmware:       asihpi/dsp8700.bin
++firmware:       asihpi/dsp8900.bin
++firmware:       ast_dp501_fw.bin
++firmware:       ath10k/QCA6174/hw2.1/board-2.bin
++firmware:       ath10k/QCA6174/hw2.1/board.bin
++firmware:       ath10k/QCA6174/hw2.1/firmware-4.bin
++firmware:       ath10k/QCA6174/hw2.1/firmware-5.bin
++firmware:       ath10k/QCA6174/hw3.0/board-2.bin
++firmware:       ath10k/QCA6174/hw3.0/board.bin
++firmware:       ath10k/QCA6174/hw3.0/firmware-4.bin
++firmware:       ath10k/QCA6174/hw3.0/firmware-5.bin
++firmware:       ath10k/QCA9377/hw1.0/board.bin
++firmware:       ath10k/QCA9377/hw1.0/firmware-5.bin
++firmware:       ath10k/QCA988X/hw2.0/board-2.bin
++firmware:       ath10k/QCA988X/hw2.0/board.bin
++firmware:       ath10k/QCA988X/hw2.0/firmware-2.bin
++firmware:       ath10k/QCA988X/hw2.0/firmware-3.bin
++firmware:       ath10k/QCA988X/hw2.0/firmware-4.bin
++firmware:       ath10k/QCA988X/hw2.0/firmware-5.bin
++firmware:       ath10k/QCA988X/hw2.0/firmware.bin
++firmware:       ath3k-1.fw
++firmware:       ath6k/AR6003/hw2.0/athwlan.bin.z77
++firmware:       ath6k/AR6003/hw2.0/bdata.SD31.bin
++firmware:       ath6k/AR6003/hw2.0/bdata.bin
++firmware:       ath6k/AR6003/hw2.0/data.patch.bin
++firmware:       ath6k/AR6003/hw2.0/otp.bin.z77
++firmware:       ath6k/AR6003/hw2.1.1/athwlan.bin
++firmware:       ath6k/AR6003/hw2.1.1/bdata.SD31.bin
++firmware:       ath6k/AR6003/hw2.1.1/bdata.bin
++firmware:       ath6k/AR6003/hw2.1.1/data.patch.bin
++firmware:       ath6k/AR6003/hw2.1.1/otp.bin
++firmware:       ath6k/AR6004/hw1.0/bdata.DB132.bin
++firmware:       ath6k/AR6004/hw1.0/bdata.bin
++firmware:       ath6k/AR6004/hw1.0/fw.ram.bin
++firmware:       ath6k/AR6004/hw1.1/bdata.DB132.bin
++firmware:       ath6k/AR6004/hw1.1/bdata.bin
++firmware:       ath6k/AR6004/hw1.1/fw.ram.bin
++firmware:       ath6k/AR6004/hw1.2/bdata.bin
++firmware:       ath6k/AR6004/hw1.2/fw.ram.bin
++firmware:       ath6k/AR6004/hw1.3/bdata.bin
++firmware:       ath6k/AR6004/hw1.3/fw.ram.bin
++firmware:       ath9k_htc/htc_7010-1.4.0.fw
++firmware:       ath9k_htc/htc_9271-1.4.0.fw
++firmware:       atmel_at76c502-wpa.bin
++firmware:       atmel_at76c502.bin
++firmware:       atmel_at76c502_3com-wpa.bin
++firmware:       atmel_at76c502_3com.bin
++firmware:       atmel_at76c502d-wpa.bin
++firmware:       atmel_at76c502d.bin
++firmware:       atmel_at76c502e-wpa.bin
++firmware:       atmel_at76c502e.bin
++firmware:       atmel_at76c503-i3861.bin
++firmware:       atmel_at76c503-i3863.bin
++firmware:       atmel_at76c503-rfmd-acc.bin
++firmware:       atmel_at76c503-rfmd.bin
++firmware:       atmel_at76c504-wpa.bin
++firmware:       atmel_at76c504.bin
++firmware:       atmel_at76c504_2958-wpa.bin
++firmware:       atmel_at76c504_2958.bin
++firmware:       atmel_at76c504a_2958-wpa.bin
++firmware:       atmel_at76c504a_2958.bin
++firmware:       atmel_at76c505-rfmd.bin
++firmware:       atmel_at76c505-rfmd2958.bin
++firmware:       atmel_at76c505a-rfmd2958.bin
++firmware:       atmel_at76c505amx-rfmd.bin
++firmware:       atmel_at76c506-wpa.bin
++firmware:       atmel_at76c506.bin
++firmware:       atmsar11.fw
++firmware:       atsc_denver.inp
++firmware:       av7110/bootcode.bin
++firmware:       b43/ucode11.fw
++firmware:       b43/ucode13.fw
++firmware:       b43/ucode14.fw
++firmware:       b43/ucode15.fw
++firmware:       b43/ucode16_mimo.fw
++firmware:       b43/ucode5.fw
++firmware:       b43/ucode9.fw
++firmware:       b43legacy/ucode2.fw
++firmware:       b43legacy/ucode4.fw
++firmware:       bfubase.frm
++firmware:       bnx2/bnx2-mips-06-6.2.3.fw
++firmware:       bnx2/bnx2-mips-09-6.2.1b.fw
++firmware:       bnx2/bnx2-rv2p-06-6.0.15.fw
++firmware:       bnx2/bnx2-rv2p-09-6.0.17.fw
++firmware:       bnx2/bnx2-rv2p-09ax-6.0.17.fw
++firmware:       bnx2x/bnx2x-e1-7.12.30.0.fw
++firmware:       bnx2x/bnx2x-e1h-7.12.30.0.fw
++firmware:       bnx2x/bnx2x-e2-7.12.30.0.fw
++firmware:       brcm/bcm43xx-0.fw
++firmware:       brcm/bcm43xx_hdr-0.fw
++firmware:       brcm/brcmfmac43143-sdio.bin
++firmware:       brcm/brcmfmac43143-sdio.txt
++firmware:       brcm/brcmfmac43143.bin
++firmware:       brcm/brcmfmac43236b.bin
++firmware:       brcm/brcmfmac43241b0-sdio.bin
++firmware:       brcm/brcmfmac43241b0-sdio.txt
++firmware:       brcm/brcmfmac43241b4-sdio.bin
++firmware:       brcm/brcmfmac43241b4-sdio.txt
++firmware:       brcm/brcmfmac43241b5-sdio.bin
++firmware:       brcm/brcmfmac43241b5-sdio.txt
++firmware:       brcm/brcmfmac43242a.bin
++firmware:       brcm/brcmfmac4329-sdio.bin
++firmware:       brcm/brcmfmac4329-sdio.txt
++firmware:       brcm/brcmfmac4330-sdio.bin
++firmware:       brcm/brcmfmac4330-sdio.txt
++firmware:       brcm/brcmfmac4334-sdio.bin
++firmware:       brcm/brcmfmac4334-sdio.txt
++firmware:       brcm/brcmfmac43340-sdio.bin
++firmware:       brcm/brcmfmac43340-sdio.txt
++firmware:       brcm/brcmfmac4335-sdio.bin
++firmware:       brcm/brcmfmac4335-sdio.txt
++firmware:       brcm/brcmfmac43362-sdio.bin
++firmware:       brcm/brcmfmac43362-sdio.txt
++firmware:       brcm/brcmfmac4339-sdio.bin
++firmware:       brcm/brcmfmac4339-sdio.txt
++firmware:       brcm/brcmfmac43430-sdio.bin
++firmware:       brcm/brcmfmac43430-sdio.txt
++firmware:       brcm/brcmfmac43455-sdio.bin
++firmware:       brcm/brcmfmac43455-sdio.txt
++firmware:       brcm/brcmfmac4350-pcie.bin
++firmware:       brcm/brcmfmac4350-pcie.txt
++firmware:       brcm/brcmfmac4354-sdio.bin
++firmware:       brcm/brcmfmac4354-sdio.txt
++firmware:       brcm/brcmfmac4356-pcie.bin
++firmware:       brcm/brcmfmac4356-pcie.txt
++firmware:       brcm/brcmfmac43569.bin
++firmware:       brcm/brcmfmac43570-pcie.bin
++firmware:       brcm/brcmfmac43570-pcie.txt
++firmware:       brcm/brcmfmac4358-pcie.bin
++firmware:       brcm/brcmfmac4358-pcie.txt
++firmware:       brcm/brcmfmac43602-pcie.bin
++firmware:       brcm/brcmfmac43602-pcie.txt
++firmware:       brcm/brcmfmac4365b-pcie.bin
++firmware:       brcm/brcmfmac4365b-pcie.txt
++firmware:       brcm/brcmfmac4366b-pcie.bin
++firmware:       brcm/brcmfmac4366b-pcie.txt
++firmware:       brcm/brcmfmac4371-pcie.bin
++firmware:       brcm/brcmfmac4371-pcie.txt
++firmware:       c218tunx.cod
++firmware:       c320tunx.cod
++firmware:       carl9170-1.fw
++firmware:       cbfw-3.2.3.0.bin
++firmware:       cis/3CCFEM556.cis
++firmware:       cis/3CXEM556.cis
++firmware:       cis/COMpad2.cis
++firmware:       cis/COMpad4.cis
++firmware:       cis/DP83903.cis
++firmware:       cis/LA-PCM.cis
++firmware:       cis/MT5634ZLX.cis
++firmware:       cis/NE2K.cis
++firmware:       cis/PCMLM28.cis
++firmware:       cis/PE-200.cis
++firmware:       cis/PE520.cis
++firmware:       cis/RS-COM-2P.cis
++firmware:       cis/SW_555_SER.cis
++firmware:       cis/SW_7xx_SER.cis
++firmware:       cis/SW_8xx_SER.cis
++firmware:       cis/tamarack.cis
++firmware:       cmmb_ming_app.inp
++firmware:       cmmb_vega_12mhz.inp
++firmware:       cmmb_venice_12mhz.inp
++firmware:       comedi/jr3pci.idm
++firmware:       cp204unx.cod
++firmware:       cpia2/stv0672_vp4.bin
++firmware:       cs46xx/cwc4630
++firmware:       cs46xx/cwcasync
++firmware:       cs46xx/cwcbinhack
++firmware:       cs46xx/cwcdma
++firmware:       cs46xx/cwcsnoop
++firmware:       ct2fw-3.2.3.0.bin
++firmware:       ct2fw-3.2.5.1.bin
++firmware:       ctefx.bin
++firmware:       ctfw-3.2.3.0.bin
++firmware:       ctfw-3.2.5.1.bin
++firmware:       cxgb3/ael2005_opt_edc.bin
++firmware:       cxgb3/ael2005_twx_edc.bin
++firmware:       cxgb3/ael2020_twx_edc.bin
++firmware:       cxgb3/t3b_psram-1.1.0.bin
++firmware:       cxgb3/t3c_psram-1.1.0.bin
++firmware:       cxgb3/t3fw-7.12.0.bin
++firmware:       cxgb4/t4fw.bin
++firmware:       cxgb4/t5fw.bin
++firmware:       cxgb4/t6fw.bin
++firmware:       cyzfirm.bin
++firmware:       daqboard2000_firmware.bin
++firmware:       digiface_firmware.bin
++firmware:       digiface_firmware_rev11.bin
++firmware:       dvb-cx18-mpc718-mt352.fw
++firmware:       dvb-demod-m88ds3103.fw
++firmware:       dvb-demod-m88rs6000.fw
++firmware:       dvb-demod-mn88472-02.fw
++firmware:       dvb-demod-mn88473-01.fw
++firmware:       dvb-demod-si2165.fw
++firmware:       dvb-demod-si2168-a20-01.fw
++firmware:       dvb-demod-si2168-a30-01.fw
++firmware:       dvb-demod-si2168-b40-01.fw
++firmware:       dvb-fe-af9013.fw
++firmware:       dvb-fe-cx24117.fw
++firmware:       dvb-fe-drxj-mc-1.0.8.fw
++firmware:       dvb-fe-ds3000.fw
++firmware:       dvb-fe-tda10071.fw
++firmware:       dvb-fe-xc4000-1.4.1.fw
++firmware:       dvb-fe-xc4000-1.4.fw
++firmware:       dvb-fe-xc5000-1.6.114.fw
++firmware:       dvb-fe-xc5000c-4.1.30.7.fw
++firmware:       dvb-tuner-si2158-a20-01.fw
++firmware:       dvb-usb-af9015.fw
++firmware:       dvb-usb-af9035-02.fw
++firmware:       dvb-usb-dib0700-1.20.fw
++firmware:       dvb-usb-dw2101.fw
++firmware:       dvb-usb-dw2102.fw
++firmware:       dvb-usb-dw2104.fw
++firmware:       dvb-usb-dw3101.fw
++firmware:       dvb-usb-ec168.fw
++firmware:       dvb-usb-it9135-01.fw
++firmware:       dvb-usb-it9135-02.fw
++firmware:       dvb-usb-it9303-01.fw
++firmware:       dvb-usb-lme2510-lg.fw
++firmware:       dvb-usb-lme2510-s0194.fw
++firmware:       dvb-usb-lme2510c-lg.fw
++firmware:       dvb-usb-lme2510c-rs2000.fw
++firmware:       dvb-usb-lme2510c-s0194.fw
++firmware:       dvb-usb-lme2510c-s7395.fw
++firmware:       dvb-usb-p1100.fw
++firmware:       dvb-usb-p7500.fw
++firmware:       dvb-usb-s630.fw
++firmware:       dvb-usb-s660.fw
++firmware:       dvb-usb-terratec-h7-az6007.fw
++firmware:       dvb_nova_12mhz.inp
++firmware:       dvb_nova_12mhz_b0.inp
++firmware:       dvb_rio.inp
++firmware:       dvbh_rio.inp
++firmware:       e100/d101m_ucode.bin
++firmware:       e100/d101s_ucode.bin
++firmware:       e100/d102e_ucode.bin
++firmware:       ea/3g_asic.fw
++firmware:       ea/darla20_dsp.fw
++firmware:       ea/darla24_dsp.fw
++firmware:       ea/echo3g_dsp.fw
++firmware:       ea/gina20_dsp.fw
++firmware:       ea/gina24_301_asic.fw
++firmware:       ea/gina24_301_dsp.fw
++firmware:       ea/gina24_361_asic.fw
++firmware:       ea/gina24_361_dsp.fw
++firmware:       ea/indigo_dj_dsp.fw
++firmware:       ea/indigo_djx_dsp.fw
++firmware:       ea/indigo_dsp.fw
++firmware:       ea/indigo_io_dsp.fw
++firmware:       ea/indigo_iox_dsp.fw
++firmware:       ea/layla20_asic.fw
++firmware:       ea/layla20_dsp.fw
++firmware:       ea/layla24_1_asic.fw
++firmware:       ea/layla24_2A_asic.fw
++firmware:       ea/layla24_2S_asic.fw
++firmware:       ea/layla24_dsp.fw
++firmware:       ea/loader_dsp.fw
++firmware:       ea/mia_dsp.fw
++firmware:       ea/mona_2_asic.fw
++firmware:       ea/mona_301_1_asic_48.fw
++firmware:       ea/mona_301_1_asic_96.fw
++firmware:       ea/mona_301_dsp.fw
++firmware:       ea/mona_361_1_asic_48.fw
++firmware:       ea/mona_361_1_asic_96.fw
++firmware:       ea/mona_361_dsp.fw
++firmware:       edgeport/boot.fw
++firmware:       edgeport/boot2.fw
++firmware:       edgeport/down.fw
++firmware:       edgeport/down2.fw
++firmware:       edgeport/down3.bin
++firmware:       emi26/bitstream.fw
++firmware:       emi26/firmware.fw
++firmware:       emi26/loader.fw
++firmware:       emi62/bitstream.fw
++firmware:       emi62/loader.fw
++firmware:       emi62/spdif.fw
++firmware:       emu/audio_dock.fw
++firmware:       emu/emu0404.fw
++firmware:       emu/emu1010_notebook.fw
++firmware:       emu/emu1010b.fw
++firmware:       emu/hana.fw
++firmware:       emu/micro_dock.fw
++firmware:       ene-ub6250/ms_init.bin
++firmware:       ene-ub6250/ms_rdwr.bin
++firmware:       ene-ub6250/msp_rdwr.bin
++firmware:       ene-ub6250/sd_init1.bin
++firmware:       ene-ub6250/sd_init2.bin
++firmware:       ene-ub6250/sd_rdwr.bin
++firmware:       ess/maestro3_assp_kernel.fw
++firmware:       ess/maestro3_assp_minisrc.fw
++firmware:       f2255usb.bin
++firmware:       fm_radio.inp
++firmware:       fm_radio_rio.inp
++firmware:       fw.ram.bin
++firmware:       go7007/go7007fw.bin
++firmware:       go7007/go7007tv.bin
++firmware:       go7007/lr192.fw
++firmware:       go7007/px-m402u.fw
++firmware:       go7007/px-tv402u.fw
++firmware:       go7007/s2250-1.fw
++firmware:       go7007/s2250-2.fw
++firmware:       go7007/wis-startrek.fw
++firmware:       i1480-phy-0.0.bin
++firmware:       i1480-pre-phy-0.0.bin
++firmware:       i1480-usb-0.0.bin
++firmware:       i2400m-fw-usb-1.5.sbcf
++firmware:       i6050-fw-usb-1.5.sbcf
++firmware:       i915/bxt_dmc_ver1.bin
++firmware:       i915/skl_dmc_ver1.bin
++firmware:       i915/skl_guc_ver4.bin
++firmware:       i915/skl_guc_ver6.bin
++firmware:       icom_asc.bin
++firmware:       icom_call_setup.bin
++firmware:       icom_res_dce.bin
++firmware:       intel/ibt-11-5.ddc
++firmware:       intel/ibt-11-5.sfi
++firmware:       intel/ibt-12-16.ddc
++firmware:       intel/ibt-12-16.sfi
++firmware:       ipw2100-1.3-i.fw
++firmware:       ipw2100-1.3-p.fw
++firmware:       ipw2100-1.3.fw
++firmware:       ipw2200-bss.fw
++firmware:       ipw2200-ibss.fw
++firmware:       ipw2200-sniffer.fw
++firmware:       isci/isci_firmware.bin
++firmware:       isdbt_nova_12mhz.inp
++firmware:       isdbt_nova_12mhz_b0.inp
++firmware:       isdbt_pele.inp
++firmware:       isdbt_rio.inp
++firmware:       isdn/ISAR.BIN
++firmware:       isi4608.bin
++firmware:       isi4616.bin
++firmware:       isi608.bin
++firmware:       isi608em.bin
++firmware:       isi616em.bin
++firmware:       isight.fw
++firmware:       isl3886pci
++firmware:       isl3886usb
++firmware:       isl3887usb
++firmware:       iwlwifi-100-5.ucode
++firmware:       iwlwifi-1000-5.ucode
++firmware:       iwlwifi-105-6.ucode
++firmware:       iwlwifi-135-6.ucode
++firmware:       iwlwifi-2000-6.ucode
++firmware:       iwlwifi-2030-6.ucode
++firmware:       iwlwifi-3160-13.ucode
++firmware:       iwlwifi-3945-2.ucode
++firmware:       iwlwifi-4965-2.ucode
++firmware:       iwlwifi-5000-5.ucode
++firmware:       iwlwifi-5150-2.ucode
++firmware:       iwlwifi-6000-4.ucode
++firmware:       iwlwifi-6000g2a-5.ucode
++firmware:       iwlwifi-6000g2b-6.ucode
++firmware:       iwlwifi-6050-5.ucode
++firmware:       iwlwifi-7260-13.ucode
++firmware:       iwlwifi-7265-13.ucode
++firmware:       iwlwifi-7265D-13.ucode
++firmware:       iwlwifi-8000-13.ucode
++firmware:       kaweth/new_code.bin
++firmware:       kaweth/new_code_fix.bin
++firmware:       kaweth/trigger_code.bin
++firmware:       kaweth/trigger_code_fix.bin
++firmware:       keyspan/mpr.fw
++firmware:       keyspan/usa18x.fw
++firmware:       keyspan/usa19.fw
++firmware:       keyspan/usa19qi.fw
++firmware:       keyspan/usa19qw.fw
++firmware:       keyspan/usa19w.fw
++firmware:       keyspan/usa28.fw
++firmware:       keyspan/usa28x.fw
++firmware:       keyspan/usa28xa.fw
++firmware:       keyspan/usa28xb.fw
++firmware:       keyspan/usa49w.fw
++firmware:       keyspan/usa49wlc.fw
++firmware:       keyspan_pda/keyspan_pda.fw
++firmware:       keyspan_pda/xircom_pgs.fw
++firmware:       korg/k1212.dsp
++firmware:       lattice-ecp3.bit
++firmware:       lbtf_usb.bin
++firmware:       lgs8g75.fw
++firmware:       libertas/cf8305.bin
++firmware:       libertas/cf8381.bin
++firmware:       libertas/cf8381_helper.bin
++firmware:       libertas/cf8385.bin
++firmware:       libertas/cf8385_helper.bin
++firmware:       libertas/gspi8385.bin
++firmware:       libertas/gspi8385_helper.bin
++firmware:       libertas/gspi8385_hlp.bin
++firmware:       libertas/gspi8686.bin
++firmware:       libertas/gspi8686_hlp.bin
++firmware:       libertas/gspi8686_v9.bin
++firmware:       libertas/gspi8686_v9_helper.bin
++firmware:       libertas/gspi8688.bin
++firmware:       libertas/gspi8688_helper.bin
++firmware:       libertas/sd8385.bin
++firmware:       libertas/sd8385_helper.bin
++firmware:       libertas/sd8686_v8.bin
++firmware:       libertas/sd8686_v8_helper.bin
++firmware:       libertas/sd8686_v9.bin
++firmware:       libertas/sd8686_v9_helper.bin
++firmware:       libertas/sd8688.bin
++firmware:       libertas/sd8688_helper.bin
++firmware:       libertas/usb8388.bin
++firmware:       libertas/usb8388_v5.bin
++firmware:       libertas/usb8388_v9.bin
++firmware:       libertas/usb8682.bin
++firmware:       libertas_cs.fw
++firmware:       libertas_cs_helper.fw
++firmware:       liquidio/lio_210nv.bin
++firmware:       liquidio/lio_210sv.bin
++firmware:       liquidio/lio_410nv.bin
++firmware:       matrox/g200_warp.fw
++firmware:       matrox/g400_warp.fw
++firmware:       me2600_firmware.bin
++firmware:       me4000_firmware.bin
++firmware:       mixart/miXart8.elf
++firmware:       mixart/miXart8.xlx
++firmware:       mixart/miXart8AES.xlx
++firmware:       mrvl/pcie8766_uapsta.bin
++firmware:       mrvl/pcie8897_uapsta.bin
++firmware:       mrvl/pcie8997_uapsta.bin
++firmware:       mrvl/sd8688.bin
++firmware:       mrvl/sd8688_helper.bin
++firmware:       mrvl/sd8786_uapsta.bin
++firmware:       mrvl/sd8787_uapsta.bin
++firmware:       mrvl/sd8797_uapsta.bin
++firmware:       mrvl/sd8887_uapsta.bin
++firmware:       mrvl/sd8897_uapsta.bin
++firmware:       mrvl/sd8997_uapsta.bin
++firmware:       mrvl/usb8766_uapsta.bin
++firmware:       mrvl/usb8797_uapsta.bin
++firmware:       mrvl/usb8801_uapsta.bin
++firmware:       mrvl/usb8997_uapsta.bin
++firmware:       mt7601u.bin
++firmware:       mts_cdma.fw
++firmware:       mts_edge.fw
++firmware:       mts_gsm.fw
++firmware:       mts_mt9234mu.fw
++firmware:       mts_mt9234zba.fw
++firmware:       multiface_firmware.bin
++firmware:       multiface_firmware_rev11.bin
++firmware:       mwl8k/fmimage_8363.fw
++firmware:       mwl8k/fmimage_8366.fw
++firmware:       mwl8k/fmimage_8366_ap-3.fw
++firmware:       mwl8k/fmimage_8687.fw
++firmware:       mwl8k/helper_8363.fw
++firmware:       mwl8k/helper_8366.fw
++firmware:       mwl8k/helper_8687.fw
++firmware:       myri10ge_eth_z8e.dat
++firmware:       myri10ge_ethp_z8e.dat
++firmware:       myri10ge_rss_eth_z8e.dat
++firmware:       myri10ge_rss_ethp_z8e.dat
++firmware:       ni6534a.bin
++firmware:       niscrb01.bin
++firmware:       niscrb02.bin
++firmware:       orinoco_ezusb_fw
++firmware:       ositech/Xilinx7OD.bin
++firmware:       pca200e.bin
++firmware:       pca200e_ecd.bin2
++firmware:       pcxhr/dspb1222e.b56
++firmware:       pcxhr/dspb1222hr.b56
++firmware:       pcxhr/dspb882e.b56
++firmware:       pcxhr/dspb882hr.b56
++firmware:       pcxhr/dspb924.b56
++firmware:       pcxhr/dspd1222.d56
++firmware:       pcxhr/dspd222.d56
++firmware:       pcxhr/dspd882.d56
++firmware:       pcxhr/dspe882.e56
++firmware:       pcxhr/dspe924.e56
++firmware:       pcxhr/xlxc1222e.dat
++firmware:       pcxhr/xlxc1222hr.dat
++firmware:       pcxhr/xlxc222.dat
++firmware:       pcxhr/xlxc882e.dat
++firmware:       pcxhr/xlxc882hr.dat
++firmware:       pcxhr/xlxc924.dat
++firmware:       pcxhr/xlxint.dat
++firmware:       phanfw.bin
++firmware:       prism2_ru.fw
++firmware:       prism_ap_fw.bin
++firmware:       prism_sta_fw.bin
++firmware:       qat_895xcc.bin
++firmware:       qed/qed_init_values_zipped-8.4.2.0.bin
++firmware:       ql2100_fw.bin
++firmware:       ql2200_fw.bin
++firmware:       ql2300_fw.bin
++firmware:       ql2322_fw.bin
++firmware:       ql2400_fw.bin
++firmware:       ql2500_fw.bin
++firmware:       qlogic/1040.bin
++firmware:       qlogic/12160.bin
++firmware:       qlogic/1280.bin
++firmware:       qlogic/sd7220.fw
++firmware:       r128/r128_cce.bin
++firmware:       r8a779x_usb3_v1.dlmem
++firmware:       radeon/ARUBA_me.bin
++firmware:       radeon/ARUBA_pfp.bin
++firmware:       radeon/ARUBA_rlc.bin
++firmware:       radeon/BARTS_mc.bin
++firmware:       radeon/BARTS_me.bin
++firmware:       radeon/BARTS_pfp.bin
++firmware:       radeon/BARTS_smc.bin
++firmware:       radeon/BONAIRE_ce.bin
++firmware:       radeon/BONAIRE_mc.bin
++firmware:       radeon/BONAIRE_mc2.bin
++firmware:       radeon/BONAIRE_me.bin
++firmware:       radeon/BONAIRE_mec.bin
++firmware:       radeon/BONAIRE_pfp.bin
++firmware:       radeon/BONAIRE_rlc.bin
++firmware:       radeon/BONAIRE_sdma.bin
++firmware:       radeon/BONAIRE_smc.bin
++firmware:       radeon/BONAIRE_uvd.bin
++firmware:       radeon/BONAIRE_vce.bin
++firmware:       radeon/BTC_rlc.bin
++firmware:       radeon/CAICOS_mc.bin
++firmware:       radeon/CAICOS_me.bin
++firmware:       radeon/CAICOS_pfp.bin
++firmware:       radeon/CAICOS_smc.bin
++firmware:       radeon/CAYMAN_mc.bin
++firmware:       radeon/CAYMAN_me.bin
++firmware:       radeon/CAYMAN_pfp.bin
++firmware:       radeon/CAYMAN_rlc.bin
++firmware:       radeon/CAYMAN_smc.bin
++firmware:       radeon/CEDAR_me.bin
++firmware:       radeon/CEDAR_pfp.bin
++firmware:       radeon/CEDAR_rlc.bin
++firmware:       radeon/CEDAR_smc.bin
++firmware:       radeon/CYPRESS_me.bin
++firmware:       radeon/CYPRESS_pfp.bin
++firmware:       radeon/CYPRESS_rlc.bin
++firmware:       radeon/CYPRESS_smc.bin
++firmware:       radeon/CYPRESS_uvd.bin
++firmware:       radeon/HAINAN_ce.bin
++firmware:       radeon/HAINAN_mc.bin
++firmware:       radeon/HAINAN_mc2.bin
++firmware:       radeon/HAINAN_me.bin
++firmware:       radeon/HAINAN_pfp.bin
++firmware:       radeon/HAINAN_rlc.bin
++firmware:       radeon/HAINAN_smc.bin
++firmware:       radeon/HAWAII_ce.bin
++firmware:       radeon/HAWAII_mc.bin
++firmware:       radeon/HAWAII_mc2.bin
++firmware:       radeon/HAWAII_me.bin
++firmware:       radeon/HAWAII_mec.bin
++firmware:       radeon/HAWAII_pfp.bin
++firmware:       radeon/HAWAII_rlc.bin
++firmware:       radeon/HAWAII_sdma.bin
++firmware:       radeon/HAWAII_smc.bin
++firmware:       radeon/JUNIPER_me.bin
++firmware:       radeon/JUNIPER_pfp.bin
++firmware:       radeon/JUNIPER_rlc.bin
++firmware:       radeon/JUNIPER_smc.bin
++firmware:       radeon/KABINI_ce.bin
++firmware:       radeon/KABINI_me.bin
++firmware:       radeon/KABINI_mec.bin
++firmware:       radeon/KABINI_pfp.bin
++firmware:       radeon/KABINI_rlc.bin
++firmware:       radeon/KABINI_sdma.bin
++firmware:       radeon/KAVERI_ce.bin
++firmware:       radeon/KAVERI_me.bin
++firmware:       radeon/KAVERI_mec.bin
++firmware:       radeon/KAVERI_pfp.bin
++firmware:       radeon/KAVERI_rlc.bin
++firmware:       radeon/KAVERI_sdma.bin
++firmware:       radeon/MULLINS_ce.bin
++firmware:       radeon/MULLINS_me.bin
++firmware:       radeon/MULLINS_mec.bin
++firmware:       radeon/MULLINS_pfp.bin
++firmware:       radeon/MULLINS_rlc.bin
++firmware:       radeon/MULLINS_sdma.bin
++firmware:       radeon/OLAND_ce.bin
++firmware:       radeon/OLAND_mc.bin
++firmware:       radeon/OLAND_mc2.bin
++firmware:       radeon/OLAND_me.bin
++firmware:       radeon/OLAND_pfp.bin
++firmware:       radeon/OLAND_rlc.bin
++firmware:       radeon/OLAND_smc.bin
++firmware:       radeon/PALM_me.bin
++firmware:       radeon/PALM_pfp.bin
++firmware:       radeon/PITCAIRN_ce.bin
++firmware:       radeon/PITCAIRN_mc.bin
++firmware:       radeon/PITCAIRN_mc2.bin
++firmware:       radeon/PITCAIRN_me.bin
++firmware:       radeon/PITCAIRN_pfp.bin
++firmware:       radeon/PITCAIRN_rlc.bin
++firmware:       radeon/PITCAIRN_smc.bin
++firmware:       radeon/R100_cp.bin
++firmware:       radeon/R200_cp.bin
++firmware:       radeon/R300_cp.bin
++firmware:       radeon/R420_cp.bin
++firmware:       radeon/R520_cp.bin
++firmware:       radeon/R600_me.bin
++firmware:       radeon/R600_pfp.bin
++firmware:       radeon/R600_rlc.bin
++firmware:       radeon/R600_uvd.bin
++firmware:       radeon/R700_rlc.bin
++firmware:       radeon/REDWOOD_me.bin
++firmware:       radeon/REDWOOD_pfp.bin
++firmware:       radeon/REDWOOD_rlc.bin
++firmware:       radeon/REDWOOD_smc.bin
++firmware:       radeon/RS600_cp.bin
++firmware:       radeon/RS690_cp.bin
++firmware:       radeon/RS780_me.bin
++firmware:       radeon/RS780_pfp.bin
++firmware:       radeon/RS780_uvd.bin
++firmware:       radeon/RV610_me.bin
++firmware:       radeon/RV610_pfp.bin
++firmware:       radeon/RV620_me.bin
++firmware:       radeon/RV620_pfp.bin
++firmware:       radeon/RV630_me.bin
++firmware:       radeon/RV630_pfp.bin
++firmware:       radeon/RV635_me.bin
++firmware:       radeon/RV635_pfp.bin
++firmware:       radeon/RV670_me.bin
++firmware:       radeon/RV670_pfp.bin
++firmware:       radeon/RV710_me.bin
++firmware:       radeon/RV710_pfp.bin
++firmware:       radeon/RV710_smc.bin
++firmware:       radeon/RV710_uvd.bin
++firmware:       radeon/RV730_me.bin
++firmware:       radeon/RV730_pfp.bin
++firmware:       radeon/RV730_smc.bin
++firmware:       radeon/RV740_smc.bin
++firmware:       radeon/RV770_me.bin
++firmware:       radeon/RV770_pfp.bin
++firmware:       radeon/RV770_smc.bin
++firmware:       radeon/RV770_uvd.bin
++firmware:       radeon/SUMO2_me.bin
++firmware:       radeon/SUMO2_pfp.bin
++firmware:       radeon/SUMO_me.bin
++firmware:       radeon/SUMO_pfp.bin
++firmware:       radeon/SUMO_rlc.bin
++firmware:       radeon/SUMO_uvd.bin
++firmware:       radeon/TAHITI_ce.bin
++firmware:       radeon/TAHITI_mc.bin
++firmware:       radeon/TAHITI_mc2.bin
++firmware:       radeon/TAHITI_me.bin
++firmware:       radeon/TAHITI_pfp.bin
++firmware:       radeon/TAHITI_rlc.bin
++firmware:       radeon/TAHITI_smc.bin
++firmware:       radeon/TAHITI_uvd.bin
++firmware:       radeon/TAHITI_vce.bin
++firmware:       radeon/TURKS_mc.bin
++firmware:       radeon/TURKS_me.bin
++firmware:       radeon/TURKS_pfp.bin
++firmware:       radeon/TURKS_smc.bin
++firmware:       radeon/VERDE_ce.bin
++firmware:       radeon/VERDE_mc.bin
++firmware:       radeon/VERDE_mc2.bin
++firmware:       radeon/VERDE_me.bin
++firmware:       radeon/VERDE_pfp.bin
++firmware:       radeon/VERDE_rlc.bin
++firmware:       radeon/VERDE_smc.bin
++firmware:       radeon/bonaire_ce.bin
++firmware:       radeon/bonaire_mc.bin
++firmware:       radeon/bonaire_me.bin
++firmware:       radeon/bonaire_mec.bin
++firmware:       radeon/bonaire_pfp.bin
++firmware:       radeon/bonaire_rlc.bin
++firmware:       radeon/bonaire_sdma.bin
++firmware:       radeon/bonaire_smc.bin
++firmware:       radeon/hainan_ce.bin
++firmware:       radeon/hainan_mc.bin
++firmware:       radeon/hainan_me.bin
++firmware:       radeon/hainan_pfp.bin
++firmware:       radeon/hainan_rlc.bin
++firmware:       radeon/hainan_smc.bin
++firmware:       radeon/hawaii_ce.bin
++firmware:       radeon/hawaii_mc.bin
++firmware:       radeon/hawaii_me.bin
++firmware:       radeon/hawaii_mec.bin
++firmware:       radeon/hawaii_pfp.bin
++firmware:       radeon/hawaii_rlc.bin
++firmware:       radeon/hawaii_sdma.bin
++firmware:       radeon/hawaii_smc.bin
++firmware:       radeon/kabini_ce.bin
++firmware:       radeon/kabini_me.bin
++firmware:       radeon/kabini_mec.bin
++firmware:       radeon/kabini_pfp.bin
++firmware:       radeon/kabini_rlc.bin
++firmware:       radeon/kabini_sdma.bin
++firmware:       radeon/kaveri_ce.bin
++firmware:       radeon/kaveri_me.bin
++firmware:       radeon/kaveri_mec.bin
++firmware:       radeon/kaveri_mec2.bin
++firmware:       radeon/kaveri_pfp.bin
++firmware:       radeon/kaveri_rlc.bin
++firmware:       radeon/kaveri_sdma.bin
++firmware:       radeon/mullins_ce.bin
++firmware:       radeon/mullins_me.bin
++firmware:       radeon/mullins_mec.bin
++firmware:       radeon/mullins_pfp.bin
++firmware:       radeon/mullins_rlc.bin
++firmware:       radeon/mullins_sdma.bin
++firmware:       radeon/oland_ce.bin
++firmware:       radeon/oland_mc.bin
++firmware:       radeon/oland_me.bin
++firmware:       radeon/oland_pfp.bin
++firmware:       radeon/oland_rlc.bin
++firmware:       radeon/oland_smc.bin
++firmware:       radeon/pitcairn_ce.bin
++firmware:       radeon/pitcairn_mc.bin
++firmware:       radeon/pitcairn_me.bin
++firmware:       radeon/pitcairn_pfp.bin
++firmware:       radeon/pitcairn_rlc.bin
++firmware:       radeon/pitcairn_smc.bin
++firmware:       radeon/tahiti_ce.bin
++firmware:       radeon/tahiti_mc.bin
++firmware:       radeon/tahiti_me.bin
++firmware:       radeon/tahiti_pfp.bin
++firmware:       radeon/tahiti_rlc.bin
++firmware:       radeon/tahiti_smc.bin
++firmware:       radeon/verde_ce.bin
++firmware:       radeon/verde_mc.bin
++firmware:       radeon/verde_me.bin
++firmware:       radeon/verde_pfp.bin
++firmware:       radeon/verde_rlc.bin
++firmware:       radeon/verde_smc.bin
++firmware:       riptide.hex
++firmware:       rp2.fw
++firmware:       rpm_firmware.bin
++firmware:       rsi_91x.fw
++firmware:       rt2561.bin
++firmware:       rt2561s.bin
++firmware:       rt2661.bin
++firmware:       rt2860.bin
++firmware:       rt2870.bin
++firmware:       rt73.bin
++firmware:       rtl_nic/rtl8105e-1.fw
++firmware:       rtl_nic/rtl8106e-1.fw
++firmware:       rtl_nic/rtl8106e-2.fw
++firmware:       rtl_nic/rtl8107e-1.fw
++firmware:       rtl_nic/rtl8107e-2.fw
++firmware:       rtl_nic/rtl8168d-1.fw
++firmware:       rtl_nic/rtl8168d-2.fw
++firmware:       rtl_nic/rtl8168e-1.fw
++firmware:       rtl_nic/rtl8168e-2.fw
++firmware:       rtl_nic/rtl8168e-3.fw
++firmware:       rtl_nic/rtl8168f-1.fw
++firmware:       rtl_nic/rtl8168f-2.fw
++firmware:       rtl_nic/rtl8168g-2.fw
++firmware:       rtl_nic/rtl8168g-3.fw
++firmware:       rtl_nic/rtl8168h-1.fw
++firmware:       rtl_nic/rtl8168h-2.fw
++firmware:       rtl_nic/rtl8402-1.fw
++firmware:       rtl_nic/rtl8411-1.fw
++firmware:       rtl_nic/rtl8411-2.fw
++firmware:       rtlwifi/rtl8188efw.bin
++firmware:       rtlwifi/rtl8192cfw.bin
++firmware:       rtlwifi/rtl8192cfwU.bin
++firmware:       rtlwifi/rtl8192cfwU_B.bin
++firmware:       rtlwifi/rtl8192cufw.bin
++firmware:       rtlwifi/rtl8192cufw_A.bin
++firmware:       rtlwifi/rtl8192cufw_B.bin
++firmware:       rtlwifi/rtl8192cufw_TMSC.bin
++firmware:       rtlwifi/rtl8192defw.bin
++firmware:       rtlwifi/rtl8192eefw.bin
++firmware:       rtlwifi/rtl8192sefw.bin
++firmware:       rtlwifi/rtl8712u.bin
++firmware:       rtlwifi/rtl8723aufw_A.bin
++firmware:       rtlwifi/rtl8723aufw_B.bin
++firmware:       rtlwifi/rtl8723aufw_B_NoBT.bin
++firmware:       rtlwifi/rtl8723befw.bin
++firmware:       rtlwifi/rtl8723efw.bin
++firmware:       rtlwifi/rtl8821aefw.bin
++firmware:       sb16/alaw_main.csp
++firmware:       sb16/ima_adpcm_capture.csp
++firmware:       sb16/ima_adpcm_init.csp
++firmware:       sb16/ima_adpcm_playback.csp
++firmware:       sb16/mulaw_main.csp
++firmware:       scope.cod
++firmware:       sd8385.bin
++firmware:       sd8385_helper.bin
++firmware:       sd8686.bin
++firmware:       sd8686_helper.bin
++firmware:       sd8688.bin
++firmware:       sd8688_helper.bin
++firmware:       slicoss/gbdownload.sys
++firmware:       slicoss/gbrcvucode.sys
++firmware:       slicoss/oasisdownload.sys
++firmware:       slicoss/oasisrcvucode.sys
++firmware:       sms1xxx-hcw-55xxx-dvbt-02.fw
++firmware:       sms1xxx-hcw-55xxx-isdbt-02.fw
++firmware:       sms1xxx-nova-a-dvbt-01.fw
++firmware:       sms1xxx-nova-b-dvbt-01.fw
++firmware:       sms1xxx-stellar-dvbt-01.fw
++firmware:       sndscape.co0
++firmware:       sndscape.co1
++firmware:       sndscape.co2
++firmware:       sndscape.co3
++firmware:       sndscape.co4
++firmware:       softing-4.6/bcard.bin
++firmware:       softing-4.6/bcard2.bin
++firmware:       softing-4.6/cancard.bin
++firmware:       softing-4.6/cancrd2.bin
++firmware:       softing-4.6/cansja.bin
++firmware:       softing-4.6/ldcard.bin
++firmware:       softing-4.6/ldcard2.bin
++firmware:       solos-FPGA.bin
++firmware:       solos-Firmware.bin
++firmware:       solos-db-FPGA.bin
++firmware:       sun/cassini.bin
++firmware:       symbol_sp24t_prim_fw
++firmware:       symbol_sp24t_sec_fw
++firmware:       tdmb_denver.inp
++firmware:       tdmb_nova_12mhz.inp
++firmware:       tdmb_nova_12mhz_b0.inp
++firmware:       tehuti/bdx.bin
++firmware:       ti-connectivity/wl1251-fw.bin
++firmware:       ti-connectivity/wl1251-nvs.bin
++firmware:       ti-connectivity/wl1271-nvs.bin
++firmware:       ti-connectivity/wl127x-fw-5-mr.bin
++firmware:       ti-connectivity/wl127x-fw-5-plt.bin
++firmware:       ti-connectivity/wl127x-fw-5-sr.bin
++firmware:       ti-connectivity/wl128x-fw-5-mr.bin
++firmware:       ti-connectivity/wl128x-fw-5-plt.bin
++firmware:       ti-connectivity/wl128x-fw-5-sr.bin
++firmware:       ti-connectivity/wl18xx-conf.bin
++firmware:       ti-connectivity/wl18xx-fw-4.bin
++firmware:       ti_3410.fw
++firmware:       ti_5052.fw
++firmware:       tigon/tg3.bin
++firmware:       tigon/tg3_tso.bin
++firmware:       tigon/tg3_tso5.bin
++firmware:       ttusb-budget/dspbootcode.bin
++firmware:       turtlebeach/msndinit.bin
++firmware:       turtlebeach/msndperm.bin
++firmware:       turtlebeach/pndsperm.bin
++firmware:       turtlebeach/pndspini.bin
++firmware:       ueagle-atm/930-fpga.bin
++firmware:       ueagle-atm/CMV4i.bin
++firmware:       ueagle-atm/CMV4i.bin.v2
++firmware:       ueagle-atm/CMV4p.bin
++firmware:       ueagle-atm/CMV4p.bin.v2
++firmware:       ueagle-atm/CMV9i.bin
++firmware:       ueagle-atm/CMV9i.bin.v2
++firmware:       ueagle-atm/CMV9p.bin
++firmware:       ueagle-atm/CMV9p.bin.v2
++firmware:       ueagle-atm/CMVei.bin
++firmware:       ueagle-atm/CMVei.bin.v2
++firmware:       ueagle-atm/CMVep.bin
++firmware:       ueagle-atm/CMVep.bin.v2
++firmware:       ueagle-atm/DSP4i.bin
++firmware:       ueagle-atm/DSP4p.bin
++firmware:       ueagle-atm/DSP9i.bin
++firmware:       ueagle-atm/DSP9p.bin
++firmware:       ueagle-atm/DSPei.bin
++firmware:       ueagle-atm/DSPep.bin
++firmware:       ueagle-atm/adi930.fw
++firmware:       ueagle-atm/eagle.fw
++firmware:       ueagle-atm/eagleI.fw
++firmware:       ueagle-atm/eagleII.fw
++firmware:       ueagle-atm/eagleIII.fw
++firmware:       ueagle-atm/eagleIV.fw
++firmware:       usb8388.bin
++firmware:       usbdux_firmware.bin
++firmware:       usbduxfast_firmware.bin
++firmware:       usbduxsigma_firmware.bin
++firmware:       v4l-cx231xx-avcore-01.fw
++firmware:       v4l-cx23418-apu.fw
++firmware:       v4l-cx23418-cpu.fw
++firmware:       v4l-cx23418-dig.fw
++firmware:       v4l-cx2341x-dec.fw
++firmware:       v4l-cx2341x-enc.fw
++firmware:       v4l-cx2341x-init.mpg
++firmware:       v4l-cx23885-avcore-01.fw
++firmware:       v4l-cx23885-enc.fw
++firmware:       v4l-cx25840.fw
++firmware:       v4l-pvrusb2-24xxx-01.fw
++firmware:       v4l-pvrusb2-29xxx-01.fw
++firmware:       v4l-pvrusb2-73xxx-01.fw
++firmware:       vicam/firmware.fw
++firmware:       vntwusb.fw
++firmware:       vpdma-1b8.bin
++firmware:       vx/bd56002.boot
++firmware:       vx/bd563s3.boot
++firmware:       vx/bd563v2.boot
++firmware:       vx/bx_1_vp4.b56
++firmware:       vx/bx_1_vxp.b56
++firmware:       vx/l_1_v22.d56
++firmware:       vx/l_1_vp4.d56
++firmware:       vx/l_1_vx2.d56
++firmware:       vx/l_1_vxp.d56
++firmware:       vx/x1_1_vp4.xlx
++firmware:       vx/x1_1_vx2.xlx
++firmware:       vx/x1_1_vxp.xlx
++firmware:       vx/x1_2_v22.xlx
++firmware:       vxge/X3fw-pxe.ncf
++firmware:       vxge/X3fw.ncf
++firmware:       wavefront.os
++firmware:       wd719x-risc.bin
++firmware:       wd719x-wcs.bin
++firmware:       whiteheat.fw
++firmware:       whiteheat_loader.fw
++firmware:       wil6210.brd
++firmware:       wil6210.fw
++firmware:       wlan/prima/WCNSS_qcom_wlan_nv.bin
++firmware:       xc3028-v27.fw
++firmware:       xc3028L-v36.fw
++firmware:       yam/1200.bin
++firmware:       yam/9600.bin
++firmware:       yamaha/ds1_ctrl.fw
++firmware:       yamaha/ds1_dsp.fw
++firmware:       yamaha/ds1e_ctrl.fw
++firmware:       yamaha/yss225_registers.bin
++firmware:       zd1201-ap.fw
++firmware:       zd1201.fw
++firmware:       zd1211/zd1211_ub
++firmware:       zd1211/zd1211_uphr
++firmware:       zd1211/zd1211_ur
++firmware:       zd1211/zd1211b_ub
++firmware:       zd1211/zd1211b_uphr
++firmware:       zd1211/zd1211b_ur
+diff --git a/debian.master/abi/4.4.0-111.134/i386/generic b/debian.master/abi/4.4.0-111.134/i386/generic
+new file mode 100644
+index 0000000..3363527
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/i386/generic
+@@ -0,0 +1,18869 @@
++EXPORT_SYMBOL arch/x86/kvm/kvm 0xd72955aa	kvm_cpu_has_pending_timer
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x254e5667	scx200_gpio_base
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x35a3c008	scx200_gpio_configure
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x8cfa375c	scx200_gpio_shadow
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x907665bd	scx200_cb_base
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0x2d7e229d	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/acpi/nfit 0xa7e9a159	to_nfit_uuid
++EXPORT_SYMBOL drivers/acpi/video 0x68625023	acpi_video_get_edid
++EXPORT_SYMBOL drivers/acpi/video 0x6de7f7ff	acpi_video_get_backlight_type
++EXPORT_SYMBOL drivers/acpi/video 0x7a45377b	acpi_video_unregister
++EXPORT_SYMBOL drivers/acpi/video 0x8826c13b	acpi_video_register
++EXPORT_SYMBOL drivers/acpi/video 0xe92ca535	acpi_video_set_dmi_backlight_type
++EXPORT_SYMBOL drivers/atm/suni 0x328654e8	suni_init
++EXPORT_SYMBOL drivers/atm/uPD98402 0x5107ecd7	uPD98402_init
++EXPORT_SYMBOL drivers/bcma/bcma 0x8f0be7eb	bcma_core_irq
++EXPORT_SYMBOL drivers/bcma/bcma 0xa61cbdbd	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x0c592454	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x189a91c2	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0x3720c18b	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0x4267110a	pi_register_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0x7caa7783	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0x8277db02	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x8d897fbc	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0x9d545f2e	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xb21ba07d	pi_unregister_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0xb40652b1	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0xbdda8018	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0xcc77041b	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xe75095ff	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xfa7cc458	pi_write_block
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0xd73a80fa	btbcm_patchram
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x396fecf0	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4a78579d	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5864dc3e	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x62708723	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x7a0ee4a5	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/nsc_gpio 0x5c9215a9	nsc_gpio_write
++EXPORT_SYMBOL drivers/char/nsc_gpio 0x8020f857	nsc_gpio_read
++EXPORT_SYMBOL drivers/char/nsc_gpio 0xd471806e	nsc_gpio_dump
++EXPORT_SYMBOL drivers/char/nvram 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x17ff2c1d	__nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x2adec1e0	__nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x7da28f12	nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL drivers/char/nvram 0xa8813189	__nvram_write_byte
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x143d19fa	st33zp24_pm_suspend
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x78558b8b	st33zp24_probe
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xf595657a	st33zp24_pm_resume
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xf9656af7	st33zp24_remove
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xc78224c0	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xeec3a48d	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xf64aa72c	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x18c02098	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x228a8883	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x38832cf5	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x3d7c3d2e	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x5958ece7	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x94f2624f	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/edac/edac_core 0x16ccfabc	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04dd92ce	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0960f61d	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0d1fce3a	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0d71cfc0	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x21705eee	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2be96d41	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x31e1ac04	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x38d25da5	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4254bde7	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x49050267	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4d5d4eca	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4dbdec6e	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4ee2293a	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x52798b39	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x5d2c2d47	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x67f3d9e8	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x764ab2b0	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7d716969	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7e431b14	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x994a7895	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9a53a4e2	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa1273148	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa8b651a7	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xae12d769	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd02d0051	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd4306c2b	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd8090878	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xdda0d910	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xfa77c0c0	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firmware/dcdbas 0xa75079d6	dcdbas_smi_request
++EXPORT_SYMBOL drivers/fmc/fmc 0x3a8e7ee2	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x51ee6772	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x9a6e2bac	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x9ef5198a	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0xa13aef78	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0xa9ad20ca	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xb31617b7	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xbf305578	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xd9c98d4c	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xfc628c01	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0xfd3780d1	fmc_driver_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x00333796	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x011f49a5	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x025e5dcf	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x032a98cb	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0d2b81dc	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0eacc2db	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f12d8cf	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f73f79d	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fccafb1	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1071d322	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x110f7350	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1144919c	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1270c367	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13299b44	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13e9fe94	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14353045	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x15190bf4	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x153c56df	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x15a05b95	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x15a65d4d	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x16127fce	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x178725cb	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x186e832b	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x19e62622	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a5cb20d	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1b7dd2cd	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1bcea355	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1d3bc998	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1d8d5cd4	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1df61ef9	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20434dd0	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20db82de	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x215082fc	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x21d970b6	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2355cde1	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x23c12fa4	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x240f4759	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x243b9256	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x247490b3	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x250f9f01	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x25c5678a	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x278c77d5	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29c25091	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2be6a144	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ca2f7cd	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2cdf11d9	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d74a1c2	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d955ef8	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2f091c9c	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x300ba21e	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x310df14c	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x31b3dbf3	drm_agp_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x33757dd7	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3406fa91	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x346127a7	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x359a2ca5	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x36050c8d	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x368d72c6	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x380c89f1	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b4ecb7d	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b5a9e08	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3c9d33fe	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d78b577	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d96fc24	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3e5f9383	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3e99409b	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ea8599c	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3fe5ddd2	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4104f34a	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4251461e	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x42ccc028	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43010bfc	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x436cdcf3	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x44c61ff6	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4536cfef	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x475516d8	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x47ba828b	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x497ae8fb	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4a0f0452	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4e98e295	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ecfd4e0	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4f043a7b	drm_agp_info
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4f2517fc	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50065a2f	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5109bbd0	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x534df36b	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x534ecda1	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x537d7106	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x53cbcf8e	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x53d6e4e3	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x55a50832	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57abaf4f	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5933986e	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5969bc58	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59c09bdf	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a42c2e1	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5b830b3e	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d039652	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d224534	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e843520	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5ece0f77	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x60f4626b	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x60f56268	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6213366d	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x63320329	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x63d5af81	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x645aee0c	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x64610a84	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x64e4bc47	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6557753d	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x665b6a3c	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68263fc2	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x682860ce	drm_agp_bind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x682afbba	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68b5e73e	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68f3a29e	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6938b1a9	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69e16a18	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6a814e89	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6cb279d6	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7010f8dd	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70617981	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x706a5fc2	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70930fcf	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70ff0abf	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72094d51	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72706831	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72b82ea8	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x75e4817f	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x76bb905d	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x788a35cc	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b764a08	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c9e0707	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7ce89d51	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7df51427	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7f082ae3	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8047a23f	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x80974825	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8127b668	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x816bbf24	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x81cbd8bb	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82298bf3	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c41075	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x83576e10	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x83aaf304	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x83c227b3	drm_agp_bind_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x85872f88	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x85b09edf	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x866702e1	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x87c046d3	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c536f1e	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c6bdff8	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c6e2cbe	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8cf33e46	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8df875eb	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8fdcf143	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x90621af3	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9255d1e4	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92c3750f	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x93c5a6c8	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9496df2f	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x952ee1e5	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x958f5445	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x96c27dfd	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97abb311	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x98571f78	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9898e95b	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a1e8514	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a3d8da4	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ae46573	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9b868323	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9c623ebe	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9d0fdc71	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9dff10de	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9e574a9f	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f6de48e	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f73c3a0	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ff1424e	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa043bcaa	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0469589	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1840ed5	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa2016364	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa22619db	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa267885e	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa34ed842	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa50887d9	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa54c9ba5	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa57fc961	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa75374fc	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa8a4c297	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xab3399b9	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaca11d95	drm_agp_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xacca57a7	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xacff8a04	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad9fd43e	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae51742d	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaf2b8c43	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb250cfc4	drm_agp_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb29756ef	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb366146f	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3b738b7	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3f04356	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb53f658a	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5a72d98	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5dd0648	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5fb45b8	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb61e161c	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb77ced66	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb8863d6b	drm_agp_acquire
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbd3fa879	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbd575e63	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbeb85cfa	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbeea2fee	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc214a22b	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc3188621	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc841e90d	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcadbff02	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb5776ec	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcbe8eefa	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd298fbd	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd31bf21	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd180968b	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3a6cb48	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3b30952	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3c0085f	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd440683f	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd4c122b2	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd520f8e4	drm_agp_unbind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd5de4055	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd75776a1	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd7869e1c	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd847034a	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xda8184d7	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdaf125b9	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb8141b	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc218f03	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc61f7e0	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdee68de5	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf14ea45	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf7e9a84	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdfb366fc	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe12f1836	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe1f4b9f7	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2569cbc	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2d10fc7	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe33fde06	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe48584e5	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe522d4ba	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe5874c5e	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6d6be4f	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6e1fbe6	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe83f96a3	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe8b558b6	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe92da7cd	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea0f6b8f	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xecb5b17b	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeceb3aa8	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed53be2b	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeeb4d8fb	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeee099ce	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef9d9c74	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0d65569	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1f4e7e2	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1f75b89	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf21eb04d	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf35e8829	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf3798da1	drm_legacy_addbufs_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf387da4a	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf5469334	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf6edd145	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf7820ce8	drm_agp_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf79f0e30	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf81e44ba	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf844e54c	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfa5004da	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb708726	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb92a919	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfba45901	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbd1a163	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbf34871	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc0da89a	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfdf92cd0	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfe6a1c72	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc732ca	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x01a71d4e	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x02565155	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x02813cfa	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x045b0ed4	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0b8a935a	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0c4be670	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0d983012	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0eea398c	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f1f1834	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0fb9e56c	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1179f275	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1192e18b	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x14723281	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1674c7b8	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1704beb6	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x22168cde	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x224165f8	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x25c102e3	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x27b5e7ed	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x27c7ce07	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x27d10e1c	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x28f2dd98	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x29646733	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2c38bcfd	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2c41b203	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2ddbfd4b	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2ef35b1e	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x30341eda	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x31003bd2	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3244b94d	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34a7488c	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3549fd59	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x368d98b9	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x378b3ad3	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x394cf7db	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3a7d7a64	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3c9e9a95	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3fbfebe7	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x40c196ec	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4150ed47	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4257e9c3	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x45256706	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x460e9d09	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4e0fc11d	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x50e9d139	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x52a07f6f	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x53e64175	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5469b64a	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x550f4a37	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x571b633e	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x57d2fab1	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x59607c48	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5b8b98dd	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5e6dfc5c	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x60209fe7	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x610ba217	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x65b97ab5	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x668ae500	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6d36bcb9	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6f872745	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6fd3b6d5	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6fdf5477	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x71a65db3	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x72dee5d9	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x74d5f8b5	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x761228d4	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x766cf199	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x775a3786	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7c88dd65	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x804870c2	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x816dfe46	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x83e5edfc	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x85d9bad6	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x87ee5f1e	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x88729812	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x890e49c5	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8b160971	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8e984bb4	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x90451a98	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9140903d	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x924e8923	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x980769ae	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x98909e81	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9d217dba	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9d3f16b9	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9edb81f6	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9fdf88c3	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa0ff4d2f	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa29250aa	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa41e30b7	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa4bb981a	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa5f4a4cc	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa81bae28	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa93ad270	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xad5d3751	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xadb08ee3	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb03adb31	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb0b4c059	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb2aef31a	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb424e7ac	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb4cd225b	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb823b23b	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb9ad01c4	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbd9eca77	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbf43ceb1	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbfb55813	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbfef8e48	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc75f61f8	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc7aaf516	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc966ce57	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcb74b10b	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcd1b104c	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xce48ce25	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcfc8f68d	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd0f6d927	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd1144d39	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd22927d5	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd35c5068	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd388a6c1	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd5a54b8b	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd8c6febb	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xda056494	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdc103226	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdf894d14	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe4cdd1fc	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe6bfc6be	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe7438e40	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe760b9b6	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe98f3adf	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xea54161d	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeaa40ec8	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeee5816c	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xef907f7d	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xefdb8623	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf22a3a2a	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf5e29fd3	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf6981598	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf87ebe78	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfadb4d63	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfce64516	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfd0fa8f8	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfd73ccab	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x01280859	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x098f03ea	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0bab7f47	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x132b05be	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x133b9e19	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x15129bce	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1940e4cd	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1d648f76	ttm_agp_tt_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x202eeb8b	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x22ec80fe	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x24765c33	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x255cd198	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x266d8a60	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x29e07eb2	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b2b9dca	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2ccc3c85	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2fd60b71	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x30327b19	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x350b3786	ttm_agp_tt_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x383d38b7	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3fab986a	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x44f8be11	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4d70e8e7	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4e861427	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x500eb15e	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5316413f	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5366a1ab	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x540552c0	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x58377527	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5a5fbcbf	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5cf59609	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x65d8b1f2	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x67b1d568	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6c8dc6bf	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6e875de9	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7ebcdcab	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x836d8fd0	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x86e95a8b	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x87a027b5	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x887bc9fa	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8b23e961	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8c051c92	ttm_prime_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x946d9ea3	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9a84a7d3	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9cbf9cdc	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa12b4479	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa15f936d	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa3cc9fa0	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa673b66b	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa7c3373b	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa963305d	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xaf59ae12	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb9a53065	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbd08f22a	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc85f7df8	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcdfd17db	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce969d64	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf49f835	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd638ee93	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xda6509a9	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdc063882	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdcfeea41	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xddc2c0c6	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xddcbb522	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe008839c	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe1f5d3f0	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe9e6e745	ttm_agp_tt_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf80ff4d0	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf91e1ed9	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0x307d75a0	vmbus_recvpacket
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0x74823c35	vmbus_sendpacket
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0xbca2384f	vmbus_sendpacket_ctl
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0e2a6864	sch56xx_read_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0f5877d4	sch56xx_read_virtual_reg16
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x34257f35	sch56xx_watchdog_unregister
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xcd59a183	sch56xx_watchdog_register
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xe5022f95	sch56xx_read_virtual_reg12
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xed1d2a08	sch56xx_write_virtual_reg
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x046ef7ff	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x51cf0195	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xc229c70d	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x35cd1806	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0xea086740	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0xcdb62b9e	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x15f01fd4	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x17c38683	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x22e32428	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x2881b1da	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x2d7b593d	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x4724da83	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x4db5fe79	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x61571823	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x62be6a9f	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x92a4da3f	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x96756dfc	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xc3427294	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xc8ab4490	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xe1033bc1	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xe8e94e13	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xf276668b	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0xbc733e11	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0xc350a42e	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0xc71f5023	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0xdd3bdc2e	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x32a02bef	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xa74768ab	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xc9c1e204	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xfc85609e	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x52d676f7	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x53a0abcd	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x7e3f609a	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x7e65a7c7	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x830d383b	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc3bf6760	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x2a2fbf26	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x52c3407a	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x539b02b6	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xc83f16b3	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x260e7ce6	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x2aeae762	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x3cc35c38	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x59b68818	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x6376535b	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xaf7d2f1e	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xb793d674	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xdf25f5da	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xf2ce4712	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x325604ab	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x46dd10f8	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x47670832	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x5d5d263b	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x78536fac	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x010c4d8a	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x570336ee	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xb9ad1d9d	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x36e6beaa	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x45ec81b6	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4b1d58c1	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x5dc5a055	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x7a037279	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x7bca9809	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x915e332c	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x95fd8143	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x9aee3aca	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x9dda4fd3	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xaee99ce5	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb07fced7	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc91d8669	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xda007562	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xe0e6fd9d	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xe8990548	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf0e0824d	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x6d811cd7	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x9ae28a49	st_sensors_match_acpi_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0xddca8d64	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0xadca46b8	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0xe7d8917c	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0x06edb8b9	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x66399675	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xb0e78f56	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/industrialio 0x13a58582	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x26712f8a	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x39c69ac7	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x44adb759	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0x47adc4c3	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x4824cdd5	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0x5a4e6f4d	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x60cbaed3	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x60f91b5f	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0x650e341a	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0x7852b38e	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x7c058c4a	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0xb366068f	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xc6b44888	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0xc83aa868	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xd1a814ac	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xf729f6a5	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x5f26e0d1	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x701e830f	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xa63519d6	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xc358deb3	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0xc670d102	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x12778215	st_press_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x2032f4b5	st_press_common_probe
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1edc4064	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x487a6b7a	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x58e7a154	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x9d9cabc5	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xa1963f34	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xfadc0cd1	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x04d27ef1	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1993ecbb	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x35f8b36e	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x385f8cf0	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x49181dbd	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x66ba930a	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x6be516c9	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x74ef803f	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x82f98072	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x9203d464	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x929a9ba7	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x943a50d1	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xbeb150cb	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xc1317a36	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xc37568a3	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd70fb397	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xe99e0256	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xf2f785c3	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x002cb9d3	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0415141e	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0420b9ea	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x04e0c0bd	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x05f60710	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x06164e99	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x095d53ca	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x09cb4cb3	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c34bbda	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x110df82f	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x11651be8	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x167f0b4e	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1ddf9422	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x21b667bd	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x23e19073	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x264d245c	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2755853e	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2df633ed	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x30b4c88c	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3567cb8b	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4020d085	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x409c552c	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x433003a5	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x43b235ec	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x46c808b8	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x479fd53c	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4f397a47	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5011a660	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5145c8e5	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x520b2638	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5922ffce	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x60912223	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x60c169f9	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6707aa3d	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6773fbc9	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x694c6bb8	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6b45e3f4	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x70cdb705	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x729e1cb1	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x737992ba	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x75c2af82	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x78b796c6	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7cd476e6	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8036eb76	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x82053a99	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x82ca3d1d	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8536a39d	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x85e80990	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x88459c5a	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x88f7d6b7	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8a07c30c	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8f4d374e	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x928418ca	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x92b92613	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x94b2b41f	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9871bcf6	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x988f8dc0	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9ad31794	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa97be7da	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xad1c6c18	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaeed2eec	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb070c29e	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb1a312e1	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbf03c716	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc0bf6a37	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc2d9220c	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc9f3671a	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd51d21c5	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd71f6a08	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd7e0eba9	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd8722832	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdc9b55fd	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe18ab488	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe34d9abc	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe8536d06	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe904ad8d	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xefbed67c	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf0f8133a	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf212fea7	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf507a0ba	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf7d6a110	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf91fb5e3	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfb77facd	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfddf260b	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xffb79c37	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x151c707c	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x550cdc94	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x56b9172d	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x597d3efa	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x72290d83	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x78db8b04	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x887d2b4d	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xa0f5dc87	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xb80e14d6	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xb8f23096	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd1452146	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd2ddaa8f	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xdb38786e	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x05f51c4a	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x11fa00c6	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x287d1e73	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x43754f48	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x4987f244	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x60dd81a0	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x6713febe	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xa54e93b1	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xbbfb9d4d	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xc53022e7	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xe8811a46	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x67cba670	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xbb3b6107	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x21388c3d	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x2c1f4795	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x316f8d3a	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x382d7d13	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x3c9d93f7	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x46fa59c5	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5433e651	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x76099f2b	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x77b9a834	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x7c3e5816	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb095da7b	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xba8d1c99	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xbcd85cd0	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xc180a1e4	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xeb2e5959	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x03e22c86	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x109f7fb0	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x1309a2c5	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x152c2bd1	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x15b375ab	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x1a5c5e8e	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x260a5187	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x33fe1343	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x4af65f20	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x4ed67720	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x543ab71c	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x567686b3	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5a857513	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x74cd072a	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x8271f754	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa3ac7539	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa6fa4ad3	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xb49596b5	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xbd3d624d	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xec6f773a	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf1cd6806	rdma_connect
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x3775a608	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x5deba643	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x685f6db3	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x84eb9f65	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xaab7b21a	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xd3e85d90	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xdada13ee	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xec5e5fed	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xf7dd7c0c	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/input-polldev 0x1b634b9c	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x532947ae	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x64c3216f	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x6def1805	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xe77c0b90	input_register_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0x1e333dbc	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x3d2a627c	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x924c25a5	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xdd597253	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xa42ccd9e	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x02ad5256	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x3a1af925	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x861a0b49	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x88550b5b	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x98472136	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xc3f8892a	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x88af8fc3	ad7879_pm_ops
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xd026c98e	ad7879_probe
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x02537d4c	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x1550a094	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x499cd47d	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e2ad1b1	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa6c72ffc	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa73cc8af	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa7c4fd6c	capi_message2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xbb24ad5e	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc10fe128	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe8ad9bd1	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xedaf6ae4	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xf0848b88	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xf3b15180	capi20_release
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x0abebe53	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x1c1af3d7	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x2efb3891	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x4bdd4032	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x4c851552	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x572a4d70	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x63f28a30	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x8d992d4e	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xd03b8780	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xd1b38eb3	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xe4f6fc33	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xe52241bd	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xf1078fbf	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xf624a80a	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xff1ed618	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x08c3f6ce	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x60ec1ac4	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x88a4350a	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xb5215f74	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xc0cfed5a	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xce3dced0	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xdabe1cf0	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xed14e113	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xfb01ea7e	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0x29562993	b1pcmcia_delcard
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xaec3240e	b1pcmcia_addcard_m1
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xea620116	b1pcmcia_addcard_m2
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xf14bf8b1	b1pcmcia_addcard_b1
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x2e4a11f8	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x97c30583	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xa46d8f38	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xd3f6d2e7	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0xa90610da	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0xbb0699f3	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9009575f	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x13c96b5f	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x39b7812c	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3b10c2b6	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x8de50dcf	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x92208023	isac_irq
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x96e19246	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xa72a6a18	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xf4583777	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x07439119	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x077b9506	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x0de0923a	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1ee3e420	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x30d0a185	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3359a0e8	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3fbecbd7	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x603791dd	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x61ef5992	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6d7ad2e4	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x729349ce	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x9035167a	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa916478e	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xaeb27922	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc0949dac	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc569a2ba	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xcce91750	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xcf4970b8	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xdba9fae8	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xdd910c52	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf08e53e5	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf1dabe93	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xfdbcc31e	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x0bd697e2	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x10dc0d06	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x4073bdaa	closure_put
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x66d28e22	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x6969b5d8	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7b55ca4f	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7f2a56c0	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x9e8b3cee	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xa130c392	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xa5ea0fee	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xab2d2b84	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xad29a6f5	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaec09a2b	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaf77343c	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xc04554f7	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca580595	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe47e0829	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xecf7cef9	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xfbf30701	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-bufio 0xa7978f56	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-log 0x70a5f224	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0x79f07c7f	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0x7f9ecb9c	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0x8e1f2345	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x08bd363c	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x0a88a268	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x82d66461	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x95005e54	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xb741e115	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xc51670ac	dm_snap_cow
++EXPORT_SYMBOL drivers/md/raid456 0x1e555183	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x29882581	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x2ceda937	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x2f3527f8	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x4f1737c1	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x60e9f5c9	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x8543069a	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x8ba6f6be	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xb92c61dd	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xc3c9129a	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xc97bb9c3	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xca633474	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xf19f977a	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xfb7dc565	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2d31b0b6	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x6934b881	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xb434883b	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xe3e15137	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0x38cd0d55	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x79dcf0ed	tveeprom_read
++EXPORT_SYMBOL drivers/media/common/tveeprom 0xe8f9cbba	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x07c34174	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x086545c0	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0945be27	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0a49d99f	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1e5f0bdd	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x28baaf9e	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2907e8ed	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2cf288a0	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3ee8cfed	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x42a79c04	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x53eed889	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x58c0b3ca	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5a6f883d	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6367c49f	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6e81383e	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x70de704a	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7a412903	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7d2d1d4c	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7e693aec	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9101e3cd	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x93b1fad6	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9a99f99e	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9ab4d06a	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9d163fed	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9efdce53	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa062bc6b	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa485b5a8	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa4f43bba	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa8ca63b0	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xabd66426	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc645fbc3	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd115452c	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdb7dd83b	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe06e998e	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe4290c13	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe6de076f	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe92ee976	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xebd38af9	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0xe58e39f6	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0x643c3d29	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0x752a2dc4	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x09624ba5	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x269e32f1	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x37b4ce53	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x3ac59568	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x4c5fad73	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x5749aa57	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x5eb0010e	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x687edaaa	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x6d844e59	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0xb584e170	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0xb1e25dc4	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0x3a314827	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0x33e1dcb8	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0xf5a884fb	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0xaf53d85e	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0xb6409d1d	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0x3791209d	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0x8ceee4bb	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x05808096	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0xa9a51644	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0x5b29a94f	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x057232d7	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xef315863	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xfd636b7b	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x56513fd5	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x9ac7efa4	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xcc87c761	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xd6e98f35	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xeedb4267	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x07b68d72	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x2761c384	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x707b801b	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7c22192a	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x84348216	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x8dc498c7	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x92f6faa4	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x94863bce	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x97f94dda	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xc0b8817e	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xc891d49b	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xd5a5f258	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xdb5336d7	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xe7d449cd	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xe97d98fd	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0x02f07e27	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x332e0640	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x7a8e77d2	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xa94fd14b	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xad64b204	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xf05aba56	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xffaff369	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x0dce2e4c	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x0f7bc33b	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x520e92f3	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xf0d8dadb	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x8ec80574	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x371c8e5a	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x36b5792c	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xbb291bf7	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xf2c9ad14	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xf2f95ea2	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xfe75f63f	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0xc4b6dd36	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0xee058886	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0x1e9f756a	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0x24ff9470	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0x69cbfd8b	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0xfccf321c	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0x5cae1450	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x04012568	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x825af692	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0xfb48f6f6	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0x92466d3f	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0x88514cbf	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0x7cbe3bb2	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0x76605b1b	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0x11293e8f	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0x5618380d	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x828d87cd	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0xfc9c7129	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0x319c361d	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0xad9c7645	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0xbb9a4008	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0xcf19fe44	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x3dd4e718	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x44c50df3	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0xdd5ce07a	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0xd2242366	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x80dbcba6	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0x4fca9aa6	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0x87eb0bfa	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0x50a47d55	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0x1f703936	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0xeb7a8d60	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0x4e6d06e6	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x5de277e4	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x9c07df48	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x79e19cac	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xb2e6e6e8	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x744affe0	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0x68e1bb9c	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x8cb6be67	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0x0eba5434	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0x5d0f96f5	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0xa0436994	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x5e45240b	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0x455559ae	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0xc300a601	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0x1a0a433d	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x88bdadaa	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0xb1cefbc4	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0xb297c3de	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0xbe6fe24e	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x0dbccad5	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x86e8ac9f	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0xbc880b79	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0x5c566216	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0xf73cc7fd	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0x84841310	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0xc2e299c1	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0xf6f731a9	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0x06b1262c	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0xaabb6ae0	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x578b487b	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0x8cc6f658	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0x86a35c13	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0x1d642129	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0x958fb9ca	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0xdb3dc482	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x81220b51	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0x1853bdbf	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0xb04c81d5	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0xbebe4ef8	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x000c6a73	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x073091f3	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x2f8bff39	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x459eb2ca	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x71756205	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x74184de9	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xb8e2911e	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x22df6fa2	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x6fe01501	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x76fea9f8	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xf009c43b	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x418f92af	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x47c9c179	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xd929c0a1	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x21127466	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x2f007e5b	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x4a43f4a4	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x4e759c84	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x61e63b6d	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x84bd8d35	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x8bf97959	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xaf67d7be	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xcc12ca91	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0xf3e7208e	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x39b70e69	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x3abf2eea	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x5a3d5da6	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x60f5a868	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x8faa7803	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x9292bdf2	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x3cab428f	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x495e3c8b	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x6e14a9ff	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x7721b10d	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x7f000c10	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xafc94611	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc16d7e48	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x6a215895	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xf60f7357	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x32297d13	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x79d1e2fe	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x8b54bccb	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x942c62b2	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x5a56b221	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x6a69bd7e	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x79b5353d	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x9ddebbba	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xabd05d6f	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xb9c5281d	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xcc199c5d	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x09f5438d	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x1df0bf86	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x20245b5a	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x2b5962c6	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x34fa14f8	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x3dc199ec	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x49134478	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x54ff6c0e	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x68f262ea	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7626241b	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x79dc434a	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x90598e9a	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xa7b9733e	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xa8d089a8	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc0793e78	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe6feaaec	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe872d320	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf644e31f	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf98bb8da	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xfdadac22	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x016631c0	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x05eb26d5	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x071cb93b	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x0ed800da	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14895e0f	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x1bd1e914	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2b6e1f74	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2ffc32f9	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x5bb947ec	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x69bed5be	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x782a1585	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa680030f	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xaa4e09c3	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xc166c7da	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xcaa6f729	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xd0a0fbb3	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xd832f3e6	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x073482f3	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x228291ec	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x5a4eda0e	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x764663ee	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7f510ff2	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x81c3c0b9	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x871adfc1	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x9e4193e4	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa56b7f40	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xc7da7c0e	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xd74271ee	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xe159e840	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x504d4db0	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x8c1496cb	videocodec_register
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x9683adc5	videocodec_detach
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0xe357e02a	videocodec_unregister
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0xfed84a20	videocodec_attach
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x1ba2e129	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x23e9699a	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x52a55134	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xb8352306	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xc5409a56	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xca42faf4	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xf55fc0fe	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x18089404	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x20166a9a	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x2cfce859	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x6fac2335	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x92ad4c74	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xb8f724ef	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xe9758c33	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x02c15b38	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x19c52a85	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x2f9238ef	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x8fb48a6c	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xc3fa7540	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xe7d3ff2f	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xf00a030d	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xffec4162	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x3bde44cc	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xf6335656	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0x7c338ea0	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0x29d4586a	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x4c6aa4b4	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x6ca05de6	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x78422b85	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/max2165 0xc7ebeccd	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0x712f927b	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0xacdcdb09	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0x94946c2c	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0xee6b0a90	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0x2d62ccc2	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x97c409ba	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0x17cdb406	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0xd0cf4e48	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0xa0bd8166	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0xd1074675	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x3c08e39f	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xa619bfaa	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x1fdee99d	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x2f244a43	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x90b355f5	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x95cdf6e2	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x9fdaf210	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xb431c90b	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xbbc3ad27	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xf8c44aa8	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xfbbe9be3	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x00a3b3f0	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x1a774ecf	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x38979781	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x3b30c1c3	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x66e1a0f8	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x7518f617	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xe364fd12	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x7a0dffb0	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x03beffed	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x1ab898c4	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x3c0cb830	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x4019831c	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x6927b2db	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x7c108722	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x7d56b536	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x9c3639e9	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb8d039b4	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xef3905f0	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xf17a4855	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x1185f0e9	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x67c6d487	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x419f06ee	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x58a9fb3f	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x6bb01e62	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x6fb3093c	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x8e697073	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xd2cb8f87	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xda276c74	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xe83f4c12	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xf0bd6226	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x00eae7e5	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x210dcad2	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x3772f8a7	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x43a29777	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x572ffdd6	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x78b5396d	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x7edc520e	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xee985321	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x47685725	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x67f935ac	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xd4d8fa13	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0xc0afc558	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0xeb68c492	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x18c31250	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x48101465	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x87a4ea0c	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x28cb9271	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x3e513f95	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x5c10d725	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x958cc231	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xad5294d7	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xe6e78458	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x4f202718	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0xdd58a852	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x1888b69c	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x486f4e10	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x7e055506	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x81e3dab9	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x8769300e	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xa06d2766	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0x394d77f5	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x01177125	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x11cbf186	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x132faeeb	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x185762ae	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x186bbf15	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b76470f	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1db3a87c	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x20600be6	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x231f9663	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2c2130ef	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3a613f20	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3ddada85	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4033bbb8	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x48b227ef	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4bb1e1ba	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4bf9d810	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4df39c8c	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x534c6897	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x54ae8f9b	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x560f7b66	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x58da5645	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5aa6980c	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5d004e09	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5d2ab775	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5e9f8582	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6140d6de	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x62ff76a8	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x69fbfff6	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x74294573	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x747e6581	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x798c7052	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7d7a36a8	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7e077d51	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x82a3f377	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8448efef	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x87b326cb	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8b926a8d	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x91ff1b3e	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9b883e11	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9d5f87ca	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9e9a8cd4	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa22a5218	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa6edea2d	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa949fb22	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xae3de747	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb40339e2	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb4a21a3e	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbbad5c56	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbfe207eb	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc2297414	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc74eec82	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xca161213	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcdad99d2	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdc96a69b	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdf008777	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe62310c6	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe7cbc06b	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe8531fec	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe95564e2	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeb76ad32	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xed92f89e	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf4149606	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf55389f3	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf6a210cf	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf8e440b4	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfc11935a	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfd8fbe11	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfe45e3c1	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x28370d01	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x2c85bbce	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x4385d3b5	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x4aa48cb3	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x53283779	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x854eed86	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x8de070dc	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x91913956	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x9ccfce14	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa35b78be	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa5987a36	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xdab7d744	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xec5e9159	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x06285107	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x073b2a32	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1645508b	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1a6d73d4	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2acd9d2f	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x34c13128	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x37454b0b	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3ad34ac7	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3b5c3a44	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3c6e0816	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3db177c5	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4a96bb42	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x510e15d0	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6c048a7c	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x7d5c60a3	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x81e06135	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8b9e84ff	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa1e0f206	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa9ff0f11	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xab195e52	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xafb1a101	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc8653021	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xcf810955	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd548e98e	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd71284d9	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd7eb3270	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe31f8e3c	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf2d21f2a	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf550b389	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1a8d1e33	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2331ac39	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x3f8bb26d	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4542954d	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x47e03ffa	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x498820fe	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4d915072	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x611569be	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x666218c8	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x68ba9778	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x783e3e11	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7ed50cd6	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x82cc2acd	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x8c78c29e	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9104be3f	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9a034196	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xa35162b4	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xaa801d70	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xba0814ab	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xbc12f25d	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xbcd125d8	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xceb50ae7	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe5fa404e	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe8d16376	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xeac79bc7	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf23b59af	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xfabf4666	mptscsih_qcmd
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x1b1b12e9	cros_ec_register
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x53cb4b3d	cros_ec_remove
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x756e1de5	cros_ec_resume
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xa12b000b	cros_ec_suspend
++EXPORT_SYMBOL drivers/mfd/dln2 0x2e6a8cbc	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/dln2 0x37c98310	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0xdc821d82	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x7e4972c8	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xac460db2	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x20a3cefe	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x64486857	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x6f452efb	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x83ae153e	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x90c371ea	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x9f6fffb3	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xad3d67f6	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xc2a78203	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xd8a7ab46	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xe4cede4d	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf7dfaead	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x56da3b77	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0xbeb88c80	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x4aacf648	wm8994_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x77a7fdf8	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x78964dd1	wm8958_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xe7f44ffc	wm1811_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xb5412eb3	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xce7db532	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x075983d1	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0x364e85f3	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0x3afe6189	c2port_device_register
++EXPORT_SYMBOL drivers/misc/ioc4 0xd68f99e4	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xfa8ec537	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/mei/mei 0x0b3c2389	__tracepoint_mei_reg_write
++EXPORT_SYMBOL drivers/misc/mei/mei 0xafdfce69	__tracepoint_mei_reg_read
++EXPORT_SYMBOL drivers/misc/tifm_core 0x25f085a0	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x269d2bd7	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x351074a3	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x39f86aa1	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0x463c93bd	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0x484f2ba2	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x4d6e535c	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x5c1dcdae	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0x87af00f4	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xcbb4329c	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xe3a3f9c0	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xe82229a2	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xfdc9d79d	tifm_add_adapter
++EXPORT_SYMBOL drivers/mmc/card/mmc_block 0xeac5da9c	mmc_cleanup_queue
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x19f7b159	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x5c40ac41	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x5d3b02da	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x8d17a9f0	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xc6b128cb	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xd754f1cb	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xffd27d18	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x17b690f9	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x7431ca21	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xb9f3e519	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xd34a804a	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0x4f1855a5	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0xd69b01a6	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0xf40e8482	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x7930e22d	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/mtd 0xb29daffc	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xba8c9d36	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xd66b5424	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x0a8b0818	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x38d4d309	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x5f47c7c3	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x5f97e0e6	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x77734e2e	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8147f282	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x3c01bccb	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x47c50bbc	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xa5236291	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x4e6eb00b	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x75c6b863	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x2d4fcf7d	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x4b2d4c3d	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x5256041b	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x9ca2bd98	onenand_default_bbt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x098e2e0c	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x1814d856	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x2025d39d	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x3b354e7d	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x72566ed8	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x88b2c207	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x9e618687	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xb2f7f074	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xd9ab025c	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xda6fbc7e	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x2afc9b25	com20020_found
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xba3d3a6b	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xd5d68651	com20020_check
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x05ede9db	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x19abb18c	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x20df2724	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x2b64c888	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x47a5cbf7	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x54ac5a62	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x75ff96f4	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x855c9c57	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xacfb6c6b	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xd9338d86	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x34466222	eip_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x45ef7897	NS8390p_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x5e452411	eip_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x6d1df26d	eip_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x99c03fd7	eip_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0xb908f858	eip_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0xca17a05c	eip_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0xd574a91e	eip_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0xd69ff665	eip_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0xe922ecc9	eip_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0xff6ccad5	__alloc_eip_netdev
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0x51b1b0ff	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0xd0ee4140	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x12504d6c	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x1b7479c3	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x1f40ebda	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x38fb6a47	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x3b638053	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x460b5383	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x4d2d2eb6	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x4eda9aff	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x8cf4e6d2	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x991a0c04	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xb6676860	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xca0a593e	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd207f0e5	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xdb07c76a	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xe285339d	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xe5e6233e	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x08c008b6	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x189c01f3	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x19b50278	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1b58ee3c	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1c774b69	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x213c2c2a	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x2cd49cd0	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3273364c	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x35d51ca9	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x437b215b	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x48551a71	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x54576d5a	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x55e6e572	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x57707dfc	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6559ee14	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x65e6821a	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6a1b8dd9	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6f3f0774	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x96f2c7bd	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9a571c3b	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9f125f11	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa32aaf98	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa63468a6	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xaed9933b	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb60f16ab	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xba283001	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xdd0d6d0f	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xde95d49b	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe409e14e	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xedad6185	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf0a349f7	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf824a9b6	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xfac4d80d	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xfe333f6e	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x3fa5e6e5	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x4b6ae9f7	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x8f388550	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x9e3329ab	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xb0b58121	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xf53365c2	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x82d8dede	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x8bb0cf9b	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b949cfd	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x159b9d31	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1abc6c48	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x211e3bd3	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2758b3de	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3096b69a	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x32347bfc	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x384dee17	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x38fe0e0e	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x39889b1b	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3cd335ff	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x49159dbd	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4982fe08	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6eaf7bd8	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x868af812	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x916bae45	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x92e13289	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9bca298b	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa11b5a70	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa6cfbfcb	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaa278cf1	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb8298c7d	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbedc47ce	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc2278280	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc2f382fe	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xca33b36e	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xccd6904c	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd2a0ae43	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd311d6c2	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xde30b51b	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdec93425	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe1099019	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe7eb157e	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xebbe1654	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xec700d12	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xed11f516	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf94ab613	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfc395bfe	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x054a7e94	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x11c6c187	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1e88befc	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1efa3da8	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x24c46b25	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2c3e8a7b	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3472210d	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x44e5ce7d	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x45c6825a	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4a5dab70	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x52233089	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x52803cda	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x66962b1f	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6d112ea5	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x718a515f	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7269b578	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x72effb17	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x761d2d0a	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x85ceaa3a	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8a718c75	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x90ea4b5a	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x96535343	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa9bdad24	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xabef39a7	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xafca0df2	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb8b43c35	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc6ba2dc0	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcf751196	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcf960e07	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd0569cf2	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdf45f21c	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe0378cd6	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe58ed593	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf82069a8	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc446dd1	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfcc6642e	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfcc99605	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfce1a5f2	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x0b783ce2	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x183ef715	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x5a7974b2	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x7bbc70f6	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x7c91ae6f	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x858e0123	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xcb5c8545	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe5cd6240	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xfd678c4d	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x11088515	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x197db782	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x265c3d69	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x4a8d8878	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x957f5630	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x141a763e	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x1a3f638f	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x1ab4dfec	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x4dc57e36	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x5f29f8ae	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x9ee67a74	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xa430ed59	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xaf7f07bd	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xde6c8d8a	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xf84ca606	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x037523fe	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0x0b7969d5	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0x0bfc8bc9	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0x988d15dd	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0xac206a67	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0xb61faeab	mii_link_ok
++EXPORT_SYMBOL drivers/net/mii 0xc20b1985	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0xcc14930b	mii_check_link
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x33891f35	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x79befa7b	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x88848cb3	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x8965ebf6	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xf9305f41	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/vitesse 0x9a78c2b6	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x1326ee70	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x7ec833de	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xb07b38f3	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/sungem_phy 0x24610135	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x1e052010	team_mode_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x651126bc	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0x663c8dd3	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0x75f357ed	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0x7e9f8dca	team_options_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x7f601484	team_options_register
++EXPORT_SYMBOL drivers/net/team/team 0xa69cb2bf	team_mode_register
++EXPORT_SYMBOL drivers/net/team/team 0xa7263161	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x023f0b99	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x07138888	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xab51a604	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xc416fa8b	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x0e51ca34	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x261facb2	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x35bde2a6	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x8126f6d0	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x8232d1ef	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x89ff2346	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xa95e25f5	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xaf6a0abc	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb7eae78a	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xcb64a6cc	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe2e19836	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/z85230 0x019729b4	z8530_sync_open
++EXPORT_SYMBOL drivers/net/wan/z85230 0x058404f8	z8530_sync_dma_close
++EXPORT_SYMBOL drivers/net/wan/z85230 0x10c78988	z8530_dead_port
++EXPORT_SYMBOL drivers/net/wan/z85230 0x23bcfa21	z8530_queue_xmit
++EXPORT_SYMBOL drivers/net/wan/z85230 0x3ac4cb8e	z8530_null_rx
++EXPORT_SYMBOL drivers/net/wan/z85230 0x46b24fc9	z8530_init
++EXPORT_SYMBOL drivers/net/wan/z85230 0x5cd24d29	z8530_hdlc_kilostream
++EXPORT_SYMBOL drivers/net/wan/z85230 0x6fa9ee22	z8530_sync_close
++EXPORT_SYMBOL drivers/net/wan/z85230 0x759ad35e	z8530_channel_load
++EXPORT_SYMBOL drivers/net/wan/z85230 0x78e228b3	z8530_nop
++EXPORT_SYMBOL drivers/net/wan/z85230 0x85608b32	z8530_shutdown
++EXPORT_SYMBOL drivers/net/wan/z85230 0x9b920697	z8530_sync
++EXPORT_SYMBOL drivers/net/wan/z85230 0x9c5d01a5	z8530_sync_dma_open
++EXPORT_SYMBOL drivers/net/wan/z85230 0xaac7a347	z8530_describe
++EXPORT_SYMBOL drivers/net/wan/z85230 0xbeac6cd8	z8530_sync_txdma_close
++EXPORT_SYMBOL drivers/net/wan/z85230 0xbf722210	z8530_sync_txdma_open
++EXPORT_SYMBOL drivers/net/wan/z85230 0xd4ffebf0	z8530_interrupt
++EXPORT_SYMBOL drivers/net/wan/z85230 0xe3d80064	z8530_hdlc_kilostream_85230
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0x786cf799	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/airo 0x3fe1b637	stop_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xa659f5f6	init_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xab69787e	reset_airo_card
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x19c0a921	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x349b1507	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x349bb74b	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x37742e12	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x3df9e3e4	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4cb80d93	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x8acefa8f	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaef99c8f	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb3a8eff6	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb97771b2	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xc9b1fbce	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xe9001c88	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x0ddfc537	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x3dcd8c8b	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x4587effd	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x6344164c	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x67e4c419	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x71a2e9a0	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x825ca144	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x92c5531e	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xa09216c2	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc2d19639	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc70f168b	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xcf915aff	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xe5c9c7c5	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xf41d9434	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xffba09aa	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x269c603a	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x2c34d823	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4ac6d8bb	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x5dd1adfa	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x67534e00	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x79969190	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x82326ddd	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x82bc8358	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa44d324a	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc3438dcb	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xd4c8219e	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x03fb2f72	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x096e537f	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x0e1ab641	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1f1cdca8	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x23c2a8a6	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2edfbfa0	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x3e580af3	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x3eb77e9c	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x4240dc6c	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x469cab07	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x68b5e4d1	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x68eedbc3	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x719030f6	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x76006b5e	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7dad6e0d	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x8545d942	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xaad162b1	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xad6cf70f	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb7b4ab9f	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xbe4bd5fe	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xdc6e08b6	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe27f6721	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf16b215e	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0194fb93	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x02474e5f	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x056792f8	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0898703e	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0ef620ed	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x128e77d0	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x12b6f7e3	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1653776d	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x16d40373	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x17ab7cbf	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x18ef2340	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1fa8ff0a	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x232af1c5	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x27490979	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x27cff689	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x27d45407	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x285de600	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x295d2efb	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2ac59187	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2eaa90cf	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2ee024e7	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2f4eaf46	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3068ae7a	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x311e3477	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x319786d6	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x33b0896d	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x398b58e3	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3edbc33c	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x40078821	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x40e60775	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x43986e82	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4763a954	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x48d697fe	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4cbfaf88	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4e8de090	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x51415fe5	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x52baf433	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5328b580	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5408065d	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x54571b46	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x54c5b08c	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x55433ccb	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x554ddb8d	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x55684fd1	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x558d4968	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x55ba18ea	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5800f1f3	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5af7fc7d	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5c25b1f4	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5d78a394	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5dc761dd	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x60081ea8	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x65101378	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6c8382d1	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6cad5bd0	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6d3bfd34	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6e634234	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7283f5c6	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x736a3e3b	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x785815fd	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7d7f0dc6	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7fe48d3f	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7ff0d35b	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8050852b	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8cf4a31a	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8d81c013	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x962be2d7	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x98068495	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x98b2d6c1	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9a49fee9	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9b80cc78	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9d1b9f75	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9d660568	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa6db9243	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaad84fc3	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xac3c4ca1	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xadac41f5	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaf935005	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb3b04223	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb5997eac	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb83a8f70	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xba017073	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbd1ccbfc	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc9fe5363	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcaf43aeb	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcb122466	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcf112ed2	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd329cb88	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd6eba1c2	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd79dbf6b	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd9d0763e	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xda142bb4	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdaea8b57	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xde66adfa	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe0e176e6	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe17f546a	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe2d2cbe4	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe483c5a6	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe9733c68	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xea26f140	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf021bcb1	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf02f69d6	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf06faddf	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf8b5097f	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfeb23b44	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x1824d9f8	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x2093dfee	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x50bf9c0e	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x04dcf023	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x060c3ce9	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x28d45003	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x2b73f0e9	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x2d35370c	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x2fc74b04	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x78456a2c	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x7c616f13	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x8a7af4e2	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xaa3980ff	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xb0f49e2b	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xdd25dce7	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xe95dc340	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x05d5d5be	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x05f288dd	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0ad69602	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0d410c27	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x12af12d6	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x17038c98	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x19d8c8da	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x50cf34b8	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x5cfaa158	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x5ec7c6d3	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x651f5453	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x731e3c08	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x771ed1e9	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x78bf5380	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7a3408bf	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8441934f	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9448e913	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9b86f4c6	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa5b5c68d	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa6c6f7c2	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa753aaed	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb168210b	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc1c948cf	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xcffb1646	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xdda59ae4	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xfd30cc6c	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x02debe3f	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x16a96287	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x1af1dd65	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x229d6d6d	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x34b8ed43	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x3520591f	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x37614030	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x3c4fef9d	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x47826c0c	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x47fbbb15	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4baf16bc	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x70046c81	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x876e8400	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x8847f327	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x91b776b8	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x95b51c02	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x988115ee	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa9e1b849	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb80a458e	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xda755938	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xe194c7f7	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x071754ff	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x09a77f93	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0aa498ef	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0b1c2574	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0b4fcf24	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x104fe100	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x11a36460	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x12670154	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x13f286f3	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x15c8938b	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1770d307	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x19c6768f	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x19d27ad1	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1a43f459	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1a9fa593	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1c5e6ba9	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1cf2de70	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1e507c6b	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1f99d27c	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1fca1ef7	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1fd0a1fd	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2246a772	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x23063c21	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x236000ce	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2526ddc8	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x26390df8	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x273bf91e	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2f3afbb2	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3038065c	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x34c6dc8b	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x377b745f	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x38135b63	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x407d5d00	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4182851f	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4bbacddd	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4bd14654	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4e599e5f	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4f90e11f	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x500cd487	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x51f62c78	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x52d9f674	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x538da6b0	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x55ec50b3	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5cc5ed08	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5d974f12	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x612ac3fe	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x632dbc11	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x63f45b93	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6514486a	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6918a871	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x69550393	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6c7c1515	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6e526c9e	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x722de4d7	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x79affc7d	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7a1e565b	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7d8e4b2b	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x81fd86f7	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x85c77829	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8a5de398	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8a61126e	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8ab31c44	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8e27f59c	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8f362fc7	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9480fdac	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x99807e2e	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9dd2e5e6	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9ea2ffb8	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa11da6b0	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa139605f	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb48deea8	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb5b357de	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbb81d667	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc09a186f	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc66eb999	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc6c7655d	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xca1655a8	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd22ce27f	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd300c934	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd79437bb	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd7c03a1b	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xda0f706c	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdbb242b7	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdbc83165	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdcd04d48	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdd5398a1	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdf04f1f4	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe185cb16	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe42c3287	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe5b2ab2a	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe834b3d8	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xea25b1b2	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xedd8c970	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf25ffe1e	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf5167196	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf5b03ed7	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfd7b19a5	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfee1f221	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x08c6664d	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x4379786d	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x95a8ab3c	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xa2b6ec39	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xb69add1f	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xcd60e86e	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xd4f50457	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x02cf7fcf	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x1e427b80	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x27e9e34b	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x2e93e43f	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x41e4e4ed	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x77270118	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x93f9292b	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x9fc73813	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa8ec8947	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb4f02748	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb9e0c385	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xbf8230a2	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xe2eb96c1	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xe4a75c1e	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xe693a1c6	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf3f05216	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf44a4732	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0x3f3787ba	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0e75aee6	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x16b9d418	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1def1949	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1f5f8dfb	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1f938cb3	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x231eeb55	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2946b832	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2bad4439	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x35c6cbdb	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3b94dea4	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x405b3fef	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x464fb62b	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4bc0d04c	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5e3d847f	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x61ddf29a	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6aa0f4be	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x81368600	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8263dab2	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x82a9b398	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x870d803f	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x877fc531	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x89803093	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x92911993	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x9732dea0	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa19d46c9	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa4b04b0f	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa92958f8	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa988da64	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xad630169	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb596bc7f	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb97ad51b	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc7a11971	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc86925c0	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xcf07fa9d	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd88875b3	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd8a43a45	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdfa5f374	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xeb19cdd4	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf0a04e5d	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xfc17f225	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xfd8ae924	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x231c708f	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xa29d0577	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xbe962e38	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xeb284dc7	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xb3138665	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xb902e516	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xca102de3	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xcc44ff69	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0682e7ca	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0f51e469	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1cb073ad	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x208deb9c	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x23d2a0b2	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2d2424bc	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3e432d6f	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x44d04c2a	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4ee12345	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x574621ad	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x7805a927	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9381d9a7	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x97cfdba7	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa0668944	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa2108aaf	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa9657fad	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xab6eb321	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb6c13aa3	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbea38e97	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xcecff5bb	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdd8aa0c6	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf14bd552	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf198fb75	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf515bed1	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf525921e	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf718a4d8	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xfbe22ce0	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xfe283be5	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x1e18f476	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xd7105f93	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xe1893566	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xf5f8956c	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x1e07a32f	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x25fcc514	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xc142d717	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x5bef93b0	microread_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0xf19a5e31	microread_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x4760aa80	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x5c37a2e7	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xff9516f5	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x8e992f3e	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0xfabd7d8f	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x2c40f59b	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x532de7ff	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x6a78e9a6	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x0bc29056	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x0ef67bcc	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x22e5cd78	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x30e30e27	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x3b1b5fc3	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x6dbb75e3	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xb141aa89	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xd7a7ea3a	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xe47c8a61	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xe8aae3f3	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xea0eb3d3	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x08b2ff3f	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x142e503a	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x1ec1eaf6	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3ad99940	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x495218fd	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x4ada311b	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x4b2cefd4	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x5089bd50	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xa95f8734	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xab632ff7	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xb248ec6d	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xc24fec64	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xdc72a4c5	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xdcd2518f	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xe736ef09	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xe8df89a1	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xfaa5282c	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xfad7ab11	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/ntb/ntb 0x0d0224d7	ntb_unregister_device
++EXPORT_SYMBOL drivers/ntb/ntb 0x3f8cb9b6	ntb_clear_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0xa29d5a45	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xa314d688	ntb_db_event
++EXPORT_SYMBOL drivers/ntb/ntb 0xaac01846	ntb_link_event
++EXPORT_SYMBOL drivers/ntb/ntb 0xc98d9a27	__ntb_register_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xe80b148d	ntb_register_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xee114ba5	ntb_set_ctx
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x033616cd	nvdimm_namespace_attach_btt
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x0636b1a2	nvdimm_namespace_detach_btt
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0x743fded6	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x00317f48	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0x0bf31cdb	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0x0e33d817	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0x0ee74f76	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x12dce1b7	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0x1664d48b	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0x1b9a0176	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x365f8b87	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0x442d94b3	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x44cc5477	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x5494b4e4	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0x5ab0d90a	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x6aafb509	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x70616c92	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0x7236f02f	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x72f00491	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0x7d33b0b8	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0x90fb4ab4	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x97f64a28	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0x98869576	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0x9f15d73e	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0xa5774879	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0xcb34b11d	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0xcffac02e	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0xd607d444	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xdeb8122d	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0xe01cb0d8	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xe08bf9ec	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0xe2dcc30b	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0xf5e4ea93	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0xf5ea36f8	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0xfa9c466d	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport_pc 0x3335ff36	parport_pc_probe_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0x77c34191	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x1729754c	pcmcia_request_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x5441dc3d	pcmcia_release_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x5e5424af	pcmcia_fixup_iowidth
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x6448e5a6	pcmcia_get_mac_from_cis
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x742f5665	pcmcia_parse_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x7654d8b3	__pcmcia_request_exclusive_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x7d75b9aa	pcmcia_get_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x85584520	pcmcia_read_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x8cc0197e	pcmcia_disable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x8f01eb36	pcmcia_map_mem_page
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xbf786120	pcmcia_loop_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xc0d6d0b8	pcmcia_unregister_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xd5a948b9	pcmcia_fixup_vpp
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xd8a8413c	pcmcia_enable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xdd2c8476	pcmcia_request_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xe6261312	pcmcia_request_io
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xf167ef9b	pcmcia_register_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xf9ad2cdd	pcmcia_loop_config
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xfced287d	pcmcia_dev_present
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xfffa63ef	pcmcia_write_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x03aa9aa3	pcmcia_socket_class
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x13484ddb	pccard_register_pcmcia
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x1af7118c	pcmcia_parse_events
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x212db8d2	pcmcia_socket_list
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xa3fe990b	pcmcia_reset_card
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xb2773d75	pcmcia_put_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xb3ba802f	pcmcia_unregister_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xb53da7a3	pcmcia_parse_uevents
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xbe3240d9	pcmcia_register_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcaef5de6	pcmcia_get_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcf97f3bd	dead_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xe0a492af	pcmcia_get_socket_by_nr
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xfa5988ba	pcmcia_socket_list_rwsem
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0x7145eeaf	pccard_nonstatic_ops
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0x7951b25e	pccard_static_ops
++EXPORT_SYMBOL drivers/platform/x86/intel_ips 0xf97d7d0e	i915_bpo_enabled
++EXPORT_SYMBOL drivers/platform/x86/intel_punit_ipc 0x3a0b563a	intel_punit_ipc_simple_command
++EXPORT_SYMBOL drivers/platform/x86/sony-laptop 0x5bb1e117	sony_pic_camera_command
++EXPORT_SYMBOL drivers/pps/pps_core 0x3ee9b5a2	pps_lookup_dev
++EXPORT_SYMBOL drivers/pps/pps_core 0x4b9b6ea8	pps_event
++EXPORT_SYMBOL drivers/pps/pps_core 0xe871fe9e	pps_unregister_source
++EXPORT_SYMBOL drivers/pps/pps_core 0xfe7c10b8	pps_register_source
++EXPORT_SYMBOL drivers/ptp/ptp 0x66694381	ptp_clock_unregister
++EXPORT_SYMBOL drivers/ptp/ptp 0x99ff9a68	ptp_clock_index
++EXPORT_SYMBOL drivers/ptp/ptp 0xab34fcf8	ptp_clock_register
++EXPORT_SYMBOL drivers/ptp/ptp 0xcc04ca7b	ptp_find_pin
++EXPORT_SYMBOL drivers/ptp/ptp 0xf818397d	ptp_clock_event
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x1501f165	pch_ch_event_write
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x26751936	pch_ch_control_write
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x2f9d9821	pch_tx_snap_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x318e479d	pch_ch_event_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x46e0dce2	pch_src_uuid_lo_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x73f51c2d	pch_rx_snap_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x93f882b9	pch_ch_control_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0xa2eb621b	pch_src_uuid_hi_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0xed0699c5	pch_set_station_address
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x0ed66c77	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x11fb4017	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x13a47c03	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x19efe51d	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x4fa882c5	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x69532bcf	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x6a6f4e36	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x73a0e9ca	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xb2b0abe1	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xffb7d8a1	rproc_put
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0x149069ac	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/53c700 0x0dc2ddbb	NCR_700_release
++EXPORT_SYMBOL drivers/scsi/53c700 0x3d9cece0	NCR_700_intr
++EXPORT_SYMBOL drivers/scsi/53c700 0xe6c42109	NCR_700_detect
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x3fea2de5	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x64c5a5da	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xdd6242c7	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xe79119bf	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x1a0ce57b	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x350f0e16	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x36c7a273	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x55d63b9b	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x568d6eae	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x61f35635	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x63f244c8	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x7f277d84	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xb6a5118c	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xc1747f38	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xf999e6f6	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xfe603116	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x009b1d69	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x04441473	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x059d3330	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x06ca172d	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x078f8a52	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0be1aec5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x14718517	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x23d97c44	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x240f44fd	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2b0f67bd	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2b110724	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2b8b2a9d	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3972a110	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3b293119	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3cfa0bdc	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x445ebb27	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4bcdcf21	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4f03387b	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x53f977a2	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x57850cd2	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x578b84f8	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5d222a6b	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6f9502c9	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7859a777	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x78e5a70c	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x79077a40	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7f01c0a2	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x845de7ee	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8925d5cb	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8a0d6b98	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x978387f3	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9a5ce228	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb1ec2ed7	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb5ea30c4	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbcb2b5d9	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xcd65682f	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd0a5964c	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd23466e9	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd3a03483	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd917822a	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd9c765f8	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdb09e834	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdcddd7a1	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe09eb85a	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe14ccbc9	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xebd4a3ba	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xec7ec915	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf01267c5	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf6e6b689	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfeb5f746	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x1d94b7c3	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x7f32d4e0	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x95181c77	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xb6f72b85	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0xe336efc1	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x077ab610	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0a4e81f3	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x102dc798	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1e857dd7	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1fae19e9	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x2617f296	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x271b8c3d	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3087c2c5	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x59e38c68	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x628484b1	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x68dc9e92	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x69d820ce	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6ae22851	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6d8807b1	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6ff6605a	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x72f40832	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x75bd80e5	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7a11406f	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7b11b1a2	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7bddb6ce	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7c106aae	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7ecb6741	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x85310c04	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8e2012bf	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x90845310	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x94d578f9	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa39cb484	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa412f840	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa921b45d	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb0c7c1dd	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbde5e848	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbee19965	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc1e68ce5	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd6c4d91d	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf77bd37e	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfde1b4d2	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x0ab6dd9a	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x67b0bba3	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x7911dae6	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x98662310	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xa0f32230	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xcc235449	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x04c5cd8d	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x1c5af5a9	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x1f0bacd1	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x4314315d	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x4bd4a71f	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x5247714e	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x600df127	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x91f09684	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xa8b1f458	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xdb3aa8d5	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xe60cbb0d	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xfb11dcba	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x0b30408b	qlogicfas408_bus_reset
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x1f55cd70	qlogicfas408_ihandl
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x39fa5f31	qlogicfas408_abort
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3fd8cd71	qlogicfas408_detect
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x47c0f690	qlogicfas408_biosparam
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x6cd32d2c	qlogicfas408_info
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xaae0376b	qlogicfas408_disable_ints
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xbded78c7	qlogicfas408_queuecommand
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xe76b3b20	qlogicfas408_get_chip_type
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf2b95199	qlogicfas408_setup
++EXPORT_SYMBOL drivers/scsi/raid_class 0x1575a306	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/raid_class 0xb60d851e	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0xfb5c634c	raid_component_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x03fc1473	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x08e78652	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x1e40e403	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x21e6852a	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x41021fa4	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x76010302	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x78fa31aa	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x9057c810	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xbeee75d5	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xcdd8ec00	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xdcdbce7e	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xe8113ab8	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xf5ca2d66	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x021786c4	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x16898cb3	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x16fded45	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1ce300c7	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2116d5d6	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2f3174af	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x3bf2aead	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x418de931	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4353ac3f	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4d34b7d1	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x623790d3	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6eb04f74	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7ad0ba89	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x8e8dc21c	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9119f184	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x92577b47	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x957af04e	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9dde3d9d	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa3550d1e	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa65dc802	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xab894a23	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb8030a5d	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb995a784	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc12e1827	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xca371a36	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xdfced2cd	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe6378081	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xea8dc558	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf225511e	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x27d67c86	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x29e1ba98	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x8bbf6cbc	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xb493658c	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xfe730a12	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x4ff45fab	srp_reconnect_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x5e6dc4e1	srp_rport_get
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xb19ffd7a	srp_rport_put
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xbc360301	srp_start_tl_fail_timers
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x2268e9d4	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x3f92d9d0	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x459437ed	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x462659e2	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x8b29e6dc	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xf5150c11	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xfb6495b0	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/ssb/ssb 0x16e2615e	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x2d15891c	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x2d88af7f	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x43d504ff	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0x61b58d37	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x7bf6223b	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x849680f9	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0x87c13c34	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0x8a81cd07	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0xb7782a07	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0xbcce8dc2	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xd1b1cd69	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xd7ce8018	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0xdae3104f	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0xedc5407e	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0xf0f77a61	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0xf2aaf70a	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0xf2c2180c	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0xf90a83fc	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0xfbb8538e	__ssb_driver_register
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x04952e55	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x07fa33e9	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x229abfdb	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x237db350	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x424a3cec	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x5232706e	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x536d4d32	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x5a3c1ee2	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x600adeba	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x6ef5dfb7	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x865dab73	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x8a66304d	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x9b44e20d	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xc33bab5f	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xcfbde8ef	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xd55db4e3	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xd9974a3e	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xde04af37	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe3dce264	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xecafbfce	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xecbea8b6	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xeea35e08	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xf80029b2	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xfbaed274	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x1c9c66df	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xc29d2f0d	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x8176d81a	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x0a8da026	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x56b2aa63	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x753e403f	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xe15bda42	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x6b010522	ade7854_remove
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0xdb2310ff	ade7854_probe
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0xb0b00f81	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0x08a0b8ce	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x050157eb	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0a6c8f25	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0c554989	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1215ccc0	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x17a6d700	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x19b9f5ea	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1b958017	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x297c60a3	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x30b72d2e	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x30ece298	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3a9305d2	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x42df6d58	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x43a6dec9	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x43de06a5	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4732ec9a	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4b8adf5f	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4b9d52f3	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x52558339	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x52f8daab	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5821e09a	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5af8b4bf	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x72582a98	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x72ad5324	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x73094686	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x76f7f5be	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x874f8420	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8adf2667	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8d6b743e	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9239a1d6	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x99f650d6	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa329971b	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa91c738d	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb2d586d4	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb91f58aa	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb9969dec	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbdea5f00	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbf2649b1	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc2ad9a4c	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc83bfbae	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xca2e5d87	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xca4c4857	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdad7f483	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xddff4fa4	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf108d66	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xea4bf06e	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xeccf868c	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xedb9951e	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf5b85d8b	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf7d3351c	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfe708ac7	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x041ee992	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x074b0dbf	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0d296c18	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x14a7e2a7	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1a99e104	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1b9b6d29	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1c999515	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x201d8f81	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2394e0a4	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x24e10533	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2c0ea445	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3157173c	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x39ab2f33	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4111107e	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5a91d475	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5d979b7c	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6517a604	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6dbd02b0	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x76302d44	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x76e268b9	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7764422e	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x77d32828	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7a837b64	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7d65e91a	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7e711c1b	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7ea36ea5	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x88cd57b2	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x896b33e0	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x89f05312	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8a333ef0	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8d6e2365	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x91003e4a	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x924b9fa7	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x959c82d6	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x97b9f5a4	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9d718ea3	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9d8cc9b7	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa16b9935	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaa4f6ba7	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xae552118	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb5f6a1e6	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb786cd72	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbed10b15	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbff25975	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc939074e	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xca610a5e	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcd615f10	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcdc444a9	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcf4c2491	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd456191a	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd74d8f09	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdc228d1d	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf259b42e	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf64c56be	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfe5c1ddf	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x11324975	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x204f737a	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x24b4908f	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x276665f3	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3c321b34	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4702eb8f	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x479a6df2	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5e76aac6	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x674e5c9b	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6e129894	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x716416cc	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x74f56ad4	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x84735232	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x848daf92	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x95200e75	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x9caf17ec	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x9e674825	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa8585736	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa9245072	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb0e08162	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc1001836	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc17b27da	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc9792dc3	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xcf2e4f01	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd35a368d	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd5f8641a	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe0d57c80	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe8765c72	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x01c64a6a	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x052f9200	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0782aa8c	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x07abca40	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0x081bb359	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0a958b05	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0aff6d95	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0cbdcdfd	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1f48c676	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2341c6e8	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x271e69b5	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2927087b	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2e224a0d	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4115a1d4	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4414d7a5	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x447bc4f1	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x44e42aee	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x47ec8da4	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x481a0c31	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4adb2ef1	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0x57798c95	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5a8e5d85	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5dfda1e4	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x64aa2088	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0x64c5c0f7	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6ae187db	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6d8f127e	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6f3fe88c	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7051f9d1	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7199546a	transport_init_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7374929f	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x76f631e3	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0x77a20090	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x78a91809	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7ded31ce	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7edae7bf	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8739d3f6	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8d06b211	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8f8bcf62	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x90f7f18c	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x935e4715	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x99064212	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9b1ee7ab	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9b7f9111	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9c088fe7	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9f8d018f	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa214e7d0	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0xacb7bef4	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb45fd4bd	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbb3ca8d7	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc76a3cd9	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc7b81703	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcb25c67f	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcd210005	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcea4fa8d	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd0c4e876	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd3a6f790	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd5717a63	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd7712fe7	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd7de92a6	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdb952813	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe0b611fd	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe3f6bbf8	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe8755ef1	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0xef77fe56	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf27de80d	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf6f21dbf	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xff7004fe	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfff630db	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x1887763e	acpi_thermal_rel_misc_device_add
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x5007fc2c	acpi_parse_art
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x86c998e6	acpi_thermal_rel_misc_device_remove
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0xdf707fab	acpi_parse_trt
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0x6150f7e5	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0x602c4496	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0x2a140e49	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x1194b65c	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x487808bc	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x5eb7d624	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x64c6b874	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x70658c2f	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x7191561f	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x96586c39	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xcd16aa5a	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xce455aa0	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xd2fdf1f0	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xf018338b	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xfc5f437f	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x052f980a	usb_serial_resume
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x86c08a96	usb_serial_suspend
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x2e91ca97	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x367ce26a	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x59f824d9	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x7bda5e6d	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x821e9390	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x937e412c	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x0db4bfd8	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x66670434	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xaaf17f8e	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xb711119a	lcd_device_register
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1a4f7f82	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x265f6424	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x3fa420ca	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x86edc297	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xadeee012	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xc2c0eccc	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe7162fd2	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/core/syscopyarea 0x55698a0e	sys_copyarea
++EXPORT_SYMBOL drivers/video/fbdev/core/sysfillrect 0x0746ed7a	sys_fillrect
++EXPORT_SYMBOL drivers/video/fbdev/core/sysimgblt 0x12f3bea2	sys_imageblit
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x2265ded4	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0x02841447	mac_find_mode
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x1fe7c048	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x77431113	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0xeec23a13	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x68579296	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xb78ffe73	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xd0b2c4d0	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xf5b932b4	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0x1ba2e1c4	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0x52c68ba0	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x2d9bce42	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x61504f97	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x7426fb17	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xce3909f5	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xa7098440	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xc3364d61	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x262c7202	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x3b9fdcc1	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x7a35e8f0	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x9d11f2f2	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xeab2248b	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0x5bf57c67	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x028ea21c	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x1b97e56e	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x1d667bc1	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x208970a4	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x7d8668fe	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x804635f9	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x2ec1eeff	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0xffea1811	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/wire 0x19c8108c	w1_register_family
++EXPORT_SYMBOL drivers/w1/wire 0x82735b83	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0xc9fbc424	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xf9c2d33e	w1_remove_master_device
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0x04e133fc	iTCO_vendor_check_noreboot_on
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xa78bd894	iTCO_vendor_pre_set_heartbeat
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xb5f20875	iTCO_vendor_pre_keepalive
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xc4f657bf	iTCO_vendor_pre_stop
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xdc6effc9	iTCO_vendor_pre_start
++EXPORT_SYMBOL fs/configfs/configfs 0x0de2b3c0	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x1cafaaca	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0x2d9a4f92	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x366c489d	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x39d1d8b8	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0x3e312b15	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0x52836844	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0x63fccae0	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x6b23394b	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0x7121ccbd	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0x7ebcbb39	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0x8c974535	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x9cf5adc1	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xa2d8a47d	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xb7723c64	configfs_unregister_default_group
++EXPORT_SYMBOL fs/exofs/libore 0x06f2329e	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0x12431aae	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0x17120d0a	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0x26018439	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x35ec98f0	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x5582a386	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0x68c22b7c	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0x7273084d	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x8a96b1de	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xe3d867ac	ore_read
++EXPORT_SYMBOL fs/fscache/fscache 0x166969d4	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x23a75987	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0x2affbf59	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x2ca4f0e7	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x2e62b163	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x33f133db	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x4460c192	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x459d21b8	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x4741aa33	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x47af148b	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x4808c4ff	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0x4955d535	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x543ed543	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x580d518c	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x5e525308	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0x5e5885f6	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0x63dd5b53	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x77382c95	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x7ad623a9	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x7b94aab5	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x8328471e	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0x8f0579db	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x928a5339	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x9560432e	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0x9bdf323e	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0xa5d664ce	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xa921ba37	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0xb2a36971	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0xbb9b297b	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xc00a730f	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0xc28bc7b3	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0xc3e3ff70	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0xc748596f	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0xca3cec4d	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xd8592c7f	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0xdbb8d0bc	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0xe96e5407	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0xeac42e84	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0xf0ea6d9e	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0xf2082df6	fscache_check_aux
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x084dd91a	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x4ba4b345	qtree_read_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x7a1c6313	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x8d5379af	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0xe02013d5	qtree_write_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x3771b461	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc-itu-t 0xf5b4a948	crc_itu_t
++EXPORT_SYMBOL lib/crc7 0x66213969	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0x41248eaf	crc8
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x03f599c7	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0x2ba1031d	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x3161ec94	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x4feade4b	lc_create
++EXPORT_SYMBOL lib/lru_cache 0x56fc3ea0	lc_put
++EXPORT_SYMBOL lib/lru_cache 0x619ed575	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x84e0214b	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0xbbe7c23c	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0xc48fa976	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xc6e4cd46	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0xcb990a55	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcea6747e	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0xd212c9f0	lc_get
++EXPORT_SYMBOL lib/lru_cache 0xeb13128b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0xf460a486	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0xf5ea5f5c	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0xf6acec20	lc_find
++EXPORT_SYMBOL lib/lz4/lz4_compress 0xcbc5d521	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x26c3aa22	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x1648337f	lowpan_nhc_add
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x3d1aab0d	lowpan_netdev_setup
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x5ed38668	lowpan_nhc_del
++EXPORT_SYMBOL net/802/p8022 0x347922df	unregister_8022_client
++EXPORT_SYMBOL net/802/p8022 0x7b698828	register_8022_client
++EXPORT_SYMBOL net/802/p8023 0x56985975	make_8023_client
++EXPORT_SYMBOL net/802/p8023 0x5ad30cec	destroy_8023_client
++EXPORT_SYMBOL net/802/psnap 0x7454f85e	unregister_snap_client
++EXPORT_SYMBOL net/802/psnap 0xf2ed0fd3	register_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x0987172d	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x113cfd64	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0x172affca	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x19468218	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x1a37c7e9	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x1ac34f83	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x1f2b2061	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x1f981cbd	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0x24f369ec	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0x25b465c7	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0x2f439602	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x38ede8ff	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x6253d6d9	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x6627350f	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x67587e60	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0x6c5b8e45	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x6cb375ea	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x770b6bcb	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x79b0ac00	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0x7dcb3f7f	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0x7df0334b	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x7e59d2fd	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0x88aa3f72	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x8f3b1cd6	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x9392e144	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0xa42060f4	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xa7f045ec	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0xa88bbd01	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0xaa9245ae	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0xad53c832	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0xb279a133	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0xbf476a26	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0xc0e12cd6	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0xc4247b76	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xd6b7dcda	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0xdad4c4b3	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0xdc7e447f	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0xe32eaf95	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xe4ef9d68	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xf0c4a740	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf7d5e091	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfc8d6009	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x5f916a31	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0x7c52dafb	aarp_send_ddp
++EXPORT_SYMBOL net/appletalk/appletalk 0xcafa21b0	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0xcde6473e	atrtr_get_dev
++EXPORT_SYMBOL net/atm/atm 0x1abd7f27	atm_charge
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x3ffb6650	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0x4094060e	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x63c9730f	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0x691d8150	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x695a4cd1	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0x852f5f11	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0x8ddbfc86	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0x913f6af0	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xa84250cd	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xc25488b3	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0xcc71d3be	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xe0a68109	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0xee7dc049	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/ax25/ax25 0x06dbccd5	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0x09cd317b	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0x1bb2c2a9	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x603dc909	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0x99f61077	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xb1bad88a	ax25_ip_xmit
++EXPORT_SYMBOL net/ax25/ax25 0xb73e0589	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xfdb45213	ax25_linkfail_release
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0527bb20	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x08c48a3e	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0a6f6d58	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0e22e70f	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x13f9d047	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x33ee47f6	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x37c97800	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x40fa16f0	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4ba27422	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4cf23d09	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4df25871	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x5331abd0	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x634087ac	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x66b1fc01	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7b1a95d2	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7bbaba08	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7e77c557	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7f12b668	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x818315db	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x84213386	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x85a3d3a6	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x894956af	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8f8b2346	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x942e7c30	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x96518eb2	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9d7856dc	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9ef3f3c4	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa28f4ded	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xaba52b80	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb1761389	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xba090d55	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc2f21a8f	bt_sock_wait_ready
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc5be33ce	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd2cfe151	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xdccaad00	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe51cbb57	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe5d8dfa4	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe8600c3e	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf25f3bd6	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf354ab02	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf55a4bcf	bt_sock_register
++EXPORT_SYMBOL net/bridge/bridge 0x82a964e9	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x0a531fb1	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x8193c60d	ebt_do_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xe0dbcf15	ebt_register_table
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x1a85dfca	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x6be009d7	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xc211216f	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0xc680383d	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0xf53d4800	caif_disconnect_client
++EXPORT_SYMBOL net/can/can 0x54cd4efe	can_ioctl
++EXPORT_SYMBOL net/can/can 0x68b81a5e	can_proto_register
++EXPORT_SYMBOL net/can/can 0x7d83797e	can_rx_register
++EXPORT_SYMBOL net/can/can 0x89e312b8	can_send
++EXPORT_SYMBOL net/can/can 0xc90487f8	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0xeae0f8c7	can_proto_unregister
++EXPORT_SYMBOL net/ceph/libceph 0x00ba6de3	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0x023af48f	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0dbd8e84	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0x120833ce	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x1e2094ab	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x21fd5d25	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0x22e5a962	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x24f0b053	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0x25ffcf3a	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0x29ff15fd	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0x2dbd5768	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0x2eadc45e	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x3276d0bd	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x374221af	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0x3854d004	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0x390d9ab0	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0x39bc0fd4	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x44184660	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x46ebf02f	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x47a9920e	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x4981e319	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x582a39ac	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x5a3e60c0	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x5dc24bea	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x5f9008a5	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x60ed679b	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x6af6c748	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6cce6792	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0x6f84ed89	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0x6fd024b7	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x728490ed	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0x730db129	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x78c604d9	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0x7a3df53b	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x7d94881c	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x7df63e21	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0x8264d295	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0x844be64f	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x8779ca7b	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x8878b43e	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x8baade06	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0x8bb14dde	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x8cc38ae0	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x8e933571	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0x9050b59f	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x9522aea9	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x981a5dd7	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x99399335	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9a0ab18b	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0x9be60dc4	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x9da563db	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0x9e8e96a5	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0x9f7f7387	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xa0c53b83	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xa1506aec	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xa1ebde8f	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0xa415c6e6	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xabab9359	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0xabfc8970	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0xaded78e1	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb193032d	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xb19dc152	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xb252a680	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xb3149695	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0xb4997a50	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb596d0cf	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb699a10d	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0xbfee5aea	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0xc0a26e71	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0xc12370e0	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0xc1f37a29	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0xc2bb5c90	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc7a7d227	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xc93e87aa	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xd216c219	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd3aea8ba	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0xd5383217	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xd813625e	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xdbca0f49	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0xde0eb6ba	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xe55d9bcd	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0xec6fb06c	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0xed8fa308	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0xf1d69073	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xf31e7565	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0xf4e2a5c7	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0xf7a6e526	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0xfa1b6919	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x039cd436	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x09f5e3b6	dccp_req_err
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x3b4d6c4d	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x4c738155	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x4cecc1f2	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x6d4ce3e2	wpan_phy_new
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xeea68e98	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xefa9cc26	wpan_phy_find
++EXPORT_SYMBOL net/ipv4/fou 0x0c07b4a3	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0x3d4b8979	gue_build_header
++EXPORT_SYMBOL net/ipv4/fou 0x5fbc2648	fou_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xed741d6f	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x43520dee	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x5072d6c7	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x6f18f08b	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x814ea2cb	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xbde97e86	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xeafbbc76	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x533d8e20	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x6a686717	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xe8c21f94	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x663f551f	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x6c8245b9	ipt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x9b7818b8	ipt_register_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x8dbeaacf	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/tunnel4 0xc2a148ae	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0x5a5666a2	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x0231cca3	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x5221a568	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xd7b2c153	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xe6eafdaa	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x0ee5136f	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x5fa6098a	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xe6fccd55	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x8ddb4583	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0xe368ceff	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0xcb72558c	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0xe14e9025	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x08da692c	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x19fe50f4	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x2960ffef	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x32b99272	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x3aacc4cd	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xa6610063	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xcd954317	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xf0815925	ircomm_data_request
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x0963c24b	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0x09939c11	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x0ba22d01	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x13623869	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x1befe583	irlap_open
++EXPORT_SYMBOL net/irda/irda 0x23bbc2ce	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0x2b432980	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x3343c974	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x3484da9b	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x34b0d3c5	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0x35193216	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x385847aa	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x38d23aca	irlap_close
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46b00fdf	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x5237892c	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x553300a2	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x5989162a	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6e00a69d	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x70a3f20f	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x786e11a1	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x8e861886	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x98a8b3b4	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0x9ccbdfca	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0xa0f947e1	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xa0fd5ff7	iriap_close
++EXPORT_SYMBOL net/irda/irda 0xa2379949	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0xac3dc858	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0xaeeff2b5	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xaf18adea	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0xb3c50c60	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xba59b92b	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xc1719003	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0xcd855495	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0xd3f23032	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0xd6deeaae	irda_setup_dma
++EXPORT_SYMBOL net/irda/irda 0xdc0196c2	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe1746b6a	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0xe1ba6308	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0xe329462a	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0xeb78333e	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0xec242b93	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0xed973e3c	iriap_open
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x0137300e	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0xeab6d697	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x0f7321ec	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0x10e51265	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0x59ae9b20	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0xa84ca8c0	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0xa89abf10	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0xdb504fd5	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0xe98c2ab9	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0xeb33ec8e	lapb_setparms
++EXPORT_SYMBOL net/llc/llc 0x03ba1a76	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x4bbfa858	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x63d3f0a2	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0x9a7d0083	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0xaed46f02	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0xaf0f9c50	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0xfe6a8f02	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/mac80211/mac80211 0x00155170	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0x04d2f9f5	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0x06c0b4fd	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x0a77f767	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0x0ae83923	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x10fd30ce	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x127e2069	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x1422ef67	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0x14b3807d	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x197d93a7	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x1c8fd338	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x2352c34a	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x2389c209	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0x24190360	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x2445b46a	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x26ae6432	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x2718ccee	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x275f3b15	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0x27914bff	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac80211/mac80211 0x2a7e7bcf	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x2af276b5	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x2b63ba0b	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x2e0de0d7	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x2e8a45db	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0x301075fb	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x3916b9e6	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x3ffcff36	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x43c81392	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x4d2748eb	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0x4ec01b08	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x55fa1ad0	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x58bbb76d	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x58f95e24	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x5d48d884	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0x5d861366	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x6092b939	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x60c2481a	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x6171948c	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x66161ccb	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0x66e2b90d	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x6f2d9047	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x7a8864c0	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x877dc73a	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x87d63160	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x8986139c	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x96a15586	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x97d73e00	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x989cbaff	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x9e674139	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0x9e87a639	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x9fda0005	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0xa1206821	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xa44aa911	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0xaa28e71a	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0xad743a9d	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xadb3ffea	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xb1ef796d	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xb3446030	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xbbc58e8a	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0xc37cb280	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0xc3af9a00	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0xc5b4c919	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xc679d047	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0xce76eca6	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0xcf496047	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0xd1f2e08e	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0xd350ca45	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xdbbd02d6	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xdcb46c10	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xde51bf5b	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0xe024c230	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xe682ec8a	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0xe7576762	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0xe759d272	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0xe7b6a5ef	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xea6ae55b	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0xed4f03df	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xf48d048c	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xf54c9644	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xf66489d1	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xfaaa0b75	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0xfb265c44	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0x20ee18a8	ieee802154_alloc_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x2b89b07a	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x33b1aa95	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0x63352c06	ieee802154_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x6de579a7	ieee802154_xmit_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0x888648b8	ieee802154_register_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xc4f2473b	ieee802154_unregister_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xd3b6be46	ieee802154_free_hw
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x102533a0	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x25081250	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x291f1429	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x3e1fab84	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x4ddb0436	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x743ec05e	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x8483677f	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x9e4ba765	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xa648952a	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xa8aa1f4b	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xcb2639e3	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd3229d40	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xef518257	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xfcf55c72	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x2cd306cb	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x601740cb	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xf452246b	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x5b090c7d	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0x6d0d47ac	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x89ba6fca	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/nf_nat 0x9094c853	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x983b3ba8	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xa2e960c6	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/x_tables 0x4611fecf	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x48d8126c	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x4c0ab8d3	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x70b460d7	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x897fd49f	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x93aeb7a9	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x94ffcd68	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x9dbb2df3	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xa5e99b2f	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xe223cb65	xt_find_target
++EXPORT_SYMBOL net/nfc/hci/hci 0x01de38fb	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x0a74e210	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x0ddd0fc8	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x11259f10	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0x1bffa4f7	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x241cc83b	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x34d9b8fa	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/hci/hci 0x3dd5aa44	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x43274adb	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0x509ed0b0	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x54a0fc2e	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0x745c44a9	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x96a84139	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xa25cd90b	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0xb0b217e5	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xb4c04f54	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xc51d9c05	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0xc5d0e210	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0xe7133d92	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0xecc9c324	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xf9b9f9fc	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x1cf54017	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0x214faebd	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nci/nci 0x29d463ce	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x2ad371cf	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x3bb62721	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x3ca825ad	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0x3dfa0a51	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0x40c07c44	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0x4d26cacf	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x5029f3b9	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0x52f9acb4	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x58bc486f	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x595e7d54	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0x65efb223	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x6f02ac13	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0x7023299a	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x7cfa4327	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x81aebf4f	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x8677cbe2	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nci/nci 0x8973f7f3	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0x8e348a25	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x94a43154	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0xa7701eba	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xcc6ca45b	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0xd8f2da8d	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0xd969de5c	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xe981bfe5	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xfe651024	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nfc 0x0aaf96c1	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x1659330b	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0x3c13cfd3	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0x3c25b215	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0x420b134f	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0x4c316c61	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0x515ebc39	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0x579530b8	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0x5db8f5c1	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x7061ac9c	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0x775f0bb3	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0x79eedf15	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0x8b7b87ef	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc 0x9c1cd1d2	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x9e0c2e1f	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0x9f0b3424	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0x9f9b0f58	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0xb1a37e2c	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0xb9c32876	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xd0c82f6a	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0xd9b56215	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0xe5019a00	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0xe63b2bab	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0xf7ffc5ad	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc_digital 0x54026b21	nfc_digital_allocate_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x76f03d45	nfc_digital_unregister_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x8afe6eec	nfc_digital_free_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xb03e056a	nfc_digital_register_device
++EXPORT_SYMBOL net/phonet/phonet 0x060f71fc	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0x2e2c77cc	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0x4c874439	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0x69294ba3	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0x6ed5594f	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0x8db811be	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0x8e2c0337	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0xc896d7c6	phonet_proto_unregister
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x029123a2	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x0910be11	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x215944f0	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x337f8263	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x47cc77a3	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x5ff4be2b	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x60966e14	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x877c1b0d	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x92c33f48	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xa1850df7	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xc614dc2e	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xcaef77f8	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xcd2a103e	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe96efecf	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xfa7639c3	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/sctp/sctp 0x32206bd3	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x5a431eed	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x730dde0c	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xd72529ae	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xd82e0563	xdr_truncate_encode
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xe3ea9e01	xdr_restrict_buflen
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xf48f011c	svc_pool_stats_open
++EXPORT_SYMBOL net/wimax/wimax 0x0380cb1b	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0xa00e3156	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x04f96a67	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0f31144b	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0x0fff7c0a	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0x11a53031	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x14a2bdfd	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0x151187a2	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x155b3541	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x19b99b6a	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x1a9ba387	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x1e5a1681	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0x1e5e085e	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x20142ec0	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x23d9f7f3	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x2a1c8afb	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0x3268a420	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x32ac66f8	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0x36c09b90	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x3bf11448	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x439d189c	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0x44f0eeeb	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x46ed0ff5	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x4945b60a	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x4d27470c	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0x4e35c810	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x4e5ee38c	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x502ebd69	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x52e30bb1	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0x54d66b4d	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x581dc096	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x5bc837dc	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x6293a56d	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x65ccbc20	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6a334f4b	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d8f4ca5	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x74bca132	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x78614aa1	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x7bd3498b	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x7e8a37c1	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x855b04c9	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x8841164f	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a934bbb	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0x8ce6f0e6	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x8d0986e5	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x8d2722b3	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x8ef99384	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x927253cb	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x9435812e	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x966ff54d	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x96923c60	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x969b229b	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0x970a4d0f	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x9aaad211	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x9ee7c7bf	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1162b09	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa3d8c8f0	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xa80d3af3	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xaa1eda92	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0xac4fd524	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0xad954055	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xaf05070c	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0xaf419efa	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/cfg80211 0xb14180e2	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0xb4e3713f	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0xb6a43d8e	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0xbb7b54ab	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xbd1e6244	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0xc4eced90	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0xc5042589	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc70cc071	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xc92bad8c	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0xca293d98	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0xd27eb897	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xdc224e6a	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0xdc3ead01	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe0db0a8c	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xe8289e4a	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xe9ef8025	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xeb6d7c6c	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xedec7fa7	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xf4386c33	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0xf5ac1e62	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xf876e629	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0xfe0e7685	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed562b2	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/lib80211 0x020fbe5a	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0x1bd8ee07	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x2c2cd958	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0x534c5359	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xdf79f88b	lib80211_crypt_info_free
++EXPORT_SYMBOL net/wireless/lib80211 0xf9d02db6	lib80211_get_crypto_ops
++EXPORT_SYMBOL sound/ac97_bus 0x680750c9	ac97_bus_type
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0xff8630b0	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x12994ee5	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x5a84fa00	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xaee56491	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xfe2998cc	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x0e72bd8f	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x205395a0	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x614705ff	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x7746bb9b	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x79794472	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x991c0f60	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xef8fa3d2	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xf3f0324e	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xf6fdda44	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0x86d72d76	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x018413d3	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0x081f2cf5	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0x089193e9	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0x0cc1fe6c	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0x123666a6	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0x15318081	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0x18e1683f	snd_dma_program
++EXPORT_SYMBOL sound/core/snd 0x191e88cf	snd_dma_pointer
++EXPORT_SYMBOL sound/core/snd 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL sound/core/snd 0x1d9b8155	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0x1daef3bd	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0x20c18d47	snd_cards
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x25e7c02b	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0x2a2501c9	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0x2e0174f4	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd 0x2f0f0ca9	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0x2fa69e21	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0x305db5c4	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0x340f848d	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x3a1cc33d	snd_card_new
++EXPORT_SYMBOL sound/core/snd 0x4029bd94	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x4b0f06cc	snd_register_device
++EXPORT_SYMBOL sound/core/snd 0x5470bc4b	snd_jack_new
++EXPORT_SYMBOL sound/core/snd 0x5f21d5ec	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0x602c96f0	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x63c01aae	snd_device_new
++EXPORT_SYMBOL sound/core/snd 0x70c15ac1	snd_dma_disable
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x83679824	snd_register_oss_device
++EXPORT_SYMBOL sound/core/snd 0x85659324	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0x8b7e3d2c	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0x8c5ba085	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL sound/core/snd 0x8da3f6a5	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x9a76aded	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0x9d032b32	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xa36fa9a1	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0xa7dc4404	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0xaf3c4697	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0xb08de994	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xbd598a4a	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0xccfcaaa8	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0xce3ca308	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd 0xd7ea81d9	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0xe5a77eae	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0xe5d8b3d3	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0xec735ff2	snd_jack_add_new_kctl
++EXPORT_SYMBOL sound/core/snd 0xf081493e	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0xf120c759	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0xf3afb5b7	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0xf45021cb	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0xf8bc715d	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0xfc9249e0	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0xfd97ff3a	snd_unregister_oss_device
++EXPORT_SYMBOL sound/core/snd-hwdep 0x8bf16d21	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x02ac5e52	snd_pcm_sgbuf_ops_page
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x0885c26c	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0x09f89f85	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x0b19243f	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0x0bfc3a1e	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0x10784898	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x10cde6fb	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0x191609f1	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x20424e2a	snd_sgbuf_get_chunk_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x265dfe3a	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0x2a50750a	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-pcm 0x31812cc4	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x3a2086f9	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x3b91f3af	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x47d881fc	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x49f1acf6	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x4d9b6d35	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x5dbd99a6	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x615ec3c3	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-pcm 0x624e4040	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x629b3d21	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0x63a6e60a	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x68697c7f	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x693babf7	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x6b86a002	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x6f293f9c	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0x73c7867f	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x786b0908	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x8d13a2cd	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0x90151121	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x9b719842	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0x9e8fa265	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0xa0107a82	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0xa5798a64	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xa72e81d3	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0xa7ad50af	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xade88e76	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xbb96dced	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0xc3ea57ae	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0xcbeb6fb8	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0xccaa9f59	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0xce3f614e	snd_pcm_lib_mmap_iomem
++EXPORT_SYMBOL sound/core/snd-pcm 0xd0a16975	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0xd2059e52	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0xe45a7e92	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xe4b73761	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xe8494b54	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0xf2d9ab88	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0xfc223565	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0xfe80bcc6	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0xfe9de3c1	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-pcm 0xff8a6f1e	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x06a568ab	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x088aad56	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x142b52f9	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x1cf33c19	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x24304206	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x3469cbc8	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x48bc2fcb	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x6ab2c592	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x91c6264d	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x952e44de	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x958a2c73	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x9f924a59	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xa16c5d39	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb83d4ee5	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xc2cdf827	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd24ebb53	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd36288cd	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd70cd88d	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xf99537c5	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-timer 0x06e32dd6	snd_timer_open
++EXPORT_SYMBOL sound/core/snd-timer 0x196ecb30	snd_timer_start
++EXPORT_SYMBOL sound/core/snd-timer 0x24551353	snd_timer_stop
++EXPORT_SYMBOL sound/core/snd-timer 0x425cd45d	snd_timer_resolution
++EXPORT_SYMBOL sound/core/snd-timer 0x48f44507	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0x4f7799c0	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0x5e545f0c	snd_timer_global_register
++EXPORT_SYMBOL sound/core/snd-timer 0x8656c420	snd_timer_close
++EXPORT_SYMBOL sound/core/snd-timer 0x8abd7e68	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0x9f2178c6	snd_timer_new
++EXPORT_SYMBOL sound/core/snd-timer 0xc608e090	snd_timer_pause
++EXPORT_SYMBOL sound/core/snd-timer 0xce437233	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0xe1b1ffd4	snd_timer_interrupt
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x065f699c	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x013ecde3	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x13c8e388	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x196e3d9e	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x3e71e6f4	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x58fc3ee4	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x5984dd75	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x5bef5af2	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xb367de0e	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xe427e357	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0x059c6004	snd_opl4_create
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0x29ddf5df	snd_opl4_read_memory
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0x2ff8fb3d	snd_opl4_write
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0x78e0459a	snd_opl4_write_memory
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0xe1df7727	snd_opl4_read
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x08c8e2d1	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x10b16da3	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x5d9f00a7	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x7bb47484	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x7ecedc70	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x80f95f01	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x8761a391	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x8f0de31e	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xb94f9a19	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x11a72496	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1475ecd5	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x174af1e5	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x2d862075	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x2edb6078	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x30e93d9d	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3c543cce	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3ee79bf7	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x680ed783	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7c66ae52	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7f62ae34	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x806d2789	amdtp_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x85e49dfa	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8f7c86cc	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x914a9f76	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x963d0b86	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x98362eca	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa4ac4050	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xaee554f5	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xb0a24c01	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xb83a4c61	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc17c965f	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc2d446fa	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xcbad7450	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe189926c	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xea66192e	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xec1d3224	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xed8b6e83	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf153536f	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf47b0459	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf75c857e	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xfcc62aef	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x20a84574	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0xb1a226b7	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x38765f0d	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x3db3c7d5	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x918049ba	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xb50edbcf	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xd7032029	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xee8864c0	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xf879e99b	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xfe706d04	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x36e847d8	snd_ak4117_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x462f1250	snd_ak4117_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x7f0c0694	snd_ak4117_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x97be7326	snd_ak4117_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xb1a425a4	snd_ak4117_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xf0a07d9b	snd_ak4117_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x038b66d5	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x29682f0f	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xba3051ba	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xbb7ff881	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x48dad7ba	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x76e398e8	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x362a1516	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x48958c87	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x718d5330	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xac4ea778	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xcd38dcdb	snd_cs8427_init
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xf95a9691	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x20365e3a	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x60d75b26	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xb59b2656	snd_i2c_device_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xb5e544c5	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xd371d06b	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xfa94bb33	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-tea6330t 0x1869e065	snd_tea6330t_update_mixer
++EXPORT_SYMBOL sound/i2c/snd-tea6330t 0x52932740	snd_tea6330t_detect
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0x11c30955	snd_es1688_pcm
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0x2ac2e6c1	snd_es1688_create
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0x389585d7	snd_es1688_mixer
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0xbbe69275	snd_es1688_reset
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0xf1f3d203	snd_es1688_mixer_write
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x07d19992	snd_gf1_write8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x0ae04b1b	snd_gf1_new_mixer
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x0cdd1bfd	snd_gf1_mem_xfree
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x109226cf	snd_gf1_rawmidi_new
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x1c1ce117	snd_gus_interrupt
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x1e299d9d	snd_gf1_pcm_new
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x327fb6cc	snd_gf1_dram_addr
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x36269b99	snd_gf1_i_look8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x3d88231f	snd_gf1_stop_voice
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x43aafb5e	snd_gf1_ctrl_stop
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x46db8d67	snd_gf1_lvol_to_gvol_raw
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x538c658d	snd_gf1_write16
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x6640a817	snd_gf1_alloc_voice
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x712ac0e0	snd_gus_create
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x7427022a	snd_gf1_i_write8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x76fed4a5	snd_gf1_write_addr
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x77b2f68a	snd_gf1_translate_freq
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x827b38ba	snd_gf1_free_voice
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x8674a78b	snd_gus_initialize
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x86958dc7	snd_gus_use_inc
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x898808c8	snd_gf1_mem_alloc
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x8d8cbfda	snd_gf1_mem_free
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x95c718f6	snd_gf1_look8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x9ced354c	snd_gf1_mem_lock
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xa7cd147d	snd_gus_dram_read
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xb71335c6	snd_gf1_look16
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xc43a5527	snd_gf1_atten_table
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xc94f549e	snd_gf1_peek
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xce077f49	snd_gus_dram_write
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xdb410979	snd_gf1_poke
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xdbafbabe	snd_gf1_delay
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xe5063969	snd_gus_use_dec
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xf2b51593	snd_gf1_i_look16
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x00cf20b8	snd_msnd_DARQ
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x0e096be3	snd_msnd_init_queue
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x188936e4	snd_msnd_pcm
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x54749c0c	snd_msnd_send_dsp_cmd
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x629c8f55	snd_msnd_enable_irq
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x75026b24	snd_msndmidi_input_read
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x7878540d	snd_msnd_DAPQ
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xa14c9ee9	snd_msnd_disable_irq
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xcb104bf2	snd_msnd_dsp_halt
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xd701d3cf	snd_msndmix_setup
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xdd29dd3b	snd_msnd_send_word
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xec31372e	snd_msndmix_force_recsrc
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xecb37531	snd_msnd_upload_host
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xfaf49e89	snd_msndmix_new
++EXPORT_SYMBOL sound/isa/opti9xx/snd-miro 0x4e1a3b1b	snd_aci_cmd
++EXPORT_SYMBOL sound/isa/opti9xx/snd-miro 0xc3683942	snd_aci_get_aci
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x18b3f6f9	snd_sbdsp_reset
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x30dc6e75	snd_sbmixer_suspend
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x3c695448	snd_sbdsp_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x49ae61c8	snd_sbmixer_read
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x60309b8d	snd_sbdsp_get_byte
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x6db7b3d6	snd_sbmixer_resume
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xa9d01926	snd_sbmixer_add_ctl
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xb68204cb	snd_sbmixer_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xfa472913	snd_sbdsp_command
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xfaa7bac0	snd_sbmixer_write
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-csp 0x51687287	snd_sb_csp_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0x4df496b9	snd_sb16dsp_configure
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0x58c2de41	snd_sb16dsp_pcm
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0xe0b3f690	snd_sb16dsp_interrupt
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0xe1e121dc	snd_sb16dsp_get_pcm_ops
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0x3e30a81d	snd_sb8dsp_interrupt
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0x52eaaf8b	snd_sb8dsp_pcm
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0xc2a48535	snd_sb8dsp_midi_interrupt
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0xcf1cdc4e	snd_sb8dsp_midi
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x04f73499	snd_emu8000_peek
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x0d5a68a6	snd_emu8000_poke_dw
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x1e1eb2d3	snd_emu8000_update_reverb_mode
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x29fd9d30	snd_emu8000_dma_chan
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x3065f49d	snd_emu8000_init_fm
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x5a5e6833	snd_emu8000_update_chorus_mode
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x62e82915	snd_emu8000_update_equalizer
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x6364b0ad	snd_emu8000_load_chorus_fx
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x6b1f7a19	snd_emu8000_peek_dw
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x6fb68232	snd_emu8000_poke
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0xab99d5e0	snd_emu8000_load_reverb_fx
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x180d6f7a	snd_wss_put_single
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x1aebc567	snd_wss_mce_up
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x2f76d86e	snd_wss_overrange
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x342ea2b4	snd_wss_get_pcm_ops
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x3760b385	snd_wss_mixer
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x3a1bc808	snd_wss_chip_id
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x4aafabeb	snd_wss_put_double
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x64cc489d	snd_wss_create
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x66caa205	snd_wss_info_single
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x6d65185d	snd_wss_out
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x6f47cf17	snd_wss_pcm
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x7b202637	snd_wss_interrupt
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x82f983a2	snd_wss_get_single
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x8c0e9c0b	snd_wss_in
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x9104d7cb	snd_cs4236_ext_in
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xacec05b6	snd_wss_info_double
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xaea2f179	snd_cs4236_ext_out
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xd05b4733	snd_wss_get_double
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xdc7ebd8c	snd_wss_mce_down
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xe0368c6f	snd_wss_timer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x00a76b5b	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x11d896e6	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x16bb4e77	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x1c3f8201	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x20dad9f5	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x21c405c9	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x2a017a84	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x38cf950e	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x6f5cbf79	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xa191b1d2	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb2d938e3	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xd821c5cb	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xd8ae83db	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xdb8e9659	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xdd233ae5	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xeff47e69	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xf791f8ec	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/asihpi/snd-asihpi 0xab1026b2	hpi_send_recv
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x0bd725ed	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x178f1d26	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x17ab7aff	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x27031402	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x492d13e8	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x624f066b	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xc12d52aa	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xe5f8e343	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xf2ba364c	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x054984b4	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x6680f106	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xdd6af752	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0390ece2	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0c62da1b	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x20fa0063	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x376fa1ae	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x3ba301cf	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x42006812	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x5b6e7ab8	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x5c34ba4e	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x7ba1325d	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x7dbc9f68	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x8036c6cb	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x9b6d9445	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa0ad5bd5	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa96e20ac	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xcb0687c7	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xd5ddee2d	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xd93a4375	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xe1489a4e	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xec92bbeb	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xef6f53d8	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf67b7712	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x2d04e997	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x7a36547e	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x92c164cc	snd_trident_free_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xc2d57e50	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xc8d2029b	snd_trident_stop_voice
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x2500630a	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x80322394	tlv320aic23_probe
++EXPORT_SYMBOL sound/soc/intel/common/snd-soc-sst-dsp 0xdc045797	sst_dma_free
++EXPORT_SYMBOL sound/soc/intel/common/snd-soc-sst-dsp 0xf3c6a384	sst_dma_new
++EXPORT_SYMBOL sound/soc/snd-soc-core 0x3e819cec	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL sound/soundcore 0x384ea487	sound_class
++EXPORT_SYMBOL sound/soundcore 0x4a9be35e	register_sound_special_device
++EXPORT_SYMBOL sound/soundcore 0x73895c0f	register_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x7888ac9d	register_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x83e8604e	register_sound_special
++EXPORT_SYMBOL sound/soundcore 0x860e9c70	register_sound_midi
++EXPORT_SYMBOL sound/soundcore 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL sound/soundcore 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x26a39894	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x5194f1c5	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x539ef3e0	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x8907ce36	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x92754948	snd_emux_register
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xa3626ec9	snd_emux_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x0a2fe25d	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x1ad0e0ef	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x5f56d217	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x618d0e75	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x6f9e738c	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xa00070d5	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xc59ec746	snd_util_memhdr_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xfc798c7a	__snd_util_mem_free
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x27463535	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL ubuntu/hio/hio 0x070f4d94	ssd_bm_status
++EXPORT_SYMBOL ubuntu/hio/hio 0x1e2b03c2	ssd_reset
++EXPORT_SYMBOL ubuntu/hio/hio 0x22080ab9	ssd_unregister_event_notifier
++EXPORT_SYMBOL ubuntu/hio/hio 0x2797f0bc	ssd_set_wmode
++EXPORT_SYMBOL ubuntu/hio/hio 0x47732c5b	ssd_register_event_notifier
++EXPORT_SYMBOL ubuntu/hio/hio 0x7ca3229f	ssd_get_temperature
++EXPORT_SYMBOL ubuntu/hio/hio 0xc18ac885	ssd_set_otprotect
++EXPORT_SYMBOL ubuntu/hio/hio 0xdd0991e5	ssd_submit_pbio
++EXPORT_SYMBOL ubuntu/hio/hio 0xe29a5b2b	ssd_get_label
++EXPORT_SYMBOL ubuntu/hio/hio 0xe628b9e1	ssd_get_pciaddr
++EXPORT_SYMBOL ubuntu/hio/hio 0xf0476a22	ssd_get_version
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x002d778d	VBoxGuest_RTMpNotificationDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0064d4f7	VBoxGuest_RTSemFastMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x00712528	VBoxGuest_RTAssertMsg2Weak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x01795170	VBoxGuest_RTMpGetCoreCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x03d8513f	VBoxGuest_RTThreadSetName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x05626dc7	VBoxGuest_RTR0MemObjReserveKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0665bcaa	VBoxGuest_RTAssertSetMayPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x06ab676b	VBoxGuest_RTLogPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0823cb2f	VBoxGuest_RTMemAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x08b98b3c	VBoxGuest_RTMpCpuIdFromSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x08d7a261	VBoxGuest_RTThreadSelfName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x09458185	VBoxGuest_RTR0MemAreKrnlAndUsrDifferent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0b14ec2c	VBoxGuest_RTThreadCreateF
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0b628628	VBoxGuest_RTSemEventMultiDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0b94344b	VBoxGuest_g_pszRTAssertExpr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0d1abebe	VBoxGuest_RTLogFlush
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0dfb68c6	VBoxGuest_RTSemEventWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0e1a390f	VBoxGuest_RTStrToInt8Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x104391d1	VBoxGuest_RTSemMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x113a02d9	VBoxGuest_RTMpOnPair
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x127e9d01	VBoxGuest_RTTimerRequestSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x143fba5b	VBoxGuest_RTThreadPreemptDisable
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x14835127	VBoxGuest_RTAssertMsg2AddWeak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x16d72922	VBoxGuest_RTR0MemObjIsMapping
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x17d84704	VBoxGuest_RTSpinlockCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x187c16e2	VBoxGuest_RTLogCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x19087f6f	VBoxGuest_RTSemEventMultiWaitEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1a79fedb	VBoxGuest_RTSemMutexRequestNoResumeDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1abe7e93	VBoxGuest_RTThreadGetNative
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1ad481e4	VBoxGuest_RTLogLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1d042132	VBoxGuest_RTMemContFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1e7216d7	VBoxGuest_RTThreadFromNative
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1efa8169	VBoxGuest_RTThreadUserSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1f152547	VBoxGuest_RTMpGetMaxCpuId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1fc40aab	VBoxGuest_RTR0MemObjReserveUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x21b1ee43	VBoxGuest_RTThreadSleepNoLog
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x221205d1	VBoxGuest_RTThreadSetType
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2280771d	VBoxGuestIDCCall
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x22bd51c7	VBoxGuest_RTErrConvertToErrno
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x23a552fd	VBoxGuest_RTMpIsCpuOnline
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x246391eb	VBoxGuest_RTStrToUInt16Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x25938e5f	VBoxGuest_RTLogWriteDebugger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x267da4c4	VBoxGuest_RTThreadIsMain
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x27740cb3	VBoxGuest_RTStrToUInt8Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2902013c	VBoxGuest_RTTimerGetSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x29066860	VBoxGuest_RTStrConvertHexBytes
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2972116c	VBoxGuest_RTThreadPreemptIsEnabled
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x29bf3685	VBoxGuest_RTThreadGetName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2b015c38	VBoxGuest_RTMpOnAll
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2b5f52a8	VBoxGuest_RTMpCurSetIndexAndId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2bad2a8e	VBoxGuest_RTStrToInt16
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2c5b3002	VBoxGuest_RTErrConvertFromErrno
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2d27c026	VBoxGuest_RTSemEventWaitExDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2e136d3c	VBoxGuest_RTR0MemObjAllocPhysExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x309de102	VBoxGuest_RTMpCpuId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3519743a	VBoxGuest_RTMpCurSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3534ed69	VBoxGuest_RTMemAllocVarTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x353b64a3	VBoxGuest_RTSemMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x353e5a81	VBoxGuest_RTSemEventMultiReset
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x365d44f1	VBoxGuest_RTR0MemObjMapKernelExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x36e780e0	VBoxGuest_RTStrToUInt8Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x37b2d47a	VBoxGuest_RTStrPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x39df70a0	VBoxGuest_RTStrPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3a29bcdb	VBoxGuest_RTThreadIsInitialized
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3a77155a	VBoxGuest_RTMpOnPairIsConcurrentExecSupported
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3b0a3d87	VBoxGuest_RTMemAllocZVarTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3d00f113	VBoxGuest_g_u32RTAssertLine
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3ed3a918	VBoxGuest_RTAssertMsg1
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3f452f12	VBoxGuest_RTR0MemObjAllocPageTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3f8d56e7	VBoxGuest_RTMemDupTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4002b8b4	VBoxGuest_RTTimeSpecToString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x405901ff	VBoxGuest_RTStrFormatTypeRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x428e3456	VBoxGuest_RTR0Term
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x428eb5ba	VBoxGuest_RTMemTmpAllocZTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x42c5bff2	VBoxGuest_RTLogRelLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x432b6724	VBoxGuest_RTR0MemObjAllocPhysNCTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x433ceadb	VBoxGuest_RTLogWriteStdOut
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4453e900	VBoxGuest_RTR0MemObjProtect
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4484f9ee	VBoxGuest_RTTimerStart
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x44ce618e	VBoxGuest_RTMemAllocExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x453e64fb	VBoxGuest_RTSemEventMultiSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x45933412	VBoxGuest_RTStrToInt8Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4597652f	VBoxGuest_RTStrFormat
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x45d332ae	VBoxGuest_RTMemReallocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x46b36f60	VBoxGuest_RTTimeSpecFromString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4819f15e	VBoxGuest_RTThreadWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x48487b79	VBoxGuest_RTLogDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4983ea42	VBoxGuest_RTAssertShouldPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4aca506e	VBoxGuest_RTStrToUInt32Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4d0161ca	VBoxGuest_RTLogBackdoorPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4d47859f	VBoxGuest_RTR0MemKernelCopyTo
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4e6d6986	VBoxGuest_RTStrToUInt16
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4e7faa59	VBoxGuest_RTStrToInt64
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x503f488a	VBoxGuest_RTLogRelSetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5045b702	VBoxGuest_RTLogGetDestinations
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5118e8ae	VBoxGuest_RTStrToUInt64
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x52041f46	VBoxGuest_RTThreadPreemptIsPossible
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x53602f45	VBoxGuest_RTMemTmpFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x539dd662	VBoxGuest_RTTimeSystemMilliTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x53b772da	VBoxGuest_RTAssertSetQuiet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x543527dc	VBoxGuest_RTLogWriteStdErr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5460fc01	VBoxGuest_RTTimeImplode
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x54abe5d4	VBoxGuest_RTSemMutexRequestNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x54e45046	VBoxGuest_RTR0MemObjAllocLowTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x55c48692	VBoxGuest_RTMpIsCpuWorkPending
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x57280c42	VBoxGuest_RTR0MemExecDonate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x57406d20	VBoxGuest_RTR0ProcHandleSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5929b954	VBoxGuest_RTPowerSignalEvent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5936a317	VBoxGuest_RTR0MemObjAddress
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x59390acb	VBoxGuest_RTTimeIsLeapYear
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5ad3216a	VBoxGuest_RTR0MemKernelIsValidAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5b0eaa4d	VBoxGuest_RTThreadWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5c15981f	VBoxGuest_RTMemContAlloc
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5ca67994	VBoxGuest_RTLogDestinations
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x613042f7	VBoxGuest_RTR0MemObjMapUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x622a261f	VBoxGuest_RTPowerNotificationRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x622bf330	VBoxGuest_RTMemAllocZTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x62fd45a8	VBoxGuest_RTTimeNanoTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x63ba9fd2	VBoxGuest_RTLogGetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x64655cd4	VBoxGuest_RTSemEventMultiWaitExDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x64af2463	VBoxGuest_RTStrToInt32
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x650e77e8	VBoxGuest_RTMpGetCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x651c778b	VBoxGuest_RTSemEventMultiCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6549a3e0	VBoxGuest_RTTimeFromString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x65b04e5d	VBoxGuest_RTStrToUInt64Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x687ae6ac	VBoxGuest_RTStrToUInt64Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6a930d21	VBoxGuest_RTTimerCanDoHighResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6bcedab4	VBoxGuest_RTThreadPreemptIsPending
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6c17021e	VBoxGuest_RTThreadUserReset
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6c2df755	VBoxGuest_RTAssertMsg1Weak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6ca5b4ec	VBoxGuest_RTSemEventMultiGetResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6f8ed216	VBoxGuest_RTStrToUInt16Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6fd2e761	VBoxGuest_RTTimeNormalize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x713f25d5	VBoxGuestIDCClose
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x715699a0	VBoxGuest_RTSpinlockDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x72d1c8f4	VBoxGuestIDCOpen
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x73a23c8b	VBoxGuest_RTLogRelPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x73f65247	VBoxGuest_RTStrToInt32Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x744623d2	VBoxGuest_RTSemMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x753d3a3a	VBoxGuest_RTLogFormatV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x755479c2	VBoxGuest_RTR0MemObjLockKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x75bee68e	VBoxGuest_RTThreadIsSelfKnown
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x76608be1	VBoxGuest_RTSemSpinMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x766a8684	VBoxGuest_RTThreadCreateV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x76b885fb	VBoxGuest_RTLogGetDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x76bb35b9	VBoxGuest_RTLogLoggerEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x76dbecb7	VBoxGuest_RTProcSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x77248ef3	VBoxGuest_RTR0MemObjLockUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7841b10d	VBoxGuest_RTMpIsCpuPossible
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x78ad2401	VBoxGuest_RTStrToInt8
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x797e701f	VBoxGuest_RTLogCreateEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x79aefc0b	VBoxGuest_RTTimeNow
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7ac53b51	VBoxGuest_RTR0MemUserCopyFrom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7ae3b63b	VBoxGuest_RTStrToUInt32
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7b423f4c	VBoxGuest_RTLogGetFlags
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7cef940f	VBoxGuest_RTStrToUInt8
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x80162938	VBoxGuest_RTStrFormatV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8229caac	VBoxGuest_RTThreadUserWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x847577ac	VBoxGuest_RTMpGetOnlineCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x84e86094	VBoxGuest_RTStrPrintfExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x854806f2	VBoxGuest_RTSpinlockAcquire
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8587f091	VBoxGuest_RTR0MemUserCopyTo
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x85afce7f	VBoxGuest_RTMpNotificationRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x867199c4	VBoxGuest_RTMpPokeCpu
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x86f9f023	VBoxGuest_RTSemFastMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x87abe8dd	VBoxGuest_RTR0MemObjSize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8ab21a95	VBoxGuest_RTSemSpinMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8b4fd3ef	VBoxGuest_RTTimeSystemNanoTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8ff5c8e5	VBoxGuest_RTSemEventMultiWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x937cd6a2	VBoxGuest_RTLogComPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9474d99a	VBoxGuest_RTSemFastMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x951fbe81	VBoxGuest_RTLogLoggerV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x953b2ba4	VBoxGuest_RTLogSetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x983f332c	VBoxGuest_RTSemSpinMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9853901a	VBoxGuest_RTAssertMsg2Add
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x98a8f55f	VBoxGuest_RTMpGetPresentCoreCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9909ff3d	VBoxGuest_g_pszRTAssertFunction
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x993cc778	VBoxGuest_RTLogRelSetBuffering
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x99ee476f	VBoxGuest_RTThreadYield
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9b02b021	VBoxGuest_RTThreadSleep
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9be73ec4	VBoxGuest_RTMpCpuIdToSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9dc75797	VBoxGuest_RTLogBackdoorPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9e97ef59	VBoxGuest_RTSemEventWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9eb3db26	VBoxGuest_RTR0MemObjAllocPhysTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa21775d1	VBoxGuest_RTSemFastMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa2c23601	VBoxGuest_RTR0MemObjAllocContTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa3ff74bf	VBoxGuest_RTStrToInt16Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa52847a2	VBoxGuest_RTR0MemUserIsValidAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa5655a80	VBoxGuest_RTTimerReleaseSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa582aeba	VBoxGuest_RTMemExecFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa5f0f1ad	VBoxGuest_RTAssertMsg2
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa61aa915	VBoxGuest_RTR0MemObjFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa6209fc7	VBoxGuest_RTLogPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa74258ab	VBoxGuest_RTTimeExplode
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa8a47d40	VBoxGuest_RTLogLoggerExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xaaab8c57	VBoxGuest_RTLogRelGetDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xaadc0b5d	VBoxGuest_RTTimerChangeInterval
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xab5ee692	VBoxGuest_RTLogWriteUser
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xab871924	VBoxGuest_RTThreadPreemptIsPendingTrusty
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xacaac41d	VBoxGuest_g_szRTAssertMsg1
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xadb5cc54	VBoxGuest_RTStrFormatTypeSetUser
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xae21ae1f	VBoxGuest_RTThreadCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb2f248c6	VBoxGuest_RTStrCopyP
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb33ca348	VBoxGuest_RTLogRelPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb3f592b9	VBoxGuest_RTThreadNativeSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb4227efb	VBoxGuest_RTTimeToString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb42ea0e3	VBoxGuest_g_pszRTAssertFile
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb5676d46	VBoxGuest_RTLogSetCustomPrefixCallback
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb5ec2977	VBoxGuest_RTStrToInt16Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb6fc848a	VBoxGuest_RTStrToUInt32Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb9a86152	VBoxGuest_RTStrFormatNumber
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb9e03c35	VBoxGuest_RTTimerStop
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xba349142	VBoxGuest_RTR0MemObjEnterPhysTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbaa97421	VBoxGuest_g_szRTAssertMsg2
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbaf6967f	VBoxGuest_RTR0MemObjGetPagePhysAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbba29a48	VBoxGuest_RTR0MemObjAddressR3
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbbbc6e84	VBoxGuest_RTSemMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbbccb0c7	VBoxGuest_RTTimeMilliTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbc7fbd2a	VBoxGuest_RTLogFlushRC
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbcd1b6de	VBoxGuest_RTSemSpinMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbd0aa67d	VBoxGuest_RTLogFlags
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbeed82c5	VBoxGuest_RTSemEventDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbf5b421e	VBoxGuest_RTLogComPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc272f283	VBoxGuest_RTLogGroupSettings
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc2e0f25a	VBoxGuest_RTMemTmpAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc312f533	VBoxGuest_RTMpIsCpuPresent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc4b8857d	VBoxGuest_RTThreadPreemptRestore
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc4c265c6	VBoxGuest_RTMpGetPresentCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc5151dcf	VBoxGuest_RTLogDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc56f27ff	VBoxGuest_RTR0Init
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc57a9c9b	VBoxGuest_RTStrToInt32Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc636859e	VBoxGuest_RTThreadUserWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc6b243bf	VBoxGuest_RTTimerDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc7601bb1	VBoxGuest_RTSemEventMultiWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc9978a5f	VBoxGuest_RTAssertMsg2V
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xcb6463c6	VBoxGuest_RTStrFormatTypeDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xcdbc5e5d	VBoxGuest_RTSemEventCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xcdd40e5b	VBoxGuest_RTMpOnOthers
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xceb98390	VBoxGuest_RTMpOnSpecific
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd032523c	VBoxGuest_RTThreadGetType
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd1c8b171	VBoxGuest_RTStrCopyEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd2ebb507	VBoxGuest_RTMpGetPresentSet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd38c5d55	VBoxGuest_RTLogCloneRC
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd4f35c7d	VBoxGuest_RTSemSpinMutexTryRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd63c8527	VBoxGuest_RTMemFreeEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd76ab832	VBoxGuest_RTMemDupExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd8730925	VBoxGuest_RTLogRelLoggerV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdd31359f	VBoxGuest_RTLogSetDefaultInstanceThread
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdd699fb2	VBoxGuest_RTSemMutexIsOwned
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xde296aea	VBoxGuest_RTAssertAreQuiet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdead7a1c	VBoxGuest_RTLogSetBuffering
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdfaa7e65	VBoxGuest_RTSemEventSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe0453bfd	VBoxGuest_RTTimerCreateEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe0afcea8	VBoxGuest_RTR0AssertPanicSystem
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe0ebf12c	VBoxGuest_RTAssertMsg2WeakV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe16047ab	VBoxGuest_RTLogDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe19acf09	VBoxGuest_RTStrCopy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe208c712	VBoxGuest_RTLogGetGroupSettings
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe2aa3ed6	VBoxGuest_RTR0MemKernelCopyFrom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe4104f8b	VBoxGuest_RTLogFlushToLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe46f3670	VBoxGuest_RTLogRelGetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe47b5364	VBoxGuest_RTSemEventGetResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe5908cc3	VBoxGuest_RTStrToInt64Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe59fc65c	VBoxGuest_RTLogWriteCom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe6a00917	VBoxGuest_RTThreadIsInInterrupt
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xebbe4bc3	VBoxGuest_RTThreadIsSelfAlive
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xecd69ee8	VBoxGuest_RTAssertMsg2AddWeakV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xed0424f7	VBoxGuest_RTMemFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xed92363f	VBoxGuest_RTR0MemObjMapKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf244ec46	VBoxGuest_RTSemMutexRequestDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf2e6e2c5	VBoxGuest_RTStrPrintfEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf3cd37e7	VBoxGuest_RTSemEventWaitEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf450a3d4	VBoxGuest_RTLogCreateExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf722f7d1	VBoxGuest_RTMemExecAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf7c384ae	VBoxGuest_RTStrToInt64Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf81b13f5	VBoxGuest_RTPowerNotificationDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfb5ca767	VBoxGuest_RTSpinlockRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfcfe8381	VBoxGuest_RTMpGetOnlineSet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfe4fce41	VBoxGuest_RTAssertMayPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfe5c0dc7	VBoxGuest_RTAssertMsg2AddV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfec59082	VBoxGuest_RTLogDumpPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfec8da5c	VBoxGuest_RTMpOnAllIsConcurrentSafe
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xffc16d99	VBoxGuest_RTMpGetSet
++EXPORT_SYMBOL vmlinux 0x00025800	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0x0066651f	gnttab_alloc_pages
++EXPORT_SYMBOL vmlinux 0x0084b31e	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x00a8acbe	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0x00b743fd	release_pages
++EXPORT_SYMBOL vmlinux 0x00b8c3a7	mempool_alloc
++EXPORT_SYMBOL vmlinux 0x00d7a5e3	dma_mark_declared_memory_occupied
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x00f22c67	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x01099bbe	rwsem_wake
++EXPORT_SYMBOL vmlinux 0x0109d08e	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0x010a2c53	__sock_create
++EXPORT_SYMBOL vmlinux 0x010e20d0	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0x01139ffc	max_mapnr
++EXPORT_SYMBOL vmlinux 0x0139b504	cpu_current_top_of_stack
++EXPORT_SYMBOL vmlinux 0x013b5348	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0x014e3fe0	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x0178667d	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x018760d6	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x018f05ad	console_start
++EXPORT_SYMBOL vmlinux 0x01905ec7	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x01a07d4b	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x01b3af69	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0x01c89ed1	security_path_link
++EXPORT_SYMBOL vmlinux 0x01e1a314	key_task_permission
++EXPORT_SYMBOL vmlinux 0x0209b187	param_ops_int
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x023100ff	user_path_create
++EXPORT_SYMBOL vmlinux 0x0237b57a	arch_unregister_cpu
++EXPORT_SYMBOL vmlinux 0x025101dc	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x0261b3fd	devm_clk_get
++EXPORT_SYMBOL vmlinux 0x0261fd6f	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x02910353	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a56cd9	pci_map_biosrom
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02c20067	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x02c36135	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x02ee26c1	free_pages_exact
++EXPORT_SYMBOL vmlinux 0x0311edec	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x03365fae	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x03777268	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x038bfb1e	tty_port_init
++EXPORT_SYMBOL vmlinux 0x038cf64b	dma_release_declared_memory
++EXPORT_SYMBOL vmlinux 0x0394c465	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0x039a5bce	dma_supported
++EXPORT_SYMBOL vmlinux 0x03e5d392	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0x03fa00c3	genphy_suspend
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x04015eec	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x040849f9	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0x040c4caa	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x0426ba24	idr_for_each
++EXPORT_SYMBOL vmlinux 0x043b5a2c	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0x04443218	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x044d6220	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x046bc8c8	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0x04794061	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x048628c4	acpi_processor_notify_smm
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x048b0ca7	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0x048ce6b6	vme_register_driver
++EXPORT_SYMBOL vmlinux 0x04afd4fb	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x04b5bc7a	pci_save_state
++EXPORT_SYMBOL vmlinux 0x04d3929c	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0x04d8c750	release_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x050877b9	dmi_first_match
++EXPORT_SYMBOL vmlinux 0x0512f901	single_open_size
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x05243732	__skb_checksum
++EXPORT_SYMBOL vmlinux 0x0531b427	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x057f5150	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x058b6057	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x05a5ed68	serio_rescan
++EXPORT_SYMBOL vmlinux 0x05b50374	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0x05b7928b	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x05cf7d23	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0x05e492d4	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x05f6a716	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x0617deb1	clear_inode
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x064f68e5	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x0672dfe2	del_gendisk
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x068a3c83	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x068c7263	ioremap_cache
++EXPORT_SYMBOL vmlinux 0x0692d5c8	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0x06935083	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x06972fd4	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x06a24490	mpage_readpages
++EXPORT_SYMBOL vmlinux 0x06a51886	param_set_uint
++EXPORT_SYMBOL vmlinux 0x06c0dae5	__kernel_fpu_end
++EXPORT_SYMBOL vmlinux 0x06f7d564	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0x06f8683b	blk_make_request
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x06ff6084	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0x070ad301	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0x0727c4f3	iowrite8
++EXPORT_SYMBOL vmlinux 0x072a448d	sock_create_lite
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x0734958f	pci_request_region
++EXPORT_SYMBOL vmlinux 0x074a6472	sk_capable
++EXPORT_SYMBOL vmlinux 0x07608604	acpi_get_vendor_resource
++EXPORT_SYMBOL vmlinux 0x076b79f2	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x0777a172	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x078822e4	gen_pool_create
++EXPORT_SYMBOL vmlinux 0x078e3fe5	nd_region_release_lane
++EXPORT_SYMBOL vmlinux 0x07a4b576	flex_array_free
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07b54342	nonseekable_open
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07d50a24	csum_partial
++EXPORT_SYMBOL vmlinux 0x07f08a18	copy_from_iter
++EXPORT_SYMBOL vmlinux 0x08120207	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x0814248b	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x082bd639	md_done_sync
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x0835266a	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0x0836b17f	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x083ee73f	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x08415519	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x0847b151	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0x084c2b29	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x0855b4f7	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0x0862af22	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x08699ba6	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0x08800985	page_address
++EXPORT_SYMBOL vmlinux 0x0897287b	acpi_disable_all_gpes
++EXPORT_SYMBOL vmlinux 0x08bcf4b6	neigh_update
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x090186ae	wake_up_process
++EXPORT_SYMBOL vmlinux 0x09018bf8	submit_bh
++EXPORT_SYMBOL vmlinux 0x090bd510	eisa_bus_type
++EXPORT_SYMBOL vmlinux 0x094822bb	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x094ffc82	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x0963d67d	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x0982551c	nla_put
++EXPORT_SYMBOL vmlinux 0x098311dd	mount_subtree
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x09921795	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0x09afb5a5	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09cafa81	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09d46e16	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0x09e88526	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a2c58ad	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x0a3131f6	strnchr
++EXPORT_SYMBOL vmlinux 0x0a373226	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0x0a469d23	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0x0a59ec82	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0x0a6200e4	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0x0a661faa	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0x0a713c38	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0x0a770832	register_memory_notifier
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0aa7b11f	install_exec_creds
++EXPORT_SYMBOL vmlinux 0x0ab0ae2d	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0x0ac1440f	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x0ac4c23b	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x0ac54baa	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0adde15d	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0x0afe26d8	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b48677a	__kfifo_init
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b5ff1c4	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b861539	param_set_charp
++EXPORT_SYMBOL vmlinux 0x0b905c66	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x0ba3f12e	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0x0bb0b430	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0x0bb56f62	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bc7a71d	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x0bd15965	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x0bd2edbd	md_update_sb
++EXPORT_SYMBOL vmlinux 0x0beeb499	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0x0bf57ec4	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x0bf9034c	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0x0c0b5dd0	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x0c0c113b	kill_block_super
++EXPORT_SYMBOL vmlinux 0x0c0c2432	xattr_full_name
++EXPORT_SYMBOL vmlinux 0x0c166bae	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x0c200ecc	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0x0c245b29	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c68ac20	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x0c69c353	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x0c718c66	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0ca7b7a8	acpi_check_region
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cc62e36	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x0cd70fdd	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x0cdb7d12	__kernel_fpu_begin
++EXPORT_SYMBOL vmlinux 0x0ce2726a	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0x0ce3ab1b	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x0d0360d8	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x0d041a98	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0x0d119ae2	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x0d133fde	kill_bdev
++EXPORT_SYMBOL vmlinux 0x0d138180	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0x0d163983	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0x0d193dd7	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x0d1a8123	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0x0d325050	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0x0d361291	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0x0d3c2c47	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x0d3dda14	acpi_get_type
++EXPORT_SYMBOL vmlinux 0x0d4005ee	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0x0d458e53	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0x0d4c9cc3	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d58d605	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d6c9b03	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x0d898156	simple_empty
++EXPORT_SYMBOL vmlinux 0x0d96b28b	pci_pme_active
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0da31411	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0x0dc1a78c	bin2hex
++EXPORT_SYMBOL vmlinux 0x0dc4c177	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0x0dd599df	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x0dd6cc78	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0x0de66930	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x0deb0b8a	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x0e175332	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0x0e204b10	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0x0e4984a1	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0x0e623dd1	devm_ioremap
++EXPORT_SYMBOL vmlinux 0x0e699a11	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0x0e6c3487	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e7390ec	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x0e99a6ff	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0x0eaf451e	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x0eaf53b3	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0x0ebf02aa	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0ecd8e4f	input_register_handler
++EXPORT_SYMBOL vmlinux 0x0eea0399	strscpy
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f0f514f	prepare_creds
++EXPORT_SYMBOL vmlinux 0x0f32e472	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f5b0a23	acpi_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f72ff5f	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f889576	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0x0f89bda0	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0x0f925645	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0x0fa69fd7	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fd00a68	acpi_clear_event
++EXPORT_SYMBOL vmlinux 0x0fd1e456	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x0ff94af2	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0x10113070	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x101e8e51	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0x102c56de	irq_regs
++EXPORT_SYMBOL vmlinux 0x10671d37	register_console
++EXPORT_SYMBOL vmlinux 0x106afb06	_dev_info
++EXPORT_SYMBOL vmlinux 0x106f13ab	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x10806ccc	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x1093eaa1	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x10a661bc	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0x10c5965e	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x10fba77a	vga_con
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x11145431	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0x112578b0	passthru_features_check
++EXPORT_SYMBOL vmlinux 0x112b76d5	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x1137dd50	register_framebuffer
++EXPORT_SYMBOL vmlinux 0x11524c6d	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x117d97ac	netif_device_detach
++EXPORT_SYMBOL vmlinux 0x1180c609	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0x11952f5a	nvdimm_namespace_capacity
++EXPORT_SYMBOL vmlinux 0x119a8205	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11a5e5f8	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0x11c962b9	from_kuid
++EXPORT_SYMBOL vmlinux 0x11cb6309	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x11dab60d	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0x11dd01ad	intel_scu_ipc_command
++EXPORT_SYMBOL vmlinux 0x11ee8160	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x11fa82fa	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0x11faf0ad	fput
++EXPORT_SYMBOL vmlinux 0x11fbce2c	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0x120add2f	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120d67d4	unregister_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x1215b6ab	x86_dma_fallback_dev
++EXPORT_SYMBOL vmlinux 0x121b4e4b	memremap
++EXPORT_SYMBOL vmlinux 0x122d3812	phy_resume
++EXPORT_SYMBOL vmlinux 0x124ff885	netdev_emerg
++EXPORT_SYMBOL vmlinux 0x1250c7e1	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x12523d3c	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0x12592d29	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0x125bbf87	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0x12605d7d	proc_create_data
++EXPORT_SYMBOL vmlinux 0x126ea969	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0x1272d6e6	flush_old_exec
++EXPORT_SYMBOL vmlinux 0x127fa666	sock_create_kern
++EXPORT_SYMBOL vmlinux 0x128060ab	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x12a1dfa3	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12c3c969	key_revoke
++EXPORT_SYMBOL vmlinux 0x12c72bd5	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x12d65685	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x12da5bb2	__kmalloc
++EXPORT_SYMBOL vmlinux 0x12ecdbb8	down_write_trylock
++EXPORT_SYMBOL vmlinux 0x13142e5b	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x1323348f	netdev_err
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x13315729	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0x1336df5f	sock_no_poll
++EXPORT_SYMBOL vmlinux 0x133856b0	dma_alloc_from_coherent
++EXPORT_SYMBOL vmlinux 0x13489345	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0x1379fbea	set_user_nice
++EXPORT_SYMBOL vmlinux 0x139144cf	inode_init_once
++EXPORT_SYMBOL vmlinux 0x139a47ce	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0x13bbabb9	iov_iter_init
++EXPORT_SYMBOL vmlinux 0x13caf920	register_cdrom
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13d25c16	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x13f9de34	cpu_info
++EXPORT_SYMBOL vmlinux 0x13ffbc70	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0x14198598	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0x1420b379	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0x1426893a	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0x14383dbf	nd_btt_probe
++EXPORT_SYMBOL vmlinux 0x149836d1	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0x149cfa60	netdev_features_change
++EXPORT_SYMBOL vmlinux 0x14b73163	pnp_release_card_device
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x14cff935	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x14e2765c	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x14ed34bf	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0x14f1c594	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0x150389d6	acpi_processor_power_init_bm_check
++EXPORT_SYMBOL vmlinux 0x1521bd13	param_get_short
++EXPORT_SYMBOL vmlinux 0x1547bfd6	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x156a8a59	down_trylock
++EXPORT_SYMBOL vmlinux 0x15799c11	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0x15860a1c	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0x15a27381	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0x15ac9406	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x15b9e291	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15c2a99a	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x15c43de8	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x15d95304	d_path
++EXPORT_SYMBOL vmlinux 0x15e65a6b	no_llseek
++EXPORT_SYMBOL vmlinux 0x15eac904	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x15eda16c	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0x15f81aa8	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x160ea4c8	sfi_disabled
++EXPORT_SYMBOL vmlinux 0x1616cb30	acpi_evaluate_dsm
++EXPORT_SYMBOL vmlinux 0x16305289	warn_slowpath_null
++EXPORT_SYMBOL vmlinux 0x16439f5d	generic_writepages
++EXPORT_SYMBOL vmlinux 0x16699a7f	blk_put_request
++EXPORT_SYMBOL vmlinux 0x167e7f9d	__get_user_1
++EXPORT_SYMBOL vmlinux 0x1683a50b	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x168cf911	nla_reserve
++EXPORT_SYMBOL vmlinux 0x1693a1c5	netlink_capable
++EXPORT_SYMBOL vmlinux 0x16984ea8	set_page_dirty
++EXPORT_SYMBOL vmlinux 0x169c6ad8	sock_wfree
++EXPORT_SYMBOL vmlinux 0x16bb0391	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0x16be2cc9	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0x16bf3c3c	acl_by_type
++EXPORT_SYMBOL vmlinux 0x16ca9338	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x16dc4d1f	fence_init
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x16ec8c54	inet_accept
++EXPORT_SYMBOL vmlinux 0x1704a9e3	path_get
++EXPORT_SYMBOL vmlinux 0x1705e82a	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x170c25ee	acpi_get_next_object
++EXPORT_SYMBOL vmlinux 0x172ec2c9	dquot_file_open
++EXPORT_SYMBOL vmlinux 0x1741391c	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x1742fe5f	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x175a76d5	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0x175df8f2	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0x1782ab38	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0x1789dad5	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x178a7372	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0x179651ac	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17b530ee	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x17defa92	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x17e1483a	nd_integrity_init
++EXPORT_SYMBOL vmlinux 0x17f341a0	i8042_lock_chip
++EXPORT_SYMBOL vmlinux 0x180e7f45	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x18211be8	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x1822a04b	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x18431ab4	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x184f1707	ata_print_version
++EXPORT_SYMBOL vmlinux 0x185c2fb7	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x1864648c	cdev_alloc
++EXPORT_SYMBOL vmlinux 0x186aa791	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x1876ae39	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x188ea314	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x189e9ef6	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x18c0e7fe	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0x18c3d8d7	nd_region_acquire_lane
++EXPORT_SYMBOL vmlinux 0x18d96501	atomic64_dec_if_positive_cx8
++EXPORT_SYMBOL vmlinux 0x18e401ae	__get_page_tail
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x1916cf47	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0x1916e38c	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x192ae141	__frontswap_test
++EXPORT_SYMBOL vmlinux 0x192f44ba	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0x195934e4	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0x1961ca9b	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x198b415e	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x19984e23	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x199b93e1	current_fs_time
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19aef062	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19b4fb4b	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x1a07bfd0	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x1a0ab802	init_special_inode
++EXPORT_SYMBOL vmlinux 0x1a2118cb	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0x1a307c2c	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0x1a3d45c3	vfs_read
++EXPORT_SYMBOL vmlinux 0x1a42adba	simple_unlink
++EXPORT_SYMBOL vmlinux 0x1a45cb6c	acpi_disabled
++EXPORT_SYMBOL vmlinux 0x1a5de3d8	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0x1a63af34	vga_switcheroo_process_delayed_switch
++EXPORT_SYMBOL vmlinux 0x1a6b6e49	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0x1a86d04f	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0x1aa1c801	dump_page
++EXPORT_SYMBOL vmlinux 0x1afb1aaa	acpi_mark_gpe_for_wake
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b0ef699	secpath_dup
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b5253d8	devm_release_resource
++EXPORT_SYMBOL vmlinux 0x1b53f4d5	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x1b557a7f	dm_get_device
++EXPORT_SYMBOL vmlinux 0x1b570d23	acpi_warning
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b711fa9	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x1b754b26	tty_hangup
++EXPORT_SYMBOL vmlinux 0x1b7c0e5d	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b88c044	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x1b8b95ad	i8042_unlock_chip
++EXPORT_SYMBOL vmlinux 0x1bae71ee	save_mount_options
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bb5290f	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0x1bb86621	bdget
++EXPORT_SYMBOL vmlinux 0x1bc168a8	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0x1bc79997	register_netdev
++EXPORT_SYMBOL vmlinux 0x1bc7a523	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0x1be1dd26	lg_global_lock
++EXPORT_SYMBOL vmlinux 0x1c114a6a	vm_event_states
++EXPORT_SYMBOL vmlinux 0x1c2e8906	tcp_req_err
++EXPORT_SYMBOL vmlinux 0x1c4150f0	dump_truncate
++EXPORT_SYMBOL vmlinux 0x1c4f4fa7	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0x1c511eba	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0x1c531ba2	redraw_screen
++EXPORT_SYMBOL vmlinux 0x1c569304	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x1c5e8fb8	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0x1c725a6f	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0x1c747be1	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0x1c783099	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x1c8a04b0	acpi_reset
++EXPORT_SYMBOL vmlinux 0x1c8dc345	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x1cb8962a	key_alloc
++EXPORT_SYMBOL vmlinux 0x1cb93d38	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x1cc44605	d_rehash
++EXPORT_SYMBOL vmlinux 0x1cd63ef7	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0x1cecf73c	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0x1ced7761	tty_port_open
++EXPORT_SYMBOL vmlinux 0x1d0b0f0b	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x1d1758fd	__nla_put
++EXPORT_SYMBOL vmlinux 0x1d2cd076	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0x1d51e043	serio_interrupt
++EXPORT_SYMBOL vmlinux 0x1db5b956	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1de74f72	acpi_execute_simple_method
++EXPORT_SYMBOL vmlinux 0x1de8e316	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0x1df05865	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0x1df55626	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0x1e0335da	seq_printf
++EXPORT_SYMBOL vmlinux 0x1e036c98	acpi_set_gpe
++EXPORT_SYMBOL vmlinux 0x1e047854	warn_slowpath_fmt
++EXPORT_SYMBOL vmlinux 0x1e0c2be4	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x1e0d5364	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e2b88d8	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x1e3317e7	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0x1e36f941	__ps2_command
++EXPORT_SYMBOL vmlinux 0x1e46a1e7	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0x1e691132	d_walk
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e6f6008	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0x1e7f2ac4	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1eb922a3	IO_APIC_get_PCI_irq_vector
++EXPORT_SYMBOL vmlinux 0x1ebb859e	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0x1ed8ebf1	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0x1edca132	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0x1ee15143	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0x1ee1794b	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x1efc654b	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0x1f0ca59e	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0x1f323997	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x1f379bbc	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0x1f383e15	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0x1f7e807f	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x1f92d322	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x1f958a0c	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fbef02d	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fd8c01f	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x1fddb744	pcibios_set_irq_routing
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1feb1983	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0x1feb99a6	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x2005e68a	acpi_remove_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x20092385	acpi_enter_sleep_state_s4bios
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x201b0ac0	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0x201b0fbb	km_query
++EXPORT_SYMBOL vmlinux 0x20205f64	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0x202f4e92	acpi_extract_package
++EXPORT_SYMBOL vmlinux 0x20334121	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x2058afe1	single_release
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x207bd52f	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x20826e68	module_refcount
++EXPORT_SYMBOL vmlinux 0x208739f6	acpi_load_table
++EXPORT_SYMBOL vmlinux 0x20917a3f	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20ae58d0	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20c6192f	intel_scu_ipc_ioread32
++EXPORT_SYMBOL vmlinux 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20f3f09b	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0x20f43eaf	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0x20f95c99	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x2108ad55	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0x2122f4c0	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0x21333b59	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0x213a4198	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x213b72e3	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0x2156a06a	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0x216c373d	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0x21a701fe	fence_signal
++EXPORT_SYMBOL vmlinux 0x21c4c727	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21e992a5	ida_simple_get
++EXPORT_SYMBOL vmlinux 0x2207a57f	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x220d245f	vga_switcheroo_client_fb_set
++EXPORT_SYMBOL vmlinux 0x2212c0ca	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x2233115b	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0x224104a1	blk_run_queue
++EXPORT_SYMBOL vmlinux 0x224d9de5	__dax_fault
++EXPORT_SYMBOL vmlinux 0x2251cebb	address_space_init_once
++EXPORT_SYMBOL vmlinux 0x2256fafa	div64_u64_rem
++EXPORT_SYMBOL vmlinux 0x22590677	simple_write_end
++EXPORT_SYMBOL vmlinux 0x225f52c1	vme_bus_type
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22dfdd06	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x22e8096a	mmc_start_req
++EXPORT_SYMBOL vmlinux 0x22fc4f3a	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x22fd1505	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x23246384	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0x232d18ec	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0x233163ea	phy_suspend
++EXPORT_SYMBOL vmlinux 0x233fe520	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0x23803f8d	skb_make_writable
++EXPORT_SYMBOL vmlinux 0x238c075d	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23a82b61	fb_find_mode
++EXPORT_SYMBOL vmlinux 0x23ae6bc9	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0x23b101e9	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23ded6e2	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0x23e0e440	free_netdev
++EXPORT_SYMBOL vmlinux 0x23f5993b	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x23f6f607	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x240e00d2	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x24267df1	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0x243b3b8a	poll_initwait
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x2445d354	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x244df8d8	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0x2458cd01	unload_nls
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x2465d2e2	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0x2468411d	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0x246a62e7	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x249d4aff	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x24b70a91	file_ns_capable
++EXPORT_SYMBOL vmlinux 0x24c557a0	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x24eb1345	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x250113b4	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x2507416e	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x250f5f6a	__invalidate_device
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x252b1d2e	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0x256e4dc7	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0x256eb00b	eth_header_parse
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x2593a435	bio_reset
++EXPORT_SYMBOL vmlinux 0x25bda2e7	kernel_listen
++EXPORT_SYMBOL vmlinux 0x25bf45ae	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x25cf3156	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x25d3e013	scsi_unregister
++EXPORT_SYMBOL vmlinux 0x25e8ed29	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x262e71cc	blk_start_request
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x2671f273	send_sig
++EXPORT_SYMBOL vmlinux 0x2687bfdd	up_read
++EXPORT_SYMBOL vmlinux 0x268802a1	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x268cc6a2	sys_close
++EXPORT_SYMBOL vmlinux 0x26a323eb	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x26ac93ac	tso_count_descs
++EXPORT_SYMBOL vmlinux 0x26bb950b	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0x26bcfa9c	acpi_evaluate_ost
++EXPORT_SYMBOL vmlinux 0x26cb34a2	mempool_create
++EXPORT_SYMBOL vmlinux 0x26cfa31c	posix_test_lock
++EXPORT_SYMBOL vmlinux 0x26e298e0	unregister_memory_notifier
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x271191e9	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0x27184538	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0x271cba95	acpi_bus_private_data_handler
++EXPORT_SYMBOL vmlinux 0x272f031f	pci_biosrom_size
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x274bb050	clkdev_drop
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x27882b9b	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0x27ae7d0c	ec_transaction
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27bbf406	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x27c71710	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x27db75dc	dquot_release
++EXPORT_SYMBOL vmlinux 0x2802b70d	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x2803002c	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x28269cb2	__alloc_skb
++EXPORT_SYMBOL vmlinux 0x2827d59b	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x28401089	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0x288ed3a9	set_bh_page
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28a3b506	empty_aops
++EXPORT_SYMBOL vmlinux 0x28b715a6	isapnp_cfg_end
++EXPORT_SYMBOL vmlinux 0x28cfd071	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0x28e09af1	iosf_mbi_available
++EXPORT_SYMBOL vmlinux 0x28eeb1cc	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0x29215277	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0x29215a70	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x293933da	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x295ef2b4	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0x2960c69c	x86_hyper_xen
++EXPORT_SYMBOL vmlinux 0x2970b75c	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0x298f1766	pnp_possible_config
++EXPORT_SYMBOL vmlinux 0x2990748d	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x29a22d0b	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x29ac4e89	brioctl_set
++EXPORT_SYMBOL vmlinux 0x29b230e2	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x29cc7393	vme_slave_request
++EXPORT_SYMBOL vmlinux 0x29fdda53	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a565a25	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0x2a59d5d4	dma_release_from_coherent
++EXPORT_SYMBOL vmlinux 0x2a5def2f	intel_scu_ipc_iowrite32
++EXPORT_SYMBOL vmlinux 0x2a66477b	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x2a69e1a0	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0x2a747cc2	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x2a8871a5	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x2a8ad21a	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x2aa0e4fc	strncasecmp
++EXPORT_SYMBOL vmlinux 0x2aa2c3d2	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2aaea3c6	ip_defrag
++EXPORT_SYMBOL vmlinux 0x2abb5dab	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2b08842b	generic_permission
++EXPORT_SYMBOL vmlinux 0x2b08c19e	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b46feba	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0x2b4c2f45	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0x2b576f6f	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0x2b678539	seq_putc
++EXPORT_SYMBOL vmlinux 0x2b75abd8	have_submounts
++EXPORT_SYMBOL vmlinux 0x2b7f7c6a	input_set_capability
++EXPORT_SYMBOL vmlinux 0x2b982cf5	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2bb3e1b1	udp_set_csum
++EXPORT_SYMBOL vmlinux 0x2bb55d6e	acpi_remove_notify_handler
++EXPORT_SYMBOL vmlinux 0x2bde7f2b	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0x2be7b6a9	d_obtain_root
++EXPORT_SYMBOL vmlinux 0x2beb3f26	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x2bfeb410	acpi_get_handle
++EXPORT_SYMBOL vmlinux 0x2c120a91	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0x2c14323a	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c83c8df	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0x2c986c99	phy_device_create
++EXPORT_SYMBOL vmlinux 0x2ca319a6	wrmsrl_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x2ca8310a	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0x2ca8eef1	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x2cbe4320	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0x2cc40ecf	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0x2cd84451	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0x2cdfc835	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x2d004a15	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0x2d0eb880	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d144e21	rdmsrl_on_cpu
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d37342e	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0x2d456a7d	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0x2d7c1fc9	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x2d87888a	elevator_init
++EXPORT_SYMBOL vmlinux 0x2d9edb2f	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0x2db7babb	copy_to_iter
++EXPORT_SYMBOL vmlinux 0x2dbe6f2d	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0x2dc921f5	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0x2dcf2420	__frontswap_store
++EXPORT_SYMBOL vmlinux 0x2dd16564	arch_register_cpu
++EXPORT_SYMBOL vmlinux 0x2dd9a36b	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x2de7abd2	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0x2dedc4c2	acpi_format_exception
++EXPORT_SYMBOL vmlinux 0x2def7f76	rtc_cmos_write
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e2d44f7	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0x2e2dc3aa	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0x2e51ab42	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x2e6bc50c	vfs_llseek
++EXPORT_SYMBOL vmlinux 0x2e6e4d8f	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x2e7fd99e	clear_nlink
++EXPORT_SYMBOL vmlinux 0x2e96a39b	nd_dev_to_uuid
++EXPORT_SYMBOL vmlinux 0x2eae6cc1	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0x2ec524ad	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x2ece0fdf	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0x2ee3608c	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2ef8dcc1	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0x2f02a2af	__mutex_init
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f0b83d0	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0x2f122d95	cpu_tlbstate
++EXPORT_SYMBOL vmlinux 0x2f2ec417	sock_rfree
++EXPORT_SYMBOL vmlinux 0x2f384db3	acpi_is_video_device
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2f54cd02	tty_register_device
++EXPORT_SYMBOL vmlinux 0x2f73a5bc	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0x2f97ecfc	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fc35786	arp_tbl
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x30226ddf	agp_device_command
++EXPORT_SYMBOL vmlinux 0x302a0822	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x3035b834	setup_new_exec
++EXPORT_SYMBOL vmlinux 0x3038ad22	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x3070a350	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x309e36f8	elevator_exit
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30a8d6e6	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0x30b04526	ida_init
++EXPORT_SYMBOL vmlinux 0x30b29d4e	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x30be21b2	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x30c3d516	lockref_put_return
++EXPORT_SYMBOL vmlinux 0x30ca7f76	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0x30cf9d80	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0x30d3fb6f	to_ndd
++EXPORT_SYMBOL vmlinux 0x30db222c	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0x30e3d38a	may_umount
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x30f688a7	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310917fe	sort
++EXPORT_SYMBOL vmlinux 0x311518d5	mntget
++EXPORT_SYMBOL vmlinux 0x31210c49	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x31253ee6	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0x31288e09	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0x312aa8c5	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0x31380354	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x3148a748	pnp_start_dev
++EXPORT_SYMBOL vmlinux 0x314e06ab	get_super_thawed
++EXPORT_SYMBOL vmlinux 0x316840d0	inc_nlink
++EXPORT_SYMBOL vmlinux 0x316883be	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x31787ee9	md_write_start
++EXPORT_SYMBOL vmlinux 0x318d8822	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0x3191f109	__krealloc
++EXPORT_SYMBOL vmlinux 0x31920d13	ip6_xmit
++EXPORT_SYMBOL vmlinux 0x31936245	pipe_unlock
++EXPORT_SYMBOL vmlinux 0x3197534e	f_setown
++EXPORT_SYMBOL vmlinux 0x31a58e21	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x31b220a1	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0x31ba6821	__dst_free
++EXPORT_SYMBOL vmlinux 0x31e33c39	security_path_truncate
++EXPORT_SYMBOL vmlinux 0x31e506b3	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0x31e76b57	recalibrate_cpu_khz
++EXPORT_SYMBOL vmlinux 0x31ec44a0	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0x31f0bb78	__kmap_atomic_idx
++EXPORT_SYMBOL vmlinux 0x3202435a	wrmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0x321857c7	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0x32430bfd	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x326425ca	pci_unmap_biosrom
++EXPORT_SYMBOL vmlinux 0x327d09d7	phy_detach
++EXPORT_SYMBOL vmlinux 0x328ffc13	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x32b5fa2f	mem_section
++EXPORT_SYMBOL vmlinux 0x32bbe948	__d_drop
++EXPORT_SYMBOL vmlinux 0x32cc3433	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x32d889ae	pci_iomap
++EXPORT_SYMBOL vmlinux 0x32ddc69b	nd_sb_checksum
++EXPORT_SYMBOL vmlinux 0x32e6f1a0	acpi_video_backlight_string
++EXPORT_SYMBOL vmlinux 0x32eaade0	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0x32f0aa0c	get_super
++EXPORT_SYMBOL vmlinux 0x3304030a	inode_permission
++EXPORT_SYMBOL vmlinux 0x3305c460	seq_open
++EXPORT_SYMBOL vmlinux 0x330ca3d0	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0x33163bf4	done_path_create
++EXPORT_SYMBOL vmlinux 0x334f10a6	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0x336ac073	down_read_trylock
++EXPORT_SYMBOL vmlinux 0x336e8506	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0x33a11091	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x33c4c0a0	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33c8515b	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0x33dbfd93	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x33f18e16	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x342f60fe	apm_info
++EXPORT_SYMBOL vmlinux 0x3431f17f	generic_setxattr
++EXPORT_SYMBOL vmlinux 0x3433fa12	down_read
++EXPORT_SYMBOL vmlinux 0x343e565a	i2c_master_send
++EXPORT_SYMBOL vmlinux 0x34462383	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0x3450bfb3	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0x34581adf	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x345d3fea	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x345f1d77	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x3461cb65	softnet_data
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x347030e9	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x3495edcf	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34ce70f8	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x34e7212b	simple_rename
++EXPORT_SYMBOL vmlinux 0x34f0f6a6	netdev_notice
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x350267d8	blk_start_queue
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x351e1086	input_release_device
++EXPORT_SYMBOL vmlinux 0x353de98f	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x353e21e3	acpi_bios_warning
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x356f9511	param_set_bint
++EXPORT_SYMBOL vmlinux 0x358db2df	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35a99911	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x35bab279	input_grab_device
++EXPORT_SYMBOL vmlinux 0x35bf2501	I_BDEV
++EXPORT_SYMBOL vmlinux 0x35d9a450	devm_request_resource
++EXPORT_SYMBOL vmlinux 0x35fc47ca	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0x360b1afe	probe_irq_mask
++EXPORT_SYMBOL vmlinux 0x3626d54e	bdi_init
++EXPORT_SYMBOL vmlinux 0x363e002c	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0x3640531e	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0x3655ee78	tcp_connect
++EXPORT_SYMBOL vmlinux 0x367ba856	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0x367fcd5f	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36c0014b	nf_reinject
++EXPORT_SYMBOL vmlinux 0x36c6af51	intel_scu_ipc_iowrite8
++EXPORT_SYMBOL vmlinux 0x36f224fc	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0x36fdda67	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x3706c7f6	i2c_use_client
++EXPORT_SYMBOL vmlinux 0x370f9850	efi
++EXPORT_SYMBOL vmlinux 0x3720b33c	kill_fasync
++EXPORT_SYMBOL vmlinux 0x3736b3f4	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x373b4cc7	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x373d0a22	set_nlink
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x3746e586	free_user_ns
++EXPORT_SYMBOL vmlinux 0x3757cf64	led_update_brightness
++EXPORT_SYMBOL vmlinux 0x376218ad	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x376b0e9e	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x376e0ec8	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x377c4036	register_shrinker
++EXPORT_SYMBOL vmlinux 0x3782acdd	skb_pull
++EXPORT_SYMBOL vmlinux 0x379dee5f	trace_print_symbols_seq_u64
++EXPORT_SYMBOL vmlinux 0x37abf462	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37b8b39e	screen_info
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37db8f19	dmi_get_date
++EXPORT_SYMBOL vmlinux 0x37e1f1af	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0x37e74642	get_jiffies_64
++EXPORT_SYMBOL vmlinux 0x37eb8953	param_set_short
++EXPORT_SYMBOL vmlinux 0x37ef7e6c	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x37f018b3	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x37f44463	pci_dev_get
++EXPORT_SYMBOL vmlinux 0x37f614b7	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x38099e13	wrmsrl_on_cpu
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x381ccc13	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x383c9afd	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0x38401724	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x38462dd7	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0x3849efb6	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x386a12de	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x388799f6	unregister_kmmio_probe
++EXPORT_SYMBOL vmlinux 0x388e65d5	__f_setown
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38c291af	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0x38c2c75d	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0x39081193	__max_logical_packages
++EXPORT_SYMBOL vmlinux 0x391f2d4e	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x39211a4a	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x39560490	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0x395898d5	serio_bus
++EXPORT_SYMBOL vmlinux 0x395fdea7	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0x3960f7a9	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x399b826e	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0x39a055f3	acpi_remove_gpe_handler
++EXPORT_SYMBOL vmlinux 0x39a21124	vme_dma_request
++EXPORT_SYMBOL vmlinux 0x39a82f43	__netif_schedule
++EXPORT_SYMBOL vmlinux 0x39ac4fd9	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39cc4c53	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0x39d4012e	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x39e49bb8	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x39f1c2f4	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x39f22b58	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0x39fcd9ec	put_cmsg
++EXPORT_SYMBOL vmlinux 0x3a08475f	platform_thermal_notify
++EXPORT_SYMBOL vmlinux 0x3a1ac054	set_normalized_timespec64
++EXPORT_SYMBOL vmlinux 0x3a20db6f	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0x3a21780a	commit_creds
++EXPORT_SYMBOL vmlinux 0x3a32839e	intel_gtt_chipset_flush
++EXPORT_SYMBOL vmlinux 0x3a472478	finish_no_open
++EXPORT_SYMBOL vmlinux 0x3a5cb3f2	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x3a6916a3	security_path_rename
++EXPORT_SYMBOL vmlinux 0x3a703674	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x3a927275	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0x3a97febb	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3aa2389b	fget_raw
++EXPORT_SYMBOL vmlinux 0x3ad421a3	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0x3ae008f4	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x3ae64250	agp_generic_alloc_pages
++EXPORT_SYMBOL vmlinux 0x3aef3dc0	bdput
++EXPORT_SYMBOL vmlinux 0x3af5f422	fget
++EXPORT_SYMBOL vmlinux 0x3afaf6d1	dquot_destroy
++EXPORT_SYMBOL vmlinux 0x3b201620	machine_real_restart
++EXPORT_SYMBOL vmlinux 0x3b29ad48	fb_set_var
++EXPORT_SYMBOL vmlinux 0x3b49fc35	simple_statfs
++EXPORT_SYMBOL vmlinux 0x3b55369e	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0x3b5f99ad	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b68f1d4	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0x3b69619a	to_nd_btt
++EXPORT_SYMBOL vmlinux 0x3b6f6cd2	udp_table
++EXPORT_SYMBOL vmlinux 0x3b85ccc4	seq_release
++EXPORT_SYMBOL vmlinux 0x3b8fe8b8	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0x3bb5114a	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x3bc7ae59	mutex_lock
++EXPORT_SYMBOL vmlinux 0x3bd408a8	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0x3be3d575	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0x3c12b480	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x3c2a59f9	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0x3c2e774c	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0x3c390db6	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c497425	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0x3c4ed157	dcb_setapp
++EXPORT_SYMBOL vmlinux 0x3c55de3c	nvm_end_io
++EXPORT_SYMBOL vmlinux 0x3c5ff3e4	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0x3c6dff47	param_ops_short
++EXPORT_SYMBOL vmlinux 0x3c7113b7	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x3c7fe877	dev_load
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c8daa6c	simple_lookup
++EXPORT_SYMBOL vmlinux 0x3c90b922	keyring_clear
++EXPORT_SYMBOL vmlinux 0x3cb3931b	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3cf7252a	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0x3d03dde2	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x3d1391e2	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x3d2c6949	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0x3d3c12ee	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0x3d7c1ed7	msrs_alloc
++EXPORT_SYMBOL vmlinux 0x3d812981	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0x3d82f064	key_type_keyring
++EXPORT_SYMBOL vmlinux 0x3d9a0a27	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x3da171f9	pci_mem_start
++EXPORT_SYMBOL vmlinux 0x3da19c2c	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x3dbe6fca	__lock_page
++EXPORT_SYMBOL vmlinux 0x3dc8b0b1	padata_stop
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3defb53b	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e01411d	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x3e0d6452	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0x3e2ae3a8	acpi_release_global_lock
++EXPORT_SYMBOL vmlinux 0x3e560f34	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x3e654f49	acpi_decode_pld_buffer
++EXPORT_SYMBOL vmlinux 0x3e72622e	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x3e882943	pcibios_align_resource
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x3e9cbafd	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x3eb9d154	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x3ef4e9ce	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0x3ef78d80	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x3eff5ac2	intel_scu_ipc_writev
++EXPORT_SYMBOL vmlinux 0x3f0546a8	ioread32_rep
++EXPORT_SYMBOL vmlinux 0x3f098cca	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0x3f1602c7	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x3f19a2c3	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x3f20ca97	rtc_lock
++EXPORT_SYMBOL vmlinux 0x3f28499a	netif_skb_features
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f56b24a	inet6_bind
++EXPORT_SYMBOL vmlinux 0x3f616ce2	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x3fb69f35	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x3fbaecdd	nf_afinfo
++EXPORT_SYMBOL vmlinux 0x3fc7f14b	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x3fdddbe7	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x40140a06	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4039918a	clk_register_clkdev
++EXPORT_SYMBOL vmlinux 0x403bb5e3	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0x40466619	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0x4050ca12	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0x4059792f	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x405ba341	mount_nodev
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x4086be80	vme_bus_num
++EXPORT_SYMBOL vmlinux 0x408fe2e5	__getblk_slow
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x4097fa45	acpi_read_bit_register
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a2d1dd	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x40a34dfd	nd_device_register
++EXPORT_SYMBOL vmlinux 0x40a410e0	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x40a6ad7d	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40b38fda	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40c89d46	acpi_get_table_by_index
++EXPORT_SYMBOL vmlinux 0x40c8bf77	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x4113aaf1	acpi_match_device_ids
++EXPORT_SYMBOL vmlinux 0x412851ee	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0x4135aa78	vga_switcheroo_register_handler
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x415a24b6	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x4162b91d	ht_create_irq
++EXPORT_SYMBOL vmlinux 0x4164dab1	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0x416fd5e9	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0x417854cd	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x41862ad4	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x418a5367	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x41af0ed9	__ht_create_irq
++EXPORT_SYMBOL vmlinux 0x41c831ae	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0x41d85b31	cdev_add
++EXPORT_SYMBOL vmlinux 0x4209cdc7	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x421817ea	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x42350e8d	ucs2_strlen
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x424f6b9f	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x42595e58	vgacon_text_force
++EXPORT_SYMBOL vmlinux 0x4259e65d	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x428282f6	dma_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x4291a781	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0x4292364c	schedule
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42a7dc1a	param_get_ullong
++EXPORT_SYMBOL vmlinux 0x42ba0f20	netdev_printk
++EXPORT_SYMBOL vmlinux 0x42c1148a	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0x42c8de35	ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x42ed632f	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0x42ff47dc	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x4340a3ea	amd_northbridges
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x436c2179	iowrite32
++EXPORT_SYMBOL vmlinux 0x4381202d	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x439ca15f	genl_notify
++EXPORT_SYMBOL vmlinux 0x43a87851	__inet_hash
++EXPORT_SYMBOL vmlinux 0x43d48036	inet_getname
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x43f979f6	dev_add_offload
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x4427f74c	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x442a334b	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0x442a6cec	noop_llseek
++EXPORT_SYMBOL vmlinux 0x442cc112	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0x44366cfc	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0x44438b96	hex2bin
++EXPORT_SYMBOL vmlinux 0x44600d2e	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0x4462cdf6	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x4467c706	param_ops_long
++EXPORT_SYMBOL vmlinux 0x44772850	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0x448e085f	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x4490e149	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0x449fe84b	acpi_set_firmware_waking_vectors
++EXPORT_SYMBOL vmlinux 0x44a068a3	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0x44a27214	path_put
++EXPORT_SYMBOL vmlinux 0x44aaf30f	tsc_khz
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44cc830d	kthread_stop
++EXPORT_SYMBOL vmlinux 0x44da87a9	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0x44dbd88e	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x44dd8e5b	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x45081703	ec_get_handle
++EXPORT_SYMBOL vmlinux 0x45163e66	kernel_connect
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x453d979a	write_cache_pages
++EXPORT_SYMBOL vmlinux 0x455070b2	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0x45631f04	kunmap_high
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x45849218	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0x45a6fb85	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45e8a32b	scsi_print_result
++EXPORT_SYMBOL vmlinux 0x45eb68a6	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0x45f65c18	noop_fsync
++EXPORT_SYMBOL vmlinux 0x45ffcf8b	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0x4629334c	__preempt_count
++EXPORT_SYMBOL vmlinux 0x462a2e75	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x46677180	simple_readpage
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x46b56013	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x46b704c6	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x46bb101f	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x46d35cfa	mmc_free_host
++EXPORT_SYMBOL vmlinux 0x46f4788d	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x4701befc	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0x4706d678	param_set_ushort
++EXPORT_SYMBOL vmlinux 0x470dbc74	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x470fdbc3	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x4731f866	udp_add_offload
++EXPORT_SYMBOL vmlinux 0x4740b3bc	xen_arch_unregister_cpu
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x474e995d	flow_cache_init
++EXPORT_SYMBOL vmlinux 0x47529fc5	pnp_unregister_card_driver
++EXPORT_SYMBOL vmlinux 0x475f010b	acpi_purge_cached_objects
++EXPORT_SYMBOL vmlinux 0x477b6542	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0x478d10b2	ht_destroy_irq
++EXPORT_SYMBOL vmlinux 0x478f0224	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0x4790c485	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x4794af5d	tcp_close
++EXPORT_SYMBOL vmlinux 0x4795b264	kmap_high
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x47d30fae	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0x47f00082	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x47f9bfd8	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0x48011464	set_cached_acl
++EXPORT_SYMBOL vmlinux 0x48193639	acpi_lid_open
++EXPORT_SYMBOL vmlinux 0x481cb9ab	acpi_enter_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x482a694f	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x482ace52	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x482cf89d	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x4830c43b	__inode_permission
++EXPORT_SYMBOL vmlinux 0x48576585	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0x4857ad90	agp3_generic_tlbflush
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x48851be5	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0x488b196c	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0x4895d7b4	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x489c78be	scsi_init_io
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48c35ea6	agp_unbind_memory
++EXPORT_SYMBOL vmlinux 0x48e5aefc	find_vma
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x490def45	vga_switcheroo_register_client
++EXPORT_SYMBOL vmlinux 0x4918d880	dquot_acquire
++EXPORT_SYMBOL vmlinux 0x493f49fe	set_pages_array_wb
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x499267bd	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b163b8	acpi_bus_scan
++EXPORT_SYMBOL vmlinux 0x49c018e5	devm_clk_put
++EXPORT_SYMBOL vmlinux 0x49c8b3b8	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x49cb04ff	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x49dd08ef	nd_device_unregister
++EXPORT_SYMBOL vmlinux 0x49f08cfb	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0x49f36dd2	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x4a0bf33a	blk_complete_request
++EXPORT_SYMBOL vmlinux 0x4a0e275a	ping_prot
++EXPORT_SYMBOL vmlinux 0x4a18f74d	contig_page_data
++EXPORT_SYMBOL vmlinux 0x4a36ef92	file_path
++EXPORT_SYMBOL vmlinux 0x4a44dcb4	irq_to_desc
++EXPORT_SYMBOL vmlinux 0x4a54a8ef	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0x4a619f83	memcpy
++EXPORT_SYMBOL vmlinux 0x4a7aa2d0	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x4a819139	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x4a84e8e0	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x4a93bd5d	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0x4a9f0099	freeze_super
++EXPORT_SYMBOL vmlinux 0x4aa75766	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x4aaa6e5a	rt6_lookup
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b085dbf	agp3_generic_configure
++EXPORT_SYMBOL vmlinux 0x4b1b2beb	acpi_bus_get_status
++EXPORT_SYMBOL vmlinux 0x4b1ec3e2	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x4b2e402d	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0x4b3c0f71	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x4b3dff27	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0x4b4cb14d	put_io_context
++EXPORT_SYMBOL vmlinux 0x4b5a6f50	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0x4b5b4f9b	revalidate_disk
++EXPORT_SYMBOL vmlinux 0x4b5c3c67	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b667176	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0x4b7eb28b	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0x4b87c5b6	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0x4b9dfb04	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0x4b9e8799	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4bc29c96	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x4bcf03a4	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x4be85a03	memweight
++EXPORT_SYMBOL vmlinux 0x4bf2f302	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x4c07a7e0	acpi_processor_unregister_performance
++EXPORT_SYMBOL vmlinux 0x4c0889b5	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x4c29dcbf	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x4c29f577	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x4c29f784	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x4c2ae700	strnstr
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c6e4faf	dma_find_channel
++EXPORT_SYMBOL vmlinux 0x4c878322	iosf_mbi_modify
++EXPORT_SYMBOL vmlinux 0x4c8fb1a8	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0x4c926afb	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x4ca94b36	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x4cab6ca8	con_is_bound
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4cf35974	ns_capable
++EXPORT_SYMBOL vmlinux 0x4d3c153f	sigprocmask
++EXPORT_SYMBOL vmlinux 0x4d45d89e	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x4d52336e	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4dc34f72	path_nosuid
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4e2084c6	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0x4e237ed9	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e3781d4	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x4e3b1170	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0x4e3f9cbc	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0x4e422a49	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x4e68c4a9	param_set_long
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e8439b9	vfs_link
++EXPORT_SYMBOL vmlinux 0x4ea25709	dql_reset
++EXPORT_SYMBOL vmlinux 0x4ee9a77a	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0x4f0b771b	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f26ac28	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x4f317041	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f46b4f2	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f6041ef	dns_query
++EXPORT_SYMBOL vmlinux 0x4f639222	find_get_entry
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f6b400b	_copy_from_user
++EXPORT_SYMBOL vmlinux 0x4f6fe896	inet_frags_init
++EXPORT_SYMBOL vmlinux 0x4f7696c3	console_stop
++EXPORT_SYMBOL vmlinux 0x4f783f30	acpi_read
++EXPORT_SYMBOL vmlinux 0x4f8b5ddb	_copy_to_user
++EXPORT_SYMBOL vmlinux 0x4f93d7bc	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0x4f9703cf	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x4f9c4d75	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0x4fa4665c	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0x4fb30eb1	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x4fb6140d	register_netdevice
++EXPORT_SYMBOL vmlinux 0x4fbea81a	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0x4fdee897	i8042_command
++EXPORT_SYMBOL vmlinux 0x4ffbfe8a	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0x5007f027	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x5011ae68	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x5011e39b	seq_path
++EXPORT_SYMBOL vmlinux 0x5017e049	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0x5021813e	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0x503533a3	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0x504430d4	fb_pan_display
++EXPORT_SYMBOL vmlinux 0x50529870	acpi_get_gpe_status
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x5065954e	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0x50676314	inet_offloads
++EXPORT_SYMBOL vmlinux 0x5079d1d4	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0x507f0160	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0x5089ea48	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0x509b64ea	acpi_has_method
++EXPORT_SYMBOL vmlinux 0x509deb90	key_link
++EXPORT_SYMBOL vmlinux 0x50adcd6b	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0x50b0ebdb	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0x50b66bcb	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x50b7f245	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x50b9b522	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0x50c2f0f2	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x50d68377	arch_phys_wc_del
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x50eedeb8	printk
++EXPORT_SYMBOL vmlinux 0x510c015d	icmpv6_send
++EXPORT_SYMBOL vmlinux 0x5114590d	skb_append
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x51354509	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0x5158739d	kern_path
++EXPORT_SYMBOL vmlinux 0x51654e8a	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x51719973	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x5186518f	profile_pc
++EXPORT_SYMBOL vmlinux 0x51d12d4e	acpi_pci_disabled
++EXPORT_SYMBOL vmlinux 0x51ef33b8	kstrndup
++EXPORT_SYMBOL vmlinux 0x51fa3fa2	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x52095e19	acpi_get_data
++EXPORT_SYMBOL vmlinux 0x520a73f7	d_tmpfile
++EXPORT_SYMBOL vmlinux 0x5213ae47	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x525e026f	acpi_os_unmap_generic_address
++EXPORT_SYMBOL vmlinux 0x52659d10	security_path_symlink
++EXPORT_SYMBOL vmlinux 0x52677c08	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0x526fcdfc	sock_from_file
++EXPORT_SYMBOL vmlinux 0x527130e2	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x527c0b35	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0x528c709d	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x529c8bba	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x52af562a	__crc32c_le
++EXPORT_SYMBOL vmlinux 0x52b5661c	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0x52e25a53	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x52f57dc9	follow_down
++EXPORT_SYMBOL vmlinux 0x530b1e4c	rdmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x530c3916	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x530f95a5	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0x531b604e	__virt_addr_valid
++EXPORT_SYMBOL vmlinux 0x531e31dd	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0x5322a790	blk_queue_split
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x53329fbb	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x534b2f65	nd_iostat_end
++EXPORT_SYMBOL vmlinux 0x5355cd2d	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0x53569707	this_cpu_off
++EXPORT_SYMBOL vmlinux 0x5356b2ff	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x535cfc11	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0x5360d394	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x539af73c	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x53acbed3	skb_put
++EXPORT_SYMBOL vmlinux 0x53c646be	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0x53c7d57f	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0x53cce8cd	request_key
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x54244052	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x543d8335	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x544b0c11	acpi_lid_notifier_register
++EXPORT_SYMBOL vmlinux 0x5464d3f6	acpi_remove_sci_handler
++EXPORT_SYMBOL vmlinux 0x54717604	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0x548cd358	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0x54905a42	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x5491a0ba	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54ba04c4	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0x54be2259	mount_ns
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54d9cd9f	ilookup
++EXPORT_SYMBOL vmlinux 0x54dc252f	path_noexec
++EXPORT_SYMBOL vmlinux 0x54df5974	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x54e4f079	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54ecb3e2	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x54f24d1a	fence_default_wait
++EXPORT_SYMBOL vmlinux 0x54fe3be4	touch_atime
++EXPORT_SYMBOL vmlinux 0x5512d6df	proc_symlink
++EXPORT_SYMBOL vmlinux 0x551338df	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x551bedc7	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x5552f205	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x55533b9d	sock_wake_async
++EXPORT_SYMBOL vmlinux 0x5561b842	backlight_force_update
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x556ef673	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0x557aae38	acpi_bus_unregister_driver
++EXPORT_SYMBOL vmlinux 0x55879874	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x558c3fee	agp_generic_create_gatt_table
++EXPORT_SYMBOL vmlinux 0x5593d15e	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x559fce34	kobject_put
++EXPORT_SYMBOL vmlinux 0x55a2342c	mmc_release_host
++EXPORT_SYMBOL vmlinux 0x55bd7c84	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x55d961e2	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0x55de79e1	nobh_write_end
++EXPORT_SYMBOL vmlinux 0x55e60a36	queued_spin_unlock_wait
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x563952a3	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x563e08ca	blk_get_request
++EXPORT_SYMBOL vmlinux 0x5641419b	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0x56434345	build_skb
++EXPORT_SYMBOL vmlinux 0x5676a3e5	intel_scu_ipc_ioread8
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x56999504	sync_inode
++EXPORT_SYMBOL vmlinux 0x56b586dc	__blk_end_request
++EXPORT_SYMBOL vmlinux 0x56ba61f2	set_pages_array_uc
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56f6d621	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0x56fc1cf3	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0x5701a98d	mem_map
++EXPORT_SYMBOL vmlinux 0x5705088a	__vmalloc
++EXPORT_SYMBOL vmlinux 0x5706637e	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x571c8ea9	dma_mmap_from_coherent
++EXPORT_SYMBOL vmlinux 0x571cc60b	md_flush_request
++EXPORT_SYMBOL vmlinux 0x572497b1	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x5733f61f	dmam_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x574545e2	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0x574937b1	current_task
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x5759667b	try_module_get
++EXPORT_SYMBOL vmlinux 0x575af70c	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x57803942	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0x579f3248	file_remove_privs
++EXPORT_SYMBOL vmlinux 0x579fbcd2	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0x57b30f3a	read_cache_pages
++EXPORT_SYMBOL vmlinux 0x57ba72ab	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0x57c51a6b	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x58322492	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x584738f9	rdmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x5849ac57	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0x584d6304	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0x5857b225	ioread16_rep
++EXPORT_SYMBOL vmlinux 0x58604e4d	alloc_iova_mem
++EXPORT_SYMBOL vmlinux 0x586103be	acpi_setup_gpe_for_wake
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x58fef6f8	ist_info
++EXPORT_SYMBOL vmlinux 0x5905d860	vm_stat
++EXPORT_SYMBOL vmlinux 0x592717b7	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x5928042a	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0x5944d015	__cachemode2pte_tbl
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x594e22f8	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x5954bfbb	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0x5963fe71	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x5964a507	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0x597c02b4	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59ab1623	dev_alert
++EXPORT_SYMBOL vmlinux 0x59af06f9	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0x59b0d85c	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0x59b2d91e	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x59bc9609	acpi_write_bit_register
++EXPORT_SYMBOL vmlinux 0x59c0baa9	tc_classify
++EXPORT_SYMBOL vmlinux 0x59cf2a26	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x59e66ea3	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0x59e8f569	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0x59eb294d	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x59f200bd	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a10f8db	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0x5a201c21	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0x5a2a7961	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x5a3aafd0	ether_setup
++EXPORT_SYMBOL vmlinux 0x5a4896a8	__put_user_2
++EXPORT_SYMBOL vmlinux 0x5a4c9d3f	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0x5a5ecf65	pnpacpi_protocol
++EXPORT_SYMBOL vmlinux 0x5a6184b0	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x5a685aa9	param_get_uint
++EXPORT_SYMBOL vmlinux 0x5a6c56fa	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0x5a82c44a	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x5aa38303	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0x5ac376a5	acpi_install_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x5ac900b3	agp_backend_release
++EXPORT_SYMBOL vmlinux 0x5ace80b7	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x5ad67fed	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0x5ad80a24	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0x5af487c3	seq_puts
++EXPORT_SYMBOL vmlinux 0x5af5fdd6	update_region
++EXPORT_SYMBOL vmlinux 0x5af6d1c5	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0x5afef6a7	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5b0a7da6	sget
++EXPORT_SYMBOL vmlinux 0x5b0b3635	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x5b117a7f	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x5b19634d	div_s64_rem
++EXPORT_SYMBOL vmlinux 0x5b28d4c4	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0x5b2ac96c	agp_generic_type_to_mask_type
++EXPORT_SYMBOL vmlinux 0x5b2d78a5	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0x5b40f6d2	twl6040_power
++EXPORT_SYMBOL vmlinux 0x5b44e39f	open_exec
++EXPORT_SYMBOL vmlinux 0x5b4fa1bf	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0x5b5ee7da	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0x5b8871b3	keyring_search
++EXPORT_SYMBOL vmlinux 0x5b8cc252	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x5b8d390b	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x5bba1c45	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0x5bbbe152	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0x5bc8d583	copy_from_user_overflow
++EXPORT_SYMBOL vmlinux 0x5bd48a5c	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0x5bdfc162	do_splice_to
++EXPORT_SYMBOL vmlinux 0x5bf42552	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x5c00bc64	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0x5c0442fd	acpi_gbl_FADT
++EXPORT_SYMBOL vmlinux 0x5c0a9161	tcp_filter
++EXPORT_SYMBOL vmlinux 0x5c113377	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0x5c156b7c	security_path_unlink
++EXPORT_SYMBOL vmlinux 0x5c17d606	unlock_rename
++EXPORT_SYMBOL vmlinux 0x5c253462	neigh_table_init
++EXPORT_SYMBOL vmlinux 0x5c2d7f0f	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0x5c30c8be	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0x5c487ceb	agp_backend_acquire
++EXPORT_SYMBOL vmlinux 0x5c527544	dev_set_group
++EXPORT_SYMBOL vmlinux 0x5c545234	ucs2_strncmp
++EXPORT_SYMBOL vmlinux 0x5c9dd541	dquot_resume
++EXPORT_SYMBOL vmlinux 0x5c9def53	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0x5cc65e13	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0x5cdb66a2	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x5cdcf53a	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0x5cee0d57	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5d051367	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x5d0d40b7	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x5d20ee97	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0x5d2e0057	x86_hyper_ms_hyperv
++EXPORT_SYMBOL vmlinux 0x5d3a04bc	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0x5d46ef71	deactivate_super
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d5b3f7e	vme_slot_num
++EXPORT_SYMBOL vmlinux 0x5d65c7ca	datagram_poll
++EXPORT_SYMBOL vmlinux 0x5d74dbcf	pnp_range_reserved
++EXPORT_SYMBOL vmlinux 0x5d8475e0	completion_done
++EXPORT_SYMBOL vmlinux 0x5db77d4d	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0x5dbb2936	acpi_device_set_power
++EXPORT_SYMBOL vmlinux 0x5dc0a39d	dquot_commit
++EXPORT_SYMBOL vmlinux 0x5dc3a827	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0x5dc5ad0a	__sb_end_write
++EXPORT_SYMBOL vmlinux 0x5dce56ee	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x5dd9e14f	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x5df70b31	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x5dffb9b0	x86_hyper_vmware
++EXPORT_SYMBOL vmlinux 0x5e1fa775	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0x5e284106	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x5e417e44	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x5e717f5a	acpi_bus_get_device
++EXPORT_SYMBOL vmlinux 0x5e866d85	prandom_bytes
++EXPORT_SYMBOL vmlinux 0x5e88c0a5	blk_finish_request
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5e99f367	component_match_add
++EXPORT_SYMBOL vmlinux 0x5e9b4838	scmd_printk
++EXPORT_SYMBOL vmlinux 0x5ea95c59	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5ed79417	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0x5ed975e5	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f1a4ccf	intel_scu_ipc_update_register
++EXPORT_SYMBOL vmlinux 0x5f7cc239	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0x5f814c65	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0x5f84aa62	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0x5faa8b55	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x5fb2e8ef	idr_init
++EXPORT_SYMBOL vmlinux 0x5fb9c441	__register_nls
++EXPORT_SYMBOL vmlinux 0x5fced5f0	tty_port_put
++EXPORT_SYMBOL vmlinux 0x5fd268cb	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0x5fd77597	set_pages_uc
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x5fdbcfb9	d_make_root
++EXPORT_SYMBOL vmlinux 0x5fee46f6	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x5fef8c23	get_user_pages
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x600bccde	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x60260e65	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0x602ed00d	acpi_current_gpe_count
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x604316d8	acpi_finish_gpe
++EXPORT_SYMBOL vmlinux 0x604cca46	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0x606b7530	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x609b4384	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL vmlinux 0x60b480f6	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x60b48457	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0x60b86f61	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x60d72e80	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0x60dcfbbd	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x60fd2a74	agp_free_memory
++EXPORT_SYMBOL vmlinux 0x610aaa40	mempool_destroy
++EXPORT_SYMBOL vmlinux 0x610c3b74	iput
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x61396292	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x618cd077	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x619fd45e	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0x61ab417a	free_task
++EXPORT_SYMBOL vmlinux 0x61b3560c	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x61b676ee	agp_bind_memory
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61b8df09	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0x61ca19d3	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x61d13a42	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x61d809ae	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x61fa5736	set_blocksize
++EXPORT_SYMBOL vmlinux 0x62049256	acpi_disable
++EXPORT_SYMBOL vmlinux 0x62090140	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x621b95d5	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0x6220b4a2	crc32_le
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6226b9fa	machine_to_phys_mapping
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x622a9f0c	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0x6237f6b5	acpi_enable_event
++EXPORT_SYMBOL vmlinux 0x6241a2ab	__copy_from_user_ll_nocache
++EXPORT_SYMBOL vmlinux 0x624737bb	i8042_install_filter
++EXPORT_SYMBOL vmlinux 0x625c75ec	get_empty_filp
++EXPORT_SYMBOL vmlinux 0x625d379b	inet6_offloads
++EXPORT_SYMBOL vmlinux 0x6262c412	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x6270d948	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x6294fdb3	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x629d2ebc	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x629d3587	agp_copy_info
++EXPORT_SYMBOL vmlinux 0x62a2aa43	bdget_disk
++EXPORT_SYMBOL vmlinux 0x62add46e	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x62e24ddb	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0x6308ee55	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x631aa17d	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0x631dc3c3	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x6331744a	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x636a5691	acpi_register_ioapic
++EXPORT_SYMBOL vmlinux 0x63721516	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0x637a5879	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x6383530c	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0x6388591c	down_timeout
++EXPORT_SYMBOL vmlinux 0x638b25f9	netif_napi_add
++EXPORT_SYMBOL vmlinux 0x638cccd5	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x63907ca4	nd_btt_arena_is_valid
++EXPORT_SYMBOL vmlinux 0x63a01291	acpi_leave_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x63a1b548	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63cd51ae	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0x63d57a95	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x63e4e79e	acpi_bus_register_driver
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63eeef4a	tcp_child_process
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x640ba484	send_sig_info
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x64170d27	param_get_string
++EXPORT_SYMBOL vmlinux 0x6418a37f	complete_request_key
++EXPORT_SYMBOL vmlinux 0x64194b4e	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0x641f032f	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0x641f24ff	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0x64233278	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0x643fc055	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x6449fd41	acpi_install_address_space_handler
++EXPORT_SYMBOL vmlinux 0x646dbce7	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x649e3310	km_state_expired
++EXPORT_SYMBOL vmlinux 0x64a4b84d	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x64ab0e98	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x64b400c8	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0x64b533fa	agp_generic_alloc_page
++EXPORT_SYMBOL vmlinux 0x64e65240	sync_filesystem
++EXPORT_SYMBOL vmlinux 0x64eae7ad	set_memory_array_wb
++EXPORT_SYMBOL vmlinux 0x64fa7693	__acpi_handle_debug
++EXPORT_SYMBOL vmlinux 0x650178f3	dquot_drop
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x65216eea	inode_init_owner
++EXPORT_SYMBOL vmlinux 0x6525c4f6	dentry_open
++EXPORT_SYMBOL vmlinux 0x6537a1a5	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x654b8ad1	sk_wait_data
++EXPORT_SYMBOL vmlinux 0x654dff6c	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x655f1ab0	set_memory_array_wc
++EXPORT_SYMBOL vmlinux 0x6565d33f	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x6571adc7	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x65804491	request_key_async
++EXPORT_SYMBOL vmlinux 0x659d8b10	__lock_buffer
++EXPORT_SYMBOL vmlinux 0x659e1fd1	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0x65a295bb	atomic64_xchg_cx8
++EXPORT_SYMBOL vmlinux 0x65b992ac	xen_alloc_p2m_entry
++EXPORT_SYMBOL vmlinux 0x65c2d0d4	md_reload_sb
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65e2f7c5	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x6621d9fb	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x662df26c	set_security_override
++EXPORT_SYMBOL vmlinux 0x6632ca35	xfrm_input
++EXPORT_SYMBOL vmlinux 0x66355efc	vprintk
++EXPORT_SYMBOL vmlinux 0x663f7cd0	acpi_install_table_handler
++EXPORT_SYMBOL vmlinux 0x667e4e80	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x669bf80b	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x66b603aa	km_is_alive
++EXPORT_SYMBOL vmlinux 0x66c8a0d9	make_kuid
++EXPORT_SYMBOL vmlinux 0x66d804b1	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x6702b610	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0x670f3989	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x6729d3df	__get_user_4
++EXPORT_SYMBOL vmlinux 0x673f815e	agp_bridges
++EXPORT_SYMBOL vmlinux 0x67485206	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x6753c251	set_pages_x
++EXPORT_SYMBOL vmlinux 0x675bed91	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x67655eee	__vfs_read
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x678a0bf8	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x67936b72	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0x67a2a6e6	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67c86072	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0x67cd4a12	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0x67e01c9c	fb_blank
++EXPORT_SYMBOL vmlinux 0x67e3461e	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x67fabb9b	make_kgid
++EXPORT_SYMBOL vmlinux 0x68018f84	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x680ec266	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x6831e403	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x6834ccc1	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0x683bb9cc	filemap_flush
++EXPORT_SYMBOL vmlinux 0x68431299	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0x68512eec	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0x685ae751	sock_efree
++EXPORT_SYMBOL vmlinux 0x68632863	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x6897c802	processors
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68c00e2a	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0x68c96d3b	serio_open
++EXPORT_SYMBOL vmlinux 0x68d5b35d	icmp_send
++EXPORT_SYMBOL vmlinux 0x68d73d9e	free_page_put_link
++EXPORT_SYMBOL vmlinux 0x69056b79	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x691001b5	acpi_evaluate_integer
++EXPORT_SYMBOL vmlinux 0x69152a97	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x69195328	tso_build_data
++EXPORT_SYMBOL vmlinux 0x691b86de	pci_map_rom
++EXPORT_SYMBOL vmlinux 0x69620690	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0x69644895	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x69666e2f	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0x69684b64	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0x696a272d	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x69759c81	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0x6988d0ca	cpu_dr7
++EXPORT_SYMBOL vmlinux 0x698f66ec	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x69a0ca7d	iowrite16be
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69b0cefc	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0x69cea9b8	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x69dae755	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0x69ebd8e7	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x69ec219f	new_inode
++EXPORT_SYMBOL vmlinux 0x69fd2a05	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a27bfce	csum_partial_copy_generic
++EXPORT_SYMBOL vmlinux 0x6a298f6b	generic_perform_write
++EXPORT_SYMBOL vmlinux 0x6a2baf6f	dst_destroy
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a60277d	acpi_buffer_to_resource
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a8da28f	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0x6ab79948	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0x6abaa218	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6acb973d	iowrite32be
++EXPORT_SYMBOL vmlinux 0x6ad43b21	dev_close
++EXPORT_SYMBOL vmlinux 0x6ad85887	acpi_enable_gpe
++EXPORT_SYMBOL vmlinux 0x6add5c9a	dmi_find_device
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6afba7a2	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0x6b063264	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b092121	kmap_to_page
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2ef042	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x6b35dacd	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x6b599591	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x6b67a11c	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0x6b74b9be	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0x6b863697	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x6b8abc8b	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0x6bb5a639	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bc84f50	path_is_under
++EXPORT_SYMBOL vmlinux 0x6bcbdd37	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0x6bcf066d	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6bf1c17f	pv_lock_ops
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c1624a5	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0x6c1ce5ce	strcspn
++EXPORT_SYMBOL vmlinux 0x6c1dc0e7	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x6c2acfd6	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0x6c2e3320	strncmp
++EXPORT_SYMBOL vmlinux 0x6c2e9e26	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x6c393d6a	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c7079b0	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x6c7218ea	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0x6c7c65b3	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0x6cb1dd51	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0x6cb6a9c4	mount_single
++EXPORT_SYMBOL vmlinux 0x6cb8261d	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0x6cbed8e1	fs_bio_set
++EXPORT_SYMBOL vmlinux 0x6cc6d173	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x6cdc5c6b	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6cea04a6	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d132cbb	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x6d1d5d9b	iosf_mbi_write
++EXPORT_SYMBOL vmlinux 0x6d278b43	__bforget
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d334118	__get_user_8
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d5342f0	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x6d571757	generic_setlease
++EXPORT_SYMBOL vmlinux 0x6d688032	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0x6d7c9b7e	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0x6d94a130	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0x6da7375b	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x6dac24fc	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x6dc0c9dc	down_interruptible
++EXPORT_SYMBOL vmlinux 0x6dc6dd56	down
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6e02e4b4	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x6e2d446c	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x6e3d0022	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x6e4be59d	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0x6e58b357	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x6e6514ed	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x6e710cf2	skb_push
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e76917a	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0x6e7eb673	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6e9e538a	kernel_accept
++EXPORT_SYMBOL vmlinux 0x6eade59c	dm_register_target
++EXPORT_SYMBOL vmlinux 0x6ed28bc1	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x6edebaae	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0x6ef66e8a	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0x6efb2df1	account_page_redirty
++EXPORT_SYMBOL vmlinux 0x6f0b5e2d	pci_set_master
++EXPORT_SYMBOL vmlinux 0x6f1bf786	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f2e4f46	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0x6f42a26a	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0x6f4e4e3b	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0x6f51805f	vfs_writev
++EXPORT_SYMBOL vmlinux 0x6f556bdb	acpi_get_gpe_device
++EXPORT_SYMBOL vmlinux 0x6f6ced07	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x6f86d841	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6f92bcd3	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x6fa77580	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6fd2284c	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x6fdcf471	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x6feb2039	acpi_write
++EXPORT_SYMBOL vmlinux 0x7023bea8	unregister_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x7029f11b	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0x7029f4fb	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7054a3e4	request_dma
++EXPORT_SYMBOL vmlinux 0x70588e9e	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0x7062b4cd	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x706eed66	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x70716f9e	block_read_full_page
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x7086e473	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x7088ce72	printk_emit
++EXPORT_SYMBOL vmlinux 0x708a79f7	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x709d16f5	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0x70aeb700	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0x70be2a10	nf_log_unset
++EXPORT_SYMBOL vmlinux 0x70c32609	lro_flush_all
++EXPORT_SYMBOL vmlinux 0x70ce5c10	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x70d1f8f3	strncat
++EXPORT_SYMBOL vmlinux 0x70d8ab82	acpi_acquire_global_lock
++EXPORT_SYMBOL vmlinux 0x70db7236	vfs_setpos
++EXPORT_SYMBOL vmlinux 0x70df7a4b	skb_clone
++EXPORT_SYMBOL vmlinux 0x70e51090	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0x70ea8058	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x70fa8958	bio_add_page
++EXPORT_SYMBOL vmlinux 0x70fbe08b	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0x7102b930	register_filesystem
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x712ed37b	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x714886da	kobject_init
++EXPORT_SYMBOL vmlinux 0x71499448	agp_generic_free_gatt_table
++EXPORT_SYMBOL vmlinux 0x715b038d	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x7195aaac	d_drop
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71be74c9	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x71c23196	inet6_release
++EXPORT_SYMBOL vmlinux 0x71f65175	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x71fa2ad5	phy_device_remove
++EXPORT_SYMBOL vmlinux 0x71fae4d2	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x7200110a	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x7200c3c8	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0x7224698e	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x724a1a6c	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0x724f8d19	block_write_full_page
++EXPORT_SYMBOL vmlinux 0x7255d63e	alloc_disk
++EXPORT_SYMBOL vmlinux 0x7294b8fa	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0x72b243d4	free_dma
++EXPORT_SYMBOL vmlinux 0x72c64733	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x72c726b5	consume_skb
++EXPORT_SYMBOL vmlinux 0x72d58de9	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x72d5df07	generic_fillattr
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x72ff94b6	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x731943a6	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x731c0dc3	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0x73366506	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x735a0bd5	native_io_delay
++EXPORT_SYMBOL vmlinux 0x7368b99e	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x7383f3ce	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0x738714db	ida_pre_get
++EXPORT_SYMBOL vmlinux 0x738803e6	strnlen
++EXPORT_SYMBOL vmlinux 0x739c99a3	__nd_driver_register
++EXPORT_SYMBOL vmlinux 0x73bd93fc	d_find_alias
++EXPORT_SYMBOL vmlinux 0x73d49cbf	phy_device_free
++EXPORT_SYMBOL vmlinux 0x73db8dbe	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0x73dd54eb	irq_fpu_usable
++EXPORT_SYMBOL vmlinux 0x73e20c1c	strlcpy
++EXPORT_SYMBOL vmlinux 0x73e6d1fa	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x73fc93f8	dev_change_flags
++EXPORT_SYMBOL vmlinux 0x740a1b95	reserve_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x7413793a	EISA_bus
++EXPORT_SYMBOL vmlinux 0x7418fba0	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x7421627e	unregister_nls
++EXPORT_SYMBOL vmlinux 0x74224853	d_lookup
++EXPORT_SYMBOL vmlinux 0x743b4ae3	atomic64_inc_not_zero_cx8
++EXPORT_SYMBOL vmlinux 0x744a01be	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x745f20a3	idr_is_empty
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x74ba2a11	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x74c0e55f	iterate_fd
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74ca5ac5	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x74e5c98f	ucs2_strnlen
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74e92104	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0x7505bdef	memchr_inv
++EXPORT_SYMBOL vmlinux 0x75177d26	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x751bc9f0	simple_getattr
++EXPORT_SYMBOL vmlinux 0x75271716	save_processor_state
++EXPORT_SYMBOL vmlinux 0x7531e3dc	acpi_get_event_resources
++EXPORT_SYMBOL vmlinux 0x7538b132	agp_off
++EXPORT_SYMBOL vmlinux 0x753ef01b	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0x7547a386	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x75491632	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0x75511054	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0x7552739f	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0x75574c68	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0x75749369	bioset_create
++EXPORT_SYMBOL vmlinux 0x7593d385	div64_s64
++EXPORT_SYMBOL vmlinux 0x75b59e14	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x75bc549a	x86_cpu_to_apicid
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75d21809	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x75d93c4b	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0x75eb953a	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x75fb3401	__kernel_write
++EXPORT_SYMBOL vmlinux 0x75fbdefd	acpi_remove_address_space_handler
++EXPORT_SYMBOL vmlinux 0x76046269	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0x7607c40d	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x76127192	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0x761dc4d7	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x762add85	atomic64_inc_return_cx8
++EXPORT_SYMBOL vmlinux 0x762ff44a	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x763654b9	neigh_destroy
++EXPORT_SYMBOL vmlinux 0x763680d3	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x76479fe1	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x767ddb02	set_memory_wc
++EXPORT_SYMBOL vmlinux 0x767fda54	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x769e06d7	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x76ae215a	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x76c51d71	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x76c9448c	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0x76cbe59d	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76d4d98e	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x76d9bf11	crc32_be
++EXPORT_SYMBOL vmlinux 0x76f40a90	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x76f6c5ef	kmalloc_order
++EXPORT_SYMBOL vmlinux 0x76ff6592	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0x770a0036	isapnp_cfg_begin
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x77456e0a	acpi_root_dir
++EXPORT_SYMBOL vmlinux 0x774b19b7	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x77513494	netif_rx
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77a4870c	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0x77a6f917	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77c5600b	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0x77de55c9	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x77effdf2	kernel_read
++EXPORT_SYMBOL vmlinux 0x7801adee	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0x780fdfd1	intel_enable_gtt
++EXPORT_SYMBOL vmlinux 0x7818ff00	proc_douintvec
++EXPORT_SYMBOL vmlinux 0x7820295e	get_io_context
++EXPORT_SYMBOL vmlinux 0x782567ec	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x7831c24d	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0x78362427	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x783b977a	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0x7865c311	vga_tryget
++EXPORT_SYMBOL vmlinux 0x786ee510	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x7880dd69	phy_find_first
++EXPORT_SYMBOL vmlinux 0x788aae76	nvdimm_namespace_disk_name
++EXPORT_SYMBOL vmlinux 0x788b0523	simple_open
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x789c7b51	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x78a5ff8a	fence_add_callback
++EXPORT_SYMBOL vmlinux 0x78b6ba33	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78e739aa	up
++EXPORT_SYMBOL vmlinux 0x78f63a25	cad_pid
++EXPORT_SYMBOL vmlinux 0x78ff0f7b	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0x7901b4f2	bio_map_kern
++EXPORT_SYMBOL vmlinux 0x79068fda	acpi_install_method
++EXPORT_SYMBOL vmlinux 0x790aebd3	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0x791ed1c9	rename_lock
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x79882e06	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79bf1ce9	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x7a2add7d	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0x7a2af7b4	cpu_number
++EXPORT_SYMBOL vmlinux 0x7a2c6758	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0x7a356e5c	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a5371a0	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x7a82cb47	rdmsrl_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x7a86d214	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x7a8dab15	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x7a95e5ae	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7ab627de	dquot_disable
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ac24ca5	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x7acc2ed9	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0x7accce24	kobject_del
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7ad6981c	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0x7ad9a833	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0x7aec9089	clear_user
++EXPORT_SYMBOL vmlinux 0x7af48e5a	ps2_init
++EXPORT_SYMBOL vmlinux 0x7afa89fc	vsnprintf
++EXPORT_SYMBOL vmlinux 0x7afb3a3f	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0x7b11130a	padata_free
++EXPORT_SYMBOL vmlinux 0x7b134ddf	acpi_get_name
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b19fce3	kmap_atomic
++EXPORT_SYMBOL vmlinux 0x7b1ade38	lz4_decompress
++EXPORT_SYMBOL vmlinux 0x7b26c190	skb_checksum
++EXPORT_SYMBOL vmlinux 0x7b279e9e	bio_advance
++EXPORT_SYMBOL vmlinux 0x7b283ce3	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0x7b4e0ccb	put_filp
++EXPORT_SYMBOL vmlinux 0x7b52a859	wrmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x7b5c8440	vm_munmap
++EXPORT_SYMBOL vmlinux 0x7b62971d	tty_mutex
++EXPORT_SYMBOL vmlinux 0x7b767909	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x7b95c3d6	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x7bad7a1a	acpi_walk_resources
++EXPORT_SYMBOL vmlinux 0x7bd800e3	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x7be74eeb	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0x7be901e0	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0x7bf31d80	fd_install
++EXPORT_SYMBOL vmlinux 0x7bf79fe7	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0x7c10918c	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c179baa	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x7c22cb16	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x7c3fc5e6	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c5c558f	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c69f2c7	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0x7c84eaf1	pnp_get_resource
++EXPORT_SYMBOL vmlinux 0x7c891c08	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7caf2777	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cb3dd12	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x7cba2f6c	vfs_unlink
++EXPORT_SYMBOL vmlinux 0x7cbbdfc1	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x7cd27c1c	iterate_mounts
++EXPORT_SYMBOL vmlinux 0x7cdb6349	kern_unmount
++EXPORT_SYMBOL vmlinux 0x7ce01d0a	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7ce83365	acpi_remove_table_handler
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7d07606f	vga_client_register
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d1c0ba7	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0x7d295c8d	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0x7d31a696	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x7d344fc4	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0x7d51a527	add_disk
++EXPORT_SYMBOL vmlinux 0x7d5ff942	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d94f746	acpi_os_write_port
++EXPORT_SYMBOL vmlinux 0x7d96cea3	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x7db3fd28	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0x7dbc2e57	mmiotrace_printk
++EXPORT_SYMBOL vmlinux 0x7dc2c36a	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x7dc8603f	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x7dde9600	backlight_device_register
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7df80178	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0x7e42472b	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0x7e464bdb	pci_get_device
++EXPORT_SYMBOL vmlinux 0x7e4c4347	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x7e50c018	dst_alloc
++EXPORT_SYMBOL vmlinux 0x7e55c63c	__scm_send
++EXPORT_SYMBOL vmlinux 0x7e5c35b1	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x7e7fc3fb	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x7e9cf62b	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x7ea2e26f	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x7eb83afb	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x7ec1c9db	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x7ec3c5fe	param_set_bool
++EXPORT_SYMBOL vmlinux 0x7ecb001b	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7ee73c0c	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0x7eea2e2e	pci_iounmap
++EXPORT_SYMBOL vmlinux 0x7ef164c3	scsi_add_device
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f252a6f	set_anon_super
++EXPORT_SYMBOL vmlinux 0x7f309f23	cdrom_release
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f6655ba	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x7f66f18c	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x7f670b20	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x7f7b6b26	soft_cursor
++EXPORT_SYMBOL vmlinux 0x7f9f0a87	cpu_tss
++EXPORT_SYMBOL vmlinux 0x7fabb97e	vfs_readf
++EXPORT_SYMBOL vmlinux 0x7fad8a59	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x7fc6ad4f	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0x7fde2edb	vme_master_read
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7ff66174	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0x800b9ab1	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x800fc657	blk_peek_request
++EXPORT_SYMBOL vmlinux 0x80244f16	ilookup5
++EXPORT_SYMBOL vmlinux 0x8057586f	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x80890177	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0x809388ca	idr_destroy
++EXPORT_SYMBOL vmlinux 0x80c503e1	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80cff739	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80d9ca85	paravirt_ticketlocks_enabled
++EXPORT_SYMBOL vmlinux 0x80e2565a	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0x80eb423b	acpi_get_object_info
++EXPORT_SYMBOL vmlinux 0x80fbb988	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0x810c088b	freeze_bdev
++EXPORT_SYMBOL vmlinux 0x81144f9d	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x811d16d8	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x812eadad	led_blink_set
++EXPORT_SYMBOL vmlinux 0x8141da09	start_tty
++EXPORT_SYMBOL vmlinux 0x81472677	acpi_get_table
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x814f5b22	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x815c56d0	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x815f2897	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x81671b51	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0x817e17c2	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x81841eef	dup_iter
++EXPORT_SYMBOL vmlinux 0x81904704	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0x819c84bc	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x81ac315a	get_fs_type
++EXPORT_SYMBOL vmlinux 0x81bb667b	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x81bf9dfe	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0x81c3ca40	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81e3eb31	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x81e6b37f	dmi_get_system_info
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x820d5edf	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0x8212721d	xenbus_dev_request_and_reply
++EXPORT_SYMBOL vmlinux 0x82308aaf	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0x8235805b	memmove
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x8272f4f9	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x829534b3	fence_free
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82b85738	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0x82cb9ae5	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0x82d64e2e	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x82e21cb5	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0x82e550ba	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0x82f4fdea	kfree_put_link
++EXPORT_SYMBOL vmlinux 0x82ff85a7	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x8303406c	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0x830e547b	ioremap_prot
++EXPORT_SYMBOL vmlinux 0x8310acce	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0x831a7b4f	dump_trace
++EXPORT_SYMBOL vmlinux 0x8329e6f0	memset
++EXPORT_SYMBOL vmlinux 0x832fa791	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x833c03aa	acpi_enable_all_runtime_gpes
++EXPORT_SYMBOL vmlinux 0x835ecf22	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0x836dfd93	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0x8372cd2f	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x8382e59a	acpi_walk_resource_buffer
++EXPORT_SYMBOL vmlinux 0x838bb3a2	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0x839245f0	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83bb7a12	vga_switcheroo_fini_domain_pm_ops
++EXPORT_SYMBOL vmlinux 0x83c4c8e0	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83cdc700	pnpbios_protocol
++EXPORT_SYMBOL vmlinux 0x83e49c97	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0x840127bf	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x84037678	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0x84060081	xen_poll_irq_timeout
++EXPORT_SYMBOL vmlinux 0x84169642	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x8417f512	acpi_update_all_gpes
++EXPORT_SYMBOL vmlinux 0x8419dfb2	tcf_register_action
++EXPORT_SYMBOL vmlinux 0x841e348b	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x8422a78a	fb_get_mode
++EXPORT_SYMBOL vmlinux 0x842d251a	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0x842e9c55	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x843a3eb6	inet6_getname
++EXPORT_SYMBOL vmlinux 0x844f84b9	pci_match_id
++EXPORT_SYMBOL vmlinux 0x845eb389	invalidate_partition
++EXPORT_SYMBOL vmlinux 0x847616e4	pnp_stop_dev
++EXPORT_SYMBOL vmlinux 0x847e2d23	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0x84894cdc	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0x84a79439	dquot_initialize
++EXPORT_SYMBOL vmlinux 0x84c0811a	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x84c1d69d	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x84c4df2e	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0x84ee35ff	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0x84ef3e5f	filp_close
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x851c9dcc	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0x8526c35a	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x8542a1ca	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x85647726	tcp_poll
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x857582f7	acpi_enable_all_wakeup_gpes
++EXPORT_SYMBOL vmlinux 0x85873582	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x858b3fe3	free_iova_mem
++EXPORT_SYMBOL vmlinux 0x85b3c06e	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85e57074	inet_ioctl
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x85f2f44c	register_key_type
++EXPORT_SYMBOL vmlinux 0x86182550	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0x861e22a4	acpi_map_cpu
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x8652ea77	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0x865d263c	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0x865fda14	tcp_prot
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x868acacc	framebuffer_release
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86a4889a	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0x86ae26dc	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x86d6b80a	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x86f2795c	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x86f28a1f	agp_alloc_bridge
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x870111a0	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x8708fdfe	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0x8718b556	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x8743a221	agp_create_memory
++EXPORT_SYMBOL vmlinux 0x875e61cd	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0x876481cd	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0x876dafc3	ec_write
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x878cd015	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x8791d2ae	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0x87a63dff	netlink_ack
++EXPORT_SYMBOL vmlinux 0x87aaddf8	wrmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0x87b76376	input_close_device
++EXPORT_SYMBOL vmlinux 0x87d8b67c	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x88139033	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x88140212	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x88171bfa	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0x882600b2	update_devfreq
++EXPORT_SYMBOL vmlinux 0x8836f4a7	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0x888794a9	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0x88a0a193	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0x88d13b5d	vga_switcheroo_register_audio_client
++EXPORT_SYMBOL vmlinux 0x88d37e58	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0x88f1289f	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0x88f4934d	inet_release
++EXPORT_SYMBOL vmlinux 0x892b26a0	set_memory_nx
++EXPORT_SYMBOL vmlinux 0x895c83c6	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0x8969f514	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89c59eec	mmc_add_host
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89f6ae72	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x8a03ca44	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0x8a041ef5	write_inode_now
++EXPORT_SYMBOL vmlinux 0x8a0b12c6	complete_all
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a3bd853	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a4eefcf	agp_generic_destroy_pages
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a5830c2	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x8a6944f9	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x8a6e00bb	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a80d7a5	acpi_error
++EXPORT_SYMBOL vmlinux 0x8a949bc9	elv_add_request
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8a9e45eb	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0x8ab64c53	skb_insert
++EXPORT_SYMBOL vmlinux 0x8ab74a7c	ppp_input_error
++EXPORT_SYMBOL vmlinux 0x8abb9a79	scsi_register
++EXPORT_SYMBOL vmlinux 0x8acdb3c3	kill_pid
++EXPORT_SYMBOL vmlinux 0x8ae8c0fd	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0x8b02ebf7	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x8b0aa68a	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0x8b16b4bf	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x8b17c150	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x8b18496f	__copy_to_user_ll
++EXPORT_SYMBOL vmlinux 0x8b2f1563	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b38830e	block_commit_write
++EXPORT_SYMBOL vmlinux 0x8b3c6761	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b4a001b	vga_switcheroo_init_domain_pm_optimus_hdmi_audio
++EXPORT_SYMBOL vmlinux 0x8b4ca0ff	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b8c1476	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x8b989cf9	acpi_bus_can_wakeup
++EXPORT_SYMBOL vmlinux 0x8b9d17ef	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0x8bb8d87c	param_get_ushort
++EXPORT_SYMBOL vmlinux 0x8bd8d016	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0x8bf54d90	free_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0x8c0dac86	__break_lease
++EXPORT_SYMBOL vmlinux 0x8c183cbe	iowrite16
++EXPORT_SYMBOL vmlinux 0x8c18b6d5	vme_master_request
++EXPORT_SYMBOL vmlinux 0x8c1bacc6	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0x8c349ac5	blk_register_region
++EXPORT_SYMBOL vmlinux 0x8c50acaf	downgrade_write
++EXPORT_SYMBOL vmlinux 0x8c599005	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c77ebfb	page_readlink
++EXPORT_SYMBOL vmlinux 0x8c9bc8aa	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0x8ca413cc	dev_crit
++EXPORT_SYMBOL vmlinux 0x8ca5f9f7	bio_copy_data
++EXPORT_SYMBOL vmlinux 0x8ca748b6	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0x8cc79cab	iowrite16_rep
++EXPORT_SYMBOL vmlinux 0x8cda8029	xen_clear_irq_pending
++EXPORT_SYMBOL vmlinux 0x8cdd885e	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x8cf963af	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x8d1801f7	get_agp_version
++EXPORT_SYMBOL vmlinux 0x8d2859d6	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0x8d2aa353	d_genocide
++EXPORT_SYMBOL vmlinux 0x8d37a0c8	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0x8d45af00	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d69558b	dma_ops
++EXPORT_SYMBOL vmlinux 0x8d6b2ce1	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x8d6f81b4	__div64_32
++EXPORT_SYMBOL vmlinux 0x8d72495b	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d838d91	ida_remove
++EXPORT_SYMBOL vmlinux 0x8d853e53	tty_throttle
++EXPORT_SYMBOL vmlinux 0x8d8d96c6	acpi_get_sleep_type_data
++EXPORT_SYMBOL vmlinux 0x8da1a3cb	acpi_remove_interface
++EXPORT_SYMBOL vmlinux 0x8daf8c42	dql_init
++EXPORT_SYMBOL vmlinux 0x8db4646c	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0x8db6f6c5	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0x8dc6e564	restore_processor_state
++EXPORT_SYMBOL vmlinux 0x8dd0af28	put_disk
++EXPORT_SYMBOL vmlinux 0x8ded15eb	generic_update_time
++EXPORT_SYMBOL vmlinux 0x8df0be81	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0x8e002cda	acpi_remove_gpe_block
++EXPORT_SYMBOL vmlinux 0x8e0c4c25	genphy_config_init
++EXPORT_SYMBOL vmlinux 0x8e3267c5	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x8e433307	security_path_mknod
++EXPORT_SYMBOL vmlinux 0x8e484068	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x8e484d39	iunique
++EXPORT_SYMBOL vmlinux 0x8e6ded90	pipe_lock
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e888ec3	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x8eaf2a5f	vga_switcheroo_unregister_handler
++EXPORT_SYMBOL vmlinux 0x8ebace6d	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0x8ebe54a1	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0x8ecde285	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x8efd0678	nd_region_to_nstype
++EXPORT_SYMBOL vmlinux 0x8f084d52	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0x8f2703b7	wbinvd_on_all_cpus
++EXPORT_SYMBOL vmlinux 0x8f649f74	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x8f64da94	acpi_pm_device_sleep_state
++EXPORT_SYMBOL vmlinux 0x8f76bba4	mmc_erase
++EXPORT_SYMBOL vmlinux 0x8f7c6b3e	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x8f8c6b2a	mount_bdev
++EXPORT_SYMBOL vmlinux 0x8f9c199c	__get_user_2
++EXPORT_SYMBOL vmlinux 0x8fd5ee3a	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x8fe59cef	convert_art_to_tsc
++EXPORT_SYMBOL vmlinux 0x8ff220f8	genphy_update_link
++EXPORT_SYMBOL vmlinux 0x8ff4079b	pv_irq_ops
++EXPORT_SYMBOL vmlinux 0x8ffdb3b8	crc16
++EXPORT_SYMBOL vmlinux 0x904409c6	acpi_set_firmware_waking_vector
++EXPORT_SYMBOL vmlinux 0x904cc03d	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0x90695906	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0x90729603	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0x908575fe	queued_write_lock_slowpath
++EXPORT_SYMBOL vmlinux 0x909ad001	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0x90a4db3b	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x90afff07	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x90c4f3eb	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0x90c5e819	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x910c2f42	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0x911e9e14	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0x91250d0c	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0x9131567a	cdev_del
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x914b4d4f	bio_endio
++EXPORT_SYMBOL vmlinux 0x915aee17	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0x91607d95	set_memory_wb
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x91765780	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x9179d14a	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0x91967e8e	xen_selfballoon_init
++EXPORT_SYMBOL vmlinux 0x9199ba56	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x91a74511	registered_fb
++EXPORT_SYMBOL vmlinux 0x91c13f0d	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x91fc3753	i2c_release_client
++EXPORT_SYMBOL vmlinux 0x9212e901	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0x921ec897	elevator_change
++EXPORT_SYMBOL vmlinux 0x9229a3bc	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x9238181f	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x92387847	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x9243cdd0	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x924a2632	bd_set_size
++EXPORT_SYMBOL vmlinux 0x92503f19	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0x926fd8fe	revert_creds
++EXPORT_SYMBOL vmlinux 0x92897e3d	default_idle
++EXPORT_SYMBOL vmlinux 0x928d4cdf	blk_end_request
++EXPORT_SYMBOL vmlinux 0x929f5b58	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92aa18ae	igrab
++EXPORT_SYMBOL vmlinux 0x92bb51f8	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0x92c7896a	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0x92f56427	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x92f6767f	lg_local_lock
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x92fd03c5	migrate_page
++EXPORT_SYMBOL vmlinux 0x9300b6ac	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0x93050d4d	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x931e02bd	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0x93215e1d	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0x932493a8	iosf_mbi_read
++EXPORT_SYMBOL vmlinux 0x9342e8f9	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0x934c7f78	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0x93599d4d	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x93865b74	iget_locked
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93b511e5	blk_init_queue
++EXPORT_SYMBOL vmlinux 0x93cb2721	arp_create
++EXPORT_SYMBOL vmlinux 0x93dab4f2	inet_select_addr
++EXPORT_SYMBOL vmlinux 0x93e61ad8	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0x93eaabac	prepare_binprm
++EXPORT_SYMBOL vmlinux 0x93ef9bd7	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x93f85873	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x940b440e	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0x940f9cf6	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x943725f5	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x9438c434	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x943cbe19	tty_devnum
++EXPORT_SYMBOL vmlinux 0x9449ca6e	pci_get_class
++EXPORT_SYMBOL vmlinux 0x9459a75b	agp_collect_device_status
++EXPORT_SYMBOL vmlinux 0x946ca315	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x94701006	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94b541b5	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x94d191f3	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0x94ec80f6	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x94eea794	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x94fd7a86	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x95181525	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x951e0623	key_invalidate
++EXPORT_SYMBOL vmlinux 0x9522971a	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0x95395301	acpi_exception
++EXPORT_SYMBOL vmlinux 0x953ac3ba	cros_ec_query_all
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x95567955	dev_activate
++EXPORT_SYMBOL vmlinux 0x957dd4d0	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0x95857767	thaw_bdev
++EXPORT_SYMBOL vmlinux 0x95937191	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0x95a0bd29	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x95a16503	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x95a36548	filp_open
++EXPORT_SYMBOL vmlinux 0x95a5bc04	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x95b62250	d_alloc
++EXPORT_SYMBOL vmlinux 0x95bd6e26	acpi_install_sci_handler
++EXPORT_SYMBOL vmlinux 0x95c08b5a	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0x95d35a4e	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0x95d88d51	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x95df08d6	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0x95fda06f	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x9603c09d	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0x960a8723	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0x960c7756	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x960dfaf5	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0x961211a5	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x96244c7e	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0x962b15fe	seq_release_private
++EXPORT_SYMBOL vmlinux 0x963ddf12	do_splice_from
++EXPORT_SYMBOL vmlinux 0x96573b80	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x965b27db	pci_request_regions
++EXPORT_SYMBOL vmlinux 0x9661f619	do_SAK
++EXPORT_SYMBOL vmlinux 0x9670d811	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0x96791773	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x9683fc6c	md_write_end
++EXPORT_SYMBOL vmlinux 0x96898769	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x969cfecc	nf_log_trace
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96f66049	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0x96f6d8eb	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0x96fbde17	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0x97090ab4	seq_lseek
++EXPORT_SYMBOL vmlinux 0x970baf9e	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0x970e24ae	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0x97113d8e	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0x9728b928	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0x973fa82e	register_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x974cf834	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x97551943	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x9762dc83	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x976c5225	md_integrity_register
++EXPORT_SYMBOL vmlinux 0x976e191f	vfs_create
++EXPORT_SYMBOL vmlinux 0x976e5e7d	use_ibrs
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x97b0d033	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0x97c5bd0a	acpi_unload_parent_table
++EXPORT_SYMBOL vmlinux 0x97c69f6b	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x97cf6abc	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0x97dbb7d9	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0x97de0ddd	acpi_install_gpe_block
++EXPORT_SYMBOL vmlinux 0x980caac2	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0x980dac7f	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0x9814c7a5	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x9818fe84	__neigh_create
++EXPORT_SYMBOL vmlinux 0x98204f0d	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0x9820b644	warn_slowpath_fmt_taint
++EXPORT_SYMBOL vmlinux 0x9829b97c	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x98425fb4	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0x98552850	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0x98591a24	skb_find_text
++EXPORT_SYMBOL vmlinux 0x985aa253	dump_skip
++EXPORT_SYMBOL vmlinux 0x985eef53	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0x9869a9ec	module_layout
++EXPORT_SYMBOL vmlinux 0x986c5b3e	nla_append
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x98735dd7	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0x9878745c	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x98897df3	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x988ed85d	set_memory_x
++EXPORT_SYMBOL vmlinux 0x98abdd68	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0x98cfba2d	udp_del_offload
++EXPORT_SYMBOL vmlinux 0x98d0cde8	clk_add_alias
++EXPORT_SYMBOL vmlinux 0x98df6212	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0x98e68eca	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0x98fe6f1b	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0x99233c32	cpu_core_map
++EXPORT_SYMBOL vmlinux 0x992e72e4	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x99726d98	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x9975f46c	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x9990713f	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x9996fec1	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0x999abf20	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99a26112	init_net
++EXPORT_SYMBOL vmlinux 0x99b19f4c	block_write_end
++EXPORT_SYMBOL vmlinux 0x99b245e0	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0x99c40372	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99daa9bf	try_offline_node
++EXPORT_SYMBOL vmlinux 0x99e1856e	kobject_add
++EXPORT_SYMBOL vmlinux 0x99ec8ceb	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0x99f39356	pnp_device_detach
++EXPORT_SYMBOL vmlinux 0x9a00ff2d	register_gifconf
++EXPORT_SYMBOL vmlinux 0x9a029c62	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a26a9a5	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0x9a3d4d7a	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0x9a481cb4	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0x9a62ecfd	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0x9a6a59e5	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x9a6a83f9	cmos_lock
++EXPORT_SYMBOL vmlinux 0x9a6d35da	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0x9a701096	follow_up
++EXPORT_SYMBOL vmlinux 0x9a7a34ea	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0x9a8219c4	setattr_copy
++EXPORT_SYMBOL vmlinux 0x9add3d63	mdiobus_free
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9af9d7cc	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x9b12a8fe	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b4a232d	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0x9b6eb137	ksize
++EXPORT_SYMBOL vmlinux 0x9b915a48	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x9b950be3	skb_unlink
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba146bf	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bbe88b3	flex_array_put
++EXPORT_SYMBOL vmlinux 0x9bd1bf58	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x9bdb9296	pci_release_region
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9c19ce76	security_file_permission
++EXPORT_SYMBOL vmlinux 0x9c2c944a	__copy_from_user_ll_nocache_nozero
++EXPORT_SYMBOL vmlinux 0x9c38e8e5	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x9c3e2694	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0x9c434c86	find_lock_entry
++EXPORT_SYMBOL vmlinux 0x9c450105	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cd60890	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0x9ce169af	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x9d02220d	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0x9d07c7d1	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x9d08bd2c	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d22ddb7	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0x9d33ef5e	acpi_enable
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d544472	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0x9d5790d5	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x9d647f90	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x9d807665	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x9d93c96a	param_set_byte
++EXPORT_SYMBOL vmlinux 0x9da136fa	nobh_writepage
++EXPORT_SYMBOL vmlinux 0x9da46285	da903x_query_status
++EXPORT_SYMBOL vmlinux 0x9dfe7307	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9e045039	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e2ea2fa	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x9e363b6b	acpi_disable_gpe
++EXPORT_SYMBOL vmlinux 0x9e3e869c	scsi_execute
++EXPORT_SYMBOL vmlinux 0x9e46de1c	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e5b0d06	pid_task
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e64fbfe	rtc_cmos_read
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e7d6bd0	__udelay
++EXPORT_SYMBOL vmlinux 0x9e880ffc	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x9e937b80	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9ea0c91f	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x9eaf4194	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9edfaa30	set_device_ro
++EXPORT_SYMBOL vmlinux 0x9efbfce5	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0x9f0d7ea8	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x9f1240ec	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0x9f36de73	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0x9f38eb8e	tty_port_close
++EXPORT_SYMBOL vmlinux 0x9f3f01ec	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0x9f447ebc	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f478295	agp_generic_remove_memory
++EXPORT_SYMBOL vmlinux 0x9f66436a	serio_close
++EXPORT_SYMBOL vmlinux 0x9f94b8cc	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9fa07523	agp_enable
++EXPORT_SYMBOL vmlinux 0x9fa2af2c	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0x9fa30038	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0x9fd41d76	vm_mmap
++EXPORT_SYMBOL vmlinux 0x9fd7cda1	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9fdf756a	pci_release_regions
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa00aca2a	dql_completed
++EXPORT_SYMBOL vmlinux 0xa022785c	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa0588560	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0xa05a07bc	vga_switcheroo_set_dynamic_switch
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa06df9e1	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0xa076ed51	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0xa07bf0c2	textsearch_register
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0c1416f	proto_unregister
++EXPORT_SYMBOL vmlinux 0xa0c67a91	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0xa0c823e7	input_unregister_device
++EXPORT_SYMBOL vmlinux 0xa0c9d4d4	generic_removexattr
++EXPORT_SYMBOL vmlinux 0xa0cb377d	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0f48cdb	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0fbc0bf	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa1444dd9	tty_check_change
++EXPORT_SYMBOL vmlinux 0xa147b8d6	page_symlink
++EXPORT_SYMBOL vmlinux 0xa14b3f5d	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0xa1650620	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0xa1748ce5	input_free_device
++EXPORT_SYMBOL vmlinux 0xa17819ca	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0xa184bf5e	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xa184d6ee	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xa195df23	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xa19de3fd	boot_cpu_data
++EXPORT_SYMBOL vmlinux 0xa1ad3682	alloc_file
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa1dff6b6	nvdimm_revalidate_disk
++EXPORT_SYMBOL vmlinux 0xa1fe9ca0	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa22daf83	force_sig
++EXPORT_SYMBOL vmlinux 0xa2315891	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0xa23ca586	seq_pad
++EXPORT_SYMBOL vmlinux 0xa23d9c4a	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0xa248c04c	dquot_operations
++EXPORT_SYMBOL vmlinux 0xa28336c9	register_md_personality
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa28f0423	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xa29377d7	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0xa2b19c28	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0xa2b69d9c	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0xa2bca5b2	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0xa2d7ae7c	lease_modify
++EXPORT_SYMBOL vmlinux 0xa2e3346f	ps2_drain
++EXPORT_SYMBOL vmlinux 0xa2fdf6aa	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa34fcb2d	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xa350a8f8	set_memory_array_uc
++EXPORT_SYMBOL vmlinux 0xa36818eb	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0xa37e78b6	flex_array_get
++EXPORT_SYMBOL vmlinux 0xa37f9f3e	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0xa3b1a706	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0xa3c6c009	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0xa3dcbfd3	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0xa3f6ccc3	dev_get_flags
++EXPORT_SYMBOL vmlinux 0xa4065f70	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0xa40e6172	netdev_update_features
++EXPORT_SYMBOL vmlinux 0xa4106648	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0xa423b662	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0xa4325206	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0xa43b1297	vscnprintf
++EXPORT_SYMBOL vmlinux 0xa441924e	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0xa44cc8e5	mmc_request_done
++EXPORT_SYMBOL vmlinux 0xa45cd7ad	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa47f448b	vga_switcheroo_init_domain_pm_ops
++EXPORT_SYMBOL vmlinux 0xa48f2c0a	PDE_DATA
++EXPORT_SYMBOL vmlinux 0xa4add03e	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0xa4ae60c6	md_check_recovery
++EXPORT_SYMBOL vmlinux 0xa4aeefde	mpage_readpage
++EXPORT_SYMBOL vmlinux 0xa4b91add	dump_align
++EXPORT_SYMBOL vmlinux 0xa4b94fea	iowrite8_rep
++EXPORT_SYMBOL vmlinux 0xa4c668ea	input_register_device
++EXPORT_SYMBOL vmlinux 0xa4d4f0e6	global_cache_flush
++EXPORT_SYMBOL vmlinux 0xa4fc6d58	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0xa51cdfe8	__FIXADDR_TOP
++EXPORT_SYMBOL vmlinux 0xa52977de	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0xa546654c	register_qdisc
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa553a792	i2c_transfer
++EXPORT_SYMBOL vmlinux 0xa567ab8c	dm_io
++EXPORT_SYMBOL vmlinux 0xa57a23e4	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0xa587e81e	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0xa597fed5	dquot_enable
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa598f8b0	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0xa5a2cf17	param_set_int
++EXPORT_SYMBOL vmlinux 0xa5af3b0c	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0xa5bf27a8	put_tty_driver
++EXPORT_SYMBOL vmlinux 0xa5fa349e	free_buffer_head
++EXPORT_SYMBOL vmlinux 0xa62af439	end_page_writeback
++EXPORT_SYMBOL vmlinux 0xa62e6e4f	acpi_get_table_with_size
++EXPORT_SYMBOL vmlinux 0xa62f4fab	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa640c86c	would_dump
++EXPORT_SYMBOL vmlinux 0xa673d74c	napi_complete_done
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa678a02c	locks_init_lock
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa68207e6	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0xa68a2ce0	do_splice_direct
++EXPORT_SYMBOL vmlinux 0xa6970398	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0xa6b4207e	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0xa6b4a5ef	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0xa6bbd805	__wake_up
++EXPORT_SYMBOL vmlinux 0xa6bd63ca	acpi_bios_error
++EXPORT_SYMBOL vmlinux 0xa6d5972f	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0xa6e86f9c	put_page
++EXPORT_SYMBOL vmlinux 0xa6fc526c	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa70fabbe	release_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0xa71093a9	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0xa712c106	__module_get
++EXPORT_SYMBOL vmlinux 0xa717864b	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0xa730a558	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa749a999	inet_addr_type
++EXPORT_SYMBOL vmlinux 0xa75357dc	thaw_super
++EXPORT_SYMBOL vmlinux 0xa75b3421	d_instantiate
++EXPORT_SYMBOL vmlinux 0xa75df954	input_flush_device
++EXPORT_SYMBOL vmlinux 0xa788f1a0	i8253_lock
++EXPORT_SYMBOL vmlinux 0xa7a2dc2b	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0xa7b6457f	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0xa7bafcc7	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0xa7cf6c2f	atomic64_dec_return_cx8
++EXPORT_SYMBOL vmlinux 0xa80d41c3	poll_freewait
++EXPORT_SYMBOL vmlinux 0xa81626f9	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0xa8168b7c	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0xa8315b92	acpi_device_hid
++EXPORT_SYMBOL vmlinux 0xa8391b07	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0xa83bba5d	stop_tty
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa848cb08	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0xa8515e8a	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0xa8526f24	dcb_getapp
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa8a2a07a	seq_escape
++EXPORT_SYMBOL vmlinux 0xa8aaa584	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0xa8c42bf6	param_set_invbool
++EXPORT_SYMBOL vmlinux 0xa8c8fe87	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0xa8cf4929	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0xa8e13307	agp_generic_alloc_user
++EXPORT_SYMBOL vmlinux 0xa8fedc08	pci_bus_put
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa92cd6f8	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0xa945b706	abort_creds
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa9a8e17f	arch_phys_wc_add
++EXPORT_SYMBOL vmlinux 0xa9b15d04	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9cfea6b	x86_hyper
++EXPORT_SYMBOL vmlinux 0xa9fb82ec	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xaa20c4c1	netdev_alert
++EXPORT_SYMBOL vmlinux 0xaa2f1872	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0xaa375592	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0xaa5bd08d	__pv_queued_spin_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xaa675a6b	audit_log_start
++EXPORT_SYMBOL vmlinux 0xaa6901ac	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa7a4dc9	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0xaa7c926a	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0xaa8fea18	acpi_processor_register_performance
++EXPORT_SYMBOL vmlinux 0xaa96676e	is_nd_btt
++EXPORT_SYMBOL vmlinux 0xaaa2bf4f	seq_dentry
++EXPORT_SYMBOL vmlinux 0xaaa64623	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0xaaaac5f5	register_quota_format
++EXPORT_SYMBOL vmlinux 0xaab61de8	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0xaac7fd06	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad4d221	user_revoke
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaae1ea74	inet_put_port
++EXPORT_SYMBOL vmlinux 0xaae7f6aa	pci_get_slot
++EXPORT_SYMBOL vmlinux 0xaae8ab0e	acpi_bus_power_manageable
++EXPORT_SYMBOL vmlinux 0xaafa7373	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab03aa7f	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0xab05459f	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0xab3bf857	write_one_page
++EXPORT_SYMBOL vmlinux 0xab3c142e	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0xab3eb7dd	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0xab40330d	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0xab551fad	acpi_get_data_full
++EXPORT_SYMBOL vmlinux 0xab600421	probe_irq_off
++EXPORT_SYMBOL vmlinux 0xab65ed80	set_memory_uc
++EXPORT_SYMBOL vmlinux 0xab694444	bsearch
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab764667	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0xab770678	rdmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab7b2c62	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xab9b236f	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0xaba3159c	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0xaba3ad0c	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xaba666e5	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabdd6463	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xabdf2947	pnp_register_card_driver
++EXPORT_SYMBOL vmlinux 0xabecf663	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xabf00581	simple_setattr
++EXPORT_SYMBOL vmlinux 0xabfcb4c3	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac0e934f	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac31b308	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0xac398912	flex_array_clear
++EXPORT_SYMBOL vmlinux 0xac5b7acd	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0xac7b618e	nf_register_hook
++EXPORT_SYMBOL vmlinux 0xaca6cf7f	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacb8145d	iterate_dir
++EXPORT_SYMBOL vmlinux 0xacb99769	ida_destroy
++EXPORT_SYMBOL vmlinux 0xacc1c0bb	blkdev_get
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad0522db	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0xad1687e1	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0xad26c510	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0xad40e399	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0xad547243	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0xad5b9771	dev_warn
++EXPORT_SYMBOL vmlinux 0xad698f77	dqstats
++EXPORT_SYMBOL vmlinux 0xad6a9ce9	sock_create
++EXPORT_SYMBOL vmlinux 0xad6e4bb6	mempool_free
++EXPORT_SYMBOL vmlinux 0xad6edc6e	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0xad6f413a	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0xad7d46a3	agp_generic_enable
++EXPORT_SYMBOL vmlinux 0xad7effdc	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0xad81deb3	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad894cb9	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0xad8acfb1	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0xad9a151e	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0xad9cc25a	simple_release_fs
++EXPORT_SYMBOL vmlinux 0xada23500	param_ops_byte
++EXPORT_SYMBOL vmlinux 0xada613ba	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0xadbe841b	sock_register
++EXPORT_SYMBOL vmlinux 0xadf5660d	submit_bio
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xae044bc7	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0xae31c616	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0xae756ce0	load_nls_default
++EXPORT_SYMBOL vmlinux 0xae77a595	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0xae7d5090	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xae822634	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0xae82598d	simple_link
++EXPORT_SYMBOL vmlinux 0xae85a27e	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0xae998a7d	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0xaea976a8	acpi_check_resource_conflict
++EXPORT_SYMBOL vmlinux 0xaec655c7	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0xaec8bd5a	file_update_time
++EXPORT_SYMBOL vmlinux 0xaecb7533	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0xaf222e7a	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0xaf271903	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf4b1540	acpi_get_irq_routing_table
++EXPORT_SYMBOL vmlinux 0xaf60fa1c	xen_biovec_phys_mergeable
++EXPORT_SYMBOL vmlinux 0xaf611eac	amd_nb_misc_ids
++EXPORT_SYMBOL vmlinux 0xafa0a1fb	tty_set_operations
++EXPORT_SYMBOL vmlinux 0xafa3a84c	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xafb4b2f3	netif_device_attach
++EXPORT_SYMBOL vmlinux 0xafbce5b7	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0xafed8ca7	bioset_free
++EXPORT_SYMBOL vmlinux 0xaff65341	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0xb01300a7	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0xb015846f	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0xb016eedd	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0xb01b1db8	intel_gtt_insert_sg_entries
++EXPORT_SYMBOL vmlinux 0xb04d4773	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0xb05c46a1	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb07ec0ce	arp_xmit
++EXPORT_SYMBOL vmlinux 0xb0817db1	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0xb081b9c3	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0xb08f4f4c	kill_anon_super
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0bdb7eb	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0xb0df718d	dm_put_device
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0e4f324	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0xb0eb41ff	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0xb0f30470	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0xb103870f	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0xb1044649	agp_generic_free_by_type
++EXPORT_SYMBOL vmlinux 0xb110f8a5	drop_super
++EXPORT_SYMBOL vmlinux 0xb119fa70	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0xb121390a	probe_irq_on
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb13d5658	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0xb152a7e4	vfs_write
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb168afb1	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0xb187b3a8	lg_lock_init
++EXPORT_SYMBOL vmlinux 0xb18a57a9	misc_deregister
++EXPORT_SYMBOL vmlinux 0xb197ae69	elv_rb_find
++EXPORT_SYMBOL vmlinux 0xb1999755	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0xb1b51e38	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0xb1c0031e	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1cfad22	rdmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xb1eccfd1	mntput
++EXPORT_SYMBOL vmlinux 0xb1fabcc0	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0xb219d56c	wbinvd_on_cpu
++EXPORT_SYMBOL vmlinux 0xb246b3dc	security_mmap_file
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb27109e1	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2c0ba22	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0xb2d48a2e	queue_work_on
++EXPORT_SYMBOL vmlinux 0xb2d5a552	complete
++EXPORT_SYMBOL vmlinux 0xb2f30b53	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0xb2f74fb6	intel_gmch_remove
++EXPORT_SYMBOL vmlinux 0xb2fd5ceb	__put_user_4
++EXPORT_SYMBOL vmlinux 0xb322139e	is_nvdimm_bus_locked
++EXPORT_SYMBOL vmlinux 0xb3284531	acpi_dbg_layer
++EXPORT_SYMBOL vmlinux 0xb32d7b7e	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0xb34048c7	set_pages_nx
++EXPORT_SYMBOL vmlinux 0xb345ead0	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0xb352177e	find_first_bit
++EXPORT_SYMBOL vmlinux 0xb355311b	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0xb3604b0c	sget_userns
++EXPORT_SYMBOL vmlinux 0xb3668035	neigh_lookup
++EXPORT_SYMBOL vmlinux 0xb38f9368	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0xb39abc77	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0xb39fc803	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3e0590d	acpi_set_current_resources
++EXPORT_SYMBOL vmlinux 0xb3edba09	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb40304dd	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0xb419d2c6	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb4390f9a	mcount
++EXPORT_SYMBOL vmlinux 0xb43d0a32	vmap
++EXPORT_SYMBOL vmlinux 0xb4519a8f	string_escape_mem
++EXPORT_SYMBOL vmlinux 0xb45578b8	memscan
++EXPORT_SYMBOL vmlinux 0xb4608f94	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0xb46792a7	iget_failed
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb4aff06e	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0xb4c84b65	bh_submit_read
++EXPORT_SYMBOL vmlinux 0xb4caec76	input_open_device
++EXPORT_SYMBOL vmlinux 0xb4cb358f	agp_put_bridge
++EXPORT_SYMBOL vmlinux 0xb4f8ef65	phy_stop
++EXPORT_SYMBOL vmlinux 0xb5137ff9	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0xb5229392	cpu_sibling_map
++EXPORT_SYMBOL vmlinux 0xb528a3a9	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0xb52a1ad3	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0xb52ee8be	intel_gtt_clear_range
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5b87389	km_report
++EXPORT_SYMBOL vmlinux 0xb5be7bd3	sock_no_getname
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb5cdee94	agp_find_bridge
++EXPORT_SYMBOL vmlinux 0xb5dbd16a	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0xb5fb9e4c	sg_miter_next
++EXPORT_SYMBOL vmlinux 0xb5ffc182	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0xb60f6b83	read_cache_page
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb6312f7e	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0xb63b24a2	__pagevec_release
++EXPORT_SYMBOL vmlinux 0xb6531658	unregister_netdev
++EXPORT_SYMBOL vmlinux 0xb674a534	acpi_unmap_cpu
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb684b779	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0xb6896671	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6a6bc99	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0xb6af2a1d	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0xb6cba267	genphy_resume
++EXPORT_SYMBOL vmlinux 0xb6e41883	memcmp
++EXPORT_SYMBOL vmlinux 0xb6ed1e53	strncpy
++EXPORT_SYMBOL vmlinux 0xb6f39f5e	__scm_destroy
++EXPORT_SYMBOL vmlinux 0xb737155a	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb74ab8ab	clkdev_add
++EXPORT_SYMBOL vmlinux 0xb758b225	acpi_disable_event
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb771d661	generic_file_open
++EXPORT_SYMBOL vmlinux 0xb77ef029	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0xb7967604	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0xb79ec15d	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7d9081c	cdev_init
++EXPORT_SYMBOL vmlinux 0xb7e02bcc	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xb7ed8d84	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0xb7f55ecc	atomic64_add_return_cx8
++EXPORT_SYMBOL vmlinux 0xb7f9da96	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0xb7fc6799	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0xb80682ff	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0xb81960ca	snprintf
++EXPORT_SYMBOL vmlinux 0xb8205781	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0xb8370414	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0xb83a1529	skb_trim
++EXPORT_SYMBOL vmlinux 0xb8451fa1	proc_remove
++EXPORT_SYMBOL vmlinux 0xb86d8a28	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xb86feabf	set_wb_congested
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb87fd3c1	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0xb8854ac8	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xb88574e7	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0xb886c4c3	ata_link_printk
++EXPORT_SYMBOL vmlinux 0xb891f6f6	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0xb8a6d67b	sync_blockdev
++EXPORT_SYMBOL vmlinux 0xb8b6a76c	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0xb8beadf4	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0xb8dd63c7	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0xb8dfa3f9	lock_rename
++EXPORT_SYMBOL vmlinux 0xb8e33a1d	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0xb8e3905d	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0xb8e7ce2c	__put_user_8
++EXPORT_SYMBOL vmlinux 0xb8e877e7	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xb8ea997f	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0xb8ee988d	vfs_rename
++EXPORT_SYMBOL vmlinux 0xb8fdcd10	mempool_resize
++EXPORT_SYMBOL vmlinux 0xb918f71a	get_cached_acl
++EXPORT_SYMBOL vmlinux 0xb931b5ce	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0xb9740653	module_put
++EXPORT_SYMBOL vmlinux 0xb97d8146	alloc_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0xb9892e9d	pnp_is_active
++EXPORT_SYMBOL vmlinux 0xb994c074	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0xb99df118	eth_header
++EXPORT_SYMBOL vmlinux 0xb9a67ed5	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0xb9bc015e	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0xb9dacf85	pnp_activate_dev
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xba01967f	bmap
++EXPORT_SYMBOL vmlinux 0xba168eb4	agp_alloc_page_array
++EXPORT_SYMBOL vmlinux 0xba175f9f	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0xba2d8594	ec_read
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba7a460c	audit_log
++EXPORT_SYMBOL vmlinux 0xba7fd2f6	seq_file_path
++EXPORT_SYMBOL vmlinux 0xba9fd104	set_posix_acl
++EXPORT_SYMBOL vmlinux 0xbaa12db9	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0xbaa8030c	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xbaab1f91	intel_gmch_probe
++EXPORT_SYMBOL vmlinux 0xbab2912d	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0xbab82379	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0xbac3cbf2	ns_to_timespec64
++EXPORT_SYMBOL vmlinux 0xbadaef20	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb084feb	param_ops_charp
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb4824e1	loop_backing_file
++EXPORT_SYMBOL vmlinux 0xbb4d00af	param_get_byte
++EXPORT_SYMBOL vmlinux 0xbb52b4e0	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb6870d2	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0xbb8387c1	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0xbb8628d1	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbb9e74fc	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0xbba70a2d	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xbbaef0a4	ihold
++EXPORT_SYMBOL vmlinux 0xbbb2d51b	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0xbbb8768f	release_sock
++EXPORT_SYMBOL vmlinux 0xbbb8f11e	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0xbbbabc2a	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xbbceb8e1	tty_kref_put
++EXPORT_SYMBOL vmlinux 0xbbd85510	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0xbbe8d2e0	__page_symlink
++EXPORT_SYMBOL vmlinux 0xbbeb1ec6	ioremap_wt
++EXPORT_SYMBOL vmlinux 0xbc0c101d	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0xbc14d347	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0xbc1d3d9a	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xbc2031de	acpi_processor_get_bios_limit
++EXPORT_SYMBOL vmlinux 0xbc24a780	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0xbc3d8ea8	__put_cred
++EXPORT_SYMBOL vmlinux 0xbc435770	dump_stack
++EXPORT_SYMBOL vmlinux 0xbc43bc67	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0xbc533c14	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0xbc72590d	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0xbc78375d	bdevname
++EXPORT_SYMBOL vmlinux 0xbc8a6138	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0xbc8ec8e2	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0xbc95d31c	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xbca3211e	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xbcac62bb	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0xbcbf0e10	kthread_bind
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcca05f4	sock_edemux
++EXPORT_SYMBOL vmlinux 0xbced127c	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0xbcf15653	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0xbd0e5052	ata_port_printk
++EXPORT_SYMBOL vmlinux 0xbd1c13ba	cros_ec_cmd_xfer_status
++EXPORT_SYMBOL vmlinux 0xbd328991	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0xbd464b7b	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0xbd6c42e0	cont_write_begin
++EXPORT_SYMBOL vmlinux 0xbd7ee671	sg_miter_start
++EXPORT_SYMBOL vmlinux 0xbd8116e8	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0xbd88b201	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbd9333b3	elv_rb_del
++EXPORT_SYMBOL vmlinux 0xbda04476	pci_restore_state
++EXPORT_SYMBOL vmlinux 0xbda75a4d	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0xbdaa3de9	input_set_keycode
++EXPORT_SYMBOL vmlinux 0xbdaf5b07	acpi_os_read_port
++EXPORT_SYMBOL vmlinux 0xbdb85c1e	dst_discard_out
++EXPORT_SYMBOL vmlinux 0xbdba3ae5	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0xbdbeb546	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0xbdc95976	release_firmware
++EXPORT_SYMBOL vmlinux 0xbde1e093	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0xbde6f387	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0xbe0e5118	nla_memcmp
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe2affa6	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0xbe47184b	ps2_end_command
++EXPORT_SYMBOL vmlinux 0xbe55149e	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0xbe61179d	pnp_register_driver
++EXPORT_SYMBOL vmlinux 0xbe63c8ba	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0xbe67c35b	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0xbe6b58c9	__breadahead
++EXPORT_SYMBOL vmlinux 0xbe7758d4	dmam_release_declared_memory
++EXPORT_SYMBOL vmlinux 0xbe8c37d9	intel_scu_ipc_simple_command
++EXPORT_SYMBOL vmlinux 0xbe99043f	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0xbea4f6fa	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0xbea6d2de	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0xbec30d05	x86_match_cpu
++EXPORT_SYMBOL vmlinux 0xbed13d18	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0xbee28d4d	arch_debugfs_dir
++EXPORT_SYMBOL vmlinux 0xbee90f2f	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf1a5a9d	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0xbf486982	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xbf4ec428	__free_pages
++EXPORT_SYMBOL vmlinux 0xbf604252	udp_prot
++EXPORT_SYMBOL vmlinux 0xbf7ef142	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8b39e9	isapnp_present
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfc177bc	iowrite32_rep
++EXPORT_SYMBOL vmlinux 0xbfc292f1	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0xbfd36729	param_ops_bint
++EXPORT_SYMBOL vmlinux 0xbfe8ff84	kernel_write
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xc007e70e	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0xc01eed33	__copy_from_user_ll_nozero
++EXPORT_SYMBOL vmlinux 0xc03cdbad	proc_mkdir
++EXPORT_SYMBOL vmlinux 0xc05e355f	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0xc068440e	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc07dacba	dget_parent
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc08f11e0	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0xc090ea6c	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0cd3b13	___ratelimit
++EXPORT_SYMBOL vmlinux 0xc0f58c35	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0xc0f9650a	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0xc10bd326	seq_write
++EXPORT_SYMBOL vmlinux 0xc1152d1d	devm_memunmap
++EXPORT_SYMBOL vmlinux 0xc11d8093	iov_shorten
++EXPORT_SYMBOL vmlinux 0xc120065b	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0xc13ae50f	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0xc13e1ee8	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0xc146b1ce	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0xc147830f	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0xc1674e5e	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0xc19b50a7	nf_log_register
++EXPORT_SYMBOL vmlinux 0xc1ab1c71	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0xc1b0ce82	agp_generic_alloc_by_type
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc1e809d1	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0xc20cae69	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0xc216750b	truncate_setsize
++EXPORT_SYMBOL vmlinux 0xc2215ffb	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0xc2276f4b	mdiobus_write
++EXPORT_SYMBOL vmlinux 0xc22d039e	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0xc22e1a57	proc_set_size
++EXPORT_SYMBOL vmlinux 0xc2424641	agp3_generic_cleanup
++EXPORT_SYMBOL vmlinux 0xc249c50c	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0xc24bc994	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0xc251bfcd	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0xc260c004	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0xc269c21f	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0xc27602c5	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0xc280a525	__copy_from_user_ll
++EXPORT_SYMBOL vmlinux 0xc2896497	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0xc2900ff0	is_bad_inode
++EXPORT_SYMBOL vmlinux 0xc2a55b77	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2acc033	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xc2b93a9c	dev_printk
++EXPORT_SYMBOL vmlinux 0xc2d711e1	krealloc
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc2e91c40	do_truncate
++EXPORT_SYMBOL vmlinux 0xc2ec1417	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0xc2f85eb7	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0xc2fb121e	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0xc32c1f31	set_binfmt
++EXPORT_SYMBOL vmlinux 0xc34c721f	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0xc38423a2	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0xc3880fef	vme_lm_request
++EXPORT_SYMBOL vmlinux 0xc39baf7e	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0xc39d26b5	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0xc3a65c55	override_creds
++EXPORT_SYMBOL vmlinux 0xc3aa465f	sk_free
++EXPORT_SYMBOL vmlinux 0xc3aaf0a9	__put_user_1
++EXPORT_SYMBOL vmlinux 0xc3b66942	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xc3bc8c71	__check_sticky
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3cc720b	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0xc3f45a9a	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0xc3fa6a59	memchr
++EXPORT_SYMBOL vmlinux 0xc4008c53	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0xc41dc8a0	param_ops_string
++EXPORT_SYMBOL vmlinux 0xc41f0516	node_states
++EXPORT_SYMBOL vmlinux 0xc4323fbc	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0xc435ed50	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0xc43b3b10	page_put_link
++EXPORT_SYMBOL vmlinux 0xc44c3889	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0xc46d0f95	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0xc47311d4	check_disk_change
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4a1ec56	single_open
++EXPORT_SYMBOL vmlinux 0xc4ac32ab	fb_class
++EXPORT_SYMBOL vmlinux 0xc4bca5f6	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0xc4cc29f7	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0xc4ea63de	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0xc5137552	x86_bios_cpu_apicid
++EXPORT_SYMBOL vmlinux 0xc52f21b2	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0xc5462085	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0xc5534d64	ioread16
++EXPORT_SYMBOL vmlinux 0xc55f437c	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0xc5604cd6	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0xc5707118	set_pages_array_wc
++EXPORT_SYMBOL vmlinux 0xc57f51a9	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0xc596ef03	netdev_info
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc59dda6a	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0xc5a8c2ec	get_tz_trend
++EXPORT_SYMBOL vmlinux 0xc5d9c46c	agp_try_unsupported_boot
++EXPORT_SYMBOL vmlinux 0xc5e26ba9	eisa_driver_unregister
++EXPORT_SYMBOL vmlinux 0xc5ebc322	phy_driver_register
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc629240b	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc631a28d	cros_ec_check_result
++EXPORT_SYMBOL vmlinux 0xc6447f8e	tty_unlock
++EXPORT_SYMBOL vmlinux 0xc64a26d9	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc657e150	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0xc65abeb7	agp3_generic_sizes
++EXPORT_SYMBOL vmlinux 0xc6700f24	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0xc672f6b8	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc6734497	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0xc67a09fe	intel_gtt_get
++EXPORT_SYMBOL vmlinux 0xc6afcf1e	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0xc6b23120	intel_scu_ipc_iowrite16
++EXPORT_SYMBOL vmlinux 0xc6b368d3	acpi_gpe_count
++EXPORT_SYMBOL vmlinux 0xc6b4c584	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6cdcd14	agp_generic_mask_memory
++EXPORT_SYMBOL vmlinux 0xc6d3f4cf	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0xc6ddcfdb	lock_fb_info
++EXPORT_SYMBOL vmlinux 0xc6f2e467	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0xc6fb3cba	param_array_ops
++EXPORT_SYMBOL vmlinux 0xc7007924	sk_common_release
++EXPORT_SYMBOL vmlinux 0xc7115f9f	dput
++EXPORT_SYMBOL vmlinux 0xc71b73ac	noop_qdisc
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc7267d39	security_path_chown
++EXPORT_SYMBOL vmlinux 0xc733a903	use_ibpb
++EXPORT_SYMBOL vmlinux 0xc74bb7c3	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0xc74cba12	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc7578d74	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0xc768de19	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7cb7fce	unregister_key_type
++EXPORT_SYMBOL vmlinux 0xc7cb8e9b	proc_set_user
++EXPORT_SYMBOL vmlinux 0xc7cd53b9	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0xc7d9e760	vme_irq_free
++EXPORT_SYMBOL vmlinux 0xc7ec6c27	strspn
++EXPORT_SYMBOL vmlinux 0xc7fcc5bf	acpi_resource_to_address64
++EXPORT_SYMBOL vmlinux 0xc80857fd	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0xc8276a79	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xc82c980d	pnp_find_dev
++EXPORT_SYMBOL vmlinux 0xc8339e24	string_unescape
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc8500356	arch_dma_alloc_attrs
++EXPORT_SYMBOL vmlinux 0xc85d27b3	param_get_int
++EXPORT_SYMBOL vmlinux 0xc862530d	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc88102e2	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0xc886cf39	seq_read
++EXPORT_SYMBOL vmlinux 0xc888a066	pv_mmu_ops
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8b6a296	devm_memremap
++EXPORT_SYMBOL vmlinux 0xc8e2a155	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0xc8f0b89e	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0xc8f1888d	nvdimm_bus_unlock
++EXPORT_SYMBOL vmlinux 0xc8f2d141	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xc8f2f023	kdb_current_task
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc917e882	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xc92a2fc4	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0xc9400d92	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0xc943aa5f	netdev_state_change
++EXPORT_SYMBOL vmlinux 0xc9458ae1	input_inject_event
++EXPORT_SYMBOL vmlinux 0xc94afdde	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0xc953d17a	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0xc95abb4c	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0xc962361c	fasync_helper
++EXPORT_SYMBOL vmlinux 0xc9629266	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc9730b6a	inode_change_ok
++EXPORT_SYMBOL vmlinux 0xc9882a05	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0xc98d3494	param_get_charp
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc99f6aae	dma_spin_lock
++EXPORT_SYMBOL vmlinux 0xc9afdfcb	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0xc9b3b0ef	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xc9c360ac	param_set_ulong
++EXPORT_SYMBOL vmlinux 0xc9dc850a	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0xc9f68a2b	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0xc9fef317	add_wait_queue
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca129026	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0xca13f23a	phy_disconnect
++EXPORT_SYMBOL vmlinux 0xca41eaa3	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0xca79bf51	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0xca8acc78	acpi_dbg_level
++EXPORT_SYMBOL vmlinux 0xca908d9a	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xca9363fb	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0xca997c5a	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0xcaa9dfbd	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xcab1069d	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0xcabde461	notify_change
++EXPORT_SYMBOL vmlinux 0xcac53493	inet_bind
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcb01efec	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb392109	inet_frag_find
++EXPORT_SYMBOL vmlinux 0xcb3ae7a9	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0xcb5cd52e	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0xcb733bf2	acpi_bus_set_power
++EXPORT_SYMBOL vmlinux 0xcb758f33	skb_store_bits
++EXPORT_SYMBOL vmlinux 0xcb7bcb78	scsi_host_get
++EXPORT_SYMBOL vmlinux 0xcb7cc79e	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xcb976de1	ip_options_compile
++EXPORT_SYMBOL vmlinux 0xcb9cc916	genphy_read_status
++EXPORT_SYMBOL vmlinux 0xcbae6c7a	acpi_lid_notifier_unregister
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbd406c6	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0xcbe96de5	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0xcbeac4be	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcbeb8c3b	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0xcbeb9b62	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xcbfdd369	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0xcc0bf118	d_move
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc332f2d	i8042_remove_filter
++EXPORT_SYMBOL vmlinux 0xcc4d1bfb	atomic64_read_cx8
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc695517	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0xcc72e1ce	import_iovec
++EXPORT_SYMBOL vmlinux 0xcc77571e	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0xcc794e09	nvdimm_bus_lock
++EXPORT_SYMBOL vmlinux 0xcc7c03d6	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0xcc82add3	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xcc838223	__pte2cachemode_tbl
++EXPORT_SYMBOL vmlinux 0xcc8897d6	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0xcc8d3f4f	acpi_os_execute
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccd59704	vga_switcheroo_unregister_client
++EXPORT_SYMBOL vmlinux 0xcce2bfa8	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0xccfef64f	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0xcd07bbf1	unlock_page
++EXPORT_SYMBOL vmlinux 0xcd10fb95	blk_init_tags
++EXPORT_SYMBOL vmlinux 0xcd13dc7c	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xcd1b095f	page_waitqueue
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd3835fd	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0xcd3c50f9	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0xcd508f09	seq_vprintf
++EXPORT_SYMBOL vmlinux 0xcd5139e3	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0xcd5f8f45	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0xcd62e080	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0xcdb34808	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdc840c1	dev_trans_start
++EXPORT_SYMBOL vmlinux 0xcde0f4ed	nf_log_set
++EXPORT_SYMBOL vmlinux 0xcde5347a	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0xcde946d2	padata_alloc
++EXPORT_SYMBOL vmlinux 0xcdf4ac53	phy_connect
++EXPORT_SYMBOL vmlinux 0xcdff8344	touch_buffer
++EXPORT_SYMBOL vmlinux 0xce008c7b	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0xce1ac7b5	d_add_ci
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce2c45cc	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xce2de92b	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0xce31538e	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0xce484899	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0xce4904a4	acpi_leave_sleep_state
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce633c74	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0xce703142	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0xce7c0abe	d_delete
++EXPORT_SYMBOL vmlinux 0xce9267f0	inet_del_offload
++EXPORT_SYMBOL vmlinux 0xce952dd1	nvm_register
++EXPORT_SYMBOL vmlinux 0xce9e41e9	lockref_get
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xcead9802	dev_err
++EXPORT_SYMBOL vmlinux 0xcebbec8a	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0xcec77476	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0xcecca5b7	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0xcedfc84d	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0xcee48e08	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefa46cc	kern_path_create
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf1ef97b	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0xcf48f5d2	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0xcf4cf4e4	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0xcf661f24	vm_map_ram
++EXPORT_SYMBOL vmlinux 0xcf6cfe1f	msrs_free
++EXPORT_SYMBOL vmlinux 0xcf752296	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0xcf8326ca	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0xcfb64c39	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0xcfbeef6b	km_state_notify
++EXPORT_SYMBOL vmlinux 0xcfd0ef01	init_buffer
++EXPORT_SYMBOL vmlinux 0xcfe05d4d	register_kmmio_probe
++EXPORT_SYMBOL vmlinux 0xcff2af30	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0xd01257b1	mdiobus_read
++EXPORT_SYMBOL vmlinux 0xd0181555	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0xd03f4116	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0xd0431189	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd0958b0b	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a90e79	kset_register
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0ba4f55	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0xd0d8621b	strlen
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f2eb0b	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0f72590	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fef3b2	agp_free_key
++EXPORT_SYMBOL vmlinux 0xd0ff78da	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0xd1001d20	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0xd135b79d	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xd15f9646	fb_is_primary_device
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd1652a93	acpi_info
++EXPORT_SYMBOL vmlinux 0xd174ac5e	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd196c9be	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xd1a3b2b2	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0xd1a55eb7	tty_name
++EXPORT_SYMBOL vmlinux 0xd1a77914	md_error
++EXPORT_SYMBOL vmlinux 0xd1c84dfb	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1f6c5f3	smp_num_siblings
++EXPORT_SYMBOL vmlinux 0xd1fe435c	get_gendisk
++EXPORT_SYMBOL vmlinux 0xd202affd	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0xd2064e2f	idr_replace
++EXPORT_SYMBOL vmlinux 0xd20f3020	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xd213e4c0	pnp_request_card_device
++EXPORT_SYMBOL vmlinux 0xd2302702	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd255ea09	inode_init_always
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd261620b	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0xd263dc24	dqget
++EXPORT_SYMBOL vmlinux 0xd272b7b6	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0xd27a3649	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd282fae3	input_reset_device
++EXPORT_SYMBOL vmlinux 0xd28305d5	register_xen_selfballooning
++EXPORT_SYMBOL vmlinux 0xd28f1b7f	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0xd28fdc50	tty_lock
++EXPORT_SYMBOL vmlinux 0xd2ae4fd1	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0xd2af138b	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xd2bef883	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0xd2cddb9a	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2e6a582	acpi_processor_preregister_performance
++EXPORT_SYMBOL vmlinux 0xd2eaa399	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0xd2fb3cd0	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xd300a780	misc_register
++EXPORT_SYMBOL vmlinux 0xd302da4f	uart_resume_port
++EXPORT_SYMBOL vmlinux 0xd30b5c52	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0xd3a10191	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3e1a232	kmap_atomic_prot
++EXPORT_SYMBOL vmlinux 0xd3e6aa82	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0xd3fdc235	fsync_bdev
++EXPORT_SYMBOL vmlinux 0xd40e0393	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0xd41d64d5	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0xd41e2c46	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0xd43eb664	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0xd455f02f	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0xd45ac936	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0xd4835ef8	dmi_check_system
++EXPORT_SYMBOL vmlinux 0xd4a0bf7d	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0xd4ae7bb8	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0xd4ba7dcc	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0xd4ba8512	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0xd4be636a	__devm_release_region
++EXPORT_SYMBOL vmlinux 0xd4d7c91c	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0xd4e155d8	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0xd4fb4efd	cdrom_open
++EXPORT_SYMBOL vmlinux 0xd50398c4	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0xd50fef48	acpi_detach_data
++EXPORT_SYMBOL vmlinux 0xd5228c29	pv_cpu_ops
++EXPORT_SYMBOL vmlinux 0xd53d411e	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0xd53d8384	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd556b5f7	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0xd55b0303	filemap_fault
++EXPORT_SYMBOL vmlinux 0xd56c14c7	udp_poll
++EXPORT_SYMBOL vmlinux 0xd5816972	__quota_error
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd59abb84	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0xd59b5372	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0xd5c227b0	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0xd5d01d31	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0xd5d51c9c	blk_rq_init
++EXPORT_SYMBOL vmlinux 0xd5f52d4f	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd6454206	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd64f9900	block_truncate_page
++EXPORT_SYMBOL vmlinux 0xd684a99a	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd68e1d1b	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0xd6a16f49	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0xd6b16ddd	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0xd6b2ed5f	generate_pm_trace
++EXPORT_SYMBOL vmlinux 0xd6b33026	cpu_khz
++EXPORT_SYMBOL vmlinux 0xd6b551e5	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0xd6c64c47	dump_emit
++EXPORT_SYMBOL vmlinux 0xd6cf1372	isapnp_protocol
++EXPORT_SYMBOL vmlinux 0xd6e11259	key_put
++EXPORT_SYMBOL vmlinux 0xd6e2e11b	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd6ffaf2f	netlink_unicast
++EXPORT_SYMBOL vmlinux 0xd7038e24	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0xd71598ff	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0xd718ce32	__devm_request_region
++EXPORT_SYMBOL vmlinux 0xd730959d	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd76213eb	file_open_root
++EXPORT_SYMBOL vmlinux 0xd796016a	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0xd797b9a5	vme_master_write
++EXPORT_SYMBOL vmlinux 0xd79dca31	param_get_bool
++EXPORT_SYMBOL vmlinux 0xd79fcc20	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0xd7a0efd2	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0xd7b33008	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0xd7b3c5a3	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0xd7b47a85	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0xd7c17776	phy_attach
++EXPORT_SYMBOL vmlinux 0xd7dd777b	reserve_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd7f2403e	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0xd834b634	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0xd838e8e9	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0xd8431cb0	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0xd8511217	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0xd85833cb	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0xd85e8ded	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0xd861d0f7	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0xd862b783	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a870de	lookup_one_len
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8d79dbd	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd8f0512a	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0xd906f2b6	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0xd9091363	acpi_install_notify_handler
++EXPORT_SYMBOL vmlinux 0xd9129c84	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0xd92abcb3	make_kprojid
++EXPORT_SYMBOL vmlinux 0xd92d39db	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0xd92e2dca	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0xd94322e7	acpi_evaluate_reference
++EXPORT_SYMBOL vmlinux 0xd94f4a41	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0xd957fa29	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0xd966ddc2	__do_once_done
++EXPORT_SYMBOL vmlinux 0xd969b2c7	amd_e400_c1e_detected
++EXPORT_SYMBOL vmlinux 0xd971c6c4	xen_arch_register_cpu
++EXPORT_SYMBOL vmlinux 0xd98044ed	scsi_device_put
++EXPORT_SYMBOL vmlinux 0xd9805555	vc_resize
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd98d7af0	tty_free_termios
++EXPORT_SYMBOL vmlinux 0xd9a22331	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0xd9a8fc8d	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0xd9b7b30a	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xd9d3bcd3	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9ea9c83	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0xd9fc64cb	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0xd9ffb270	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0xda04c414	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0xda08c0d7	pcibios_get_irq_routing_table
++EXPORT_SYMBOL vmlinux 0xda2606ac	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda40dce8	dma_pool_create
++EXPORT_SYMBOL vmlinux 0xda45f15a	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0xda487be0	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0xda56b382	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0xda5cc583	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0xda658432	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda8fd495	isapnp_write_byte
++EXPORT_SYMBOL vmlinux 0xda9697c7	neigh_for_each
++EXPORT_SYMBOL vmlinux 0xda9d8acd	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0xdaa57ec3	totalhigh_pages
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdadfaa5c	read_code
++EXPORT_SYMBOL vmlinux 0xdae2640e	dev_mc_del
++EXPORT_SYMBOL vmlinux 0xdb16b170	topology_phys_to_logical_pkg
++EXPORT_SYMBOL vmlinux 0xdb40d4fe	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0xdb44ad8a	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0xdb54101d	padata_start
++EXPORT_SYMBOL vmlinux 0xdb62f260	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb7305a1	__stack_chk_fail
++EXPORT_SYMBOL vmlinux 0xdb73b15a	from_kprojid
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb7fc98b	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0xdb7fccc6	pnp_disable_dev
++EXPORT_SYMBOL vmlinux 0xdb870afd	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0xdb9c126f	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0xdbae5332	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0xdbafa0f7	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0xdbb45b2f	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0xdbc2eb63	vga_switcheroo_get_client_state
++EXPORT_SYMBOL vmlinux 0xdbc7079e	generic_readlink
++EXPORT_SYMBOL vmlinux 0xdbf79540	pci_bus_get
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc250298	led_set_brightness
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc48a93b	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdc57f532	acpi_install_gpe_handler
++EXPORT_SYMBOL vmlinux 0xdc71652e	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0xdcbdc352	pci_clear_master
++EXPORT_SYMBOL vmlinux 0xdcc05761	generic_write_checks
++EXPORT_SYMBOL vmlinux 0xdcc6170c	block_write_begin
++EXPORT_SYMBOL vmlinux 0xdcd1b990	bdgrab
++EXPORT_SYMBOL vmlinux 0xdcece50b	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0xdcef6221	skb_split
++EXPORT_SYMBOL vmlinux 0xdd0a2ba2	strlcat
++EXPORT_SYMBOL vmlinux 0xdd30f62c	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0xdd3a8794	dev_add_pack
++EXPORT_SYMBOL vmlinux 0xdd3dfcec	kunmap
++EXPORT_SYMBOL vmlinux 0xdd4e1664	vfs_getattr
++EXPORT_SYMBOL vmlinux 0xdd83ac3c	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0xddb37d02	proc_dointvec
++EXPORT_SYMBOL vmlinux 0xddb56ad4	simple_follow_link
++EXPORT_SYMBOL vmlinux 0xddbfcf54	set_groups
++EXPORT_SYMBOL vmlinux 0xddd15775	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0xddd43254	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0xddf8f16b	vc_cons
++EXPORT_SYMBOL vmlinux 0xde16dc16	tboot
++EXPORT_SYMBOL vmlinux 0xde18ce15	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0xde251ad3	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0xde3c7d62	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0xde3de9d2	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0xde478ebd	inet_sendpage
++EXPORT_SYMBOL vmlinux 0xde51cbc4	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xde6915bf	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde9b17ed	agp3_generic_fetch_size
++EXPORT_SYMBOL vmlinux 0xdeb4b2dc	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0xded931f3	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0xdedb6611	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0xdee686fa	uart_match_port
++EXPORT_SYMBOL vmlinux 0xdee8ad49	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0xdef8de12	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0xdf0da3cc	acpi_get_devices
++EXPORT_SYMBOL vmlinux 0xdf12a927	acpi_check_dsm
++EXPORT_SYMBOL vmlinux 0xdf13f31b	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0xdf1427e5	idr_remove
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf2c5011	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0xdf2d0175	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0xdf2e2a3c	dev_driver_string
++EXPORT_SYMBOL vmlinux 0xdf3a693d	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0xdf47655a	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0xdf4fc797	__register_nmi_handler
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf5b0960	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf6f4f87	nvm_register_target
++EXPORT_SYMBOL vmlinux 0xdf897ac7	unregister_console
++EXPORT_SYMBOL vmlinux 0xdf8b8837	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0xdf8c695a	__ndelay
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdf93b9d8	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0xdf946a65	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0xdf9b4aa1	dst_release
++EXPORT_SYMBOL vmlinux 0xdfa8447b	get_acl
++EXPORT_SYMBOL vmlinux 0xdfaea400	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0xdfb6406d	kernel_bind
++EXPORT_SYMBOL vmlinux 0xdfc16cfa	bio_init
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xdfc94b1a	input_register_handle
++EXPORT_SYMBOL vmlinux 0xdfd3a075	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0xdfe0b2fe	input_event
++EXPORT_SYMBOL vmlinux 0xdfe44d35	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xe00195b7	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0xe00e1a5c	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0xe0247756	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe05f33e9	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe0778682	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe08f148b	pnp_device_attach
++EXPORT_SYMBOL vmlinux 0xe0a16a20	intel_scu_ipc_i2c_cntrl
++EXPORT_SYMBOL vmlinux 0xe0ac8bd2	acpi_bus_generate_netlink_event
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0b2adc4	cros_ec_cmd_xfer
++EXPORT_SYMBOL vmlinux 0xe1024410	blkdev_put
++EXPORT_SYMBOL vmlinux 0xe112fdd3	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0xe12f2fb9	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe13cd8a7	dmi_name_in_vendors
++EXPORT_SYMBOL vmlinux 0xe1546095	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0xe15b08a9	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe17f5d27	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0xe188f816	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0xe189e7a2	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0xe18a223a	__register_chrdev
++EXPORT_SYMBOL vmlinux 0xe18c814c	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xe19e7a92	scsi_device_get
++EXPORT_SYMBOL vmlinux 0xe1a211aa	inet6_protos
++EXPORT_SYMBOL vmlinux 0xe1acc704	pci_disable_device
++EXPORT_SYMBOL vmlinux 0xe1b06b41	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0xe1dee864	__find_get_block
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe20391cb	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0xe221668c	sock_no_listen
++EXPORT_SYMBOL vmlinux 0xe2325f13	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe259ae9e	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2a8aec7	netlink_set_err
++EXPORT_SYMBOL vmlinux 0xe2a98e0c	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2e2b8c1	vfs_writef
++EXPORT_SYMBOL vmlinux 0xe2e8065e	memdup_user
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe2fae716	kmemdup
++EXPORT_SYMBOL vmlinux 0xe2ff7e4f	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xe3197208	proc_dostring
++EXPORT_SYMBOL vmlinux 0xe319eb24	acpi_pci_osc_control_set
++EXPORT_SYMBOL vmlinux 0xe330092a	agp_bridge
++EXPORT_SYMBOL vmlinux 0xe338fdb3	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0xe3399a75	native_queued_spin_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xe3889710	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0xe39c5d0e	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0xe3a2705a	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3c863dc	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0xe3d1b30c	load_nls
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3da2870	bdi_register
++EXPORT_SYMBOL vmlinux 0xe3e4ea50	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0xe3fa0635	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0xe3fb6c55	finish_open
++EXPORT_SYMBOL vmlinux 0xe40b3715	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0xe4200aa1	skb_pad
++EXPORT_SYMBOL vmlinux 0xe42fda60	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0xe445db4a	acpi_check_address_range
++EXPORT_SYMBOL vmlinux 0xe4536094	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0xe47530f5	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0xe475e6b1	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0xe484e35f	ioread32
++EXPORT_SYMBOL vmlinux 0xe48c8a09	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0xe48e0a51	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0xe4b77305	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0xe4c17741	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0xe4c1cba7	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0xe4cce6f7	set_disk_ro
++EXPORT_SYMBOL vmlinux 0xe4daa3c7	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe50f904f	intel_scu_ipc_ioread16
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe528a3c8	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0xe52b805a	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0xe530d757	acpi_clear_gpe
++EXPORT_SYMBOL vmlinux 0xe540eb1b	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0xe5479e33	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0xe56cf129	kset_unregister
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe57d10cf	dev_uc_init
++EXPORT_SYMBOL vmlinux 0xe5815f8a	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe58bf807	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0xe5949a97	__nd_iostat_start
++EXPORT_SYMBOL vmlinux 0xe596dd79	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0xe5b28747	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0xe5b40047	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0xe5bacf65	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5ec60a5	dst_init
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe5f16a5a	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0xe6162877	down_killable
++EXPORT_SYMBOL vmlinux 0xe62ee578	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0xe632f9b2	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0xe636cd14	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0xe64d98fe	rdmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0xe657fe92	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0xe6711c43	km_policy_expired
++EXPORT_SYMBOL vmlinux 0xe67c941c	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0xe693a6ce	vme_get_size
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe697d498	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0xe6b281b7	sock_release
++EXPORT_SYMBOL vmlinux 0xe6c588e7	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0xe6d9f2a4	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0xe6eae207	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0xe6ebab82	dqput
++EXPORT_SYMBOL vmlinux 0xe6ebc016	key_create_or_update
++EXPORT_SYMBOL vmlinux 0xe6ee4f8d	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe70d7038	netdev_change_features
++EXPORT_SYMBOL vmlinux 0xe7121f9d	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0xe716baed	acpi_unregister_ioapic
++EXPORT_SYMBOL vmlinux 0xe71ff1ab	__vfs_write
++EXPORT_SYMBOL vmlinux 0xe7758f4f	proto_register
++EXPORT_SYMBOL vmlinux 0xe781b5f6	intel_scu_ipc_readv
++EXPORT_SYMBOL vmlinux 0xe78c266b	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0xe7952efd	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7afbf73	__serio_register_port
++EXPORT_SYMBOL vmlinux 0xe7b6315e	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xe7bccdc4	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0xe7c5ad5e	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0xe7caa30e	sk_alloc
++EXPORT_SYMBOL vmlinux 0xe7ccc205	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7de18f7	tty_do_resize
++EXPORT_SYMBOL vmlinux 0xe7fece48	pci_bus_type
++EXPORT_SYMBOL vmlinux 0xe813b4ad	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0xe816916c	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0xe81b1d11	bio_put
++EXPORT_SYMBOL vmlinux 0xe81ef1dd	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe82ec8ec	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0xe8324477	key_unlink
++EXPORT_SYMBOL vmlinux 0xe83f27c8	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0xe84e11a0	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0xe87025f0	acpi_evaluate_object_typed
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe87b2edd	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0xe88bc9ef	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0xe8912d2a	simple_dname
++EXPORT_SYMBOL vmlinux 0xe89e62fe	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8b61f14	generic_read_dir
++EXPORT_SYMBOL vmlinux 0xe8b68849	wrmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0xe8bb8bca	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8c97b2c	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xe8db8dd2	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe93f6042	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0xe94f068e	fb_show_logo
++EXPORT_SYMBOL vmlinux 0xe94ff699	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe95e00cf	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0xe9782924	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0xe97cd794	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0xe9935870	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0xe997667b	wrmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xe9aa334b	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0xe9acfac4	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xe9b73c0a	get_task_io_context
++EXPORT_SYMBOL vmlinux 0xe9b8c139	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0xe9da85ab	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0xe9ec943e	generic_make_request
++EXPORT_SYMBOL vmlinux 0xe9f154b4	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea1472cc	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0xea2ac245	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0xea3f725d	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xea44f132	inet_listen
++EXPORT_SYMBOL vmlinux 0xea48708b	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0xea76ffdb	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0xea7987f1	key_update
++EXPORT_SYMBOL vmlinux 0xea7a42f9	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xea7b8a44	acpi_install_interface
++EXPORT_SYMBOL vmlinux 0xea83e4a2	md_register_thread
++EXPORT_SYMBOL vmlinux 0xea8575fb	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0xea8a4b55	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xea90bdd3	acpi_attach_data
++EXPORT_SYMBOL vmlinux 0xea9e741b	get_phy_device
++EXPORT_SYMBOL vmlinux 0xeaa2cf50	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0xead37484	follow_down_one
++EXPORT_SYMBOL vmlinux 0xeae3dfd6	__const_udelay
++EXPORT_SYMBOL vmlinux 0xeae3eda4	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0xeae8cefa	wireless_send_event
++EXPORT_SYMBOL vmlinux 0xeaf4d40e	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0xeb017985	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0xeb0ec7b3	sock_i_uid
++EXPORT_SYMBOL vmlinux 0xeb290245	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb371a53	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0xeb44404e	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0xeb527d0f	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0xeb55a931	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xeb969f1a	scsi_print_command
++EXPORT_SYMBOL vmlinux 0xeba70207	clk_get
++EXPORT_SYMBOL vmlinux 0xebb322fd	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0xebb3e61e	__napi_complete
++EXPORT_SYMBOL vmlinux 0xebff5cf5	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0xec091659	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0xec0e9ccd	dev_deactivate
++EXPORT_SYMBOL vmlinux 0xec10eb01	pci_find_bus
++EXPORT_SYMBOL vmlinux 0xec1aa6ef	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xec1e5d57	netdev_crit
++EXPORT_SYMBOL vmlinux 0xec214050	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec6db012	sk_net_capable
++EXPORT_SYMBOL vmlinux 0xec784d44	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0xecbb5d7d	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0xecbcb8bb	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xeccd3e0c	acpi_handle_printk
++EXPORT_SYMBOL vmlinux 0xecd5b740	dev_emerg
++EXPORT_SYMBOL vmlinux 0xece187c2	phy_start
++EXPORT_SYMBOL vmlinux 0xece69dbd	follow_pfn
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xecf48cdc	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0xecfc80f5	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0xecfd85a5	agp_generic_insert_memory
++EXPORT_SYMBOL vmlinux 0xed184090	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0xed54d6f9	nd_namespace_blk_validate
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed73c3ac	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0xed93f29e	__kunmap_atomic
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedb41269	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedc39fd0	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0xedd1e4ba	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0xeded8779	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xedfcf702	dquot_get_state
++EXPORT_SYMBOL vmlinux 0xee11f82a	generic_show_options
++EXPORT_SYMBOL vmlinux 0xee154ae0	pci_select_bars
++EXPORT_SYMBOL vmlinux 0xee1abb39	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0xee25e124	skb_copy
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee3563a1	tso_start
++EXPORT_SYMBOL vmlinux 0xee64efb4	__genl_register_family
++EXPORT_SYMBOL vmlinux 0xee7b11a1	kobject_get
++EXPORT_SYMBOL vmlinux 0xee7eb9e1	pnp_platform_devices
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xeea7ae56	pnp_unregister_driver
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeec2c7cf	ucs2_as_utf8
++EXPORT_SYMBOL vmlinux 0xeec957da	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0xeed30eb9	from_kgid
++EXPORT_SYMBOL vmlinux 0xeee37179	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0xeee70824	init_task
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xeef2d845	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0xeefcf21b	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0xeefd2a13	iget5_locked
++EXPORT_SYMBOL vmlinux 0xef02cf09	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0xef179d55	ppp_input
++EXPORT_SYMBOL vmlinux 0xef70c1a1	acpi_get_hp_hw_control_from_firmware
++EXPORT_SYMBOL vmlinux 0xef76000a	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0xef89117e	gnttab_free_pages
++EXPORT_SYMBOL vmlinux 0xef972c1c	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0xef9aedfc	boot_option_idle_override
++EXPORT_SYMBOL vmlinux 0xefaeb64f	netdev_warn
++EXPORT_SYMBOL vmlinux 0xefd07660	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefda8d99	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xefdd0978	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefe099c3	acpi_get_event_status
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf0058440	mutex_trylock
++EXPORT_SYMBOL vmlinux 0xf00cd39e	tty_write_room
++EXPORT_SYMBOL vmlinux 0xf01441f8	sk_dst_check
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf05045e9	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf062576b	ucs2_utf8size
++EXPORT_SYMBOL vmlinux 0xf065f629	ioread16be
++EXPORT_SYMBOL vmlinux 0xf0671e03	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0xf067257c	register_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0xf07b8c35	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0xf07da9b8	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0xf08242c2	finish_wait
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0bf270b	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xf0c218a1	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xf0dd912e	cros_ec_prepare_tx
++EXPORT_SYMBOL vmlinux 0xf0e30ebf	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0xf0e530ee	down_write
++EXPORT_SYMBOL vmlinux 0xf0eaffce	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf10de535	ioread8
++EXPORT_SYMBOL vmlinux 0xf11543ff	find_first_zero_bit
++EXPORT_SYMBOL vmlinux 0xf117e8a7	napi_disable
++EXPORT_SYMBOL vmlinux 0xf126e885	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0xf12d54df	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xf1398e2e	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xf13daeae	set_pages_wb
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf14d8d27	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0xf1535796	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0xf153a9f4	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0xf1687b4b	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0xf1700da8	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0xf177bbdf	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0xf18242e1	atomic64_set_cx8
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1dbcba8	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0xf1deabf2	div64_u64
++EXPORT_SYMBOL vmlinux 0xf1e0a57e	phy_print_status
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf20567d5	__block_write_begin
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf22ea90c	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0xf23b3c07	phy_device_register
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf26bc471	first_ec
++EXPORT_SYMBOL vmlinux 0xf28ed6e2	machine_to_phys_nr
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2ad74df	d_splice_alias
++EXPORT_SYMBOL vmlinux 0xf2ae9606	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2de1c62	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0xf2f5a555	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0xf312cb9d	ucs2_strsize
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf313eb4e	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0xf31ad482	agp_generic_destroy_page
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf3517fe2	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0xf35396eb	sock_i_ino
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf35b60db	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0xf362a642	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0xf36a22d3	acpi_pm_device_run_wake
++EXPORT_SYMBOL vmlinux 0xf3761d75	phy_init_hw
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf3986b06	acpi_os_map_generic_address
++EXPORT_SYMBOL vmlinux 0xf39b6d45	agp_allocate_memory
++EXPORT_SYMBOL vmlinux 0xf3d80e7e	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0xf3e0c631	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf40162a3	neigh_xmit
++EXPORT_SYMBOL vmlinux 0xf406410f	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0xf40b2297	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xf41fa52f	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0xf441ac43	ioread8_rep
++EXPORT_SYMBOL vmlinux 0xf4467bef	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0xf44e9632	generic_write_end
++EXPORT_SYMBOL vmlinux 0xf45c0666	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf4a5c213	avail_to_resrv_perfctr_nmi_bit
++EXPORT_SYMBOL vmlinux 0xf4b754fd	acpi_resources_are_enforced
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4bea797	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0xf4cd1569	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0xf4d3cf37	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0xf4db2967	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf50175b5	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0xf502d273	acpi_get_current_resources
++EXPORT_SYMBOL vmlinux 0xf502fcd0	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0xf5074e93	dev_notice
++EXPORT_SYMBOL vmlinux 0xf51ae235	touch_nmi_watchdog
++EXPORT_SYMBOL vmlinux 0xf5238b60	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0xf536d22e	acpi_set_gpe_wake_mask
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf54ef472	simple_rmdir
++EXPORT_SYMBOL vmlinux 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL vmlinux 0xf5a77ecc	arp_send
++EXPORT_SYMBOL vmlinux 0xf5adf797	seq_open_private
++EXPORT_SYMBOL vmlinux 0xf5b10e67	acpi_install_global_event_handler
++EXPORT_SYMBOL vmlinux 0xf5b7c1d1	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5dbf400	__seq_open_private
++EXPORT_SYMBOL vmlinux 0xf5dce586	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0xf5e4e88c	param_get_long
++EXPORT_SYMBOL vmlinux 0xf5e5a3a1	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf61d3fa4	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0xf62a70d4	irq_set_chip
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf66ad7d0	vfs_statfs
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf67ebbe2	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf6873546	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0xf6899c5a	acpi_get_possible_resources
++EXPORT_SYMBOL vmlinux 0xf689fcf5	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0xf69364b8	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0xf693a145	irq_stat
++EXPORT_SYMBOL vmlinux 0xf699aeb4	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0xf6b17c99	bio_chain
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6bdf8bf	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xf6be91fc	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0xf6ccd0e8	dev_mc_add
++EXPORT_SYMBOL vmlinux 0xf6cf6ae8	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0xf6df747d	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0xf6e220b1	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0xf6e8c493	give_up_console
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf71174b6	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0xf712c8aa	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0xf726d02f	atomic64_add_unless_cx8
++EXPORT_SYMBOL vmlinux 0xf72ccadc	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0xf72ea72d	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0xf72eba7d	vga_get
++EXPORT_SYMBOL vmlinux 0xf736a986	current_in_userns
++EXPORT_SYMBOL vmlinux 0xf745cb16	atomic64_sub_return_cx8
++EXPORT_SYMBOL vmlinux 0xf75178b7	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0xf753c5ec	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0xf7553f5f	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf764868a	udplite_table
++EXPORT_SYMBOL vmlinux 0xf771eb9e	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0xf7800caa	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0xf788424d	register_sysctl
++EXPORT_SYMBOL vmlinux 0xf7891779	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xf79b5243	nvdimm_namespace_common_probe
++EXPORT_SYMBOL vmlinux 0xf79e97cd	acpi_get_physical_device_location
++EXPORT_SYMBOL vmlinux 0xf7a2fa89	dev_open
++EXPORT_SYMBOL vmlinux 0xf7b7b94c	pnp_find_card
++EXPORT_SYMBOL vmlinux 0xf7c4514b	request_firmware
++EXPORT_SYMBOL vmlinux 0xf7c75efe	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0xf7c9e039	sock_init_data
++EXPORT_SYMBOL vmlinux 0xf7d09729	pmem_should_map_pages
++EXPORT_SYMBOL vmlinux 0xf7e2bf17	vme_irq_request
++EXPORT_SYMBOL vmlinux 0xf7ea1915	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0xf7ea503e	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0xf8050fac	acpi_evaluate_object
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf8307a25	mapping_tagged
++EXPORT_SYMBOL vmlinux 0xf839286e	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0xf8482427	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0xf876ab21	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0xf88e0ee2	acpi_get_table_header
++EXPORT_SYMBOL vmlinux 0xf89e6a80	__brelse
++EXPORT_SYMBOL vmlinux 0xf8a38cdb	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0xf8b3ecfe	devm_free_irq
++EXPORT_SYMBOL vmlinux 0xf8bb6de9	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0xf8ec3cdc	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0xf8efa43e	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf908c78e	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0xf9091a35	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0xf913fa34	key_validate
++EXPORT_SYMBOL vmlinux 0xf924e7b4	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0xf9348cbc	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xf946638c	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0xf96d4ba9	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0xf975ca2e	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0xf99b7c69	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9aa5f2f	bio_split
++EXPORT_SYMBOL vmlinux 0xf9c37861	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0xf9c52317	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0xf9cb98a0	ps2_command
++EXPORT_SYMBOL vmlinux 0xf9d88d18	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0xf9dd0e61	eth_header_cache
++EXPORT_SYMBOL vmlinux 0xf9e73082	scnprintf
++EXPORT_SYMBOL vmlinux 0xf9eb1ae6	keyring_alloc
++EXPORT_SYMBOL vmlinux 0xf9fb73ff	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0xf9fc68b1	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0xf9ff9c83	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0xfa2f76f9	param_set_ullong
++EXPORT_SYMBOL vmlinux 0xfa37d24e	drop_nlink
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa574417	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0xfa577eff	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa6f3d3a	get_disk
++EXPORT_SYMBOL vmlinux 0xfa764936	__bread_gfp
++EXPORT_SYMBOL vmlinux 0xfa78ac9e	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0xfa8608f9	serio_reconnect
++EXPORT_SYMBOL vmlinux 0xfa9b7364	__get_user_pages
++EXPORT_SYMBOL vmlinux 0xfa9b8e95	udp_ioctl
++EXPORT_SYMBOL vmlinux 0xfaad11c0	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xfad72d4e	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0xfade5264	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfafe9913	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0xfb0443fb	acpi_get_parent
++EXPORT_SYMBOL vmlinux 0xfb249197	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0xfb28de91	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0xfb2c5b8a	up_write
++EXPORT_SYMBOL vmlinux 0xfb2e8071	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0xfb351660	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0xfb3e2798	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0xfb468e2f	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0xfb4bbf88	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xfb63659e	vga_put
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb6e6146	set_trace_device
++EXPORT_SYMBOL vmlinux 0xfb707fc3	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0xfb80c7a0	acpi_walk_namespace
++EXPORT_SYMBOL vmlinux 0xfb8411ba	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0xfb8c21e8	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbb76a21	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0xfbbd1d4b	eisa_driver_register
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbd12b07	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xfbd59fba	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0xfbd71298	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0xfbf898aa	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc217201	flush_signals
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc47c8d8	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0xfc485219	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0xfc50143a	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0xfc562165	acpi_run_osc
++EXPORT_SYMBOL vmlinux 0xfc65459a	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0xfc6a4d9e	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0xfc734327	queued_read_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xfc872fd1	get_ibs_caps
++EXPORT_SYMBOL vmlinux 0xfc8bd242	dquot_alloc
++EXPORT_SYMBOL vmlinux 0xfc8e7a0c	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0xfca44d66	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0xfca7281a	udplite_prot
++EXPORT_SYMBOL vmlinux 0xfcac0d40	acpi_install_interface_handler
++EXPORT_SYMBOL vmlinux 0xfcbc9c92	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcc34c6e	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xfcc7ea83	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0xfcd67ff8	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfcfe0ed1	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0xfd1e5b2b	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0xfd33b5fa	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xfd5158a8	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0xfd5f431c	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0xfd6d938c	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0xfd72d809	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0xfd8d7725	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfd99b95c	kfree_skb
++EXPORT_SYMBOL vmlinux 0xfda182c5	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0xfdb9b629	ioread32be
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfdeddc2b	vfs_readv
++EXPORT_SYMBOL vmlinux 0xfdf1726a	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfdfc49a8	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0xfdfd6c90	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe047ce6	acpi_enter_sleep_state
++EXPORT_SYMBOL vmlinux 0xfe13c522	acpi_install_gpe_raw_handler
++EXPORT_SYMBOL vmlinux 0xfe4201cc	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0xfe44c90e	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0xfe5400cf	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0xfe5d30e9	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe5e7cb2	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0xfe6729fa	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0xfe6a1108	bdi_destroy
++EXPORT_SYMBOL vmlinux 0xfe7c18f1	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe9ebbbb	acpi_osi_is_win8
++EXPORT_SYMBOL vmlinux 0xfea2d11b	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0xfeb3a246	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0xfeb56c9c	locks_free_lock
++EXPORT_SYMBOL vmlinux 0xfec52728	kmap
++EXPORT_SYMBOL vmlinux 0xfeca7590	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfee4e69d	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0xfeeb6c7b	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0xfef2c78f	idr_get_next
++EXPORT_SYMBOL vmlinux 0xfeff7368	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0xff05088d	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff35d3ee	default_llseek
++EXPORT_SYMBOL vmlinux 0xff42eebf	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0xff480992	dump_fpu
++EXPORT_SYMBOL vmlinux 0xff486019	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0xff492250	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0xff49bc99	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0xff4c0006	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0xff63b514	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff6c521d	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff89d375	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff90920d	__destroy_inode
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffa73cda	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0xffac0162	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0xffb00ae0	d_invalidate
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-i586 0x7060bf0a	crypto_aes_encrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-i586 0xe409b491	crypto_aes_decrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x8a555f59	glue_cbc_decrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x8f02ac4d	glue_xts_crypt_128bit_one
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x91382921	glue_ecb_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x9a6780ac	glue_xts_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xa19a3731	glue_cbc_encrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xd89d24e6	glue_ctr_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-i586 0x28afd262	twofish_enc_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-i586 0x6f068d90	twofish_dec_blk
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x00aaf935	kvm_disable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x00ace5af	kvm_cpu_get_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0270da87	kvm_init_shadow_ept_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x03e3e650	kvm_vcpu_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x045c3678	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x046f768b	reprogram_gp_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0531c1a2	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x09b309c8	kvm_arch_unregister_noncoherent_dma
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0be2b8aa	kvm_vcpu_is_reset_bsp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0f48d5a3	kvm_io_bus_write
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0fe5b8fd	kvm_apic_write_nodecode
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x13b017c0	kvm_set_cr8
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x14165476	kvm_x86_ops
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x175aea24	kvm_write_guest_virt_system
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1c581db2	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1d201515	kvm_vcpu_gfn_to_hva
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1db25587	reprogram_fixed_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2124f042	kvm_read_guest_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x22f59eaa	gfn_to_hva
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x232c3418	kvm_mmu_unprotect_page_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x232eb70f	kvm_vcpu_write_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x236fa151	kvm_lapic_set_eoi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x287fafd4	gfn_to_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2aaa9af6	kvm_queue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2c328258	kvm_cpu_has_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2c78b8d4	__gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2c9a01fb	kvm_set_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2f636c31	kvm_spurious_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2fb5927f	kvm_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x30e40361	kvm_set_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x314cc5cb	kvm_get_dirty_log_protect
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x317f9e6b	kvm_enable_efer_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x320a6bf6	kvm_debugfs_dir
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x327f5731	kvm_vcpu_reload_apic_access_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x34435d49	kvm_mtrr_valid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x35aa5509	kvm_scale_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x35c5bfaf	kvm_put_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x36ff21fc	__tracepoint_kvm_nested_vmexit_inject
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3849ae3e	__tracepoint_kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x38f0e9f1	kvm_vcpu_block
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x39901f4a	kvm_set_xcr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3ad4c827	kvm_get_dirty_log
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3c1fa318	kvm_vcpu_mark_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3c339163	kvm_get_cr8
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3c5237c6	kvm_mtrr_get_guest_memory_type
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3cf52b78	kvm_get_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3e094575	__tracepoint_kvm_pml_full
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3e1f72e0	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3e70c29f	x86_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x40ce1e45	__tracepoint_kvm_inj_virq
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x415a6c19	kvm_read_l1_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4170a987	kvm_mmu_reset_context
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x43f4230c	__tracepoint_kvm_write_tsc_offset
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x465c0f0f	kvm_get_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x466a6fed	kvm_mmu_unload
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x49252cef	kvm_get_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4e8eb093	kvm_get_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x520b630d	kvm_set_cr4
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x52a6ac4e	kvm_mmu_slot_largepage_remove_write_access
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x59e8aa38	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5a08c102	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5ad748e1	kvm_inject_realmode_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5bcfed61	kvm_clear_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5d52703f	kvm_require_cpl
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5ed0a7f4	kvm_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x61ee2a39	__x86_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x62404522	kvm_get_linear_rip
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x62a348eb	kvm_mmu_invlpg
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x64020e10	kvm_set_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6502aaf3	kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x68138a79	__tracepoint_kvm_nested_intercepts
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x683f8625	kvm_arch_end_assignment
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6c395b7e	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6d3667c9	kvm_requeue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6fd59508	kvm_inject_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x70b0a861	kvm_vcpu_read_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x72bb629b	kvm_valid_efer
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x73eeb83e	kvm_mmu_unprotect_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x741b8ce0	kvm_arch_has_noncoherent_dma
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x75205135	kvm_inject_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7771c3fb	gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x79620bbe	kvm_apic_update_irr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7bc3672b	kvm_set_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7c59e22e	__tracepoint_kvm_ple_window
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x80bda2e6	kvm_vcpu_write_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x80ecfb6b	__tracepoint_kvm_skinit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8145ce8d	kvm_get_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x831327da	kvm_max_guest_tsc_khz
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8325c4a6	kvm_vcpu_gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x834b0c39	kvm_write_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8361cf32	kvm_apic_set_eoi_accelerated
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x86b3eca8	kvm_get_cs_db_l_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8b5d0c4e	gfn_to_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8ce4f3ab	kvm_enable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8cea86d0	kvm_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8e4017a7	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8e6a2197	kvm_mmu_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x905ed6e9	kvm_mmu_clear_dirty_pt_masked
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x912b804e	kvm_lmsw
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9133eb2c	kvm_write_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x919a285d	kvm_arch_start_assignment
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x92d713dd	__tracepoint_kvm_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x953c54a9	reset_shadow_zero_bits_mask
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x96dbe382	kvm_mpx_supported
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x982a0040	kvm_after_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x982cd932	__tracepoint_kvm_nested_vmrun
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x99499db1	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9a216313	kvm_define_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9c171a59	__tracepoint_kvm_cr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9cf2d41a	kvm_task_switch
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9e0a65d0	__tracepoint_kvm_nested_intr_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa0ec3a0a	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa1f1106a	kvm_vcpu_gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa383abf6	kvm_complete_insn_gp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa39c7e38	kvm_require_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa476ac1d	vcpu_load
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa70f0d98	kvm_read_guest_page_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa981e879	kvm_mmu_slot_leaf_clear_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xacf7f97c	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xad60a00f	kvm_queue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xadfa5b83	kvm_find_cpuid_entry
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaebb3af6	kvm_vcpu_gfn_to_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb077e0b4	kvm_vcpu_read_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb2a92eb8	load_pdptrs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb2c6d9bd	kvm_read_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb3a2b459	kvm_fast_pio_out
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb46d3876	vcpu_put
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb4703e3d	kvm_mmu_sync_roots
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb4b8fe3b	kvm_read_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb96b2c7d	kvm_get_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xba9ed435	kvm_mmu_set_mmio_spte_mask
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbb5d05e6	kvm_set_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbd002e2a	kvm_set_cr3
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc1d9a6fb	mark_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc23f3bc8	__tracepoint_kvm_pi_irte_update
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc31c053a	kvm_mmu_slot_set_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc346e7fb	kvm_arch_has_assigned_device
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc56d75ce	__kvm_apic_update_irr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc599bc18	kvm_max_tsc_scaling_ratio
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc6afa13d	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc85a0f23	handle_mmio_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcb0564d6	kvm_flush_remote_tlbs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xccab21c8	kvm_vcpu_halt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcce40fd3	kvm_mmu_load
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcd6181f8	kvm_set_msi_irq
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xce545991	kvm_set_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0459e67	kvm_has_tsc_control
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0b2727a	kvm_mmu_set_mask_ptes
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd79a3b70	kvm_requeue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd7c404c5	kvm_emulate_wbinvd
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd7eb738b	__tracepoint_kvm_fast_mmio
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd88c4061	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd907274a	kvm_is_linear_rip
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd93bbd46	gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xda11af86	__tracepoint_kvm_nested_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdafd91ad	kvm_inject_pending_timer_irqs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdb493365	kvm_intr_is_single_vcpu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdb698aa3	kvm_emulate_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdbb2b289	kvm_set_cr0
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdc7c6423	kvm_rdpmc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xde856085	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xde8ccad5	kvm_before_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xde9c017c	__tracepoint_kvm_invlpga
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdf572aba	kvm_init_shadow_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdfcf0bbf	kvm_write_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe1a2adb6	kvm_release_page_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe912e32a	cpuid_query_maxphyaddr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe967776d	kvm_arch_register_noncoherent_dma
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xefc7ee0c	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xefed90db	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf2f286c4	kvm_tsc_scaling_ratio_frac_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf3882caa	kvm_emulate_hypercall
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf4a2e1ae	reprogram_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfb37863c	kvm_vcpu_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfb900076	x86_emulate_instruction
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfcfefd8f	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfd150053	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfd58d9c8	kvm_emulate_halt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfdc68132	__tracepoint_kvm_page_fault
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x28e38c6e	ablk_set_key
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x49b42440	ablk_init_common
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x7e1cdb55	ablk_init
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xbc70b8ad	__ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xc4fdbab1	ablk_exit
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xc85401ed	ablk_decrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0xcc449891	ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/af_alg 0x0d838c35	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0x11badcb8	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0x6865a705	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0x8a0c049a	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0x96f1582d	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0xae94760b	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xb384f277	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xc724ce32	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xd0f70829	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xf2ea715a	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0xf7eb9e52	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x2c1f6335	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x3f410258	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0xca54ed7b	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x9a0c11e9	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0xbc3e98bc	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x485a4399	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x9a181ad2	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xaf18d6e0	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xd6228067	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x0ca40a7e	async_xor
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x1a81282b	async_xor_val
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x370f8546	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0xbb6da58c	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0xaaf6b4ba	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x3a374b4d	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x952dee36	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/cryptd 0x54933aea	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x59d2ca54	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x66b7f5bc	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x8317b7e2	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x966e955a	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x96a61135	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0xa477203b	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0xb95964c3	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xe7cd429a	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xeaebc2e7	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/lrw 0xdf6b1ce5	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x14bdd4d3	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x2cadc60c	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x43364c7d	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x4d1af656	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xd3ab03c5	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xe6fc3b88	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xf09e7ad4	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xf687db2c	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xfcc34001	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3cfff71a	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x9292e0ed	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xb5ad50af	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xc5f8734a	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0xcd54e64b	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x3b1cbeca	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0xcdb0841c	xts_crypt
++EXPORT_SYMBOL_GPL drivers/acpi/nfit 0xb68fbc18	acpi_nfit_init
++EXPORT_SYMBOL_GPL drivers/acpi/nfit 0xe418edc7	acpi_nfit_attribute_groups
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x1c8984c7	acpi_smbus_unregister_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x87bd07bd	acpi_smbus_register_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xb9a141b0	acpi_smbus_read
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xe1372311	acpi_smbus_write
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x3b032d05	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x473829ed	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x47e43b2e	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x52d07f0d	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x57abfb3c	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x5e434624	ahci_qc_issue
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x6ecc9088	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x71c38e14	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x81749c58	ahci_host_activate
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x863c7bf3	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8c5026c4	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x9992f3e0	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x9e90d363	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xb360f0fb	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc07b90cd	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc11790cd	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc230c141	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc3e5b2de	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc73f6d46	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xd620d95f	ahci_error_handler
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xdbbaeea3	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe7f55d7c	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xec8f7ec2	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x052dfac3	ahci_platform_suspend_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x1692b182	ahci_platform_suspend
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x30b98b09	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x30e2234c	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x6165edff	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x709ff0e9	ahci_platform_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xb3cdc4a3	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xb4b655cb	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xb8896826	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xd061d754	ahci_platform_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xe1f4a15b	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xf318dcb5	ahci_platform_resume_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xf3a64fbd	ahci_platform_init_host
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0xa1943188	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x02ff9464	cfag12864b_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x0ecb2e5d	cfag12864b_disable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x305dc3c6	cfag12864b_isenabled
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x3389f926	cfag12864b_enable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x9522a342	cfag12864b_getrate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0xc48e9d95	cfag12864b_buffer
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x297798ba	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x353c96bd	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xd3f94e7c	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xf4962b2d	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x0d7ff991	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x11669dac	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3aa5757d	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x481b09e9	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x605492fc	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6e096ec1	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x7152353e	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x73d4df91	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x778c3207	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x80a30b61	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x84f12b7a	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x8a776233	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x997eb506	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc042b794	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc20447c6	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xcab6c873	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdae27c47	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdff05795	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe0dfe6e5	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe2f32b44	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe3dbf119	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe9ec636c	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xef4ec4db	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xfbc88f2f	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x0a57c4f3	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x259ec0fc	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x27f3d503	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xd547390d	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xeaeb1d6e	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xef02b4c6	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x1e059ffa	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x1e3c70d1	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x28fb0b41	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x4eaa4317	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x5cfebfb2	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x63610c0d	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x6cd95538	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x98f2d0f2	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xb7d06720	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xd92b310d	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xf53cdd47	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xfff3aecb	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x0685249d	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x12430ce6	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x52d14580	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x6c3ed47f	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x7934f2df	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x942ecf37	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xb43329ee	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xbe514773	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xc299af03	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xc97a642a	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xca9dc946	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0xdff3bef0	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0xe7d27398	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0x597802c5	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0xb715d908	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/char/scx200_gpio 0x835313fc	scx200_gpio_ops
++EXPORT_SYMBOL_GPL drivers/crypto/ccp/ccp 0x04773b60	ccp_present
++EXPORT_SYMBOL_GPL drivers/crypto/ccp/ccp 0x1a968516	ccp_enqueue_cmd
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x0093666d	adf_disable_sriov
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x06935bcc	adf_init_etr_data
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x0e755c70	adf_dev_put
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x10160269	adf_cleanup_etr_data
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x1486b286	adf_init_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x24b11dd6	adf_cfg_dev_remove
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x2ec5150e	adf_dev_stop
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x30a65bb1	adf_init_admin_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x4a8b4106	adf_send_admin_init
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x4c12ea06	adf_response_handler
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x51d372cc	adf_devmgr_in_reset
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x5e36e125	adf_service_unregister
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x79d1eb10	adf_iov_putmsg
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x7e2d3a4d	adf_service_register
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x84e99952	adf_exit_admin_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x8e4fe09b	adf_dev_init
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x90f26552	adf_cfg_dev_add
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x91c11df3	adf_enable_pf2vf_interrupts
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x98950643	adf_dev_shutdown
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x98e5c042	adf_cfg_section_add
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xa6031dda	adf_sriov_configure
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xa7cff3d2	adf_update_ring_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xa916fe42	adf_cfg_add_key_value_param
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xb6fc9819	adf_dev_in_use
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xbb4316f2	adf_enable_vf2pf_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc3a77de7	adf_devmgr_update_class_index
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc406b455	adf_devmgr_pci_to_accel_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc69aed4e	adf_devmgr_add_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc903b01a	adf_disable_aer
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc9836a01	adf_dev_get
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xcb1e4476	adf_dev_start
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xcc3b167a	adf_clean_vf_map
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd7616933	adf_dev_started
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xf2e5f170	adf_disable_pf2vf_interrupts
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xf4103e2f	adf_devmgr_rm_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xfaf7cce9	adf_exit_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xfbb5f0e3	adf_enable_aer
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xfec60b0f	adf_disable_vf2pf_interrupts
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x0f568e72	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x635e3910	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x7518d6ba	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xbe4aaf75	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xe65ddf08	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x0ae7aec3	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x1c44ce23	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x27f4c783	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x050ff452	vchan_find_desc
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x9e4ae1d1	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xc48915e8	vchan_tx_submit
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xe0f9bb62	vchan_init
++EXPORT_SYMBOL_GPL drivers/edac/amd64_edac_mod 0xf13924f7	amd64_get_dram_hole_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x019baf82	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x28520fea	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x29d5e93e	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x41172cf8	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x45a4941a	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4d23952b	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4dec52a4	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6cb84cc1	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6d64e6cd	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7a6b0eab	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x863854ee	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x8f2f5938	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x93d3da1e	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa5e49ca4	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa913ca8a	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xae022267	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb6b0d7ff	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xba2e7290	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc2a18175	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc44d74cd	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xcae5e841	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd196f553	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd9cb7952	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x14878009	amd_report_gart_errors
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x1d34e996	pp_msgs
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x81d75507	amd_register_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0xb30b7e56	amd_decode_mce
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0xd3cc2686	amd_unregister_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x2e078db4	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x30683138	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x8fd1b1c7	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xe6ee5df9	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xf016f440	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xf8e5fb38	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0x013fbdac	cs5535_gpio_set
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0x93f8fe67	cs5535_gpio_set_irq
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xc0bb404a	cs5535_gpio_setup_event
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xd3bd9300	cs5535_gpio_isset
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xe07c0954	cs5535_gpio_clear
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x43e14f00	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0xeb584d01	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x158461db	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x805c8842	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x0d0d1bc6	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x39f5ff9a	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x58de7714	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x05876c69	i915_gpu_busy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x08a7896d	i915_gpu_raise
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x402468e9	i915_gpu_lower
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x500858b9	i915_read_mch_val
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0xe7237b0b	i915_gpu_turbo_disable
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xb25964c1	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xc7e63432	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xde96ada0	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x077b258d	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x09ee6a4e	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x16d66c8b	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2201796f	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2314bc6b	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2a685181	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2bb4c992	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2d9f01ce	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2f82ab80	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2f8e2dc3	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x30b8278e	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3103ba79	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x34d2aa7e	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x37fe9b3a	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3e0074d7	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x483efb3c	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x558c25f2	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5cad6909	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x61d3ee80	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6f1ba7ca	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6f8ae5db	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x736b35e5	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x8a6ebc32	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9f7618cf	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa4bcfef0	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa9880728	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xac0cb25b	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb7c29f0e	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc23bfda8	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc68cce94	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd49c213f	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe16fec14	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xedc4e2aa	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf62ab342	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfed2df50	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfede8080	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x34a70dc4	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x0e47f956	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x1e9a81f5	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x30c55ab3	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x5f33592a	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x5fb22b27	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xf56c239f	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x0264b2f2	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x0d2f50a4	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x0e9eb91b	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x0edac395	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x19c1308f	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x278b1e9b	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x5c1c645c	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x60f8d4c9	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xfb1391e5	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0xc1bdd953	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x01c080b6	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x2221f850	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x2b96ea92	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x4b1e072c	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x60f2083e	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x7925b756	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x930def81	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa56b1506	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc1940145	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc58172ee	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xccac2e69	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xd2d82350	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xdf31e2d3	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe424b6e6	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xed21d76f	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf34158b6	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf5c63c75	hsi_async
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x118505f7	vmbus_sendpacket_pagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x143ed420	vmbus_close
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x1a25cd8a	hv_do_hypercall
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x1bae14d7	vmbus_sendpacket_mpb_desc
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x25a0a3d2	vmbus_cpu_number_to_vp_number
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x27b52a2e	vmbus_sendpacket_pagebuffer_ctl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x312759a2	vmbus_are_subchannels_present
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x358fafa5	vmbus_prep_negotiate_resp
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x45bb8038	vmbus_establish_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x46a417ca	vmbus_proto_version
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x54687128	vmbus_teardown_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x7814a325	__vmbus_driver_register
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x864da3bc	vmbus_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x86ff5fa6	hyperv_cs
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x8c00e0e9	vmbus_setevent
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x94911a9a	vmbus_hvsock_device_unregister
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x968e34cb	vmbus_get_outgoing_channel
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x982a3739	vmbus_allocate_mmio
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xb1ff4b54	vmbus_set_sc_create_callback
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xd5284853	vmbus_sendpacket_multipagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xd8e8af0e	vmbus_recvpacket_raw
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xdb2f6047	vmbus_free_mmio
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xdf8bd345	vmbus_open
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xeadb5fcc	vmbus_send_tl_connect_request
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xfc330427	vmbus_set_chn_rescind_callback
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xffbc8555	vmbus_set_event
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x375aa662	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x70dd8071	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x881e25bc	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x1405c0ed	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x3453f8ee	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x4acda2a8	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x4ad67d42	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x4c244d9e	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x54b2fec3	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x5b7d0bc4	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x7f53c542	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x97d41c22	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xa114c51f	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xa4f630bd	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xcd8bcd02	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xde7a48c1	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xe2d86f32	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf4dcecb4	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x05a080bf	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x0afa291e	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x86b6e425	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xd06f8fda	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xdbb2b52a	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xeac95838	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xeec6c9f4	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x1a844546	stm_source_write
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x80ac7aa1	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x80b059fc	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xc55f2ef9	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xeb9dd5d8	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x3b9ae1ff	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xa3cd0c7a	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xc738cc79	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xd960e79b	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xea543240	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-nforce2 0x156d1917	nforce2_smbus
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xfb6c9a79	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xfc50bd51	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x50e164d0	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xa289ace1	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x25339a68	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x2c63b759	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x998b711f	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x1806b9c4	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x21da1a94	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x2e3d02a9	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x44f423ca	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x7405c791	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x78987474	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x8879f750	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xb7db4905	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xbf76a67a	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xd3cbf873	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a900021	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x79f12894	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0x33d30d6d	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0x80c61408	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x00c4c0a1	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x585778e0	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x601bbfe0	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x161db87b	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x24e8813b	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x2cafd75d	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x552a5ed3	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x604f4f81	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x7290131e	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x7a9c6dc5	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x8fadcf69	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x98401d3f	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x9e13b64a	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xa57941d4	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xba2eed91	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x053b4e27	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0581d247	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x05e6367a	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0dcd59d2	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0e022536	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x20e28301	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x272be6dd	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2f3be927	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2f90c5d6	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x32f9f114	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x331c0020	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x371afac1	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3b047abf	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3ec5c03b	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3fa95870	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x434a85d7	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x43b24cec	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4414ae92	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x496e3e6a	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x67e9d91f	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6ddb73cc	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x79ae9d6d	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7f91105c	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9dcea93f	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xae4f7692	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xae925a22	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb9145bd2	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd3c640dc	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe49baa74	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xebcd2de7	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xfcdf26c1	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0xb30da835	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xa6ddf1a6	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x86d97486	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x99eeec38	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xe2b254fc	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x2e381d79	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xee5e091a	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xf6635b81	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x4462e76a	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0xb85dfabb	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xb49985cb	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xcddc58b4	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xde001705	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xeb0eae10	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x0a4d2c2a	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x0ad9c281	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x1767dfdb	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x1f0d9617	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x38c59e01	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x3d8bbd15	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x642a20fc	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x845972f7	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xa1a1b4f7	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xc673c21f	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xf22a6493	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xfa17f5a7	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x19934df9	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x2b2c71be	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x3f685a8f	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x4e9b5b4b	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x589a863b	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x9725ceae	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xaa4cc504	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xabf41975	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xfb0d3fc0	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x03f1ac78	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x07bad5bf	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x20a2fcc3	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x216f50da	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x228a9d5d	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x477d2787	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x4c25a373	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x673bff0d	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x6f0cb630	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x88bbcda0	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8eff32df	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xab7a607d	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xbbd857d5	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc35b6ea0	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xca2bef09	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xdd3071ac	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xe09758b0	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xf76951e7	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/leds/dell-led 0x86fd1ffb	dell_app_wmi_led_set
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x1f5d9cdf	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x699d4280	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x83ffb7e0	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xdc386a14	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xe934cdf1	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xf2baedce	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x13d0eba3	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x2fc2033a	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x474e5c5f	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x4b85e414	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x5345a9b0	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x8702fa40	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xabe43ee0	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xb56878cf	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xba145d25	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xc9db84f7	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xce956a52	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x64e3c0dd	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x7f5fd153	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8bf52ac0	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xac2e07c7	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xbe9744a1	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc24c7792	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc33eb5fb	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc6c45c80	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc8f0a2ab	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xcb6a6b2c	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xcf6bc006	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xebafaa5c	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xf5e51309	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xfaa45b06	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x00b74659	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2a1a7a99	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x374f45ea	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3a4dfef7	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x48991e9c	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4f124797	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x614e860f	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x647af374	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6724de29	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6726a0c1	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x68f1ea6d	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7114cfcc	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x78c57fa5	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7cb4bd6f	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x816ebfe0	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x833b99dd	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8afe3e2b	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x912566ef	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x92c55e92	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x9c59320b	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa7004101	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xaf2376ac	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb3942afe	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb4cffcbb	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb9c28744	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc0bd3171	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc773563c	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd81ad8c9	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe30b6b2a	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf6169c53	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfcb52b5f	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x0f7ca986	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2673d936	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x3ff906bb	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x53ea7b0f	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6f6dfa79	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x8fbb4886	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb12950a2	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb8d680df	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xdc424304	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x15f2e2ef	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x22163b69	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x3909d3a8	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x594952bd	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x62a23587	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9b2b253a	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xdc69e37a	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe004ee92	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x1ba6fdaa	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x2da77fc3	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x488126e6	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x644c2b76	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x6b100d97	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x939abdb9	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xc17fa983	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x6a8217a7	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0xaeda0c7f	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x030205f5	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x087cddbf	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x09472122	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x2c3b6295	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4eb7d690	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa8813ad6	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe1a6a11	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc66ce277	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xcab63c3d	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf37a3cfe	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf63d9cf0	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x11eab9fe	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x150c85ce	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2e730a21	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x33c03da6	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3bd68495	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x619701dc	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9b4b5b29	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa2507774	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbcfdc290	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbe0497aa	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xead1e727	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x0ff15de8	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x18be5614	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x2059f11d	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x28026f2a	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x3228a7f6	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x5a9c22f8	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x84be507a	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x9bae96c3	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xb351ab2d	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xf2c2fe9c	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x050eb575	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x21ce04f1	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x22b5267e	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x917c7dda	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x97899d6f	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xb983f732	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xbfc08c36	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x05c79c70	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x22bcdb82	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x2cba0c8a	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x49b7b46a	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x4d0254ef	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x62e7a0d2	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x63222b29	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x6c2f889c	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x76dc573c	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7b86cf3c	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x95c8c6ab	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xa8a9be29	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xb390ca8b	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xb62af7a2	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbf9733d4	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xe4248b83	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xea577236	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xebd1659e	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0xc0c3f305	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0x31e3a4c5	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0x0cb42496	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x0b93390d	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/media 0x218e320c	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0x30638469	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x3f94807f	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/media 0x48021010	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x49baa1ae	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0x5c7c18ee	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/media 0x6ee5271c	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x89f2e21f	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0x8f1d062a	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x97af34cc	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x9a152d9f	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/media 0xb446b43c	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0xbe469a6a	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0xc6bec1ab	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/media 0xca5a9e33	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0xd6485858	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0xfe237747	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0xaf952c45	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x13c448ea	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x16a62ff2	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x210fe98d	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x26b6b591	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x3e3700f4	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x53134683	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x5a2f4012	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x5fd49410	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x6787801c	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x6e0ada12	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x791354f0	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x8f4805cd	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xa07955c7	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xac74112f	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xbd95772f	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xdfe8bbc3	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xdff9a9f8	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf3d1f04e	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf75d51f6	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x05d63505	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0b45df48	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0e10bd2e	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x4ed7b600	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x7154b344	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x7eae8a76	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x80f1e7c9	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x86060e8f	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x86ed77fc	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa201a2b9	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa54642fb	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa5604652	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xbf231169	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc698c1b7	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe02a97ac	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe2ff6c5e	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe4406292	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xf81c382d	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xfd616bb8	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x151a8b47	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x336e1ae0	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x6c641ce4	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7684b063	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x838235ec	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x97841d4b	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x9f851a9a	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0x056a2ec8	radio_isa_match
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0x06c6c3d5	radio_isa_remove
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0x61e79a06	radio_isa_probe
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0x88c99003	radio_isa_pnp_remove
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0xc0f62ddd	radio_isa_pnp_probe
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x76d7656c	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0xefd9f0af	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x1ee3be6e	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x211bc3b8	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x2cbe7b92	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x3508bc6d	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x37c163e3	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x3d3fe003	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x89c3002a	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9266da49	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x966539ee	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa2c98bc5	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb4b4e95c	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb99c1e67	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xbadc7203	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc28901b1	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc88c3cd7	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xcd897d9e	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xe1a28cb0	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xf34c1316	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xfda239f0	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0xcb5d7d53	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0xa5924220	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0x2c6e39d5	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0xf3c828b2	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0xe3d6365b	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x87d24448	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xbdc38ca6	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xbeacdf48	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x8f98fb50	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x1f978f93	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0xb86d0cba	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xe2596659	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xf61925cd	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0xfbf6caae	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x0bf90b94	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x161b08bf	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x19cc10e4	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x1a390e2c	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x2e3c70d6	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x4094a56f	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x48cae9d5	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x5f223339	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x77287d56	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x9d2a1433	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xbcc3bce7	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xbec8eff8	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xbf6395b2	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xc2a1d4c3	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd1ae7df1	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd3d35e06	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd94bd90d	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xda1a1e42	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xeae1c5a1	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xfda606e2	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0xb8add25c	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x53c5c52a	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x0add5a04	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1b68391c	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1ffef3cf	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x35359f96	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x35cc6999	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x4d321ffb	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x50fca95f	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x5fde6b20	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x73217f2d	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x769f6c36	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x8146bb23	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x97df226c	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9b4ddbe9	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9b6dbb79	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xb97db4a2	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xe0f855e3	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xf67d729b	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xfee6ac16	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x20d5aee9	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x45c7bdb9	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xc7bbdaa2	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xff4b8ec9	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x1ac133e9	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x2a2af3bf	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x40c359f8	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x51401f26	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x865e78dc	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xb5cc0707	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x1053c25b	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x75c7e426	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x0461ca01	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x0d9441ea	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x124355be	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1477c9d5	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1bae4eab	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x24c953d2	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x29dbf46a	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x2bcb8f3f	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x46a859db	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x499550b9	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x617a1fd4	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7123c707	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x77bd162b	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7e0d954f	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x8127aeac	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x891e747a	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x8cb89292	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x8ec7ea6b	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x903d9b16	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9767bd96	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9a50489d	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9f52dfc3	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xaae3eac5	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xcaeae32f	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe194ad19	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe3ccf0c4	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf520387e	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x16aece84	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x1dd94d7c	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x27b9022d	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x30221423	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x34f78ed1	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4e1b56de	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x5e2f6080	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x67905f4b	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6b1405b8	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6ec2356f	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x78ddf141	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x80db627d	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x82515c99	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x90a09a0e	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x940b3992	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x9f5760f4	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa235cb7c	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa8d09e53	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xc32cefb2	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe3d5827d	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe576c920	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe72c9c0e	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xeef49d1a	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xffbf6658	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0x69d1c42b	videobuf_queue_dma_contig_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xaa2add32	videobuf_to_dma_contig
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xe303d1c7	videobuf_dma_contig_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x15cb2214	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x256a231b	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x4cad47bc	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x844c63d2	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xa825c75b	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x013f14e0	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xc22d817a	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xea4ca749	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0ef5a175	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x499ac937	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x49b88008	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x4e96b331	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x55b760d0	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7140fabb	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7d0c3379	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x9a674a83	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x9cc76e8c	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xb6e65402	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xbc645f4c	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xc91043b1	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd419e9eb	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xeea0be67	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xefdebe23	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf11134bf	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf4054e3c	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfac6fe75	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x2f1e62d5	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xdfd27ec1	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x04db2b31	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x272fe2bb	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x1da65983	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0461a4e8	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x09521af9	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0a780f47	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0bde2253	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x16615e12	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x38b59e3a	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x452c8d3e	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x47e14912	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x52f8464b	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x569ed660	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x57c789e7	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x6dd59485	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x6f19337e	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x77dd85bf	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x89051a11	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8c0d1313	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8f6e5ac0	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x937a926b	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa437cdfa	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa99ae1d1	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb2fddff6	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb41e144f	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb4ff3bba	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb9945f04	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xbf450165	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc174868f	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xd2094228	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xda958039	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xe87d4de0	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf80ce87c	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xfb98b539	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xfe043573	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x2807a12c	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x085c1c98	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x119a76b2	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x19455c47	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1bbd9094	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x278c4bd0	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x28d20b15	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3129d103	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x31e3d76e	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3740e82b	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3c0fb0dd	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3fb71c47	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x40289275	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4b62d52b	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x55fc27b5	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x662c260a	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x6b327d8f	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x72520fab	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x79305d27	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7a85f5d7	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7a94fbe8	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8c18364f	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8fa601e9	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x98545b10	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9e23b29c	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9f3ca3fd	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb6e0252f	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xbc9786c6	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc760c3db	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc9efd268	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xddcf5f10	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xdf1dc19e	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe83b5b1a	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xeed73f78	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf57298e0	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf5956f8c	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf65e7d87	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x2520e2f4	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x2fb89a57	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xb3d5ced3	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x2daeb418	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x3a9bbe56	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x4284fb8a	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x71e80d00	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x7e39e0ed	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xe309e1bf	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xf8671ff6	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x3ffaa62f	intel_lpss_resume
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x4b763169	intel_lpss_prepare
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x5494accf	intel_lpss_probe
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0xa6ca9951	intel_lpss_suspend
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0xe7217a67	intel_lpss_remove
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x06029d8b	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x42975877	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x54436bfe	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x61de9a1a	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x75177ac5	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xc9c4824b	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xcdfba4c1	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xf3ffa9f3	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x2e4026f0	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x3ff670b9	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x5fa6fd4a	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x015c679e	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x22b77a9c	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x2c5c742b	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x32af55a0	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x554b454a	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xba5957a5	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xcf36fbb5	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x53a5a28c	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xa959f841	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xd3bf8b54	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x71d66960	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x748518f8	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xa60b319f	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xb4228801	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xe6973649	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xf498c321	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x179c1c8c	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x67220cbb	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x8700fa8d	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x8a1e7530	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x8ba6c468	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x8e7dde8c	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xc5b14c3e	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xd4af3fa8	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xd6ef04bf	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xe92abe7a	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xf74be987	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x505d67bb	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xd747577f	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x399ec46a	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x778c92f9	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x86ebc735	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x8c055b36	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xd2f7d84c	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x1596eae5	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x22045172	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x2e7172c8	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x338c5457	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x34bc3500	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3bbe208c	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x40ac3b83	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x50b84f9b	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x74c99847	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x75168a86	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x8faee47f	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x92138110	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9a41e713	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9d69c2bc	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9f06e335	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa25be37c	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa3082407	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xc1a33281	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd2fcc0da	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd70fc766	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe82d70f6	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe9c26032	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xef4cebd6	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf4a1fcf2	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x0391f20f	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x0666560b	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x06f01b06	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x1c251f9e	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x2dead589	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x4814a307	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x5678f8ee	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x6ecca053	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x8924e60c	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x91acbd59	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xb6d272a7	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xfcb9acac	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xffaecf86	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x07396b7c	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1035258c	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1af4c450	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1c1b4f02	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1d553a7a	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x328eee42	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x44d86628	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5c6558f6	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x60429e9c	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x637ff43b	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x655361b5	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x67de22e1	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6c5c255c	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6e3e0945	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x73aa4623	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x770dd061	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8233e352	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x83a21fd4	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8bc63848	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8d6a6b70	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8f234910	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x996b0dc5	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa36abe07	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa791a0ae	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xac948b9e	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb4963d01	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb62a9fa8	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc35407b5	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc3bd2194	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xcc069a77	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd1a506aa	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd4c54964	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xdacca90a	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xdb491be0	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x2144d864	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x2320fdf0	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x77ddb533	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xc33110cd	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xf0d0dadf	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x2863bd9c	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x5f3734fc	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x7c4d156a	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xb077f7ea	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x422deb22	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x5b9fb75e	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xa30e4e76	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xff50952e	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0x476d4952	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x5146ba20	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x87ae991c	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x9d866ca7	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xc93a8578	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x09d7ec95	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x1861abdb	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x6337fd5a	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x8c82da58	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x1c865ab4	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x446937f4	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x871b42de	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x8ab7e93d	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xa090575f	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xa95c4f93	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xece8eb0b	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xf2000c40	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x4a94efd7	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x567f4a54	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x87a29a57	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x9fd0ba73	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xa51f653f	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xb065c4ab	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xb1f3b258	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xb68fe1a7	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x0beab748	mei_cldev_recv
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x15e1968b	mei_hbm_pg
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x171f0697	mei_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x1d2f6fcb	mei_start
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x1e6c8996	mei_cldev_send
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x2b94ae92	mei_cancel_work
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x395b4ffe	mei_irq_read_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3cca1057	mei_cldev_driver_unregister
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3eb55cea	mei_restart
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x6fc19913	mei_cldev_uuid
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x7ceb2de3	mei_stop
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x874d3d18	mei_deregister
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x8d72af8a	mei_irq_compl_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x929b4ad1	mei_device_init
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x9617857e	mei_irq_write_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x9d41d2fe	mei_cldev_enable
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xa4c481d2	mei_cldev_enabled
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xa69c2034	mei_write_is_idle
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xaa20cd12	__mei_cldev_driver_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xadc640ec	mei_hbm_pg_resume
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xb3760274	mei_reset
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xbc547f5b	mei_cldev_disable
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xc239537b	mei_cldev_get_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xce751fe0	mei_cldev_ver
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xda27124f	mei_fw_status2str
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xdba3b15e	mei_cldev_register_event_cb
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xe9ed1984	mei_cldev_set_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/pti 0x19f09b98	pti_release_masterchannel
++EXPORT_SYMBOL_GPL drivers/misc/pti 0x23bde487	pti_request_masterchannel
++EXPORT_SYMBOL_GPL drivers/misc/pti 0x52a78e81	pti_writedata
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x81df6421	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xcd6e377b	st_register
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x0f6680ea	vmci_qpair_produce_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1152e318	vmci_qpair_get_produce_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x13aa5a5d	vmci_datagram_create_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1872c7af	vmci_qpair_produce_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1a195863	vmci_context_get_priv_flags
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1f858f68	vmci_qpair_peekv
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x231dbc0c	vmci_qpair_enquev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x2e30d970	vmci_qpair_dequeue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x3ef56cd5	vmci_qpair_alloc
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4b630dac	vmci_get_context_id
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4ea2ccbc	vmci_qpair_peek
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x50a255c9	vmci_doorbell_create
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x612df9ae	vmci_qpair_detach
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x677c36d0	vmci_is_context_owner
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x69ef87ff	vmci_datagram_destroy_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x6cc1a5f7	vmci_datagram_create_handle_priv
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x722d488a	vmci_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x76e24c57	vmci_qpair_dequev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x7d540b50	vmci_qpair_consume_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x8b8ad67a	vmci_qpair_enqueue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9624c58c	vmci_datagram_send
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9973b9b2	vmci_qpair_consume_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9d16164a	vmci_send_datagram
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xccbb53d1	vmci_doorbell_notify
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xcf5ed7ef	vmci_event_subscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xdac94780	vmci_qpair_get_consume_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xe7e7c107	vmci_doorbell_destroy
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x13d19593	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x5ba24119	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x61f40953	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x63f0c300	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x8da06ff1	sdhci_reset
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x90128e6e	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x911fac9b	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x9653105e	sdhci_send_command
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xc61daae8	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xce7f0645	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe03c776c	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe7aaabcd	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe82b13ee	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xfd0eae20	sdhci_set_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x0173d05b	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x0893dcc0	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x2297e82a	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x3f4bbf68	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x490c8d15	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x4ad2801a	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x4d38340b	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xb0626069	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xc0247bcc	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x496d34d7	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x7644113f	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x8b5a34a9	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x107c3b57	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x6e2e7087	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xe385f4d1	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0xf817e54c	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x3ab7dac9	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x6b047a9d	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xcaa42c4d	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x00c980a3	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x08453602	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x17b195bb	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x238582fe	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2623b360	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x338d0fd7	mtd_block_isreserved
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x35caf5bd	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3a3bec31	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3b7149bf	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x47943954	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x48182ee2	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x48c48604	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4f4f66e0	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5252a2ef	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x58ddb9b9	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5b6a2e6b	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6ab12ecf	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6ad6185f	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6c739934	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x716aa130	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x72a6d68b	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7c445fec	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7f927f84	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x94d4df91	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9cc670f0	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xae23b9cc	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb0493c41	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb2a4326f	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb43fa85c	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xbb04fcb7	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xbfaf238d	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc1eea955	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc3fa41d5	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc6842a8d	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xce023b69	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcf8c5421	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd00949e7	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd5605df5	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe1f77539	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xea82f666	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xeff14d2a	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf4a1813a	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x004a056c	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x0c565bf9	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x4155f015	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xbb8637d9	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xbfbbd178	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x4419df0d	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x5aafc6ae	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0x05a0e85f	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x12258649	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x41ae5449	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0x8d0fb6e6	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x0e672424	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x12edd751	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x1d407876	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x513f9132	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5815d944	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5ff91b91	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x68f9e601	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xb8a5dd23	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xb9e9cb8e	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xd6c12a3d	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xdbf22a6b	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xde345e31	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe0fe50c0	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf9cbb078	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x497e1f0a	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x711f264a	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x15a16388	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x4078f7fa	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x6a534e39	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x89e6842d	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xd824ef52	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xe7d6dbec	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x00f8e72a	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x02fa3401	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x10dc83d3	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x15e057eb	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x1acf6a7d	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x2f7de287	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x352fd994	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x37e083be	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x521b7d7b	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x5fce50ea	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x63845c92	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x6dc32426	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x8fab265a	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x92713dcc	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x9af20881	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xa01df0b6	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xa7bb5f4d	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xf8bcc452	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x1501073c	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x27db294c	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xa482b092	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xd35f3a38	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x22ca1314	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x2f704f74	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x474b15df	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x7b4f5a94	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x00b0852d	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0170cb88	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b8cf899	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0e62a5fc	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0e93ab51	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1149bba0	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x174f685d	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x19d0e249	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1b8f1537	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1bb00919	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1ca2469e	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1e96ccbe	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1f48aee3	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x22a8f35e	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x22ca6531	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2375a51d	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x247de41e	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x24a87b19	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2592feba	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x27e3a142	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x28ff84d0	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2ac204cc	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2d62feb0	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2df7cad2	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2fa56d73	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3135c8c0	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x32073503	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x324aa5c4	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3680adb5	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x392278f9	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3f315c31	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3f416d2b	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x426deccc	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x46bad073	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4ac6ce7f	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4df4ec71	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4f6c077d	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4f6e056f	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4fb4c737	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x50938337	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5287193d	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5364aced	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5651b0f0	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x591c1be9	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x59a15eac	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5a127ce5	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5b3450a3	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5b6282f3	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5e570bad	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5f29e518	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5f85322d	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x60664df1	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x606a7d8f	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x63cdfec5	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x64545a37	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x661f5dff	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x674ef520	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x676f041f	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6b734252	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6d07110e	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6eb2502d	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x72e886ac	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x73d62b2b	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x75ce6ac7	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7612a991	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7629797f	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7a9d2c72	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7aa82b96	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x841b125a	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x88b4be01	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x89da117a	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8a382143	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8d2c9959	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x910919c8	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x956014b4	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x95ba8eab	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x95dda51e	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x99d40dff	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9a04618c	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9bd737fc	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9bf3412d	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9d641bd7	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9ee878c9	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa35638aa	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa3cfe6d5	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaac2d632	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xae7de5bf	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb178bcc3	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb262182e	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb283d2c3	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb88f22c7	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb5cec16	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbbcb1be8	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbcb88d58	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc32c1f7d	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc3511fba	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc401a25b	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc5078cb9	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc53d3b07	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc546c0ee	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc7a85cd7	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcac57f4e	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcbf74b4d	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd64077c9	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd7f56ecb	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd9a26ae2	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xda77c41a	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdbc73797	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdd506550	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xde93e897	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdf169027	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdff3f13a	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe59be713	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe696dc9a	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe6c58ac3	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe911fb60	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe9302722	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe9988cb2	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xea524c52	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xeb43fb15	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf06bc5cd	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf1923b89	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf57439e8	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfe883bd7	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09543b3d	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0afcbbca	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0dec44cc	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x12fd9d93	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x18da191c	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x28b9932d	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2d89397a	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3200aaf2	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x321f0062	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x369e8f84	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x37294a51	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3730cc2f	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x37b485ea	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3a486b5a	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x55521598	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6288594c	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x66951be4	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6e0f6de5	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8094b711	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x85c2c64b	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8c387e53	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8cd48a5e	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x91d7a118	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa0ae1340	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa9a32222	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xaaba79ae	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xad6fc28e	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb25e172a	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb4c35c7b	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb9014bf3	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb9c4fa53	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbb201d08	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbe22eb2d	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc06e9f54	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc0ee3899	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc4432780	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc51aadfb	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc679ddfb	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc7538195	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd4b35b25	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdb7330ef	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe57e27d7	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xef97b043	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf5e01d77	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf8ea2b5e	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfb74fb7e	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x368d3d71	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x9ebbba41	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xd4ab3625	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x2025a994	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x31a72973	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x3411f189	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x7e1d53ba	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x82fdf457	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x8b40c7cc	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x9e5b6db3	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xa52eb3fc	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x06656362	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x0c01075b	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x162049c1	cpsw_ale_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x1de0b325	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x269e7b00	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x27257826	cpsw_ale_add_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x3751f221	cpsw_ale_dump
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x3b7912e2	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x48adedb9	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x63b3013b	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x8f51dd64	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x9cbb78c0	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xa0bfa436	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xc62dd8ab	cpsw_ale_start
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xf221f5f0	cpsw_ale_stop
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x6957031d	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x941d73c2	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x1cffab01	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x676aa308	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xaab465aa	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xf40f0a12	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0x73ce5d27	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x03236a4a	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x0fe8cead	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x45b127d4	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x50ee8fa5	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x68c701be	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x8dae0326	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x92cd20d4	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xaa03f55c	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xdee6bc97	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xfc9fb16b	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x64044b16	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xcc4e89df	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xd380220b	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xdc22ab31	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x0ad95ecc	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x29e347a1	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x363b8b4d	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x39d97c66	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x6be29a15	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x73745591	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x9523cf68	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xe0a3f8b2	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xe5e95ce6	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x15143114	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x27275dfb	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x33989045	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x60c89cb7	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xb7cc5d1a	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xdf3bc100	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x069e295d	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0722b067	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x16df6355	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x18cfde09	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2a7f9fce	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2aadcb0c	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2ee70c23	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x333d993d	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x354d41c9	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x384df81c	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x52b2a3ff	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x59c3b5d7	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x5bd65dd4	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x62d98a5b	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x62ed841e	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6c772711	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6f51fd90	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x77ddfab1	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8728330b	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa03fc77a	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa57e3cef	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa5f0a38d	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xadba343e	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb3f351a7	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbbc01096	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc12a2689	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc3df3594	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xcfb4b034	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd3a9b6d0	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xebd7e2ba	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf6b7d5c6	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf9b3f7cc	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x9e28a528	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0xc5e2f833	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x161b9ae7	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1f606b64	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x22613a5d	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x510e8c99	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x6d1b565a	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x7a5a5fd6	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x87143c5a	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x87999cf7	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x9f018ff1	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa4964cc7	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xba9c1999	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xc683e7ef	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xc9b01b83	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xdcb3301d	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xdee061ec	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xed8a5c62	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x5d423ba2	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x81f96eec	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x90d9b15a	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xfe1c68ee	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0xc707ce31	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x27885816	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x2c117116	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xab514e38	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xf6cad6f2	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xffaf6c8f	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1b074767	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1e6f621c	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x23aa23b6	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x34e21431	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x390ff4fc	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x41bf5dea	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x42cfe2f7	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x47b23ce8	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x48fe5f9a	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x512a2413	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x53b9079a	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5ee5ab54	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7a9150c9	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7aa6aedc	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7fced590	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x85ac6cf7	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8e046954	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9cf7f3ff	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa1beb689	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa757442e	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb27c1ac8	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb4a07882	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb8979af3	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xbda9eee0	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc1adcbf5	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc4a8fc91	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xcab72b47	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xcf9f5433	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd49b4b3e	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe1c49a9c	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf54151ae	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x0d7d6c6c	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x16756d84	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x2091ccf2	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x21b96900	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x27a7e4a0	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x42e09667	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x50177c60	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5c5fc4db	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x66e2a0ce	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x727b8138	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x836f13ff	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x88a02e88	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x88f8f719	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa106b9cd	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xb26405f0	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xc09a4422	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x18576980	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x67114cf9	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x67b999cf	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x8bb85775	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x9a7e83f1	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xbcbdda58	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xf068aee3	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xf9f349c3	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x07e39042	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x0ebc1997	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x13e8797e	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x185b8c31	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x244f3834	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2fe4a92d	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x3001c135	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x33d7a8e3	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x40b5f28d	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x4600a590	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x6fe72a1b	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x8115943d	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x91349132	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x95ffb99d	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb457cad3	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xddb06ede	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xed262147	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf3be40d9	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf3ee8ebc	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x1e78d304	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x22883a5c	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x30273b8a	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x822008c9	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x8c0b8423	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xab6dad22	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xafc2ff1b	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xd2e5b992	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xfbacf3c7	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x449c024c	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x626cd92e	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8191c0e1	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x9504063b	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1427d265	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x201867f3	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x29ecef5e	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3ac29bd8	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3c51e5c3	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x43228146	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x5190b770	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x563b5e5d	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x597487a2	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x61034f39	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x784d4af9	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7a0b9bfa	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x874892bb	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x93a3b8c1	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x9e2eb116	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa0de3b75	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa1de7d55	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa6418995	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xbc0be4d9	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xc8687f22	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xcf51f2d2	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xdabd23ff	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xdec5ba26	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xe8d2a69f	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf01a6dff	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xff202265	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xffa5f516	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x19763652	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1b0351f1	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2f143040	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3756c418	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x486dd098	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x48d6cf39	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x492a2146	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5c78e750	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6262deb0	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x62ed3f32	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x694009dc	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6ce57a27	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa8791f8c	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xafcdc668	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb9859327	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc116380e	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc12fec90	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xed5a4c4f	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf83e2e90	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf8ff6add	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf938971c	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x3d42409d	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x56a9ad8e	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x79f6f2ab	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xadb2ce88	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0edd63e1	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x11516bfd	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x129c4b58	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x218a0ccf	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x2824a3cc	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x293aebfe	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x2d023acc	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3301ecff	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x35ae1d64	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x36d695bb	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x414290f7	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4c0c79bc	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4c3e9140	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4ef6a134	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4f494356	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5639f20a	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5b54ff4d	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5facc870	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6456c8e8	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6f17e75f	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x722217d9	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8b499a85	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8d6fece4	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x947fb674	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x995d9dfc	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x9b341af2	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa270443c	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xaddfcd0e	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb17b15cb	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb41cb23f	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc44d01f0	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xca259824	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd05de36c	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd1af4ee0	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd70ca6d8	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd7c3a2de	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xee503833	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf4038e45	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x198ac4da	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x19da3c2b	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x282415ae	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x28d9105a	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2aad3393	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x42ba70b5	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x471b735a	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x50903567	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x934a5044	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xa99a9c4c	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xccc0fec8	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xed4efb9e	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xf59d48b9	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x02df972b	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x03f08caa	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x08a5e04f	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x10b8fcf9	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x14ac02a7	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x15d2e385	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2604d68c	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2bfce6ab	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2c09866a	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2c893c4a	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2cfde930	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2e469743	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x326d886d	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x35f5cfd9	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3a3ac1b8	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x430069b2	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4855f0d9	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x49245c7b	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4bdee8fe	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x566edc22	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x58c46f21	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5930af84	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5b9b6bef	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5d99aabf	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5fadd70e	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6a7ffb7e	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6c915c36	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7240942a	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x79d0ee3f	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x866f7070	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8862bf9c	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x997e3192	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9eabba96	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa3edd152	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa5693edf	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb135d692	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb45e0ec8	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd31a3899	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe2dfaa69	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe59a2b64	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe9a6c4fb	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf159fd84	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfb663b69	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfbc4ca11	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfc6c94e4	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfff60dcb	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x00e57b69	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x959fdf75	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x99d741e5	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xe06f442e	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xfeb60e83	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x816e6b07	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x9029215e	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xc9de6cba	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xfdbfbf0f	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x4325bfab	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x47991c59	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x4cca2def	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6a4ea70d	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x76bd9716	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x8be08718	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x943a6f0c	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xafa098e8	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xb6674979	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xbd02cc92	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xc5c3f791	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe01320ed	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe536da94	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xebaa57f3	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xef6ff47d	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xf3e0b891	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x78bf812d	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x957e1091	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xee7722e0	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0512ca58	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0a2fff77	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x167f131a	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1857cdb5	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x19a36ff3	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x19d53706	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1d4938db	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1d9ed8a1	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x254473f3	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2e189ff6	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x309c5236	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x38209550	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3ef268d9	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x40568eb1	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4d6f894e	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4f70165a	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x55c585e1	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x648a74a2	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6b891d89	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x73cbfde6	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x74c2f62a	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x84258ac3	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x87e965df	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8dccd970	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x91da5146	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x96fd601d	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9aa64bf9	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9f0d04f2	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa54eaeee	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa7d36e95	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xab8310d6	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xad9f7117	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xaf3118b9	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb2b13442	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb3591936	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb4e2d4fc	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb50d5c46	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbef7ccc9	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc6435cf0	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xca157e9f	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xcca3ea54	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xcf095c35	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd441568d	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe1fce0a9	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf8a31b5b	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x6c5a0d45	nfc_mei_phy_free
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x76b65bb3	mei_phy_ops
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0xbf99f58d	nfc_mei_phy_alloc
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x2067ee3d	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x23e167c1	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x2ed8a360	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xca802618	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x3eea38f1	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x3f120498	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x85689d7b	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xa514d20d	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xb5aa7d5f	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xb6e76e0f	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xb70ebb9f	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xbcc2ef24	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x29487d9d	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x438c58bd	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc23eb677	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x358ee3b6	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x36ec8a8a	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x523bc014	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x5756ed53	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x68758fda	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x7bf0541f	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc96fb674	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe18960ba	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe220895e	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe9a7fe16	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xf5f12835	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x3d965e28	intel_pinctrl_probe
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x98f0636f	intel_pinctrl_resume
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x9d97a629	intel_pinctrl_remove
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0xe9f1111f	intel_pinctrl_suspend
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0x40d4d292	asus_wmi_register_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0x525c4e83	asus_wmi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/dell-rbtn 0x51552fca	dell_rbtn_notifier_unregister
++EXPORT_SYMBOL_GPL drivers/platform/x86/dell-rbtn 0xa060fe7d	dell_rbtn_notifier_register
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_ips 0x46809fa9	ips_link_to_i915_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0x56235c72	intel_pmc_ipc_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0x75068282	intel_pmc_ipc_raw_cmd
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0xdea07053	intel_pmc_ipc_simple_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_punit_ipc 0xa6c87106	intel_punit_ipc_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x232b5238	mxm_wmi_supported
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x61cdf799	mxm_wmi_call_mxds
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0xe26032eb	mxm_wmi_call_mxmx
++EXPORT_SYMBOL_GPL drivers/platform/x86/thinkpad_acpi 0x706cdcef	tpacpi_led_set
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x3ecf6cfc	wmi_install_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x64ebe677	wmi_query_block
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xa9b7afd8	wmi_set_block
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xb5a6ebe2	wmi_remove_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xc5e3dddf	wmi_get_event_data
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xc9d4d6d1	wmi_has_guid
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xe2426710	wmi_evaluate_method
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x2b217bf0	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x3c599fb0	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x98da11f9	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0x6365870a	pwm_lpss_byt_info
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0x8b24d981	pwm_lpss_probe
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xafcf8794	pwm_lpss_bxt_info
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xb563cdb0	pwm_lpss_remove
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xc34d815f	pwm_lpss_bsw_info
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x29c65881	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x7bf3ccf6	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xb3afbd45	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x14348b5e	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x223a0219	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x60a2ea4a	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x63e5ab34	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xb402b216	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xd5f4de4d	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0x57598f2e	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0f921fc1	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1b37967e	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x26f976d7	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x288b4eb5	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x41d92170	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x423b0def	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x441f9395	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x44e2ff5f	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x47d2d9d6	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4cf89c78	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4d3e79bb	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x536cee1d	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5f5002ba	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x659c83bc	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6d71c4e6	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x70172d72	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7128242e	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x754fcad4	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7776d73f	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7a2b23e5	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7bb729ae	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x807f46f4	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x87355eff	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x979bfd64	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x985e907b	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9cd77a71	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9e3d922f	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa2541566	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa571995c	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa866a6b2	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xab7cc894	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb47ab723	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb6aa437e	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbcfd24a5	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc35b590f	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc39942f1	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdadb2e41	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdaf2e680	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdc244b25	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe0446a23	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe4470bfb	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf0b43613	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfc69b714	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfde97970	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfee33e0e	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xff2a6ec1	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x197dcbda	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x1a41c621	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x3143dd07	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x33a7a61c	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x40b29ecd	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x468d9e85	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5b3e201a	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5e41ff1d	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x899c30d9	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x907e0268	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa9625608	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb98df7e3	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xd101f29e	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xd6096203	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xee144dc6	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf22c184d	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x39fcbcb3	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x3cd27bad	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xb4a96cd2	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xd27ea436	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xd3b5fd73	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xdd92fe9c	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0e2703b2	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x17a05003	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1d0c3f28	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x24397f55	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x291f1424	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2a0e9981	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2d8abb88	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x383c91a1	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3b31eb5a	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3f41acff	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x50289236	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5077d5a9	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x57ffcd28	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x598e105f	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x61c6f2c7	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x68f5673e	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6b8149a8	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6d507cbd	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7110cdde	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7523c154	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7dcc0e10	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x89d08e00	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x91209126	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9ffe18c7	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa5ce476b	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb2b69077	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb44c5114	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb46695dc	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc15c85e3	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd10d15e9	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd5743ba1	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd9779fea	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe0c48281	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe5b10d73	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe79049b4	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xec58f85c	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xedb0de5d	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf0dd749c	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf2e6f3ea	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf7808a88	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf871e3c7	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfedf0e89	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x10a0baf0	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2525ef7a	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2a476255	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x32b3f747	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x3e737f00	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x3ea7d69a	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x430e09ab	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4b528c5d	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4dda5ccc	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x5e8e07dc	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x8076e568	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x8a150199	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x8a7758c8	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xa8639dd8	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xad721fea	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xafc7469a	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xd7a8c195	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x0517ef4b	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x14ea54d7	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1a0ec8cd	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2125a695	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x27ebc2d7	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2b2dbbea	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x31671591	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3ccbcba9	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x4129b4ba	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x433b0313	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x61f91744	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x68cf0225	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6d185d55	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7a5c9a7b	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7c8dbf97	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x870f40c3	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8dae45d4	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb28cc2ec	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xcbc8bef2	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xd57c4f24	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xdb959196	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe81b7368	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfafe5d85	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfd01b1ba	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x037f152c	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x04de75fa	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0a9552de	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x14bacd29	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1aa1f463	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x23db0504	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2bc7c487	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x30c89b80	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x363f91d9	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3f9babe7	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x411dea99	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x44dd75a7	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x464ccf71	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4690aafb	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4c6cdab8	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4fbe4c18	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x51615e72	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x567df21a	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5dea8039	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6045357f	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x78925698	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7bade67b	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x878f3eef	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8808cf6c	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x94a23c67	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9f1a97aa	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9f39b0e9	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa486dfbf	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xace12845	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb5494171	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbe3fe200	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbfc81518	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc0361623	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xca226458	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xcab8dd5c	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd192e0d0	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd44d5d61	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe5d488a2	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xedae1f73	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfc04189b	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x50d83766	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x5da265e1	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x85130ccb	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xf6080c3d	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0930e847	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x63c16247	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x75c8583f	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x89b7cbdb	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x9b3a6fc5	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xc677cb52	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xc6db53ae	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x45dd9fde	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x5c236ad7	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x7830d863	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xa66a08c0	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xd172af11	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xdf9b0b79	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xe2d88f9f	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x01dce051	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x578af4dc	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x6d8d1b06	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x76fd6710	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xb20bd73c	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xd2f599ad	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xd359c92c	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x06d2b63d	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x5293a2f3	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xa7512a5b	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xac4c5465	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xb2cefc95	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x38ce9474	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x9b0ec8a0	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xb8acd3e0	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xdff0db31	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x05b4abad	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x2fadfd40	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x33c39202	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x45e59236	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x46c2f8db	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x482acc7b	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x4d87617e	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x513fb6de	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x59f458ef	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x6bd61ee3	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x9cfe802b	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xa3ab1309	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xa4d41c26	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xb1240445	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xc5bb8b92	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xca267be1	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xda87a7b2	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xf3036be4	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0x797df1fe	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x09acd413	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0d926ff5	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0e261c15	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x12400991	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x16ce019c	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1f6e7988	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x26ecd638	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x29fbd3c3	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2c3623d8	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x36c9e9d2	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4f061c5c	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x509097e8	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5a532b9e	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x865489b8	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8c65b43f	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x90313a5d	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x93e886bb	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9d3cb1c9	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa65f5364	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb8a0449a	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb8cd4c35	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbc7a9b1c	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbd66ab16	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbec8befd	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc49c3f1d	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc70661cf	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd3e34d99	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe26d0452	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe508170a	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xec6c8dd4	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf2b50a27	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf3ebfcec	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf43f1d43	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xfe9aa743	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xffedd072	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x17448d85	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x9f6b28b6	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xa6db34c0	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xd8abeeb5	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xdfe87090	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xe7663bbd	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xf27ef074	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xfa9022e8	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x2cd1978b	comedi_pcmcia_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x60626cfb	comedi_pcmcia_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x7d28a176	comedi_pcmcia_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x813b2cc5	comedi_to_pcmcia_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xa44ac791	comedi_pcmcia_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xcd1117ce	comedi_pcmcia_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xfbff4662	comedi_pcmcia_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x30b4fc2f	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x505b9d3f	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x51aa92c9	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x51d1ee02	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xc2496d23	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xd318eac9	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x3e500ea1	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x0e5501c1	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x20eea3a3	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0xab4f1907	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x0ebba6c7	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x1817c821	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x197d8687	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x1e5eb79b	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x3de4c81a	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x7e93055f	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xa4c3f162	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xab7ea8ac	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb6f55e07	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xbffac573	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xca42bcf8	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xe9f06f90	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xf7e3a8d9	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x291ec78c	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x4326b693	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xe0faabd1	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x0d68fcd9	comedi_isadma_poll
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x12fba874	comedi_isadma_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x4a17474e	comedi_isadma_disable_on_sample
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x6815a033	comedi_isadma_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x703113fb	comedi_isadma_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa3d01a85	comedi_isadma_program
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa7ebb8a3	comedi_isadma_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x2fae9245	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x004cb525	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x16074163	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5837ed3e	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6d819be8	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6dc80712	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x72eee078	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x746a7df8	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x75bb7041	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x75bcd8a5	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x83edee52	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x8491fe2f	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x8d0cd8d9	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x8d259d84	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x9fb6d3ba	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xaa7f31b3	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc1d3abed	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xcc6887c9	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe844e03d	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe978b16b	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf14fbb0f	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xff82a2aa	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x716f408f	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0xf8f88e7c	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x009bbc6a	labpc_setup_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x02711086	labpc_handle_dma_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x69c48161	labpc_init_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xb7736ad7	labpc_free_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xc9b2a411	labpc_drain_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x13abc32e	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x15853eeb	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x6445e3ae	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x88254b98	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x9fcedfa6	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xb3e3245d	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xef02d995	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xf4715fc2	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x1607f6ab	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x6602a667	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x89606952	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xaf1899e0	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xd7c91625	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xf68ce562	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x10d97ea1	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x5cd5f709	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x65072d2a	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x9725c3f2	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xe71d7cc7	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xf4640b18	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xf6a43374	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0x2ea56c49	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x02b950fe	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x075cd34b	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x14c497e7	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x243f58da	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x3fda040c	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x5a3bd6e1	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x5bf22b3a	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x6b369aa9	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x9903190e	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xb9431e9b	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xc6c078e9	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xe0867dec	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x18e6fedb	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x2ab8daa7	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4f07f20a	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x785747c8	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x7c245d57	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8b3aeb81	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8eefe4ce	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x97eaab99	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a1fb73c	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbd57e155	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xde1eee08	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe5d9abed	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/thermal/int340x_thermal/int340x_thermal_zone 0x60cd53ff	int340x_thermal_zone_add
++EXPORT_SYMBOL_GPL drivers/thermal/int340x_thermal/int340x_thermal_zone 0x9c755808	int340x_thermal_zone_remove
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x23c2e39c	intel_soc_dts_iosf_add_read_only_critical_trip
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x25ec857c	intel_soc_dts_iosf_interrupt_handler
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x8e5c65d8	intel_soc_dts_iosf_exit
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0xced87293	intel_soc_dts_iosf_init
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x4131251b	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x43618d24	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xf2a28d62	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x17f4854d	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xe77f2ac8	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x1ab83ea7	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x9e6b6c86	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x0fe4d151	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x1e46595f	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x2410b546	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x625d6efc	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x8b3b41ca	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xe365163a	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x20c6a03b	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x51774f38	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x55cc22a5	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x6327d13d	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x70e6a46a	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x731e8536	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x76ac9233	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x853f05d5	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x9308dd9a	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x9fbfaed7	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xb69d2325	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xe9b256ac	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xed8b834b	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xeedde912	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xfc3e1049	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x89ca818c	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xd371dd12	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xdf16245e	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xef9d4d3f	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x4257b856	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x7859e25d	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xfebc109f	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x0f64109a	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x11381b11	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x22d58ebd	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x28764002	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x28a1989b	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x3c870e79	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x481a8a44	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x50de23c4	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x536af75f	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5ba25101	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6824cd88	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x746c6877	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x92cf3baf	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xacc5c05e	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xbd5cc74d	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x17f7a5fc	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x21c4387e	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x2ac3ff79	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x3f9f337e	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x528fb44a	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x56b5c8a2	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x72daec66	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x83bbcb13	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x9d7eb057	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xb7d3f423	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xbbf57e1a	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xbd4d32c0	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xd0d34a4b	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xdf66e444	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xe48e76d6	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x001c6ee3	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0354ce1f	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x1309f141	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2d154d28	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x3e3334a6	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x44ae6081	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x459ba287	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x46ae7957	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x474d9c93	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5eccefa7	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x63ce8398	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x67595282	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x68494784	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7551a075	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7a848287	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7dafef55	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x87996053	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8b3d12cc	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x93e932ec	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9a733157	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9e5ae2be	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xae29e269	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xbd30e71b	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc0c52e8d	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xcefaed93	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd93426a6	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe0db4b83	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe3952ea0	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe6e7ef65	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xed44eaf1	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf2fc2646	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfc411468	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x0488d344	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x11d4b57a	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x3134af9c	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x335eba52	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x43cc7130	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x60753f3d	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x6dd14eee	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x75f8bc90	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x817cf239	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x99666e4a	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa4744dba	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xd796f269	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xe26c2e54	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xff01d564	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x0694b919	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x3c6c010b	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x1f9dd1de	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x2ee45bc1	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x7fce3d1e	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x81c1ce94	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x9863aff7	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xa5234776	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xae5683c4	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xbe1c340b	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xe1f5213e	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x469c4551	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0x86860db7	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x232f39e3	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x24e53e51	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x374d170e	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x3d32b4b9	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x3f604b1d	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x44c34d44	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4b91b1b7	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4be4de53	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x59f7f3eb	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x62668806	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x6a14ff13	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x861aab03	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x8a4a9f42	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x93e236fe	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xb1633461	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xb6c954c1	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xbd64188f	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc02a8299	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd1f0e231	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd684d460	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xdf44ce39	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe04916b2	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x230d145c	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x2ed66b69	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3cd5c3d6	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3e7c74f7	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4174015d	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x484a6d34	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4df7254d	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x579826a9	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x5d4cd483	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x684ca137	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x69a0e137	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x69e6493c	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6aaa451c	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x71235b4e	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x78bd0ec9	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xafb51e7c	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb3ed6f63	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb55d166d	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xba57c4a6	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbf848d36	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd29632e6	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd963ab3b	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xfc8e36ad	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xfd9f0f8d	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x00a07782	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x229e2cc2	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x457992fa	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x70277181	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x7bf6b52a	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x9209e11c	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xa46053ec	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xccddbe8d	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd37e82af	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xdeb61681	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xf7a7bac4	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xfe30dc35	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x2d77fb38	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x3760bc4b	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x5f27c5ae	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x7f3731c1	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x84436193	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xc543b60e	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xd5553514	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xea1f1435	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xf4654c3f	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0298222b	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0f2e995d	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x11f77c44	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x1425e9b5	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x364d0dc7	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x96c771db	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xa3363d9a	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb411a386	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xbe8a40c4	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xca270447	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xd61604e8	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xe31c062c	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf75db216	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfbe0eac6	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x1af2b445	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x6ff2d684	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xa53ffb88	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x06723ac6	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x11fcaa52	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x152f914f	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x2cba505d	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x3af21099	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x3db64f43	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x4340880f	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x572e16dd	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0488c673	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0b8aad57	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0d01fb52	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0fa61ea3	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0fbf3805	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1897f0e9	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1b496f56	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2932cb5c	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3f2a6077	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4a597012	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4de0cdb8	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x50f7a978	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x55638bc1	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x591493ba	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5e4bc088	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x637b351b	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x70c451d3	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7adf35f0	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7d540650	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7dcfcd23	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8bebfd92	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9044bead	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x913caea3	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa22ba9f0	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb0994d4f	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb26ef95a	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbcbddf31	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbcc7fdbe	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbdcd199c	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbeb73b86	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xccd6d4b3	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xce223528	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd46321c2	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xda9cfb98	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xdacd09b1	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xdbc6c4de	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe1716f06	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe1ec18ef	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xeb3b228d	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xed372ddd	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xefacd5e0	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0x91f73607	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3567743b	vfio_external_user_iommu_id
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3f15fe57	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x91e63fd2	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x9622a364	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xba919494	vfio_external_group_match_file
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc1d989c5	vfio_external_check_extension
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc4913442	vfio_group_put_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xd1abeccc	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xddbc787a	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xe3b14134	vfio_group_get_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0x7d35ff7e	vfio_virqfd_enable
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0xd0265cb5	vfio_virqfd_disable
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x03e0ba71	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x12bc834f	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x28041e07	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2ba57649	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2de2dfb8	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2df36c42	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x37e028fa	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3b6ebedc	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3d6658e5	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x41f1af5a	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x49cdb2f3	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4cb96f77	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x594e621b	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x67a93797	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x6829e28f	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x89837ccf	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x89ff61a5	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8ac2a73b	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8c048f72	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x97d320b7	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xad1e300c	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb0a3d841	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc269259d	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc5c275d4	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd0c5e75a	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe68919c3	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe761bc17	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xeafa6654	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfb6076a1	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfc193ec0	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0x2c63e051	apple_bl_register
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0xdab0f892	apple_bl_unregister
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x30fc7ba9	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x49fb9ce6	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x4fd43005	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x533be0d0	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x7e09eafe	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x9b808d8f	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xd83027e7	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x257f9ec3	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x685b6a04	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x96745e20	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x9a16f08c	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xa55d833a	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xaac2c577	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xb8c500d8	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xc3258d50	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xe93402fb	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xfaca57a7	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0xc1bfefb8	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0x4679ee52	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0xbc8bce3a	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x512a3d64	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0xe7b530c9	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/vermilion/vmlfb 0x016e6c20	vmlfb_unregister_subsys
++EXPORT_SYMBOL_GPL drivers/video/fbdev/vermilion/vmlfb 0x90c018c6	vmlfb_register_subsys
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x22a7af24	viafb_dma_copy_out_sg
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x292da7a2	viafb_irq_enable
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x30cc9311	viafb_request_dma
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x31469540	viafb_pm_unregister
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x79e6190a	viafb_irq_disable
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xb4f863e6	viafb_pm_register
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xcaefb732	viafb_release_dma
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xeffa61d7	viafb_find_i2c_adapter
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xfff2dfd2	viafb_gpio_lookup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x0fb6a4c9	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x3c230c35	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x462f90cc	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x4a510a18	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x5cda25ec	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x6f5a2917	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x77e07694	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xa8e2f705	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xbc479f80	w1_read_8
++EXPORT_SYMBOL_GPL drivers/xen/xen-privcmd 0xc7ad2a84	xen_privcmd_fops
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x0de9176a	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x222588dc	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xfbff137a	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x19c59e80	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x1cca48d5	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x4a2289d5	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x75483d3d	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x7c785f84	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x81035fed	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x9494618a	lockd_down
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0260389d	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x03e19121	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x06790c07	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x07cd53e1	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0816eb6c	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1365beff	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x15a2a4ef	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1688610b	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1f6de42d	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x24fa92a3	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x25c96ef3	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26dd6962	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x29d2ed5d	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2baf46ff	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2c7af339	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2df83fea	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2e9db6d1	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x307db126	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3291af93	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x387fbfd6	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3c59ece3	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3e64d67b	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3eb8e488	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4549b0fc	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x468f1c6c	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x490f40b9	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x49afbf77	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4ac1ea09	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4b71c2cb	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4bdfe417	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4c38b079	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4d6dc977	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4f7bd3fa	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x50f09fd7	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x511aa544	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x521daa6f	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x53d2f0aa	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x552e0ed7	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5a5ec8d9	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5be0461c	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5ed96ae0	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x62a44683	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x63462def	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x66e642c5	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x680b9369	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6834b0d4	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6a6e1587	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6d25fd1e	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6fb4ed56	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x70b4a796	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x72df4282	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7849e660	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x788d5318	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7b88ea7f	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7b94d814	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7f25a2b6	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7ffe5e21	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x81683785	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x81c24ed5	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x85571774	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x865f82ed	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x87de56bc	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8c59a51b	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8f0aaea0	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9054675c	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91827ea2	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x925deaee	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x93369f11	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9970322e	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x99e6371b	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9a399ef1	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9de12306	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa0315707	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa15b81ba	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa2f61a5b	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa42bb10c	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa5f9a116	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaa20487d	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaa5e85a3	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaaa14361	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xae3dd989	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaeee1033	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb16af3e2	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb2861c24	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb33a241b	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb7de07f1	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb9e68894	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbdf46046	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbeb7759a	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbee98a2e	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbf8c3887	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc024052a	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc184c744	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc1c24b19	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc1fa424f	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc2eba9a9	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc30f311e	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc31ffff9	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5e6d62f	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc6399e53	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc7234ef7	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcb1b3861	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcc37aeb0	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcd1a4b59	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcf07e1ec	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcff4b2a8	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd1a2d0a6	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd44b7afd	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd4c789c1	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd68a9f5b	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdb9e7c2d	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdbcccd49	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe01e387b	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe1095b68	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe36d493b	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe434199c	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe54a263a	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe9b79704	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xead703e4	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xee5dfc82	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf7f556e2	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf94de5e9	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfbe28b2e	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfda48c33	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfdb92d5f	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0x124b3187	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x04bb7c4f	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x05b00a48	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0789ab95	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0b8ec822	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0db0842d	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x12c2d286	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x243929f0	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x299223ae	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2a0807a9	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2bdf18fd	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x387d6650	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3b977ffa	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3d146a04	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x406d8ec4	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x48cddcb6	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4b508d52	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x501d36ce	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5c1ff8e9	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5c9ce821	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5cc94bb5	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5edd7f84	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x635bd86b	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x67ae3c39	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69f8e687	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6b3cc214	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6f0bac42	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6f7bc00a	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x70a16fde	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7104613e	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x745a1eae	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x76fb32d8	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7d8e8569	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x86da8fee	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8b3fe06f	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8cbc4d9a	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x92f649ec	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x95d45ad8	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x988c6ba2	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9b1e4be5	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9e84cbc2	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa02df320	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa7b64ffb	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xad2d620b	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xae7a6d48	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb4353710	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb567b9eb	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb6f30246	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb95d41f1	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbcc675d4	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbd9699c2	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc4ec16f4	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd29103f1	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd576bffd	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd5c363c5	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd5cce2ac	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe59a46c1	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe5d2b8a7	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xeb8500ed	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf1e5efe9	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf652b84c	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf8b01299	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfcdab57a	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x4ca64b82	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x85514479	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xed490ae9	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x40ac63b3	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x785ddf90	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1cb231d0	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x5c8cb983	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x687f6251	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x78e39eaa	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x815cc035	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x9b036bc3	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa6f8e215	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa90a86b1	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa9f5379a	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc152237b	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x428b34c3	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x4d8a9253	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x6146a3b4	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x88ac5af9	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xbef4baf7	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xdaa8ae46	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x0de04ca6	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x43d65c58	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xd61d2eb1	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL kernel/torture 0x100c56e5	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0xb36f95ba	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf3510be3	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xb1952324	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xd485f413	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x021957e1	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x0f8a2742	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xd4cb6873	raid6_call
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x57861324	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x57d39367	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x882ce5fc	base_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x9e0112d0	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xaedfbb15	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xc8fca8a6	base_inv_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xd11741a1	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xe3d900b5	base_old_false_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x8ef6ef75	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x9ecfa2fd	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/802/garp 0x3c347f50	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0x48d6605f	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0x556d2ba3	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x65af7963	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0x812c5226	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x9b1b3733	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0x27a1590a	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x2dae3adf	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x2f124396	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0x5f06f1ce	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x99970c99	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xae9e02a9	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/stp 0x094dc340	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/802/stp 0x8ec13346	stp_proto_register
++EXPORT_SYMBOL_GPL net/9p/9pnet 0xa4bce26b	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/9p/9pnet 0xcd88085f	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xfb9ac2aa	ax25_register_pid
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x2731d290	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x2b27f73f	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x43ec87c2	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x6e6f1701	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x742f8873	bt_debugfs
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xaf68d88b	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xd771b161	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xdfaa3cd6	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x1db25d76	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x235c6c10	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x2c82df7f	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x5276180f	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x6221e29a	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x7c7fa632	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x919d0db1	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xba62311d	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x9c99c27b	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0xd589545a	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x00457c1d	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x07df25b1	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1afb3173	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1b47e326	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x23672cd0	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x29c40ab5	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x364a2c75	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3a2b1d40	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3d1943c7	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3e192bc3	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ac45e90	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4e2d4d99	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x57945cf8	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6c2bb6be	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6e2f3f70	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x740a1943	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x828869f0	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9495933d	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa75ba003	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa86cd7e1	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb20e738e	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xba372482	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc2b22e88	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc6a58e42	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc8da8997	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xda4405c2	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xdbcde415	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe1b130e2	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe401aa35	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xebacb7e0	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xec3f9f3e	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xee49e998	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf06c0175	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf29c2cdf	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x4f419052	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x8928a967	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x979fc530	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xc83dbf81	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xd5967abc	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xee6a67b6	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x3d2db503	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x4d7aef69	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x5e5e1f84	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xa817229e	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xd06f6fbe	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x082936b2	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x3e5f0bf5	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x15d50fc1	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x611aa2eb	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x7b04bd42	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xa2d052e8	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xe6b24f60	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xfa396992	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0x82876765	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x37629e96	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x41ddb788	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x589f38db	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x5fd27c60	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x62592032	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x645e76d7	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x69356a07	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x7c888d52	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xaca8d1dc	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd2009827	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd5b27606	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xeb6ad661	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xef84b034	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xf7509314	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xfd710527	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0x69c4e3c2	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0xa4d2876f	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0x71b43605	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x484addf6	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x579fd5be	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x640c1b95	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xc04d2f8c	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xfd55e075	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3ab59eb8	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x09d45326	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x914dddf1	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xa7cd6607	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xbccd0ad1	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xbe867729	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0xf5f27c61	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x1b364cc3	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x45572f78	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x59a7d4fb	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x9ab039d4	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xa90a12c0	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x0665e69a	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x319e2831	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x47dc3f31	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xc2caac3d	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x37cc24d3	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x3ab206b9	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x52489502	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x58ac9a9c	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xd6e287de	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xe9cadabc	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xfd2b223f	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x482a6d47	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0xa43bb7eb	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0x31e37eb8	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0xe2317af8	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0xf27b1f40	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0x98e96cae	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x69a58f2a	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xa0c723ea	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xddfd672a	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xde421c92	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xea46409e	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0xe49d0040	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x2bbffc6a	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x810ce3fb	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x9e4745ab	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xcc9d641e	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xd13ddda6	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0x8247568e	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x080b9f42	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x1bfac41b	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x1fdc9a37	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x2fc3c685	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x30131b36	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x3824fe42	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x3ad5ecfc	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x457a1566	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x45fb10d4	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x499356cb	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x69b53762	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x83315356	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xa24cddaa	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xb8258bb1	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc05d4c84	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xe2dcecf0	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x8133cb06	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x065e45a6	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x0b120c8e	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x18867597	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x25fadd9c	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x274551d5	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x3085b3f5	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x33afd28d	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x558749bf	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x71cb02f7	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x8ea67951	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x93a61aad	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xab1793f1	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xb356c880	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xc07898ca	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xd84f0ce8	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe7c183fc	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xeb186511	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xebdf8959	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x1b11f7d5	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x32af86a9	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xa3ab604f	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf8d3161f	nla_put_labels
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x002f70e6	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x25849543	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x293a9fc1	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x299fac5f	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x2b9b39a2	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3a1cb20a	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x417859e0	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x618d8c68	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6344eaf6	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x68c867af	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6fe7da3f	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x80664bb8	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x90425beb	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xae20e72b	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xb9490c58	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd5cea228	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xdce64f19	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x9e5551aa	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xd5bb0941	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xf58df3d3	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xf802e0fa	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x01bd607e	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x063e18f4	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x097d045b	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0b8da8ea	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0e5a0e7f	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x13eb5ed4	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1497885b	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x178830c1	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x215e294b	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x26035489	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2605302b	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x264965a7	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x26b549a2	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2dc71b3b	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2eb8cfd7	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x308bca79	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x311612ec	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x36437fa5	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x398d5e2c	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3a461292	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3b599fb7	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3b9538df	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x402cd77b	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x418cc08d	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x44244111	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4678b806	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x47f1473d	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x48a37f3a	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4c3275db	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4f5793b3	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x529018e1	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x590b5c9f	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5b5f1dea	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5c66a0a0	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5d21db97	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5f8a0b5d	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x622b94e3	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x645bb825	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6818117b	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6a18dc58	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6c2cb841	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6ce51be7	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x721bc817	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7401fff3	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7d2d43c0	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7e1e7965	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7eb682f6	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x802a0958	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x86906896	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x87ce43ee	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x881495f9	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x88bf0a39	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x98bbac61	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x992c5aeb	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9946c95f	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9c4895fc	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9dd06e5c	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa4dbd359	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaaa32530	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab1a3869	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad12aa69	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb2ac21ea	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb47e6789	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbb0f36f0	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbf2cd991	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbf723a8e	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc266dd56	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc47d6bf1	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcb33b098	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcee69296	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd1565224	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd2d4de96	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdc1488e4	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdd3f7cd7	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdf3f83e9	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdfe4a051	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe974484f	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xee22ea66	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf1367bc5	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf88a786b	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0xee84b3f6	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0xe0ae54d5	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x8bc9cbee	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x1ab3770f	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x1fdda91f	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x237cc34f	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x4ab9aa2c	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x4e82a2a8	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x65580d80	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xa35e4f88	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xa6b140a5	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xba986e87	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc3fed9a5	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0x6083df5c	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x1aab8963	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x618dbfaf	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x67dc37ed	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xe53cc3db	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x05364884	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xa13cca5e	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x29b8fd33	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x98fc619d	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xa7ad961e	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xade07f41	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xd35591e7	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xe5d63019	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xee110c84	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0x8845fbae	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0xf2a89153	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x3afe4b58	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x445d9025	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xb022201d	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xed0e2b9e	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x01664ca7	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x10b852af	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x1dec908d	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x378b8b79	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x3cdd2c5e	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x6c9f495a	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x82f4bc03	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x857387eb	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xaccd48be	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xdc7ce5d8	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xf96d8c66	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x710bbeab	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x839f3786	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x8841d39b	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x19a02384	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1afdbb7a	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x417e10dc	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x4f2d4206	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x79f28c9f	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x81dfdc11	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x8f0d097f	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x9bac8c19	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xb1e2f4f5	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc11a4204	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc1dcc291	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xd2f43053	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xd45806fb	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xd882b8de	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe7a05f08	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed4b1b24	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xfb1092f2	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x2083748a	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x27b7700d	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x52987a67	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x738c63fb	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x7b9437ef	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xb0c7f027	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xc519df72	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x8b558308	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xd39dc5ba	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xdfe28458	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0x7036922f	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x05abcfe0	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x3664766b	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x3e5152a1	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x13561715	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x16c6c019	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x7bb7c454	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x83a2f546	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x8e7ad4ae	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xe86b91f1	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x259d4ad0	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xce968114	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xdfe5d1b2	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x03a5a40e	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x8db75b95	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x0f889d0b	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x157189b9	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x19af0131	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x278fd8e1	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x415d8501	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x448f742b	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5bdbed44	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x795f0320	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8ae62bb0	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xae979ed7	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xb4636aed	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc063271f	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc8b3973a	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xfc4cca2d	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x4c32c169	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xb7459345	xt_rateest_put
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x681f2368	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0xbbe6b0c3	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0xcf0df4e5	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x6fe78079	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x8c53ad49	nci_uart_register
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x9541d207	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x0fb581b0	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x25ec1bd0	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x692c8878	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x6a67db47	ovs_vport_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x76a24ab1	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x8e88b6b6	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xbd20e21f	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xbd524361	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xcb847c47	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/rds/rds 0x00203e74	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x143b34be	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x31411514	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x39c98917	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x39f24206	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b3daae6	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x528bf67f	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0x5dc0f1e3	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x63dd98ae	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0x686abb6a	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0x68d5035f	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x6cf13336	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x76c4e233	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x8cfde243	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x96fafe85	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x9f849961	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xce0b7d37	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0xcf69825a	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0xd6b5c3f3	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0xde62acb9	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0xde673448	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0xee05a4d9	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0xf08c559b	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xf406e563	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0xf64df077	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x1cf7e92f	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xda7f1e37	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x4982d561	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x7c303ae4	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xdc2a7d15	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0032cdb0	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x01d4d44c	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x03a29b36	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05a034f2	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x073ec3c6	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x078872ff	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x07a6a934	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x07aac0cb	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0a837c8c	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0bfa2267	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0cebc042	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0d1fbecd	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0e656e09	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0e9029e6	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0e9449bb	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x10943cd9	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x10d40dda	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x11d228b0	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1202a4e3	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x146d4c71	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x148982c2	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x165ab81c	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x214c3cce	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x23c2fa1b	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x241d2d04	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x262fd72c	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x27e27a6f	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2a131d67	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2a152a76	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2b392f56	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2b5a7231	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2bc67628	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c41b17f	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2cd1b22a	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2dc2fa54	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2def065e	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2e2d1b11	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eac34b3	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f8ebbe0	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3078ed94	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x316a6ca6	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31fdaa91	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3256aa34	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x33eac1b6	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x372b022d	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x37fba5f0	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x38921779	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x39cc9f26	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3ac203bd	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3aee1c2e	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c46572e	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f40b422	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f684aa2	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x40a6b13a	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x41b0481e	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4260ba8f	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x42c01b09	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x434e2978	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x44badd78	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x455b7e7b	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x45a709fd	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x47d5c5c1	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x48ee9a93	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4a691b3d	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4e6579ae	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4ef9b0b9	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x518b79fd	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x51f935c6	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x530b5dab	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5356e7f2	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x55688a42	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x56c4a27c	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x58428350	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x595d3839	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x595dd422	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5a35db88	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5c92f4d8	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5d62b74b	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5df365d2	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5df665bb	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5e11fe3a	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5eb75e5b	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5fa2f765	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5fed2aaa	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x602afa72	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x62155cc9	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x626f7633	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x63b50cfd	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x65fdf04d	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6609b9af	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x664bfccd	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6abdf384	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6d1dcb7f	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71c43efd	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7481680b	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x74a8d4b1	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x760a46a3	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x774c48a0	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x78d8a840	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7b0ca84d	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7c716989	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7f46fd8d	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8073076a	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80e7a1c9	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x812e694e	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x82d642fb	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x840df893	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8799921b	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8835b68f	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x890633dd	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8cb46f4e	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8e381ca3	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x904c360d	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x92bf3071	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x938e8cbd	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x97ff39da	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x996f6914	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9a270629	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ab2f76e	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9bb468d6	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ce94afc	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9d16c12a	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9d84942b	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ed7a1a6	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa2a3738e	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa5ac661d	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa7ae888e	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa8e7d960	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa982fe92	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa9f82245	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa5c9d03	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xac36722c	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xac52835a	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb0e52e5d	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb3fb446a	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb9ff9cb3	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbb6c6ea0	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbba7438a	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbc9624d1	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbd0c0364	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbe2528b2	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbe436e58	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc02ab066	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc10b1bd2	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc16a8deb	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc233b9ee	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc2e6dea3	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc2ef0d84	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3097d4c	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc5beecad	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc68a87e2	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcb83e5a2	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcd195d51	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcd9fd2a7	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce0dce6c	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce83705f	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd14c8eb9	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd22c4cd9	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd4086a97	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd5b3714f	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd622686f	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd64e947f	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd6e5686c	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7368a3f	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdb39feef	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdc725188	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdd560ec9	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xddc45c84	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xde58156c	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xde6d428c	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdf383b74	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe04eb6c5	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe2612845	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe44bb16c	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe823eaec	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe99eb6d3	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xea553092	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeb31a535	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xec9e81c1	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xed26b3e5	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef0b10e0	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef702c5d	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xefb06bdd	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf26371fd	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf2a17076	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf31f68f9	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf3e7d3ed	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf481cfd8	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf7dd157c	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf80d4c02	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf8112c4e	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9ab2a1c	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa301956	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa8531d2	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfb00c1a6	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfc4b1305	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfceb4c3e	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfd0d1c8b	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xffc174ae	rpc_pton
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x02e6c5e3	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x05dc71b7	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0e8e6b6f	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x161de470	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x36abb745	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x3e40ca62	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x50a6ed8d	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x51b6a135	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x6004525b	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x69d41d6b	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x6feb0d0b	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x74e91915	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xdf880c26	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xe71f35b9	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf593c40a	vsock_pending_work
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x1b4b85e4	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x26432e09	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x2aee4a58	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x5c371786	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6fb2cea8	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x727bcf27	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x843865f5	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x857a4d19	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x9044d3ad	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xa4fd329d	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xab9853ea	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xba746e8e	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xd0daea24	wimax_msg
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x1a68ab6d	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x38c3b8f2	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x6359624a	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x69eb3a59	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x8708ffb9	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x8f424b3d	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x9394e2db	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x9551efb6	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xad208c23	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xb017cfaf	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xb9d04672	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xde98fe66	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xe53d784d	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x0300ebff	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x12391bc4	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x967e4eec	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xe1d6de51	ipcomp_destroy
++EXPORT_SYMBOL_GPL sound/ac97_bus 0xb5053e05	snd_ac97_reset
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0xe8fbd5ae	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0xf1f49ac2	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/core/snd 0x1f0d0560	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL sound/core/snd 0x43b52854	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd 0x50905117	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd 0x5cbc213e	snd_device_initialize
++EXPORT_SYMBOL_GPL sound/core/snd 0xa1b3cbf3	snd_device_disconnect
++EXPORT_SYMBOL_GPL sound/core/snd 0xb7fc12d6	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL sound/core/snd 0xf8ec3d8e	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0x3369dff1	snd_compress_register
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0xd1c773a7	snd_compress_new
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0xe31fd6c6	snd_compress_deregister
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x10ae3576	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x42a9e61d	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x431ef12d	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x7ca87a1a	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x7e4f13ce	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xc0964d50	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xd3a5ec8e	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xd997ded1	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xf8ed3fd5	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x2e47d726	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x3efd4a73	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x6276887b	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x6b334aaa	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x6e70cbed	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x90605d2e	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x9192668a	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x91caf507	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xa42f127f	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xbd79e2eb	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xcacb6fdc	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x1e6683fe	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x3b19e364	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xa9a9a1af	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xad7be554	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xba81a1f7	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xc3091055	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xd1e8561b	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x01494bb2	snd_hdac_ext_bus_device_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x045d9707	snd_hdac_ext_stop_streams
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x061fb165	snd_hdac_ext_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x1451754a	snd_hdac_ext_stream_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x16534ef6	snd_hdac_ext_link_stream_start
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x20e80018	snd_hdac_ext_link_set_stream_id
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x36173a68	snd_hdac_ext_bus_link_power_down
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x3de951e2	snd_hdac_ext_link_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x42662d19	snd_hdac_ext_bus_device_remove
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x4e17fe64	snd_hdac_stream_free_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x57b95d46	snd_hdac_ext_stream_init_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x621b26de	snd_hdac_ext_bus_ppcap_int_enable
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x630eef3c	snd_hdac_ext_link_clear_stream_id
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x67de0c97	snd_hdac_link_free_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x6a647279	snd_hdac_ext_bus_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x7ae47520	snd_hdac_ext_bus_get_ml_capabilities
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x91e19569	snd_hda_ext_driver_register
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x9229a2f5	snd_hdac_ext_bus_link_power_down_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x95dc300e	snd_hdac_ext_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x9c3a756b	snd_hdac_ext_stream_release
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xae1ac067	snd_hdac_ext_stream_spbcap_enable
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xbad4a90f	snd_hdac_ext_bus_link_power_up
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xbbacf8a5	snd_hdac_ext_link_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xc9b56911	snd_hdac_ext_stream_get_spbmaxfifo
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xca96609b	snd_hdac_ext_bus_get_link
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xcdc49ad3	snd_hdac_ext_link_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd10ffcd8	snd_hdac_ext_stream_set_spib
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd2d14383	snd_hdac_ext_stream_decouple
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd4c8eb07	snd_hdac_ext_bus_parse_capabilities
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xdcd4b7fe	snd_hda_ext_driver_unregister
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xf6629c1b	snd_hdac_ext_bus_device_exit
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xff901d1e	snd_hdac_ext_bus_ppcap_enable
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x02fc89cc	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0d6a92a1	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1a71cfc9	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1e62e371	snd_hdac_i915_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x20d12288	snd_hdac_i915_init_bpo
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x24c5f332	snd_hdac_set_codec_wakeup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x24e38b83	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2556739b	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2b97ac97	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x37497054	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x39a21887	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3db7dbf6	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3e6ab304	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4db5ffbc	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x519ae1e0	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x51aec7cf	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5227c00b	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x571820b5	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5f0d8a91	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x602bdc14	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x605bd736	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6149a6fa	snd_hdac_i915_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x62e1c314	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6f9be6dc	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6fa478b8	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6fb271c6	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x70f2cfdf	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x73187668	snd_hdac_i915_register_notifier
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7e95dde3	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7ea9e694	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8645d15d	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8b02e91e	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8b21f5d6	snd_hdac_get_display_clk
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8cfc3db5	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x953e2e1c	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9adfef3a	snd_hdac_display_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9de2fc6e	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9f4790bc	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9f8f18f5	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa77a060c	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xad786bf0	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xaf12c3ee	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xaf1e17c9	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb1c6449c	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb224d4fb	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb2ba8e4c	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb4c0fe58	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb5129871	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xba6b920c	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbdbbc7f4	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc18e209d	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc5aeb3b0	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc5fa24e5	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xce8ce985	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd2d1aa14	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd7bf1383	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd918bb96	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdb11efcf	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe4feedef	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe794112c	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe7b9bcbe	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe8217a9e	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe8d797b6	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe91a24d3	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xea29e5ae	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xeb9ee1a5	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf017044d	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf2abcade	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf44c3d14	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf849e9e0	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf9183d5c	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf9a2a621	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfa8bca6e	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfc457aba	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfd0c9ef6	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfeb0cfa3	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfeeb8453	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xffb9687c	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x16983fc7	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x2a31b1a2	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x4dc2611d	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x903b0a6d	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xbf002810	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xe3910251	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x00ece88c	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x01e9eaba	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0318474b	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x03686a4a	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x03e8bf51	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x05b3181b	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x05fa3a06	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0939b919	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0ba16fa8	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0fda24cc	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x116babb3	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1263588a	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x153f3d84	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x15fdf257	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x19b52afd	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1ad1215b	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1c6c6634	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x21202742	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2400cc64	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x24b12e25	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x28e50388	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2a6d56aa	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2da13d92	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x30845dff	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x335a61a1	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3503cfd0	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3560dbc1	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3561bf23	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x356e8f69	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x36af9a67	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x37ecf48b	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x39dab992	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3ab58953	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3c6707dd	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3d4ae1d6	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4377a353	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x437f6f37	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x43821000	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x44e1e0f2	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4658d229	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x468466f6	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x46a5c9a0	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4a7410d9	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4ab41b4a	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4ade9ec1	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4cc0bf40	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4eee8cc7	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x509555b2	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5238505c	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6146eed9	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x65328ce1	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x69b2057e	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x69eb7751	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6affda71	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6c2ddfdc	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6ec34c5d	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7007d379	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x74cf8fb8	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x76af97ec	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7a2ed353	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7b621556	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7b75996b	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7d9974c9	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x80361f35	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8037e4ea	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x897b7318	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8a00a27b	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x906a06c1	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x924089b4	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x938091d0	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x96cfd19d	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x99423dd2	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a3ccea0	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a77a9fd	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9bb7fb26	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa13ff906	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa2c1cb76	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa4cb0a17	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa58a8b8d	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa97f68c0	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa9f8a077	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaa06f07b	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xab08ff4a	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xacde5b7b	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xad016736	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb1c1394e	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb25c887b	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb37b8b2a	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb56f83b9	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb9658776	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb9fb6119	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbab42cb0	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbb84d04f	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbc5fdfc6	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbfbc4f0c	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbff865ed	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc3ffae61	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc4658c3e	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc5431712	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc5a73db1	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc65a4aca	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc8a57a33	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcad7a21e	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcb7fa199	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcc1f99d3	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcce2e6e4	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xce4ff92c	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd09b235e	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd203ae9d	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd4f8a5fd	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd6431130	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd6d236a5	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdc994dfa	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdff5c053	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe0977646	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe227028a	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe4858df8	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe4a39d60	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf5680e7b	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf58d2222	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf646c996	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfb2007ef	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfba55ba5	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xffe42e7e	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x01f8bc5d	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x020e0604	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x0c055aa8	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x0c0651b5	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x1e03980c	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x1eac51cc	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x2dec02d1	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x34edf817	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x406cddac	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x4642861d	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x53115002	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x6c961ff2	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x84725abc	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x96a62d04	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xb00fc528	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xb56e456e	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xc19623b4	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xce3e26bf	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xefe753ac	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xf18148f7	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xfe169c17	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xba1b50a7	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xfd9e1593	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x0b12ba05	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xe8c6bd26	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0ffc099b	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x56bbe430	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x926d8f23	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x64dfd157	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0xc7dade03	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98090 0x7fb85938	max98090_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x59a8d04b	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x8b1af2c3	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xe1ff994f	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xf797385d	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x70617a04	rl6231_get_clk_info
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x7f68b24d	rl6231_pll_calc
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x8d7fa148	rl6231_get_pre_div
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0xdba4502f	rl6231_calc_dmic_clk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6347a 0xa7aa810f	rl6347a_hw_write
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6347a 0xade4bf4c	rl6347a_hw_read
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt286 0xbf6dae0b	rt286_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5640 0x504e06c8	rt5640_dmic_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0x92e0014e	rt5645_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0xcb190cf8	rt5645_set_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0x186ef895	rt5670_jack_resume
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0x476f0c77	rt5670_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0x734eebad	rt5670_set_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0x7fa8f9fd	rt5670_jack_suspend
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x0d5ac1fa	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x1514aedf	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x54df6381	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x9939198b	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xd04f933d	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0x3cce3817	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sn95031 0x4d89fbca	sn95031_jack_detection
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x3e8bba19	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x56e0f88e	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x5d8033a7	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xfcfd2c01	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0x422d42b9	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x151a98a5	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x1f0d1db1	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x38b9a353	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xb4d1d984	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0xc95cd9db	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0x2c13544a	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x45dae049	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0xad37685e	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/snd-soc-sst-mfld-platform 0x805a8be7	sst_unregister_dsp
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/snd-soc-sst-mfld-platform 0xb64e65f1	sst_register_dsp
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x0c51379f	sst_alloc_drv_context
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x90350ee1	sst_context_init
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x93350770	sst_configure_runtime_pm
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0xab14edd5	relocate_imr_addr_mrfld
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0xbbc1762c	intel_sst_pm
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0xd50586d4	sst_context_cleanup
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0x40229cf8	sst_byt_dsp_wait_for_ready
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0x54cc261d	sst_byt_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0xb7969f4d	sst_byt_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0xc02e18f9	sst_byt_dsp_boot
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0xdf35fbaf	sst_byt_dsp_suspend_late
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x0c2b1eee	sst_module_get_from_id
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x0c938b6c	sst_mem_block_unregister_all
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x1826644d	sst_module_runtime_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x196ebe0c	sst_dsp_inbox_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x1b5e8b82	sst_shim32_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x1ba05317	sst_dsp_inbox_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x1c27521e	sst_dsp_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x1cedab2a	sst_module_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x222ce07f	sst_block_alloc_scratch
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x282f9ce8	sst_fw_unload
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x28b93573	sst_dsp_register_poll
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x2c422c39	sst_dsp_outbox_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x32dfa939	sst_block_free_scratch
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x3691d71e	sst_module_runtime_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x3a47d591	sst_dsp_dma_put_channel
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x418fb2f9	sst_dsp_ipc_msg_tx
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x42378a7e	sst_fw_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x43ab05ed	sst_dsp_shim_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x450c7327	sst_dsp_reset
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4535421f	sst_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4a045773	sst_shim32_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4cc3d9af	sst_dsp_stall
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4d26bba6	sst_dsp_outbox_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x54020752	sst_module_runtime_get_from_id
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x5637de78	sst_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x568b4ff5	sst_dsp_dma_copyfrom
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x61ed28cf	sst_memcpy_toio_32
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x62b60398	sst_module_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x65e798f6	sst_dsp_get_offset
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x662517b6	sst_dsp_sleep
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x67ed4530	sst_module_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x7bc08099	sst_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x80eb9bdf	sst_dsp_boot
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x817bfd99	sst_module_runtime_save
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x81f340fa	sst_dsp_shim_update_bits64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x8277f5cb	sst_dsp_dump
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x8bd9a245	sst_dsp_shim_update_bits_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x8d8e20e4	sst_mem_block_register
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x9fbfa1cf	sst_dsp_dma_get_channel
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xa0e57e9e	sst_fw_reload
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xa0ef798e	sst_dsp_shim_update_bits
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xa2761be7	sst_dsp_shim_update_bits_forced
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xa7781b15	sst_dsp_dma_copyto
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xad93290d	sst_dsp_shim_write_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xaed7cad5	sst_dsp_shim_update_bits64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb01fcf21	sst_dsp_shim_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb8e9f475	sst_fw_free_all
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbc7a6452	sst_memcpy_fromio_32
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbcec5387	sst_shim32_read64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbdbaea8a	sst_dsp_shim_write64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbe0a718b	sst_module_runtime_restore
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xc183948b	sst_dsp_mailbox_init
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xc892c522	sst_dsp_wake
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xc9120097	sst_dsp_shim_read_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xcce0c82c	sst_dsp_shim_read64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xcd14461b	sst_dsp_shim_read64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xd9a2c94c	sst_shim32_write64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xde4fa098	sst_dsp_shim_update_bits_forced_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xe1bb0d4c	sst_dsp_ipc_msg_rx
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xe31a9f30	sst_fw_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xe55b005f	sst_module_runtime_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xe89d7ca2	sst_dsp_shim_write64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xea2094d8	sst_module_runtime_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf605a51b	sst_module_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x31daf7a7	sst_ipc_tx_message_wait
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x5676fa9a	sst_ipc_fini
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x6b3bfc4f	sst_ipc_tx_msg_reply_complete
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x9607ddca	sst_ipc_init
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x97a2a1d5	sst_ipc_drop_all
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0xeb0b70e5	sst_ipc_reply_find_msg
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0xf4417675	sst_ipc_tx_message_nowait
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0xaafe364b	sst_hsw_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0xd1f69f64	sst_hsw_device_set_config
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0xf0dbac97	sst_hsw_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x07ffdaf1	skl_dsp_wake
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x1b7510e4	skl_ipc_save_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x283aa1d5	skl_ipc_restore_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x3461afa5	is_skl_dsp_running
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x63acbe0e	skl_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x73f464d3	skl_ipc_init_instance
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x762b1161	skl_ipc_set_dx
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x7d412df3	skl_dsp_sleep
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x98d18f19	skl_ipc_bind_unbind
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xba2973f4	skl_ipc_delete_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xc24991c9	skl_ipc_set_pipeline_state
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xc3dd2c4d	skl_ipc_create_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xe1c079a7	skl_sst_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xf0739679	skl_ipc_set_large_config
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xf5794d20	skl_sst_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0207321c	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x02ad3ea2	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x04820e15	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x06cc52e0	snd_soc_component_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0a7a6af9	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0cde7bbc	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0df41eb8	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0e05af54	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0f54757b	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x10013849	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1061a3f9	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x110eb00c	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x113e1c7d	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x11b544f5	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x11cb0c2d	snd_soc_tplg_component_remove
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x129f02aa	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x13e70286	snd_soc_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x16072c94	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1af4a553	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1be0eecb	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1d8de501	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1e34796d	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1ea4d622	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1faef90a	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x21c90feb	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x22cb9ab9	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x23fe5552	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x25fa0f27	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x284a5a13	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x29cfbd83	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2b88b432	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2dfc7851	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2e62741c	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2eaa5910	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2f0507df	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2f0c0fd6	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2f1550c8	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x32a02bf6	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x34715cd9	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x393a0508	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3bf3d872	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3c29c9d4	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x400dd2bf	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x41987f9b	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4222e6f3	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4242b71e	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x433a610f	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4384de22	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x43fbfc15	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x44866539	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x459c3f4d	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4992f490	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4bcdc7f6	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4fe2e38a	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4ff2061e	snd_soc_tplg_widget_remove
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x52fc482b	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5753d68f	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x57dd4a71	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x58c797a2	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x59931cd6	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5a4a8356	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5b2f2ca1	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5b85921f	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5f42e01a	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x605a823e	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x61056597	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6324703b	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x68ef4606	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x696a8631	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6a8093db	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6e3fb37c	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6e9572ef	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6f5f65e1	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x71189d0d	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x72cb8277	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x73fc14a9	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x750f849a	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x75b290a0	snd_soc_tplg_widget_remove_all
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7632eeb6	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x770eccd4	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x795fbbe5	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x79ebfa62	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7d0a4ab6	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7d4e78f6	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7d6502af	snd_soc_new_compress
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x814426b6	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8185ed67	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x81f868e2	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x83bd0d6f	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8bea515e	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8d7036ba	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8f98b909	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9400805d	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x94235641	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x94370f28	snd_soc_resume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9496057c	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x96830015	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x98d7970b	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x99369e70	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9acda6ea	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9b2ee824	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9dc83c2a	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9efc68aa	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa14ea9f3	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa192ff63	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa34297e3	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa43999f4	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa7b06361	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xab2dda6d	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xab9251d0	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xab9cf067	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xac9a6b1d	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb03c1367	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb0eef76d	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb259a3a6	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb7c2f96f	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbd208a29	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc11e5426	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc147175e	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc1d1f012	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc1d2854b	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc25b28e5	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc43986cf	snd_soc_component_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc56292a3	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc6911eca	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc865af0c	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcaae67b6	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd0f607a6	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd0fac2fd	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd1cd72fc	snd_soc_tplg_component_load
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd3a4f0ef	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd48742d1	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd59dbdde	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd5ef551f	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd8749ec1	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xda1f3dbb	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdfb288c0	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe1fd95c6	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe33e7217	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe5447e51	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe56bcf6c	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe5d37765	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe695dc25	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe93e7b9d	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xea82f48c	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xec69d841	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xec8073cb	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf12b5c26	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf313bdc4	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf3714d3b	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf3ca7bb1	snd_soc_tplg_widget_bind_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf5ceb439	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf5cf9e45	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfaf0a642	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x1bb22dc9	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x20328899	line6_suspend
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x22c5e252	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x3621e0f7	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x3ae7436c	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x5c701830	line6_write_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x5d126cb4	line6_pcm_release
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x72dd2707	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x77427358	line6_read_serial_number
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x7a4de52f	line6_pcm_acquire
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ea1de72	line6_version_request_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8f194d12	line6_init_midi
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x9fd8b696	line6_send_sysex_message
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xa135b60c	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xfcda6b7d	line6_read_data
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x08003b2f	i915_bpo_gpu_turbo_disable
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x0d97d346	i915_bpo_gpu_raise
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x358a54ae	i915_bpo_gpu_busy
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x451432c2	i915_bpo_gpu_lower
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x7d4de94c	i915_bpo_read_mch_val
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x00eb718d	ven_rsi_read_pkt
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x101236e4	rsi_init_dbgfs
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x12ebbfd7	rsi_send_rx_filter_frame
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x1e678bb2	dot11_pkt_type
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x267fd716	rsi_send_rfmode_frame
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x328042dd	ven_rsi_mac80211_detach
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x437447f4	rsi_hex_dump
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x45ca198c	ven_rsi_dbg
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x49493d1d	rsi_config_wowlan
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x4d1ea4de	rsi_remove_dbgfs
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x59a92f09	rsi_hal_device_init
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x7e97b420	ven_rsi_91x_init
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x8e02e104	ven_rsi_91x_deinit
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xa6d19714	rsi_hci_attach
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xb92892bc	rsi_deregister_bt
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xcaec6602	rsi_default_ps_params
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xdbf0d52a	rsi_hci_detach
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xe610d5b1	rsi_hci_recv_pkt
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x3fe35aea	irq_bypass_unregister_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x418873cc	irq_bypass_register_producer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x888c5be5	irq_bypass_register_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0xf6e772c3	irq_bypass_unregister_producer
++EXPORT_SYMBOL_GPL vmlinux 0x002dba6b	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x0034f3b6	xen_has_pv_nic_devices
++EXPORT_SYMBOL_GPL vmlinux 0x00462bb8	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x00632780	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x006ec128	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x006f59eb	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x00747181	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0x008f5ae8	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00ab1a7e	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x00e7a120	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x00f8624f	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x00fac9ac	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x010ee2d2	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0x011047e2	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x014b6628	dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0x015ef0cd	device_move
++EXPORT_SYMBOL_GPL vmlinux 0x016ad45a	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x0170cb6c	efivar_work
++EXPORT_SYMBOL_GPL vmlinux 0x0178796a	__efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x01848a8e	local_apic_timer_c2_ok
++EXPORT_SYMBOL_GPL vmlinux 0x01852310	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x02010eb3	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x0223bcf2	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0x022dd0ff	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x023cc7bb	__efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0x0252ab4f	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x025b7a1e	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x02653eac	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0x0283ebab	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x02956853	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x02963686	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0x029e42c4	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0x029e7101	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x02a75267	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0x02e0df77	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0x02e3b109	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0x02e8201f	to_nvdimm_bus
++EXPORT_SYMBOL_GPL vmlinux 0x02fa1242	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x03010687	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x03071a61	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x030c9848	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x031cbaa6	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0x03275737	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x032e7586	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0x033019b7	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x03375639	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x0373a727	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x037f6ddb	unregister_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x03814aac	ata_acpi_stm
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03a5fec9	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0x03a71968	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0x03ce75ee	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x03d77078	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x0402cbbf	preempt_notifier_inc
++EXPORT_SYMBOL_GPL vmlinux 0x04363c3f	rio_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x04384714	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x043bf3c9	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x04551fb7	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x045c2eab	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x046b0093	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0x046c1620	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x047c8ddf	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x0485655f	amd_get_nodes_per_socket
++EXPORT_SYMBOL_GPL vmlinux 0x04897b9a	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x048a6846	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x04972400	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04b0807c	ata_acpi_cbl_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x04b1ba2a	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x04bf26af	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x04c3f2c1	gnttab_empty_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04d055af	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x04d07f92	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x04ecfb5c	set_memory_wt
++EXPORT_SYMBOL_GPL vmlinux 0x04f4bd8d	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0509cf6a	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0x05125d80	to_nd_desc
++EXPORT_SYMBOL_GPL vmlinux 0x05196d63	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x0524dc28	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x05306bfe	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x05564d79	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x0574e17c	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x0576fd25	md_run
++EXPORT_SYMBOL_GPL vmlinux 0x0587a13d	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x0589a49d	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x05a9367c	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x05cc2363	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x05dbb78e	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x05f5dd56	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x06161f53	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x061f2938	rio_mport_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x064b4c83	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x065a0280	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0x065dc81c	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0x0668692a	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x06963c36	intel_msic_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x069b74c6	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0x06c9fc91	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x06d549e6	pinctrl_free_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x06edbbb6	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0x07032f9e	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x0706f924	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0x071ee624	__tracepoint_detach_device_from_domain
++EXPORT_SYMBOL_GPL vmlinux 0x073a338b	fpstate_init
++EXPORT_SYMBOL_GPL vmlinux 0x07442711	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x077efbb9	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x07916685	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x0795c414	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0x079c731d	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x07a4f537	x86_vector_domain
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07d8f332	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x07f300c3	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x081e65a5	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x082333d6	rio_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x0829127d	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x0879fc94	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x08a101e5	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x08c06da7	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x08d26f05	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x08ebab77	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x08f0bd3c	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0x08f10258	gnttab_unmap_refs_sync
++EXPORT_SYMBOL_GPL vmlinux 0x0903fe67	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0961ebc6	__rio_local_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x0962d0e8	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x096ed14b	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x09829c1e	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x098592cc	ata_acpi_gtm
++EXPORT_SYMBOL_GPL vmlinux 0x0989378c	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0x09b09813	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0x09dc0244	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0x09eb3f19	pinctrl_remove_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x09eda0a2	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0x09f20cdc	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0a0f34f2	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x0a11e18c	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0a1f36b3	rio_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x0a3ee7e1	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0x0a4fde00	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x0a519867	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0a57df06	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0a5914af	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x0a64775f	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x0a674bf3	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0a737c67	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x0a742ea5	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0x0a89b220	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0a8d21ae	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0x0a97fc9d	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x0a9be626	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x0a9cc482	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x0a9de457	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x0af4e2cc	rio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0afd4610	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b1a9bef	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x0b52e502	apei_resources_add
++EXPORT_SYMBOL_GPL vmlinux 0x0b911090	xen_pci_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x0bad2538	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0x0bad4cac	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0bad76d6	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x0bad8bfd	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x0be30b6e	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c097119	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c0e583d	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x0c23613c	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c33d743	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x0c53eecc	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x0c5b8061	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x0c5bc86b	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x0c805f93	clflush_cache_range
++EXPORT_SYMBOL_GPL vmlinux 0x0c80e3fe	efivar_init
++EXPORT_SYMBOL_GPL vmlinux 0x0c8fa94a	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x0c94ff64	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0ccf86de	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x0ce75a41	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x0cf52b62	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x0d059e64	static_key_deferred_flush
++EXPORT_SYMBOL_GPL vmlinux 0x0d0a115c	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x0d107daf	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0x0d29b3cd	xenbus_frontend_closed
++EXPORT_SYMBOL_GPL vmlinux 0x0d2c8b0b	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d4e446d	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x0d6fcf66	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0d85a87c	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x0d918865	dax_pfn_mkwrite
++EXPORT_SYMBOL_GPL vmlinux 0x0d9bd8cb	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x0da09cec	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x0db649e4	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x0db8d22d	clk_hw_get_num_parents
++EXPORT_SYMBOL_GPL vmlinux 0x0dce1f9c	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0df6ba51	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x0df925f6	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0x0e007edf	xen_evtchn_nr_channels
++EXPORT_SYMBOL_GPL vmlinux 0x0e13cb4d	apei_resources_release
++EXPORT_SYMBOL_GPL vmlinux 0x0e1b8e8e	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x0e20aba6	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x0e52ff11	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x0e6a33a0	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0x0e833c1a	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x0e8d6972	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x0e919b34	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0x0eaacca8	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0x0eb37246	clk_register_gpio_mux
++EXPORT_SYMBOL_GPL vmlinux 0x0ed21548	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x0ed57b66	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x0ed6925f	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0x0ee72fea	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0x0f0e4109	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0x0f289ac1	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x0f2d7d87	mce_unregister_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f361b45	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x0f3bb7dc	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x0f543e9d	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x0f5d1017	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0x0f6e4206	gnttab_unmap_refs_async
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f783fee	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f8ed4eb	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x0f93e8eb	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0x0fa138de	xen_hvm_need_lapic
++EXPORT_SYMBOL_GPL vmlinux 0x0fa24308	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0x0fb9f204	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x0fbff461	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x0fc01e9f	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0fcc1969	copy_from_user_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x0fe2d570	xenbus_directory
++EXPORT_SYMBOL_GPL vmlinux 0x0fe3577a	acpi_dev_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0fe7d785	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x0fe859e8	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x10075bf3	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x10092113	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x102e56f9	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x10383b9f	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0x103b8d63	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x103de206	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0x1059cd4a	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x10604b26	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x1094725e	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0x10abcde9	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0x10c927b1	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0x10cdc4d2	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x110106c1	cper_severity_to_aer
++EXPORT_SYMBOL_GPL vmlinux 0x11199183	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x11216fb1	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x1140a2d8	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x11932187	acpi_subsys_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x11a3d991	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x11d7589e	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x11d81720	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x11dfb69e	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0x11e3f7c4	rio_map_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0x1211e545	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x1214694d	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1235e860	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0x12365e8c	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x12547883	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x126fdb51	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0x1273b31a	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x1298bcf4	nd_device_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x129bd5e4	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x129dbd5c	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x129ebad5	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x12a1fdc5	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x12b00439	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x12c8d89c	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x12ca8e17	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x12dfb1d6	xenbus_watch_path
++EXPORT_SYMBOL_GPL vmlinux 0x12ea3c14	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x130bd388	check_tsc_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x134a7977	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x134e3bcb	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1365cebe	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0x1372a4bc	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0x138aff76	gnttab_init
++EXPORT_SYMBOL_GPL vmlinux 0x13ad647f	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x13b89dee	pinctrl_request_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x13bb5cb5	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x13c3efa9	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0x13c5a4ee	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0x13ede55d	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x13f51fc3	ms_hyperv
++EXPORT_SYMBOL_GPL vmlinux 0x140477c5	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0x141a67cf	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x142f240e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0x14530b1c	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x14579e22	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x1470f694	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0x14937b9b	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x1498cd24	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0x14a54d1a	xenbus_map_ring
++EXPORT_SYMBOL_GPL vmlinux 0x14bc6acf	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x14c1ddcd	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0x14e60851	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0x14ee8ad1	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x14fb3d5c	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x15010e1f	arbitrary_virt_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0x1515313d	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0x15203ab5	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x153a2378	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x1540c469	efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x15450b25	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0x154642db	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0x154c985c	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0x15568631	lookup_address
++EXPORT_SYMBOL_GPL vmlinux 0x156107b1	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x1568f79b	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x1578beb2	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x157d6335	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x15b0606e	e820_any_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x15dc5fdc	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x161f4df3	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0x1627e626	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x162f78f8	rio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1646aa2d	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x164934f4	pgprot_writethrough
++EXPORT_SYMBOL_GPL vmlinux 0x164f16e2	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x1664cfca	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x16707705	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x16b15d3f	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0x16b4fc5c	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x16e215c6	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x16ef3254	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x17045172	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0x1716a5cc	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x1716cd73	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0x172d08b8	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x17321c22	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0x17614bf3	apei_resources_sub
++EXPORT_SYMBOL_GPL vmlinux 0x177c25ee	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x17826ef9	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x1792e71f	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x17984f0b	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0x17994d70	memhp_auto_online
++EXPORT_SYMBOL_GPL vmlinux 0x1799a7c2	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x179bca0e	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x17a73204	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x17d71d4c	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x17daf154	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x17f63e87	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x183c8ef2	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x184f5113	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x18582826	amd_pmu_disable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x186bcb40	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x189bfbd1	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0x18ac7f3c	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x18c40c8c	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x18c5e961	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x18c805bd	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0x18edf8d6	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x18f5e50e	arch_apei_enable_cmcff
++EXPORT_SYMBOL_GPL vmlinux 0x18f83fab	gnttab_grant_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0x18fd91d9	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x19104941	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x19248c1f	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x19274aed	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x1934b829	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0x1942c88b	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x194e81d9	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x1959dc86	hypervisor_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x196614ce	hw_breakpoint_restore
++EXPORT_SYMBOL_GPL vmlinux 0x19702390	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x19755b98	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x1990f8ff	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19a95529	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x19c2910f	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x19f24edc	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x19fdbd74	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0x1a16e170	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0x1a1b53c8	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x1a1c4082	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x1a4f9a90	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x1a509c46	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x1a55d365	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1a9afa23	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x1a9cb062	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x1ab91595	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0x1ab9f936	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1adb4a5f	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0x1af958f7	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0x1b1f2bda	speedstep_get_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x1b38b3c6	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0x1b3e3a8c	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0x1b43f5bc	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x1b52db1c	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x1b52ddc8	acpi_subsys_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x1b68b0ac	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x1b790944	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0x1b8822d8	pinctrl_gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x1b8efa0f	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x1b90882e	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1ba1ee94	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x1bb2d05e	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0x1bbd88f6	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0x1bc5eebe	pinctrl_gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x1bdd263e	xen_remap_domain_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x1be5074d	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0x1c114562	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0x1c340583	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x1c4651ff	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c5ff742	clk_get_phase
++EXPORT_SYMBOL_GPL vmlinux 0x1c6660c7	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0x1c66ab46	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x1c79969d	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x1c7e005c	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1cc60b94	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x1cdd5440	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0x1ce51409	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x1d112c28	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d3b41b3	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x1d3c0ef0	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x1d459685	xstate_size
++EXPORT_SYMBOL_GPL vmlinux 0x1d4b6855	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0x1d4c959d	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d681eb5	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x1d739e1c	xen_set_callback_via
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1d7cb586	clk_register_fixed_rate_with_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x1d82f054	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0x1d8cbe7d	nvdimm_volatile_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x1d9da838	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x1def880e	bind_interdomain_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1df5463e	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x1e05d1d4	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0x1e2190e5	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0x1e408843	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x1e41969a	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e5d3e89	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x1e655037	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e80cce5	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1e92fef1	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0x1e93b0eb	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x1e9b90d6	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0x1e9c6f77	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0x1e9d0f78	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ebfc1c5	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1edcb439	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x1edea8c4	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1ee4592a	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1eea04c2	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0x1ef5914a	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x1f0c72ae	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0x1f1b663a	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0x1f1c61d1	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x1f3303b1	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x1f406110	rio_request_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x1f5b0ace	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x1f7f6fac	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1fa0ae4b	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1fa190a5	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x1fdbbb37	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0x1fe6ef61	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x200619d5	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x20070d8a	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x200cc695	__free_iova
++EXPORT_SYMBOL_GPL vmlinux 0x20398ffe	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0x204e66e6	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0x20741170	acpi_dev_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x208a5a28	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x209ec764	xen_event_channel_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0x20a25dce	acpi_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0x20aa6f51	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x20c359f3	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x20e12bd0	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0x20f2afa5	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x20f935a0	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0x20fed3b3	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0x21317018	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x21356c4c	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x213e2574	clk_hw_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x21625eed	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0x216e7d1c	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x2182c507	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x21a563da	clk_get_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21b17d9b	pinctrl_lookup_state
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21d3eb3a	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x21dd2645	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x21e19f3d	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x224fedc5	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x227a2181	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x2287f137	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0x22951750	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x2299ec81	perf_assign_events
++EXPORT_SYMBOL_GPL vmlinux 0x22ac0199	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0x22b70e6f	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0x22e18a13	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x22f97be1	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0x2302d3d9	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0x23048011	__intel_mid_cpu_chip
++EXPORT_SYMBOL_GPL vmlinux 0x230c9cd3	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x2311ed74	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x2315a82c	clk_mux_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x232fba9b	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x234900de	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x23526622	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x235e0caa	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0x23634a50	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0x23644594	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2366a2c0	errata
++EXPORT_SYMBOL_GPL vmlinux 0x23770f29	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x2396c7f0	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0x239f1f7a	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x23ad0d89	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x23adf953	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0x23b48c20	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x240580a9	xenbus_probe
++EXPORT_SYMBOL_GPL vmlinux 0x2440ffb6	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x2460a5bf	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0x24656ad9	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0x246e5758	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x247bf620	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x248d1bd1	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24c7698a	xenbus_write
++EXPORT_SYMBOL_GPL vmlinux 0x24d41c76	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x24f45195	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x24ff257d	pinconf_generic_dump_config
++EXPORT_SYMBOL_GPL vmlinux 0x251835ce	nvdimm_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x2522ade9	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x252c09be	injectm
++EXPORT_SYMBOL_GPL vmlinux 0x25379e73	clk_set_min_rate
++EXPORT_SYMBOL_GPL vmlinux 0x2543c3a6	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x2545c170	unregister_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x25468846	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x25544f69	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x25703d32	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x25775571	acpi_subsys_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x257aa0c5	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x25800473	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x25a7150c	acpi_subsys_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x25b278cf	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0x25b6320c	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0x25bd595e	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0x25f02c87	xen_p2m_addr
++EXPORT_SYMBOL_GPL vmlinux 0x26085a7e	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x264ae4c6	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x26656e6a	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x26965721	slow_virt_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x26b181a5	acpi_get_pci_dev
++EXPORT_SYMBOL_GPL vmlinux 0x26b3c701	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26d03756	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x26d12ec3	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0x26e1051e	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0x26e35828	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x26e5cdff	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x2704d7d2	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x271574e9	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0x2742a7dc	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x274b308a	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x274cf5e1	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x27545a08	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x276567a5	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x277e5999	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x2787db00	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x278b6c3c	nvdimm_bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x27904ca9	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0x279cb985	apei_exec_pre_map_gars
++EXPORT_SYMBOL_GPL vmlinux 0x27a99cea	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27c97f29	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0x27d8fa04	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x28084a7d	reserve_iova
++EXPORT_SYMBOL_GPL vmlinux 0x28280102	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x28341d65	xenbus_probe_devices
++EXPORT_SYMBOL_GPL vmlinux 0x2839cf98	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0x28430ce5	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0x284aff39	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0x2853fe3f	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0x285cb7dd	pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0x285d1bde	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x287161cd	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x28922ed3	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x28a0a0cf	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x28b936f3	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0x28ccfd73	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x28ce407b	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0x28e64c64	xen_has_pv_and_legacy_disk_devices
++EXPORT_SYMBOL_GPL vmlinux 0x28fc1315	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x28fd1944	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x2901eb43	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0x292a5720	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x293f073e	vrtc_cmos_write
++EXPORT_SYMBOL_GPL vmlinux 0x295eed45	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x299ca0af	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x29d65e5b	acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x29d7fa1a	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x29e6c299	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x29e7eb04	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x29fc2f31	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x2a0a7152	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x2a123106	set_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x2a34e11c	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x2a4090da	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0x2a49fec1	__clk_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x2a61cef4	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a7c08c4	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0x2acdc2ce	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x2af63321	acpi_dev_resource_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x2b179a0b	rio_unlock_device
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b2f0906	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x2b4b97ba	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x2b4f1b50	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x2b58d0bd	xen_register_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x2b5f9014	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x2b67f096	speedstep_get_frequency
++EXPORT_SYMBOL_GPL vmlinux 0x2b952517	clk_has_parent
++EXPORT_SYMBOL_GPL vmlinux 0x2b96316a	efivar_variable_is_removable
++EXPORT_SYMBOL_GPL vmlinux 0x2bb3c704	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0x2bdbd7fe	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa39ee	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa985e	nd_cmd_dimm_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2c1d4c39	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c2d03b0	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c4cf1ca	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0x2c52f709	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0x2c5c7810	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0x2c630bd1	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0x2c6a0410	xen_set_domain_pte
++EXPORT_SYMBOL_GPL vmlinux 0x2c6cb8ae	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0x2c78bb6a	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x2c7d9c64	xen_store_interface
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c8edb58	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x2c9f54d7	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0x2cd14b13	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2d000d93	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x2d018fcd	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x2d1a6ef2	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d248726	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0x2d2fe3de	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0x2d3e6bea	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0x2d3eeda3	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d488ff9	acpi_gpiochip_free_interrupts
++EXPORT_SYMBOL_GPL vmlinux 0x2d4bae3d	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d6be4fc	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0x2d6c5e36	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0x2d9f2ce3	sched_clock_idle_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x2da469f9	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x2ddea1c0	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x2de681b6	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x2e0b9823	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2eadfe45	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x2eb9d6ae	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ebf0328	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x2ec18f52	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0x2ec53d99	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2ef0b342	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x2f0ae360	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f3aad81	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f487cbe	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0x2f5d9b25	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x2f5df57f	xen_find_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x2f64415f	unregister_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2f656128	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f90da7e	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0x2f936209	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0x2fd71fd9	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x2fe6c7a6	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x300cfdcc	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0x3012968a	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x3051fe2a	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x30635782	cpu_has_xfeatures
++EXPORT_SYMBOL_GPL vmlinux 0x309028a0	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x30a4f4ca	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0x30c424fc	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30efd325	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0x310559e4	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x310d6dad	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x31128b8e	hv_remove_kexec_handler
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x314a9cba	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0x314f75d9	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0x318ba497	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0x31b1e1cf	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c4a0b2	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31e44b16	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x3219a99f	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0x3222a704	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x3229ad34	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x3238c600	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x32557712	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x325e677c	gnttab_grant_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x3263d968	gnttab_map_refs
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x32924a4d	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x329dbffc	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x32bc0fcf	preempt_notifier_dec
++EXPORT_SYMBOL_GPL vmlinux 0x32bd75fc	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32e3b076	mxcsr_feature_mask
++EXPORT_SYMBOL_GPL vmlinux 0x331e7806	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x33269aa0	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0x332cf3b7	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x332ddae8	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0x333228ec	intel_msic_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x3340f92c	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0x3345a22c	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x3362b03c	xen_p2m_size
++EXPORT_SYMBOL_GPL vmlinux 0x33655159	xen_pcpu_hotplug_sync
++EXPORT_SYMBOL_GPL vmlinux 0x336d4b88	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0x3387c721	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0x33881dd0	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x33b96e5d	apei_exec_write_register
++EXPORT_SYMBOL_GPL vmlinux 0x33ce200d	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x33e0eaa6	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x33e3c4ba	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0x3413b3a3	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0x3416a7b7	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x34331d5e	nd_fletcher64
++EXPORT_SYMBOL_GPL vmlinux 0x344e56af	rio_get_asm
++EXPORT_SYMBOL_GPL vmlinux 0x346bd3df	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x347682ce	snmp_fold_field64
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x349925a1	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34ac50a4	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x34c03456	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0x34db7102	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x34dfa0ce	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x34effa4e	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x34ff3654	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x3506f5dc	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x35071656	__rio_local_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x351e12b1	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0x352650ee	gnttab_batch_map
++EXPORT_SYMBOL_GPL vmlinux 0x353c6f82	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0x35428fb8	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0x3549b01c	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0x35582861	acpi_subsys_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x35667b22	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x3581f995	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x35827816	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x35839455	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0x358e2a60	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0x358e8a52	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x35910f72	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x35b14c26	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x35b3f983	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0x35dcd1f7	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x35ea34a0	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x36588f05	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0x365936ab	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x367aa0ff	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36b117f4	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0x36b5497e	intel_iommu_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x36ba2551	intel_scu_devices_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x36baaedc	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0x36bda7b0	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x36d54c12	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x36de2236	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x36e60520	pci_get_hp_params
++EXPORT_SYMBOL_GPL vmlinux 0x37011fa9	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0x3707a221	xenbus_switch_state
++EXPORT_SYMBOL_GPL vmlinux 0x3764af2a	rio_mport_class
++EXPORT_SYMBOL_GPL vmlinux 0x37951d7a	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x37998947	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0x37a2e98b	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0x37d0f7df	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x37d2612b	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x381ed945	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x38292234	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x3833a9ec	dax_do_io
++EXPORT_SYMBOL_GPL vmlinux 0x38417804	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0x385e2aae	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x38722f80	kernel_fpu_end
++EXPORT_SYMBOL_GPL vmlinux 0x387ad46e	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x38973e35	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0x38a396b4	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x38a5176e	acpi_dev_gpio_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0x38a97752	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x38a9c2c7	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x38afe3fa	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0x38e5bc5a	clk_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x38fd37f7	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x39016642	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x39056d1b	nvdimm_bus_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x39298420	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x392d252f	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x39479a34	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x394c1b7d	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x395b7894	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x3971a8ae	xenbus_unmap_ring
++EXPORT_SYMBOL_GPL vmlinux 0x3980cb7e	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0x398635dc	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x398786cd	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0x398937c9	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x39b11ff9	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39ceed6c	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x39d38c57	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x39d5a41e	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0x39e4e457	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x39f26eae	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x3a0ee31f	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x3a15ef89	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a3db234	divider_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a641822	acpi_dma_request_slave_chan_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x3a6657c1	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x3a668cc8	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x3a6d886f	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3a7d80f9	xen_max_p2m_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3aa1d825	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x3aa7936a	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0x3acb26a1	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3ad833d7	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x3aea1f06	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x3af90150	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x3afd45b6	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3b04c2e3	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3b08ac59	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0x3b469ab7	__rio_local_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x3b547bc9	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x3b70a4c3	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0x3b7145bb	apei_exec_read_register_value
++EXPORT_SYMBOL_GPL vmlinux 0x3b82f64d	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x3b9b54db	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x3bbce6f9	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3bd4d649	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x3bde3415	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x3be94826	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x3becfdc7	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0x3c070743	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0x3c28ec43	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x3c425a52	efivar_entry_set
++EXPORT_SYMBOL_GPL vmlinux 0x3c5a6151	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0x3c5c08b6	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3c73d131	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3c93ea25	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x3cb95922	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3d0356b1	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x3d296abb	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d4cef22	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x3d4d7d58	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x3d5a7782	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x3d7ea99a	gnttab_grant_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x3d82215b	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x3d96c263	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x3da110d9	xenbus_map_ring_valloc
++EXPORT_SYMBOL_GPL vmlinux 0x3da2dcb6	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x3daccfd7	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3dd4d3a7	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3dead550	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3e127343	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x3e2496a0	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x3e2d6df3	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3e4138b6	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x3e548a76	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0x3e54b244	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3e5bdd04	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e639f99	efivar_entry_add
++EXPORT_SYMBOL_GPL vmlinux 0x3e69c7c5	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e70a53b	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x3e757637	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0x3e8b6f08	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x3e9cd267	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3ea5196d	apei_osc_setup
++EXPORT_SYMBOL_GPL vmlinux 0x3eb517f1	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0x3ec373d4	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0x3ef32c5b	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x3ef8544d	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f1bd29d	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0x3f1c7587	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x3f229c4c	oops_begin
++EXPORT_SYMBOL_GPL vmlinux 0x3f34767b	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x3f481993	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0x3f5b9efa	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x3f68b90b	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0x3f84d4c9	gnttab_release_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x3f9a9e03	nvdimm_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x3fa5af9c	nd_cmd_bus_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3fcc2a49	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0x3fdbb8e5	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0x3fe3a17a	nd_blk_region_set_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x3ff73608	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x400a024b	acpi_scan_lock_release
++EXPORT_SYMBOL_GPL vmlinux 0x4010b80f	pmc_atom_read
++EXPORT_SYMBOL_GPL vmlinux 0x40169c74	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x401e84c8	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x4021fedc	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x402bdc3b	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x405ef31a	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x40616325	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x408212ba	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0x40a00546	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0x40a7dc4f	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40e3d4a4	xen_swiotlb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x411ff21b	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0x413a72ba	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x413ecdd8	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x414ca3d8	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0x4156d543	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x416f2c7b	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0x417c15c8	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x418710e7	mce_inject_log
++EXPORT_SYMBOL_GPL vmlinux 0x41a3d53f	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x41adbe55	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x41afeedc	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x41d38fdc	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x41d4992b	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0x41e44367	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x41f4e7a6	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x41f8416d	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x4205ad24	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x420ac016	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x4212de6e	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x4213a51a	efivar_entry_set_safe
++EXPORT_SYMBOL_GPL vmlinux 0x4219677b	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x4226fa0a	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0x42387255	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0x423da50f	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x423f5e49	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x42635d55	pm_suspend_global_flags
++EXPORT_SYMBOL_GPL vmlinux 0x42652844	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x426b88ac	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42c22fb1	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x42c989ff	iomap_atomic_prot_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x42dc3800	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x42e33a9a	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x42ede965	sis_info133_for_sata
++EXPORT_SYMBOL_GPL vmlinux 0x42fe53d3	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x432007a2	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0x432c3563	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x43579599	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0x43619e1a	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x43636ff3	nd_cmd_in_size
++EXPORT_SYMBOL_GPL vmlinux 0x4377b218	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x437c28b9	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0x438d8df2	iova_cache_get
++EXPORT_SYMBOL_GPL vmlinux 0x4395953e	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43c1c0ab	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x43cd65e1	device_create
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43d0879c	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0x43ef8351	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x43f81957	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x4413e012	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0x4417c965	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0x441fa356	irq_ts_save
++EXPORT_SYMBOL_GPL vmlinux 0x442ab6db	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x448b2a1a	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x44b0cc3e	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44e1e9aa	balloon_stats
++EXPORT_SYMBOL_GPL vmlinux 0x450e0c2a	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x4512b086	intel_scu_devices_create
++EXPORT_SYMBOL_GPL vmlinux 0x4541fe0d	mtrr_state
++EXPORT_SYMBOL_GPL vmlinux 0x4542fc36	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0x454f1cb4	efi_query_variable_store
++EXPORT_SYMBOL_GPL vmlinux 0x4554a842	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x45603b8e	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x459177c0	pinctrl_force_default
++EXPORT_SYMBOL_GPL vmlinux 0x459d22ef	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x45b7d6a0	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45d14bdf	hypercall_page
++EXPORT_SYMBOL_GPL vmlinux 0x45e3a852	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x4606151e	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x4606e3bf	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x460f31aa	rodata_test_data
++EXPORT_SYMBOL_GPL vmlinux 0x4617ad98	acpi_os_map_iomem
++EXPORT_SYMBOL_GPL vmlinux 0x461d9a75	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x46357f89	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x46647c87	acpi_bus_trim
++EXPORT_SYMBOL_GPL vmlinux 0x4678157d	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x4680ea9d	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0x46875a63	apic
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x469afe56	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0x46f60798	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0x46f990db	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0x4707a95c	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x471991fc	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x472d3558	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0x47377d5c	efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0x47403cd8	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x476380e7	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47add933	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x47d0eea2	acpi_lpat_temp_to_raw
++EXPORT_SYMBOL_GPL vmlinux 0x47de0dc7	clk_unregister_mux
++EXPORT_SYMBOL_GPL vmlinux 0x48199268	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x481fe30e	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x481fecb2	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x482426bb	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x4828e77b	acpi_scan_lock_acquire
++EXPORT_SYMBOL_GPL vmlinux 0x4843d066	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x485a7e55	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0x4862bd8c	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x48682db9	perf_guest_get_msrs
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x48a24968	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x48e8f3c1	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0x48eaefbb	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0x490a8df6	x86_platform
++EXPORT_SYMBOL_GPL vmlinux 0x493891db	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x494659c0	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x4967ccf8	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x497ca247	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x4982a57f	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x4986c67f	pinctrl_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x498fb701	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x49a73031	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0x49a7ac98	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0x49baa745	acpi_dev_get_resources
++EXPORT_SYMBOL_GPL vmlinux 0x49c4a84d	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x49c72176	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x49d120d2	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x49d18daf	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0x49de88ff	xen_swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x49e62842	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4a061e5d	clkdev_create
++EXPORT_SYMBOL_GPL vmlinux 0x4a2ed303	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4a3c3cf9	microcode_sanity_check
++EXPORT_SYMBOL_GPL vmlinux 0x4a420d09	acpi_bus_detach_private_data
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a4cd226	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4ab821d3	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x4abc1390	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4ad3c04d	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4afb573b	vrtc_cmos_read
++EXPORT_SYMBOL_GPL vmlinux 0x4b0830b5	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x4b1c5558	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0x4b73a89c	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0x4b756a60	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0x4b832477	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4b9b5087	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0x4bc71d89	rio_register_scan
++EXPORT_SYMBOL_GPL vmlinux 0x4bddc39e	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x4be15281	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x4bedcb55	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x4bee2b65	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0x4bffb3f5	pinctrl_register
++EXPORT_SYMBOL_GPL vmlinux 0x4c0a6c00	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0x4c1070ce	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0x4c27954f	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0x4c2a472b	__static_cpu_has_safe
++EXPORT_SYMBOL_GPL vmlinux 0x4c3e84da	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0x4c43337b	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x4c58ec18	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c63a9a4	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4c7b30d5	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0x4c7d0da2	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x4c8054c0	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0x4cb8e7a2	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x4cc4a8c7	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x4ce0dc63	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x4ce8f5a2	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d0aa139	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0x4d34c485	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x4d47ba41	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0x4d4c09e1	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0x4d4eeef0	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x4d5def9d	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x4d5fd074	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0x4d6434a4	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x4d6ce7ed	xenbus_read_otherend_details
++EXPORT_SYMBOL_GPL vmlinux 0x4d97fc9d	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x4dab0b8a	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4dc8f15e	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0x4dd4deb5	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0x4dd56e36	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4de7fe81	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4e047c70	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e12f266	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e2c2dd2	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x4e2d070a	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4e327410	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x4e3b237d	xenbus_alloc_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x4e57723d	apei_read
++EXPORT_SYMBOL_GPL vmlinux 0x4e691bc5	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x4e73f10c	__online_page_increment_counters
++EXPORT_SYMBOL_GPL vmlinux 0x4e74e625	gnttab_batch_copy
++EXPORT_SYMBOL_GPL vmlinux 0x4e8d7a7a	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0x4e92fc5d	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0x4e97a832	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0x4ec9cdbf	pinctrl_force_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x4ed5185b	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4ee4e67a	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0x4eed5a73	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f1c2b5b	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4f27164d	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f433f16	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4f4bf92c	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x4f518ecf	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0x4f52c9cc	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0x4f5edc96	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4f89f59d	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x4f990bcb	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0x4f9f0827	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x4faebcbb	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0x4fb5158a	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0x4fc48a1a	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0x4fd26a37	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x4fd32bb1	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4ffa9c21	register_mce_write_callback
++EXPORT_SYMBOL_GPL vmlinux 0x50093df1	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x501beff9	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x501f860c	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0x50243e2f	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x5024523b	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0x5026585c	xen_irq_from_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x50433d85	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x506e3c6c	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x50769915	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x507de8c6	add_memory
++EXPORT_SYMBOL_GPL vmlinux 0x507ff56a	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0x5080c352	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x5091fab0	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x509c6004	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x50a3293f	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0x50a8c561	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x50c89f23	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x50d47af9	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50e75b7f	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x511d693c	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x514e9875	divider_get_val
++EXPORT_SYMBOL_GPL vmlinux 0x51719489	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5187ac4b	xen_store_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x518c2fc6	hpet_rtc_dropped_irq
++EXPORT_SYMBOL_GPL vmlinux 0x51963dc6	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0x51966b51	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0x51c55bef	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x51d02ed7	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0x51d7107e	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0x520f5b5e	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x521c6d1d	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x5239e93e	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x523c0153	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0x52599567	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0x526280c7	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0x526794ff	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x5272d8bc	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0x528748ca	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x5289dcef	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x52924f20	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x52a41251	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x52a535ea	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x52d27082	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x52d3f877	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x52d8c375	clk_register_divider
++EXPORT_SYMBOL_GPL vmlinux 0x52f102db	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0x5320ec67	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x53629d67	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x536a225c	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x53989e4b	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x53995884	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x539f157b	pci_xen_swiotlb_init_late
++EXPORT_SYMBOL_GPL vmlinux 0x53bf8d82	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x53c9c6eb	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0x53e247b9	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x54161ff9	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x54227944	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0x5434619f	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0x54373c79	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x544705b6	component_add
++EXPORT_SYMBOL_GPL vmlinux 0x5453681c	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x547f5cda	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x549ecb82	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x54a2f5f3	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0x54af5603	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0x54c8a53a	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x54cab2db	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x54d468f1	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x54dd1d8d	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x54e79f34	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0x550ce709	pat_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x554e9595	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x55526907	xen_features
++EXPORT_SYMBOL_GPL vmlinux 0x556e4390	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x556f6bcf	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0x55778c23	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x55a2fa67	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0x55a43988	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x55a6c09c	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x55aeee71	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0x55df97ba	rio_mport_send_doorbell
++EXPORT_SYMBOL_GPL vmlinux 0x55eb11e0	is_dock_device
++EXPORT_SYMBOL_GPL vmlinux 0x55ed9198	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0x55edd53d	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x560d4284	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0x5613ba8f	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x56398615	mark_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x56407ffe	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x5654f836	erst_get_record_id_next
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x56947347	dmi_walk
++EXPORT_SYMBOL_GPL vmlinux 0x56b63670	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56e2f4d2	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56f9c3ec	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x570872e6	gpiochip_remove_pin_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x57282f57	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x572e2909	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x5745835d	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0x575796ce	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0x576b9c8a	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x576ddb54	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x5779d445	xenbus_exists
++EXPORT_SYMBOL_GPL vmlinux 0x57881ace	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57c2f033	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x57ebff4e	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0x57f06412	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x57f8062c	acpi_dev_resource_io
++EXPORT_SYMBOL_GPL vmlinux 0x58082ce6	dax_zero_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x58139305	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0x5821b670	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x5841bcf3	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5843bde5	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x585704ab	aer_recover_queue
++EXPORT_SYMBOL_GPL vmlinux 0x586df08e	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x587bd46f	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0x58828b6a	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0x589aa47a	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0x589ae76a	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58b722be	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x58ca3291	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x58fe9409	rio_inb_pwrite_handler
++EXPORT_SYMBOL_GPL vmlinux 0x59044f93	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0x591bc4a9	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x59392c2b	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0x594cde67	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0x59688cf7	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x5979ff96	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0x598b6434	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x599436e8	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x59acca9b	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x59b40407	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x5a0b2fd5	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0x5a0e11d4	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x5a2b1b67	gnttab_free_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5a4a712d	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0x5a65c37b	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x5a68d94d	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0x5a699c6a	fpu__save
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a82b9af	acpi_unbind_one
++EXPORT_SYMBOL_GPL vmlinux 0x5a9668d4	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x5aad3e37	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x5ab223cf	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x5abcb79e	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0x5acc54c5	nd_blk_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x5acdee06	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0x5ade15ff	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0x5af03a28	gnttab_claim_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5b0ed26c	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0x5b1899f8	free_iova
++EXPORT_SYMBOL_GPL vmlinux 0x5b2f5301	xenbus_dev_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x5b6c566b	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x5b81f73a	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0x5b9b2979	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0x5babf842	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x5bb5cc93	rio_release_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x5bc078fa	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0x5bcd6ae6	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x5bce8ca1	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0e646	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5bef7055	xenbus_dev_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x5bf9ae77	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x5c32586b	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x5c4ac66b	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1392	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c63ba90	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x5c66e90c	efivar_run_worker
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5ceb30b9	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x5cf246f0	dummy_con
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d366dec	gnttab_cancel_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0x5d5ca512	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x5d8eb727	__clk_get_hw
++EXPORT_SYMBOL_GPL vmlinux 0x5d9425cb	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5dab0db1	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5dacb09b	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0x5db54979	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0x5db70648	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0x5dbcfa4f	boot_cpu_physical_apicid
++EXPORT_SYMBOL_GPL vmlinux 0x5dbdf027	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x5dd8f480	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0x5de0c33a	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x5df1c97f	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x5df3b1af	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x5dff6fda	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x5e0644e5	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x5e3740c6	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x5e4374ec	gnttab_unmap_refs
++EXPORT_SYMBOL_GPL vmlinux 0x5e46c605	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x5e515be6	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e77ba35	do_machine_check
++EXPORT_SYMBOL_GPL vmlinux 0x5e817007	x86_hyper_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x5e94270e	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x5e984929	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0x5ee92a13	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5eefd830	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0x5f0b5826	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0x5f11c864	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0x5f1742cd	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0x5f2da8c4	check_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x5f34ad18	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x5f9323d1	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x5fa2234d	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0x5fc27be9	acpi_dev_irq_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5fdfa2c1	amd_pmu_enable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x5ffa47d2	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x5ffa8f96	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x5ffc7118	component_del
++EXPORT_SYMBOL_GPL vmlinux 0x6007ac3a	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x60091316	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x602e5412	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x6035b78e	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x605ad133	efivars_register
++EXPORT_SYMBOL_GPL vmlinux 0x60930d37	save_mc_for_early
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60a88b7d	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0x60c41d2c	xen_swiotlb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x60cd73ed	pv_apic_ops
++EXPORT_SYMBOL_GPL vmlinux 0x60cef609	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x60d44649	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0x60e0a894	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x60e73ecc	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x60fbb41e	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0x6144ab35	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x615b4c40	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0x61766faf	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0x6178abf2	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0x618e113c	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0x6193d5fe	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x61b0f0c9	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x61bc3aa8	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0x61cb78d4	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x61cdc96f	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x61cde409	acpi_dev_resource_memory
++EXPORT_SYMBOL_GPL vmlinux 0x61ffe481	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x6211487d	rio_mport_get_efb
++EXPORT_SYMBOL_GPL vmlinux 0x6211ee68	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0x621421c2	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x6222f5fa	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x623803c8	hest_disable
++EXPORT_SYMBOL_GPL vmlinux 0x624c1ef2	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x625ec74a	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x62603fc2	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x626a7a48	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x6283daa0	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x62955c19	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x62982824	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x62a1c981	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x62a7f33a	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x62c11598	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x62e8b9f9	efivar_entry_set_get_size
++EXPORT_SYMBOL_GPL vmlinux 0x63150e06	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x632b3477	acpi_subsys_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x6341d03b	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x635ec980	apei_exec_post_unmap_gars
++EXPORT_SYMBOL_GPL vmlinux 0x63789678	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x63a17c34	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0x63a2505c	clk_register_gpio_gate
++EXPORT_SYMBOL_GPL vmlinux 0x63bdbe5d	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0x63d214d7	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0x63de782a	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x63e17b86	divider_recalc_rate
++EXPORT_SYMBOL_GPL vmlinux 0x63e61ecf	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0x63ea80b3	cper_mem_err_type_str
++EXPORT_SYMBOL_GPL vmlinux 0x63f6971d	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x6420a012	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x64256424	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0x642c9caa	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0x64318593	acpi_dev_filter_resource_type
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x64737e49	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x648ea313	xenbus_probe_node
++EXPORT_SYMBOL_GPL vmlinux 0x64a70cfc	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x64b7069e	apei_mce_report_mem_error
++EXPORT_SYMBOL_GPL vmlinux 0x64d5839b	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x64da0dbb	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x64e24a5e	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x64fb0fdc	acpi_initialize_hp_context
++EXPORT_SYMBOL_GPL vmlinux 0x6502c4ba	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0x65047533	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0x6527a231	dbgp_external_startup
++EXPORT_SYMBOL_GPL vmlinux 0x6536953b	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0x653cb02d	intel_msic_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x6560127a	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0x65690cde	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0x658c8186	amd_get_nb_id
++EXPORT_SYMBOL_GPL vmlinux 0x658e5cff	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x65abd1f5	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x6612e3e2	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x6623a53d	rio_mport_get_physefb
++EXPORT_SYMBOL_GPL vmlinux 0x66281664	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x66494024	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x665ecab0	pv_time_ops
++EXPORT_SYMBOL_GPL vmlinux 0x66757659	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x6682b6a5	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x668b3811	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0x668caa7e	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x6691e658	acpi_ec_remove_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0x66a3dbe7	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0x66a4f0ae	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66cb4705	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0x66d4393e	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0x66d6d3a9	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66ee62f2	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0x6705b4fa	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0x6739a503	balloon_set_new_target
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x67ba3cea	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0x67d60fb5	pinctrl_utils_add_map_configs
++EXPORT_SYMBOL_GPL vmlinux 0x67d9aca4	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0x6827e476	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x682c424a	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0x682e6bb0	hugetlb_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x6834ac43	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x683c85ad	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0x6845b36d	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x684a96b4	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0x684c0948	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0x685a3097	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0x68956406	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x689690d2	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x68ae1489	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x68c162d8	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0x68c9c629	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0x68d61b19	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x68eb35a2	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x692e17fa	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x69332c75	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x69395e0b	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x693e7039	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x6945725e	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0x694ee479	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6956b1be	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x695f6259	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x6984efa7	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x698c58b7	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0x698f2fdf	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x69c1a56f	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0x6a09a623	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0x6a0b308a	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a263e41	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x6a2a6a19	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a65f151	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x6a83e46f	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a893921	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0x6aa27a5c	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0x6ab1b8bb	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x6acacd90	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6acad21f	acpi_get_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0x6ad50e2e	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x6addc89b	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0x6aecc830	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x6afe1450	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0x6b04f135	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x6b0dc565	xen_set_irq_priority
++EXPORT_SYMBOL_GPL vmlinux 0x6b0eda4e	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x6b1e7c4b	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x6b288727	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b6b3123	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x6b7049ce	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0x6b74c0dd	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0x6b7a681d	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6bb2d1df	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x6bbeb7c9	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x6bd373ed	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x6be5a8ef	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0x6bf1b90d	dmi_memdev_name
++EXPORT_SYMBOL_GPL vmlinux 0x6bf61bd7	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0x6bf64920	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0x6bfbf670	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0x6c0786c9	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c109f19	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x6c1251fd	apei_exec_read_register
++EXPORT_SYMBOL_GPL vmlinux 0x6c209eab	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x6c267d54	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x6c389761	acpi_bus_get_private_data
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c60d14e	rio_release_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x6c6538df	init_iova_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6c655913	register_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6c6c8674	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0x6c7e0252	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6c9c3bc6	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cbe0bcb	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0x6cc89e0e	nd_cmd_out_size
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6cf56ab3	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0x6d05d330	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d33661d	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0x6d45fd2c	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0x6d47b3c2	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0x6da41eaa	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x6dac0acb	hugetlb_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x6dbeb9d1	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x6dcb0daa	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e179713	acpi_dev_add_driver_gpios
++EXPORT_SYMBOL_GPL vmlinux 0x6e49a1b0	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0x6e51afc8	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x6e58ddf0	gnttab_end_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x6e64b90f	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0x6e782c23	iomap_create_wc
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e85b00b	local_touch_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6e94c3a4	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x6ea67622	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6eb01618	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x6ee10602	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0x6eeb5918	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x6f0c025d	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x6f1a6d82	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f3422cf	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x6f3d0cd1	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x6f402ba6	acpi_dev_resource_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x6f5c1292	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6f8aa1c8	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x6f993a3f	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x6fa9ec87	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x6fce743c	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0x6fcef549	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0x6fd4a2cc	__clk_mux_determine_rate_closest
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6ff1b7c0	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x6ff94c53	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x70201233	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x702e0174	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x704c47e8	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x7052480f	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x7054517f	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0x70705c1e	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x707f40f3	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x708bac30	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x70916166	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x70a0c3e4	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70cce8d0	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x71225627	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7133648f	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x713d4b83	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x7150137a	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x7157e281	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x716cea69	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0x716e73b3	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x716f8786	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x717c0a03	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0x719d0470	acpi_register_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x719e17ff	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x71cb5dcc	dax_truncate_page
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71fc1000	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x7206b57f	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x72170b16	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x7223cc03	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0x722e2bf6	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x72515d5a	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x72ca737e	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x72cf714d	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x72df5f0c	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x72f706be	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x73013896	xenbus_printf
++EXPORT_SYMBOL_GPL vmlinux 0x730d2e28	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x731dba7a	xen_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0x73481239	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0x734ed0ee	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x734f0276	__tracepoint_add_device_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x7370e7a9	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x737de723	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x738fd248	intel_msic_reg_update
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73b98231	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73d3efbd	pinctrl_get_group_pins
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x74041ad6	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0x740b9f73	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x7436a2d9	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x74407785	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x74457e56	apei_resources_fini
++EXPORT_SYMBOL_GPL vmlinux 0x744b5391	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0x744e3a9c	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0x7452adff	user_return_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7468b74e	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0x7476946a	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0x747e6e43	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x748fb1f4	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0x74aaaf86	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74b9f79b	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74c08941	kvm_async_pf_task_wake
++EXPORT_SYMBOL_GPL vmlinux 0x74c1c0e9	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x74d007c2	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x74deb10c	used_vectors
++EXPORT_SYMBOL_GPL vmlinux 0x74ec9a62	nvdimm_name
++EXPORT_SYMBOL_GPL vmlinux 0x74edf689	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x74fab285	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x74ff8b77	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x7521afb6	leave_mm
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x75314e14	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x753a7087	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x7562de64	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0x75797266	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x757b0cdf	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x75993be1	intel_svm_unbind_mm
++EXPORT_SYMBOL_GPL vmlinux 0x759998b3	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0x75c2b9f1	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75e0eb99	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x75fbdb12	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x7609c8c8	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x76597668	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0x7663cee4	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x7677d668	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x76c3b234	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x76cdefe3	rio_request_mport_dma
++EXPORT_SYMBOL_GPL vmlinux 0x76d9b876	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0x76e791ca	acpiphp_unregister_attention
++EXPORT_SYMBOL_GPL vmlinux 0x76f7ef1c	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0x770cf981	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x770fb260	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0x7712771a	unbind_from_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x772fe36c	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0x7739ed4e	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7747537d	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0x77502cf6	xenbus_dev_remove
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x7757b51a	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x775a6ef5	kvm_read_and_reset_pf_reason
++EXPORT_SYMBOL_GPL vmlinux 0x775f82a3	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x77861d63	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0x778b675a	pmc_atom_write
++EXPORT_SYMBOL_GPL vmlinux 0x7790adc0	aout_dump_debugregs
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x77c02292	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x77ccd66b	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x77d58d72	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x77f6a948	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x78076381	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x78151326	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x7815ff49	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0x78257052	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x7828751d	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x782adb74	hpet_rtc_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x78575bee	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x785cf1c3	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x7864ae9a	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x786d084e	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x7872466c	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x7874b5ec	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7884d34f	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x788524fb	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78b98faf	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0x78c0dfed	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x78da85c9	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0x78e84890	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x78eaaab0	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x790eea23	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x79148337	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x79171c44	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x793b1b9c	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x796bcefe	pinctrl_dev_get_devname
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x796f6a41	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x7991fd8d	crash_vmclear_loaded_vmcss
++EXPORT_SYMBOL_GPL vmlinux 0x7998bd4d	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x79a3c602	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x79a6ec76	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x79a71c48	kernel_stack_pointer
++EXPORT_SYMBOL_GPL vmlinux 0x79dc2b5b	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x79e69460	intel_iommu_gfx_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x79ed45a9	pci_msi_set_desc
++EXPORT_SYMBOL_GPL vmlinux 0x79effe3b	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0x79f43cab	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0x7a093833	set_memory_array_wt
++EXPORT_SYMBOL_GPL vmlinux 0x7a135468	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0x7a17cbe3	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a319404	clk_register_fixed_rate
++EXPORT_SYMBOL_GPL vmlinux 0x7a472c57	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0x7a4996b7	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x7a4ab664	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0x7a4dc3d5	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x7a52790e	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0x7a63ff7c	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x7a7ed88d	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x7a7f30d6	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7a9c7a1d	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7aad75c2	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0x7ab1f98a	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x7ab3ca18	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x7ab8b883	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x7abb0cc4	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0x7ac0861b	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x7ac8e5b0	acpi_gsi_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7ad46cce	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0x7aefed21	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1a8987	default_iommu_map_sg
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b202401	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x7b302216	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x7b3ab781	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x7b3f36e3	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x7b45dfe2	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x7b6ce39b	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x7b7d92ae	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x7b853458	put_device
++EXPORT_SYMBOL_GPL vmlinux 0x7b90d1a9	bind_virq_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7bb286e9	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x7bec9ebe	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x7bf294d6	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x7bff4171	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x7c11f84b	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x7c138641	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7c27b65f	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0x7c2c0e69	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0x7c532eac	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x7c9a7371	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x7cc6d018	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0x7cd4e522	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7cdf7695	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7d00c65b	nd_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x7d240ffa	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x7d2f929d	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x7d38af40	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x7d3939ca	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x7d43c81d	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d5bbdba	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x7d826874	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x7d9785ca	devm_pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0x7d9c2402	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x7da4e720	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7de65a03	acpi_lpat_free_conversion_table
++EXPORT_SYMBOL_GPL vmlinux 0x7e28a395	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x7e368251	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0x7e3923bc	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x7e3a9a69	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x7e5377d3	rio_request_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x7e572d98	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e6f8bff	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0x7e713e07	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7ed0b32b	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0x7ee3716a	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f263b51	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x7f338d60	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0x7f377408	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x7f3ec087	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7f9a9ade	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0x7fb17405	set_pages_array_wt
++EXPORT_SYMBOL_GPL vmlinux 0x7fbc52af	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7fd1d020	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0x7ff4fd9f	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x7ffc453b	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x800ef339	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x801bf6b8	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8025692e	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x80277e7c	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0x804a4d97	pinctrl_pm_select_sleep_state
++EXPORT_SYMBOL_GPL vmlinux 0x804da1df	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x80526c5d	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0x805f7782	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x8062c96b	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x806eeba3	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x808d5367	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x809529fd	alloc_iova
++EXPORT_SYMBOL_GPL vmlinux 0x80955201	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0x80ae9d77	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80ef5c01	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0x80efc1b0	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x80f8589f	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0x81109e3b	rio_mport_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x813d91db	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x815588a6	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x817b9a82	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x819abcae	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x81aacb4f	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x81b9906a	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0x81c8db6b	acpi_match_device
++EXPORT_SYMBOL_GPL vmlinux 0x81cba675	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x81ce4ca3	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x822ad4c7	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0x82398383	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0x82862633	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x828c8376	pinctrl_add_gpio_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x82978442	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x82bd5928	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x82ce18a1	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x82cf4477	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82d79d4d	print_context_stack
++EXPORT_SYMBOL_GPL vmlinux 0x82dbec19	erst_write
++EXPORT_SYMBOL_GPL vmlinux 0x83120aba	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x8349d798	xen_swiotlb_set_dma_mask
++EXPORT_SYMBOL_GPL vmlinux 0x834c4ee0	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x834d41f2	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x836666ce	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x83a1cd2e	__online_page_set_limits
++EXPORT_SYMBOL_GPL vmlinux 0x83ba5796	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0x83ba5fbb	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x83d2cae5	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0x83d8c217	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x83e5a31d	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0x843d70ef	acpi_is_root_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x845289b1	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x8462bdcf	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x847dd9d2	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0x84b1a9a8	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x84b5e44c	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0x84c6f67c	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0x84d53e7d	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x84e69f86	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x84e839a9	acpi_os_unmap_iomem
++EXPORT_SYMBOL_GPL vmlinux 0x84f06176	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x84f6eb6a	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x8506baa8	clk_unregister_gate
++EXPORT_SYMBOL_GPL vmlinux 0x850aa5ff	xenbus_unmap_ring_vfree
++EXPORT_SYMBOL_GPL vmlinux 0x850df8b9	clk_divider_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x851097eb	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x852af33d	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0x8574ca6c	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x858737ec	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x85a94b8a	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x85ac1bca	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x85ad23ee	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x85ae1093	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0x85afc47d	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85cb2c45	xen_has_pv_devices
++EXPORT_SYMBOL_GPL vmlinux 0x85cda435	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x85d7edfd	hpet_set_periodic_freq
++EXPORT_SYMBOL_GPL vmlinux 0x85eaf2cb	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x8615649e	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8652110e	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0x8654be58	hv_remove_vmbus_irq
++EXPORT_SYMBOL_GPL vmlinux 0x86623fd7	notify_remote_via_irq
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x86792771	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0x867a1f61	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x86819bc6	irq_ts_restore
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x868f5e00	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x86931fa6	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x86a51007	gnttab_end_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x86afdcd0	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x86bbdc69	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x86cd7051	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x87043088	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x870e16b7	xen_test_irq_shared
++EXPORT_SYMBOL_GPL vmlinux 0x871dbbdb	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0x872a5741	usb_acpi_set_power_state
++EXPORT_SYMBOL_GPL vmlinux 0x87338d7d	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x8749fade	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0x878df161	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0x879b916d	set_foreign_p2m_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x87a1f430	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x87ab063a	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x87bb184f	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x88136838	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8829314c	rio_request_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x882eed40	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0x8831f8b1	kmap_atomic_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x883c2740	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x8849b297	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x88598a00	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x88905000	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0x8896f966	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0x88a9a411	clk_fractional_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88aef35f	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0x88b02d62	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x88b14fc7	xenbus_watch_pathfmt
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88ba6c49	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x88cf5232	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x88de708f	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x8902641c	xen_xlate_unmap_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x890b0e8d	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x891a5a7f	gnttab_max_grant_frames
++EXPORT_SYMBOL_GPL vmlinux 0x891d1b26	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x8956aeae	apei_exec_ctx_init
++EXPORT_SYMBOL_GPL vmlinux 0x89651fdd	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x8981cdd5	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x89b23532	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0x89b3bf1f	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89bcc035	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0x89d32208	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0x89dffc67	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0x89e31d69	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x89f6bd87	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x8a05ad3e	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8a396584	register_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x8a3ade3e	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x8a559846	gnttab_setup_auto_xlat_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a5f86ce	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x8a60d39e	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0x8a78989f	irq_from_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x8a7cb9c4	platform_thermal_package_rate_control
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8aef463d	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0x8af63140	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0x8af68a9a	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0x8afc7a40	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x8afdbf40	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8b04668e	bind_interdomain_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x8b094aae	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x8b149c36	clk_is_match
++EXPORT_SYMBOL_GPL vmlinux 0x8b39f108	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0x8b74a273	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8b91f7a7	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x8b9c4495	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x8ba3dd1e	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0x8ba51110	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x8ba51be6	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0x8baf62e7	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0x8bc41382	fpu__restore
++EXPORT_SYMBOL_GPL vmlinux 0x8bcf9949	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x8bd37020	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c06a108	xenbus_transaction_start
++EXPORT_SYMBOL_GPL vmlinux 0x8c576ca1	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c88250c	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x8c991153	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x8c9d1661	arch_phys_wc_index
++EXPORT_SYMBOL_GPL vmlinux 0x8cc8cee4	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8cd9f935	setup_APIC_eilvt
++EXPORT_SYMBOL_GPL vmlinux 0x8ce7f3a9	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8d05b6b0	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x8d05fa4c	acpi_pci_check_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0x8d0f76dc	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d58ea2f	isa_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8d796fb3	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x8d9d2fe2	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8daacfcc	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0x8db9a15b	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x8dd2eedd	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0x8dff927d	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x8e11d840	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8e123030	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x8e18ccef	intel_scu_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x8e219df2	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e3e3110	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x8e3fefb4	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x8e994873	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x8e99ab3d	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0x8ea14211	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x8ebf2831	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0x8ee041b8	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x8eecae18	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f1e76ae	nvdimm_blk_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x8f3905bb	__xenbus_register_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x8f3e6f81	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x8f4eadf3	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f6fde0c	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x8f78baab	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8f7a0f89	nvdimm_bus_check_dimm_count
++EXPORT_SYMBOL_GPL vmlinux 0x8f7e7d43	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0x8f805745	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8f9bc256	xen_unmap_domain_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x8f9e200d	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x8fbb41b9	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x8fd643ac	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x8ff650e9	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0x8ffbd14c	irqd_cfg
++EXPORT_SYMBOL_GPL vmlinux 0x9009602a	acpi_bus_get_ejd
++EXPORT_SYMBOL_GPL vmlinux 0x9016d310	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0x9022d5bc	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x903bb65b	acpi_dev_resource_ext_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x9047c11a	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x905fbb49	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x906dfddd	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x9080270e	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0x909b2220	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90b2a19f	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x90bbf3ed	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x90de0452	platform_thermal_package_notify
++EXPORT_SYMBOL_GPL vmlinux 0x90ea5d52	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x910458f8	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x91177691	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0x912439ab	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0x91548a3e	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0x916773ba	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0x916cdf51	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91de4dcd	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x91ef4444	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0x91fec685	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0x9208d2f7	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0x920ba18c	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x920f6150	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x923fa9a8	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x925676fa	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0x9262433b	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x92625b26	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0x9298086f	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0x929c3c7c	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x92b16145	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x92b57248	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x92c5cfa4	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92de65bb	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x92e18acd	rio_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0x92f6e4b6	__ktime_divns
++EXPORT_SYMBOL_GPL vmlinux 0x9311a2b3	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0x9312d80e	evtchn_put
++EXPORT_SYMBOL_GPL vmlinux 0x9317360d	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x932e1a62	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x934288a2	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x935519ce	clk_multiplier_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9364a3b2	xen_swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x9380766a	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x939d37a4	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x93a1ae45	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x93bf2fcd	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x93c8cecb	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x93e85bbf	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0x93f8d9e8	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x93fe335b	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x9403fc32	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x942e8c16	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x94324d6c	acpi_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x9432b036	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x943fc708	xen_setup_shutdown_event
++EXPORT_SYMBOL_GPL vmlinux 0x94467a2f	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0x94552b1f	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x945b0a66	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0x945edcb4	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0x9467000f	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0x9480806f	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x94abb745	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0x94af9368	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0x94b7b8c5	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0x94bcb129	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x94c318be	apei_exec_collect_resources
++EXPORT_SYMBOL_GPL vmlinux 0x94df1718	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x95013d25	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x952edfc3	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x952ee34d	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x95335557	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x9575ae7d	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0x957ba439	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x958a3feb	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x9592aaae	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9594756d	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0x95ba7a5e	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95d7c208	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x95f0e8ad	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x95f5bec8	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x96487784	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x964add15	xenbus_scanf
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x965688b0	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0x96651200	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0x9694dcc9	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x96a1a4c5	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x96ac6143	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0x96b80fa7	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x96e1abc5	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x96f3ad71	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x96f91d52	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0x9715747a	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x971968da	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0x97296e2e	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x973ab8ad	cper_estatus_print
++EXPORT_SYMBOL_GPL vmlinux 0x974307b2	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x977a87f9	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0x979ed407	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x97af31a4	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x97c11a8d	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x97cb9bca	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x97e7e93f	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x980e773e	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0x981567e6	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x984f438e	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x986bd85c	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9888b4f1	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0x989eb047	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x98dd4920	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x98f1076c	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x990dbf91	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x99213030	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x9938813b	acpi_subsys_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x99503efb	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0x99535f1b	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x99694e65	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x9973add9	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x9999a395	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0x999be974	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x999e4a22	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0x99a6663d	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x99a9ff9a	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99ce0592	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x99dc903e	rio_register_mport
++EXPORT_SYMBOL_GPL vmlinux 0x99fa28b5	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0x99fa4c43	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x99fcafc8	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0x9a10da89	__tracepoint_extlog_mem_event
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a57d563	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9a92b43f	rio_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x9a931f7f	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x9a9ebf08	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x9aa5fe9b	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x9ab13028	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x9abea338	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9b1195ff	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9b25030f	xen_swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x9b4da354	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x9b58b84a	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0x9b5c6c62	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9b5d385f	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x9b6dd605	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0x9b720312	acpi_target_system_state
++EXPORT_SYMBOL_GPL vmlinux 0x9b7627b8	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x9b888b01	pinctrl_dev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x9b8d3ec1	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x9b9ca064	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0x9b9f3648	pcibios_scan_specific_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9ba51663	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0x9bad683f	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9bc6f438	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0x9bd72b78	apei_write
++EXPORT_SYMBOL_GPL vmlinux 0x9be233d5	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x9be3a239	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c09dc5c	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x9c10b6d2	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9c12fbde	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x9c1b4234	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x9c1ef578	rio_dma_prep_slave_sg
++EXPORT_SYMBOL_GPL vmlinux 0x9c2e4b66	acpi_unregister_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x9c347c07	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0x9c3ff0d2	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0x9c462261	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0x9c491919	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9c54298d	irq_chip_ack_parent
++EXPORT_SYMBOL_GPL vmlinux 0x9c69ad6c	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x9c87e9a8	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x9ca2a7c0	xenbus_dev_is_online
++EXPORT_SYMBOL_GPL vmlinux 0x9caedd74	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x9cb7bb39	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x9cc0599d	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cda09bb	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0x9cee8102	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0x9d02a00b	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0x9d06688b	register_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x9d2a307f	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0x9d2e45bc	rio_lock_device
++EXPORT_SYMBOL_GPL vmlinux 0x9d3850e1	gnttab_alloc_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x9d4821c2	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x9d62c898	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x9d8331c0	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x9d933cf6	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9dbbaef6	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x9dcfea8e	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0x9dd29f3c	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0x9dd7769b	xenbus_dev_probe
++EXPORT_SYMBOL_GPL vmlinux 0x9de608b6	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x9dfdf722	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0x9e089ee2	clk_register_fractional_divider
++EXPORT_SYMBOL_GPL vmlinux 0x9e25c23e	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e654850	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0x9e68adf9	mmput
++EXPORT_SYMBOL_GPL vmlinux 0x9eb29eda	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0x9eb7483f	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9ebbdfff	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9ebff902	start_thread
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ee37aa2	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x9f26cbc2	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9f47ccda	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x9f681a1d	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x9f69b09c	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0x9fa0ebf7	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x9fab59db	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fceb9c4	xenbus_dev_groups
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9fec166c	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0x9ff4a9aa	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xa00d30a9	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xa0208e02	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xa02e97f0	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0xa0467c40	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xa06c9ffa	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0xa0703264	xen_swiotlb_sync_single_for_device
++EXPORT_SYMBOL_GPL vmlinux 0xa071b020	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0xa073d0ef	rio_unregister_scan
++EXPORT_SYMBOL_GPL vmlinux 0xa0855bfc	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0xa0cb9fe8	acpi_ec_add_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0xa1100e62	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0xa11216be	xen_store_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0xa112bdba	acpi_pci_find_root
++EXPORT_SYMBOL_GPL vmlinux 0xa1183923	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0xa119f612	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xa11b55b2	xen_start_info
++EXPORT_SYMBOL_GPL vmlinux 0xa14a1817	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0xa14b18d0	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0xa156a1f2	erst_get_record_id_end
++EXPORT_SYMBOL_GPL vmlinux 0xa1819c92	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa1a9fbf2	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0xa1d31306	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xa1db3f2c	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0xa1dfc665	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0xa1f5350a	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0xa1f79553	xen_create_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xa1fbaffd	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xa2335c37	pinctrl_utils_add_map_mux
++EXPORT_SYMBOL_GPL vmlinux 0xa2587694	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa27eff8b	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0xa2b9c993	clk_register_fixed_factor
++EXPORT_SYMBOL_GPL vmlinux 0xa2ba051d	rio_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2e5f255	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xa3003eac	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa32947c0	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xa32e6fe4	rio_mport_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xa353fffc	xenbus_rm
++EXPORT_SYMBOL_GPL vmlinux 0xa35b8100	iommu_get_domain_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa366eb10	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa38d3e5c	__xenbus_register_backend
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3a7b38d	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3d60b64	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0xa3e58789	efivar_validate
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa3f449b6	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0xa430280b	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa4353ed3	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xa43e314c	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa44882ba	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0xa44a81c5	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xa452c297	hpet_mask_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa452f2a4	xen_pirq_from_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa466de38	acpi_processor_ffh_cstate_enter
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa48620b2	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xa48a1a6c	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa4ab944a	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0xa4ae4c30	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xa4b058d7	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa4b6f2ed	acpi_device_modalias
++EXPORT_SYMBOL_GPL vmlinux 0xa4d9e374	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xa4e8b09a	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0xa507b83d	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0xa5095fdb	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0xa50b88af	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0xa5109640	efivars_kobject
++EXPORT_SYMBOL_GPL vmlinux 0xa5779cdf	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0xa5ae6061	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa5d8cbc3	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa5e3104f	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5f12796	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa62892c6	efivar_sysfs_list
++EXPORT_SYMBOL_GPL vmlinux 0xa6381a2d	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0xa64c2452	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xa6590d60	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa6620bfe	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0xa66bcb7b	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xa6a690e2	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6d17887	agp_remove_bridge
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa710424c	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0xa7454122	rio_route_clr_table
++EXPORT_SYMBOL_GPL vmlinux 0xa77ce234	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0xa7a7d427	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xa7afa64e	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0xa7b0faad	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xa7df9fc9	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0xa7e1b3a9	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa7e357c9	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0xa7e54b70	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0xa7e5c066	rio_request_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xa7ec957f	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0xa7fae3cb	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xa800f3d3	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa801b359	efivar_entry_iter_begin
++EXPORT_SYMBOL_GPL vmlinux 0xa81bd685	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xa8227568	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa859c2e9	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0xa8621a87	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xa8825c17	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0xa8964752	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0xa8a62d11	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xa8b15210	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8c2eb1a	pinctrl_find_gpio_range_from_pin
++EXPORT_SYMBOL_GPL vmlinux 0xa8d80ab2	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xa911b4e9	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xa9126bff	hpet_set_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa9143342	find_iova
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa952bbf1	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xa973481a	pinctrl_select_state
++EXPORT_SYMBOL_GPL vmlinux 0xa979a04e	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0xa98ffeb6	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xa9aae8ef	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0xa9b20db8	__online_page_free
++EXPORT_SYMBOL_GPL vmlinux 0xa9bf318a	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0xa9c41064	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xaa15f525	gnttab_foreach_grant_in_range
++EXPORT_SYMBOL_GPL vmlinux 0xaa2883ef	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xaa2a72bf	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0xaa5f4acb	find_module
++EXPORT_SYMBOL_GPL vmlinux 0xaa6fa99c	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0xaa8833b2	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xaa8cfbf1	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xaa9d3fd0	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaabc563e	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0xaac4c47a	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0xaacb5efb	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xaacb7c5e	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xaace1e31	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xaae0a711	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0xaafe8ad1	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xab01acbe	gnttab_request_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0xab132bc3	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xab1e0e93	hv_setup_kexec_handler
++EXPORT_SYMBOL_GPL vmlinux 0xab29ad96	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0xab34c55c	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xab3cbe7e	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5aab	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab652e56	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab945a16	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xaba4c807	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xabc035ff	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabe32983	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xabf7ffae	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0xac00c4fe	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0xac886599	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0xac8c1120	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xac9ce195	kvm_async_pf_task_wait
++EXPORT_SYMBOL_GPL vmlinux 0xaca52819	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xacafa8e7	vector_used_by_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xacb2915b	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0xacc49990	acpi_processor_get_performance_info
++EXPORT_SYMBOL_GPL vmlinux 0xacda96b5	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xacfd3ab2	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xad0aff93	clk_gpio_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xad12cb82	rio_mport_chk_dev_access
++EXPORT_SYMBOL_GPL vmlinux 0xad3a8df1	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0xad4e1032	xen_swiotlb_map_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xad713e4a	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0xad7e03c6	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xad8d8ab0	xen_physdev_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0xad8e8410	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0xada50f7d	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0xadc3286b	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadd82be0	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xadd8dea1	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xae1d0558	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xae35f264	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xaeb0a28e	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0xaeb5f691	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xaedda634	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xaf4cd6d3	acpi_os_map_memory
++EXPORT_SYMBOL_GPL vmlinux 0xaf635800	rio_request_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xaf76479c	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0xaf9439db	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xaf9add31	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0xafab7dd5	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0xafbce3a0	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0xaff4fcbd	clk_hw_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0xb008aa0c	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xb02ac411	register_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb02dcc48	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb055bf16	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0xb077e70a	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xb07f7dd7	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xb083d508	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xb08616b2	efivar_entry_remove
++EXPORT_SYMBOL_GPL vmlinux 0xb0867e3b	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0xb0880a99	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0bce4f0	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xb0c85892	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb0e589ad	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0xb0f79c40	to_nvdimm
++EXPORT_SYMBOL_GPL vmlinux 0xb1005af2	nd_numa_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xb1350976	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb150da09	pin_is_valid
++EXPORT_SYMBOL_GPL vmlinux 0xb15cd9f1	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xb1633779	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0xb172ffac	efivars_sysfs_init
++EXPORT_SYMBOL_GPL vmlinux 0xb1762232	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0xb1762efe	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb18eb6f4	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0xb1a5f2fe	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1b8b996	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1cd06b2	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1e438b0	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0xb1ed14d2	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb23593f5	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xb24586ba	__tracepoint_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xb24b0a25	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xb256f832	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xb2576433	xenbus_dev_fatal
++EXPORT_SYMBOL_GPL vmlinux 0xb265ee81	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0xb26a1add	elfcorehdr_addr
++EXPORT_SYMBOL_GPL vmlinux 0xb2832a8c	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0xb285b8f8	xen_in_preemptible_hcall
++EXPORT_SYMBOL_GPL vmlinux 0xb2b1c254	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xb2c7c08b	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0xb2e401e0	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb2f2b050	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0xb30e8963	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0xb3249fc6	input_class
++EXPORT_SYMBOL_GPL vmlinux 0xb3253ed9	hpet_rtc_timer_init
++EXPORT_SYMBOL_GPL vmlinux 0xb33820e6	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0xb3526a64	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xb35934b9	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0xb37bf95d	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0xb39a7673	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb3c55ba4	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xb3d386cc	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xb3dbe427	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xb3e78c0d	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0xb407990d	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xb40d8d8f	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xb42e37e9	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0xb4557e67	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0xb47710ba	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb4870a57	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0xb4945cbe	dmi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xb4b13e2a	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4cd0f69	xen_swiotlb_dma_mapping_error
++EXPORT_SYMBOL_GPL vmlinux 0xb4e14553	gnttab_query_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb4e8181b	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb51d5789	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb54a7b7d	acpi_gpiochip_request_interrupts
++EXPORT_SYMBOL_GPL vmlinux 0xb54d40db	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xb57ce96e	rio_local_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xb5847fa9	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5a11eab	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0xb5bb6a80	rio_release_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xb5c02271	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0xb5d2b335	clk_gpio_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb5e896fb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb5f2b0fc	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0xb5fed353	pci_msi_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xb601d482	to_nd_blk_region
++EXPORT_SYMBOL_GPL vmlinux 0xb6230f1f	gnttab_grant_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb634d833	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xb6589b1e	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xb66421b2	acpi_str_to_uuid
++EXPORT_SYMBOL_GPL vmlinux 0xb666293f	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0xb66ee4a2	devm_acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6bc49a9	__supported_pte_mask
++EXPORT_SYMBOL_GPL vmlinux 0xb6c307d1	xen_swiotlb_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0xb6cfb2d0	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xb6d84c41	clk_hw_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0xb6e5aef7	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xb6e6d99d	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb6fbefe1	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0xb70d1e15	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xb711d130	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xb718f2f9	sfi_table_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb7329c06	clk_set_phase
++EXPORT_SYMBOL_GPL vmlinux 0xb743e335	acpi_bind_one
++EXPORT_SYMBOL_GPL vmlinux 0xb74f269d	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0xb781a458	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xb7d0a240	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0xb7d75eab	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0xb7d7c12e	hpet_set_alarm_time
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb80f9309	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb828b220	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xb832a6b5	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0xb84b568c	nvdimm_pmem_region_create
++EXPORT_SYMBOL_GPL vmlinux 0xb875fa28	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0xb88209a8	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb8906112	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0xb892446f	print_context_stack_bp
++EXPORT_SYMBOL_GPL vmlinux 0xb892809d	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0xb8b2b1f7	mce_register_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8d278ca	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xb901d81c	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb9176155	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0xb92427b4	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb94a2975	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0xb9606689	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xb964ae0b	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xb966cef5	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0xb9730627	gdt_page
++EXPORT_SYMBOL_GPL vmlinux 0xb99184f0	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb99d5837	xenbus_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9ac6d44	ata_acpi_gtm_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c3f8b8	acpi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9e46a77	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0xba1048c3	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0xba19a530	acpi_create_platform_device
++EXPORT_SYMBOL_GPL vmlinux 0xba1ebd8a	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba4b75d7	user_read
++EXPORT_SYMBOL_GPL vmlinux 0xba54bade	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0xba860749	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0xba8929ea	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xba94c685	cper_estatus_check
++EXPORT_SYMBOL_GPL vmlinux 0xbaa0e765	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xbaaee0b4	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbaf6d630	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb04d526	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0cf5af	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xbb1c3dc2	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xbb355cd9	xenbus_register_driver_common
++EXPORT_SYMBOL_GPL vmlinux 0xbb40de92	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0xbb4719ab	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0xbb47f17b	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xbb58b814	iomap_free
++EXPORT_SYMBOL_GPL vmlinux 0xbb692a4c	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0xbb7cf9cb	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0xbba59ec1	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0xbba8f8a8	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0xbbb98859	edid_info
++EXPORT_SYMBOL_GPL vmlinux 0xbbc5db6a	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0xbbd4f657	xen_pcpu_id
++EXPORT_SYMBOL_GPL vmlinux 0xbbda32a0	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0xbbf2252b	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0xbbf2e09e	__add_pages
++EXPORT_SYMBOL_GPL vmlinux 0xbbf63026	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xbbf70486	acpi_dma_request_slave_chan_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xbc028df6	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xbc0dc15e	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0xbc12f372	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0xbc187865	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0xbc2bc46c	__rio_local_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xbc4217d4	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0xbc462366	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0xbc527a0d	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbc563b51	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc8b3948	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0xbca0201a	sfi_mrtc_array
++EXPORT_SYMBOL_GPL vmlinux 0xbca8e0cf	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcafb9f7	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xbcb838a1	amd_flush_garts
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcd44dad	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbceaf01a	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcfddb86	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0xbd19951e	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0xbd2bb45c	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0xbd3ac9e4	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fc9d2	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd471a16	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd727d6e	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0xbd7dc938	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xbd86b127	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xbd9062ab	pinctrl_pm_select_default_state
++EXPORT_SYMBOL_GPL vmlinux 0xbda682ca	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbdb08d1c	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xbdbd0fb0	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xbdcb9d69	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbdd5f10f	apei_hest_parse
++EXPORT_SYMBOL_GPL vmlinux 0xbddb50a1	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0xbddf6a72	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbdf1462c	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0xbdfb69a3	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe3fb967	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xbe42c8db	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0xbe4740ba	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0xbe49e682	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0xbe4e015a	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0xbe5a7f7b	gpiochip_add_pin_range
++EXPORT_SYMBOL_GPL vmlinux 0xbe5eafce	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe7074cc	acpi_device_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xbe75a4b5	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0xbe8320d7	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbeb86170	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbeeb3603	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xbefe7dda	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf10959a	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0xbf3a5dde	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xbf430d7f	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xbf4662b7	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xbf46c392	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0xbf4bdddb	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xbf909a98	xenbus_dev_error
++EXPORT_SYMBOL_GPL vmlinux 0xbf93ec7d	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0xbfb1be70	hv_setup_vmbus_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbfb4fec0	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfcbf4f8	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xbfce683e	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0xbfd10bb7	clk_register_mux_table
++EXPORT_SYMBOL_GPL vmlinux 0xbfd7a78f	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xbfe86fc3	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xbff75e26	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xc00131cf	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0xc02a191e	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0xc02c936f	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0xc06ba32c	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0xc0709478	rio_unmap_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xc079a946	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc0900fcf	acpi_os_get_iomem
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0d8f3fa	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0e75cec	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc117c6ae	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xc12e0ada	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0xc1432573	iommu_capable
++EXPORT_SYMBOL_GPL vmlinux 0xc1551799	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc15dc547	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0xc164642e	xenbus_otherend_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc16c0f49	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc17519f7	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc18578ed	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xc190ba97	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0xc191624b	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xc19ae185	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0xc1d03951	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xc1d463b5	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0xc1dd3787	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc1ee30dc	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0xc1f08088	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0xc2041966	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xc213d599	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc22e9690	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0xc24159d7	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0xc25b8971	hv_remove_crash_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc26351f8	bind_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc27226bf	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc275a470	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc287d96a	kvm_set_posted_intr_wakeup_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc28b7817	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0xc292b41f	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xc2a6b3ee	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0xc2a6df56	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0xc2ba49d0	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0xc2d751de	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc2e728dc	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0xc3239e9a	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc329b6df	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0xc338dc25	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0xc33e912f	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc34740c3	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0xc34afdc0	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xc36e910d	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc37bdac9	user_update
++EXPORT_SYMBOL_GPL vmlinux 0xc37c0531	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0xc3929967	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0xc397639f	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0xc3a436b8	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xc3ab89f7	xen_swiotlb_dma_mmap
++EXPORT_SYMBOL_GPL vmlinux 0xc3c7744f	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xc3cdfc0a	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc3e190af	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0xc403a782	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc43c9740	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xc449c08c	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc45746a7	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc45c6a63	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0xc465c315	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc48aa3cb	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc49dceb4	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0xc4bb84bf	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0xc4c23d5e	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4d1defe	acpi_dev_get_property
++EXPORT_SYMBOL_GPL vmlinux 0xc4e3bbb9	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0xc4e8219e	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0xc500c2c0	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xc511668c	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0xc52dd247	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0xc5397da6	xenbus_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc55987c8	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0xc56475d8	isa_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc569d8ce	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc5a775cc	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0xc5a87b5a	rio_release_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xc5a93cf9	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc5acb6e5	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc5d681f2	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc5d785e2	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0xc5fa7d16	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0xc5fe0c57	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0xc60e68d8	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc612ea36	acpi_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc636a3cf	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc65c6f0d	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc66019cc	xen_resume_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc66b5b2a	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc675c3e4	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0xc677fcd4	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6a4a872	__clk_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc6c73109	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0xc6e54edb	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xc7002ac4	evtchn_make_refcounted
++EXPORT_SYMBOL_GPL vmlinux 0xc7061ef3	iova_cache_put
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc77218b4	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xc7749e1f	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0xc7769959	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0xc7895ac3	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7a34a7e	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xc7a40204	xenbus_dev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7e4a7dd	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xc7ec22a0	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xc80ea766	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xc81423eb	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xc81b765d	put_iova_domain
++EXPORT_SYMBOL_GPL vmlinux 0xc8295b48	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xc832d65b	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0xc850fcdf	rio_get_comptag
++EXPORT_SYMBOL_GPL vmlinux 0xc87a3471	nvdimm_create
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc87e2d7a	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xc87e487a	sched_clock_idle_sleep_event
++EXPORT_SYMBOL_GPL vmlinux 0xc88031c1	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xc895f4e4	xen_xenbus_fops
++EXPORT_SYMBOL_GPL vmlinux 0xc8a1bc21	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8d337ff	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc8e5f591	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc9003845	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0xc9007a40	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc935ca76	pinctrl_find_and_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc9705eeb	has_newer_microcode
++EXPORT_SYMBOL_GPL vmlinux 0xc9736012	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xc97e4c71	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xc994164e	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xc9a7729a	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xc9a9939d	restore_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0xc9c3f176	hpet_register_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc9d141f0	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xca06f41f	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0xca3abd67	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0xca3ca643	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0xca445d58	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0xca4a1023	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0xca668479	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca81ea9a	xenbus_transaction_end
++EXPORT_SYMBOL_GPL vmlinux 0xcab5cf21	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xcabb0802	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0xcabc7c71	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb1db3eb	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xcb209d94	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0xcb3abcd7	clk_hw_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0xcb40d98e	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0xcb44662e	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb51b8f7	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0xcb66d4ef	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xcb76fc6d	rio_mport_get_feature
++EXPORT_SYMBOL_GPL vmlinux 0xcb87014a	ioremap_uc
++EXPORT_SYMBOL_GPL vmlinux 0xcb980f1a	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcbb72f4f	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0xcbbee1a5	__tracepoint_remove_device_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xcbbf2b78	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0xcbc41b04	pcc_mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0xcbd48c3f	hv_setup_crash_handler
++EXPORT_SYMBOL_GPL vmlinux 0xcbd80818	xen_xlate_remap_gfn_array
++EXPORT_SYMBOL_GPL vmlinux 0xcbdf8cb0	xen_swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcc095948	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xcc2ff140	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0xcc52be89	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xcc6d5f38	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xcc733366	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xcc7e6d6c	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc900656	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xccac1173	xenbus_match
++EXPORT_SYMBOL_GPL vmlinux 0xccbe497b	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0xccbed926	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0xcccbda33	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccda8915	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0xcce11c1e	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0xcce5ec27	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0xcce8dd9a	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0xccea4e34	perf_get_x86_pmu_capability
++EXPORT_SYMBOL_GPL vmlinux 0xcced0d0e	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xccefa6d1	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0xccfb3073	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0xcd014594	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0xcd0f2b99	xen_swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0xcd1516df	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xcd2af65a	generic_access_phys
++EXPORT_SYMBOL_GPL vmlinux 0xcd2cadd7	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xcd31af39	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0xcd3bece1	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0xcd418254	__remove_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcd437cde	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xcd5a0d7c	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0xcd5d4ef9	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0xcd6290c5	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xcd75f0b8	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0xcd78aae3	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0xcd88a216	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0xcd8ffa10	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdb83418	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcdcc8125	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0xcde34ce3	add_memory_resource
++EXPORT_SYMBOL_GPL vmlinux 0xcde7a4be	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0xcdf086d2	__nvdimm_bus_register
++EXPORT_SYMBOL_GPL vmlinux 0xce12d037	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xce1c5d07	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce7fbb0e	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xcec67374	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcee5b7a7	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xceeb9ca3	rio_mport_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xceeba22a	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xceeec9ac	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0xcef1dd0e	perf_check_microcode
++EXPORT_SYMBOL_GPL vmlinux 0xcef81d04	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf5b721d	get_device
++EXPORT_SYMBOL_GPL vmlinux 0xcf6509d6	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0xcf7c0ebe	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0xcf867ad2	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xcf93b36a	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xcfa0805a	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfc75cd8	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xcfcd1bad	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcfd514ec	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd0458ccb	xenbus_strstate
++EXPORT_SYMBOL_GPL vmlinux 0xd0513b8d	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd056df4d	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0xd05e1d2b	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0xd05f904a	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd06263b7	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd07cfd59	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0xd080cff4	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xd093599e	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xd0962d3a	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd09ad085	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd09fa834	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0ca9143	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0xd0d54d2b	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xd0d95dde	xen_swiotlb_sync_sg_for_device
++EXPORT_SYMBOL_GPL vmlinux 0xd0d965d1	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xd0f9eea5	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xd1250159	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0xd12cd8a8	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xd133efbb	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xd13a84b1	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xd1507e59	erst_clear
++EXPORT_SYMBOL_GPL vmlinux 0xd15cbf80	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd1b7262a	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xd1de7b37	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd20be3f1	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd215e2d6	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0xd2164a96	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd218adee	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0xd21c32c2	__tracepoint_io_page_fault
++EXPORT_SYMBOL_GPL vmlinux 0xd2249d03	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0xd226906e	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0xd23122f0	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0xd2538056	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0xd2539ecb	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xd254942a	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd28285ef	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd2a1adae	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0xd2aaeb4e	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xd2b47dfe	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0xd2bdca65	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0xd2c58ab2	apei_exec_noop
++EXPORT_SYMBOL_GPL vmlinux 0xd2ce01c1	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0xd2d1927b	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2e88de5	clk_register_gate
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd3016ba5	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd313baec	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0xd3210398	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0xd331a8ae	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0xd33257ae	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0xd338ede0	pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0xd3484c49	clk_hw_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0xd36477ee	rio_route_add_entry
++EXPORT_SYMBOL_GPL vmlinux 0xd3769110	agp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0xd38ff993	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0xd3a6d5b2	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3b2d562	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd41dc330	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd42920a5	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0xd42d047e	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xd4441db1	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd44ac1f4	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd44b03a2	acpi_node_get_property_reference
++EXPORT_SYMBOL_GPL vmlinux 0xd44db93a	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0xd44e6a69	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0xd4561dd0	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0xd45ea32f	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0xd47c9626	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd4868102	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0xd48a5b98	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0xd4b11546	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0xd4b1c055	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0xd4b30939	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4c9435c	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xd4cf632d	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xd4d90889	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xd4db0165	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xd4e312fb	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0xd4e940d5	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0xd4f46cde	clear_foreign_p2m_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xd4fa0f8d	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0xd502345d	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0xd5030f07	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xd544e902	pgprot_writecombine
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd5605a45	xenbus_free_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0xd5a0fead	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xd5a5b86f	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0xd5b85c98	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd2cb8	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5e55e73	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd6328a67	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0xd632b65f	efivar_entry_size
++EXPORT_SYMBOL_GPL vmlinux 0xd635534d	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xd63f55a2	dax_fault
++EXPORT_SYMBOL_GPL vmlinux 0xd6412f4f	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0xd650889b	clk_hw_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xd656af12	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0xd65b0b53	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd68a630d	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xd6cf7615	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xd6e6f900	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0xd6ebf92d	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xd6ec7d35	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xd6ed3a8e	cper_next_record_id
++EXPORT_SYMBOL_GPL vmlinux 0xd6ee2541	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0xd6feefa5	agp_num_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd7125e33	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xd72a760e	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xd72cb603	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0xd72feba2	xenbus_read_driver_state
++EXPORT_SYMBOL_GPL vmlinux 0xd7399d2a	efivar_entry_iter_end
++EXPORT_SYMBOL_GPL vmlinux 0xd745a835	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xd75068fc	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0xd764d265	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd772fce6	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd77dd7e0	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd79461b7	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0xd7ab2c0c	speedstep_detect_processor
++EXPORT_SYMBOL_GPL vmlinux 0xd7bf4f08	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xd7c75198	acpi_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0xd7c7ffe3	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7d9bb87	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0xd8040503	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0xd81826c8	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd8250a5c	iounmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xd85fba12	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xd86a2131	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd88b1733	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0xd8af8d8f	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xd8b870ac	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xd8b8fee4	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0xd8c76c4b	pv_info
++EXPORT_SYMBOL_GPL vmlinux 0xd8eea502	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xd919806a	amd_cache_northbridges
++EXPORT_SYMBOL_GPL vmlinux 0xd923afae	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0xd923e4d6	nd_region_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94b737e	erst_read
++EXPORT_SYMBOL_GPL vmlinux 0xd94fa823	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd97819f5	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xd9805be1	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd986dad1	kernel_fpu_begin
++EXPORT_SYMBOL_GPL vmlinux 0xd997a83e	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0xd9cf8b67	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xda16218f	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0xda1ef35c	intel_svm_bind_mm
++EXPORT_SYMBOL_GPL vmlinux 0xda4bbd3d	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0xda7febef	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0xda862c20	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0xda864c3c	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdaa06dc1	acpi_lpat_raw_to_temp
++EXPORT_SYMBOL_GPL vmlinux 0xdaa74860	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdae61b98	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0xdaea0533	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdb088cb1	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0xdb25725f	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0xdb261f83	efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0xdb263724	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0xdb3d8354	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb4cf33c	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0xdb63a944	acpi_lpat_get_conversion_table
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdba34f62	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0xdbc5657f	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xdbcf6a6c	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0xdbdb54db	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xdbe9d084	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0xdbf440a3	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc14a211	xen_hvm_evtchn_do_upcall
++EXPORT_SYMBOL_GPL vmlinux 0xdc31d2b7	xenbus_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xdc3c24c2	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0xdc3f74fa	smp_ops
++EXPORT_SYMBOL_GPL vmlinux 0xdc6699cb	acpi_dev_free_resource_list
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc95098e	rio_dma_prep_xfer
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdcae8c56	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xdcb3fd8a	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xdcbc6062	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xdceba602	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0xdd069d07	rio_mport_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd289a51	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd2f5d17	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd3ff15e	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xdd579e0d	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0xdd66ebee	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0xdd6e3fec	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xddb31a6d	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0xddb696a8	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddc42e04	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0xddc560f9	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xdddf131e	xenbus_grant_ring
++EXPORT_SYMBOL_GPL vmlinux 0xdde3ef3f	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0xddf1b396	gpiochip_add_pingroup_range
++EXPORT_SYMBOL_GPL vmlinux 0xddf8cca3	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xde0ecbad	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0xde1f4124	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0xde46e353	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xde747356	intel_msic_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xde8dd926	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0xde9463a6	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xded351b3	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0xdeeaf904	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0xdef8ec6c	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0xdeff5b9f	__dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf1882af	dbgp_reset_prep
++EXPORT_SYMBOL_GPL vmlinux 0xdf20dc98	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xdf2a1971	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0xdf3f0fd0	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0xdf42a38e	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0xdf584f07	__efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0xdf622181	clk_register_divider_table
++EXPORT_SYMBOL_GPL vmlinux 0xdf66ca81	ucode_cpu_info
++EXPORT_SYMBOL_GPL vmlinux 0xdf75282c	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0xdf761434	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdf7ecd10	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0xdf8100f8	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xdfb52c89	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe027821a	rio_release_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe046d67f	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe04b7dfc	clk_register_mux
++EXPORT_SYMBOL_GPL vmlinux 0xe04d59b6	fpu__activate_curr
++EXPORT_SYMBOL_GPL vmlinux 0xe050d14c	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe0745fc4	pinctrl_pm_select_idle_state
++EXPORT_SYMBOL_GPL vmlinux 0xe08938e7	rio_set_port_lockout
++EXPORT_SYMBOL_GPL vmlinux 0xe089cfcc	agp_memory_reserved
++EXPORT_SYMBOL_GPL vmlinux 0xe08f7e78	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0xe099e57d	to_nd_region
++EXPORT_SYMBOL_GPL vmlinux 0xe0a76e1c	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0xe0b1c103	clk_set_max_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe0c089e6	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0xe0c3768d	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0xe0c77bb5	mce_notify_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe1083ae3	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0xe10cd6ad	erst_get_record_id_begin
++EXPORT_SYMBOL_GPL vmlinux 0xe1183e83	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xe11abdf3	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xe11c830d	rio_route_get_entry
++EXPORT_SYMBOL_GPL vmlinux 0xe121cbb6	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0xe1381ff5	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0xe14feff3	__tracepoint_attach_device_to_domain
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe1a207fe	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0xe1bd6c99	rio_init_mports
++EXPORT_SYMBOL_GPL vmlinux 0xe1c59069	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0xe1cff2cd	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xe1d8d98c	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0xe1dea997	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0xe1eef8c0	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0xe23d8582	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xe2555da4	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0xe25ede9f	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0xe2777695	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe29349dc	copy_reserved_iova
++EXPORT_SYMBOL_GPL vmlinux 0xe295c0ff	is_hpet_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe2b25158	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0xe2b6919a	xenbus_dev_changed
++EXPORT_SYMBOL_GPL vmlinux 0xe2d8c20c	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe2fea4a4	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe31e3c54	pinctrl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe32ced51	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xe33f23e5	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0xe3424f2e	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0xe3781628	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0xe37a007c	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0xe3948ff4	acpi_walk_dep_device_list
++EXPORT_SYMBOL_GPL vmlinux 0xe395ebf7	dax_clear_blocks
++EXPORT_SYMBOL_GPL vmlinux 0xe397edf7	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xe3a7b3b7	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xe3bc7fd4	hpet_unregister_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe3bda663	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe3be1f8a	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0xe3c9da8a	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xe3f1f9e9	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0xe402eb6f	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0xe41534ce	bind_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0xe418fde4	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xe41f89d5	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe439815c	erst_get_record_count
++EXPORT_SYMBOL_GPL vmlinux 0xe43d61ec	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe46e8f4f	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xe472724b	apei_get_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe4a0d7af	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xe4b70bf3	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0xe4b8027a	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0xe4c331b6	acpi_os_unmap_memory
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4c5cf93	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe4e68bc8	apei_map_generic_address
++EXPORT_SYMBOL_GPL vmlinux 0xe4f233a5	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0xe4ffa1ac	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe514d401	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xe51ad11f	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe545a811	get_xsave_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe57b04e1	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5a0579f	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0xe5b8082b	cper_estatus_check_header
++EXPORT_SYMBOL_GPL vmlinux 0xe5d58b0a	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xe5ddac70	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0xe6060185	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe6281b4f	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0xe62e8315	efivars_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe62ef742	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0xe647f410	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0xe64ad8ea	unregister_nmi_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe6534747	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0xe65de440	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0xe6750ea5	efivar_entry_find
++EXPORT_SYMBOL_GPL vmlinux 0xe6946768	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0xe6b1f8df	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe6f83837	acpi_bus_attach_private_data
++EXPORT_SYMBOL_GPL vmlinux 0xe6fb3f7a	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0xe70e945e	rio_dev_get
++EXPORT_SYMBOL_GPL vmlinux 0xe7119122	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0xe7232e0f	user_return_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe732aa33	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe757b3ea	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe77e0c8c	__rio_local_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe7a13348	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe7b40b87	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xe7dc4d47	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0xe7fb7e0e	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe8081108	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xe80f7d48	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe8203ddc	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0xe82bea8f	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe82c66ee	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xe83a49a6	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe870d785	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe898832f	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0xe8ab38de	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0xe8acabaa	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xe8bf4851	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0xe8cb2796	xen_remap_domain_gfn_array
++EXPORT_SYMBOL_GPL vmlinux 0xe8d59551	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xe8e041db	acpi_dev_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0xe908ea11	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xe9260be3	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xe93b862f	nd_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe94c7d93	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0xe94fe84e	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0xe981c9db	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0xe9a8acea	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0xe9be2009	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0xe9c0744e	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe9c12c96	__clk_mux_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe9c8d2b6	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0xe9ce931a	kvm_para_available
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xe9db0101	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0xe9edb03e	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea47e930	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0xea5d795f	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0xea62ade6	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0xea844b4d	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xea99b795	__tracepoint_map
++EXPORT_SYMBOL_GPL vmlinux 0xeaa7a476	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0xeabb8c79	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0xeabf284e	acpiphp_register_attention
++EXPORT_SYMBOL_GPL vmlinux 0xeae9e4b3	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0xeaf48e2a	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0xeb2798f7	xen_destroy_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xeb317976	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0xeb370805	__apei_exec_run
++EXPORT_SYMBOL_GPL vmlinux 0xeb38b7f1	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xeb497840	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xeb833c22	xen_has_pv_disk_devices
++EXPORT_SYMBOL_GPL vmlinux 0xeb9abbee	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xeba9bac0	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0xebb3592b	snmp_get_cpu_field64
++EXPORT_SYMBOL_GPL vmlinux 0xebc5c5d9	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0xebc61165	__rio_local_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xebc7dd72	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0xebdec251	acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xec14ce25	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec374b58	nd_blk_region_to_dimm
++EXPORT_SYMBOL_GPL vmlinux 0xec631f34	remove_memory
++EXPORT_SYMBOL_GPL vmlinux 0xec6bf0e9	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0xec7170e1	rio_mport_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xec8c1d44	acpi_dev_pm_attach
++EXPORT_SYMBOL_GPL vmlinux 0xec91fc2e	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0xecaafb25	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0xecac7abd	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xecba7e0e	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0xecd2d65c	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xed06c5cb	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xed16c658	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xed4dd069	device_register
++EXPORT_SYMBOL_GPL vmlinux 0xed8d09c4	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xed8efbb8	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0xed90bcf9	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0xed9ce7ef	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0xedbc6f67	gnttab_end_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xedcdffd4	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0xedea6f15	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xedee9310	nd_mapping_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xee0eed3d	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xee169f5f	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xee2a67d1	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0xee4a201e	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0xee66be8d	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee6f5e3e	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0xee85bbca	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0xee88d7b8	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xeeb1f0c4	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xeebc792d	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0xeeed0038	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xeefabc5f	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xef156f0a	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xef1f6e23	apei_resources_request
++EXPORT_SYMBOL_GPL vmlinux 0xef305f5d	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xef409b74	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0xef464c28	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0xef4a11ac	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xef4fc0b6	pci_msi_create_irq_domain
++EXPORT_SYMBOL_GPL vmlinux 0xef588a73	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6e0818	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0xef76ea0a	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xef9960c6	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefa9ccac	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0xefec6cda	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0xeffc2f2c	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xf0269c1a	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf04cc611	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0xf054ac97	intel_msic_irq_read
++EXPORT_SYMBOL_GPL vmlinux 0xf0658dc4	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0xf0696401	acpi_pci_detect_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf09391b2	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xf094bce6	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4cfa3	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xf0c68290	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf0dd608a	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf0e15958	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xf0e30556	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf11d98f4	pinctrl_utils_dt_free_map
++EXPORT_SYMBOL_GPL vmlinux 0xf1496264	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0xf14e1650	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0xf14ea02e	pinctrl_utils_add_config
++EXPORT_SYMBOL_GPL vmlinux 0xf1535108	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xf173b683	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0xf17830bf	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0xf182d826	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf1a5226f	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xf1ac0e14	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1b551d9	ibft_addr
++EXPORT_SYMBOL_GPL vmlinux 0xf1bb2867	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf1e47914	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0xf209ab97	of_css
++EXPORT_SYMBOL_GPL vmlinux 0xf20ab5eb	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0xf20e4414	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xf2196393	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf23ee917	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf291252d	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0xf2a37426	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2eee43e	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0xf2f1d86e	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf30fda27	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf32bdc5d	unregister_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf3344fd5	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0xf3587d2d	device_del
++EXPORT_SYMBOL_GPL vmlinux 0xf3627420	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf38b3213	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf3aeddb3	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3b503fc	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3c1c980	pinctrl_utils_reserve_map
++EXPORT_SYMBOL_GPL vmlinux 0xf3d1ee2c	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0xf3d251d7	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0xf3dd3ec1	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf3ebf4eb	arch_apei_report_mem_error
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf41eebde	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xf429ae34	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xf43f65d5	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0xf446837f	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0xf45a6e0d	xen_unregister_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0xf4630185	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf489512f	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0xf48c348e	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4ae4e60	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf4b98843	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0xf4d50b6f	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0xf4ef015b	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf508c031	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf5361b39	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf5465a55	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf54fa145	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf5657e31	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0xf5785b42	evtchn_get
++EXPORT_SYMBOL_GPL vmlinux 0xf57d8d9f	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0xf57fa8d4	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xf5848c8b	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xf5871a31	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf5945bac	gnttab_free_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0xf5964e88	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5cc6951	acpi_is_pnp_device
++EXPORT_SYMBOL_GPL vmlinux 0xf5d2e404	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6039dae	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xf604d0fa	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xf615386f	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xf62f8414	clk_debugfs_add_file
++EXPORT_SYMBOL_GPL vmlinux 0xf6497e0f	usb_acpi_power_manageable
++EXPORT_SYMBOL_GPL vmlinux 0xf6769a48	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0xf67f5e98	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0xf6bf860e	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xf6c71a25	cper_severity_str
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6cf488c	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0xf6db3ec2	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf6ecb4cf	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf6f596f7	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xf7016530	xenbus_gather
++EXPORT_SYMBOL_GPL vmlinux 0xf7264cd4	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xf72a1c2f	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0xf73c13e6	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf7545fa8	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xf76bc672	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0xf7c3f273	xen_resume_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xf7d17126	devm_acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xf7daadc3	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf7e3b8c5	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0xf7e3d204	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xf7f12733	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf803bac4	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0xf818fc3f	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xf819bdc1	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xf81e35b4	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0xf82a4fd7	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0xf82f16b3	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf8355365	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf85770a7	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf894ba00	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0xf8c9ec63	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0xf8cbd147	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0xf8cf3ccb	acpi_dev_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xf8d781f1	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0xf8e6b564	hibernation_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf9048ee1	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xf90adf1e	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0xf910e864	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0xf916482b	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0xf92cda13	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf9307bc1	rio_enable_rx_tx_port
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf95e8ae0	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xf9765833	dmi_match
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9ad44af	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9cc5ee3	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0xf9d9264e	xen_have_vector_callback
++EXPORT_SYMBOL_GPL vmlinux 0xf9f04dac	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa35044a	alternatives_patched
++EXPORT_SYMBOL_GPL vmlinux 0xfa42870c	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0xfa471902	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0xfa4ff3d9	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0xfa5e5b67	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xfa611584	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0xfa6adb7d	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0xfa9e33f7	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0xfaa5d5a6	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xfabddf64	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xfacb9bb8	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0xfae29f12	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0xfb11aaf3	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xfb250e34	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0xfb25ce06	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb35b44c	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0xfb54427f	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0xfb582919	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0xfb64b230	acpi_processor_ffh_cstate_probe
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb7bce4b	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0xfb80489f	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xfb8237eb	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0xfb83db03	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xfb905c89	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfbcff401	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0xfbd62c35	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0xfbd6a7e0	xenbus_dev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc216628	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xfc254d15	gnttab_free_auto_xlat_frames
++EXPORT_SYMBOL_GPL vmlinux 0xfc3b4246	acpi_bus_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xfc4f85e0	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfc7b60f4	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xfc968c8b	apei_exec_write_register_value
++EXPORT_SYMBOL_GPL vmlinux 0xfcbee39a	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0xfcf654a7	rio_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xfd0e3e79	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0xfd124564	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0xfd1432a1	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xfd190374	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0xfd2c49b0	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xfd3733d7	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0xfd3a8898	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xfd5131f4	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0xfd51b281	gnttab_end_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0xfd54c210	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xfd57a738	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xfd6adf20	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xfd7243c7	erst_disable
++EXPORT_SYMBOL_GPL vmlinux 0xfd77d23c	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd8e7a4b	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xfdb47e76	pcc_mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xfdc0a996	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xfdcbb464	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xfde895d4	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0xfdf7b781	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xfe010712	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xfe031037	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0xfe144535	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xfe51ddca	clk_hw_get_parent_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xfe52aa6a	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xfe727411	get_phys_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfeafabd0	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xfeb1979b	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xfec0468d	pinctrl_dev_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xfec11087	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfed2c946	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xfee02f24	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xfef7e664	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff05632f	acpi_driver_match_device
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff277cc3	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xff291ecf	clk_unregister_divider
++EXPORT_SYMBOL_GPL vmlinux 0xff2ce747	machine_check_poll
++EXPORT_SYMBOL_GPL vmlinux 0xff50e8ed	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0xff5452d1	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff676787	devm_pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffba4dfb	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xffc42efc	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0xffddaac8	phy_pm_runtime_put
++EXPORT_SYMBOL_GPL vmlinux 0xffe57394	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xffe729b6	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xfff320da	inet6_csk_addr2sockaddr
+diff --git a/debian.master/abi/4.4.0-111.134/i386/generic.compiler b/debian.master/abi/4.4.0-111.134/i386/generic.compiler
+new file mode 100644
+index 0000000..d1936f3
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/i386/generic.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/i386/generic.modules b/debian.master/abi/4.4.0-111.134/i386/generic.modules
+new file mode 100644
+index 0000000..ce13ae4
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/i386/generic.modules
+@@ -0,0 +1,4757 @@
++3c509
++3c515
++3c574_cs
++3c589_cs
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++53c700
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_accent
++8250_boca
++8250_dw
++8250_exar_st16c554
++8250_fintek
++8250_fourport
++8250_hub6
++8250_mid
++8255
++8255_pci
++8390
++8390p
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++BusLogic
++DAC960
++NCR53c406a
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++abituguru
++abituguru3
++ablk_helper
++ac97_bus
++acard-ahci
++acecad
++acenic
++acer-wmi
++acerhdf
++acpi-als
++acpi_extlog
++acpi_ipmi
++acpi_pad
++acpi_power_meter
++acpi_thermal_rel
++acpiphp_ibm
++acquirewdt
++act2000
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7170
++adv7175
++adv7180
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++advantechwdt
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++aes-i586
++aesni-intel
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++ah4
++ah6
++aha152x
++aha152x_cs
++aha1542
++aha1740
++ahci
++ahci_platform
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airo
++airo_cs
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++ali-agp
++ali-ircc
++alienware-wmi
++alim1535_wdt
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am53c974
++ambassador
++amc6821
++amd
++amd-rng
++amd5536udc
++amd64_edac_mod
++amd76x_edac
++amd76xrom
++amd8111e
++amd_freq_sensitivity
++amdgpu
++amilo-rfkill
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apanel
++apds9300
++apds9802als
++apds990x
++apds9960
++apm
++apple-gmux
++apple_bl
++appledisplay
++applesmc
++appletalk
++appletouch
++applicom
++aquantia
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_ps2
++arc_uart
++arcfb
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3935
++as5011
++asb100
++asc7621
++ascot2e
++asix
++ast
++asus-laptop
++asus-nb-wmi
++asus-wmi
++asus_atk0110
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati-agp
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atlas_btns
++atm
++atmel
++atmel_cs
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp
++atp870u
++atusb
++atxp1
++aty128fb
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avm_cs
++avma1_cs
++avmfritz
++ax25
++ax88179_178a
++axnet_cs
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1isa
++b1pci
++b1pcmcia
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_epp
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcma
++bcma-hcd
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_aout
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluecard_cs
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpck
++bpck6
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmsmac
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bt3c_cs
++bt819
++bt856
++bt866
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btuart_cs
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c101
++c2port-duramar2150
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_das16_cs
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc10001_adc
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++ccp
++ccp-crypto
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfag12864b
++cfag12864bfb
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipreg
++chnl_net
++chromeos_laptop
++chromeos_pstore
++ci_hdrc
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++ck804xrom
++classmate-laptop
++clip
++clk-cdce706
++clk-palmas
++clk-pwm
++clk-s2mps11
++clk-si5351
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cm4000_cs
++cm4040_cs
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmtp
++cnic
++cobalt
++cobra
++coda
++com20020
++com20020-isa
++com20020-pci
++com20020_cs
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_isadma
++comedi_parport
++comedi_pci
++comedi_pcmcia
++comedi_test
++comedi_usb
++comm
++compal-laptop
++configfs
++contec_pci_dio
++cops
++cordic
++core
++coretemp
++cosa
++cp210x
++cpcihp_generic
++cpcihp_zt5550
++cpia2
++cpqphp
++cpsw_ale
++cpu-notifier-error-inject
++cpu5wdt
++cpuid
++cr_bllcd
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc32-pclmul
++crc7
++crc8
++cros_ec
++cros_ec_devs
++cros_ec_i2c
++cros_ec_keyb
++cros_ec_lpc
++cros_ec_spi
++crvml
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++cs5535-mfd
++cs553x_nand
++cs89x0
++csiostor
++ct82c710
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_cs
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++db9
++dc395x
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++dcdbas
++ddbridge
++de2104x
++de4x5
++decnet
++deflate
++defxx
++dell-laptop
++dell-led
++dell-rbtn
++dell-smm-hwmon
++dell-smo8800
++dell-wmi
++dell-wmi-aio
++dell_rbu
++denali
++denali_dt
++denali_pci
++des_generic
++designware_i2s
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9601
++dme1737
++dmfe
++dmi-sysfs
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++donauboe
++dp83848
++dp83867
++dpt_i2o
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dtc
++dtl1_cs
++dtlk
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_wdt
++dwc3
++dwc3-pci
++dwmac-generic
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++e752x_edac
++e7xxx_edac
++earth-pt1
++earth-pt3
++eata
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++ec_bhf
++ec_sys
++echainiv
++echo
++edac_core
++edac_mce_amd
++edt-ft5x06
++eeepc-laptop
++eeepc-wmi
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efficeon-agp
++efi-pstore
++efi_test
++efs
++ehset
++einj
++elan_i2c
++elo
++elsa_cs
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++empeg
++ems_pci
++ems_pcmcia
++ems_usb
++emu10k1-gp
++ena
++enc28j60
++enclosure
++encx24j600
++encx24j600-regmap
++ene_ir
++eni
++enic
++epat
++epia
++epic100
++eql
++esas2r
++esb2rom
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++eurotechwdt
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++ezusb
++f2fs
++f71805f
++f71808e_wdt
++f71882fg
++f75375s
++f81232
++fakelb
++fam15h_power
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_sys_fops
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdomain_cs
++fdp
++fdp_i2c
++fealnx
++ff-memless
++fintek-cir
++firedtv
++firestream
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fixed
++fjes
++fl512
++flexfb
++floppy
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fmvj18x_cs
++fnic
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fschmd
++fsl_lpuart
++ft6236
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu-laptop
++fujitsu-tablet
++fujitsu_ts
++g450_pll
++g760a
++g762
++g_NCR5380
++g_NCR5380_mmio
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcm
++gdmtty
++gdmulte
++gdmwm
++gdth
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++geode-aes
++geode-rng
++gf128mul
++gf2k
++gfs2
++ghash-generic
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++glue_helper
++gluebi
++gma500_gfx
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-104-idio-16
++gpio-addr-flash
++gpio-adp5520
++gpio-adp5588
++gpio-amd8111
++gpio-amdpt
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-cs5535
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-f7188x
++gpio-fan
++gpio-generic
++gpio-ich
++gpio-ir-recv
++gpio-it87
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-pch
++gpio-rdc321x
++gpio-regulator
++gpio-sch
++gpio-sch311x
++gpio-tps65912
++gpio-twl4030
++gpio-twl6040
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mouse
++gpio_tilt_polled
++gr_udc
++grace
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++gx-suspmod
++gx1fb
++gxfb
++gxt4500
++hackrf
++hamachi
++hampshire
++hangcheck-timer
++hanwang
++hci
++hci_uart
++hci_vhci
++hdaps
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hecubafb
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfs
++hfsplus
++hgafb
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-hyperv
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++hih6130
++hio
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi504_nand
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hopper
++horizon
++horus3a
++hostap
++hostap_cs
++hostap_pci
++hostap_plx
++hostess_sv11
++hp-wireless
++hp-wmi
++hp100
++hp_accel
++hpfs
++hpilo
++hpsa
++hptiop
++hpwdt
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++hsu_dma_pci
++htc-pasic3
++htcpen
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hv_balloon
++hv_netvsc
++hv_storvsc
++hv_utils
++hv_vmbus
++hwa-hc
++hwa-rc
++hwmon-vid
++hx8357
++hyperv-keyboard
++hyperv_fb
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd756-s4882
++i2c-amd8111
++i2c-cbus-gpio
++i2c-cros-ec-tunnel
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-eg20t
++i2c-emev2
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-ismt
++i2c-kempld
++i2c-matroxfb
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-pinctrl
++i2c-mux-reg
++i2c-nforce2
++i2c-nforce2-s4985
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-isa
++i2c-pca-platform
++i2c-piix4
++i2c-robotfuzz-osif
++i2c-scmi
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i3000_edac
++i3200_edac
++i40e
++i40evf
++i5000_edac
++i5100_edac
++i5400_edac
++i5500_temp
++i5k_amb
++i6300esb
++i7300_edac
++i740fb
++i7core_edac
++i810
++i810fb
++i82092
++i82365
++i82860_edac
++i82875p_edac
++i82975x_edac
++i915
++i915_bpo
++iTCO_vendor_support
++iTCO_wdt
++ib700wdt
++ib_addr
++ib_cm
++ib_core
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibm_rtl
++ibmaem
++ibmasm
++ibmasr
++ibmpex
++ibmphp
++ichxrom
++icn
++icp_multi
++icplus
++ics932s401
++ideapad-laptop
++ideapad_slidebar
++idma64
++idmouse
++idt77252
++idt_gen2
++idtcps
++ie31200_edac
++ie6xx_wdt
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imm
++imon
++ims-pcu
++imx074
++in2000
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int3400_thermal
++int3402_thermal
++int3403_thermal
++int340x_thermal_zone
++int51x1
++intel-hid
++intel-lpss
++intel-lpss-acpi
++intel-lpss-pci
++intel-mid-touch
++intel-mid_wdt
++intel-rng
++intel-rst
++intel-smartconnect
++intel-vbtn
++intel_ips
++intel_menlow
++intel_mid_battery
++intel_mid_powerbtn
++intel_mid_thermal
++intel_oaktrail
++intel_pch_thermal
++intel_pmc_ipc
++intel_powerclamp
++intel_punit_ipc
++intel_qat
++intel_quark_i2c_gpio
++intel_rapl
++intel_scu_ipcutil
++intel_soc_dts_iosf
++intel_soc_dts_thermal
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++intelfb
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipwireless
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++iris
++irlan
++irnet
++irqbypass
++irtty-sir
++isci
++iscsi_boot_sysfs
++iscsi_ibft
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it87
++it8712f_wdt
++it87_wdt
++it913x
++itd1000
++ite-cir
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++k10temp
++k8temp
++kafs
++kalmia
++kaweth
++kb3886_bl
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks0108
++ks0127
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kvm
++kvm-amd
++kvm-intel
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l440gx
++l4f00242t03
++l64781
++lan78xx
++lanai
++lance
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-adp5520
++leds-bd2802
++leds-blinkm
++leds-clevo-mail
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-net48xx
++leds-ot200
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-pwm
++leds-regulator
++leds-ss4200
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++leds-wrap
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libahci_platform
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_cs
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++litelink-sir
++lkkbd
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lmc
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++logibm
++longhaul
++longrun
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltpc
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxfb
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac80211
++mac80211_hwsim
++mac802154
++mac_hid
++macb
++machzwd
++macmodes
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++marvell
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77693
++max77693-haptic
++max77693_charger
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mce-inject
++mce_amd_inj
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++mdacon
++mdc800
++mdio
++mdio-bcm-unimac
++mdio-bitbang
++mdio-gpio
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++mei
++mei-me
++mei-txe
++mei_phy
++memory-notifier-error-inject
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++metro-usb
++metronomefb
++meye
++mf6x4
++mga
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microread_mei
++microtek
++mii
++minix
++mip6
++mite
++mixcomwd
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmc_block
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi-laptop
++msi-wmi
++msi001
++msi2500
++msp3400
++mspro_block
++msr
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtd_dataflash
++mtdblock
++mtdblock_ro
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-sd
++mtouch
++multipath
++multiq3
++musb_hdrc
++mv_u3d_core
++mv_udc
++mvmdio
++mvsas
++mvumi
++mwave
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxc4005
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxm-wmi
++mxser
++mxuport
++myri10ge
++n2
++n411
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nci
++nci_spi
++nci_uart
++ncpfs
++nct6683
++nct6775
++nct7802
++nct7904
++nd_blk
++nd_btt
++nd_pmem
++ne
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++nettel
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfit
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni65
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_daq_700
++ni_daq_dio24
++ni_labpc
++ni_labpc_common
++ni_labpc_cs
++ni_labpc_isadma
++ni_labpc_pci
++ni_mio_cs
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicstar
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nmclan_cs
++nosy
++notifier-error-inject
++nouveau
++nozomi
++ns558
++ns83820
++nsc-ircc
++nsc_gpio
++nsp32
++nsp_cs
++ntb
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nuvoton-cir
++nv_tco
++nvidiafb
++nvme
++nvmem_core
++nvram
++nxp-nci
++nxp-nci_i2c
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_xilinx_wdt
++old_belkin-sir
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_cs
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p4-clockmod
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++padlock-aes
++padlock-sha
++palmas-pwrbutton
++palmas-regulator
++panasonic-laptop
++pandora_bl
++panel
++paride
++parkbd
++parport
++parport_ax88796
++parport_cs
++parport_pc
++parport_serial
++pas16
++pata_acpi
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cs5520
++pata_cs5530
++pata_cs5535
++pata_cs5536
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_isapnp
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pcmcia
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sc1200
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sl82c105
++pata_triflex
++pata_via
++pc110pad
++pc300too
++pc87360
++pc8736x_gpio
++pc87413_wdt
++pc87427
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcbit
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_can
++pch_dma
++pch_gbe
++pch_phub
++pch_uart
++pch_udc
++pci
++pci-stub
++pci200syn
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmcia
++pcmcia_core
++pcmcia_rsrc
++pcmciamtd
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcnet_cs
++pcrypt
++pcspkr
++pcwd
++pcwd_pci
++pcwd_usb
++pd
++pd6729
++pda_power
++pdc_adma
++peak_pci
++peak_pcmcia
++peak_usb
++pegasus
++penmount
++percpu_test
++pf
++pfuze100-regulator
++pg
++phantom
++phonet
++phram
++phy-bcm-kona-usb2
++phy-exynos-usb2
++phy-gpio-vbus-usb
++phy-isp1301
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-tahvo
++phy-tusb1210
++physmap
++pinctrl-broxton
++pinctrl-intel
++pinctrl-sunrisepoint
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl2303
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8941-wled
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pn533
++pn544
++pn544_i2c
++pn544_mei
++pn_pep
++poly1305_generic
++port100
++powermate
++powernow-k6
++powernow-k7
++powr1220
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_core
++pps_parport
++pptp
++prism2_usb
++processor_thermal_device
++ps2mult
++psmouse
++psnap
++pt
++pti
++ptp
++ptp_pch
++pulsedlight-lidar-lite-v2
++punit_atom_debug
++pvpanic
++pvrusb2
++pwc
++pwm-beeper
++pwm-lp3943
++pwm-lpss
++pwm-lpss-pci
++pwm-lpss-platform
++pwm-pca9685
++pwm-regulator
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa27x_udc
++qat_dh895xcc
++qat_dh895xccvf
++qcaux
++qcom-spmi-iadc
++qcom-spmi-vadc
++qcom_spmi-regulator
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qlogic_cs
++qlogicfas
++qlogicfas408
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quatech_daqp_cs
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r82600_edac
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-aimslab
++radio-aztech
++radio-bcm2048
++radio-cadet
++radio-gemtek
++radio-i2c-si470x
++radio-isa
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-miropcm20
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-rtrack2
++radio-sf16fmi
++radio-sf16fmr2
++radio-shark
++radio-si476x
++radio-tea5764
++radio-terratec
++radio-timb
++radio-trust
++radio-typhoon
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++radio-zoltrix
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++ray_cs
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++reed_solomon
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio-scan
++rio500
++rionet
++rivafb
++rj54n1cb0c
++rmd128
++rmd160
++rmd256
++rmd320
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-bq32k
++rtc-bq4802
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-hid-sensor-time
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-mrst
++rtc-msm6242
++rtc-mt6397
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-r9701
++rtc-rc5t583
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-twl
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7110
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7185
++saa7706h
++safe_serial
++salsa20-i586
++salsa20_generic
++samsung-keypad
++samsung-laptop
++samsung-q10
++samsung-sxgbe
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_sil
++sata_sil24
++sata_sis
++sata_svw
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sb1000
++sbc60xxwdt
++sbc7240_wdt
++sbc8360
++sbc_epx_c3
++sbc_fitpc2_wdt
++sbc_gxx
++sbni
++sbp_target
++sbs
++sbs-battery
++sbshc
++sc
++sc1200wdt
++sc16is7xx
++sc92031
++sca3000
++scb2_flash
++scc
++sch311x_wdt
++sch5627
++sch5636
++sch56xx-common
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++scx200
++scx200_acb
++scx200_docflash
++scx200_gpio
++scx200_hrt
++scx200_wdt
++sdhci
++sdhci-acpi
++sdhci-pci
++sdhci-pltfm
++sdio_uart
++sdla
++sdricoh_cs
++sealevel
++sedlbauer_cs
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial2002
++serial_cs
++serio_raw
++sermouse
++serpent-sse2-i586
++serpent_generic
++serport
++ses
++sfc
++sfi-cpufreq
++sh_veu
++shark2
++shpchp
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sim710
++sir-dev
++sis
++sis-agp
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skfp
++skge
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++sl811_cs
++slcan
++slicoss
++slip
++slram
++sm501
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smc-ultra
++smc9194
++smc91c92_cs
++smipcie
++smm665
++smsc
++smsc-ircc2
++smsc37b787_wdt
++smsc47b397
++smsc47m1
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1816a
++snd-ad1848
++snd-ad1889
++snd-adlib
++snd-ak4113
++snd-ak4114
++snd-ak4117
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als100
++snd-als300
++snd-als4000
++snd-asihpi
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt1605
++snd-azt2316
++snd-azt2320
++snd-azt3328
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmi8328
++snd-cmi8330
++snd-cmipci
++snd-compress
++snd-cs4231
++snd-cs4236
++snd-cs4281
++snd-cs46xx
++snd-cs5530
++snd-cs5535audio
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emu8000-synth
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1688
++snd-es1688-lib
++snd-es18xx
++snd-es1938
++snd-es1968
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-gus-lib
++snd-gusclassic
++snd-gusextreme
++snd-gusmax
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-ext-core
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel-sst-acpi
++snd-intel-sst-core
++snd-intel-sst-pci
++snd-intel8x0
++snd-intel8x0m
++snd-interwave
++snd-interwave-stb
++snd-isight
++snd-jazz16
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-miro
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-msnd-classic
++snd-msnd-lib
++snd-msnd-pinnacle
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-opl3sa2
++snd-opl4-lib
++snd-opl4-synth
++snd-opti92x-ad1848
++snd-opti92x-cs4231
++snd-opti93x
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm
++snd-pcm-dmaengine
++snd-pcm-oss
++snd-pcsp
++snd-pcxhr
++snd-pdaudiocf
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-sb-common
++snd-sb16
++snd-sb16-csp
++snd-sb16-dsp
++snd-sb8
++snd-sb8-dsp
++snd-sbawe
++snd-sc6000
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-sis7019
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-core
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-dmic
++snd-soc-es8328
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-ssi
++snd-soc-gtm601
++snd-soc-imx-audmux
++snd-soc-max98090
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rl6231
++snd-soc-rl6347a
++snd-soc-rt286
++snd-soc-rt5631
++snd-soc-rt5640
++snd-soc-rt5645
++snd-soc-rt5660
++snd-soc-rt5670
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-skl
++snd-soc-skl-ipc
++snd-soc-skl_rt286
++snd-soc-sn95031
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sst-acpi
++snd-soc-sst-baytrail-pcm
++snd-soc-sst-broadwell
++snd-soc-sst-byt-max98090-mach
++snd-soc-sst-byt-rt5640-mach
++snd-soc-sst-bytcr-rt5640
++snd-soc-sst-bytcr-rt5660
++snd-soc-sst-cht-bsw-max98090_ti
++snd-soc-sst-cht-bsw-rt5645
++snd-soc-sst-cht-bsw-rt5672
++snd-soc-sst-dsp
++snd-soc-sst-haswell
++snd-soc-sst-haswell-pcm
++snd-soc-sst-ipc
++snd-soc-sst-mfld-platform
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-xtfpga-i2s
++snd-sonicvibes
++snd-sscape
++snd-tea6330t
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-us122l
++snd-usb-usx2y
++snd-usb-variax
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-vxpocket
++snd-wavefront
++snd-wss-lib
++snd-ymfpci
++snic
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++softdog
++softing
++softing_cs
++solo6x10
++solos-pci
++sony-btf-mpx
++sony-laptop
++sonypi
++soundcore
++sp2
++sp5100_tco
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntpc
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_decpc
++speakup_dectlk
++speakup_dtlk
++speakup_dummy
++speakup_keypc
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++spectrum_cs
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi-lm70llp
++spi-nor
++spi-oc-tiny
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tle62x0
++spi-topcliff-pch
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spmi
++sr9700
++sr9800
++ssb
++ssb-hcd
++ssfdc
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++sstfb
++ssu100
++ssv_dnp
++st
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++surfacepro3_button
++svgalib
++sworks-agp
++sx8
++sx8654
++sx9500
++sym53c416
++sym53c500_cs
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink
++synclink_cs
++synclink_gt
++synclinkmp
++syscopyarea
++sysfillrect
++sysimgblt
++sysv
++t128
++t1isa
++t1pci
++t5403
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc1100-wmi
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcic
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tehuti
++tekram-sir
++teles_cs
++teranetics
++test-hexdump
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tg3
++tgr192
++thinkpad_acpi
++thmc50
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timb_dma
++timberdale
++timblogiw
++timbuart
++timeriomem-rng
++tipc
++tlan
++tlclk
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmem
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++topstar-laptop
++torture
++toshiba-wmi
++toshiba_acpi
++toshiba_bluetooth
++toshiba_haps
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_atmel
++tpm_crb
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_infineon
++tpm_nsc
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tscan1
++tsi568
++tsi57x
++tsi721_mport
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl-regulator
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish-i586
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++u14-34f
++uPD98402
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udf
++udl
++udlfb
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++ultrastor
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++usnic_verbs
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vboxguest
++vboxsf
++vboxvideo
++vcan
++vcnl4000
++ven_rsi_91x
++ven_rsi_sdio
++ven_rsi_usb
++ves1820
++ves1x93
++veth
++vfio
++vfio-pci
++vfio_iommu_type1
++vfio_virqfd
++vga16fb
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-camera
++via-cputemp
++via-ircc
++via-rhine
++via-rng
++via-sdmmc
++via-velocity
++via686a
++via_wdt
++viafb
++video
++videobuf-core
++videobuf-dma-contig
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videocodec
++videodev
++vim2m
++viperboard
++viperboard_adc
++virt-dma
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_scsi
++virtual
++visor
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_ca91cx42
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmlfb
++vmw_balloon
++vmw_pvscsi
++vmw_vmci
++vmw_vsock_vmci_transport
++vmwgfx
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vpx3220
++vrf
++vringh
++vsock
++vsxxxaa
++vt1211
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83627ehf
++w83627hf
++w83627hf_wdt
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83877f_wdt
++w83977af_ir
++w83977f_wdt
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++wafer5823wdt
++walkera0701
++wanxl
++warrior
++wbsd
++wcn36xx
++wd
++wd7000
++wd719x
++wdt
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++winbond-cir
++wire
++wishbone-serial
++wistron_btns
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wl3501_cs
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wmi
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x38_edac
++x86_pkg_temp_thermal
++x_tables
++xc4000
++xc5000
++xcbc
++xen-blkback
++xen-evtchn
++xen-fbfront
++xen-gntalloc
++xen-gntdev
++xen-kbdfront
++xen-netback
++xen-pciback
++xen-pcifront
++xen-privcmd
++xen-scsiback
++xen-scsifront
++xen-tpmfront
++xen_wdt
++xenfs
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xhci-plat-hcd
++xillybus_core
++xillybus_pcie
++xirc2ps_cs
++xircom_cb
++xor
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yenta_socket
++yurex
++z85230
++zatm
++zaurus
++zd1201
++zd1211rw
++zforce_ts
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++zr36016
++zr36050
++zr36060
++zr36067
++zr364xx
++zram
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/i386/lowlatency b/debian.master/abi/4.4.0-111.134/i386/lowlatency
+new file mode 100644
+index 0000000..d6c5241
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/i386/lowlatency
+@@ -0,0 +1,18882 @@
++EXPORT_SYMBOL arch/x86/kvm/kvm 0x1d58ff24	kvm_cpu_has_pending_timer
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x254e5667	scx200_gpio_base
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x35a3c008	scx200_gpio_configure
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x8cfa375c	scx200_gpio_shadow
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x907665bd	scx200_cb_base
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0x2d7e229d	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/acpi/nfit 0xa7e9a159	to_nfit_uuid
++EXPORT_SYMBOL drivers/acpi/video 0x6de7f7ff	acpi_video_get_backlight_type
++EXPORT_SYMBOL drivers/acpi/video 0x7a45377b	acpi_video_unregister
++EXPORT_SYMBOL drivers/acpi/video 0x8826c13b	acpi_video_register
++EXPORT_SYMBOL drivers/acpi/video 0xe92ca535	acpi_video_set_dmi_backlight_type
++EXPORT_SYMBOL drivers/acpi/video 0xeb5329a0	acpi_video_get_edid
++EXPORT_SYMBOL drivers/atm/suni 0x401a5270	suni_init
++EXPORT_SYMBOL drivers/atm/uPD98402 0xfab6f56f	uPD98402_init
++EXPORT_SYMBOL drivers/bcma/bcma 0x8f0be7eb	bcma_core_irq
++EXPORT_SYMBOL drivers/bcma/bcma 0xa61cbdbd	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x10c30b46	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x1e23c56f	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0x3c9fddfa	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0x3fc6c4f1	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0x4267110a	pi_register_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0x806b9e2b	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x8a43ce57	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x8d49a788	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0x9a451f8d	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xa6462b73	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xb21ba07d	pi_unregister_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0xb50453eb	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xcbceedf2	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xd08301f5	pi_disconnect
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0xb39deb9d	btbcm_patchram
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x0304952c	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x0f954a2d	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x11ea2250	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x2093589f	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78ba5231	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/nsc_gpio 0x5c9215a9	nsc_gpio_write
++EXPORT_SYMBOL drivers/char/nsc_gpio 0x8020f857	nsc_gpio_read
++EXPORT_SYMBOL drivers/char/nsc_gpio 0xd471806e	nsc_gpio_dump
++EXPORT_SYMBOL drivers/char/nvram 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x17ff2c1d	__nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x2adec1e0	__nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x7da28f12	nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL drivers/char/nvram 0xa8813189	__nvram_write_byte
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x15267636	st33zp24_pm_resume
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x3d681ce5	st33zp24_probe
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x8c3edadf	st33zp24_pm_suspend
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xb38e825c	st33zp24_remove
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x7aab1a6e	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x7eeec169	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xff25c058	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x18c02098	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x228a8883	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x38832cf5	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x3d7c3d2e	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x5958ece7	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x94f2624f	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/edac/edac_core 0x10e0610a	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04dd92ce	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0960f61d	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0d1fce3a	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0d71cfc0	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x21705eee	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2be96d41	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x31e1ac04	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x38d25da5	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4254bde7	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x49050267	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4d5d4eca	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4dbdec6e	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4ee2293a	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x52798b39	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x5d2c2d47	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x67f3d9e8	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x764ab2b0	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7d716969	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7e431b14	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x994a7895	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9a53a4e2	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa1273148	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa8b651a7	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xae12d769	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd02d0051	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd4306c2b	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd8090878	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xdda0d910	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xfa77c0c0	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firmware/dcdbas 0xa75079d6	dcdbas_smi_request
++EXPORT_SYMBOL drivers/fmc/fmc 0x3a8e7ee2	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x51ee6772	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x9a6e2bac	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x9ef5198a	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0xa13aef78	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0xa9ad20ca	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xb31617b7	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xbf305578	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xd9c98d4c	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xfc628c01	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0xfd3780d1	fmc_driver_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x00ef571e	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0194782f	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x01dcdad8	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x020e4003	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0378d665	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x03e86017	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x055abd39	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x05840532	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x05b8d919	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x05b967db	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06346d0a	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0731e874	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x07aa4b93	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x085392d9	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0abac7dd	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0abb83b9	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0c58e904	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0c5e547f	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0c888525	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0e239c7d	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0e6e9391	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fccafb1	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fe6ed9b	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x10d64f0f	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1108637d	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11c7b798	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12be2248	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x155076b7	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x15b0483b	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1716a6fd	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1921056b	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x196af515	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1b72a6e3	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1e1788d8	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x21160084	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x211b995f	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x212ed718	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x21ce0387	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x21db8a28	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x226a4c7f	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2552aa89	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x256c01e1	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x26a88729	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x283250c2	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x28f34d6c	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2b9a40cf	drm_agp_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2bd22dc8	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c2b33c6	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c994694	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d4dbb05	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2eb90b89	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x31843f78	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x31a94819	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x332afae1	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3346535a	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3406fa91	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x346127a7	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3613738b	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3860d3ab	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ad07b3a	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3af409ab	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b41ec0c	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b43600a	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d685a82	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3f3ff0a8	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x409b73dd	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4146a9fd	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x421e7393	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43f2ee3d	drm_agp_unbind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4577e740	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x46c04692	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48356c62	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48e3862a	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x49b34b42	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4a90e42d	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4aa0a5d6	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4b1928d9	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4b49ca6b	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4bc5a988	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4bf9774d	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d0eb1dd	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d9aa6b1	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4e7989f2	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4e90d36d	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x502ccced	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50acfb8f	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50d029d2	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x52764389	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54a04857	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x55ba1413	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5646d022	drm_agp_info
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5686f96a	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x595c239a	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59d87828	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a3171bf	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5b9715b9	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5c4aa7e4	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e440306	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5f6e908f	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6050b553	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x612a9eb6	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6279443c	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x634760eb	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x63bcec4c	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x64e4bc47	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6869b68b	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6870623c	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6a35d521	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6aa6da9d	drm_agp_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6c32d117	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6d7e5073	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6dbaea21	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e526f25	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6eca3353	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f4b4411	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f65a838	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f7d5a9d	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70bc818e	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x714427b4	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72f707ae	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x73111d62	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x738381e0	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74d3d2ca	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7554fc18	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7597d46b	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7607945e	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x76fb68cc	drm_agp_acquire
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x775fb78d	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x78863733	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x789a2cc6	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x793c04b7	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a1ccc84	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a34ea97	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a79b08e	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7ac08edd	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7e98d29b	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7e9b90fe	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7f650fb5	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x81c7ecb0	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82d4000f	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82f4d030	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8372a083	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x83d5ccd5	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x846e31a9	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x84c6a277	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x85b6b282	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x85e710d6	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x872a6b2f	drm_agp_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x877b9ec4	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x87915195	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x87bbbc1e	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x886186ec	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x89d43a77	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a12ccdc	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a549586	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a952d42	drm_agp_bind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8aeff398	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8cea7b31	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e9c9558	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ed26ded	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x904248af	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x90c76f09	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x93eea22c	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x941d50cf	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x94f96a50	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9500ccab	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9519780e	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x95bb71ce	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x95f54847	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9898e95b	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x99591329	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x997545aa	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a987569	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9aeec1ee	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9d0fdc71	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9db036c7	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9dfdff0c	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ef02de1	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f6a5749	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f845c1b	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9fa748f1	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa008fc20	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1a84864	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa22ada68	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa2fb477b	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa3577d5f	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa40b89c5	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa41232a5	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4bbc56b	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa55d44e7	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa6c80def	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa76a4b10	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa7926017	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa8321a7f	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa9b3bb85	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaa1f01b4	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xac4c89ff	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xacbce6b9	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xacca57a7	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad8fa785	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad96a7a1	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb345199a	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3b0a01d	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3f3da2d	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb4016c0c	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb4ad9ae1	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb4e1a180	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5dd0648	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb63a0af9	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb7996529	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb8d571e5	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbb96f6cd	drm_agp_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbbedec7e	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbbf611d8	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbdaed8df	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbdcdd0b3	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbede9f33	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc112406f	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc1af0cd9	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc33f36b0	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc388038f	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc388bdde	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc3be2810	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc4139973	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc66ec8e1	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc801a1c6	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcafacfe8	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb05a9f6	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcdbc88e4	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcdeb4f78	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf366d40	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf559249	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcfd7ed9f	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd13543cf	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd21af439	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2cd35d1	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd668a899	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd7809d0c	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd79e73f2	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd88695c3	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd88eef41	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd8ce7be2	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd8e8bf20	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdb2a389a	drm_agp_bind_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xde861cf7	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe06209e4	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe20ad490	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2951b52	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2c123e5	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe32ebf80	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe522d4ba	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe5fcd57f	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe756a8f2	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe78985a7	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe853da88	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe8936e2e	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe9e7f79d	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea0cc670	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea841aee	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeadce1f4	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xec98a58e	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xee2bf350	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef04e4e3	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf089f2b4	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0b618c3	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf19179df	drm_legacy_addbufs_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1f4e7e2	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf2cc907e	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf3a4aad1	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf4223fc1	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf4a848c5	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf4d28bf4	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf5d32902	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf7f36ca3	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf81e44ba	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf975813b	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb06be0b	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbf34871	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcc135b2	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd4d549b	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfdee2cec	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfe3bc0ae	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfe53089e	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfe564c0c	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x00cb73a4	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x01f6fe9c	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x03689312	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x050dec9d	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x057be9b1	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x078ca4e6	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x07eb36cb	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0c458d09	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0c9ffa4e	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0d55f526	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0e05fecf	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1009e205	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x170de0db	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1dea9c32	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1ebf1415	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1f11a765	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x209e64e2	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x22f21a33	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x27aee52e	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x27f848ca	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x29122722	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2aeff547	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3050fd20	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x31504994	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3170a8a7	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x324699f2	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34cac22b	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x350141dd	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x37265aa6	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3982706b	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x39ffbe9e	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3f4a20d4	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3fb5f34b	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x41c35eb2	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4336e314	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4456953a	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4ad4cb2f	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4b891de2	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x53081cbc	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x532caf24	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x54371c75	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x54fe48b3	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5563d315	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x55af14a6	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x55d4a828	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5f0071f2	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5faee6db	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5fd0089f	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x673e98b5	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x678f6cb8	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x681000a1	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x69c4ad87	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6bc5bc62	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6f971705	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x72fac4c6	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x763ff7c4	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x77269d6c	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7823cd97	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x79047a50	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x79bcf372	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7ad546f0	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7c0b2203	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7d6db50f	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7d98ac08	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7e741202	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8355bb0b	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8564f969	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8611be2d	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x86963a2d	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x87271994	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8ba58cf4	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8d6bca23	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8ef5f238	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x90c9bfa0	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x90ec0b2a	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x915e918a	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x91f6ac76	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x925534dc	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9345ac2f	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9727022e	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x97a63954	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x97f36b52	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x98e90136	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x990af3ba	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x997c624e	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9a1eac14	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9acb1887	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9b8126f3	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9dc8173e	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9dda9be2	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9de1f55a	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa324916b	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa381690d	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa59bd22a	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa5c01a30	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa7593beb	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xadc16772	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaf082ea3	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb03eeaaa	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb27afeea	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb2bae9cd	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb2c834ea	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb30c78ce	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb66299d3	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xba132ef8	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbabead3a	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbac20408	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbac960a3	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbdd3aaf2	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc542c883	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc5d53fab	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc66f96f6	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc7355429	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc79781af	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcd21fd9e	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xce4b0a57	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd09bfdc7	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd205c9ad	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd3055841	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd347e9c6	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd3f40404	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd401bef5	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd46e0942	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd489157b	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd67860d1	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd74b6d89	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd95eb273	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe13bbe78	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe1ed34dd	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe269ba05	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe45a489b	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe47f0b4f	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xea157bbf	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xea4ea020	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xec0d350b	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xec6be356	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xed5b9ba3	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xef2b434f	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf27893d9	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf4d71099	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfa992398	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfe499c16	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0786c948	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0a554b9b	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0b3ca9c2	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0bab7f47	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x125f9ce7	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x129ef82a	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x132b05be	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x13b222c2	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x13b55807	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x18007b2d	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1940e4cd	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1b108bf2	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1c9ab4bb	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1d64d7fa	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1e9b14ab	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x22ec80fe	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x24765c33	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x266d8a60	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x296363a7	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x29896ad9	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x35c98dc6	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3a669144	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x41b2a672	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x42d7f49f	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4400f2c1	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x49428a0f	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4acc5369	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x50e7c500	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5544d753	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5cf59609	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5fc73d90	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63978d02	ttm_prime_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x67b1d568	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6c8dc6bf	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6e875de9	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x709d01a3	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7f432728	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7fcfb138	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x836d8fd0	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x86f66b82	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x946d9ea3	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x96b9c739	ttm_agp_tt_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9f71c725	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa05ac44a	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa203fdd4	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa25c2f32	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa336e156	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xaccd1776	ttm_agp_tt_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb8484f85	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbea1c151	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbfa7c2b1	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf49f835	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcfb88d90	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd222a9bd	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd458b926	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd5aee78c	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdcaf5a10	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xddf9aef1	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdeab016c	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdf66f11b	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe45be179	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe61220fa	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xec803aaf	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xefaa0bd0	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf13f8ee5	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf4ce7c51	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf84446bf	ttm_agp_tt_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf94e0b72	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfb6348bd	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0x1f9beb8d	vmbus_sendpacket_ctl
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0xa5e8fffb	vmbus_recvpacket
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0xdda3eeb0	vmbus_sendpacket
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0e2a6864	sch56xx_read_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0f5877d4	sch56xx_read_virtual_reg16
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x34257f35	sch56xx_watchdog_unregister
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xa7449de3	sch56xx_watchdog_register
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xe5022f95	sch56xx_read_virtual_reg12
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xed1d2a08	sch56xx_write_virtual_reg
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x18b35baa	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x9faae56e	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xf74b033e	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x80af12d0	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0xf55ff127	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0xe09684d5	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x0212eec3	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x12e79b38	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x2027e45b	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x4b00130c	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x4c84a437	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x5f53e532	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x61a2c73c	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x643ea0eb	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x6e487a30	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x7121e1db	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xa1ab752c	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xb2ec82c3	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xc64ea742	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xd2298aea	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xd50377e3	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xe990bbbb	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x3058babb	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x73dcace4	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0xc71f5023	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0xdd3bdc2e	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x5da5ecab	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x78519145	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xc00c70ed	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xcae0e70e	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x52d676f7	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x53a0abcd	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x7e3f609a	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x7e65a7c7	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x830d383b	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc3bf6760	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x2a2fbf26	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x52c3407a	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x539b02b6	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xc83f16b3	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x17f1d760	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x213288c0	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x70259fac	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x78389c23	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x928114f4	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x96ba5b80	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xa1ce1f98	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xe51de647	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xff59cf6b	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x34cc9011	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x3d0890dd	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x6ef27eea	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x7a9d2a71	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x9e475cce	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x010c4d8a	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x570336ee	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xb9ad1d9d	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x00f563cf	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x1547b941	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x2298a4f5	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x381d5496	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x49d6411d	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x63e5e6cf	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x685d130f	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6b294c90	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6fef62d2	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x817bbabb	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x86908e3a	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x9c18b51b	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xa99d7ac3	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xcf574c0a	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xe9b43e68	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf4a17d34	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xffab34e6	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x220ba7ec	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xa43b8fcd	st_sensors_match_acpi_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0x381a4fce	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x1d75f98b	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x33e3766d	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0x06edb8b9	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x31824099	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xd2885227	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/industrialio 0x0878c91c	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0x13a58582	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x2754fc2c	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x39c69ac7	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x40fd02e4	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x44adb759	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0x47adc4c3	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x4824cdd5	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0x60cbaed3	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x650e341a	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0x7bdfb185	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0xbdd67049	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xc83aa868	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xcdfd8805	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xd86793bc	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xe4074c9d	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0xf729f6a5	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x5f26e0d1	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x701e830f	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x35b1deea	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xf57c8955	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0xc670d102	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x02f01503	st_press_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0xb6543ff5	st_press_common_remove
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1edc4064	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x41fc25f9	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x49b7c327	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x4ae67dc3	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x9d9cabc5	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xf23af65a	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x17206ec3	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x183098b1	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x22b45b14	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x386f2061	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x601e0aeb	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x653928a0	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x95558e12	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x9d4d7218	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xb963de80	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xbd9c75f9	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xc421fa26	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xccf51e88	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xdbf3a476	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xe0f85ad1	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xe2078f1a	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xe4e287ae	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xe999662c	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xebc62571	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x08ed600a	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x091b466c	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0dab003f	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x12c633f6	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x138e4f49	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x14e66a19	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x14ec0ca8	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1743e105	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1af6bf5b	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e09ead1	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x235ee920	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x24bc4d8a	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x26a61003	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2c917961	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x386f0b71	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x38dade8d	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3993dbfb	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3fddec51	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4044243a	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x40fbf473	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4582419f	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4667d501	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x48a3c390	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x492e295b	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4bb47cb4	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4ca7a128	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4d200a00	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4d48dd56	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4ede0b4f	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x501eb4c2	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x520b2638	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5369bab2	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x583c9f1d	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x58e8165b	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x58ed7316	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5c87e614	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x64a62aae	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6b5bfd44	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6fb9e3de	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x710ead01	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7c8377ac	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7fbdefdd	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7fcb1615	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x82430b18	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x835fc082	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x858e5942	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x863f0ed1	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x867f2cad	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x87879113	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x87f6c393	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8fbb379a	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x907f3538	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9180c040	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x967830ef	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x972204b0	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9769f05d	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9945f1b3	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9fcab11b	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa4691e93	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa71bc4ac	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa86933f6	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xae257779	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb1a312e1	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb288795c	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb3717f8c	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb375f069	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb55d3dab	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xba5e4b3b	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbb315a98	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbb4bf190	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbb6dcd9d	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc8c80eed	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xca63483a	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd3cedb78	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd4734b26	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd7f405f2	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd8573516	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe2d5aac5	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe4741f64	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe494c361	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xea7644b6	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xed842156	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf5868d6f	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf98d2ef1	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfe001e60	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x151c707c	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x550cdc94	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x56b9172d	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x597d3efa	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x72290d83	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x78db8b04	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x887d2b4d	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xa0f5dc87	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xb80e14d6	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xb8f23096	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd1452146	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd2ddaa8f	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xdb38786e	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x05f51c4a	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x070657a4	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x2666aac7	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x287d1e73	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x75519871	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xb230d5e2	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xbbca13cd	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xc5c40334	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xd57fae4b	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xdefc3e7c	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xfea90769	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xa21a11b1	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xc244710f	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x1d99ab8e	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x24e091f1	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x29c55284	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x38b79ddf	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x41ef0942	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x50a16402	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x56f71888	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6334beb4	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6d3d35f1	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x71bd6ffa	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x7ce852a3	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x81404a17	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xaa373f7e	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xc52e29ef	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xe2fc6ad8	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x20a73667	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x29f1b514	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x31fc67d7	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3427e3f2	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3ce90280	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x48de2de5	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5f596bd2	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x6661d7dc	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x6c3905d6	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7085df72	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x723cd12d	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x780de9f4	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x85d09629	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x998fa7d1	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x9cb870da	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x9d4a5fd0	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xc8bf86ef	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xcc0d1043	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xcc1867fa	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xdab54cc1	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xecb15de9	rdma_reject
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x2ae6523a	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x32102c88	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x4adbbf1a	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x78176dea	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x7b71592b	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x83037707	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xc00980ba	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xd3389da4	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xf21c451a	__gameport_register_port
++EXPORT_SYMBOL drivers/input/input-polldev 0x1b634b9c	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x532947ae	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x64c3216f	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x6def1805	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xe77c0b90	input_register_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0x1e333dbc	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x3d2a627c	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x924c25a5	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xdd597253	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xa42ccd9e	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x02ad5256	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x3a1af925	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x861a0b49	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x88550b5b	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x98472136	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xc3f8892a	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x547708bd	ad7879_pm_ops
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xf23099e7	ad7879_probe
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x029455bd	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x097e92a8	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x24f6f625	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x522c970a	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa2e9a619	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa38241d4	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa7c4fd6c	capi_message2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa86250e4	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb772099f	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xbdb3ba4b	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc10fe128	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc6efe9d7	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe8ad9bd1	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x074028d5	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x0a160cb7	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x14e40393	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x2c9f96b9	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x3bedf6cc	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x58dc68e5	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x5f0d300d	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x7f27f824	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9824941f	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x990e7c5a	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xbc09f09b	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xc7273f65	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xda0fc9fe	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xeb7bbb31	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xf2259076	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x17319639	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x2d9572e6	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x375b8b49	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x43bbb6ee	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x56179763	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x643eabf1	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xb295083c	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xb767b7f3	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xbb759037	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0x29562993	b1pcmcia_delcard
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xaec3240e	b1pcmcia_addcard_m1
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xea620116	b1pcmcia_addcard_m2
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xf14bf8b1	b1pcmcia_addcard_b1
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x0127f048	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xaa0fb6db	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xb65f556c	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xb89bb2ab	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x6d5328cb	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x95030ac8	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xe40a8a14	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3584ad2d	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x57cbe502	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x69cda056	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xc4202874	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xeeb3679a	isac_irq
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x46cdb791	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x8943f929	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xc2e99f2e	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x201979ee	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4cf19fb3	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4f0bffae	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x54c295d6	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x5aca2edc	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x61d785da	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6228f9f7	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x79d06d3f	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x82926197	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x862b2399	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x87a61657	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8b6a758b	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8b75aad6	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8c049ca0	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8ea579ab	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x9c331e54	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb2c07610	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb2fe4679	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb435e24b	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb64aa00d	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xdeeda3f3	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xed1ccaf3	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf8265f3a	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x0aad5ab2	closure_put
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x10c8cf2a	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x10dc0d06	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x66d28e22	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x6969b5d8	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7b55ca4f	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7f2a56c0	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x889d88d5	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x9dd90f94	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x9e8b3cee	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xab2d2b84	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xad29a6f5	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaec09a2b	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaf77343c	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xc04554f7	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca580595	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe47e0829	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xecf7cef9	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xfbf30701	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-bufio 0xa7978f56	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-log 0x4380302f	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0x5e570e04	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-log 0xbafb9887	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0xc2b34f26	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x14fd02aa	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x26c59930	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x3c7ec269	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x55679fb0	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x615bc68c	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x8837d03f	dm_snap_origin
++EXPORT_SYMBOL drivers/md/raid456 0x70896d32	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x2744d09a	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x7e1b8f81	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x906703c4	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x9dff9b3b	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xac02f7e0	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xac0fd580	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xca084ae1	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xd561043d	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xe6b90889	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xe7c6e5f3	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xfe00462d	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xfe6b7502	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xffda8ea4	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x5b15369c	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xbffceb03	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xe27d5b58	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xf2ebab08	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0x46a7320f	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x4849922f	tveeprom_read
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x4c8fe217	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0a49d99f	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x16e3c215	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x17ffc7bd	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1e5f0bdd	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2907e8ed	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2cf288a0	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2eca698f	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3ee8cfed	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x48eae2f5	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x499b79be	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x49b50c9e	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x56a33958	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x58c0b3ca	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5a6f883d	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x62452eda	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6367c49f	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6ed50b51	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6fc6213c	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x70de704a	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7d2d1d4c	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7e693aec	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x93b1fad6	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x94d9e087	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9ab4d06a	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9e553013	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9efdce53	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa898c6d8	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb6dbd8d5	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc16835b1	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc3ac6c86	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc645fbc3	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc775d912	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd9cbe3cc	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe167fe57	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe92ee976	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xea5fddbc	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xebd38af9	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf663edbc	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0x0a5aa631	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0x300f1ab7	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0xe97e240b	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x28e7027a	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x802cfb12	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x842079e9	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x8c189aa9	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xb7e34b50	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xbecf6f76	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xd4d496f2	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xebb45f71	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xf8f87f2c	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0xde91a2d6	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0xb773df24	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0x5c9a2078	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0x998fad68	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0x9303eca4	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x1dabdd80	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0xc4b99411	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0xfd78f1f5	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0xa0a40427	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x2eae65c7	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0xe33dc386	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0x6eeb836d	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x668a6560	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x74d85678	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x8cc90fd4	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x874862c6	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xb43c1ac9	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xb74f5676	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xf29ff3dd	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xffce308d	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x060af8e8	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x117e8b0d	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x2b50b1b5	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x4cc71266	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5a1002cd	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5c7a1bce	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x68b6a9c6	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x79ca7bcf	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7dc5a781	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x814352b9	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x92a4be85	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xb9b72919	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xca9dace4	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf4002c40	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xfcd7e9d8	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0x8837df61	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x0da92736	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x1cfa1d00	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x26adf483	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x7620a064	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x86ee3993	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x9d9a93c9	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x85d2cfbf	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x96be66e6	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xe44f3a68	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xf46a7383	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x4e0fbd11	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x367c8410	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x02d5bc6f	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x61d59d1c	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x8b2a195d	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xd68d2c25	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xd9cc098e	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0xbdc5d82a	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0x63d252f9	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0x694f6164	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0x6f781581	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0xdf17493a	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0x654fd89b	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0x089d33ce	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x2d39a3ac	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x3e8aa93c	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0xd4ce127b	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0xf67be251	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0x28a1d696	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0x48a3a7d8	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0xe51e4ca5	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0x3d3e02c6	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0x4388e6ad	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0xbe40c2cf	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0x545bc660	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0xe036fa30	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x27336f42	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x4cd32a3c	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0xc8c9ac39	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x120a7b78	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0xd56dd4fd	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0x30dc67b9	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0xe9247621	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x2a0c337d	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0x9e60568b	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0xbc711ef1	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0xaa661f7e	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0x5b1b7da8	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0x11b8ef4b	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0x19bc8b60	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0xb236e823	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x7d71ae5e	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x737239f4	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xf87e332a	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x1c5c1c79	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0xfc57e993	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x26d8cfb7	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0x3b04bb45	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0x68b17984	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0xca60d743	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x869e7bfc	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0x296a86f6	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0xfb044581	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0xd7550b23	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x4eb686e9	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x89979699	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x8aceae83	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0x2638da16	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0xac273bcb	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x0ea6216a	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0xdf6f8f9b	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0xfa6c4ccd	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0x1abc403e	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0x00dd9d33	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x1d47dae3	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x2952728b	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0xa641bc05	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x9c8916ae	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x31202024	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0x9081b9df	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0x46b877b8	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0x6ab43527	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0x4d54e63d	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0xa99b7069	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x2bf5f38a	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0x1aae051e	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0x6638ac7d	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0x15978397	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x32a82496	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x839a8b21	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x9ce01346	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xa4bece4a	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xb41ffad2	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xb80c85e6	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xc0a88005	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x08f45329	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x58a66a81	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xb17f3cd5	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xf239095c	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x5a1a7ba1	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbc72b615	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xff39986b	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x206b5dcd	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x2c6cf7d3	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xa72e7f85	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xb702eae4	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xb83f80bd	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xc19100c6	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xd6dba3d6	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xda976e0e	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xfc1f3b3a	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0xd1be1b0d	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x1ec79a55	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x90ac5032	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x99c54235	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xa3269a84	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xb619de61	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdbcd9d37	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x14eb8f60	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x427c2f94	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x6d5b9ff1	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x93cdbc85	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xb58bdaa7	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xb8b64d30	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xff26d5ec	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xa2327eae	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xe6a01e7b	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x1371c527	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xa97d85f3	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xe27e2fc2	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xe6a23aed	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x0c8563e8	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x10562f71	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x35b57c8a	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x963c7292	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xa7c47a13	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xc71a4f71	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xd9503b66	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x016635f8	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0d5e50a1	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x14e32d43	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x27e9601d	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x371043f6	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x50a5bb2d	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x56cede3c	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x64ef0625	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x71829013	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7ebb910e	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x93f0df6c	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x99862280	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xad99d0ea	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xadfabfa3	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc5c863ff	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xdbd0c437	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xdd5574cb	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe26d32bf	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe952a36b	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xffaf1405	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x118e46a1	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2034454c	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x21fe44f4	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x37904a4b	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x444c383b	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x59c0ec96	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x63a95f24	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x65940ec6	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x8ea54d35	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x9a529edd	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x9c2da8f9	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xbdbd2a42	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xc424d014	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xc5864b0d	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xc8147780	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xf4c059ff	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xfbdcd9c0	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1458061f	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1c8374e9	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x2f66af80	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x34add0b5	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x40ddbfc4	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x4b80f76c	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x751a8664	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x9f14d0c2	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa6c0d3f7	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xe3d20558	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xe8ce6229	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xf2c0d12e	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x4e35e01e	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x8c1496cb	videocodec_register
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x9683adc5	videocodec_detach
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0xe357e02a	videocodec_unregister
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0xfed84a20	videocodec_attach
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x39d7348b	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x3a8d8f5a	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xa1735df8	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xabe85eb2	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xb3ad16cd	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xc8b138f4	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xf5c9e3dc	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x0fd8a208	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x3387926c	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x41c15956	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x509472fc	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xabdf7c0d	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xc3ff8bbf	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xd258fa6a	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04e4e6d9	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x30b6e946	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x469f6e6c	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x8679b35d	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xc3e569eb	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xc81a9bac	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xcea63f86	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xf6252ab2	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x47f9e2f0	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xdf3c4574	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0x6d94bfd2	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0x89d82b90	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x62199c59	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xb96c5a39	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xf41e5ebe	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/max2165 0x1a5f68a3	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0x60844edf	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0xcd05dcdf	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0xf54d6bfa	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0x7a0130a5	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0x5ab2d8cc	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x03ae338f	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0x9f8339f3	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x21c5eac2	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0x41cbf070	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0xdb94e32d	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x1d5516e1	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xda54adc0	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x0e15c7bf	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x324346a3	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x4660ce15	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x4b99a829	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x5433ee8b	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x5714c45f	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x6711b60e	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x8d5310a0	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xedc5c315	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x0029481a	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x5d6a4cbc	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x7501d36c	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x758e0a24	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x76383c88	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x96bab935	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xf9192e1a	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x53c5fd05	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x02474210	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x37bfe390	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x42dacdd9	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x5394bf24	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x56128349	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x645f7f07	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x6d9515f8	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x80a0f6d9	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x9c27daf6	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xfa405847	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xfd59642d	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x95a100d1	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xb21698df	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x0e06ee89	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x1a331f1e	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x21e8a939	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x2c5edfba	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x3afb42d7	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x4054beca	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x82ff67e7	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xc238fb2b	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xd5437176	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x0b7e11d7	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x12f9165c	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x30897cd4	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x788a0ee5	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x7db0ad63	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x935aa015	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xe28567e7	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xfa43ea01	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x1edc1078	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xcabe08d8	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xf1a56a60	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0xc853c1f7	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0xe394c03d	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x6d1bbbb4	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xbd2c43f7	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xcab7ecee	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x1fbfd1d3	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x2f412e8d	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x69f93ffc	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x6a551cd6	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x8a729964	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xd023ce3c	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x55604f15	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x8d31ccf0	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x7abd44c8	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x85fade72	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xa3fe692f	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xa8e38200	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xb14f322d	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xdeb364da	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0xfb9fe58a	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x00dd69f2	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x00f76d03	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x01b43f0f	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x080d3a53	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0b52ef46	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0f3ffc08	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0fef90e2	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x18f42278	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1956ea9f	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1c1cfbba	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1d44a76a	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1e6c7e84	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x33c32097	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3965d665	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3f107abc	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x44bd1fc0	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x48849811	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4a9a66b3	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4aa68a99	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5118c8e0	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x56c0a823	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5b95ad30	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x628f0a68	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x63137ae9	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x64c039b9	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x701beb66	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x728d7db0	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x769173a4	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7cb86ec9	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7df8a301	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x80ef5bba	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x864b402b	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8a7a0513	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8ced444c	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8ef577d0	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x918f9f0c	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x91d78c7e	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9530e34e	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9805e2ce	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9f2593d5	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9ff57dc8	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9fff3886	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa6cab48c	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa8238560	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa98ef9f5	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xaa16bee5	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xaa869520	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xab6aa6fb	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xab7197f5	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb04f834c	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb3ebcfbe	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb57a8e58	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbd9e4a61	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbf9586a7	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc505da30	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc5acd259	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc74aea1c	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc87274b5	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc8b545d0	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd0f05815	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdde1db4e	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdf9e6571	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe04e6080	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeac15c57	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeb26daac	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xec67db31	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf0818a8a	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfad5b655	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x28370d01	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x2c85bbce	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x4385d3b5	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x4aa48cb3	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x53283779	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x854eed86	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x8de070dc	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x91913956	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x9ccfce14	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa35b78be	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa5987a36	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xdab7d744	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xec5e9159	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x0198449d	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x04ec99fd	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x0f886781	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2024b65f	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2ca325aa	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3dbe2437	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4041d3f4	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4b59a97d	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x52bb776a	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x55c885a8	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x56fe2ea1	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x5bc9ebfe	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6d5dcb08	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x76e51846	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8a4711b4	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa932fb21	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb5de0973	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb68c131e	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb7fc633e	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc3d799ce	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xcd1dc0bb	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd005f0f3	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd3f4757	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xddfb54e9	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xde01bec7	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe233ef61	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xeb7d594a	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf58ee94e	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xfa29802f	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0cf89f97	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x111dad99	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1936c7a9	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1ef18dc6	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2051dad0	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2ec24410	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x36b19f7d	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x3c4b3f7b	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x43e15c41	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4f4445c7	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x68a350f2	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x6a1266d3	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x6c140581	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x738e2c24	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x82ea7565	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x84827f34	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x8a1e3388	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb529ff7d	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc79c22f9	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd0db1dd6	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd4714e95	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd490fba2	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd7275658	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xeda7bb26	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xeff5e78e	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf25ea152	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf61c30f3	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x1b1b12e9	cros_ec_register
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x53cb4b3d	cros_ec_remove
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x756e1de5	cros_ec_resume
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xa12b000b	cros_ec_suspend
++EXPORT_SYMBOL drivers/mfd/dln2 0x27cc598c	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0x78b5224e	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0xc5b9b94e	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x7e4972c8	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xac460db2	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x20a3cefe	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x64486857	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x6f452efb	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x83ae153e	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x90c371ea	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x9f6fffb3	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xad3d67f6	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xc2a78203	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xd8a7ab46	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xe4cede4d	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf7dfaead	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x6658b9ad	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0xdc9f969c	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x4aacf648	wm8994_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x77a7fdf8	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x78964dd1	wm8958_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xe7f44ffc	wm1811_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xb5412eb3	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xce7db532	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x075983d1	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0x7084fa08	c2port_device_register
++EXPORT_SYMBOL drivers/misc/c2port/core 0x79285fdf	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/ioc4 0xd68f99e4	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xfa8ec537	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/mei/mei 0x0b3c2389	__tracepoint_mei_reg_write
++EXPORT_SYMBOL drivers/misc/mei/mei 0xafdfce69	__tracepoint_mei_reg_read
++EXPORT_SYMBOL drivers/misc/tifm_core 0x25f085a0	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x269d2bd7	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x351074a3	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x39f86aa1	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0x463c93bd	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0x484f2ba2	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x4d6e535c	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x5c1dcdae	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0x87af00f4	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xcbb4329c	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xe3a3f9c0	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xe82229a2	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xfdc9d79d	tifm_add_adapter
++EXPORT_SYMBOL drivers/mmc/card/mmc_block 0xcafaf0c6	mmc_cleanup_queue
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x26e7fe29	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x30f02f46	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x41220309	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x4f12395c	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x5e626ff2	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x8178c520	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xaa652db1	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x17b690f9	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x7431ca21	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xb9f3e519	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xd34a804a	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0x4e630935	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0x600b741a	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0xf40e8482	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x5c0d0af9	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/mtd 0xe6911604	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x07bbf2a7	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x762ef0be	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x2708442b	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x3908b311	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x52c2ea66	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x5dd52915	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x802db298	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xa850c4aa	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x2899f1fd	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x4c6e2df0	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xca5756f5	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xf5624758	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xf8f36d67	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x1c9a9abf	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x8937f514	onenand_default_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x94837732	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xaf5e7763	onenand_addr
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x0c13c76d	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x150a7f6f	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x3317b261	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x38bd87f5	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x495999eb	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xa63bfe42	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xbf88562d	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xbfa400b1	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xdeb7010c	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xe9abe347	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x6b103606	com20020_found
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x7c6c7c0d	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xa193c051	com20020_check
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x00e01b9f	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x150fa70a	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x27896459	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x6159039d	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x76bbe9a1	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x81e39e06	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xe23ab810	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xeff642e8	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xf66a7246	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xfe526e85	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x09a9662c	eip_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x233f850d	eip_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x5a914513	eip_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x5c067ff4	__alloc_eip_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x88e7a4cf	eip_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x9470b128	eip_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x95523da7	eip_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x99c03fd7	eip_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x9a0b5757	NS8390p_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0xa50e9905	eip_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0xd8a30b9d	eip_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0x33cfa64d	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x9627a446	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x0c1f413d	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x1c572b6f	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x1e9b5b53	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x34846b8b	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x36dd7159	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x384aa9d3	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x3dc300b0	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x6e91689e	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x831529af	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x85bcdf15	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xa441590c	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xa9f0313c	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xc14629cd	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd6eebf7f	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xe4175a6a	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xf09729f8	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x123baef5	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x153f0ec2	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1d4b718f	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x264669cb	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3273364c	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x35d51ca9	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3d5f8373	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x57707dfc	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x5b21207b	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x661a6af1	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6bff3a30	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7167875f	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x75728383	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8006675b	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x853313b7	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8635a134	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x871f2d09	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8aa3ee5a	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8cbb52c3	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8da992eb	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9519506d	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9b2df65f	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa445b307	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xaed9933b	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xaf7a4d2b	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xbc48d585	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc8051aa8	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd81199fc	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xdf659087	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xec29c9d2	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xedad6185	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf6f93e62	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf9c65e58	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xfe333f6e	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x31e97fbf	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x54d8514b	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x58436498	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x6ae86d26	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x9f508463	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xc2b85fad	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x79b6bd7f	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x85f021eb	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x031b80f1	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x049a131c	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0f8a59e9	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x40c59fc5	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4ca84eee	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4f5c4f42	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x515c641a	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x55230c74	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x60e23f14	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x646c8176	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6a459ad4	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6c98b37c	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x73e35a52	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x76739da2	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8bfeb04a	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8ead3758	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x91903dc9	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9565c902	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x96251507	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9cd682c9	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9de65066	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa408f848	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa6d05a40	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa998cedc	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa9d1f42e	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xac5c0c33	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xba49d051	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbfcbe6c8	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc121f749	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc4a1d44c	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc7030494	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcef92e41	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd4535885	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd47d8619	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe90a3393	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xeaabe892	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xebae9396	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfaab6e19	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x01965cdd	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x05060540	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x15d55e45	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3255a73b	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x32db18ef	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3feaa985	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x42b46fb1	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x44b1d45d	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x46915e40	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x46f3bfd6	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5d019a47	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6bca3e33	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x71d212cc	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x71d5fc22	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x75bad477	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x77eb783f	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8ffda502	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x94bf4630	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x95fccd07	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa112ffba	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa750ac31	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa7b003e3	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa9c35fd4	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xaee6d378	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xaef30ecb	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xaf53d396	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb2f0aed0	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbf49da30	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc3feaf66	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc528a3ec	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc6a57a56	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd24a79c3	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd33d4677	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd8435430	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe4623961	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe46c8366	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfcdf1604	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfebeeb3f	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x4a2a4597	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x7995964e	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x87c09654	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x8f7f70bd	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xb70bad67	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xcb5c8545	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe27714b8	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xed7cf89c	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x1e0f3276	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x0472df57	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x1f803393	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x32738950	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xb8c3f218	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xc065af74	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x32ec02fd	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x7054f55a	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x92b8e055	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xb4939081	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xd756da1e	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xe9a2f20d	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xf146f4a4	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xf17887ab	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xf6446a57	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xf69e37b1	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x1a1b0dae	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0x2263afb5	mii_link_ok
++EXPORT_SYMBOL drivers/net/mii 0x317ca811	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0x63b42007	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0x6cb4703a	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0x930c0911	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0xc35eb1ab	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0xcfc3b329	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xb1ce0985	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xd0d517fa	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x0488ab48	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x07da191a	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x71d371bc	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/vitesse 0xd10b9fd5	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x2ca7960e	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x5a2a4f47	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x7b529306	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/sungem_phy 0xc2b6f075	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x05e8d9f2	team_mode_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x146e8071	team_options_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x4f7c26b9	team_mode_register
++EXPORT_SYMBOL drivers/net/team/team 0x6f2a483e	team_options_register
++EXPORT_SYMBOL drivers/net/team/team 0x89505cce	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0x9505f3fc	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/team/team 0xe961cf56	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0xf595d542	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x050935f5	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x0f8204b8	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x2ace6de4	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xbdc040c4	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x19b77659	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x34a89722	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x41fd5c8d	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x4ce18bae	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x778e5667	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x9970af6e	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xa37e16a1	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb94fb24e	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xce7e7d09	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xd5fe7ccc	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe55f1eb3	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/z85230 0x10c78988	z8530_dead_port
++EXPORT_SYMBOL drivers/net/wan/z85230 0x2485b17d	z8530_sync_dma_close
++EXPORT_SYMBOL drivers/net/wan/z85230 0x2fd32d6f	z8530_sync
++EXPORT_SYMBOL drivers/net/wan/z85230 0x3277e74f	z8530_nop
++EXPORT_SYMBOL drivers/net/wan/z85230 0x5cd24d29	z8530_hdlc_kilostream
++EXPORT_SYMBOL drivers/net/wan/z85230 0x758788d4	z8530_sync_open
++EXPORT_SYMBOL drivers/net/wan/z85230 0x80404293	z8530_sync_dma_open
++EXPORT_SYMBOL drivers/net/wan/z85230 0x94788657	z8530_null_rx
++EXPORT_SYMBOL drivers/net/wan/z85230 0x9a9ddb58	z8530_channel_load
++EXPORT_SYMBOL drivers/net/wan/z85230 0xbf5c4caa	z8530_queue_xmit
++EXPORT_SYMBOL drivers/net/wan/z85230 0xccc8a284	z8530_sync_close
++EXPORT_SYMBOL drivers/net/wan/z85230 0xcff4d41e	z8530_shutdown
++EXPORT_SYMBOL drivers/net/wan/z85230 0xd4ffebf0	z8530_interrupt
++EXPORT_SYMBOL drivers/net/wan/z85230 0xdf297a18	z8530_sync_txdma_close
++EXPORT_SYMBOL drivers/net/wan/z85230 0xe3d80064	z8530_hdlc_kilostream_85230
++EXPORT_SYMBOL drivers/net/wan/z85230 0xf8c742cc	z8530_sync_txdma_open
++EXPORT_SYMBOL drivers/net/wan/z85230 0xf8d25297	z8530_init
++EXPORT_SYMBOL drivers/net/wan/z85230 0xfacd5c03	z8530_describe
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0xfb75de01	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/airo 0x565f1ca3	init_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0x8501c59b	reset_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xd8f20797	stop_airo_card
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x33c02f01	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x43aa8021	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4f01b84c	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x5a7825c9	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x6ee30523	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xa449587c	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xbebba983	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xcb6d24bd	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xd6ce4322	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xebf01832	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xf6092098	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfeddaf09	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x0779f6b0	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x14145b2b	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x2087e70b	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x228ff2dc	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x2b47d147	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x2c2942f0	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x3b8a1e54	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x462ebc25	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x7de306ba	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x80ed90e9	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x93a5ff4a	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x9e7b28bd	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc577957e	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xd2364155	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xfe11df4f	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x1475a61b	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x15c7c52f	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x2f98b18d	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x3972f90b	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x5469560f	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x8f715ac3	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc3a0f1fc	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xd429877f	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xdceed900	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xed4065e5	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xf63781da	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x37b13741	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x5189c9e7	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x5468e90b	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x5718edfe	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x5ce9a8ee	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x6422a6f0	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7a3b99ed	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x83a88a9c	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x85930da1	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x907fd112	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x943f7611	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x94975497	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x99b607fc	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9b2b7f7e	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xace9c1fb	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xadc7eb70	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb3a29e96	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb5131b2c	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xbd742879	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xde6bf973	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe207fc9c	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf44f620f	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf98f6979	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x018b163c	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0348b830	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x04d91bb1	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x07030c95	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x07f1452c	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0b377b38	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1932a1f7	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1a2957c4	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1b2bc779	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1b393fd2	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1b73d13e	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1cbcda38	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x21be0d21	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x254962d6	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x25aa5348	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2a744865	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2b7184e0	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2fac69c8	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x314899ee	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x33497e3f	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x334ddaef	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x353213e8	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x36cf65fe	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x37dabfe6	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3a8a538d	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3bd5207a	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x42ecf6dc	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x43a1c6f7	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x482a4710	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x483a8ffe	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4bca9b3d	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5215c9e2	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x53b84faf	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x55287b6e	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x598e3fa8	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5c371843	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5d44961b	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x606f6ad4	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x61dc7c46	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x625f3eac	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x63dfa1d3	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x651a258e	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6920618b	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6bda0fc4	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6f1a7fe1	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x75c08c91	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x788311ca	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7b6e1da5	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7c648261	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7e0747d2	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7fb80972	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x80409204	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x806fccfb	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x82cff39e	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x87c595b2	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8a4078cf	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8ec04faa	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x91cd6598	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9603ed82	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x96418a36	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x975e8cf5	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x98996a8f	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9a403f78	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9a92c9c7	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9ba5d843	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9e6feb54	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa1c4b606	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa29c5ff9	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa56f5d1e	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa6913daf	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa7f8fccf	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa8589047	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaa760315	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xab56fe69	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xad7e930b	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xade22ae1	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb046d96a	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb05fb469	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb5ac8208	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb8051364	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb8b9b3e0	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbd7e3c7b	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbdafbd6e	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc123bf12	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc1637695	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc1ef9e26	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc20a6a14	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc2f787a6	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc49a2f19	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc652a3a0	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc7ff8509	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcb8041fa	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcd2b053d	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd0e93a92	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdaf14f53	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdd58b9e3	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xde9548d8	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdfde7fbb	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe01b6107	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe1a6e3f4	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe434a336	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xef962845	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf351e38a	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf67e7a98	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfbfdbd44	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x57cf8783	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xb9781d2b	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xcecd9339	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x00b7f0c3	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x0ada1d4e	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x21a44efd	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3cff1b26	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x460b1ef2	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x49c15451	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x8743b4d2	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x99d02ef8	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xcd17e071	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xcf929d81	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd0ee8cf6	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xedfa7e4a	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xf0d8da96	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0664b781	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0ad69602	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1b99c933	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x2172c827	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x2995864a	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x2ff05244	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x322e3ab5	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x33f3cf14	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x38ee9aa5	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x3cc139be	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x4ad13399	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x54513eb3	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x6187c594	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7ab5c132	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x995bbdeb	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa7552d78	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xafb18091	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb78ef9f8	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb9245874	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc0a1f9e8	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc4eb68e2	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc7e50dea	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd0fe1929	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd1b5ddab	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd8fd73c3	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf61f238e	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x03674b88	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x0a6a8ba5	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x0b996ce3	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x0d4edac1	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4cf939ca	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x51bd76d1	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5349f349	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x55fb19f1	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x616883ec	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x731dfb98	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x8596f5f5	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x8b638472	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa541c85a	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xad9bfb95	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xaeaac9b0	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xaff47128	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xbd63ada3	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xc1f2dff2	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xc67f3647	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xebf0563b	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf9c996e1	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0094ac35	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x039ae62e	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x056a30ff	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x05b8523e	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x079a24ae	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x07c4f0ea	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x08d76343	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0970d7d3	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0db0d668	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x109c2709	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x10fb0e10	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x14fdfaa8	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x17a880c8	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x17d19248	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1c0a51e6	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1c478b79	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x21e32afb	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x23bfe710	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x241948f5	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x28b1295b	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2c6af284	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2fe8a716	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x33034e95	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x357d404c	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x36adc257	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x370b0653	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3a9e5cab	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3f2f118e	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x41308bc9	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x43b8adc2	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x44e234fd	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4a1731a1	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4bc34463	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4c8924a8	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4f7b475a	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5031ece7	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5489e4db	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x561aacdd	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x572005fb	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5828648c	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x586f5053	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x58aa6d89	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5d8e7ff8	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x61856cbd	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6288ef3f	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x62b80084	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x63e89aad	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x667147c3	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6a9ad996	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x709e5133	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x72ba7463	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x75e8439a	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x79da68e9	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7baf5ec8	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7f6c2f16	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x81b01507	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x81c76270	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8aa02da9	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8af856c7	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x971fc24f	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x98274c4e	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa2128ac3	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa264533e	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa910451c	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa9388e9b	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xaa4079ff	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xac1d9fad	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xad0d4059	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xae1c8b31	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb0bd9fba	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb801a252	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb839687a	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xba853079	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbdd56c44	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbfaeb3a4	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc5a6a5a2	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc696c5e8	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xccd8968d	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcd8fe392	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xce6b3f14	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd6fc9471	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd90ff6f0	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xda2df7c6	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdd13a661	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe01e7111	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe07b6231	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe801853b	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe855bca7	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xea4a5ae3	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xea851a72	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xebea9f60	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xeca9563f	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xee6228ff	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf2ce1920	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf3e78834	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf76c1da0	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf81d4532	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf980d855	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x08c6664d	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x4379786d	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x95a8ab3c	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xa2b6ec39	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xb69add1f	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xcd60e86e	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xd4f50457	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x02cf7fcf	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x09d0e32d	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x182e1cb2	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x1da32eb7	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x218be794	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x31aa4f2f	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x548a424b	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5fd55857	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x601bd734	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x76b48afe	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x7c62a55c	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x818e52f0	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x8ac77c01	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x9bf94567	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xbda454d3	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xc18b9783	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xd8f2a90c	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0xe453b33b	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x00e95704	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x02d15ee8	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x071e0685	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x134131da	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x190790f7	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1eae9323	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x23241cef	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x32407992	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3686a29d	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x37dea02c	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x395f1837	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x40686688	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x460e3cbc	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x50755e9a	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x548d2550	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x563c4d93	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5d5d4f06	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5f3f1a9f	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x60d40cf5	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6305fb55	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x69531a67	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6adde167	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x716fc6cc	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7d7325c6	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x857c2223	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8623c444	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x89e52b81	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x89f4584c	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x967439f5	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa163dbc0	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa3c4dcef	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb13e3254	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc42b3b4b	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xcc6e31ce	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdf843e6a	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xec1efa71	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf1c89c2c	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf9f42421	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf9fa8f90	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xfc920167	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xfcbc5a69	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x40328f3c	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x6a37c06e	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x9af34843	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xb79c402b	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x129afb37	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xa34ec727	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xcb9fedb3	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xcd32f048	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x139a988c	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x18045fb6	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2da75da8	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3080cb50	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3b833874	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3bf8522e	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4e7e0ca6	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x55743955	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x588c0540	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x592311c9	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5abf6373	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5d1f14a7	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6545545b	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x72469b61	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x745460b9	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x907c2014	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xaa7af1d3	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbb0fa38e	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbc370260	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd0371d72	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd1c8e6c6	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdba143d5	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe09dca19	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe67bbd04	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xedeb1181	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xee99031c	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xeee7ef7c	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf3e7f6a4	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x633de1d4	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x6c636562	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x7d698293	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x92db69e1	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x4a505b27	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xbc64f083	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xe642dd84	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x335c61b7	microread_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x6b7ee2a0	microread_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x12dc866c	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x58e82966	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xdc5cc8eb	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x7537e3ef	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0xe960ed95	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xb254304f	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xcd3fbc38	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xd7156b5f	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x02372c20	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x09246c8d	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x20e98055	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x2156d3c8	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x23c4f33b	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x288f0a9d	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x443c1496	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x81cd1fd0	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x8ded3572	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xb6d7ee7a	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xc173e715	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x11422bec	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x242d6302	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x2a3df72f	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x34075b71	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3721e964	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3a600a98	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x4533d1ca	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x5261b354	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x5a928593	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x726b490d	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x890a9093	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x9a26b24c	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x9c28ee83	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xc82230a3	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xced4e8b4	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xcf1114e5	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xe5df59c3	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xff459bee	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/ntb/ntb 0x0d0224d7	ntb_unregister_device
++EXPORT_SYMBOL drivers/ntb/ntb 0x3f8cb9b6	ntb_clear_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0xa29d5a45	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xa314d688	ntb_db_event
++EXPORT_SYMBOL drivers/ntb/ntb 0xaac01846	ntb_link_event
++EXPORT_SYMBOL drivers/ntb/ntb 0xc98d9a27	__ntb_register_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xe80b148d	ntb_register_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xee114ba5	ntb_set_ctx
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x8978ccf6	nvdimm_namespace_detach_btt
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0xa0e56ab4	nvdimm_namespace_attach_btt
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0x743fded6	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x03b23025	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0x173f717f	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0x1a2eac8b	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0x1cd474b8	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0x1fee9881	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0x2614b90b	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0x312b1508	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x37e3a89a	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0x3e861aee	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x45fe1ea5	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x61e190f3	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x76170e88	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0x7c373c7d	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x7df41e68	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x8a450373	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0x8c008c19	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0x920336a0	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport 0xa3d607c8	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0xb2653585	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0xb5284e8e	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0xb52e6061	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0xb6993d67	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xb700edb5	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0xb70aaef7	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0xb887382b	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0xc9391454	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0xcc16ee07	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0xd0540c80	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0xdaacc6c0	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0xdfaa1b08	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0xfb851412	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xfbfe248b	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0x9b7497fe	parport_pc_probe_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0xefcf9e8f	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x02bef5c8	pcmcia_write_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x05dbe35a	pcmcia_loop_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x0f055000	pcmcia_get_mac_from_cis
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x198145bb	pcmcia_get_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x2ae71a3d	pcmcia_request_io
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x36509b12	pcmcia_fixup_iowidth
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x43c401b8	pcmcia_map_mem_page
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x44e084d4	pcmcia_unregister_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x51af1393	pcmcia_read_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x5cfceaa0	pcmcia_disable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x6c75ab7a	pcmcia_dev_present
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x742f5665	pcmcia_parse_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x8a78a950	pcmcia_loop_config
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xa3dfb65e	pcmcia_request_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xb4f7125b	pcmcia_enable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xb8a44700	pcmcia_request_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xc41f0f57	pcmcia_register_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xd077ae42	__pcmcia_request_exclusive_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xdb9c81d3	pcmcia_fixup_vpp
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xdfdc6aac	pcmcia_release_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x212db8d2	pcmcia_socket_list
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x2a789498	pcmcia_reset_card
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x2d4e0526	pcmcia_get_socket_by_nr
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x38ff41b1	pcmcia_put_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x4130682a	pcmcia_socket_list_rwsem
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x4221ce98	pcmcia_parse_events
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x42a8675d	pccard_register_pcmcia
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x4bc1c0c3	pcmcia_register_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcf97f3bd	dead_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xd2a30166	pcmcia_socket_class
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xe3a6af49	pcmcia_get_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xf43442c6	pcmcia_parse_uevents
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xfe838636	pcmcia_unregister_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0x1459a677	pccard_nonstatic_ops
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0x2ef14ed5	pccard_static_ops
++EXPORT_SYMBOL drivers/platform/x86/intel_ips 0xf97d7d0e	i915_bpo_enabled
++EXPORT_SYMBOL drivers/platform/x86/intel_punit_ipc 0x3a0b563a	intel_punit_ipc_simple_command
++EXPORT_SYMBOL drivers/platform/x86/sony-laptop 0x5bb1e117	sony_pic_camera_command
++EXPORT_SYMBOL drivers/pps/pps_core 0x42a86a80	pps_event
++EXPORT_SYMBOL drivers/pps/pps_core 0x4c073131	pps_register_source
++EXPORT_SYMBOL drivers/pps/pps_core 0x793175ec	pps_unregister_source
++EXPORT_SYMBOL drivers/pps/pps_core 0xca409f1d	pps_lookup_dev
++EXPORT_SYMBOL drivers/ptp/ptp 0x04c04967	ptp_clock_register
++EXPORT_SYMBOL drivers/ptp/ptp 0x1f18cd36	ptp_find_pin
++EXPORT_SYMBOL drivers/ptp/ptp 0x40831ab5	ptp_clock_index
++EXPORT_SYMBOL drivers/ptp/ptp 0xa3862727	ptp_clock_event
++EXPORT_SYMBOL drivers/ptp/ptp 0xac6f619d	ptp_clock_unregister
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x1501f165	pch_ch_event_write
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x26751936	pch_ch_control_write
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x2f9d9821	pch_tx_snap_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x318e479d	pch_ch_event_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x46e0dce2	pch_src_uuid_lo_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x73f51c2d	pch_rx_snap_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x93f882b9	pch_ch_control_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0xa2eb621b	pch_src_uuid_hi_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0xed0699c5	pch_set_station_address
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x0ed66c77	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x11fb4017	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x13a47c03	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x19efe51d	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x4fa882c5	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x69532bcf	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x6a6f4e36	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x73a0e9ca	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xb2b0abe1	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xffb7d8a1	rproc_put
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0x149069ac	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/53c700 0x0ce3425a	NCR_700_release
++EXPORT_SYMBOL drivers/scsi/53c700 0x3d9cece0	NCR_700_intr
++EXPORT_SYMBOL drivers/scsi/53c700 0x598c41b2	NCR_700_detect
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x0527986a	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4c798822	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xa0562488	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xe829e5af	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x1969df36	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x20afd9d6	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x26201f1d	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x307b734c	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x38b400e6	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x5b454776	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x6d06b9d2	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x70c8aa8c	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x7b48615e	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xa3e1c26e	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xefb358cf	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xf7422d03	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x06ca172d	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0be1aec5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x13ab7fd7	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x14718517	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x168ec0fb	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x17a0d919	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2b110724	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2da4312f	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x340dc65e	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x343c3eb2	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x35d834c0	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3b8cd275	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3d21b66c	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3f37abc3	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5c58428a	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x60d07673	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6168778c	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x616b2065	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6caca925	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x709085b9	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7165ef3f	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x76930406	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x84343d1d	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8597defa	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8914908b	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8a0d6b98	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x929b9e40	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9417019b	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9a1d5167	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9c7fc73e	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa559416a	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xad0a013b	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb043cbf2	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb2da2e78	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb3017c24	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb8a3cfbc	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb9f6e569	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xcfae2221	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd0a5964c	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd3a03483	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd6310c60	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdb10b1b8	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xddea1b2a	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe4c7256c	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe5f6cd0e	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe6871817	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xea5f6551	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf27d299d	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf7cc27e0	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfdb5db87	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x3e14c713	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x4ce0ccb2	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x6cb56052	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xe5af747c	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x0ecc56c7	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x02177a8f	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0ede7216	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1a1e40e3	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x26e437ca	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x2765d81c	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x29da2e5f	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3d2f7f32	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4101c5b6	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x43395753	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x525a97d1	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x552c2b00	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5715ab93	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x71c40810	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x77415f3e	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x78e77e09	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x80ab8d1f	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8383ec15	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9355e7ec	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9dc3d781	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9df0aa3c	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9e27a484	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa25bdc36	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa3525b1d	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb041f293	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb6150470	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xba6a06e1	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc33dd6c5	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd63ca6d0	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdf56e889	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe16c2f5a	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe27f8d7d	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe576fb9e	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf0efc362	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf1098e84	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf480634e	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfde4556b	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x2b096cec	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x7d9ed383	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x911904e3	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xbc23f129	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xcff5484a	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xea4467db	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x189b0827	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x1c2bcaac	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x2f830902	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x3312ffd6	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x494125ec	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x4e565505	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x627c8c57	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x6dbf4e5c	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xa56ef5ea	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xd4cc08d1	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xd8368690	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xf511db3a	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x1f55cd70	qlogicfas408_ihandl
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x35b2dfbf	qlogicfas408_disable_ints
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3fd8cd71	qlogicfas408_detect
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xc3f77836	qlogicfas408_info
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xce2085b3	qlogicfas408_bus_reset
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xd7eef9bb	qlogicfas408_biosparam
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xe76b3b20	qlogicfas408_get_chip_type
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xedfc15a3	qlogicfas408_queuecommand
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf155cf88	qlogicfas408_abort
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf2b95199	qlogicfas408_setup
++EXPORT_SYMBOL drivers/scsi/raid_class 0x51685716	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0x8a72e438	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/raid_class 0xbc434008	raid_component_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x22b2672f	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x2eec2237	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x55b10f29	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x5965b5a3	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x5f96cb3c	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x76733460	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x825b24de	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x85749295	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x895f718d	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x9d6de2d2	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xb8f509c7	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xc9026ac6	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd5b865c6	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x109f7cad	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x17df13d8	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2cddfc83	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x3160c033	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x34c921d6	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x350d1631	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x39f198de	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x3b2163fe	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x45e96724	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x47c66fa6	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x48920256	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x504e29e6	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x50fbd4a3	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x50fc912b	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x69b3fa91	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6c6496a9	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6fc176a2	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7a69f754	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x93c9c51c	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xaa6ce254	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb13c7df8	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb22333d3	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb320fd14	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb5875b51	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xba148f3c	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc2081297	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xca972e87	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xdd42073f	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xfb17a817	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x088ac34e	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x2fc60029	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x52e8f5db	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xb4343ce1	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xb677fc0c	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x58620444	srp_start_tl_fail_timers
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x58f551e7	srp_rport_get
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x996dfef6	srp_rport_put
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xad11a985	srp_reconnect_rport
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x28701233	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x486b0a90	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x7dc50c78	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x9544383d	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x9acdfdf0	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xacb1e4c2	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xd57ffc1f	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x005e7613	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0x0102a3af	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x13ed44a2	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0x1da71834	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0x2d88af7f	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x30f596b2	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x31acf85b	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x40ba7d94	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0x61b58d37	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x7fb49c9c	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0x86b4ab50	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x8c6824af	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0x94e30c28	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x9969ea4d	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0x9aa8ffef	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xd38bc3f7	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xd7ce8018	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0xedc123e2	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0xf2c2180c	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0xf90a83fc	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x00c15dca	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x03e0b64e	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x2dc00046	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x38ffb52c	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x3c030c5f	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x4cb25dae	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x5185f206	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x5f32d331	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x60b1bd00	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x75292435	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x7c5782c0	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x7e867bda	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x8f32e516	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x8fbdfd72	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x9e6e9e78	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa2f59650	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xad293e72	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xc526da04	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe3cdc399	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe72b9dd5	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe9b9d496	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xee038256	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xef8a04c9	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xfdf4cac4	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x5b2b1aea	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x5c464ed3	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0xfc98e738	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x0a8da026	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x56b2aa63	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x753e403f	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xe15bda42	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x6b010522	ade7854_remove
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0xdb2310ff	ade7854_probe
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0x01163761	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0xd10d933c	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0524ea60	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x090b6e82	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x11b2cf17	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x15e697de	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1807f5a9	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1d028693	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1d2f6e41	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x23cd6742	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2ba56479	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x31f07965	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x32028e35	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x35417cde	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x35856f7b	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3e87ea60	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x45e69267	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x49a8047b	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x56a82285	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5b9197ff	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5ff02993	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6145a827	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x63da730f	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x64244e57	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x67f7bcd3	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6b4396e8	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6c43d5bd	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7308c2d1	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x77636809	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x79aaa815	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7dad416b	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x82acac78	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8e9bccaa	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9fe97b2b	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa269335c	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xab452e5c	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb5e8e1f1	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbbc05e40	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc27d3f08	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcb1bdefd	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcf21c4ba	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcf58a14e	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd0d1d974	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd8be3be5	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe91c42b6	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xed48293c	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xef32fb96	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf062e6df	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf31c01e6	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfc232682	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xff4f9879	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xffcc74ff	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x041ee992	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x04fc1fcd	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x06f4ed9b	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0e3375a5	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0ebee892	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x16521243	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x16c557b1	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x17bf5132	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1a62f952	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2965d30d	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x30f455a2	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x348a09c9	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x37254e6c	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x38993b8e	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x404094ae	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x46f24a56	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4bc48642	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x59179fe3	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6508682e	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x65f4555f	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x69ac313c	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6b6b8696	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6c02fce4	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6caa9227	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7158fd35	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x72207e2a	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7cb0fe11	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8d92762d	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x92037f7b	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa02a22e3	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa0e13fdb	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa567e8a1	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa7120298	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa835e250	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaa9fe56a	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaaf8edab	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xafced947	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb185f554	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb1b3ae6c	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb6038383	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xba887607	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc558c217	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xca26d27c	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcc665163	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcd9cead8	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcdb3be33	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcf4c2491	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd0a32b47	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd19cc71a	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd3f09612	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd939a276	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe1e09e64	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe51c5703	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe769bd3a	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf57316c2	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x1428208e	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x163da662	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x1804bc5a	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x182e747f	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x1d99387b	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x1f52f887	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x35fec63d	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x376e789e	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3d24ddc3	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x477a30fa	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x47cdb815	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x48f97eb8	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5ffd8309	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x65ddb85f	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x66afb7be	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x67d94614	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6a6f145f	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x76726f95	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x82058115	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x87e2e0a3	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xad0de6b9	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc4fea85e	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xce6ce21a	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd45e285d	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd753a68b	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe9b9cd98	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xea951903	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xec89f280	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x00a077f3	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x048b2220	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0x097f027a	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0d37fea3	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0x13afd1f1	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x163771a9	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0x23a10d01	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2871dc17	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3150b849	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3284b999	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x33064daa	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x349d47ea	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3c327026	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3c32bbed	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3d29bb34	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3fc1a990	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4361d26f	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x481adf5b	transport_init_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x49808d7e	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4b2ee1db	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x57526153	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x59878989	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5da1c1ac	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x69be0e8a	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6a6a96f7	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6c0bb69e	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6d4fe900	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x721d9bfd	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0x73c6e1f6	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x750a9463	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7f34db07	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x833e3f3a	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x83b32a5f	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x84a5a6e1	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x92ba14d5	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9423b479	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x94e94558	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9ce0b7f0	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9d00f865	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9e191757	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa16215f4	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa64f4dd0	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa7db5b00	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa83076b5	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa86cabc1	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0xaa764b18	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb5233840	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb60d832e	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb67bf888	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb78fec4a	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xba652422	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbbe41f8c	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc205ec9d	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xca9f9dd7	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd046a303	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd1846047	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd1cbfced	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd662de02	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd8d83869	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0xda191b20	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdf478d23	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdf9662e1	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdfe9a605	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe22d6e07	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe788e3a3	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe876bb40	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf021e46e	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf6cda978	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xff46fcc3	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x1887763e	acpi_thermal_rel_misc_device_add
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x5007fc2c	acpi_parse_art
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0x86c998e6	acpi_thermal_rel_misc_device_remove
++EXPORT_SYMBOL drivers/thermal/int340x_thermal/acpi_thermal_rel 0xdf707fab	acpi_parse_trt
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0xdf29cac6	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0x602c4496	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0x86dc1d94	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x2f54e9ea	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x3770f686	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x4218f3ec	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x55cceb08	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x7913055f	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x808988b1	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x83e6e5c9	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x9725d283	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x9a609906	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xaf11b597	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xdc6dafd3	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xe9671014	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x342ae1e3	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0xc821a03b	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x2e91ca97	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x367ce26a	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x59f824d9	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x7bda5e6d	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x821e9390	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x937e412c	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x14fc8613	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x2efe24fc	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x886730fd	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xde71eb76	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x24b41eae	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x37daaf54	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x5d850d52	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x7dd8a073	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x870dc5ab	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xbffea04b	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xce052bca	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/core/syscopyarea 0x5bb05c14	sys_copyarea
++EXPORT_SYMBOL drivers/video/fbdev/core/sysfillrect 0x3c0d7889	sys_fillrect
++EXPORT_SYMBOL drivers/video/fbdev/core/sysimgblt 0x2f71b7af	sys_imageblit
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xa0589f8a	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0x92f754d4	mac_find_mode
++EXPORT_SYMBOL drivers/video/fbdev/macmodes 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x2a11d9d5	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x6df2fc40	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x6ff69e8e	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x5ce97cda	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x68f878a9	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xa0a69f73	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xaf992884	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0x72c7b817	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0x9986c01f	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x21924dfb	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x2a748db5	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x926e8bdd	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x9a707344	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0x8fb17e01	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xa1f8e186	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x0d063e11	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x178f7105	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x1d5ed134	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xc422adea	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xe4a923ce	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0xf0343979	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x028ea21c	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x1b97e56e	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x1d667bc1	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x208970a4	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x7d8668fe	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x804635f9	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x2ec1eeff	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0xffea1811	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/wire 0x64ea102d	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x75bab976	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0xae272826	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xe3fb7ede	w1_register_family
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0x04e133fc	iTCO_vendor_check_noreboot_on
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xa78bd894	iTCO_vendor_pre_set_heartbeat
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xb5f20875	iTCO_vendor_pre_keepalive
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xc4f657bf	iTCO_vendor_pre_stop
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xdc6effc9	iTCO_vendor_pre_start
++EXPORT_SYMBOL fs/configfs/configfs 0x0de2b3c0	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x1cafaaca	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0x2d9a4f92	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x366c489d	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x39d1d8b8	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0x3e312b15	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0x52836844	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0x63fccae0	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x6b23394b	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0x7121ccbd	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0x7ebcbb39	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0x8c974535	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x9cf5adc1	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xa2d8a47d	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xb7723c64	configfs_unregister_default_group
++EXPORT_SYMBOL fs/exofs/libore 0x05deda7f	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x065bb31a	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x2bf3104a	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x46778982	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0x5f1ba5d9	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x729aab62	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0x78a50f5c	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0x9beb8f91	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xa6eef7a1	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0xef5017a2	extract_attr_from_ios
++EXPORT_SYMBOL fs/fscache/fscache 0x0ab98cc2	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0x102abbe6	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0x2851cf39	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x33d1f4fc	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x3805161a	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0x3c8c3d94	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x3cce5ea3	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x3e054b96	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x3edd1ca0	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x41df90c1	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x4577b615	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x47840a7b	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x47ab1702	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x58794427	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x64551923	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x69276bf5	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x6b87f8e4	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x6bc63a9d	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x72999a01	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x75c61203	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0x7a03fa2f	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x820547f8	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0x8696d16f	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x86bceb69	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0x8c328c00	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x8d36c8d5	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x937d92c2	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0x9bdf323e	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0xae0d8587	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xb37f680f	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0xb90a1f11	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0xc071e0b3	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xc6fe0899	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xcbe3a322	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0xcc1d0a05	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0xcce30fb2	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xd82a6675	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0xf7eabf26	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0xfc434525	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0xfc987d3a	fscache_check_aux
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x084dd91a	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x4ba4b345	qtree_read_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x7a1c6313	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x8d5379af	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0xe02013d5	qtree_write_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x3771b461	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc-itu-t 0xf5b4a948	crc_itu_t
++EXPORT_SYMBOL lib/crc7 0x66213969	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0x41248eaf	crc8
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x03f599c7	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0x2ba1031d	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x3161ec94	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x4feade4b	lc_create
++EXPORT_SYMBOL lib/lru_cache 0x56fc3ea0	lc_put
++EXPORT_SYMBOL lib/lru_cache 0x619ed575	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x84e0214b	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0xbbe7c23c	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0xc48fa976	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xc6e4cd46	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0xcb990a55	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcea6747e	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0xd212c9f0	lc_get
++EXPORT_SYMBOL lib/lru_cache 0xeb13128b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0xf460a486	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0xf5ea5f5c	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0xf6acec20	lc_find
++EXPORT_SYMBOL lib/lz4/lz4_compress 0xcbc5d521	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x26c3aa22	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x3c1ec137	lowpan_nhc_add
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x3dfcb8c1	lowpan_nhc_del
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x91c03d19	lowpan_netdev_setup
++EXPORT_SYMBOL net/802/p8022 0x2a3057f5	register_8022_client
++EXPORT_SYMBOL net/802/p8022 0x9457567f	unregister_8022_client
++EXPORT_SYMBOL net/802/p8023 0x33327409	make_8023_client
++EXPORT_SYMBOL net/802/p8023 0x9248de6e	destroy_8023_client
++EXPORT_SYMBOL net/802/psnap 0x1c8ca0f6	register_snap_client
++EXPORT_SYMBOL net/802/psnap 0x40402a5c	unregister_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x02933d87	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x05c8ea34	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x183774e6	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x19468218	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x1a37c7e9	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x1c18e1fe	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0x1d4a88a7	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x21cbe22a	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0x273294e1	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0x2ac05f0a	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x460a483e	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x4ce918df	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0x4ee6e87a	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x52dc1295	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x588b4006	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0x61986e41	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x6cb375ea	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x74d0d678	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x76c3b4d2	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0x7ea8ff45	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0x7eb08f63	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0x7f8ef1b9	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0x803fae82	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x84bd9697	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0x87e8ea89	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0x8b5e14ca	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x9db36c5b	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0xa4eb7406	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0xa7abb8a5	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xaa9245ae	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0xafc657c1	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0xb33ddf0f	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xba31ee9d	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0xbb66291b	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0xbc66bd04	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xc9dcea8e	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xca1fcf9e	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0xd2bff864	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xd5b6fc45	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0xdd7a3755	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0xe549a8b3	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xebc952a5	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x05c14f28	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0x07e53198	aarp_send_ddp
++EXPORT_SYMBOL net/appletalk/appletalk 0xb67b33a1	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0xcdc7bc72	atrtr_get_dev
++EXPORT_SYMBOL net/atm/atm 0x16b8091b	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x6b4ab68e	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x6cc1e94d	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x7027544a	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x8ddbfc86	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xa592ec0f	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0xa5a29705	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xabcbc92b	atm_charge
++EXPORT_SYMBOL net/atm/atm 0xbd9dec99	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0xc61952b2	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0xdfebb69c	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0xe9b7f80a	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0xee7dd0b9	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xef199016	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/ax25/ax25 0x1ace2e96	ax25_ip_xmit
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x4471e00c	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x4ba74a5f	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x5f3b1288	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0x9a9434f0	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xdcb75c29	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0xdd0527cc	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0xfdd392c8	ax25_linkfail_release
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0354a9e0	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x04074133	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1459238f	bt_sock_wait_ready
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x14adbec0	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x15f05189	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1753d290	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x213d4298	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2617a5c2	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x267105a8	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2cb00ffc	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2d455e2d	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2fa78057	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2fb4cfab	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x314d9e11	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3ca089b9	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4352a0d0	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4496a225	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x54d0ea01	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x5923252d	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6db982ee	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7007815e	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x710cfb03	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7d8ac289	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7ef01bc9	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8ab4b431	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91ca805a	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x929f93c9	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9c861d0d	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xae9ad6d1	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb87d01b5	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc700245c	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc894080e	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc8b31f36	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd388f88e	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xdc5dc7af	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe610b97d	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe782434c	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe8444ccc	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xeeb863c7	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf6933413	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xfe8b9c70	hci_conn_switch_role
++EXPORT_SYMBOL net/bridge/bridge 0x26a27796	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x038abbfd	ebt_do_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x890c0f5a	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xb55b76d7	ebt_register_table
++EXPORT_SYMBOL net/caif/caif 0x10872ccf	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x348fd312	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x5a84382f	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x8831ece0	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xed48c11a	caif_enroll_dev
++EXPORT_SYMBOL net/can/can 0x326e911c	can_send
++EXPORT_SYMBOL net/can/can 0x511d6040	can_ioctl
++EXPORT_SYMBOL net/can/can 0x679e6b17	can_proto_unregister
++EXPORT_SYMBOL net/can/can 0xa6683bdb	can_rx_register
++EXPORT_SYMBOL net/can/can 0xce5351e7	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0xfceb7bcb	can_proto_register
++EXPORT_SYMBOL net/ceph/libceph 0x04f5abeb	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x0575d380	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x061b14bd	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x067897f9	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0af0ee4b	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0x0b51992c	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0x0c49efb1	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x0d957745	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x0e56aa09	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x0ef32157	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0x141739c2	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x1862aad9	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x1961e153	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0x1c5b2a4f	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0x1db6c5e8	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x224ee5f3	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x287021b1	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0x28db2273	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x2be04870	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x2ca5878a	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x30857328	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0x34863752	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0x3710ab4f	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0x3aafcd84	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3c02369a	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x3ff2de82	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x40236c9f	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x41a9a21a	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0x42d9be28	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x45211915	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0x453f984d	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x467c11d9	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0x47a9920e	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x47c06000	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x518f1ac0	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x5449ad1c	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x5ae23743	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x5fcf3af4	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0x61749bbb	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0x6245f050	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x630ce8c3	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x6aba9225	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0x6b0d6876	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6c99c69b	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x713aeb2a	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x718d793e	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0x7214265d	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x74e3cffd	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x7502dc17	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x7b8d2de4	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0x7c8895e9	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0x7ced6ab9	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x80b93db7	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x86b7bd87	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0x8fa94daf	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9f432c3d	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa1ebde8f	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0xa20db102	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0xa2e3fa8a	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0xa51d1566	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0xaa51ca92	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xaf8d172a	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb05bd36a	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0xb19dc152	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xb48565db	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb7c41645	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0xb841cbcc	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0xbe75cefa	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0xc1c165a4	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc51b5303	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xc60c7f5b	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xca56587e	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0xca857280	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xcaba553e	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0xcaf805a0	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd5383217	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xd73faf41	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0xd813625e	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xd81cacfb	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xde0eb6ba	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xe55d9bcd	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0xe99f112f	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xeba684e1	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0xee3728a2	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0xf0523b80	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0xf2bed24f	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xf362d405	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0xfe2a551f	ceph_open_session
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x4e9bf726	dccp_req_err
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0xe36155e1	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x25218fe2	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x31713582	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x53fdbe96	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x6f232f46	wpan_phy_find
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xa8c695ca	wpan_phy_new
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xec372b17	wpan_phy_register
++EXPORT_SYMBOL net/ipv4/fou 0x0c07b4a3	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0x33e84ee9	gue_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xebc8417b	fou_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xed741d6f	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x00891136	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x05a7c30f	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x54aca50f	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x69e9539e	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x9c8c0e53	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xb45cdbf5	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x1e3743df	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x35e0bef7	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x824ab004	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x075cb3b6	ipt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x60bc276b	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x81be0b4a	ipt_register_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0xdc6be72d	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/tunnel4 0xe9045fc5	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0x5793a1ea	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x49470a2d	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x7822339e	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x950ae96d	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xbd1ffa29	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x0526b5c0	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x5abcf37f	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x5fe39858	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0xe90d82e3	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0xeba57717	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x497f771a	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x5b72a497	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x0eb0a339	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x0f277531	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x0f5d86b5	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x0fdf0614	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x66132eff	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x6a25e688	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xd317bebb	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xe868b324	ircomm_close
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x08eee08e	iriap_open
++EXPORT_SYMBOL net/irda/irda 0x0963c24b	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0x09939c11	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x18b981df	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0x1f47937d	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x21379393	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0x23bbc2ce	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0x2b432980	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x358ea30e	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x35c600c2	irlap_open
++EXPORT_SYMBOL net/irda/irda 0x385847aa	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x410c36ad	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x45b50713	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0x46b00fdf	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x4d73a6fc	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0x62dc17a7	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x65172873	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0x6a0549f5	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0x6a9be3f5	iriap_close
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x70a3f20f	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0x70fcba0e	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x74aabb34	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x98a8b3b4	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0x9ccbdfca	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0xa4213068	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0xac3dc858	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0xaeeff2b5	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xb9ea3b80	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xd39ff152	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0xd6deeaae	irda_setup_dma
++EXPORT_SYMBOL net/irda/irda 0xdc0196c2	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe001a25a	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xe1ba6308	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0xe329462a	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0xe5abf088	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xe96cbb14	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0xeb78333e	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0xec242b93	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xeefe949f	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0xefa0435d	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0xf9bc67a4	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0xffc8567f	irlap_close
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x4ccf8aa6	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0x00cdc98c	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x2338657b	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0x24a4a869	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0x34a4302b	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0x7c7d9b39	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0x845c936d	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0xaa2b6104	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0xd57aaf82	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0xffd07a81	lapb_unregister
++EXPORT_SYMBOL net/llc/llc 0x153ecaa7	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0x27dc2cda	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x6d4c2375	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0x756e7384	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0x79ed46f7	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0x95936a74	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0xf3fff8ea	llc_mac_hdr_init
++EXPORT_SYMBOL net/mac80211/mac80211 0x0117aaae	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x078db118	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x10fd30ce	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x149b54a3	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0x14abe96d	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x2a98ecf9	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x2ca97626	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0x2d782fe3	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x301075fb	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x31b03656	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x31ccaaa9	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0x329eac08	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x33b350f7	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0x3648f61b	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0x38084423	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x382d0c14	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0x3aaf6eb1	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0x3d99cada	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0x3e97aab7	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x43abc086	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0x48ae333a	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x4a387f5f	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x4d68522c	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x4d8c6513	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x51d58511	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0x5545f90e	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x55fa1ec1	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x5f9353fb	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x6171948c	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x62fa7cea	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x63ac1058	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x6556f8ad	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x674a9634	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0x6a852d1d	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x6a8f00a0	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0x6bd9cad5	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x6c2e0e0c	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x70761455	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0x718c2ccc	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x7a165d7f	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x817f7ecc	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x8499253f	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac80211/mac80211 0x8c6f629d	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0x8dc518c4	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x8de464bb	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x8fb446f0	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x90548f8b	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x90e65957	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x92dade65	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x9380f7ce	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x94da4827	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x97eab865	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0x98cce075	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0xa8256061	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xa8528f8c	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xac5da3eb	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xadb3855b	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0xb5e7851c	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xb6ff6145	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xbc8bbac4	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0xbe6fe0d1	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xbe8a697c	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xc1e4bef6	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xc6d9c0dc	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xce710aed	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xd02a14f4	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0xd0c6864c	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0xd5025478	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xde2803e3	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xdf92fbd4	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xe18b18ca	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0xe49df122	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0xe759d272	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0xec32f07f	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xec7a3ab7	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0xeda362ae	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xee99109b	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac80211/mac80211 0xf8050287	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xf97ed920	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xfa8ddc57	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xfb0e7976	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xffa065e7	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac802154/mac802154 0x1e63c68b	ieee802154_xmit_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0x32e33221	ieee802154_alloc_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x47928506	ieee802154_unregister_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x542d9d26	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x65501875	ieee802154_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x81b5504c	ieee802154_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xa9f66d8f	ieee802154_register_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xcae515e4	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x235390e3	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x271f6850	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x3515e919	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x619623dc	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x70a3ab52	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x79260b66	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x7fb2b296	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x8e4029e4	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xa5b35fb9	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb2394515	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd631b51e	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xdb2c14f0	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xe188ba44	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xfa299099	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x5d2d7f01	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x62ca5714	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x90764c9d	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x03cb8161	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x12602c6a	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x1b5bee1f	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0xa759f706	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xc792860d	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0xf642183a	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/x_tables 0x0698cec5	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x0e8c6eb4	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x2cd983d9	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x405f1b5c	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x5a894588	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x5ecc6f21	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x6628baa4	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x7b4d97b3	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x9789f5d0	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xa99690a3	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/nfc/hci/hci 0x2bfdac9d	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x30d0dd8e	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x353e51dd	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x36bb39e2	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x44c81578	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x4c267763	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0x526cb5c4	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x53afd348	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0x562bca40	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x59fb2080	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x6ff18e91	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0x717485c7	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0x77a075fa	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x7a802231	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x7ed7c58b	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0x99abf43c	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xe6e740a3	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0xf357bbfb	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0xf5e0b330	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0xf75630d7	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0xfcb49ac9	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/nci/nci 0x0976879e	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0x0d8db301	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0x16c81e9e	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x1a463941	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x1a8f6c70	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x241c7c33	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nci/nci 0x2de64ac5	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x2e62657b	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x2ee06168	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nci/nci 0x37cbb3c6	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0x731147ec	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x7640fb16	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0x81b7b44a	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x8241925b	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0x839f4347	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x92748471	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x97ad7923	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0x999160ab	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0x9ffedeff	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xa877e7b5	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xc12a5d79	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0xc5eb551c	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0xd0a745e5	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0xdc808653	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xee314f40	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0xee5344ba	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0xeebef28c	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xf44eaa84	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nfc 0x0fef7231	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0x11e9c560	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0x160e11bb	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0x16e1668b	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0x3577f418	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0x36ec83d8	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x3a53ee72	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0x3c69155c	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0x425203e9	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0x611af9ba	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0x64a14294	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x7c97e821	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x8d84ea33	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0x9efd7721	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xa0add81b	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0xa1de9c27	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0xb48d3486	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0xcebf4a97	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc 0xd51b7602	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0xd903fb76	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0xdf3423b4	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0xe3c49bff	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0xe9a56ab7	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0xf22fd82b	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc_digital 0x9b0982fe	nfc_digital_unregister_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x9ce11260	nfc_digital_allocate_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xa5a4df79	nfc_digital_register_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xad0729fa	nfc_digital_free_device
++EXPORT_SYMBOL net/phonet/phonet 0x17e99f7b	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0x884c9e10	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0x8c7bbc3c	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0xaca0b770	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0xc5e9e113	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0xef4301ae	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0xf9a1a8d7	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0xfece2df4	phonet_proto_register
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x0f86bff1	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x105020dd	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x106d651d	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x27b7f865	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x2892b47c	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x2ea1d3de	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x3eed0f11	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x40fd48ce	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x410a1a91	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x4b7758e8	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xaafd8a4c	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xba478d91	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xc0302aae	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xd961385d	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xebd92d0d	key_type_rxrpc
++EXPORT_SYMBOL net/sctp/sctp 0x5dff6344	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x31fd48f1	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x7e32acf9	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xd7abf82e	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x17ea911f	xdr_restrict_buflen
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x1d4609ce	xdr_truncate_encode
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x729692a4	svc_pool_stats_open
++EXPORT_SYMBOL net/wimax/wimax 0x070bae4d	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0x581ab390	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x0330b914	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0x04ef3dbe	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x08dd158b	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x102f1011	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0x13ccaa0a	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x1451da38	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x168a71ad	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e23eb1	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0x1a1b83c8	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x1cb9f497	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x20234355	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x239a5cd0	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0x254ee14e	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x29c8306e	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x2b3c688b	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0x2caa6b0f	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0x3007440a	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0x300c7e11	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x33aaa0a7	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x3bcf0639	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d34cbbc	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x41d2d891	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x44d13d6e	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x46d8da99	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x4a061109	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x59698c62	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0x5afb1513	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x5bc1abd6	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x5febca03	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0x61636f74	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x617a06f1	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0x62916e7f	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x66aab927	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6cadc1ac	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d0f042c	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x75a48de0	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x78431bb1	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x78f5cfe5	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x7bcd3836	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0x7e48f1db	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7f212e3f	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x836375c6	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x836558b9	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x870ddde7	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x8841fbcb	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x8d555ef4	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0x8dad1671	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x907099d7	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x9609002b	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x966ff54d	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x98ac2a20	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x98e2fb1f	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0x9f15915e	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0x9fbe1cad	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa2697a7f	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xa28fddf0	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0xa5a94674	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xaa32915e	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xae378b74	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xb1c83fa7	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0xb1f1baba	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xb37426c4	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0xb80b3c27	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0xb99b05db	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0xbc8fd4b7	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xbccbb264	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0xc0c4ed81	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xc1df8791	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc67024d9	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xc9191ade	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0xca5c24b3	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xceab94a6	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0xd20dd99e	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xd269411e	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0xd40b6ec4	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xdf3c8522	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xe26d5ae3	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0xeb404da6	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0xeb6d7c6c	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xf1b6b494	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xfae74812	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0xfba5a616	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xfcc8f05a	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0xff1e59cf	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/lib80211 0x2f383667	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x3e430e31	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0x4eadd1b8	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x594d4012	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x9f23c972	lib80211_crypt_info_free
++EXPORT_SYMBOL net/wireless/lib80211 0xac57e24b	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL sound/ac97_bus 0x7b77e15a	ac97_bus_type
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0x82794069	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x094df430	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x96f1cd3d	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xc964e33d	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xd8680342	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x8d0df86b	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x205395a0	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x614705ff	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x7746bb9b	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x79794472	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x991c0f60	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xef8fa3d2	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xf3f0324e	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xf6fdda44	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0xf21f314f	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x0e0ee05f	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0x0f618f4d	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0x10bdfb23	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0x128ced8f	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd 0x1337bb54	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0x155d3f49	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0x16d29131	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0x18e1683f	snd_dma_program
++EXPORT_SYMBOL sound/core/snd 0x191e88cf	snd_dma_pointer
++EXPORT_SYMBOL sound/core/snd 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL sound/core/snd 0x1d177b09	snd_unregister_oss_device
++EXPORT_SYMBOL sound/core/snd 0x1e798604	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0x2106b91d	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0x2491d78a	snd_jack_add_new_kctl
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0x34003ea2	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0x3735d22a	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x3d8f3c8b	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x55a23419	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0x572fb2de	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0x5ff281e2	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0x602c96f0	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x65288b9b	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0x6b6613d7	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0x6dc88876	snd_register_oss_device
++EXPORT_SYMBOL sound/core/snd 0x70c15ac1	snd_dma_disable
++EXPORT_SYMBOL sound/core/snd 0x728da773	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL sound/core/snd 0x7a8f589d	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0x7c540970	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL sound/core/snd 0x8f3ad0a5	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x96213167	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0x966361d0	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0x98b769b6	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xa2cd474a	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0xac30954b	snd_register_device
++EXPORT_SYMBOL sound/core/snd 0xb1ecbdb0	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0xb28746e2	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0xb2c9c007	snd_card_new
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xb49cb20c	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0xb745add1	snd_cards
++EXPORT_SYMBOL sound/core/snd 0xb84d31b2	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd 0xb97e55c9	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0xc991627f	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0xce3ca308	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd 0xce5733ef	snd_device_new
++EXPORT_SYMBOL sound/core/snd 0xd14b2f0a	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0xd1e1cf16	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0xd7f65b93	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0xde294f29	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0xdeb562d6	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0xeb6b1f0a	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0xf246bb60	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0xf8a702b4	snd_jack_new
++EXPORT_SYMBOL sound/core/snd-hwdep 0x97f07ec3	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x0104f98b	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x148b4bb4	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x20424e2a	snd_sgbuf_get_chunk_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x2074984a	snd_pcm_lib_mmap_iomem
++EXPORT_SYMBOL sound/core/snd-pcm 0x2a50750a	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-pcm 0x3076dd02	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x3b91f3af	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x3d8f20a1	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x4d9b6d35	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x54ea7ca3	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x55fd59a1	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0x5a8a31c0	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0x5bb4441b	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x5d310396	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x611bc57a	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0x61e2b53d	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x65dd363a	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0x682baa45	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x6a51cd13	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x70c27749	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0x7130a58a	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x73c7867f	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x7db911b6	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0x7f56961b	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x874c68aa	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x91df3707	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x95e81df5	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-pcm 0x9f811077	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xa657cffb	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xade88e76	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xb1d9a1d4	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0xb36a1605	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xc300388b	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0xc828933a	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0xc88d4eab	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0xc94e41cd	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0xcb3e73d8	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0xd3122c4a	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0xd6dc31cc	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0xd89adcb3	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0xdd0248b8	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0xe22f5f24	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0xe4b5a593	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0xe4b73761	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xe9fe0aa4	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xed336bf6	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-pcm 0xed4f5abc	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0xf3b0f03e	snd_pcm_sgbuf_ops_page
++EXPORT_SYMBOL sound/core/snd-pcm 0xf84a93d9	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0xf9ee23b8	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0xfbca69dc	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0xfe511eb5	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x0843771e	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x0d8a1723	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x21f15fe6	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x399faa0e	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x3e474c3a	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x5760c691	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x6028e1b2	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x655b474e	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x6e783dd4	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x84cf7c22	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x89cedf36	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x8b10f9ee	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x930d0081	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xae49b45c	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb5198183	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb775ba4b	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xbbb515e0	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xe9eeffc8	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xf93ced42	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-timer 0x0d6fa7ca	snd_timer_pause
++EXPORT_SYMBOL sound/core/snd-timer 0x25809682	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0x566c88ec	snd_timer_interrupt
++EXPORT_SYMBOL sound/core/snd-timer 0x6506c025	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0x89dae53c	snd_timer_stop
++EXPORT_SYMBOL sound/core/snd-timer 0x928ead46	snd_timer_close
++EXPORT_SYMBOL sound/core/snd-timer 0x9f7ac005	snd_timer_global_register
++EXPORT_SYMBOL sound/core/snd-timer 0xc2df7b11	snd_timer_new
++EXPORT_SYMBOL sound/core/snd-timer 0xcf2e0bf2	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0xd5b1482b	snd_timer_resolution
++EXPORT_SYMBOL sound/core/snd-timer 0xdc02398c	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0xeac91031	snd_timer_start
++EXPORT_SYMBOL sound/core/snd-timer 0xf6bd25f9	snd_timer_open
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x00634392	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x000bf425	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x2ff50eb0	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x329596a8	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x37bb4c56	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x52299161	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x96306020	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xa4e3fb91	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xb9d51933	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xfb0e7d3e	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0x2754d85c	snd_opl4_read_memory
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0x33f6f392	snd_opl4_create
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0x4225db56	snd_opl4_write_memory
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0xc48c18de	snd_opl4_read
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0xd69b355d	snd_opl4_write
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x1eb05318	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x40bda9e9	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x5ef4f5b6	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x727dc424	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x8377b15c	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x8a5870cc	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x8a76ad17	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x8b041c81	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xb2f880bb	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x00a5fdfc	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x04d6188a	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x0d774b42	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x13b1b981	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x18586f82	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1d6a1caa	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x24e7b975	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x29897ab7	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x2f258e0b	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x43a8144a	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5a83c849	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x680ed783	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x705b5576	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x71cc0886	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7efaacf0	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x80c60954	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x86382279	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8e3ba2c2	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x91ab702f	amdtp_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x99c81ddd	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xaab1a4c1	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xb356012f	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc1e8f7bc	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc7a98c44	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xcbad7450	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xda1c8893	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xdc432444	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe48de1b6	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe65ae9b0	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe8b15a6c	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xfadb7d01	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xfcdc348b	snd_fw_transaction
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x0055a653	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x8fd39a26	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x042608ad	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x5855b30e	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x657b0efc	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x6bfff2b3	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x71436a7c	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x9c3f3175	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xcb92997a	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xef651125	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x091b3498	snd_ak4117_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x1c843de4	snd_ak4117_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x9ed74fce	snd_ak4117_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xc89e8189	snd_ak4117_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xdc2ef779	snd_ak4117_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xe0b56573	snd_ak4117_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x6e8aa3b3	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x7158d425	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x95bbb3f4	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xa1446810	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0xa5c887ca	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0xd41fa14e	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x0560d733	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x1bee3882	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x25ac2fd3	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x5143e861	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x54097ecb	snd_cs8427_init
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x5a8ef5bb	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x48cadc62	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x495bf551	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x8dcf07be	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x8e7917aa	snd_i2c_device_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xb724fd37	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xe8e06918	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-tea6330t 0x06fb18f0	snd_tea6330t_update_mixer
++EXPORT_SYMBOL sound/i2c/snd-tea6330t 0x53ece9e2	snd_tea6330t_detect
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0x760e86db	snd_es1688_reset
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0xb144c0ed	snd_es1688_mixer_write
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0xb9ce2b96	snd_es1688_create
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0xbe9be90b	snd_es1688_mixer
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0xf5ec4100	snd_es1688_pcm
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x0559e432	snd_gus_use_inc
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x0bf78dfa	snd_gf1_pcm_new
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x120f30d9	snd_gf1_ctrl_stop
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x1c1ce117	snd_gus_interrupt
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x1e39d9d4	snd_gf1_new_mixer
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x1e8a1037	snd_gf1_i_look16
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x24c4d818	snd_gf1_dram_addr
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x301ddb0b	snd_gf1_look8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x32306255	snd_gf1_alloc_voice
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x348139a1	snd_gf1_write_addr
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x3a27e9f1	snd_gf1_poke
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x3a917f75	snd_gf1_free_voice
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x3e392e35	snd_gus_create
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x3fe414db	snd_gus_dram_read
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x46db8d67	snd_gf1_lvol_to_gvol_raw
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x4ff0270c	snd_gf1_look16
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x5230a953	snd_gf1_i_look8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x56080ac9	snd_gus_initialize
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x5ec94819	snd_gf1_mem_lock
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x623f0a33	snd_gf1_i_write8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x6d5b14d5	snd_gf1_mem_xfree
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x95f33888	snd_gf1_rawmidi_new
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x98231017	snd_gf1_delay
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x9c08484e	snd_gf1_peek
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x9c6106d8	snd_gf1_stop_voice
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x9f74fb09	snd_gf1_translate_freq
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xa0474ed3	snd_gus_use_dec
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xc43a5527	snd_gf1_atten_table
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xc5b50938	snd_gf1_mem_free
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xcb41a7fc	snd_gus_dram_write
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xd493f5be	snd_gf1_write8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xed56a4e5	snd_gf1_write16
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xf10b2ff0	snd_gf1_mem_alloc
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x030316b8	snd_msndmix_force_recsrc
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x0e096be3	snd_msnd_init_queue
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x0f46887a	snd_msnd_upload_host
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x1510f91d	snd_msnd_send_word
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x568c4fdf	snd_msnd_DAPQ
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x6ef90f3d	snd_msnd_send_dsp_cmd
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x75026b24	snd_msndmidi_input_read
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x79d1a12a	snd_msnd_enable_irq
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x90afc408	snd_msnd_disable_irq
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xb375d92d	snd_msnd_DARQ
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xb5cfbf96	snd_msndmix_new
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xbcdef29a	snd_msndmix_setup
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xd74c01c6	snd_msnd_dsp_halt
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xee89c8da	snd_msnd_pcm
++EXPORT_SYMBOL sound/isa/opti9xx/snd-miro 0x02ccc733	snd_aci_cmd
++EXPORT_SYMBOL sound/isa/opti9xx/snd-miro 0xcc82800d	snd_aci_get_aci
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x1c29f574	snd_sbdsp_get_byte
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x5c5c0f17	snd_sbmixer_add_ctl
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x759769f3	snd_sbmixer_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x815df73f	snd_sbmixer_write
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x914d0bcf	snd_sbmixer_resume
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x9b282e5b	snd_sbdsp_command
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xcd82e19c	snd_sbmixer_read
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xd6b0a2de	snd_sbmixer_suspend
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xd9cfbab8	snd_sbdsp_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xf748868f	snd_sbdsp_reset
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-csp 0xe4c01d38	snd_sb_csp_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0x5612bee2	snd_sb16dsp_pcm
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0xadf87fc9	snd_sb16dsp_get_pcm_ops
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0xe0b3f690	snd_sb16dsp_interrupt
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0xe4662d20	snd_sb16dsp_configure
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0x4063aa47	snd_sb8dsp_interrupt
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0x7b3c854a	snd_sb8dsp_midi_interrupt
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0x8db188b6	snd_sb8dsp_pcm
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0xaf83a8e5	snd_sb8dsp_midi
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x090093ac	snd_emu8000_update_reverb_mode
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x329fbf11	snd_emu8000_update_equalizer
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x64009d1e	snd_emu8000_poke_dw
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x73abada1	snd_emu8000_load_reverb_fx
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x76740d2e	snd_emu8000_peek_dw
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x9d0fc506	snd_emu8000_peek
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0xd4ea9a7a	snd_emu8000_update_chorus_mode
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0xd7ba880d	snd_emu8000_poke
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0xe28c1944	snd_emu8000_dma_chan
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0xf387239c	snd_emu8000_load_chorus_fx
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0xf66484c9	snd_emu8000_init_fm
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x063a5e5a	snd_wss_timer
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x0733501f	snd_wss_mixer
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x0b23003d	snd_wss_info_single
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x2d24a9a4	snd_wss_mce_up
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x32ccfa48	snd_wss_put_double
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x42435cfb	snd_cs4236_ext_out
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x64035d49	snd_wss_get_double
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x75aa4ace	snd_wss_out
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x7b202637	snd_wss_interrupt
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x81a20fd9	snd_wss_get_pcm_ops
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x85b649bc	snd_wss_put_single
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x8c53b0aa	snd_wss_in
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x9b3e04dd	snd_wss_overrange
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xa104a784	snd_cs4236_ext_in
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xcccccf43	snd_wss_info_double
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xcdd8d737	snd_wss_pcm
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xd379eebd	snd_wss_get_single
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xd736aa6b	snd_wss_chip_id
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xfa2af97d	snd_wss_create
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xfee11129	snd_wss_mce_down
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x07c0279a	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x0b096188	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x160c3f0c	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x407aff2a	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5f3b2ed2	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x6f01ff34	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x8d1120c0	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xa53a8069	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb58ce07b	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb95a9bc0	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xc2b1db13	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xc690c281	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xc8249a8e	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xda330424	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xdd16ce32	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xe2b6abcf	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xfa2c7f1d	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/asihpi/snd-asihpi 0xd54ff91a	hpi_send_recv
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x112da59f	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x1844ebec	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x1b1b3e0a	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x6f8a0b07	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x894a53d8	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x92b55145	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xca877eda	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xd72efe45	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xfe55a2a6	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x0fa3bdc0	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x3545874e	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x68656cb2	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0aedfd4d	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x11c07f43	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x25d0efb9	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x26e3a027	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x455c73c4	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x4925a72e	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x65ea96eb	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x662bd9bf	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x66cfe148	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x68472a8c	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x918640f0	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x95937f9c	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x9be0a121	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa81eabc2	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xab2fc5fd	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xab2fefa1	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb59334b0	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb9624ffa	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc252a6d2	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc799e739	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xd864c93a	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x519c09fe	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x8bec5a0e	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xbf8a6173	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xcdcf1ea9	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xfa4673ad	snd_trident_free_voice
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0xe4e41c0f	tlv320aic23_probe
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0xf467f4d9	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/intel/common/snd-soc-sst-dsp 0xdc045797	sst_dma_free
++EXPORT_SYMBOL sound/soc/intel/common/snd-soc-sst-dsp 0xe246a862	sst_dma_new
++EXPORT_SYMBOL sound/soc/snd-soc-core 0x56ab1ab7	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL sound/soundcore 0x173c49fb	register_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x1c2dc8ef	register_sound_special_device
++EXPORT_SYMBOL sound/soundcore 0x3e4392da	register_sound_special
++EXPORT_SYMBOL sound/soundcore 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x7e34cafe	sound_class
++EXPORT_SYMBOL sound/soundcore 0x8b32e689	register_sound_midi
++EXPORT_SYMBOL sound/soundcore 0x93bb97e4	register_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL sound/soundcore 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x42c424d9	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x4da399fe	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x59b9ab4d	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x9eecb651	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xa572e021	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xb0e21ed0	snd_emux_register
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x2e4f9bb4	__snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x3e3189cd	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x443e064f	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x76d9963e	snd_util_memhdr_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x8abc0240	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xe0ce3e1f	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xea4c27ad	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xec83060a	snd_util_mem_free
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x42418b70	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL ubuntu/hio/hio 0x11ed29e2	ssd_register_event_notifier
++EXPORT_SYMBOL ubuntu/hio/hio 0x267790d1	ssd_set_otprotect
++EXPORT_SYMBOL ubuntu/hio/hio 0x27da9fc2	ssd_get_label
++EXPORT_SYMBOL ubuntu/hio/hio 0x44353807	ssd_set_wmode
++EXPORT_SYMBOL ubuntu/hio/hio 0x481c0b13	ssd_get_version
++EXPORT_SYMBOL ubuntu/hio/hio 0x57f6e792	ssd_get_pciaddr
++EXPORT_SYMBOL ubuntu/hio/hio 0x5ceab207	ssd_submit_pbio
++EXPORT_SYMBOL ubuntu/hio/hio 0x842f1292	ssd_unregister_event_notifier
++EXPORT_SYMBOL ubuntu/hio/hio 0x9e7cb63d	ssd_reset
++EXPORT_SYMBOL ubuntu/hio/hio 0xaca028c7	ssd_bm_status
++EXPORT_SYMBOL ubuntu/hio/hio 0xfa8077b0	ssd_get_temperature
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x002d778d	VBoxGuest_RTMpNotificationDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0064d4f7	VBoxGuest_RTSemFastMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x00712528	VBoxGuest_RTAssertMsg2Weak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x01795170	VBoxGuest_RTMpGetCoreCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x03d8513f	VBoxGuest_RTThreadSetName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x05626dc7	VBoxGuest_RTR0MemObjReserveKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0665bcaa	VBoxGuest_RTAssertSetMayPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x06ab676b	VBoxGuest_RTLogPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0823cb2f	VBoxGuest_RTMemAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x08b98b3c	VBoxGuest_RTMpCpuIdFromSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x08d7a261	VBoxGuest_RTThreadSelfName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x09458185	VBoxGuest_RTR0MemAreKrnlAndUsrDifferent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0b14ec2c	VBoxGuest_RTThreadCreateF
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0b628628	VBoxGuest_RTSemEventMultiDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0b94344b	VBoxGuest_g_pszRTAssertExpr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0d1abebe	VBoxGuest_RTLogFlush
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0dfb68c6	VBoxGuest_RTSemEventWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x0e1a390f	VBoxGuest_RTStrToInt8Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x104391d1	VBoxGuest_RTSemMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x113a02d9	VBoxGuest_RTMpOnPair
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x127e9d01	VBoxGuest_RTTimerRequestSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x143fba5b	VBoxGuest_RTThreadPreemptDisable
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x14835127	VBoxGuest_RTAssertMsg2AddWeak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x16d72922	VBoxGuest_RTR0MemObjIsMapping
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x17d84704	VBoxGuest_RTSpinlockCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x187c16e2	VBoxGuest_RTLogCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x19087f6f	VBoxGuest_RTSemEventMultiWaitEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1a79fedb	VBoxGuest_RTSemMutexRequestNoResumeDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1abe7e93	VBoxGuest_RTThreadGetNative
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1ad481e4	VBoxGuest_RTLogLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1d042132	VBoxGuest_RTMemContFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1e7216d7	VBoxGuest_RTThreadFromNative
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1efa8169	VBoxGuest_RTThreadUserSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1f152547	VBoxGuest_RTMpGetMaxCpuId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x1fc40aab	VBoxGuest_RTR0MemObjReserveUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x21b1ee43	VBoxGuest_RTThreadSleepNoLog
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x221205d1	VBoxGuest_RTThreadSetType
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2280771d	VBoxGuestIDCCall
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x22bd51c7	VBoxGuest_RTErrConvertToErrno
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x23a552fd	VBoxGuest_RTMpIsCpuOnline
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x246391eb	VBoxGuest_RTStrToUInt16Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x25938e5f	VBoxGuest_RTLogWriteDebugger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x267da4c4	VBoxGuest_RTThreadIsMain
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x27740cb3	VBoxGuest_RTStrToUInt8Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2902013c	VBoxGuest_RTTimerGetSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x29066860	VBoxGuest_RTStrConvertHexBytes
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2972116c	VBoxGuest_RTThreadPreemptIsEnabled
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x29bf3685	VBoxGuest_RTThreadGetName
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2b015c38	VBoxGuest_RTMpOnAll
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2b5f52a8	VBoxGuest_RTMpCurSetIndexAndId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2bad2a8e	VBoxGuest_RTStrToInt16
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2c5b3002	VBoxGuest_RTErrConvertFromErrno
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2d27c026	VBoxGuest_RTSemEventWaitExDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x2e136d3c	VBoxGuest_RTR0MemObjAllocPhysExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x309de102	VBoxGuest_RTMpCpuId
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3519743a	VBoxGuest_RTMpCurSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3534ed69	VBoxGuest_RTMemAllocVarTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x353b64a3	VBoxGuest_RTSemMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x353e5a81	VBoxGuest_RTSemEventMultiReset
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x365d44f1	VBoxGuest_RTR0MemObjMapKernelExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x36e780e0	VBoxGuest_RTStrToUInt8Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x37b2d47a	VBoxGuest_RTStrPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x39df70a0	VBoxGuest_RTStrPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3a29bcdb	VBoxGuest_RTThreadIsInitialized
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3a77155a	VBoxGuest_RTMpOnPairIsConcurrentExecSupported
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3b0a3d87	VBoxGuest_RTMemAllocZVarTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3d00f113	VBoxGuest_g_u32RTAssertLine
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3ed3a918	VBoxGuest_RTAssertMsg1
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3f452f12	VBoxGuest_RTR0MemObjAllocPageTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x3f8d56e7	VBoxGuest_RTMemDupTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4002b8b4	VBoxGuest_RTTimeSpecToString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x405901ff	VBoxGuest_RTStrFormatTypeRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x428e3456	VBoxGuest_RTR0Term
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x428eb5ba	VBoxGuest_RTMemTmpAllocZTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x42c5bff2	VBoxGuest_RTLogRelLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x432b6724	VBoxGuest_RTR0MemObjAllocPhysNCTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x433ceadb	VBoxGuest_RTLogWriteStdOut
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4453e900	VBoxGuest_RTR0MemObjProtect
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4484f9ee	VBoxGuest_RTTimerStart
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x44ce618e	VBoxGuest_RTMemAllocExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x453e64fb	VBoxGuest_RTSemEventMultiSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x45933412	VBoxGuest_RTStrToInt8Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4597652f	VBoxGuest_RTStrFormat
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x45d332ae	VBoxGuest_RTMemReallocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x46b36f60	VBoxGuest_RTTimeSpecFromString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4819f15e	VBoxGuest_RTThreadWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x48487b79	VBoxGuest_RTLogDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4983ea42	VBoxGuest_RTAssertShouldPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4aca506e	VBoxGuest_RTStrToUInt32Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4d0161ca	VBoxGuest_RTLogBackdoorPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4d47859f	VBoxGuest_RTR0MemKernelCopyTo
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4e6d6986	VBoxGuest_RTStrToUInt16
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x4e7faa59	VBoxGuest_RTStrToInt64
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x503f488a	VBoxGuest_RTLogRelSetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5045b702	VBoxGuest_RTLogGetDestinations
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5118e8ae	VBoxGuest_RTStrToUInt64
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x52041f46	VBoxGuest_RTThreadPreemptIsPossible
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x53602f45	VBoxGuest_RTMemTmpFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x539dd662	VBoxGuest_RTTimeSystemMilliTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x53b772da	VBoxGuest_RTAssertSetQuiet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x543527dc	VBoxGuest_RTLogWriteStdErr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5460fc01	VBoxGuest_RTTimeImplode
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x54abe5d4	VBoxGuest_RTSemMutexRequestNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x54e45046	VBoxGuest_RTR0MemObjAllocLowTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x55c48692	VBoxGuest_RTMpIsCpuWorkPending
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x57280c42	VBoxGuest_RTR0MemExecDonate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x57406d20	VBoxGuest_RTR0ProcHandleSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5929b954	VBoxGuest_RTPowerSignalEvent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5936a317	VBoxGuest_RTR0MemObjAddress
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x59390acb	VBoxGuest_RTTimeIsLeapYear
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5ad3216a	VBoxGuest_RTR0MemKernelIsValidAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5b0eaa4d	VBoxGuest_RTThreadWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5c15981f	VBoxGuest_RTMemContAlloc
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x5ca67994	VBoxGuest_RTLogDestinations
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x613042f7	VBoxGuest_RTR0MemObjMapUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x622a261f	VBoxGuest_RTPowerNotificationRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x622bf330	VBoxGuest_RTMemAllocZTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x62fd45a8	VBoxGuest_RTTimeNanoTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x63ba9fd2	VBoxGuest_RTLogGetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x64655cd4	VBoxGuest_RTSemEventMultiWaitExDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x64af2463	VBoxGuest_RTStrToInt32
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x650e77e8	VBoxGuest_RTMpGetCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x651c778b	VBoxGuest_RTSemEventMultiCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6549a3e0	VBoxGuest_RTTimeFromString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x65b04e5d	VBoxGuest_RTStrToUInt64Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x687ae6ac	VBoxGuest_RTStrToUInt64Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6a930d21	VBoxGuest_RTTimerCanDoHighResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6bcedab4	VBoxGuest_RTThreadPreemptIsPending
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6c17021e	VBoxGuest_RTThreadUserReset
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6c2df755	VBoxGuest_RTAssertMsg1Weak
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6ca5b4ec	VBoxGuest_RTSemEventMultiGetResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6f8ed216	VBoxGuest_RTStrToUInt16Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x6fd2e761	VBoxGuest_RTTimeNormalize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x713f25d5	VBoxGuestIDCClose
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x715699a0	VBoxGuest_RTSpinlockDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x72d1c8f4	VBoxGuestIDCOpen
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x73a23c8b	VBoxGuest_RTLogRelPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x73f65247	VBoxGuest_RTStrToInt32Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x744623d2	VBoxGuest_RTSemMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x753d3a3a	VBoxGuest_RTLogFormatV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x755479c2	VBoxGuest_RTR0MemObjLockKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x75bee68e	VBoxGuest_RTThreadIsSelfKnown
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x76608be1	VBoxGuest_RTSemSpinMutexCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x766a8684	VBoxGuest_RTThreadCreateV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x76b885fb	VBoxGuest_RTLogGetDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x76bb35b9	VBoxGuest_RTLogLoggerEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x76dbecb7	VBoxGuest_RTProcSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x77248ef3	VBoxGuest_RTR0MemObjLockUserTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7841b10d	VBoxGuest_RTMpIsCpuPossible
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x78ad2401	VBoxGuest_RTStrToInt8
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x797e701f	VBoxGuest_RTLogCreateEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x79aefc0b	VBoxGuest_RTTimeNow
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7ac53b51	VBoxGuest_RTR0MemUserCopyFrom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7ae3b63b	VBoxGuest_RTStrToUInt32
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7b423f4c	VBoxGuest_RTLogGetFlags
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x7cef940f	VBoxGuest_RTStrToUInt8
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x80162938	VBoxGuest_RTStrFormatV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8229caac	VBoxGuest_RTThreadUserWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x847577ac	VBoxGuest_RTMpGetOnlineCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x84e86094	VBoxGuest_RTStrPrintfExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x854806f2	VBoxGuest_RTSpinlockAcquire
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8587f091	VBoxGuest_RTR0MemUserCopyTo
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x85afce7f	VBoxGuest_RTMpNotificationRegister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x867199c4	VBoxGuest_RTMpPokeCpu
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x86f9f023	VBoxGuest_RTSemFastMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x87abe8dd	VBoxGuest_RTR0MemObjSize
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8ab21a95	VBoxGuest_RTSemSpinMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8b4fd3ef	VBoxGuest_RTTimeSystemNanoTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x8ff5c8e5	VBoxGuest_RTSemEventMultiWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x937cd6a2	VBoxGuest_RTLogComPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9474d99a	VBoxGuest_RTSemFastMutexDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x951fbe81	VBoxGuest_RTLogLoggerV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x953b2ba4	VBoxGuest_RTLogSetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x983f332c	VBoxGuest_RTSemSpinMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9853901a	VBoxGuest_RTAssertMsg2Add
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x98a8f55f	VBoxGuest_RTMpGetPresentCoreCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9909ff3d	VBoxGuest_g_pszRTAssertFunction
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x993cc778	VBoxGuest_RTLogRelSetBuffering
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x99ee476f	VBoxGuest_RTThreadYield
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9b02b021	VBoxGuest_RTThreadSleep
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9be73ec4	VBoxGuest_RTMpCpuIdToSetIndex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9dc75797	VBoxGuest_RTLogBackdoorPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9e97ef59	VBoxGuest_RTSemEventWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0x9eb3db26	VBoxGuest_RTR0MemObjAllocPhysTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa21775d1	VBoxGuest_RTSemFastMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa2c23601	VBoxGuest_RTR0MemObjAllocContTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa3ff74bf	VBoxGuest_RTStrToInt16Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa52847a2	VBoxGuest_RTR0MemUserIsValidAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa5655a80	VBoxGuest_RTTimerReleaseSystemGranularity
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa582aeba	VBoxGuest_RTMemExecFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa5f0f1ad	VBoxGuest_RTAssertMsg2
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa61aa915	VBoxGuest_RTR0MemObjFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa6209fc7	VBoxGuest_RTLogPrintf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa74258ab	VBoxGuest_RTTimeExplode
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xa8a47d40	VBoxGuest_RTLogLoggerExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xaaab8c57	VBoxGuest_RTLogRelGetDefaultInstanceEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xaadc0b5d	VBoxGuest_RTTimerChangeInterval
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xab5ee692	VBoxGuest_RTLogWriteUser
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xab871924	VBoxGuest_RTThreadPreemptIsPendingTrusty
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xacaac41d	VBoxGuest_g_szRTAssertMsg1
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xadb5cc54	VBoxGuest_RTStrFormatTypeSetUser
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xae21ae1f	VBoxGuest_RTThreadCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb2f248c6	VBoxGuest_RTStrCopyP
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb33ca348	VBoxGuest_RTLogRelPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb3f592b9	VBoxGuest_RTThreadNativeSelf
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb4227efb	VBoxGuest_RTTimeToString
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb42ea0e3	VBoxGuest_g_pszRTAssertFile
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb5676d46	VBoxGuest_RTLogSetCustomPrefixCallback
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb5ec2977	VBoxGuest_RTStrToInt16Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb6fc848a	VBoxGuest_RTStrToUInt32Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb9a86152	VBoxGuest_RTStrFormatNumber
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xb9e03c35	VBoxGuest_RTTimerStop
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xba349142	VBoxGuest_RTR0MemObjEnterPhysTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbaa97421	VBoxGuest_g_szRTAssertMsg2
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbaf6967f	VBoxGuest_RTR0MemObjGetPagePhysAddr
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbba29a48	VBoxGuest_RTR0MemObjAddressR3
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbbbc6e84	VBoxGuest_RTSemMutexRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbbccb0c7	VBoxGuest_RTTimeMilliTS
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbc7fbd2a	VBoxGuest_RTLogFlushRC
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbcd1b6de	VBoxGuest_RTSemSpinMutexRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbd0aa67d	VBoxGuest_RTLogFlags
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbeed82c5	VBoxGuest_RTSemEventDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xbf5b421e	VBoxGuest_RTLogComPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc272f283	VBoxGuest_RTLogGroupSettings
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc2e0f25a	VBoxGuest_RTMemTmpAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc312f533	VBoxGuest_RTMpIsCpuPresent
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc4b8857d	VBoxGuest_RTThreadPreemptRestore
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc4c265c6	VBoxGuest_RTMpGetPresentCount
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc5151dcf	VBoxGuest_RTLogDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc56f27ff	VBoxGuest_RTR0Init
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc57a9c9b	VBoxGuest_RTStrToInt32Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc636859e	VBoxGuest_RTThreadUserWaitNoResume
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc6b243bf	VBoxGuest_RTTimerDestroy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc7601bb1	VBoxGuest_RTSemEventMultiWait
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xc9978a5f	VBoxGuest_RTAssertMsg2V
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xcb6463c6	VBoxGuest_RTStrFormatTypeDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xcdbc5e5d	VBoxGuest_RTSemEventCreate
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xcdd40e5b	VBoxGuest_RTMpOnOthers
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xceb98390	VBoxGuest_RTMpOnSpecific
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd032523c	VBoxGuest_RTThreadGetType
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd1c8b171	VBoxGuest_RTStrCopyEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd2ebb507	VBoxGuest_RTMpGetPresentSet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd38c5d55	VBoxGuest_RTLogCloneRC
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd4f35c7d	VBoxGuest_RTSemSpinMutexTryRequest
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd63c8527	VBoxGuest_RTMemFreeEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd76ab832	VBoxGuest_RTMemDupExTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xd8730925	VBoxGuest_RTLogRelLoggerV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdd31359f	VBoxGuest_RTLogSetDefaultInstanceThread
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdd699fb2	VBoxGuest_RTSemMutexIsOwned
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xde296aea	VBoxGuest_RTAssertAreQuiet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdead7a1c	VBoxGuest_RTLogSetBuffering
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xdfaa7e65	VBoxGuest_RTSemEventSignal
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe0453bfd	VBoxGuest_RTTimerCreateEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe0afcea8	VBoxGuest_RTR0AssertPanicSystem
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe0ebf12c	VBoxGuest_RTAssertMsg2WeakV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe16047ab	VBoxGuest_RTLogDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe19acf09	VBoxGuest_RTStrCopy
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe208c712	VBoxGuest_RTLogGetGroupSettings
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe2aa3ed6	VBoxGuest_RTR0MemKernelCopyFrom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe4104f8b	VBoxGuest_RTLogFlushToLogger
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe46f3670	VBoxGuest_RTLogRelGetDefaultInstance
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe47b5364	VBoxGuest_RTSemEventGetResolution
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe5908cc3	VBoxGuest_RTStrToInt64Full
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe59fc65c	VBoxGuest_RTLogWriteCom
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xe6a00917	VBoxGuest_RTThreadIsInInterrupt
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xebbe4bc3	VBoxGuest_RTThreadIsSelfAlive
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xecd69ee8	VBoxGuest_RTAssertMsg2AddWeakV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xed0424f7	VBoxGuest_RTMemFree
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xed92363f	VBoxGuest_RTR0MemObjMapKernelTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf244ec46	VBoxGuest_RTSemMutexRequestDebug
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf2e6e2c5	VBoxGuest_RTStrPrintfEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf3cd37e7	VBoxGuest_RTSemEventWaitEx
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf450a3d4	VBoxGuest_RTLogCreateExV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf722f7d1	VBoxGuest_RTMemExecAllocTag
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf7c384ae	VBoxGuest_RTStrToInt64Ex
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xf81b13f5	VBoxGuest_RTPowerNotificationDeregister
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfb5ca767	VBoxGuest_RTSpinlockRelease
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfcfe8381	VBoxGuest_RTMpGetOnlineSet
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfe4fce41	VBoxGuest_RTAssertMayPanic
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfe5c0dc7	VBoxGuest_RTAssertMsg2AddV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfec59082	VBoxGuest_RTLogDumpPrintfV
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xfec8da5c	VBoxGuest_RTMpOnAllIsConcurrentSafe
++EXPORT_SYMBOL ubuntu/vbox/vboxguest/vboxguest 0xffc16d99	VBoxGuest_RTMpGetSet
++EXPORT_SYMBOL vmlinux 0x00072638	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x0026280d	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x0066651f	gnttab_alloc_pages
++EXPORT_SYMBOL vmlinux 0x006ed8d2	dev_add_offload
++EXPORT_SYMBOL vmlinux 0x0097e374	path_noexec
++EXPORT_SYMBOL vmlinux 0x00a380ed	set_blocksize
++EXPORT_SYMBOL vmlinux 0x00b0d375	put_page
++EXPORT_SYMBOL vmlinux 0x00b8c3a7	mempool_alloc
++EXPORT_SYMBOL vmlinux 0x00c9d561	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0x00d7a5e3	dma_mark_declared_memory_occupied
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x00dc1762	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x00e36f2c	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x010e20d0	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0x01122ad2	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0x01139ffc	max_mapnr
++EXPORT_SYMBOL vmlinux 0x012357b9	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0x0132e7ef	__vfs_write
++EXPORT_SYMBOL vmlinux 0x0139b504	cpu_current_top_of_stack
++EXPORT_SYMBOL vmlinux 0x0150ee97	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x0197e8f4	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0x01c4096f	phy_stop
++EXPORT_SYMBOL vmlinux 0x01caaf76	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0x01e1f1ca	get_acl
++EXPORT_SYMBOL vmlinux 0x01eace20	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x0209b187	param_ops_int
++EXPORT_SYMBOL vmlinux 0x020cf969	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x0237b57a	arch_unregister_cpu
++EXPORT_SYMBOL vmlinux 0x02498c5a	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x026055f8	inet6_protos
++EXPORT_SYMBOL vmlinux 0x0261b3fd	devm_clk_get
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x026e52ee	first_ec
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x0276feb4	from_kprojid
++EXPORT_SYMBOL vmlinux 0x0298da95	sk_wait_data
++EXPORT_SYMBOL vmlinux 0x029e97c0	i8042_install_filter
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a643d6	vfs_unlink
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02a70fd6	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x02c36135	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x02ee26c1	free_pages_exact
++EXPORT_SYMBOL vmlinux 0x02f58604	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x03177e88	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x033f112f	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0x0343853a	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x035e341d	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x036cac6e	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x038cf64b	dma_release_declared_memory
++EXPORT_SYMBOL vmlinux 0x03a5c22d	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0x03e53be2	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x041b72e6	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x0426ba24	idr_for_each
++EXPORT_SYMBOL vmlinux 0x0432fec1	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0x043b5a2c	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x0451ac98	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0x0460e59b	do_splice_from
++EXPORT_SYMBOL vmlinux 0x047cc38d	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x048b25d2	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x04a0c951	netif_napi_add
++EXPORT_SYMBOL vmlinux 0x04afd4fb	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x04b2d229	file_path
++EXPORT_SYMBOL vmlinux 0x04b9af94	acpi_get_hp_hw_control_from_firmware
++EXPORT_SYMBOL vmlinux 0x04d110fe	current_in_userns
++EXPORT_SYMBOL vmlinux 0x04d346d3	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x04d3929c	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0x04d8c750	release_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x050877b9	dmi_first_match
++EXPORT_SYMBOL vmlinux 0x0512f901	single_open_size
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x0531b427	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x05321b61	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0x055b3bf0	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x058f5635	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0x05a7b544	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0x05bd4d40	sock_from_file
++EXPORT_SYMBOL vmlinux 0x05e11f6d	vc_cons
++EXPORT_SYMBOL vmlinux 0x05e20979	security_path_unlink
++EXPORT_SYMBOL vmlinux 0x05e5ffcb	skb_checksum
++EXPORT_SYMBOL vmlinux 0x05f762b7	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x0632fe0c	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x067b1997	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x068c7263	ioremap_cache
++EXPORT_SYMBOL vmlinux 0x069c1e0f	console_stop
++EXPORT_SYMBOL vmlinux 0x06a277ff	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x06a51886	param_set_uint
++EXPORT_SYMBOL vmlinux 0x06bf9c68	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0x06c0dae5	__kernel_fpu_end
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x070e0d72	md_check_recovery
++EXPORT_SYMBOL vmlinux 0x0720636b	alloc_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0x0727c4f3	iowrite8
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x074861b4	netif_device_attach
++EXPORT_SYMBOL vmlinux 0x076039bd	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x07608604	acpi_get_vendor_resource
++EXPORT_SYMBOL vmlinux 0x0769941e	start_tty
++EXPORT_SYMBOL vmlinux 0x07812919	__free_pages
++EXPORT_SYMBOL vmlinux 0x078822e4	gen_pool_create
++EXPORT_SYMBOL vmlinux 0x0797bebc	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x07a4b576	flex_array_free
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07bdbd93	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0x07ca9a93	make_kprojid
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07d50a24	csum_partial
++EXPORT_SYMBOL vmlinux 0x07e16efc	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x07efd174	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x0814248b	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x084c29e2	scsi_add_device
++EXPORT_SYMBOL vmlinux 0x08605111	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0x086a9c37	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0x086d8b79	down_write
++EXPORT_SYMBOL vmlinux 0x087f0c8b	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0x0897287b	acpi_disable_all_gpes
++EXPORT_SYMBOL vmlinux 0x08a0df68	mntput
++EXPORT_SYMBOL vmlinux 0x08a5c5f4	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0x08ddecf1	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x08fd4b26	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0x090bd510	eisa_bus_type
++EXPORT_SYMBOL vmlinux 0x09178ec3	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x0952a0d2	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x0982551c	nla_put
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x09913de0	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x09925de2	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0x09a9dd2d	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x09ab95bd	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x09b02b09	d_alloc
++EXPORT_SYMBOL vmlinux 0x09b1c515	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0x09bf0d28	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09e88526	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0x0a1b4e79	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x0a207563	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a3131f6	strnchr
++EXPORT_SYMBOL vmlinux 0x0a373226	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0x0a469d23	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0x0a47b918	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x0a661faa	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0x0a770832	register_memory_notifier
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0aa9adf3	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0ad7426a	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x0ae1d189	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x0af0dbce	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1be2c4	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b22388b	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0x0b33b7b0	vm_mmap
++EXPORT_SYMBOL vmlinux 0x0b48677a	__kfifo_init
++EXPORT_SYMBOL vmlinux 0x0b4b898e	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b62767d	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0x0b71b850	I_BDEV
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b861539	param_set_charp
++EXPORT_SYMBOL vmlinux 0x0b905c66	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x0b96c21d	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x0b9d891a	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x0bbad7b2	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bcc90a1	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0x0bcd6db2	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0x0bd2c455	filemap_flush
++EXPORT_SYMBOL vmlinux 0x0bdad31c	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x0be7dc4a	kill_fasync
++EXPORT_SYMBOL vmlinux 0x0bebbac5	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0x0bf6d8b0	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0x0c03fecb	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x0c23311a	get_fs_type
++EXPORT_SYMBOL vmlinux 0x0c261fc1	acpi_device_hid
++EXPORT_SYMBOL vmlinux 0x0c285555	iterate_mounts
++EXPORT_SYMBOL vmlinux 0x0c3980f9	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0x0c3c3956	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c46e6c5	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x0c52309e	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c59e532	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x0c69c353	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x0c6a91ba	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0x0c7a7cbd	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0x0c877bf1	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0x0c894937	register_netdevice
++EXPORT_SYMBOL vmlinux 0x0c8c3b8e	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0x0c929c7c	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0ca7b7a8	acpi_check_region
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0ccac2cc	inet6_offloads
++EXPORT_SYMBOL vmlinux 0x0cdb7d12	__kernel_fpu_begin
++EXPORT_SYMBOL vmlinux 0x0ce4d784	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x0cfdd54a	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x0d032ce6	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0x0d041a98	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0x0d1103af	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0x0d149277	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x0d3dda14	acpi_get_type
++EXPORT_SYMBOL vmlinux 0x0d4005ee	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0x0d452648	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x0d458e53	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0x0d4a8775	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x0d4d0e71	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d6979af	agp_copy_info
++EXPORT_SYMBOL vmlinux 0x0d7cfdb6	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0daeb716	acpi_bus_unregister_driver
++EXPORT_SYMBOL vmlinux 0x0db1a28c	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0x0db7718b	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0x0dc1a78c	bin2hex
++EXPORT_SYMBOL vmlinux 0x0dc5a6b4	genphy_update_link
++EXPORT_SYMBOL vmlinux 0x0dd599df	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x0e001fbe	dump_align
++EXPORT_SYMBOL vmlinux 0x0e3cbcf3	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x0e623dd1	devm_ioremap
++EXPORT_SYMBOL vmlinux 0x0e6a8e4b	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e77a423	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x0e99a6ff	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0x0eaf451e	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x0eb1ef6b	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0x0ebb0e5d	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0ee22bc1	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0x0eea0399	strscpy
++EXPORT_SYMBOL vmlinux 0x0efc1b4e	simple_getattr
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f1a18fa	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0x0f2126e4	__nd_driver_register
++EXPORT_SYMBOL vmlinux 0x0f441c90	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f8a4321	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0x0f980652	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0x0f9d6ec1	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0x0fa8ac8b	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fb4dcd4	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0x0fd00a68	acpi_clear_event
++EXPORT_SYMBOL vmlinux 0x0fed1b6e	dup_iter
++EXPORT_SYMBOL vmlinux 0x0fee0e19	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x102a3ae3	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x102c56de	irq_regs
++EXPORT_SYMBOL vmlinux 0x10313a79	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0x1035eec9	elevator_change
++EXPORT_SYMBOL vmlinux 0x106f13ab	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x107d2185	acpi_device_set_power
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x1089bd64	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0x1093eaa1	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x109cfcf7	find_vma
++EXPORT_SYMBOL vmlinux 0x109f1a1a	vme_slave_request
++EXPORT_SYMBOL vmlinux 0x10a661bc	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x11145431	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0x11247300	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0x113a960c	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x1187d77e	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x119950fd	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11a3191f	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0x11dd01ad	intel_scu_ipc_command
++EXPORT_SYMBOL vmlinux 0x11e29508	module_refcount
++EXPORT_SYMBOL vmlinux 0x11e73573	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x11f0a23f	agp_alloc_page_array
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x11f96848	__sb_end_write
++EXPORT_SYMBOL vmlinux 0x11fa82fa	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0x11fcf927	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0x1205a696	check_disk_change
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120d67d4	unregister_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x12166328	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x12176f91	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x12179f28	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0x121b4e4b	memremap
++EXPORT_SYMBOL vmlinux 0x1242cbdd	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0x1250c7e1	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x12564f6a	phy_suspend
++EXPORT_SYMBOL vmlinux 0x1265e29c	cont_write_begin
++EXPORT_SYMBOL vmlinux 0x126bf84c	netif_device_detach
++EXPORT_SYMBOL vmlinux 0x126d2af9	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0x12853028	vga_switcheroo_init_domain_pm_ops
++EXPORT_SYMBOL vmlinux 0x12a1dfa3	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12a578e5	release_pages
++EXPORT_SYMBOL vmlinux 0x12c1e94b	write_cache_pages
++EXPORT_SYMBOL vmlinux 0x12c2540a	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x12c3aa43	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0x12d7c062	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x12da5bb2	__kmalloc
++EXPORT_SYMBOL vmlinux 0x12e5e6b6	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0x12e6c146	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x12f4d8cd	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x130c67c8	bmap
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x1326e377	vfs_link
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x13315729	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0x133856b0	dma_alloc_from_coherent
++EXPORT_SYMBOL vmlinux 0x133b4944	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0x13468a44	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x134fa178	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0x13963c26	drop_super
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13e9c5ec	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x13f9de34	cpu_info
++EXPORT_SYMBOL vmlinux 0x1420b379	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0x1420dcb0	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x1421f6ad	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x142bebdd	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0x1447f2e1	input_register_device
++EXPORT_SYMBOL vmlinux 0x144a167c	path_is_under
++EXPORT_SYMBOL vmlinux 0x1452564f	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0x14649488	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x146c32b6	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x14730279	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x14776618	inet_del_offload
++EXPORT_SYMBOL vmlinux 0x1499d603	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0x149b000f	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x14b73163	pnp_release_card_device
++EXPORT_SYMBOL vmlinux 0x14c7229d	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x14d8da6c	netdev_info
++EXPORT_SYMBOL vmlinux 0x14e2765c	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x14e5e7f1	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x14e96f3e	md_error
++EXPORT_SYMBOL vmlinux 0x14f1c594	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0x14fada05	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0x14fc013f	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0x150389d6	acpi_processor_power_init_bm_check
++EXPORT_SYMBOL vmlinux 0x15218790	dev_load
++EXPORT_SYMBOL vmlinux 0x1521bd13	param_get_short
++EXPORT_SYMBOL vmlinux 0x1547bfd6	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x1560dc1a	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x1564c7ea	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x156a8a59	down_trylock
++EXPORT_SYMBOL vmlinux 0x15799c11	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0x158ea1b3	__kernel_write
++EXPORT_SYMBOL vmlinux 0x15a27381	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0x15b9aa70	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15e20fa9	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0x15e601b0	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x1603eebd	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x160dd533	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x160ea4c8	sfi_disabled
++EXPORT_SYMBOL vmlinux 0x1616cb30	acpi_evaluate_dsm
++EXPORT_SYMBOL vmlinux 0x161c4c4b	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x16305289	warn_slowpath_null
++EXPORT_SYMBOL vmlinux 0x1641b1e1	file_ns_capable
++EXPORT_SYMBOL vmlinux 0x164596be	vc_resize
++EXPORT_SYMBOL vmlinux 0x167e7f9d	__get_user_1
++EXPORT_SYMBOL vmlinux 0x1683a50b	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x168a9450	dev_notice
++EXPORT_SYMBOL vmlinux 0x168cf911	nla_reserve
++EXPORT_SYMBOL vmlinux 0x16a76d24	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0x16b9ef5a	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x16ca9338	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x16dc4d1f	fence_init
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x16ea34d9	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0x1707b49a	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x170c25ee	acpi_get_next_object
++EXPORT_SYMBOL vmlinux 0x171747eb	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0x1717bdd6	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0x172fade2	agp_generic_remove_memory
++EXPORT_SYMBOL vmlinux 0x1742fdcd	__vfs_read
++EXPORT_SYMBOL vmlinux 0x17440705	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0x174746c7	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x175f8b52	d_instantiate
++EXPORT_SYMBOL vmlinux 0x1784e4cf	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0x1789dad5	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x179651ac	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17f341a0	i8042_lock_chip
++EXPORT_SYMBOL vmlinux 0x17f389d9	__genl_register_family
++EXPORT_SYMBOL vmlinux 0x17fa37b2	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x17fbd52d	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x181342d0	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0x181df745	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x18211be8	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x1827c406	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x18354b92	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x1840d24a	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x18643cc1	uart_match_port
++EXPORT_SYMBOL vmlinux 0x186ab81f	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0x186ef6e1	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0x1871db37	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x1876d46d	path_get
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x188ea314	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x18d96501	atomic64_dec_if_positive_cx8
++EXPORT_SYMBOL vmlinux 0x18e04718	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x18e504e8	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x18f1560d	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0x18fdd924	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0x1916e38c	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x19473f16	blk_peek_request
++EXPORT_SYMBOL vmlinux 0x1951c4e1	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0x1961ca9b	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x196def78	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0x199574d8	setattr_copy
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19b74280	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19cc58b7	__netif_schedule
++EXPORT_SYMBOL vmlinux 0x19dd42f6	vme_irq_request
++EXPORT_SYMBOL vmlinux 0x19e24aa3	page_waitqueue
++EXPORT_SYMBOL vmlinux 0x19fbab84	register_key_type
++EXPORT_SYMBOL vmlinux 0x1a0ccb44	d_invalidate
++EXPORT_SYMBOL vmlinux 0x1a2aaa45	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0x1a45cb6c	acpi_disabled
++EXPORT_SYMBOL vmlinux 0x1a5266ba	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x1a536b95	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x1a541852	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x1a58427b	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x1a5d9bbd	acpi_pm_device_run_wake
++EXPORT_SYMBOL vmlinux 0x1a63af34	vga_switcheroo_process_delayed_switch
++EXPORT_SYMBOL vmlinux 0x1a6d8f03	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0x1a7c734a	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x1aae1c2b	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0x1abdd62e	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0x1ae09f75	_raw_write_unlock_irq
++EXPORT_SYMBOL vmlinux 0x1afb1aaa	acpi_mark_gpe_for_wake
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b096d5b	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b37cddd	eth_header_parse
++EXPORT_SYMBOL vmlinux 0x1b3e7fa3	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x1b4840fc	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x1b570d23	acpi_warning
++EXPORT_SYMBOL vmlinux 0x1b5e65ec	would_dump
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b7341c8	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x1b7a4413	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b853d0d	nd_namespace_blk_validate
++EXPORT_SYMBOL vmlinux 0x1b8b95ad	i8042_unlock_chip
++EXPORT_SYMBOL vmlinux 0x1b943a6b	block_write_begin
++EXPORT_SYMBOL vmlinux 0x1ba19d75	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x1ba63dc0	skb_split
++EXPORT_SYMBOL vmlinux 0x1bac5d82	get_phy_device
++EXPORT_SYMBOL vmlinux 0x1bb198fe	save_mount_options
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bb90ad2	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0x1bba4370	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0x1bc9fd46	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0x1bd4b8b1	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x1be1dd26	lg_global_lock
++EXPORT_SYMBOL vmlinux 0x1c114a6a	vm_event_states
++EXPORT_SYMBOL vmlinux 0x1c1cdd5c	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x1c2d93ec	pci_disable_device
++EXPORT_SYMBOL vmlinux 0x1c5bca43	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0x1c6aed56	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x1c8a04b0	acpi_reset
++EXPORT_SYMBOL vmlinux 0x1c93909a	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0x1c9d8ca0	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0x1ca8a4b6	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0x1ce86d70	register_netdev
++EXPORT_SYMBOL vmlinux 0x1cff571e	nobh_writepage
++EXPORT_SYMBOL vmlinux 0x1d05f5bd	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x1d1758fd	__nla_put
++EXPORT_SYMBOL vmlinux 0x1d1fbb28	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0x1d23db4d	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x1d271cea	vga_switcheroo_register_handler
++EXPORT_SYMBOL vmlinux 0x1d4634f0	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0x1d68f944	generic_write_end
++EXPORT_SYMBOL vmlinux 0x1d6ba276	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0x1d7ec392	set_posix_acl
++EXPORT_SYMBOL vmlinux 0x1d81d359	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0x1db8379d	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1dd5a2f0	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x1de62564	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0x1de74f72	acpi_execute_simple_method
++EXPORT_SYMBOL vmlinux 0x1dec163b	sk_dst_check
++EXPORT_SYMBOL vmlinux 0x1dffd62e	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x1e0335da	seq_printf
++EXPORT_SYMBOL vmlinux 0x1e036c98	acpi_set_gpe
++EXPORT_SYMBOL vmlinux 0x1e047854	warn_slowpath_fmt
++EXPORT_SYMBOL vmlinux 0x1e0c2be4	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e3bd117	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x1e4574f9	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x1e46bab0	netdev_emerg
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ea7b2fd	netdev_crit
++EXPORT_SYMBOL vmlinux 0x1eb922a3	IO_APIC_get_PCI_irq_vector
++EXPORT_SYMBOL vmlinux 0x1ec6e935	icmpv6_send
++EXPORT_SYMBOL vmlinux 0x1ed52dbe	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0x1edca132	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0x1ee15143	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0x1f19bc2c	blk_end_request
++EXPORT_SYMBOL vmlinux 0x1f210f1f	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0x1f239b99	vga_con
++EXPORT_SYMBOL vmlinux 0x1f2f7536	blkdev_put
++EXPORT_SYMBOL vmlinux 0x1f2f8ee6	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0x1f40ad0b	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0x1f51f114	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0x1f5c23b1	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x1f5f55b7	nd_region_acquire_lane
++EXPORT_SYMBOL vmlinux 0x1f660d04	posix_test_lock
++EXPORT_SYMBOL vmlinux 0x1f6cda9a	skb_find_text
++EXPORT_SYMBOL vmlinux 0x1f71e00f	i2c_master_send
++EXPORT_SYMBOL vmlinux 0x1f76aa57	softnet_data
++EXPORT_SYMBOL vmlinux 0x1f7e807f	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x1f9e7741	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0x1fb31b17	netdev_features_change
++EXPORT_SYMBOL vmlinux 0x1fbacb6f	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fca1021	key_task_permission
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fda98d6	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0x1fe0e7c3	up_read
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1fed47cd	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x2005e68a	acpi_remove_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x20092385	acpi_enter_sleep_state_s4bios
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x201b0ac0	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0x20205f64	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0x20263e8a	__quota_error
++EXPORT_SYMBOL vmlinux 0x202f4e92	acpi_extract_package
++EXPORT_SYMBOL vmlinux 0x2039c511	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x205869f4	set_bh_page
++EXPORT_SYMBOL vmlinux 0x2058afe1	single_release
++EXPORT_SYMBOL vmlinux 0x205b9ba6	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x206f4f48	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x2075f60e	vme_master_request
++EXPORT_SYMBOL vmlinux 0x207cf4d8	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0x207ec9a3	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0x2084deb2	__skb_checksum
++EXPORT_SYMBOL vmlinux 0x208739f6	acpi_load_table
++EXPORT_SYMBOL vmlinux 0x208ba319	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x209b350c	nf_reinject
++EXPORT_SYMBOL vmlinux 0x209d5185	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0x209f8f4d	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x20a406fe	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20ae58d0	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0x20b554f8	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x20c2a7db	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20c6192f	intel_scu_ipc_ioread32
++EXPORT_SYMBOL vmlinux 0x20d9fc73	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0x20dd4091	request_key_async
++EXPORT_SYMBOL vmlinux 0x20ddd744	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20ef4f75	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0x20f3f09b	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0x20f95c99	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x21621380	current_task
++EXPORT_SYMBOL vmlinux 0x216c373d	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0x2198ac67	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x2199adcb	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x21a701fe	fence_signal
++EXPORT_SYMBOL vmlinux 0x21b88c43	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21e992a5	ida_simple_get
++EXPORT_SYMBOL vmlinux 0x21fa1ffb	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x2207a57f	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x222b730b	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x22334164	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0x223bb541	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x224d80a2	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x2256fafa	div64_u64_rem
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x226c46e5	setup_new_exec
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x2289311d	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22d4b37d	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x22dbfc06	console_start
++EXPORT_SYMBOL vmlinux 0x22dce054	udp_set_csum
++EXPORT_SYMBOL vmlinux 0x22dfdd06	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x22fc4f3a	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x232d18ec	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0x233646de	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x23406715	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x2345c190	dquot_resume
++EXPORT_SYMBOL vmlinux 0x2348ca25	bdevname
++EXPORT_SYMBOL vmlinux 0x2350e4bd	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x235c2dc6	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0x236399d9	inode_init_once
++EXPORT_SYMBOL vmlinux 0x2364adcd	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x23807591	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0x23833ca8	free_task
++EXPORT_SYMBOL vmlinux 0x23a4d525	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0x23a548e9	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23ab824b	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0x23ac455d	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23f77e61	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x243b88f2	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x244c702e	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0x2458cd01	unload_nls
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x246020de	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0x24827895	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x248aa838	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0x2499b5de	ps2_drain
++EXPORT_SYMBOL vmlinux 0x249a12be	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x249d4aff	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x24a7e10b	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0x24d6bb50	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0x24f60a12	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0x24f62170	ata_print_version
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x250113b4	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x250a1c90	dump_truncate
++EXPORT_SYMBOL vmlinux 0x250bed57	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x25464cd4	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0x256d0056	kill_bdev
++EXPORT_SYMBOL vmlinux 0x256e4dc7	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x257ce822	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x2582f53f	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x258518b5	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0x25b9a46f	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x25be7d0b	up_write
++EXPORT_SYMBOL vmlinux 0x25cbcc6e	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0x25e8ed29	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x260790f4	acpi_bus_get_status
++EXPORT_SYMBOL vmlinux 0x262784c4	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x266ad7d3	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0x268cc6a2	sys_close
++EXPORT_SYMBOL vmlinux 0x26b3e79f	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x26bb950b	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0x26bcfa9c	acpi_evaluate_ost
++EXPORT_SYMBOL vmlinux 0x26c7c853	agp_generic_alloc_user
++EXPORT_SYMBOL vmlinux 0x26cb34a2	mempool_create
++EXPORT_SYMBOL vmlinux 0x26e298e0	unregister_memory_notifier
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26ebfa7d	km_report
++EXPORT_SYMBOL vmlinux 0x271805b8	phy_device_remove
++EXPORT_SYMBOL vmlinux 0x271cba95	acpi_bus_private_data_handler
++EXPORT_SYMBOL vmlinux 0x27208dcd	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0x27294c6f	dget_parent
++EXPORT_SYMBOL vmlinux 0x272fb2c0	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x2746236d	__d_drop
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x274b0294	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x274bb050	clkdev_drop
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x274ef82f	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0x276828fd	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0x277b932f	agp_alloc_bridge
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x27882b9b	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0x278b8a4f	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0x278fa2a6	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0x27989a92	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0x279deecc	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0x27ae7d0c	ec_transaction
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27e3bb09	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0x27ffe683	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x2840757d	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0x287557d1	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0x2884e294	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x2890042f	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28ab60c1	tty_write_room
++EXPORT_SYMBOL vmlinux 0x28b715a6	isapnp_cfg_end
++EXPORT_SYMBOL vmlinux 0x28e09af1	iosf_mbi_available
++EXPORT_SYMBOL vmlinux 0x29015c26	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x292f53dc	kill_pid
++EXPORT_SYMBOL vmlinux 0x2939baa3	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x294fbab3	netdev_warn
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x2960c69c	x86_hyper_xen
++EXPORT_SYMBOL vmlinux 0x29899e1a	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x298f1766	pnp_possible_config
++EXPORT_SYMBOL vmlinux 0x29a0772a	arp_send
++EXPORT_SYMBOL vmlinux 0x29a16802	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x29a90f00	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0x29ac8936	block_commit_write
++EXPORT_SYMBOL vmlinux 0x29bc0efa	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0x29c34879	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0x29cd334e	skb_trim
++EXPORT_SYMBOL vmlinux 0x29cf20c1	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0x29dc064b	elv_rb_find
++EXPORT_SYMBOL vmlinux 0x29fdda53	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a40251e	agp3_generic_tlbflush
++EXPORT_SYMBOL vmlinux 0x2a4d732e	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0x2a521108	get_super_thawed
++EXPORT_SYMBOL vmlinux 0x2a565a25	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0x2a59d5d4	dma_release_from_coherent
++EXPORT_SYMBOL vmlinux 0x2a5def2f	intel_scu_ipc_iowrite32
++EXPORT_SYMBOL vmlinux 0x2a6181b1	arch_dma_alloc_attrs
++EXPORT_SYMBOL vmlinux 0x2a6756a2	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0x2a813c49	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0x2a83a11c	vga_switcheroo_get_client_state
++EXPORT_SYMBOL vmlinux 0x2a8ad21a	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x2a9f4e65	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0x2aa0e4fc	strncasecmp
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2abaf1af	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2ae5d336	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b1544c7	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b678539	seq_putc
++EXPORT_SYMBOL vmlinux 0x2b6b7eb5	tcp_filter
++EXPORT_SYMBOL vmlinux 0x2b795e35	vfs_create
++EXPORT_SYMBOL vmlinux 0x2b7d5a49	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0x2b84cc3e	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x2b9187ea	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0x2b970dd9	input_register_handle
++EXPORT_SYMBOL vmlinux 0x2b99149f	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2bb55d6e	acpi_remove_notify_handler
++EXPORT_SYMBOL vmlinux 0x2be11e4b	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x2bfeb410	acpi_get_handle
++EXPORT_SYMBOL vmlinux 0x2c14323a	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c3f72ed	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0x2c46958c	__ps2_command
++EXPORT_SYMBOL vmlinux 0x2c4b6e73	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0x2c65452b	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x2c71a7fc	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0x2c763d32	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x2c94466c	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x2c994707	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0x2ca319a6	wrmsrl_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x2cb29b88	skb_make_writable
++EXPORT_SYMBOL vmlinux 0x2cb9abeb	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x2cc40ecf	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0x2cf637c9	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x2d004a15	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d144e21	rdmsrl_on_cpu
++EXPORT_SYMBOL vmlinux 0x2d15de94	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d334299	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d37342e	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0x2d56f1cd	may_umount
++EXPORT_SYMBOL vmlinux 0x2d9f6bc9	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x2d9fbeef	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0x2da60ed3	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0x2da87cfc	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0x2da8e923	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x2dc462b3	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0x2dd16564	arch_register_cpu
++EXPORT_SYMBOL vmlinux 0x2dd9a36b	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x2ddafb53	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0x2dedc4c2	acpi_format_exception
++EXPORT_SYMBOL vmlinux 0x2def7f76	rtc_cmos_write
++EXPORT_SYMBOL vmlinux 0x2e0fbb04	fasync_helper
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e2dc3aa	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0x2e329bb8	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0x2e33dceb	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x2e423c32	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x2e4cb012	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x2e518644	bioset_free
++EXPORT_SYMBOL vmlinux 0x2e61fd28	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x2e660964	security_file_permission
++EXPORT_SYMBOL vmlinux 0x2e78066f	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0x2e79809a	register_qdisc
++EXPORT_SYMBOL vmlinux 0x2e8cdd37	tc_classify
++EXPORT_SYMBOL vmlinux 0x2ec42ea7	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x2ec524ad	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x2ecca71a	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0x2ed4f03a	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0x2ee0433c	inet_ioctl
++EXPORT_SYMBOL vmlinux 0x2ee9fb32	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f1d39f4	kernel_bind
++EXPORT_SYMBOL vmlinux 0x2f384db3	acpi_is_video_device
++EXPORT_SYMBOL vmlinux 0x2f4254d0	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2f74a72f	fb_pan_display
++EXPORT_SYMBOL vmlinux 0x2f773463	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x2f7a0343	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x2f9aefa4	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fca5851	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x2fdac583	security_mmap_file
++EXPORT_SYMBOL vmlinux 0x2fdbaba3	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0x2fdfbe4e	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2ff9917b	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x301ba631	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0x30226ddf	agp_device_command
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x303d4a68	dump_skip
++EXPORT_SYMBOL vmlinux 0x30437ef8	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x3062b725	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x306acf72	blk_rq_init
++EXPORT_SYMBOL vmlinux 0x307921ef	blk_make_request
++EXPORT_SYMBOL vmlinux 0x307a0d05	fb_get_mode
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x30928d17	input_reset_device
++EXPORT_SYMBOL vmlinux 0x30942ae2	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30b04526	ida_init
++EXPORT_SYMBOL vmlinux 0x30b3a467	tty_unlock
++EXPORT_SYMBOL vmlinux 0x30c3d516	lockref_put_return
++EXPORT_SYMBOL vmlinux 0x30d233ed	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0x30d436af	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x30f688a7	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0x3102a378	sk_free
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310917fe	sort
++EXPORT_SYMBOL vmlinux 0x311cf8b7	inode_init_always
++EXPORT_SYMBOL vmlinux 0x31288e09	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0x312a1ad8	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0x31380354	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x3139280c	dev_err
++EXPORT_SYMBOL vmlinux 0x313c3de3	pipe_lock
++EXPORT_SYMBOL vmlinux 0x313c9caf	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x3148a748	pnp_start_dev
++EXPORT_SYMBOL vmlinux 0x314e9074	revert_creds
++EXPORT_SYMBOL vmlinux 0x316d31e9	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0x316d50e0	dcb_setapp
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x3191f109	__krealloc
++EXPORT_SYMBOL vmlinux 0x31af083a	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x31b220a1	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0x31b6a7da	security_path_truncate
++EXPORT_SYMBOL vmlinux 0x31df29b3	nvm_end_io
++EXPORT_SYMBOL vmlinux 0x31e76b57	recalibrate_cpu_khz
++EXPORT_SYMBOL vmlinux 0x31ebb847	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0x31ec44a0	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0x31f0bb78	__kmap_atomic_idx
++EXPORT_SYMBOL vmlinux 0x3202435a	wrmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0x32312c31	put_cmsg
++EXPORT_SYMBOL vmlinux 0x32350ed6	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0x32410659	nd_device_register
++EXPORT_SYMBOL vmlinux 0x3243a457	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x3258b80c	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0x326425ca	pci_unmap_biosrom
++EXPORT_SYMBOL vmlinux 0x328b1561	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0x32a72305	netdev_printk
++EXPORT_SYMBOL vmlinux 0x32b5fa2f	mem_section
++EXPORT_SYMBOL vmlinux 0x32d889ae	pci_iomap
++EXPORT_SYMBOL vmlinux 0x32dc8c9f	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0x32ddc69b	nd_sb_checksum
++EXPORT_SYMBOL vmlinux 0x32de1ab3	tty_register_device
++EXPORT_SYMBOL vmlinux 0x32e6f1a0	acpi_video_backlight_string
++EXPORT_SYMBOL vmlinux 0x32e821d8	fb_class
++EXPORT_SYMBOL vmlinux 0x32f61d8e	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0x32f8962f	iget5_locked
++EXPORT_SYMBOL vmlinux 0x3305c460	seq_open
++EXPORT_SYMBOL vmlinux 0x33201504	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0x3333e634	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0x335e988d	sk_capable
++EXPORT_SYMBOL vmlinux 0x33849545	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0x339a88b8	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x33a6cfb7	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33db6380	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0x33dbfd93	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x33e925a2	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x340758db	ping_prot
++EXPORT_SYMBOL vmlinux 0x340df4c0	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0x34125497	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0x34127593	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0x342f60fe	apm_info
++EXPORT_SYMBOL vmlinux 0x343c42f1	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x3446592b	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x349b2eaf	nf_log_trace
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34b9ece1	address_space_init_once
++EXPORT_SYMBOL vmlinux 0x34de7b02	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x34edb87e	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x34f83df1	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x353a58c0	d_add_ci
++EXPORT_SYMBOL vmlinux 0x353de98f	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x353e21e3	acpi_bios_warning
++EXPORT_SYMBOL vmlinux 0x354d8cf9	ip6_xmit
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x356e17c4	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0x356f9511	param_set_bint
++EXPORT_SYMBOL vmlinux 0x3584235a	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x35873d9d	pci_release_region
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35a90400	bio_endio
++EXPORT_SYMBOL vmlinux 0x35a99911	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x35e02c7e	generic_make_request
++EXPORT_SYMBOL vmlinux 0x35fb16db	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x36007adb	alloc_disk
++EXPORT_SYMBOL vmlinux 0x360b1afe	probe_irq_mask
++EXPORT_SYMBOL vmlinux 0x360b5f6d	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0x3613bbba	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0x36386f64	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0x3650de35	ether_setup
++EXPORT_SYMBOL vmlinux 0x3654ffce	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x365fa1c1	netif_rx
++EXPORT_SYMBOL vmlinux 0x3676f3fb	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0x367ba856	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0x36918ff5	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0x369ccb6c	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36c6af51	intel_scu_ipc_iowrite8
++EXPORT_SYMBOL vmlinux 0x36c6b807	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0x36efd357	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x36efdb61	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x36f224fc	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0x36f659cd	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0x36fdda67	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x370f9850	efi
++EXPORT_SYMBOL vmlinux 0x371dd8f1	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0x37201c5f	tty_check_change
++EXPORT_SYMBOL vmlinux 0x3722cc61	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0x373b4cc7	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x37401fff	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x3743767e	pci_match_id
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x37489b83	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0x37552520	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0x3757cf64	led_update_brightness
++EXPORT_SYMBOL vmlinux 0x379dee5f	trace_print_symbols_seq_u64
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37b8b39e	screen_info
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37c9994e	inet_frag_find
++EXPORT_SYMBOL vmlinux 0x37cb30ee	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x37db8f19	dmi_get_date
++EXPORT_SYMBOL vmlinux 0x37df471c	sget_userns
++EXPORT_SYMBOL vmlinux 0x37e74642	get_jiffies_64
++EXPORT_SYMBOL vmlinux 0x37eb8953	param_set_short
++EXPORT_SYMBOL vmlinux 0x37f614b7	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x38099e13	wrmsrl_on_cpu
++EXPORT_SYMBOL vmlinux 0x380fe29b	netlink_set_err
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x381ccc13	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x38282cfa	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x38364b41	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0x383c02f2	serio_close
++EXPORT_SYMBOL vmlinux 0x38462dd7	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0x38500d86	dquot_enable
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x388799f6	unregister_kmmio_probe
++EXPORT_SYMBOL vmlinux 0x388ad2c3	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0x388e1ccf	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38cf470c	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0x38e55616	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0x390502d1	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x39081193	__max_logical_packages
++EXPORT_SYMBOL vmlinux 0x390b9800	ps2_init
++EXPORT_SYMBOL vmlinux 0x3913c248	bdi_init
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x394357bb	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x394fcd61	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0x3954824e	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x396515cf	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0x396bf5d5	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x3988de94	simple_readpage
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x39a055f3	acpi_remove_gpe_handler
++EXPORT_SYMBOL vmlinux 0x39abc73b	__register_chrdev
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39bbb380	ppp_input_error
++EXPORT_SYMBOL vmlinux 0x39c71537	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x39d2c62e	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0x39f1c2f4	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x3a046e7a	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0x3a08475f	platform_thermal_notify
++EXPORT_SYMBOL vmlinux 0x3a18c430	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0x3a1ac054	set_normalized_timespec64
++EXPORT_SYMBOL vmlinux 0x3a2a305e	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0x3a32839e	intel_gtt_chipset_flush
++EXPORT_SYMBOL vmlinux 0x3a384715	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x3a3f5146	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x3a49328c	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0x3a65a808	request_firmware
++EXPORT_SYMBOL vmlinux 0x3a65fb24	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x3a9931b7	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3ab73ef4	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x3abb2f6c	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x3ad5b432	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0x3ae22223	simple_unlink
++EXPORT_SYMBOL vmlinux 0x3aee4c6a	nvm_register
++EXPORT_SYMBOL vmlinux 0x3b201620	machine_real_restart
++EXPORT_SYMBOL vmlinux 0x3b2313bc	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0x3b24db2e	dev_change_flags
++EXPORT_SYMBOL vmlinux 0x3b5d5bba	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b6d1e36	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0x3b6f6cd2	udp_table
++EXPORT_SYMBOL vmlinux 0x3b85ccc4	seq_release
++EXPORT_SYMBOL vmlinux 0x3b898375	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0x3b8f068d	kern_unmount
++EXPORT_SYMBOL vmlinux 0x3b8fe8b8	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0x3bad4038	cdev_add
++EXPORT_SYMBOL vmlinux 0x3bae9776	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x3bb5114a	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x3bb9de88	blkdev_get
++EXPORT_SYMBOL vmlinux 0x3bbc6381	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0x3bbf5058	find_lock_entry
++EXPORT_SYMBOL vmlinux 0x3bc7fdc7	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0x3c2e774c	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0x3c351670	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0x3c3b77cc	set_security_override
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c4f1ece	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0x3c558be0	tty_hangup
++EXPORT_SYMBOL vmlinux 0x3c6c89dc	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x3c6dff47	param_ops_short
++EXPORT_SYMBOL vmlinux 0x3c6fd4fa	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0x3c76756c	nvdimm_namespace_capacity
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c869396	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0x3ca6042d	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x3cb3931b	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x3cc6943c	path_put
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3cec93c0	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x3d1391e2	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x3d2c6949	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0x3d35a770	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0x3d44d1e9	audit_log
++EXPORT_SYMBOL vmlinux 0x3d5d90de	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0x3d68d9c2	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0x3d753d06	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0x3d7c1ed7	msrs_alloc
++EXPORT_SYMBOL vmlinux 0x3d81474b	arp_xmit
++EXPORT_SYMBOL vmlinux 0x3da171f9	pci_mem_start
++EXPORT_SYMBOL vmlinux 0x3da19c2c	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x3dbbbc25	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x3dc18726	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3dd976b8	set_wb_congested
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e2ae3a8	acpi_release_global_lock
++EXPORT_SYMBOL vmlinux 0x3e654f49	acpi_decode_pld_buffer
++EXPORT_SYMBOL vmlinux 0x3e68f8fc	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x3e7dba5f	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x3e882943	pcibios_align_resource
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x3e9a594a	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x3ebec468	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0x3ed90024	sock_init_data
++EXPORT_SYMBOL vmlinux 0x3ef78d80	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x3eff5ac2	intel_scu_ipc_writev
++EXPORT_SYMBOL vmlinux 0x3f026730	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x3f0546a8	ioread32_rep
++EXPORT_SYMBOL vmlinux 0x3f1602c7	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x3f20ca97	rtc_lock
++EXPORT_SYMBOL vmlinux 0x3f32a0b5	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f4ae4c4	md_reload_sb
++EXPORT_SYMBOL vmlinux 0x3f59b446	scsi_init_io
++EXPORT_SYMBOL vmlinux 0x3f616ce2	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x3f87af6f	account_page_redirty
++EXPORT_SYMBOL vmlinux 0x3f927b42	dquot_release
++EXPORT_SYMBOL vmlinux 0x3fa1ce2a	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0x3fb6346e	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x3fc39b1d	nd_region_release_lane
++EXPORT_SYMBOL vmlinux 0x3fcb96b2	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x40115fac	iget_locked
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4039918a	clk_register_clkdev
++EXPORT_SYMBOL vmlinux 0x404f144c	vm_map_ram
++EXPORT_SYMBOL vmlinux 0x4059792f	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x405bf3ee	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x407fdf47	security_path_rename
++EXPORT_SYMBOL vmlinux 0x408c4250	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x4097fa45	acpi_read_bit_register
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x409ea739	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a2d1dd	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40c89d46	acpi_get_table_by_index
++EXPORT_SYMBOL vmlinux 0x40cea3e5	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40e7960b	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x412d9c84	dquot_disable
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x4162b91d	ht_create_irq
++EXPORT_SYMBOL vmlinux 0x41769eb6	ata_link_printk
++EXPORT_SYMBOL vmlinux 0x41862ad4	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x418a5367	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x41af0ed9	__ht_create_irq
++EXPORT_SYMBOL vmlinux 0x41af99b9	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0x41bb7530	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0x41ca6374	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0x41eee8fd	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0x42013863	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x422c809e	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0x42350e8d	ucs2_strlen
++EXPORT_SYMBOL vmlinux 0x423ba79c	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x42595e58	vgacon_text_force
++EXPORT_SYMBOL vmlinux 0x42749ac5	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x428271b0	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x428282f6	dma_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x428364bd	inet_select_addr
++EXPORT_SYMBOL vmlinux 0x4292364c	schedule
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42a7dc1a	param_get_ullong
++EXPORT_SYMBOL vmlinux 0x42adcee5	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0x42c8de35	ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x42ce3b3d	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0x42ce59a6	dput
++EXPORT_SYMBOL vmlinux 0x42d20d8b	put_tty_driver
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x4330e7dd	register_md_personality
++EXPORT_SYMBOL vmlinux 0x4340a3ea	amd_northbridges
++EXPORT_SYMBOL vmlinux 0x43484b9a	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0x4351018f	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x436967ca	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x436c2179	iowrite32
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x439e583f	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x43d08e85	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0x43d30101	to_nd_btt
++EXPORT_SYMBOL vmlinux 0x43defb6f	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0x43e19eb7	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x43f5b388	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0x43f7e3b0	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x442cc112	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0x44366cfc	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0x44382328	neigh_for_each
++EXPORT_SYMBOL vmlinux 0x44438b96	hex2bin
++EXPORT_SYMBOL vmlinux 0x444494d5	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x4467c706	param_ops_long
++EXPORT_SYMBOL vmlinux 0x4467fdaf	do_splice_direct
++EXPORT_SYMBOL vmlinux 0x446dfb4d	generic_fillattr
++EXPORT_SYMBOL vmlinux 0x44776a63	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0x4484f7b0	generic_permission
++EXPORT_SYMBOL vmlinux 0x44890026	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0x448e085f	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x449fe84b	acpi_set_firmware_waking_vectors
++EXPORT_SYMBOL vmlinux 0x44a706d6	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0x44aaf30f	tsc_khz
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44d65f7f	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0x44e05974	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44ef3fda	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0x44f50795	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0x4500f02c	iunique
++EXPORT_SYMBOL vmlinux 0x45081703	ec_get_handle
++EXPORT_SYMBOL vmlinux 0x450bcadb	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0x451e324a	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0x45239442	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0x4536cc20	eth_header
++EXPORT_SYMBOL vmlinux 0x453863c9	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0x453b9d3e	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x453da64d	i2c_use_client
++EXPORT_SYMBOL vmlinux 0x455d653c	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x457ccd89	cad_pid
++EXPORT_SYMBOL vmlinux 0x458381c8	agp_generic_alloc_pages
++EXPORT_SYMBOL vmlinux 0x45849218	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0x458c5f6a	dma_find_channel
++EXPORT_SYMBOL vmlinux 0x4595fc5b	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45a7d9bc	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x45c111de	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x45c67aa8	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0x45cda4c3	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0x45d0a7b9	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0x45d4aa1b	fb_set_var
++EXPORT_SYMBOL vmlinux 0x460fbeee	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x460fe44a	fd_install
++EXPORT_SYMBOL vmlinux 0x4629334c	__preempt_count
++EXPORT_SYMBOL vmlinux 0x462a2e75	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x462abdd4	__neigh_create
++EXPORT_SYMBOL vmlinux 0x462db0d5	vfs_writef
++EXPORT_SYMBOL vmlinux 0x462fc680	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x4663f2de	nd_iostat_end
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x467f0e03	submit_bio
++EXPORT_SYMBOL vmlinux 0x4686a968	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x46a89d84	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0x46af6359	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x46c3bb77	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x46cd836e	d_genocide
++EXPORT_SYMBOL vmlinux 0x46eb47ac	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x470120b4	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0x4706d678	param_set_ushort
++EXPORT_SYMBOL vmlinux 0x4717ccb8	dev_printk
++EXPORT_SYMBOL vmlinux 0x471cbaf7	neigh_table_init
++EXPORT_SYMBOL vmlinux 0x471dc344	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x473f1a4a	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x4740b3bc	xen_arch_unregister_cpu
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x47529fc5	pnp_unregister_card_driver
++EXPORT_SYMBOL vmlinux 0x475f010b	acpi_purge_cached_objects
++EXPORT_SYMBOL vmlinux 0x4784a50f	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0x4785936a	pci_biosrom_size
++EXPORT_SYMBOL vmlinux 0x4788aee4	tcf_register_action
++EXPORT_SYMBOL vmlinux 0x478d10b2	ht_destroy_irq
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x47a2dbe4	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0x47ec67f2	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0x47ede854	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x47f37f88	i2c_transfer
++EXPORT_SYMBOL vmlinux 0x47f56402	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0x481630c3	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0x48193639	acpi_lid_open
++EXPORT_SYMBOL vmlinux 0x481cb9ab	acpi_enter_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x482cf89d	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x484b1239	phy_detach
++EXPORT_SYMBOL vmlinux 0x48526403	skb_put
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x48696ec9	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0x486ca6a6	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0x48851be5	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48e68b9e	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0x490134ab	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0x49041114	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x49285ba3	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x49330450	set_nlink
++EXPORT_SYMBOL vmlinux 0x49387ea2	mmc_start_req
++EXPORT_SYMBOL vmlinux 0x494637ec	del_gendisk
++EXPORT_SYMBOL vmlinux 0x494c9fd9	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x495c78ac	mpage_readpages
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x496d9948	__blk_end_request
++EXPORT_SYMBOL vmlinux 0x4970bdb7	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x49791c92	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0x497af091	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x497c5a94	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0x499cca42	fb_show_logo
++EXPORT_SYMBOL vmlinux 0x49a98b0f	serio_bus
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b163b8	acpi_bus_scan
++EXPORT_SYMBOL vmlinux 0x49c018e5	devm_clk_put
++EXPORT_SYMBOL vmlinux 0x49cb0a79	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0x49d9c432	dquot_initialize
++EXPORT_SYMBOL vmlinux 0x49ea8871	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x49eaa05e	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x49fb4973	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0x49fd9edd	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x4a0a178e	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0x4a18f74d	contig_page_data
++EXPORT_SYMBOL vmlinux 0x4a3f27d9	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x4a54a8ef	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0x4a619f83	memcpy
++EXPORT_SYMBOL vmlinux 0x4a6ec53d	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x4ab000ee	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4ac02ddb	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4ae7e376	kern_path_create
++EXPORT_SYMBOL vmlinux 0x4ae9eab4	iov_iter_init
++EXPORT_SYMBOL vmlinux 0x4aebb9f5	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b085dbf	agp3_generic_configure
++EXPORT_SYMBOL vmlinux 0x4b1ec3e2	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x4b54695d	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b667176	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0x4b97b497	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0x4b9daf96	noop_llseek
++EXPORT_SYMBOL vmlinux 0x4b9dfb04	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0x4badf346	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4bc722e4	bio_add_page
++EXPORT_SYMBOL vmlinux 0x4bcf03a4	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x4bdec99e	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x4be85a03	memweight
++EXPORT_SYMBOL vmlinux 0x4c07a7e0	acpi_processor_unregister_performance
++EXPORT_SYMBOL vmlinux 0x4c242bb4	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x4c29dcbf	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x4c2ae700	strnstr
++EXPORT_SYMBOL vmlinux 0x4c318bdd	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c56bbeb	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0x4c622828	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x4c878322	iosf_mbi_modify
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4cea8302	___preempt_schedule_notrace
++EXPORT_SYMBOL vmlinux 0x4d00aa00	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x4d3156fd	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0x4d3c153f	sigprocmask
++EXPORT_SYMBOL vmlinux 0x4d3ca5fe	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x4d45d89e	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x4d4a095c	dma_ops
++EXPORT_SYMBOL vmlinux 0x4d560e6d	read_cache_pages
++EXPORT_SYMBOL vmlinux 0x4d640b13	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x4d6bce7b	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4d9e8026	flush_signals
++EXPORT_SYMBOL vmlinux 0x4da8a7ab	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4df44ca8	submit_bh
++EXPORT_SYMBOL vmlinux 0x4e237ed9	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0x4e27ee11	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0x4e2963f2	lock_fb_info
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e5a6d9e	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x4e64491c	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0x4e68c4a9	param_set_long
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e6eb5f2	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0x4e83e9c3	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x4e923032	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x4e99686d	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0x4ea25709	dql_reset
++EXPORT_SYMBOL vmlinux 0x4ebb764c	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x4ec18b60	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x4ecdf1a8	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x4ee3afb1	set_pages_wb
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f3d9ce5	md_write_end
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f5dc0e4	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x4f6041ef	dns_query
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f6b400b	_copy_from_user
++EXPORT_SYMBOL vmlinux 0x4f783f30	acpi_read
++EXPORT_SYMBOL vmlinux 0x4f85da50	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x4f8b5ddb	_copy_to_user
++EXPORT_SYMBOL vmlinux 0x4f93d7bc	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0x4f93fe16	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x4f99b4e5	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x4fbea81a	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0x4fd9284a	simple_lookup
++EXPORT_SYMBOL vmlinux 0x4fdee897	i8042_command
++EXPORT_SYMBOL vmlinux 0x4fe8dfd5	commit_creds
++EXPORT_SYMBOL vmlinux 0x4fec77b2	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x50069fa0	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x5011e39b	seq_path
++EXPORT_SYMBOL vmlinux 0x5012501f	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0x501f9fcc	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x5029fbbd	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0x50307d43	send_sig
++EXPORT_SYMBOL vmlinux 0x503d3062	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0x503f1792	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x50529870	acpi_get_gpe_status
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x50660b0a	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0x506e9bc8	freeze_super
++EXPORT_SYMBOL vmlinux 0x5079d1d4	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0x507a6e5b	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0x50880778	input_set_capability
++EXPORT_SYMBOL vmlinux 0x508f28f2	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0x509b64ea	acpi_has_method
++EXPORT_SYMBOL vmlinux 0x50a6173c	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0x50b66bcb	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x50b7bc86	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x50c53301	lock_rename
++EXPORT_SYMBOL vmlinux 0x50d66c78	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0x50d68377	arch_phys_wc_del
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x50e84822	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x50eedeb8	printk
++EXPORT_SYMBOL vmlinux 0x50f663a3	block_write_end
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x5131767b	elevator_init
++EXPORT_SYMBOL vmlinux 0x513280a1	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x5138fb7c	try_module_get
++EXPORT_SYMBOL vmlinux 0x513cba12	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0x514166a0	sock_efree
++EXPORT_SYMBOL vmlinux 0x514946f9	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0x51548bbd	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0x5154e657	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x515bb2d3	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0x51693764	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0x51719973	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x517d21c1	agp_unbind_memory
++EXPORT_SYMBOL vmlinux 0x5186518f	profile_pc
++EXPORT_SYMBOL vmlinux 0x51aaa8bd	napi_disable
++EXPORT_SYMBOL vmlinux 0x51d0a423	phy_connect
++EXPORT_SYMBOL vmlinux 0x51d12d4e	acpi_pci_disabled
++EXPORT_SYMBOL vmlinux 0x51ef33b8	kstrndup
++EXPORT_SYMBOL vmlinux 0x51f3ab0a	proc_set_user
++EXPORT_SYMBOL vmlinux 0x520130c0	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x52084841	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0x52095e19	acpi_get_data
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x52277796	blk_start_request
++EXPORT_SYMBOL vmlinux 0x522e63ff	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0x522f0685	unlock_page
++EXPORT_SYMBOL vmlinux 0x524babe7	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0x525e026f	acpi_os_unmap_generic_address
++EXPORT_SYMBOL vmlinux 0x528c709d	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x52af562a	__crc32c_le
++EXPORT_SYMBOL vmlinux 0x530b1e4c	rdmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x531b604e	__virt_addr_valid
++EXPORT_SYMBOL vmlinux 0x532abe6c	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x53322fdc	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x53329fbb	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x53569707	this_cpu_off
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x53636451	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0x5374c84f	override_creds
++EXPORT_SYMBOL vmlinux 0x537bd8c5	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0x539142f0	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0x5392753a	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x539af73c	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x53a43265	do_SAK
++EXPORT_SYMBOL vmlinux 0x53e53c21	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0x53eadb8d	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x53edb3d6	dev_warn
++EXPORT_SYMBOL vmlinux 0x54019a5d	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x540a3c40	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x54243e54	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0x5430f863	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x5431438a	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x54486818	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0x54487d60	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x544b0c11	acpi_lid_notifier_register
++EXPORT_SYMBOL vmlinux 0x544f134a	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x5459baf4	__napi_complete
++EXPORT_SYMBOL vmlinux 0x5464d3f6	acpi_remove_sci_handler
++EXPORT_SYMBOL vmlinux 0x546db734	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x54905a42	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x5497a310	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54ac5617	tty_lock
++EXPORT_SYMBOL vmlinux 0x54baf871	phy_find_first
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54e4f079	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54f24d1a	fence_default_wait
++EXPORT_SYMBOL vmlinux 0x54f815a8	vfs_write
++EXPORT_SYMBOL vmlinux 0x54f855b8	tcp_child_process
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x551bedc7	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x555908b9	udp_add_offload
++EXPORT_SYMBOL vmlinux 0x55604ab5	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x556ef673	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0x5590b69b	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x5594ef1f	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x5599e8a6	dquot_destroy
++EXPORT_SYMBOL vmlinux 0x559fce34	kobject_put
++EXPORT_SYMBOL vmlinux 0x55b19150	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x55e60a36	queued_spin_unlock_wait
++EXPORT_SYMBOL vmlinux 0x55f627ef	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0x56138112	finish_no_open
++EXPORT_SYMBOL vmlinux 0x5623968e	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x563952a3	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x563a6505	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x563d0111	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x5641419b	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0x56526adc	tty_port_put
++EXPORT_SYMBOL vmlinux 0x5676a3e5	intel_scu_ipc_ioread8
++EXPORT_SYMBOL vmlinux 0x5677e0c6	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x568b9f49	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x569f85a5	agp_put_bridge
++EXPORT_SYMBOL vmlinux 0x56a0743e	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0x56b318ed	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56d4f8ad	acl_by_type
++EXPORT_SYMBOL vmlinux 0x56df3c1a	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0x56e8b67e	genphy_resume
++EXPORT_SYMBOL vmlinux 0x56f75a95	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0x5705088a	__vmalloc
++EXPORT_SYMBOL vmlinux 0x571c8ea9	dma_mmap_from_coherent
++EXPORT_SYMBOL vmlinux 0x572497b1	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0x572b6e03	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x5733f61f	dmam_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x574e09cf	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0x57528b2c	mntget
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x575af70c	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x579b21c4	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0x579fbcd2	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0x57b4d4b1	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0x57ba72ab	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0x57c51a6b	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x57e9a8e1	pv_mmu_ops
++EXPORT_SYMBOL vmlinux 0x57f604c9	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0x58167e9f	agp_generic_destroy_page
++EXPORT_SYMBOL vmlinux 0x581a1e88	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x5836ad5c	mount_bdev
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x584738f9	rdmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x5857b225	ioread16_rep
++EXPORT_SYMBOL vmlinux 0x58604e4d	alloc_iova_mem
++EXPORT_SYMBOL vmlinux 0x586103be	acpi_setup_gpe_for_wake
++EXPORT_SYMBOL vmlinux 0x58720030	stop_tty
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58beab98	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x58d8f16c	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x58fdca1f	cdev_init
++EXPORT_SYMBOL vmlinux 0x58fef6f8	ist_info
++EXPORT_SYMBOL vmlinux 0x5905d860	vm_stat
++EXPORT_SYMBOL vmlinux 0x590d6ece	bio_copy_data
++EXPORT_SYMBOL vmlinux 0x59106416	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x5944d015	__cachemode2pte_tbl
++EXPORT_SYMBOL vmlinux 0x5949e765	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x59535195	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x5984481a	acpi_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0x59870462	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x59a2627a	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59bc9609	acpi_write_bit_register
++EXPORT_SYMBOL vmlinux 0x59e56f9c	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x59e8f569	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a2db87f	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x5a4896a8	__put_user_2
++EXPORT_SYMBOL vmlinux 0x5a4af7b2	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x5a685aa9	param_get_uint
++EXPORT_SYMBOL vmlinux 0x5a7e89a0	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x5a82c44a	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x5aa21744	nf_log_unset
++EXPORT_SYMBOL vmlinux 0x5aa81e3d	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0x5ac376a5	acpi_install_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x5adfac7a	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0x5af487c3	seq_puts
++EXPORT_SYMBOL vmlinux 0x5afdf317	con_is_bound
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5affdf1b	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0x5b047b51	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x5b11423c	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x5b1549e7	generic_setlease
++EXPORT_SYMBOL vmlinux 0x5b19634d	div_s64_rem
++EXPORT_SYMBOL vmlinux 0x5b1d75a8	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0x5b1da261	pci_save_state
++EXPORT_SYMBOL vmlinux 0x5b208506	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x5b7623b3	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x5b798306	user_revoke
++EXPORT_SYMBOL vmlinux 0x5b7c08c8	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0x5bab9b21	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0x5bb4c6ac	vfs_read
++EXPORT_SYMBOL vmlinux 0x5bc3469f	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0x5bc38dad	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0x5bc8d583	copy_from_user_overflow
++EXPORT_SYMBOL vmlinux 0x5bdb484f	__dst_free
++EXPORT_SYMBOL vmlinux 0x5be3f5e5	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x5bee4815	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0x5c0442fd	acpi_gbl_FADT
++EXPORT_SYMBOL vmlinux 0x5c236ae0	set_pages_array_uc
++EXPORT_SYMBOL vmlinux 0x5c30b1c8	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0x5c545234	ucs2_strncmp
++EXPORT_SYMBOL vmlinux 0x5c573ef3	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x5c672724	acpi_pm_device_sleep_state
++EXPORT_SYMBOL vmlinux 0x5c813f1a	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0x5c8ed799	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x5c8ee4cb	agp_find_bridge
++EXPORT_SYMBOL vmlinux 0x5c958c55	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0x5cc27596	agp_generic_create_gatt_table
++EXPORT_SYMBOL vmlinux 0x5cdb7f1a	kernel_connect
++EXPORT_SYMBOL vmlinux 0x5cdcf53a	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0x5ce2b43a	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5d051367	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x5d059486	pci_release_regions
++EXPORT_SYMBOL vmlinux 0x5d1aab15	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x5d2ce4b7	tty_port_init
++EXPORT_SYMBOL vmlinux 0x5d2e0057	x86_hyper_ms_hyperv
++EXPORT_SYMBOL vmlinux 0x5d2f7f99	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0x5d32d1fb	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x5d4b1d4a	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0x5d525787	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d6e060b	lease_modify
++EXPORT_SYMBOL vmlinux 0x5d74dbcf	pnp_range_reserved
++EXPORT_SYMBOL vmlinux 0x5d8475e0	completion_done
++EXPORT_SYMBOL vmlinux 0x5daa05ab	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0x5dee5611	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0x5dffb9b0	x86_hyper_vmware
++EXPORT_SYMBOL vmlinux 0x5e0cde9e	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0x5e21ef0f	agp_free_memory
++EXPORT_SYMBOL vmlinux 0x5e544e5c	phy_print_status
++EXPORT_SYMBOL vmlinux 0x5e5d76e4	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0x5e5eb555	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0x5e6fb6d5	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x5e866d85	prandom_bytes
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5e99f367	component_match_add
++EXPORT_SYMBOL vmlinux 0x5eaf2b01	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ec2593f	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5ed3e3af	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0x5ed80cb5	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x5ed958c0	netdev_change_features
++EXPORT_SYMBOL vmlinux 0x5ef74148	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f06c8ab	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f10b2e6	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0x5f1645b8	irq_set_chip
++EXPORT_SYMBOL vmlinux 0x5f1a4ccf	intel_scu_ipc_update_register
++EXPORT_SYMBOL vmlinux 0x5f4fadc3	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0x5f6557fb	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0x5f814c65	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0x5f856447	init_special_inode
++EXPORT_SYMBOL vmlinux 0x5f8aa1b4	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x5f9c093b	vga_switcheroo_unregister_client
++EXPORT_SYMBOL vmlinux 0x5fa937ac	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0x5fac61af	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x5fb2e8ef	idr_init
++EXPORT_SYMBOL vmlinux 0x5fb9c441	__register_nls
++EXPORT_SYMBOL vmlinux 0x5fd268cb	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0x5fd89f95	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x600bccde	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x602ed00d	acpi_current_gpe_count
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x604316d8	acpi_finish_gpe
++EXPORT_SYMBOL vmlinux 0x604db195	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0x605c033e	agp_create_memory
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x607dfefc	x86_dma_fallback_dev
++EXPORT_SYMBOL vmlinux 0x607e165e	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0x607fdd18	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60a24ee9	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL vmlinux 0x60b86f61	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x60ea7553	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x610aaa40	mempool_destroy
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x614c2626	dquot_file_open
++EXPORT_SYMBOL vmlinux 0x61709c69	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0x6183114f	arp_create
++EXPORT_SYMBOL vmlinux 0x618437cf	kunmap_high
++EXPORT_SYMBOL vmlinux 0x619dcd25	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x61a93f3a	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0x61ad6ad2	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0x61b3560c	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x61b7a270	kmap
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61bb2f2e	sk_alloc
++EXPORT_SYMBOL vmlinux 0x62049256	acpi_disable
++EXPORT_SYMBOL vmlinux 0x620bc2a3	make_kuid
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x621a7a84	loop_backing_file
++EXPORT_SYMBOL vmlinux 0x6220b4a2	crc32_le
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6226b9fa	machine_to_phys_mapping
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x62367252	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0x6237f6b5	acpi_enable_event
++EXPORT_SYMBOL vmlinux 0x6241a2ab	__copy_from_user_ll_nocache
++EXPORT_SYMBOL vmlinux 0x62620be6	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x62c72d2b	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0x62ce8124	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0x62f5a888	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0x62fea255	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x6312e77f	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x6320c4ef	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0x63287f22	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0x634130e2	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x6343187a	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0x636a5691	acpi_register_ioapic
++EXPORT_SYMBOL vmlinux 0x636efb3e	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x63721516	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0x637b5744	blk_complete_request
++EXPORT_SYMBOL vmlinux 0x637e5552	bioset_create
++EXPORT_SYMBOL vmlinux 0x6383530c	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0x63845dd3	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x6388591c	down_timeout
++EXPORT_SYMBOL vmlinux 0x6390b3ad	input_unregister_device
++EXPORT_SYMBOL vmlinux 0x639e89ff	d_delete
++EXPORT_SYMBOL vmlinux 0x63a01291	acpi_leave_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63d57a95	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63ec8517	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x63ffe27c	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x640a6a0a	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x64170d27	param_get_string
++EXPORT_SYMBOL vmlinux 0x64201cf0	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x6425d734	__inode_permission
++EXPORT_SYMBOL vmlinux 0x64277e43	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0x6449fd41	acpi_install_address_space_handler
++EXPORT_SYMBOL vmlinux 0x64865ef0	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x648f90f5	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0x6497d9fc	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64a4b84d	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x64ab0e98	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x64ae1910	init_net
++EXPORT_SYMBOL vmlinux 0x64b400c8	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0x64b8397e	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0x64cc04ab	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0x64d321c0	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x64eae7ad	set_memory_array_wb
++EXPORT_SYMBOL vmlinux 0x64f5a1e1	__scm_destroy
++EXPORT_SYMBOL vmlinux 0x64fa7693	__acpi_handle_debug
++EXPORT_SYMBOL vmlinux 0x64fc7419	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x652dcbf4	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x655f1ab0	set_memory_array_wc
++EXPORT_SYMBOL vmlinux 0x6565d33f	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x6571adc7	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x65a295bb	atomic64_xchg_cx8
++EXPORT_SYMBOL vmlinux 0x65b992ac	xen_alloc_p2m_entry
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65e08dc5	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x661f39b3	genphy_suspend
++EXPORT_SYMBOL vmlinux 0x66355efc	vprintk
++EXPORT_SYMBOL vmlinux 0x663cdf84	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x663f7cd0	acpi_install_table_handler
++EXPORT_SYMBOL vmlinux 0x667e4e80	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x669bf80b	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x66a2f676	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0x66d804b1	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x66fcd95e	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0x66ffe04c	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0x67007702	mpage_readpage
++EXPORT_SYMBOL vmlinux 0x67053751	__devm_release_region
++EXPORT_SYMBOL vmlinux 0x670541ac	dst_alloc
++EXPORT_SYMBOL vmlinux 0x6708209c	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0x6729d3df	__get_user_4
++EXPORT_SYMBOL vmlinux 0x673b8f55	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x673f815e	agp_bridges
++EXPORT_SYMBOL vmlinux 0x6741d2e2	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0x67486b3e	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x675634bc	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x677fcc31	kernel_listen
++EXPORT_SYMBOL vmlinux 0x67875001	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0x678e0528	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x6791a68b	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b528fa	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67d3093e	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0x67e89914	md_done_sync
++EXPORT_SYMBOL vmlinux 0x67fc65e5	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x680ec266	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x6832e643	kmap_atomic
++EXPORT_SYMBOL vmlinux 0x683afa59	lookup_one_len
++EXPORT_SYMBOL vmlinux 0x685b5cb1	blk_register_region
++EXPORT_SYMBOL vmlinux 0x68784ad5	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x6890e75c	keyring_clear
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68b31c1d	blk_finish_request
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68b8962a	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0x68c9785d	fb_is_primary_device
++EXPORT_SYMBOL vmlinux 0x68da11e2	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0x691001b5	acpi_evaluate_integer
++EXPORT_SYMBOL vmlinux 0x691097ab	padata_stop
++EXPORT_SYMBOL vmlinux 0x691b86de	pci_map_rom
++EXPORT_SYMBOL vmlinux 0x691fa236	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0x692463f6	elv_rb_del
++EXPORT_SYMBOL vmlinux 0x692cbc20	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0x69388aae	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0x693e1e64	__page_symlink
++EXPORT_SYMBOL vmlinux 0x69475d08	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x695a975b	set_trace_device
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x697a2a34	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x6986a25b	mmc_free_host
++EXPORT_SYMBOL vmlinux 0x6988d0ca	cpu_dr7
++EXPORT_SYMBOL vmlinux 0x69a0ca7d	iowrite16be
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69b47232	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x69fd2a05	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a08c4c0	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0x6a09111a	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0x6a200868	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0x6a24dd74	unregister_console
++EXPORT_SYMBOL vmlinux 0x6a25cffa	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x6a270af4	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0x6a27bfce	csum_partial_copy_generic
++EXPORT_SYMBOL vmlinux 0x6a3f5889	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a60277d	acpi_buffer_to_resource
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a8f567a	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x6a9982e9	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x6aa2a3d2	proc_remove
++EXPORT_SYMBOL vmlinux 0x6aa94776	finish_open
++EXPORT_SYMBOL vmlinux 0x6ab46479	dquot_operations
++EXPORT_SYMBOL vmlinux 0x6ab7bd7d	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0x6abacb1a	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0x6ac06769	sock_wake_async
++EXPORT_SYMBOL vmlinux 0x6ac12619	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6acb973d	iowrite32be
++EXPORT_SYMBOL vmlinux 0x6ad85887	acpi_enable_gpe
++EXPORT_SYMBOL vmlinux 0x6add5c9a	dmi_find_device
++EXPORT_SYMBOL vmlinux 0x6adde2de	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0x6ae28f67	agp_generic_alloc_page
++EXPORT_SYMBOL vmlinux 0x6ae47745	dev_uc_init
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b15cd41	dump_page
++EXPORT_SYMBOL vmlinux 0x6b1a2979	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b3a6612	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x6b55c815	install_exec_creds
++EXPORT_SYMBOL vmlinux 0x6b5c5391	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x6b61d7f6	__mutex_init
++EXPORT_SYMBOL vmlinux 0x6b67a11c	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0x6b68378f	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x6b74b9be	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0x6b82e266	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0x6b9ac2be	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0x6baa3ce1	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0x6bb67c28	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bcf066d	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6bf1c17f	pv_lock_ops
++EXPORT_SYMBOL vmlinux 0x6bf9081e	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c1ce5ce	strcspn
++EXPORT_SYMBOL vmlinux 0x6c210852	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x6c2e3320	strncmp
++EXPORT_SYMBOL vmlinux 0x6c2e9e26	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c723a64	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0x6c75c0a0	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x6c969928	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0x6c9982a9	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0x6cb1c11e	block_write_full_page
++EXPORT_SYMBOL vmlinux 0x6cbd18d6	mdiobus_read
++EXPORT_SYMBOL vmlinux 0x6cc09d17	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0x6cdc5c6b	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6cff8b92	register_gifconf
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d132cbb	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x6d1d5d9b	iosf_mbi_write
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d334118	__get_user_8
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d3b2d15	simple_link
++EXPORT_SYMBOL vmlinux 0x6d437245	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0x6d4881f7	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x6d5342f0	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x6d62b9d7	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0x6d688032	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0x6d71de9f	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0x6d829240	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0x6dc0c9dc	down_interruptible
++EXPORT_SYMBOL vmlinux 0x6dc68f00	inode_permission
++EXPORT_SYMBOL vmlinux 0x6dc6dd56	down
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6e013ca9	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0x6e103852	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0x6e11bc91	inet6_getname
++EXPORT_SYMBOL vmlinux 0x6e1f42f2	key_alloc
++EXPORT_SYMBOL vmlinux 0x6e2d9d7a	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x6e2dd3bc	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x6e354f09	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x6e4be59d	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0x6e55f203	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0x6e5ed487	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0x6e622776	sock_create
++EXPORT_SYMBOL vmlinux 0x6e63c120	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x6e6514ed	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e8e9416	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6eaaaa6e	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0x6ed52917	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0x6edebaae	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0x6ee47260	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x6ee91d86	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0x6eea54a7	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x6ef66e8a	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0x6efa5c40	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x6f1ac275	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x6f1bf786	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x6f20092d	flush_old_exec
++EXPORT_SYMBOL vmlinux 0x6f20937f	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f22630f	sk_common_release
++EXPORT_SYMBOL vmlinux 0x6f2e4f46	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0x6f3da85c	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x6f556bdb	acpi_get_gpe_device
++EXPORT_SYMBOL vmlinux 0x6f68b177	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x6f7eacee	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0x6f831e14	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0x6f86bb1d	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6f951db1	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0x6f9fb603	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6fdb6b70	nvdimm_bus_unlock
++EXPORT_SYMBOL vmlinux 0x6feb2039	acpi_write
++EXPORT_SYMBOL vmlinux 0x6fff308f	acpi_match_device_ids
++EXPORT_SYMBOL vmlinux 0x70024e9a	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x7007b970	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x700c0af2	vfs_statfs
++EXPORT_SYMBOL vmlinux 0x7023bea8	unregister_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x7029f11b	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0x704cf45f	mem_map
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7054a3e4	request_dma
++EXPORT_SYMBOL vmlinux 0x7062b4cd	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x706e9ea6	nd_integrity_init
++EXPORT_SYMBOL vmlinux 0x707c3c70	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x707f93dd	preempt_schedule
++EXPORT_SYMBOL vmlinux 0x707fd09c	cdev_del
++EXPORT_SYMBOL vmlinux 0x708610ec	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0x7088ce72	printk_emit
++EXPORT_SYMBOL vmlinux 0x708a79f7	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x7096dae8	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0x7097c3f4	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x709b25fe	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x709bb0b9	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0x70a92e85	md_register_thread
++EXPORT_SYMBOL vmlinux 0x70c34bf5	pci_map_biosrom
++EXPORT_SYMBOL vmlinux 0x70d1f8f3	strncat
++EXPORT_SYMBOL vmlinux 0x70d8ab82	acpi_acquire_global_lock
++EXPORT_SYMBOL vmlinux 0x70e02afd	rwsem_wake
++EXPORT_SYMBOL vmlinux 0x70e459dd	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x70e5ec0c	dev_open
++EXPORT_SYMBOL vmlinux 0x70e8f354	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x70ea8058	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x70fd9593	scsi_execute
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x712ed37b	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x7138fae4	proc_symlink
++EXPORT_SYMBOL vmlinux 0x714886da	kobject_init
++EXPORT_SYMBOL vmlinux 0x7156a4e1	set_device_ro
++EXPORT_SYMBOL vmlinux 0x715f0cc9	inet_getname
++EXPORT_SYMBOL vmlinux 0x716e3231	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x718e866d	register_xen_selfballooning
++EXPORT_SYMBOL vmlinux 0x71a156ad	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71b73116	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x71b77ace	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0x71f65175	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x7209e986	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x72173d44	tcp_req_err
++EXPORT_SYMBOL vmlinux 0x7225131e	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0x724f18cc	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x7258d998	__inet_hash
++EXPORT_SYMBOL vmlinux 0x7266d413	empty_aops
++EXPORT_SYMBOL vmlinux 0x72718dae	bd_set_size
++EXPORT_SYMBOL vmlinux 0x72741f9d	mount_subtree
++EXPORT_SYMBOL vmlinux 0x728641e4	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x72a93451	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x72b243d4	free_dma
++EXPORT_SYMBOL vmlinux 0x72d58de9	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x73233e96	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0x732ca752	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x734cf9e8	touch_atime
++EXPORT_SYMBOL vmlinux 0x734fc093	d_walk
++EXPORT_SYMBOL vmlinux 0x735a0bd5	native_io_delay
++EXPORT_SYMBOL vmlinux 0x73683029	vga_switcheroo_client_fb_set
++EXPORT_SYMBOL vmlinux 0x73710ecd	sock_register
++EXPORT_SYMBOL vmlinux 0x738714db	ida_pre_get
++EXPORT_SYMBOL vmlinux 0x738803e6	strnlen
++EXPORT_SYMBOL vmlinux 0x738cb5b2	kill_block_super
++EXPORT_SYMBOL vmlinux 0x73dd54eb	irq_fpu_usable
++EXPORT_SYMBOL vmlinux 0x73e15bf8	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0x73e20c1c	strlcpy
++EXPORT_SYMBOL vmlinux 0x73e513d5	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0x73e8729a	kmap_atomic_prot
++EXPORT_SYMBOL vmlinux 0x73ea0b00	security_path_link
++EXPORT_SYMBOL vmlinux 0x73ed6db1	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0x73f1d70c	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0x74005fdf	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0x740a1b95	reserve_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x74119060	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0x7413793a	EISA_bus
++EXPORT_SYMBOL vmlinux 0x7421627e	unregister_nls
++EXPORT_SYMBOL vmlinux 0x743b4ae3	atomic64_inc_not_zero_cx8
++EXPORT_SYMBOL vmlinux 0x743fe395	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x74451ba8	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x745f20a3	idr_is_empty
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x748af19a	ppp_input
++EXPORT_SYMBOL vmlinux 0x748c2230	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0x749ea2bf	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x74bf6326	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74d1d602	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x74d4a327	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0x74dd13d4	page_address
++EXPORT_SYMBOL vmlinux 0x74e5c98f	ucs2_strnlen
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74ed7033	ps2_end_command
++EXPORT_SYMBOL vmlinux 0x74f16675	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0x7505bdef	memchr_inv
++EXPORT_SYMBOL vmlinux 0x75114213	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0x75271716	save_processor_state
++EXPORT_SYMBOL vmlinux 0x75281e2f	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0x7531e3dc	acpi_get_event_resources
++EXPORT_SYMBOL vmlinux 0x7538b132	agp_off
++EXPORT_SYMBOL vmlinux 0x754bd04f	vga_switcheroo_set_dynamic_switch
++EXPORT_SYMBOL vmlinux 0x754fe892	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x755d8dec	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0x7593d385	div64_s64
++EXPORT_SYMBOL vmlinux 0x75aaf245	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0x75b6fade	sk_net_capable
++EXPORT_SYMBOL vmlinux 0x75bc549a	x86_cpu_to_apicid
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75d21809	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x75d708f1	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x75d7a0b4	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x75fbdefd	acpi_remove_address_space_handler
++EXPORT_SYMBOL vmlinux 0x7601242c	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x76163bca	sget
++EXPORT_SYMBOL vmlinux 0x762add85	atomic64_inc_return_cx8
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764b4cd8	mdiobus_free
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x76666a08	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0x767ddb02	set_memory_wc
++EXPORT_SYMBOL vmlinux 0x769e06d7	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x76ae215a	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x76bc2eee	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0x76cfaeb2	ip_options_compile
++EXPORT_SYMBOL vmlinux 0x76d19c3b	module_put
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76d926eb	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x76d9bf11	crc32_be
++EXPORT_SYMBOL vmlinux 0x76ddb025	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x76e12795	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0x76f6c5ef	kmalloc_order
++EXPORT_SYMBOL vmlinux 0x770a0036	isapnp_cfg_begin
++EXPORT_SYMBOL vmlinux 0x770aa029	vfs_readv
++EXPORT_SYMBOL vmlinux 0x771aa59e	simple_setattr
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x7739ea7c	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0x7740fa73	netlink_capable
++EXPORT_SYMBOL vmlinux 0x77456e0a	acpi_root_dir
++EXPORT_SYMBOL vmlinux 0x77629783	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x77871567	pci_clear_master
++EXPORT_SYMBOL vmlinux 0x778d5ae2	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77aa9115	generic_readlink
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77c5600b	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0x77dc94ba	noop_fsync
++EXPORT_SYMBOL vmlinux 0x77dd98fe	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0x77e21db4	__module_get
++EXPORT_SYMBOL vmlinux 0x77ef44cd	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x780fdfd1	intel_enable_gtt
++EXPORT_SYMBOL vmlinux 0x7815ea9b	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x7818ff00	proc_douintvec
++EXPORT_SYMBOL vmlinux 0x782567ec	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x783b977a	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0x78542f14	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x786c4ec3	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x786c5aa5	iput
++EXPORT_SYMBOL vmlinux 0x7872d218	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x788aba03	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x788c5a63	vfs_rename
++EXPORT_SYMBOL vmlinux 0x7890977e	i2c_release_client
++EXPORT_SYMBOL vmlinux 0x7895cb1c	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78a301df	sync_inode
++EXPORT_SYMBOL vmlinux 0x78a4eade	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x78a5ff8a	fence_add_callback
++EXPORT_SYMBOL vmlinux 0x78c20341	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0x78d6f972	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0x78dae55d	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78e739aa	up
++EXPORT_SYMBOL vmlinux 0x78ed8f72	input_release_device
++EXPORT_SYMBOL vmlinux 0x78fb9338	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0x79068fda	acpi_install_method
++EXPORT_SYMBOL vmlinux 0x791ed1c9	rename_lock
++EXPORT_SYMBOL vmlinux 0x79276f9d	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x79379ee6	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x79466675	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x7978ddd6	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0x799694b3	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79bd9c39	dquot_drop
++EXPORT_SYMBOL vmlinux 0x79c97ef1	do_splice_to
++EXPORT_SYMBOL vmlinux 0x79fbb5fb	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x7a2add7d	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0x7a2af7b4	cpu_number
++EXPORT_SYMBOL vmlinux 0x7a3d40ae	backlight_device_register
++EXPORT_SYMBOL vmlinux 0x7a40abb7	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a53ac5c	md_update_sb
++EXPORT_SYMBOL vmlinux 0x7a600559	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x7a6fd02c	dqput
++EXPORT_SYMBOL vmlinux 0x7a82cb47	rdmsrl_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x7a95e5ae	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7ab8171d	is_nd_btt
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7accce24	kobject_del
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7adde233	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x7aec9089	clear_user
++EXPORT_SYMBOL vmlinux 0x7afa89fc	vsnprintf
++EXPORT_SYMBOL vmlinux 0x7b134ddf	acpi_get_name
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b1aa74b	kmap_to_page
++EXPORT_SYMBOL vmlinux 0x7b1ade38	lz4_decompress
++EXPORT_SYMBOL vmlinux 0x7b25bc03	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0x7b283ce3	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0x7b2ebe1c	copy_to_iter
++EXPORT_SYMBOL vmlinux 0x7b34ab31	wireless_send_event
++EXPORT_SYMBOL vmlinux 0x7b4909bc	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0x7b4c3a7b	get_agp_version
++EXPORT_SYMBOL vmlinux 0x7b52a859	wrmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x7b56a08b	inet_frags_init
++EXPORT_SYMBOL vmlinux 0x7b5c8440	vm_munmap
++EXPORT_SYMBOL vmlinux 0x7b829f52	locks_init_lock
++EXPORT_SYMBOL vmlinux 0x7b83d15d	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0x7bab4b56	get_empty_filp
++EXPORT_SYMBOL vmlinux 0x7bac56e1	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0x7bad7a1a	acpi_walk_resources
++EXPORT_SYMBOL vmlinux 0x7bd72427	input_register_handler
++EXPORT_SYMBOL vmlinux 0x7bd92dbc	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0x7be65946	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x7bf05fdc	km_policy_expired
++EXPORT_SYMBOL vmlinux 0x7bf85aec	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0x7c026d6f	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0x7c0958c1	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c24b52c	free_user_ns
++EXPORT_SYMBOL vmlinux 0x7c3091e9	path_nosuid
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c4f5e7e	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0x7c5c990f	dev_deactivate
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c84eaf1	pnp_get_resource
++EXPORT_SYMBOL vmlinux 0x7c8ae9b0	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x7c8d9857	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7c9d615d	filp_open
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cde71f1	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7ce3b2bf	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x7ce83365	acpi_remove_table_handler
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7cf3c9f7	unlock_rename
++EXPORT_SYMBOL vmlinux 0x7cf76e40	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d118728	simple_follow_link
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d344fc4	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d8d76ea	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x7d94f746	acpi_os_write_port
++EXPORT_SYMBOL vmlinux 0x7d96cea3	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x7db7eef4	vme_bus_num
++EXPORT_SYMBOL vmlinux 0x7dbc2e57	mmiotrace_printk
++EXPORT_SYMBOL vmlinux 0x7de43f60	tso_start
++EXPORT_SYMBOL vmlinux 0x7de5ba68	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0x7ded2d4f	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7e0c0740	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0x7e20b9df	agp_enable
++EXPORT_SYMBOL vmlinux 0x7e31678e	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x7e464bdb	pci_get_device
++EXPORT_SYMBOL vmlinux 0x7e5c35b1	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x7e7fc3fb	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x7ebe57a8	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x7ec3c5fe	param_set_bool
++EXPORT_SYMBOL vmlinux 0x7ec49754	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x7ecb001b	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x7ed29d89	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0x7ed8b001	complete_request_key
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7ee73c0c	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0x7eea2e2e	pci_iounmap
++EXPORT_SYMBOL vmlinux 0x7ef7f239	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x7efed859	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f074f6e	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x7f12df44	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f251fd1	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f71d0d0	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x7f79c23d	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0x7f9d158b	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x7f9f0a87	cpu_tss
++EXPORT_SYMBOL vmlinux 0x7fbeb5d7	file_remove_privs
++EXPORT_SYMBOL vmlinux 0x7fc718ee	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x7fdc24c9	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0x7fde2edb	vme_master_read
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x801aecbf	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x802c84bf	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x802da8c4	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0x802e85bf	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x804363af	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0x804a4eb0	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0x80699a9a	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0x8071ccaf	km_state_notify
++EXPORT_SYMBOL vmlinux 0x8084897e	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0x808546f1	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0x809388ca	idr_destroy
++EXPORT_SYMBOL vmlinux 0x80b64549	set_pages_array_wc
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80d9ca85	paravirt_ticketlocks_enabled
++EXPORT_SYMBOL vmlinux 0x80eb423b	acpi_get_object_info
++EXPORT_SYMBOL vmlinux 0x80f55e51	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0x80f9d1fc	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x80fcb288	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x81144f9d	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x812ac8bf	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0x812eadad	led_blink_set
++EXPORT_SYMBOL vmlinux 0x81472677	acpi_get_table
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x814febfc	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x815c56d0	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x815f2897	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x81671b51	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0x81902f2f	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x81a531ef	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x81a81fa8	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0x81afbaee	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81e3eb31	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x81e6b37f	dmi_get_system_info
++EXPORT_SYMBOL vmlinux 0x81fb4bad	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x8212721d	xenbus_dev_request_and_reply
++EXPORT_SYMBOL vmlinux 0x821a3d70	alloc_file
++EXPORT_SYMBOL vmlinux 0x821b2caa	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0x8235805b	memmove
++EXPORT_SYMBOL vmlinux 0x8253a0b3	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0x826fff47	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x82789b14	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x829534b3	fence_free
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82d89c98	nvdimm_revalidate_disk
++EXPORT_SYMBOL vmlinux 0x830e547b	ioremap_prot
++EXPORT_SYMBOL vmlinux 0x8329e6f0	memset
++EXPORT_SYMBOL vmlinux 0x8329fd22	serio_open
++EXPORT_SYMBOL vmlinux 0x832fa791	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x833c03aa	acpi_enable_all_runtime_gpes
++EXPORT_SYMBOL vmlinux 0x83514847	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x83599ca2	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x835ecf22	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0x8372cd2f	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x8382e59a	acpi_walk_resource_buffer
++EXPORT_SYMBOL vmlinux 0x838cbdcc	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0x839245f0	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0x839290a9	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x83a0f15a	file_open_root
++EXPORT_SYMBOL vmlinux 0x83a169de	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0x83a2e4e9	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0x83ac42b4	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83ce11af	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x83e99562	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0x84060081	xen_poll_irq_timeout
++EXPORT_SYMBOL vmlinux 0x840be543	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x8417f512	acpi_update_all_gpes
++EXPORT_SYMBOL vmlinux 0x84188597	generic_write_checks
++EXPORT_SYMBOL vmlinux 0x843306de	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0x844d0130	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x845539ed	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0x8459fd3f	prepare_binprm
++EXPORT_SYMBOL vmlinux 0x84726800	no_llseek
++EXPORT_SYMBOL vmlinux 0x847616e4	pnp_stop_dev
++EXPORT_SYMBOL vmlinux 0x8488fe6a	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0x84894cdc	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0x84a6c1ee	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x84de4aff	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x84f4848f	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0x84f97108	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x851bc5a0	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0x852581b5	iterate_dir
++EXPORT_SYMBOL vmlinux 0x8526c35a	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x853ed7bc	cdev_alloc
++EXPORT_SYMBOL vmlinux 0x8555e2fa	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0x85585ad6	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x856c4bbc	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0x857582f7	acpi_enable_all_wakeup_gpes
++EXPORT_SYMBOL vmlinux 0x858b3fe3	free_iova_mem
++EXPORT_SYMBOL vmlinux 0x85a43be4	mmc_erase
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85bbed25	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x85ca069a	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x85fdd904	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x8602866d	bio_chain
++EXPORT_SYMBOL vmlinux 0x86182550	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0x861e22a4	acpi_map_cpu
++EXPORT_SYMBOL vmlinux 0x862ae1ab	framebuffer_release
++EXPORT_SYMBOL vmlinux 0x862ca545	user_path_create
++EXPORT_SYMBOL vmlinux 0x862eafa4	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0x8638e523	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x864df3cf	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x865d263c	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0x8660a9d9	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x8670cf3c	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x8684dd37	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x86897b2a	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86a4889a	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0x86a49cc1	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x86d450be	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0x86d8307e	done_path_create
++EXPORT_SYMBOL vmlinux 0x86dd6737	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x86f2795c	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x86f304a1	sock_edemux
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x8704bdd8	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x872cae6b	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x872f3bf2	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0x876dafc3	ec_write
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x878cd015	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x87a6a462	xattr_full_name
++EXPORT_SYMBOL vmlinux 0x87aaddf8	wrmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0x87add53c	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x87efb6d1	skb_unlink
++EXPORT_SYMBOL vmlinux 0x87fe1948	xen_biovec_phys_mergeable
++EXPORT_SYMBOL vmlinux 0x87fe790b	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x88161e4d	agp_generic_enable
++EXPORT_SYMBOL vmlinux 0x88258fbe	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x883450ca	proto_unregister
++EXPORT_SYMBOL vmlinux 0x88477e5b	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x884b17fe	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0x8854a051	dquot_commit
++EXPORT_SYMBOL vmlinux 0x88910b65	input_close_device
++EXPORT_SYMBOL vmlinux 0x8896a0b8	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x889c2384	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x889fd9b5	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0x88a83a75	blk_start_queue
++EXPORT_SYMBOL vmlinux 0x88b9cc43	build_skb
++EXPORT_SYMBOL vmlinux 0x88c9d1b2	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0x88cc8e6b	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0x88fe21f0	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x892491d1	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0x892b26a0	set_memory_nx
++EXPORT_SYMBOL vmlinux 0x893d1dd5	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0x896030f1	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0x896155c3	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x8978cf2f	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x897aa8ec	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0x89832416	register_quota_format
++EXPORT_SYMBOL vmlinux 0x899c92d8	scsi_register
++EXPORT_SYMBOL vmlinux 0x89a38aea	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0x89aef27e	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89b489dc	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89de6704	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0x8a098a89	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x8a0b12c6	complete_all
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a45b34f	bio_map_kern
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a58af4e	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x8a6403ff	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0x8a6944f9	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x8a7b90eb	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0x8a7c87fe	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a80d7a5	acpi_error
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8acf9d28	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x8add6085	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x8ae1249d	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0x8af53df5	init_buffer
++EXPORT_SYMBOL vmlinux 0x8b0aa68a	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0x8b18496f	__copy_to_user_ll
++EXPORT_SYMBOL vmlinux 0x8b2e063c	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b989cf9	acpi_bus_can_wakeup
++EXPORT_SYMBOL vmlinux 0x8bb2571f	proc_set_size
++EXPORT_SYMBOL vmlinux 0x8bb8d87c	param_get_ushort
++EXPORT_SYMBOL vmlinux 0x8bbd57ed	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x8bea3de0	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0x8bfec0fb	skb_insert
++EXPORT_SYMBOL vmlinux 0x8c183cbe	iowrite16
++EXPORT_SYMBOL vmlinux 0x8c4dfef2	sg_miter_next
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c933ec0	scsi_unregister
++EXPORT_SYMBOL vmlinux 0x8c9f7f92	dst_discard_out
++EXPORT_SYMBOL vmlinux 0x8ca1e089	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x8cb719ec	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0x8cc588b8	pnpbios_protocol
++EXPORT_SYMBOL vmlinux 0x8cc63e07	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x8cc79cab	iowrite16_rep
++EXPORT_SYMBOL vmlinux 0x8cda8029	xen_clear_irq_pending
++EXPORT_SYMBOL vmlinux 0x8ce20ec4	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0x8cebb7be	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0x8cebfed2	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x8cf4a792	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0x8d209804	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0x8d247ace	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d6b2ce1	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x8d6f81b4	__div64_32
++EXPORT_SYMBOL vmlinux 0x8d708972	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x8d72495b	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d838d91	ida_remove
++EXPORT_SYMBOL vmlinux 0x8d8d96c6	acpi_get_sleep_type_data
++EXPORT_SYMBOL vmlinux 0x8da1a3cb	acpi_remove_interface
++EXPORT_SYMBOL vmlinux 0x8daf8c42	dql_init
++EXPORT_SYMBOL vmlinux 0x8dc354f0	dm_put_device
++EXPORT_SYMBOL vmlinux 0x8dc6e564	restore_processor_state
++EXPORT_SYMBOL vmlinux 0x8dfefdf3	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x8e002cda	acpi_remove_gpe_block
++EXPORT_SYMBOL vmlinux 0x8e01cdc5	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0x8e0d33fa	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x8e1e4426	is_nvdimm_bus_locked
++EXPORT_SYMBOL vmlinux 0x8e24b341	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0x8e27b7d2	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0x8e3267c5	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x8e3717cb	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0x8e3c3b10	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x8e6d54a5	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e76f570	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0x8e7ff318	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0x8e86d7f4	bio_put
++EXPORT_SYMBOL vmlinux 0x8e888ec3	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x8e97ffd1	nobh_write_end
++EXPORT_SYMBOL vmlinux 0x8eaf2a5f	vga_switcheroo_unregister_handler
++EXPORT_SYMBOL vmlinux 0x8ed4faf9	freeze_bdev
++EXPORT_SYMBOL vmlinux 0x8edd26fb	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x8f0271ba	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x8f2703b7	wbinvd_on_all_cpus
++EXPORT_SYMBOL vmlinux 0x8f40f5eb	agp_generic_alloc_by_type
++EXPORT_SYMBOL vmlinux 0x8f4bb258	skb_pad
++EXPORT_SYMBOL vmlinux 0x8f510acf	dquot_acquire
++EXPORT_SYMBOL vmlinux 0x8f649f74	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x8f8230d4	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0x8f8988cb	netdev_alert
++EXPORT_SYMBOL vmlinux 0x8f933960	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x8f9c199c	__get_user_2
++EXPORT_SYMBOL vmlinux 0x8fa01a12	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x8fb4ab01	kfree_put_link
++EXPORT_SYMBOL vmlinux 0x8fbe9d5c	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0x8fd1152e	_raw_write_unlock
++EXPORT_SYMBOL vmlinux 0x8fde39bb	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0x8fe59cef	convert_art_to_tsc
++EXPORT_SYMBOL vmlinux 0x8ff4079b	pv_irq_ops
++EXPORT_SYMBOL vmlinux 0x8ffbc4f6	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0x8ffdb3b8	crc16
++EXPORT_SYMBOL vmlinux 0x90183b66	genl_notify
++EXPORT_SYMBOL vmlinux 0x90279ffd	agp_bind_memory
++EXPORT_SYMBOL vmlinux 0x904409c6	acpi_set_firmware_waking_vector
++EXPORT_SYMBOL vmlinux 0x90695906	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0x908575fe	queued_write_lock_slowpath
++EXPORT_SYMBOL vmlinux 0x908951a6	icmp_send
++EXPORT_SYMBOL vmlinux 0x909ad001	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0x90a1a11d	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0x90b611d4	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0x90c5e819	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x90f489c7	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0x9107e0ec	dma_supported
++EXPORT_SYMBOL vmlinux 0x91112165	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0x91145b6f	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x915aee17	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0x91607d95	set_memory_wb
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x917a6d7c	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x91967e8e	xen_selfballoon_init
++EXPORT_SYMBOL vmlinux 0x91985829	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0x91b02206	cdrom_open
++EXPORT_SYMBOL vmlinux 0x91b63328	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0x91ba4912	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0x91c4ee17	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0x91ce6826	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0x91d5247a	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0x91d5f2ae	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0x91da6280	free_netdev
++EXPORT_SYMBOL vmlinux 0x91f37aef	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x91fcbd4d	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x9220c376	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0x92274372	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0x92307ccd	vme_slot_num
++EXPORT_SYMBOL vmlinux 0x9231b298	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x924a384f	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x9255fe61	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0x92805ef9	nd_device_unregister
++EXPORT_SYMBOL vmlinux 0x9288d970	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0x92897e3d	default_idle
++EXPORT_SYMBOL vmlinux 0x929515c2	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0x929f5b58	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0x92a0fc89	nvm_register_target
++EXPORT_SYMBOL vmlinux 0x92a73cf7	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92aaee2d	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0x92b181a6	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x92b28977	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x92bf0d16	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0x92d57acb	dump_trace
++EXPORT_SYMBOL vmlinux 0x92f6767f	lg_local_lock
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x9302f9fa	thaw_bdev
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x931421b6	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0x9314f952	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0x93215e1d	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0x932493a8	iosf_mbi_read
++EXPORT_SYMBOL vmlinux 0x93454dc8	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x937ae900	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x9382902c	PDE_DATA
++EXPORT_SYMBOL vmlinux 0x93a37adc	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93d2a2f2	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0x93d37d11	nf_afinfo
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x940f9cf6	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x9411fad4	ihold
++EXPORT_SYMBOL vmlinux 0x943725f5	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x943abd88	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x9447e9b3	get_cached_acl
++EXPORT_SYMBOL vmlinux 0x9449ca6e	pci_get_class
++EXPORT_SYMBOL vmlinux 0x944b9584	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94a79780	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0x94b541b5	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x94e12171	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x94e97329	d_find_alias
++EXPORT_SYMBOL vmlinux 0x94eea794	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x95175ef0	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0x951f5fdc	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0x952199a1	skb_clone
++EXPORT_SYMBOL vmlinux 0x9522971a	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0x9529cecc	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x9531adc0	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0x95395301	acpi_exception
++EXPORT_SYMBOL vmlinux 0x953ac3ba	cros_ec_query_all
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x954f5327	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x956cdce5	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0x956cecd6	tty_port_open
++EXPORT_SYMBOL vmlinux 0x957ae75c	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x957dd4d0	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0x95843d8d	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0x95918f2b	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x959a5347	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x95a3dc44	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0x95acc1ea	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0x95b2720d	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0x95bd6e26	acpi_install_sci_handler
++EXPORT_SYMBOL vmlinux 0x95c08b5a	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0x95cb5e44	rt6_lookup
++EXPORT_SYMBOL vmlinux 0x95cecff6	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x95ee3e59	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0x95f4d2d8	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0x9603c09d	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0x960737d9	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0x960dfaf5	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0x96244c7e	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0x962b15fe	seq_release_private
++EXPORT_SYMBOL vmlinux 0x963a1156	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0x963e074a	_dev_info
++EXPORT_SYMBOL vmlinux 0x9648df5d	register_console
++EXPORT_SYMBOL vmlinux 0x96573b80	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x9657f266	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x9670d811	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0x96898769	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x96a1c89a	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x96b15d2d	phy_start
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96cef754	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0x96d24ed7	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0x96d4137e	serio_rescan
++EXPORT_SYMBOL vmlinux 0x96fbde17	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0x96fdd594	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0x9705362d	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x97090ab4	seq_lseek
++EXPORT_SYMBOL vmlinux 0x9711b204	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0x9713bee8	simple_rmdir
++EXPORT_SYMBOL vmlinux 0x972b7780	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0x972dd62c	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0x973fa82e	register_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x9762dc83	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x976cda61	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0x976e5e7d	use_ibrs
++EXPORT_SYMBOL vmlinux 0x977ae72c	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0x977d07d2	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x97a42c79	pcibios_set_irq_routing
++EXPORT_SYMBOL vmlinux 0x97c5bd0a	acpi_unload_parent_table
++EXPORT_SYMBOL vmlinux 0x97de0ddd	acpi_install_gpe_block
++EXPORT_SYMBOL vmlinux 0x97e908c3	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0x97f9ee77	kdb_current_task
++EXPORT_SYMBOL vmlinux 0x98147435	vga_get
++EXPORT_SYMBOL vmlinux 0x9814c7a5	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x9820b644	warn_slowpath_fmt_taint
++EXPORT_SYMBOL vmlinux 0x9826f81c	release_firmware
++EXPORT_SYMBOL vmlinux 0x9829b97c	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x9836012c	dump_emit
++EXPORT_SYMBOL vmlinux 0x984b695e	give_up_console
++EXPORT_SYMBOL vmlinux 0x985eef53	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0x986538a7	devm_release_resource
++EXPORT_SYMBOL vmlinux 0x986c5b3e	nla_append
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x9878745c	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x988ed85d	set_memory_x
++EXPORT_SYMBOL vmlinux 0x988f1bd5	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x98979590	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0x98d0cde8	clk_add_alias
++EXPORT_SYMBOL vmlinux 0x98e68eca	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0x98e7e0f4	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x98eccc10	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0x98f22ab2	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0x98f2717c	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0x98fe8538	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0x99224501	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0x99233c32	cpu_core_map
++EXPORT_SYMBOL vmlinux 0x9924bd15	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x993e987b	vme_dma_request
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x995c22ca	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x9970d5f5	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0x9989b259	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d9c09a	clear_nlink
++EXPORT_SYMBOL vmlinux 0x99daa9bf	try_offline_node
++EXPORT_SYMBOL vmlinux 0x99e1856e	kobject_add
++EXPORT_SYMBOL vmlinux 0x99f1c217	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0x99f39356	pnp_device_detach
++EXPORT_SYMBOL vmlinux 0x99fdf123	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x9a01cc2e	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x9a078351	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0x9a0bfcdd	nvdimm_bus_lock
++EXPORT_SYMBOL vmlinux 0x9a1d8e6a	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a3d4d7a	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0x9a42e261	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0x9a6594c8	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x9a6a83f9	cmos_lock
++EXPORT_SYMBOL vmlinux 0x9a82499b	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0x9a8ac8fd	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x9aa1824d	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9b14bf09	tso_count_descs
++EXPORT_SYMBOL vmlinux 0x9b189d48	blk_init_queue
++EXPORT_SYMBOL vmlinux 0x9b18c6e0	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x9b1da288	register_framebuffer
++EXPORT_SYMBOL vmlinux 0x9b3294e4	genphy_read_status
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b54d4d6	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x9b6a0148	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0x9b6eb137	ksize
++EXPORT_SYMBOL vmlinux 0x9b7fdbbd	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba146bf	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bb151c3	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0x9bbe88b3	flex_array_put
++EXPORT_SYMBOL vmlinux 0x9bc563c7	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9c00800b	d_path
++EXPORT_SYMBOL vmlinux 0x9c1e8baf	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0x9c268059	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0x9c2c944a	__copy_from_user_ll_nocache_nozero
++EXPORT_SYMBOL vmlinux 0x9c38d9b3	input_grab_device
++EXPORT_SYMBOL vmlinux 0x9c450105	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c839c21	nonseekable_open
++EXPORT_SYMBOL vmlinux 0x9ca7c99e	agp_backend_acquire
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cb45984	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x9cb9ce1b	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x9cbad315	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x9cdc28eb	end_page_writeback
++EXPORT_SYMBOL vmlinux 0x9ce169af	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x9cf7905f	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d33ef5e	acpi_enable
++EXPORT_SYMBOL vmlinux 0x9d3638a1	follow_pfn
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d49c0ef	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0x9d78ddf4	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0x9d93c96a	param_set_byte
++EXPORT_SYMBOL vmlinux 0x9d9823e8	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0x9db61e43	d_lookup
++EXPORT_SYMBOL vmlinux 0x9dcc4b4b	set_page_dirty
++EXPORT_SYMBOL vmlinux 0x9dcd846a	nd_btt_probe
++EXPORT_SYMBOL vmlinux 0x9de1118f	__nd_iostat_start
++EXPORT_SYMBOL vmlinux 0x9dfe7307	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e363b6b	acpi_disable_gpe
++EXPORT_SYMBOL vmlinux 0x9e3b7282	vga_switcheroo_init_domain_pm_optimus_hdmi_audio
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e60b9a6	inet_bind
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e634619	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x9e64fbfe	rtc_cmos_read
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e7d6bd0	__udelay
++EXPORT_SYMBOL vmlinux 0x9e93b53d	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x9e9cd648	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0x9e9dbde3	__sock_create
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9ea0c91f	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x9eaf4194	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9ef59436	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0x9f1b4c5d	audit_log_start
++EXPORT_SYMBOL vmlinux 0x9f419057	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f5b6297	km_is_alive
++EXPORT_SYMBOL vmlinux 0x9f6c98a5	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x9f96b9cc	serio_reconnect
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9fbba8d1	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x9fbd84ce	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0x9fbfb55c	padata_alloc
++EXPORT_SYMBOL vmlinux 0x9fd33050	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0x9fd7cda1	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9fe113d0	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0x9fe28c8d	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0x9ffb1fef	vme_register_driver
++EXPORT_SYMBOL vmlinux 0xa00aca2a	dql_completed
++EXPORT_SYMBOL vmlinux 0xa020913a	vme_bus_type
++EXPORT_SYMBOL vmlinux 0xa022785c	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa054941f	secpath_dup
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa06df9e1	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0xa07bf0c2	textsearch_register
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa08920e6	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0xa0aac151	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0b5c9f9	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0xa0b78bfa	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0ea1e1c	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0f48cdb	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa111ad53	input_open_device
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa127765e	set_pages_array_wb
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa14ab0b3	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0xa14b3f5d	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0xa14ced2a	d_set_d_op
++EXPORT_SYMBOL vmlinux 0xa1650620	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0xa16733fd	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0xa16f5af1	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0xa197294b	__bforget
++EXPORT_SYMBOL vmlinux 0xa19de3fd	boot_cpu_data
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1c41baf	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa1ea6ec8	get_gendisk
++EXPORT_SYMBOL vmlinux 0xa204ad45	udp_ioctl
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa20ea5f7	wake_up_process
++EXPORT_SYMBOL vmlinux 0xa23ca586	seq_pad
++EXPORT_SYMBOL vmlinux 0xa250a024	vfs_getattr
++EXPORT_SYMBOL vmlinux 0xa2680f70	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0xa27f1d0e	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0xa2848b43	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa2af5372	inet_addr_type
++EXPORT_SYMBOL vmlinux 0xa2b89117	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0xa2ccf1ac	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xa2d27200	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0xa2f96d79	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0xa30ffe43	proc_create_data
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa339f712	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0xa348a7f7	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0xa34fcb2d	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xa350a8f8	set_memory_array_uc
++EXPORT_SYMBOL vmlinux 0xa358046d	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0xa3681a48	set_binfmt
++EXPORT_SYMBOL vmlinux 0xa3697071	phy_disconnect
++EXPORT_SYMBOL vmlinux 0xa37e78b6	flex_array_get
++EXPORT_SYMBOL vmlinux 0xa3adf45d	agp_allocate_memory
++EXPORT_SYMBOL vmlinux 0xa3bf9ecb	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0xa3c24039	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0xa3dcbfd3	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0xa3f0a78e	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0xa4132544	vfs_fsync
++EXPORT_SYMBOL vmlinux 0xa425a567	mmc_add_host
++EXPORT_SYMBOL vmlinux 0xa42b377e	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0xa42b8d35	notify_change
++EXPORT_SYMBOL vmlinux 0xa42ccbe4	__bread_gfp
++EXPORT_SYMBOL vmlinux 0xa4304547	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0xa43b1297	vscnprintf
++EXPORT_SYMBOL vmlinux 0xa451f5b1	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0xa45fea43	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa47d9662	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0xa4921d74	set_pages_x
++EXPORT_SYMBOL vmlinux 0xa4a90500	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0xa4b6dabb	open_exec
++EXPORT_SYMBOL vmlinux 0xa4b94fea	iowrite8_rep
++EXPORT_SYMBOL vmlinux 0xa4b98f06	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0xa4d4f0e6	global_cache_flush
++EXPORT_SYMBOL vmlinux 0xa4d71e82	blk_put_request
++EXPORT_SYMBOL vmlinux 0xa4e2c90d	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0xa4eb2b25	sock_create_lite
++EXPORT_SYMBOL vmlinux 0xa512366f	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0xa51cdfe8	__FIXADDR_TOP
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa5594e4b	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0xa56550d0	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0xa5789cbc	__scm_send
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa5a2cf17	param_set_int
++EXPORT_SYMBOL vmlinux 0xa5c1f7d9	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0xa5dabe21	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0xa5e5eabf	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0xa5e99a2a	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xa5ec85ca	vm_insert_page
++EXPORT_SYMBOL vmlinux 0xa5f79832	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0xa60ac649	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0xa624ce25	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0xa62e6e4f	acpi_get_table_with_size
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa640e35a	pci_request_regions
++EXPORT_SYMBOL vmlinux 0xa64eadbc	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0xa6547a27	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa67f7db4	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa6935573	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0xa6970398	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0xa6bbd805	__wake_up
++EXPORT_SYMBOL vmlinux 0xa6bd63ca	acpi_bios_error
++EXPORT_SYMBOL vmlinux 0xa6e6aed8	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0xa6fe9c97	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa70fabbe	release_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa7407e21	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0xa74c9dd9	dst_init
++EXPORT_SYMBOL vmlinux 0xa75eb054	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0xa760eb29	read_cache_page
++EXPORT_SYMBOL vmlinux 0xa7643af7	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0xa76dc913	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0xa77fbefa	generic_show_options
++EXPORT_SYMBOL vmlinux 0xa788f1a0	i8253_lock
++EXPORT_SYMBOL vmlinux 0xa7a2502b	from_kgid
++EXPORT_SYMBOL vmlinux 0xa7b0f270	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0xa7b31baf	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0xa7cf2d38	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0xa7cf6c2f	atomic64_dec_return_cx8
++EXPORT_SYMBOL vmlinux 0xa7d60172	agp_backend_release
++EXPORT_SYMBOL vmlinux 0xa7dd98bc	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0xa8365612	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa85bad5e	pci_enable_device
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa87e93a8	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0xa890e5c2	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0xa8a2a07a	seq_escape
++EXPORT_SYMBOL vmlinux 0xa8abbe90	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0xa8bfebf1	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0xa8c186c0	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0xa8c42bf6	param_set_invbool
++EXPORT_SYMBOL vmlinux 0xa8c9a131	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0xa8cb9c1c	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0xa8e0bfa4	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0xa8fedc08	pci_bus_put
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa90525de	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0xa9054a07	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa919bc52	vfs_setpos
++EXPORT_SYMBOL vmlinux 0xa9299809	__f_setown
++EXPORT_SYMBOL vmlinux 0xa92efc30	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0xa9352271	simple_empty
++EXPORT_SYMBOL vmlinux 0xa936f04b	current_fs_time
++EXPORT_SYMBOL vmlinux 0xa949946e	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0xa967a0c1	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0xa972b1e2	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa977e050	dev_mc_add
++EXPORT_SYMBOL vmlinux 0xa97a4516	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xa9a35c79	vga_switcheroo_fini_domain_pm_ops
++EXPORT_SYMBOL vmlinux 0xa9a88ba8	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0xa9a8e17f	arch_phys_wc_add
++EXPORT_SYMBOL vmlinux 0xa9accd17	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0xa9b56050	key_unlink
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9cfea6b	x86_hyper
++EXPORT_SYMBOL vmlinux 0xa9ecd3f5	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0xaa1d4ba9	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0xaa297c74	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xaa375592	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0xaa440190	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0xaa4ecd91	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0xaa5bd08d	__pv_queued_spin_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xaa6901ac	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa7a4dc9	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0xaa7f1969	pnpacpi_protocol
++EXPORT_SYMBOL vmlinux 0xaa896d41	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0xaa8fea18	acpi_processor_register_performance
++EXPORT_SYMBOL vmlinux 0xaa93a465	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0xaa9c4823	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0xaaa2bf4f	seq_dentry
++EXPORT_SYMBOL vmlinux 0xaaa3e20b	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0xaac680db	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad48788	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaae7f6aa	pci_get_slot
++EXPORT_SYMBOL vmlinux 0xaae8ab0e	acpi_bus_power_manageable
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab0a0ac6	eth_header_cache
++EXPORT_SYMBOL vmlinux 0xab15e657	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xab210b3d	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0xab2a20f4	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0xab36046b	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0xab3eb7dd	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0xab551fad	acpi_get_data_full
++EXPORT_SYMBOL vmlinux 0xab600421	probe_irq_off
++EXPORT_SYMBOL vmlinux 0xab65ed80	set_memory_uc
++EXPORT_SYMBOL vmlinux 0xab694444	bsearch
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab770678	rdmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab81e862	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0xab909fb5	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0xaba3159c	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0xaba3ad0c	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xaba49717	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0xaba82408	input_get_keycode
++EXPORT_SYMBOL vmlinux 0xabc17f56	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabd96b85	bdi_destroy
++EXPORT_SYMBOL vmlinux 0xabdd6463	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xabdf2947	pnp_register_card_driver
++EXPORT_SYMBOL vmlinux 0xabea7b26	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0xabfcb4c3	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0xabffe52c	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac398912	flex_array_clear
++EXPORT_SYMBOL vmlinux 0xac57c44a	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0xac874743	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0xac94d383	inet_offloads
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacabd595	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xacacdb71	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0xacb99769	ida_destroy
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xaccf0cc0	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xacdac029	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0xacdd1386	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0xacf3bb87	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad1687e1	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0xad1749bf	inode_set_flags
++EXPORT_SYMBOL vmlinux 0xad1c7f6b	set_pages_uc
++EXPORT_SYMBOL vmlinux 0xad48adc8	prepare_creds
++EXPORT_SYMBOL vmlinux 0xad547243	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0xad698f77	dqstats
++EXPORT_SYMBOL vmlinux 0xad6e4bb6	mempool_free
++EXPORT_SYMBOL vmlinux 0xad6f413a	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0xad722090	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0xad759331	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xada23500	param_ops_byte
++EXPORT_SYMBOL vmlinux 0xadc3dba9	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0xadcd9077	get_task_io_context
++EXPORT_SYMBOL vmlinux 0xadd4dcb4	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0xadd9884b	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xae044bc7	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0xae118ddd	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0xae25d513	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0xae4cf5fd	phy_resume
++EXPORT_SYMBOL vmlinux 0xae6b3a42	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0xae756ce0	load_nls_default
++EXPORT_SYMBOL vmlinux 0xae77a595	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0xae85a27e	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0xae88c37d	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0xae8b6c22	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0xae8d8525	invalidate_partition
++EXPORT_SYMBOL vmlinux 0xae921ef8	mount_single
++EXPORT_SYMBOL vmlinux 0xaea976a8	acpi_check_resource_conflict
++EXPORT_SYMBOL vmlinux 0xaebbbeb5	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0xaebeeca4	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0xaec655c7	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0xaeccb21c	get_super
++EXPORT_SYMBOL vmlinux 0xaeebe4ed	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0xaf13ac8b	follow_up
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf4b1540	acpi_get_irq_routing_table
++EXPORT_SYMBOL vmlinux 0xaf53af64	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0xaf611eac	amd_nb_misc_ids
++EXPORT_SYMBOL vmlinux 0xaf730254	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0xaf998427	__put_cred
++EXPORT_SYMBOL vmlinux 0xafa6f4f6	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0xafbaa0a5	nvdimm_namespace_common_probe
++EXPORT_SYMBOL vmlinux 0xafc1de35	inet6_bind
++EXPORT_SYMBOL vmlinux 0xb016dae5	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0xb01b1db8	intel_gtt_insert_sg_entries
++EXPORT_SYMBOL vmlinux 0xb01cbb49	ip_defrag
++EXPORT_SYMBOL vmlinux 0xb02433ec	__alloc_skb
++EXPORT_SYMBOL vmlinux 0xb02bd591	_raw_read_unlock_irq
++EXPORT_SYMBOL vmlinux 0xb0428805	kthread_stop
++EXPORT_SYMBOL vmlinux 0xb049bf09	igrab
++EXPORT_SYMBOL vmlinux 0xb0567e1a	dm_register_target
++EXPORT_SYMBOL vmlinux 0xb05bbf03	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb081b9c3	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0xb0954c17	inet_release
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0a1599c	simple_open
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0d62fb7	down_read_trylock
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0e4f324	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0xb0eb41ff	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0xb0edb954	tcp_prot
++EXPORT_SYMBOL vmlinux 0xb0edb98f	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0xb0f0deaa	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0xb0f30470	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0xb10820e4	_raw_read_unlock
++EXPORT_SYMBOL vmlinux 0xb1127e91	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0xb121390a	probe_irq_on
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb13aaee7	replace_mount_options
++EXPORT_SYMBOL vmlinux 0xb1447872	xfrm_input
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb15e1e06	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb187b3a8	lg_lock_init
++EXPORT_SYMBOL vmlinux 0xb18a57a9	misc_deregister
++EXPORT_SYMBOL vmlinux 0xb1934b0c	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0xb1b51e38	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0xb1beac62	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0xb1c267fa	sock_i_uid
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1cfad22	rdmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xb1d7dc08	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0xb1eac244	deactivate_super
++EXPORT_SYMBOL vmlinux 0xb1f2c906	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0xb2135b49	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0xb2154a89	iterate_fd
++EXPORT_SYMBOL vmlinux 0xb219d56c	wbinvd_on_cpu
++EXPORT_SYMBOL vmlinux 0xb21ac433	arch_debugfs_dir
++EXPORT_SYMBOL vmlinux 0xb21d9615	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0xb2549c0c	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0xb261a1d7	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb27e2afe	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2c0ba22	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0xb2ceda15	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0xb2d48a2e	queue_work_on
++EXPORT_SYMBOL vmlinux 0xb2d5a552	complete
++EXPORT_SYMBOL vmlinux 0xb2f30b53	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0xb2f74fb6	intel_gmch_remove
++EXPORT_SYMBOL vmlinux 0xb2fd5ceb	__put_user_4
++EXPORT_SYMBOL vmlinux 0xb31338fd	mount_nodev
++EXPORT_SYMBOL vmlinux 0xb3161db7	d_make_root
++EXPORT_SYMBOL vmlinux 0xb31b99f9	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0xb324ac2d	vme_lm_request
++EXPORT_SYMBOL vmlinux 0xb3284531	acpi_dbg_layer
++EXPORT_SYMBOL vmlinux 0xb32d7b7e	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0xb352177e	find_first_bit
++EXPORT_SYMBOL vmlinux 0xb3809705	__lock_page
++EXPORT_SYMBOL vmlinux 0xb382e15b	tty_name
++EXPORT_SYMBOL vmlinux 0xb38a09e3	sync_filesystem
++EXPORT_SYMBOL vmlinux 0xb397868f	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0xb39af489	padata_start
++EXPORT_SYMBOL vmlinux 0xb3b58865	__dax_fault
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3e0590d	acpi_set_current_resources
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb403125d	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0xb419d2c6	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb4390f9a	mcount
++EXPORT_SYMBOL vmlinux 0xb4519a8f	string_escape_mem
++EXPORT_SYMBOL vmlinux 0xb45578b8	memscan
++EXPORT_SYMBOL vmlinux 0xb45a0447	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0xb46792a7	iget_failed
++EXPORT_SYMBOL vmlinux 0xb46bd149	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb479d5fe	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0xb47cab6b	dst_destroy
++EXPORT_SYMBOL vmlinux 0xb47e3384	security_path_symlink
++EXPORT_SYMBOL vmlinux 0xb4812736	agp_generic_type_to_mask_type
++EXPORT_SYMBOL vmlinux 0xb48cb53c	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0xb4c8e959	fsync_bdev
++EXPORT_SYMBOL vmlinux 0xb4ca0be9	redraw_screen
++EXPORT_SYMBOL vmlinux 0xb4cdb5b0	agp_generic_insert_memory
++EXPORT_SYMBOL vmlinux 0xb5077c05	md_write_start
++EXPORT_SYMBOL vmlinux 0xb5139b9c	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0xb513ad96	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0xb51b8e05	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0xb5229392	cpu_sibling_map
++EXPORT_SYMBOL vmlinux 0xb523e9a2	skb_push
++EXPORT_SYMBOL vmlinux 0xb52ee8be	intel_gtt_clear_range
++EXPORT_SYMBOL vmlinux 0xb541a381	__block_write_begin
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb58dbda0	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5a8c1fb	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb5dbd16a	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0xb5dfe870	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0xb5e81ef2	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0xb5ef9b21	nf_register_hook
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb62535bb	kmap_high
++EXPORT_SYMBOL vmlinux 0xb654a8de	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0xb673db41	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0xb674a534	acpi_unmap_cpu
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb681b780	down_write_trylock
++EXPORT_SYMBOL vmlinux 0xb6896671	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb69f58fa	pci_restore_state
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6a8b5cf	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0xb6b395f6	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0xb6e41883	memcmp
++EXPORT_SYMBOL vmlinux 0xb6ed1e53	strncpy
++EXPORT_SYMBOL vmlinux 0xb6f3fdf1	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0xb7151b31	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb74ab8ab	clkdev_add
++EXPORT_SYMBOL vmlinux 0xb74bac22	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0xb758b225	acpi_disable_event
++EXPORT_SYMBOL vmlinux 0xb75ade70	put_io_context
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb7756888	pv_cpu_ops
++EXPORT_SYMBOL vmlinux 0xb7967604	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0xb79b4fc3	vfs_writev
++EXPORT_SYMBOL vmlinux 0xb79ec15d	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0xb7a3c875	update_devfreq
++EXPORT_SYMBOL vmlinux 0xb7bf7a76	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7dc7a21	set_disk_ro
++EXPORT_SYMBOL vmlinux 0xb7e8b065	skb_queue_head
++EXPORT_SYMBOL vmlinux 0xb7f0275c	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0xb7f55ecc	atomic64_add_return_cx8
++EXPORT_SYMBOL vmlinux 0xb7ffb61d	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0xb812227f	agp_bridge
++EXPORT_SYMBOL vmlinux 0xb81960ca	snprintf
++EXPORT_SYMBOL vmlinux 0xb81a6ecd	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xb8370414	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0xb8377c51	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0xb839a62f	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0xb83daf02	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0xb86a61fd	put_filp
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb8854ac8	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xb8ac5295	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0xb8b466fa	datagram_poll
++EXPORT_SYMBOL vmlinux 0xb8b6a76c	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0xb8bf392a	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0xb8c83c1c	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0xb8d1b7b7	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0xb8e16aa8	__lock_buffer
++EXPORT_SYMBOL vmlinux 0xb8e7ce2c	__put_user_8
++EXPORT_SYMBOL vmlinux 0xb8e877e7	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xb8fdcd10	mempool_resize
++EXPORT_SYMBOL vmlinux 0xb9058ad4	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0xb9063ed5	input_flush_device
++EXPORT_SYMBOL vmlinux 0xb9314d50	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0xb9892e9d	pnp_is_active
++EXPORT_SYMBOL vmlinux 0xb9898873	md_flush_request
++EXPORT_SYMBOL vmlinux 0xb9a61e66	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0xb9bd8e44	module_layout
++EXPORT_SYMBOL vmlinux 0xb9c39751	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0xb9c5d5ae	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0xb9d267f7	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0xb9dacf85	pnp_activate_dev
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xb9ff03e1	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0xba121c83	import_iovec
++EXPORT_SYMBOL vmlinux 0xba2d8594	ec_read
++EXPORT_SYMBOL vmlinux 0xba36e2dc	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0xba3df0b0	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba5ae402	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0xba5eec68	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0xba7fd2f6	seq_file_path
++EXPORT_SYMBOL vmlinux 0xba8f67a7	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0xbaa4b0ce	downgrade_write
++EXPORT_SYMBOL vmlinux 0xbac3cbf2	ns_to_timespec64
++EXPORT_SYMBOL vmlinux 0xbaefe00c	tso_build_data
++EXPORT_SYMBOL vmlinux 0xbaff9bfa	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb084feb	param_ops_charp
++EXPORT_SYMBOL vmlinux 0xbb3200a3	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb3f649b	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0xbb485cca	bdi_register
++EXPORT_SYMBOL vmlinux 0xbb4d00af	param_get_byte
++EXPORT_SYMBOL vmlinux 0xbb52b4e0	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb6363e3	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0xbb6bee14	vmap
++EXPORT_SYMBOL vmlinux 0xbb74388b	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0xbb800fa9	tcf_em_register
++EXPORT_SYMBOL vmlinux 0xbb87e719	processors
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbb9fcc31	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0xbba2e6cb	sock_i_ino
++EXPORT_SYMBOL vmlinux 0xbba70a2d	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xbbb2d51b	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0xbbd5c1a7	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xbbeb1ec6	ioremap_wt
++EXPORT_SYMBOL vmlinux 0xbc1226f5	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0xbc2031de	acpi_processor_get_bios_limit
++EXPORT_SYMBOL vmlinux 0xbc278947	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0xbc2958f2	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0xbc34b1e5	napi_complete_done
++EXPORT_SYMBOL vmlinux 0xbc3d7fec	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0xbc435770	dump_stack
++EXPORT_SYMBOL vmlinux 0xbc4ed6d9	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xbc69fae5	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0xbc6bc63d	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0xbc6f1368	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0xbc77615f	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0xbc8ec8e2	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0xbc92a1cb	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0xbcb9a6a2	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0xbcba39e4	irq_to_desc
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbccd111b	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0xbceb6980	netif_skb_features
++EXPORT_SYMBOL vmlinux 0xbcf15653	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0xbd1c13ba	cros_ec_cmd_xfer_status
++EXPORT_SYMBOL vmlinux 0xbd22424f	input_inject_event
++EXPORT_SYMBOL vmlinux 0xbd331ceb	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0xbd3d0452	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0xbd648e52	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0xbd816256	generic_update_time
++EXPORT_SYMBOL vmlinux 0xbd83ec6f	mmc_request_done
++EXPORT_SYMBOL vmlinux 0xbd8a487a	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbdaf5b07	acpi_os_read_port
++EXPORT_SYMBOL vmlinux 0xbdc9377a	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0xbdcd511f	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0xbdebbe2d	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xbdf32a66	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0xbe0e5118	nla_memcmp
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe34cfe8	blk_get_request
++EXPORT_SYMBOL vmlinux 0xbe5a8726	bdgrab
++EXPORT_SYMBOL vmlinux 0xbe5b47c9	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0xbe61179d	pnp_register_driver
++EXPORT_SYMBOL vmlinux 0xbe61f82f	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xbe7758d4	dmam_release_declared_memory
++EXPORT_SYMBOL vmlinux 0xbe799b55	key_put
++EXPORT_SYMBOL vmlinux 0xbe838e48	d_rehash
++EXPORT_SYMBOL vmlinux 0xbe8c37d9	intel_scu_ipc_simple_command
++EXPORT_SYMBOL vmlinux 0xbec03efe	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0xbec30d05	x86_match_cpu
++EXPORT_SYMBOL vmlinux 0xbec86937	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0xbed13d18	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0xbee1b4f2	tty_mutex
++EXPORT_SYMBOL vmlinux 0xbee90f2f	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0xbef38296	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf486982	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xbf555e7a	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8b39e9	isapnp_present
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfc177bc	iowrite32_rep
++EXPORT_SYMBOL vmlinux 0xbfd36729	param_ops_bint
++EXPORT_SYMBOL vmlinux 0xbfe49de7	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0xbfe6f427	_raw_spin_unlock_irq
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xc01eed33	__copy_from_user_ll_nozero
++EXPORT_SYMBOL vmlinux 0xc032f4b1	udp_poll
++EXPORT_SYMBOL vmlinux 0xc0504953	d_tmpfile
++EXPORT_SYMBOL vmlinux 0xc05e355f	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0xc068440e	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0cd3b13	___ratelimit
++EXPORT_SYMBOL vmlinux 0xc0f3dfbe	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0xc0ffba18	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0xc10bd326	seq_write
++EXPORT_SYMBOL vmlinux 0xc1152d1d	devm_memunmap
++EXPORT_SYMBOL vmlinux 0xc11d79ca	tty_do_resize
++EXPORT_SYMBOL vmlinux 0xc11d8093	iov_shorten
++EXPORT_SYMBOL vmlinux 0xc120065b	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0xc1484635	devm_request_resource
++EXPORT_SYMBOL vmlinux 0xc16ba356	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0xc16f901d	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0xc17a312d	phy_device_create
++EXPORT_SYMBOL vmlinux 0xc18f197a	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0xc19118a8	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0xc1a74a02	filp_close
++EXPORT_SYMBOL vmlinux 0xc1c964d1	read_dev_sector
++EXPORT_SYMBOL vmlinux 0xc1cc9a91	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0xc1cf74bc	skb_append
++EXPORT_SYMBOL vmlinux 0xc1d89af3	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1de9d74	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc1f95b6b	force_sig
++EXPORT_SYMBOL vmlinux 0xc20e9e6f	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0xc226bcac	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0xc2424641	agp3_generic_cleanup
++EXPORT_SYMBOL vmlinux 0xc27033ac	generic_setxattr
++EXPORT_SYMBOL vmlinux 0xc2776928	block_read_full_page
++EXPORT_SYMBOL vmlinux 0xc27b8212	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0xc280a525	__copy_from_user_ll
++EXPORT_SYMBOL vmlinux 0xc289f650	fget
++EXPORT_SYMBOL vmlinux 0xc2900ff0	is_bad_inode
++EXPORT_SYMBOL vmlinux 0xc2a6b738	netlink_ack
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2acc033	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xc2b51c97	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0xc2d0731d	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0xc2d711e1	krealloc
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc30d2cc7	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0xc31d272f	follow_down
++EXPORT_SYMBOL vmlinux 0xc31d9277	neigh_update
++EXPORT_SYMBOL vmlinux 0xc324d67a	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0xc3292e01	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0xc3379111	vga_client_register
++EXPORT_SYMBOL vmlinux 0xc34ecf58	abort_creds
++EXPORT_SYMBOL vmlinux 0xc356cf20	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0xc369ffea	agp_generic_free_by_type
++EXPORT_SYMBOL vmlinux 0xc37f5f2e	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xc393faf2	__frontswap_store
++EXPORT_SYMBOL vmlinux 0xc3a99597	lro_flush_all
++EXPORT_SYMBOL vmlinux 0xc3aaf0a9	__put_user_1
++EXPORT_SYMBOL vmlinux 0xc3b70870	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3d67bec	update_region
++EXPORT_SYMBOL vmlinux 0xc3e1d9a9	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0xc3e25e3e	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0xc3f45a9a	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0xc3fa6a59	memchr
++EXPORT_SYMBOL vmlinux 0xc41dc8a0	param_ops_string
++EXPORT_SYMBOL vmlinux 0xc41f0516	node_states
++EXPORT_SYMBOL vmlinux 0xc435ed50	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0xc450b0e9	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0xc460e062	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0xc4626b3e	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0xc464d261	default_llseek
++EXPORT_SYMBOL vmlinux 0xc47210aa	dcb_getapp
++EXPORT_SYMBOL vmlinux 0xc48c4f38	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4a1ec56	single_open
++EXPORT_SYMBOL vmlinux 0xc4a58249	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0xc4ba3221	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0xc4ca00e9	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0xc4d0c387	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0xc4e85a12	tty_port_close
++EXPORT_SYMBOL vmlinux 0xc4f0e2b8	register_cdrom
++EXPORT_SYMBOL vmlinux 0xc4f13354	bh_submit_read
++EXPORT_SYMBOL vmlinux 0xc50b4602	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0xc5137552	x86_bios_cpu_apicid
++EXPORT_SYMBOL vmlinux 0xc520286d	free_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0xc5462085	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0xc5534d64	ioread16
++EXPORT_SYMBOL vmlinux 0xc55b18c0	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0xc55f437c	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0xc56833bf	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0xc568a9c0	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc5a05475	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0xc5a4549b	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0xc5bede54	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0xc5d12844	poll_freewait
++EXPORT_SYMBOL vmlinux 0xc5d53b7a	netdev_notice
++EXPORT_SYMBOL vmlinux 0xc5d9c46c	agp_try_unsupported_boot
++EXPORT_SYMBOL vmlinux 0xc5e26ba9	eisa_driver_unregister
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc601400b	drop_nlink
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc63199f7	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0xc631a28d	cros_ec_check_result
++EXPORT_SYMBOL vmlinux 0xc6378c13	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0xc64345dc	__find_get_block
++EXPORT_SYMBOL vmlinux 0xc644609b	tty_free_termios
++EXPORT_SYMBOL vmlinux 0xc64a26d9	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc65637a9	inet_sendpage
++EXPORT_SYMBOL vmlinux 0xc65abeb7	agp3_generic_sizes
++EXPORT_SYMBOL vmlinux 0xc6700f24	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0xc672f6b8	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc676b4f6	register_filesystem
++EXPORT_SYMBOL vmlinux 0xc67a09fe	intel_gtt_get
++EXPORT_SYMBOL vmlinux 0xc68cd9d7	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0xc6b0503d	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0xc6b23120	intel_scu_ipc_iowrite16
++EXPORT_SYMBOL vmlinux 0xc6b368d3	acpi_gpe_count
++EXPORT_SYMBOL vmlinux 0xc6b424e1	phy_device_register
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6d5372f	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0xc6e3323f	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0xc6f0afbd	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0xc6f14b76	fb_find_mode
++EXPORT_SYMBOL vmlinux 0xc6f1ff7e	fs_bio_set
++EXPORT_SYMBOL vmlinux 0xc6fb3cba	param_array_ops
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc731ed17	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0xc733a903	use_ibpb
++EXPORT_SYMBOL vmlinux 0xc733f7ba	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc768de19	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0xc76e0273	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0xc773a310	bdget
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc7902f75	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0xc79a381c	get_io_context
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7a8b64c	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0xc7ca190d	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0xc7cd53b9	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0xc7dd4199	nd_region_to_nstype
++EXPORT_SYMBOL vmlinux 0xc7e8ad48	rtnl_notify
++EXPORT_SYMBOL vmlinux 0xc7ec6c27	strspn
++EXPORT_SYMBOL vmlinux 0xc7f3febc	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0xc7fcc5bf	acpi_resource_to_address64
++EXPORT_SYMBOL vmlinux 0xc8088d38	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0xc8263bcc	have_submounts
++EXPORT_SYMBOL vmlinux 0xc8276a79	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xc82c980d	pnp_find_dev
++EXPORT_SYMBOL vmlinux 0xc832473a	tty_devnum
++EXPORT_SYMBOL vmlinux 0xc8339e24	string_unescape
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc8511de0	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0xc858f5f0	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0xc85b2bca	ps2_command
++EXPORT_SYMBOL vmlinux 0xc85d27b3	param_get_int
++EXPORT_SYMBOL vmlinux 0xc86d6799	___preempt_schedule
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc87ebeb4	netdev_update_features
++EXPORT_SYMBOL vmlinux 0xc88102e2	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0xc885a8c1	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0xc886cf39	seq_read
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8aceca7	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8b6a296	devm_memremap
++EXPORT_SYMBOL vmlinux 0xc8dff2b2	dst_release
++EXPORT_SYMBOL vmlinux 0xc8ed2f64	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0xc8fcc836	fget_raw
++EXPORT_SYMBOL vmlinux 0xc905331a	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0xc9075430	agp_generic_mask_memory
++EXPORT_SYMBOL vmlinux 0xc90acd51	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc9324d94	skb_store_bits
++EXPORT_SYMBOL vmlinux 0xc933b58c	d_move
++EXPORT_SYMBOL vmlinux 0xc93860f2	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0xc94afdde	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc9768728	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0xc98d3494	param_get_charp
++EXPORT_SYMBOL vmlinux 0xc9923ada	scsi_print_result
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc99f6aae	dma_spin_lock
++EXPORT_SYMBOL vmlinux 0xc9a1cef8	serio_interrupt
++EXPORT_SYMBOL vmlinux 0xc9c360ac	param_set_ulong
++EXPORT_SYMBOL vmlinux 0xc9c9a01e	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0xc9faa285	register_shrinker
++EXPORT_SYMBOL vmlinux 0xc9fef317	add_wait_queue
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca109b13	kfree_skb
++EXPORT_SYMBOL vmlinux 0xca29996f	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0xca2b0b40	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0xca32d766	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0xca41eaa3	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0xca45e24a	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0xca4da8e9	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0xca5bcc60	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0xca7aff4a	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0xca8acc78	acpi_dbg_level
++EXPORT_SYMBOL vmlinux 0xca908d9a	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xcaba3d3f	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcaf6a031	acpi_processor_notify_smm
++EXPORT_SYMBOL vmlinux 0xcaf6c204	inet6_release
++EXPORT_SYMBOL vmlinux 0xcafeaa6d	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0xcb01efec	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb11434b	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0xcb1fa6da	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0xcb234443	kunmap
++EXPORT_SYMBOL vmlinux 0xcb3ab447	security_path_chown
++EXPORT_SYMBOL vmlinux 0xcb602abf	get_disk
++EXPORT_SYMBOL vmlinux 0xcb733bf2	acpi_bus_set_power
++EXPORT_SYMBOL vmlinux 0xcb952e83	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0xcba0b329	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0xcbac3a78	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0xcbae6c7a	acpi_lid_notifier_unregister
++EXPORT_SYMBOL vmlinux 0xcbb25eda	__invalidate_device
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbeac4be	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcc1e10e0	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc4bde0b	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0xcc4d1bfb	atomic64_read_cx8
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc52d12d	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0xcc5bd58f	keyring_search
++EXPORT_SYMBOL vmlinux 0xcc828d77	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0xcc82add3	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xcc838223	__pte2cachemode_tbl
++EXPORT_SYMBOL vmlinux 0xcc8d3f4f	acpi_os_execute
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xcce62678	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0xccef5ab8	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0xccf3cede	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0xccfef64f	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0xcd13dc7c	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd2aed5e	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0xcd2b844e	udplite_prot
++EXPORT_SYMBOL vmlinux 0xcd400dc7	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0xcd508f09	seq_vprintf
++EXPORT_SYMBOL vmlinux 0xcd5755f4	proto_register
++EXPORT_SYMBOL vmlinux 0xcd62e080	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0xcd73ecc9	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0xcd9b2745	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0xcda0136f	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0xcda323bb	thaw_super
++EXPORT_SYMBOL vmlinux 0xcdaab875	pci_pme_active
++EXPORT_SYMBOL vmlinux 0xcdbfc1c4	sock_no_getname
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdc5492e	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0xcdc55556	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0xcdcbcf97	neigh_xmit
++EXPORT_SYMBOL vmlinux 0xcdf28454	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0xce1af71d	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0xce23f55e	free_page_put_link
++EXPORT_SYMBOL vmlinux 0xce243cd0	dev_set_group
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce2897ca	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0xce2c45cc	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xce473976	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0xce4904a4	acpi_leave_sleep_state
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce70ee8c	elv_add_request
++EXPORT_SYMBOL vmlinux 0xce87f122	pipe_unlock
++EXPORT_SYMBOL vmlinux 0xce9be3aa	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0xce9e41e9	lockref_get
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xcebe42f0	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0xceca8ada	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0xcedfc84d	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0xcee58848	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0xceea8de5	kern_path
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcef9183c	down_read
++EXPORT_SYMBOL vmlinux 0xcef937d8	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf092c59	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0xcf1418de	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0xcf169a0d	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0xcf1ef97b	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0xcf5df111	phy_device_free
++EXPORT_SYMBOL vmlinux 0xcf631e7a	i8042_remove_filter
++EXPORT_SYMBOL vmlinux 0xcf6479d2	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xcf6cfe1f	msrs_free
++EXPORT_SYMBOL vmlinux 0xcf77f930	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0xcf7ba9f8	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0xcf8ac3cc	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0xcfa64552	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0xcfb7a7db	request_key
++EXPORT_SYMBOL vmlinux 0xcfd4ddc8	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0xcfe05d4d	register_kmmio_probe
++EXPORT_SYMBOL vmlinux 0xcfe4e3d5	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0xd0199539	vga_switcheroo_register_audio_client
++EXPORT_SYMBOL vmlinux 0xd0235854	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0xd0534813	get_user_pages
++EXPORT_SYMBOL vmlinux 0xd05e0885	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xd06913ff	__frontswap_test
++EXPORT_SYMBOL vmlinux 0xd06a8063	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd081a5e3	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xd0841e34	key_validate
++EXPORT_SYMBOL vmlinux 0xd0905c6b	blk_queue_split
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a3e0c2	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0xd0a90e79	kset_register
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0ba721d	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0xd0d67268	__brelse
++EXPORT_SYMBOL vmlinux 0xd0d8621b	strlen
++EXPORT_SYMBOL vmlinux 0xd0dbbc60	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0xd0e42a8b	tcp_connect
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fef3b2	agp_free_key
++EXPORT_SYMBOL vmlinux 0xd11d1a28	mount_ns
++EXPORT_SYMBOL vmlinux 0xd14829fd	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd160d08d	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0xd1652a93	acpi_info
++EXPORT_SYMBOL vmlinux 0xd166b087	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0xd175703a	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd189ec0d	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0xd196c9be	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xd1bfaead	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0xd1c84dfb	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xd1d3c65d	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1f6c5f3	smp_num_siblings
++EXPORT_SYMBOL vmlinux 0xd2064e2f	idr_replace
++EXPORT_SYMBOL vmlinux 0xd20f3020	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xd213e4c0	pnp_request_card_device
++EXPORT_SYMBOL vmlinux 0xd219a7c8	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0xd235edc9	follow_down_one
++EXPORT_SYMBOL vmlinux 0xd23f0443	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0xd24334a0	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd25580cd	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd262a962	pid_task
++EXPORT_SYMBOL vmlinux 0xd26ee69f	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0xd2756629	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd2af138b	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xd2bd6b0e	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0xd2bef883	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0xd2c31f64	cpu_tlbstate
++EXPORT_SYMBOL vmlinux 0xd2cf496e	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0xd2d04a2e	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2e57167	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0xd2e580b7	ipv4_specific
++EXPORT_SYMBOL vmlinux 0xd2e6a582	acpi_processor_preregister_performance
++EXPORT_SYMBOL vmlinux 0xd2f9131c	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0xd2fa6b41	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0xd2fadde1	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0xd300a780	misc_register
++EXPORT_SYMBOL vmlinux 0xd30be606	bdget_disk
++EXPORT_SYMBOL vmlinux 0xd33f11e1	skb_pull
++EXPORT_SYMBOL vmlinux 0xd38f4ba8	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0xd393f0c2	netlink_unicast
++EXPORT_SYMBOL vmlinux 0xd3a21d63	pci_request_region
++EXPORT_SYMBOL vmlinux 0xd3b8d2cb	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd40e9a04	touch_buffer
++EXPORT_SYMBOL vmlinux 0xd41573a9	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0xd43735aa	revalidate_disk
++EXPORT_SYMBOL vmlinux 0xd44140b4	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0xd4468e4e	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0xd4592dc6	find_get_entry
++EXPORT_SYMBOL vmlinux 0xd46172ca	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0xd4835ef8	dmi_check_system
++EXPORT_SYMBOL vmlinux 0xd4848e11	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0xd4993260	sock_create_kern
++EXPORT_SYMBOL vmlinux 0xd4aab9d2	pci_select_bars
++EXPORT_SYMBOL vmlinux 0xd4bacb58	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0xd4d889ff	skb_copy
++EXPORT_SYMBOL vmlinux 0xd506c32b	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0xd50fef48	acpi_detach_data
++EXPORT_SYMBOL vmlinux 0xd52eae47	generic_read_dir
++EXPORT_SYMBOL vmlinux 0xd52f59ba	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0xd53ccd4d	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0xd53d411e	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd56e3728	ata_port_printk
++EXPORT_SYMBOL vmlinux 0xd58560e1	do_truncate
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd5a1e545	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0xd5ced54d	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0xd5d16ead	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0xd5f52d4f	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0xd5f58a1c	tty_throttle
++EXPORT_SYMBOL vmlinux 0xd5fe8b08	da903x_query_status
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd631da1b	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd68e1d1b	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0xd6a16f49	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0xd6b16ddd	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0xd6b2ed5f	generate_pm_trace
++EXPORT_SYMBOL vmlinux 0xd6b33026	cpu_khz
++EXPORT_SYMBOL vmlinux 0xd6b4a0a8	backlight_force_update
++EXPORT_SYMBOL vmlinux 0xd6bb5f5a	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0xd6c17fd4	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0xd6cf1372	isapnp_protocol
++EXPORT_SYMBOL vmlinux 0xd6d0208e	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd730959d	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xd75b55e3	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd768dea0	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0xd76fcb27	kernel_read
++EXPORT_SYMBOL vmlinux 0xd775e204	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0xd796873c	uart_resume_port
++EXPORT_SYMBOL vmlinux 0xd797b9a5	vme_master_write
++EXPORT_SYMBOL vmlinux 0xd79dca31	param_get_bool
++EXPORT_SYMBOL vmlinux 0xd7a39a74	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0xd7a7378d	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0xd7c11235	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0xd7c41295	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0xd7cc7164	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0xd7ce4cf6	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0xd7d9221b	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0xd7dc6560	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0xd7dd66bd	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0xd7dd777b	reserve_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd847b119	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0xd85833cb	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0xd85f8060	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0xd86cf5b5	tty_set_operations
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8abd0c1	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0xd8d1424d	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0xd8d993d7	registered_fb
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd9091363	acpi_install_notify_handler
++EXPORT_SYMBOL vmlinux 0xd910d7bd	bdput
++EXPORT_SYMBOL vmlinux 0xd92e2dca	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0xd94322e7	acpi_evaluate_reference
++EXPORT_SYMBOL vmlinux 0xd966ddc2	__do_once_done
++EXPORT_SYMBOL vmlinux 0xd969b2c7	amd_e400_c1e_detected
++EXPORT_SYMBOL vmlinux 0xd971c6c4	xen_arch_register_cpu
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd99d7530	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xd9b69616	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0xd9b7a496	pmem_should_map_pages
++EXPORT_SYMBOL vmlinux 0xd9cb3fc7	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0xd9d3bcd3	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9ddd322	nf_log_set
++EXPORT_SYMBOL vmlinux 0xd9ecaabc	dev_emerg
++EXPORT_SYMBOL vmlinux 0xda04bde2	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0xda08c0d7	pcibios_get_irq_routing_table
++EXPORT_SYMBOL vmlinux 0xda0b9feb	input_free_device
++EXPORT_SYMBOL vmlinux 0xda26fa92	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda4268c2	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0xda4341ca	inode_init_owner
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda8fd495	isapnp_write_byte
++EXPORT_SYMBOL vmlinux 0xda9e900c	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0xdaa57ec3	totalhigh_pages
++EXPORT_SYMBOL vmlinux 0xdaa86269	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0xdaabd954	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdad5b77a	md_integrity_register
++EXPORT_SYMBOL vmlinux 0xdae80100	_raw_spin_unlock
++EXPORT_SYMBOL vmlinux 0xdafb456b	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0xdb05321b	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0xdb16b170	topology_phys_to_logical_pkg
++EXPORT_SYMBOL vmlinux 0xdb4b7e81	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0xdb51e35c	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb7305a1	__stack_chk_fail
++EXPORT_SYMBOL vmlinux 0xdb73b13a	vga_put
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb7fccc6	pnp_disable_dev
++EXPORT_SYMBOL vmlinux 0xdb870afd	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0xdbafa0f7	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0xdbb08daf	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0xdbc6b679	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0xdbccd78c	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0xdbef5df2	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0xdbf79540	pci_bus_get
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc15f2be	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0xdc250298	led_set_brightness
++EXPORT_SYMBOL vmlinux 0xdc25a01b	nvdimm_namespace_disk_name
++EXPORT_SYMBOL vmlinux 0xdc3e568f	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc48a93b	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdc57f532	acpi_install_gpe_handler
++EXPORT_SYMBOL vmlinux 0xdc60dc74	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0xdca608d2	nf_log_packet
++EXPORT_SYMBOL vmlinux 0xdcaba60d	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0xdcd5d54f	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0xdcd8ffc4	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0xdd03bd4f	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0xdd0a2ba2	strlcat
++EXPORT_SYMBOL vmlinux 0xdd4d999c	kill_anon_super
++EXPORT_SYMBOL vmlinux 0xdd4df982	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0xdd633634	bio_reset
++EXPORT_SYMBOL vmlinux 0xdd753fcb	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0xdd7f3d19	key_revoke
++EXPORT_SYMBOL vmlinux 0xdd962d2d	from_kuid
++EXPORT_SYMBOL vmlinux 0xdd9e863b	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0xddb37d02	proc_dointvec
++EXPORT_SYMBOL vmlinux 0xddb9c412	d_obtain_root
++EXPORT_SYMBOL vmlinux 0xddba5f70	input_set_keycode
++EXPORT_SYMBOL vmlinux 0xddc6ec16	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0xde16dc16	tboot
++EXPORT_SYMBOL vmlinux 0xde2b7c11	release_sock
++EXPORT_SYMBOL vmlinux 0xde2e7cb7	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0xde44061d	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0xde51cbc4	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xde56acc1	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0xde853b41	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde9b17ed	agp3_generic_fetch_size
++EXPORT_SYMBOL vmlinux 0xded931f3	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0xdedb6611	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0xdee82254	kernel_write
++EXPORT_SYMBOL vmlinux 0xdef8de12	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0xdefa09ed	cdrom_release
++EXPORT_SYMBOL vmlinux 0xdf0da3cc	acpi_get_devices
++EXPORT_SYMBOL vmlinux 0xdf12a927	acpi_check_dsm
++EXPORT_SYMBOL vmlinux 0xdf1427e5	idr_remove
++EXPORT_SYMBOL vmlinux 0xdf1a5612	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf3a693d	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0xdf4bfebf	dev_crit
++EXPORT_SYMBOL vmlinux 0xdf4fc797	__register_nmi_handler
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf6bd3c1	dqget
++EXPORT_SYMBOL vmlinux 0xdf8c695a	__ndelay
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdf93b9d8	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0xdf941da7	netdev_state_change
++EXPORT_SYMBOL vmlinux 0xdf941fad	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0xdfa7a8ec	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xdfd3a075	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0xdfd7616d	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0xdfe200cb	d_drop
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xe008b660	d_splice_alias
++EXPORT_SYMBOL vmlinux 0xe00fa1ae	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0xe046c155	simple_statfs
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe0540202	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe065c63b	set_pages_nx
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe08f148b	pnp_device_attach
++EXPORT_SYMBOL vmlinux 0xe0a16a20	intel_scu_ipc_i2c_cntrl
++EXPORT_SYMBOL vmlinux 0xe0ac8bd2	acpi_bus_generate_netlink_event
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0b2adc4	cros_ec_cmd_xfer
++EXPORT_SYMBOL vmlinux 0xe0c0874a	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0xe0d1c3c1	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0xe0ea99ab	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0xe10c239b	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0xe11d7007	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0xe12f2fb9	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe13cd8a7	dmi_name_in_vendors
++EXPORT_SYMBOL vmlinux 0xe142dc2f	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0xe160d479	mdiobus_write
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe17a7f7a	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0xe1a8e00a	phy_init_hw
++EXPORT_SYMBOL vmlinux 0xe1e7e058	netdev_err
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe20391cb	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0xe20d6265	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0xe22f603c	read_code
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe23b278c	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0xe24cb19c	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe259ae9e	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0xe26d4bd9	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0xe286a6c3	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0xe2895c98	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0xe28c1639	ilookup5
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2c4d97e	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0xe2c8196d	acpi_bus_register_driver
++EXPORT_SYMBOL vmlinux 0xe2d47270	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2e8065e	memdup_user
++EXPORT_SYMBOL vmlinux 0xe2f24a47	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe2f6d35d	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0xe2fae716	kmemdup
++EXPORT_SYMBOL vmlinux 0xe3197208	proc_dostring
++EXPORT_SYMBOL vmlinux 0xe319eb24	acpi_pci_osc_control_set
++EXPORT_SYMBOL vmlinux 0xe3399a75	native_queued_spin_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xe358dac0	tcp_poll
++EXPORT_SYMBOL vmlinux 0xe379b727	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0xe381e679	dev_close
++EXPORT_SYMBOL vmlinux 0xe392abab	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xe3a08cb0	vme_irq_free
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3c965ca	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xe3d1b30c	load_nls
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3db61d6	nf_log_register
++EXPORT_SYMBOL vmlinux 0xe3de250f	truncate_setsize
++EXPORT_SYMBOL vmlinux 0xe3e3e8e9	set_groups
++EXPORT_SYMBOL vmlinux 0xe4279d82	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0xe42d40f7	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0xe445db4a	acpi_check_address_range
++EXPORT_SYMBOL vmlinux 0xe467e3ed	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0xe4827fb6	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0xe484e35f	ioread32
++EXPORT_SYMBOL vmlinux 0xe493c17c	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0xe4b35e8a	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0xe4c17741	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0xe4e23e4b	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe50f904f	intel_scu_ipc_ioread16
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe530c983	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0xe530d757	acpi_clear_gpe
++EXPORT_SYMBOL vmlinux 0xe53446c4	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0xe5584203	agp_generic_destroy_pages
++EXPORT_SYMBOL vmlinux 0xe56cf129	kset_unregister
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5815f8a	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe5a95d10	phy_attach
++EXPORT_SYMBOL vmlinux 0xe5c64d33	page_put_link
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5ca0f9e	sync_blockdev
++EXPORT_SYMBOL vmlinux 0xe5d51089	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe6162877	down_killable
++EXPORT_SYMBOL vmlinux 0xe6209b95	netif_napi_del
++EXPORT_SYMBOL vmlinux 0xe62636d9	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0xe63f9a8b	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0xe64d98fe	rdmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0xe65465d2	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0xe6844aba	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0xe6861a55	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0xe693a6ce	vme_get_size
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe6eae207	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0xe6eba4c4	filemap_fault
++EXPORT_SYMBOL vmlinux 0xe6ebc016	key_create_or_update
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe7145cc9	keyring_alloc
++EXPORT_SYMBOL vmlinux 0xe716baed	acpi_unregister_ioapic
++EXPORT_SYMBOL vmlinux 0xe71ca900	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0xe738348e	pci_bus_type
++EXPORT_SYMBOL vmlinux 0xe743c6d2	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0xe74adbc3	make_kgid
++EXPORT_SYMBOL vmlinux 0xe781b5f6	intel_scu_ipc_readv
++EXPORT_SYMBOL vmlinux 0xe7844234	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7b6315e	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe8009460	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0xe81ef1dd	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe86998af	dm_io
++EXPORT_SYMBOL vmlinux 0xe87025f0	acpi_evaluate_object_typed
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe87b2edd	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0xe8a12a20	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8b68849	wrmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8c02dd8	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0xe8c82f9d	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0xe8d36f99	unregister_key_type
++EXPORT_SYMBOL vmlinux 0xe8d79a56	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0xe8db8dd2	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0xe8e1a757	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe9304fad	padata_free
++EXPORT_SYMBOL vmlinux 0xe93f6042	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe95e00cf	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0xe9603ba4	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0xe97b6d8a	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0xe992853e	input_event
++EXPORT_SYMBOL vmlinux 0xe997667b	wrmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xe99a1077	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0xe9a555a2	__serio_register_port
++EXPORT_SYMBOL vmlinux 0xe9acfac4	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xe9d183d0	simple_rename
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea05a179	__breadahead
++EXPORT_SYMBOL vmlinux 0xea1029b8	mutex_lock
++EXPORT_SYMBOL vmlinux 0xea132806	add_disk
++EXPORT_SYMBOL vmlinux 0xea2ec768	blk_run_queue
++EXPORT_SYMBOL vmlinux 0xea3f725d	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xea4cf340	simple_dname
++EXPORT_SYMBOL vmlinux 0xea7987f1	key_update
++EXPORT_SYMBOL vmlinux 0xea7a42f9	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xea7b8a44	acpi_install_interface
++EXPORT_SYMBOL vmlinux 0xea826631	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0xea90bdd3	acpi_attach_data
++EXPORT_SYMBOL vmlinux 0xea98e7f3	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0xea9d8a08	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0xeae3c52e	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0xeae3dfd6	__const_udelay
++EXPORT_SYMBOL vmlinux 0xeaedf6a6	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0xeafc7ff7	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0xeafcb9b4	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0xeb1e5be6	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0xeb28d983	acpi_bus_get_device
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb44404e	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0xeb4c08f0	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0xeb55a931	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xeb678d8a	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0xeb686e66	set_cached_acl
++EXPORT_SYMBOL vmlinux 0xeb7c276b	skb_seq_read
++EXPORT_SYMBOL vmlinux 0xeb9c3014	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0xeba70207	clk_get
++EXPORT_SYMBOL vmlinux 0xeba8d18a	sock_no_listen
++EXPORT_SYMBOL vmlinux 0xebb4ee63	__break_lease
++EXPORT_SYMBOL vmlinux 0xebc03d94	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0xebd487a5	key_type_keyring
++EXPORT_SYMBOL vmlinux 0xebd739eb	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xebdb8969	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0xebe8229f	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0xebf77225	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0xebff5cf5	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0xec0dd4c8	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0xec10eb01	pci_find_bus
++EXPORT_SYMBOL vmlinux 0xec1aa6ef	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xec3578fa	soft_cursor
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec5fb132	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0xeca0b9ca	scsi_host_get
++EXPORT_SYMBOL vmlinux 0xecb26069	dev_activate
++EXPORT_SYMBOL vmlinux 0xecbcb8bb	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xecc6fcc2	inet_listen
++EXPORT_SYMBOL vmlinux 0xeccd3e0c	acpi_handle_printk
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xed2aba18	generic_writepages
++EXPORT_SYMBOL vmlinux 0xed327562	to_ndd
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed70daf4	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0xed93f29e	__kunmap_atomic
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedab545a	inet_accept
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedcb0b07	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0xedcb7582	consume_skb
++EXPORT_SYMBOL vmlinux 0xedd4d8a4	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0xedeb1a81	mmc_release_host
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xee0c0403	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0xee0d79e8	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee2e2e80	ilookup
++EXPORT_SYMBOL vmlinux 0xee530f95	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xee6e8b4a	bio_advance
++EXPORT_SYMBOL vmlinux 0xee76642a	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xee7b11a1	kobject_get
++EXPORT_SYMBOL vmlinux 0xee7eb9e1	pnp_platform_devices
++EXPORT_SYMBOL vmlinux 0xee880b77	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xeea7ae56	pnp_unregister_driver
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeec2c7cf	ucs2_as_utf8
++EXPORT_SYMBOL vmlinux 0xeec957da	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xeef470db	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0xeefcf21b	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0xef011b18	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0xef0b715d	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0xef1f325e	vfs_llseek
++EXPORT_SYMBOL vmlinux 0xef89117e	gnttab_free_pages
++EXPORT_SYMBOL vmlinux 0xef93c375	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0xef954ccc	udp_proc_register
++EXPORT_SYMBOL vmlinux 0xef9aedfc	boot_option_idle_override
++EXPORT_SYMBOL vmlinux 0xef9bfa80	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefda8d99	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefe099c3	acpi_get_event_status
++EXPORT_SYMBOL vmlinux 0xeff08481	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0xeff7c99b	dev_get_stats
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf00d8dc3	arp_tbl
++EXPORT_SYMBOL vmlinux 0xf015496d	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0xf018214f	passthru_features_check
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf0236e9c	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0xf02bf60e	agp_collect_device_status
++EXPORT_SYMBOL vmlinux 0xf037f92e	__getblk_slow
++EXPORT_SYMBOL vmlinux 0xf044ae64	nd_dev_to_uuid
++EXPORT_SYMBOL vmlinux 0xf0495d90	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0xf050d78f	elv_register_queue
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf062576b	ucs2_utf8size
++EXPORT_SYMBOL vmlinux 0xf065f629	ioread16be
++EXPORT_SYMBOL vmlinux 0xf067257c	register_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0xf07ad21c	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0xf08242c2	finish_wait
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf08e99ff	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf09f117d	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0xf0a62453	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0xf0b3d74c	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0xf0bf2d2b	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0xf0c24c19	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xf0dd912e	cros_ec_prepare_tx
++EXPORT_SYMBOL vmlinux 0xf0eaffce	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf10de535	ioread8
++EXPORT_SYMBOL vmlinux 0xf11543ff	find_first_zero_bit
++EXPORT_SYMBOL vmlinux 0xf1398e2e	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf169c8f6	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0xf18242e1	atomic64_set_cx8
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf1a14613	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0xf1ad1923	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0xf1b6bb8d	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1dbcba8	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0xf1deabf2	div64_u64
++EXPORT_SYMBOL vmlinux 0xf1e31a09	sock_no_poll
++EXPORT_SYMBOL vmlinux 0xf1e7a242	migrate_page
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1fe1bfa	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf21f920a	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0xf221e6a9	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf25db4e2	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0xf2625084	poll_initwait
++EXPORT_SYMBOL vmlinux 0xf27a25dc	simple_write_begin
++EXPORT_SYMBOL vmlinux 0xf28ed6e2	machine_to_phys_nr
++EXPORT_SYMBOL vmlinux 0xf292da22	fb_blank
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf2999b0a	copy_from_iter
++EXPORT_SYMBOL vmlinux 0xf29ea03b	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2a10553	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0xf2bdf774	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0xf2c1a8d8	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2c4b7d7	sock_wfree
++EXPORT_SYMBOL vmlinux 0xf2eb1728	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0xf2ed56d3	simple_write_end
++EXPORT_SYMBOL vmlinux 0xf2f4ca30	bio_split
++EXPORT_SYMBOL vmlinux 0xf30dde3b	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0xf312737a	phy_driver_register
++EXPORT_SYMBOL vmlinux 0xf312cb9d	ucs2_strsize
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf313eb4e	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0xf32c6af7	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf33dd447	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0xf3401c32	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf34e6518	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf3778106	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xf37c7734	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf38ef4bb	agp_generic_free_gatt_table
++EXPORT_SYMBOL vmlinux 0xf38fe6c2	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf3986b06	acpi_os_map_generic_address
++EXPORT_SYMBOL vmlinux 0xf3aaa39a	nd_btt_arena_is_valid
++EXPORT_SYMBOL vmlinux 0xf3d7df4b	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf3ede795	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0xf3ee7a3f	send_sig_info
++EXPORT_SYMBOL vmlinux 0xf404c9f9	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0xf406410f	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0xf40b2297	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xf4300008	f_setown
++EXPORT_SYMBOL vmlinux 0xf43c5f1a	key_link
++EXPORT_SYMBOL vmlinux 0xf4418789	tcp_close
++EXPORT_SYMBOL vmlinux 0xf441ac43	ioread8_rep
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf4871b2e	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0xf4a5c213	avail_to_resrv_perfctr_nmi_bit
++EXPORT_SYMBOL vmlinux 0xf4b754fd	acpi_resources_are_enforced
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4de8d8c	tty_kref_put
++EXPORT_SYMBOL vmlinux 0xf4dee67f	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0xf4e0e9f2	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf4f7bfb6	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0xf502d273	acpi_get_current_resources
++EXPORT_SYMBOL vmlinux 0xf5033b48	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0xf51ae235	touch_nmi_watchdog
++EXPORT_SYMBOL vmlinux 0xf51bae4e	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0xf5289ae9	__sb_start_write
++EXPORT_SYMBOL vmlinux 0xf534332a	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0xf536d22e	acpi_set_gpe_wake_mask
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf53f3ca6	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0xf54019a6	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0xf543d7d1	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0xf54a79d5	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0xf579c832	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0xf59247ca	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0xf5931888	brioctl_set
++EXPORT_SYMBOL vmlinux 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL vmlinux 0xf5a73a3f	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0xf5adf797	seq_open_private
++EXPORT_SYMBOL vmlinux 0xf5b10e67	acpi_install_global_event_handler
++EXPORT_SYMBOL vmlinux 0xf5b6f5e8	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5d6ae25	generic_file_open
++EXPORT_SYMBOL vmlinux 0xf5dbf400	__seq_open_private
++EXPORT_SYMBOL vmlinux 0xf5e4e88c	param_get_long
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf5ed19c4	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xf5f40565	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0xf5fb0d32	twl6040_power
++EXPORT_SYMBOL vmlinux 0xf6007451	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0xf6065949	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0xf61fd35e	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0xf62568e3	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0xf62dae2b	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf644f116	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0xf647f801	blk_free_tags
++EXPORT_SYMBOL vmlinux 0xf655d743	fput
++EXPORT_SYMBOL vmlinux 0xf656e443	sock_rfree
++EXPORT_SYMBOL vmlinux 0xf6576b97	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf6899c5a	acpi_get_possible_resources
++EXPORT_SYMBOL vmlinux 0xf693a145	irq_stat
++EXPORT_SYMBOL vmlinux 0xf69a3f9b	set_anon_super
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6ed42d1	vga_switcheroo_register_client
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf726d02f	atomic64_add_unless_cx8
++EXPORT_SYMBOL vmlinux 0xf73a1a9a	unregister_netdev
++EXPORT_SYMBOL vmlinux 0xf745cb16	atomic64_sub_return_cx8
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf764868a	udplite_table
++EXPORT_SYMBOL vmlinux 0xf7795477	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0xf787fadc	dquot_get_state
++EXPORT_SYMBOL vmlinux 0xf788424d	register_sysctl
++EXPORT_SYMBOL vmlinux 0xf7891779	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xf79e97cd	acpi_get_physical_device_location
++EXPORT_SYMBOL vmlinux 0xf7b7b94c	pnp_find_card
++EXPORT_SYMBOL vmlinux 0xf7c47218	udp_prot
++EXPORT_SYMBOL vmlinux 0xf7d0d525	new_inode
++EXPORT_SYMBOL vmlinux 0xf7d3489a	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0xf7e0dd55	elevator_exit
++EXPORT_SYMBOL vmlinux 0xf7f6572d	scmd_printk
++EXPORT_SYMBOL vmlinux 0xf7fd7b44	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0xf7ff5113	noop_qdisc
++EXPORT_SYMBOL vmlinux 0xf8050fac	acpi_evaluate_object
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf81b5e54	km_query
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf839286e	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0xf85ed5de	clear_inode
++EXPORT_SYMBOL vmlinux 0xf8659e96	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0xf8680c63	genphy_config_init
++EXPORT_SYMBOL vmlinux 0xf86c99a1	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0xf87b5239	file_update_time
++EXPORT_SYMBOL vmlinux 0xf88e0ee2	acpi_get_table_header
++EXPORT_SYMBOL vmlinux 0xf8b3ecfe	devm_free_irq
++EXPORT_SYMBOL vmlinux 0xf8cb0922	flow_cache_init
++EXPORT_SYMBOL vmlinux 0xf8dd814b	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf907078e	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0xf9348cbc	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xf9448738	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0xf947e77b	init_task
++EXPORT_SYMBOL vmlinux 0xf952a647	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0xf95a53ce	__check_sticky
++EXPORT_SYMBOL vmlinux 0xf95b2c1a	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0xf9612cd0	sock_no_accept
++EXPORT_SYMBOL vmlinux 0xf970d920	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0xf990b704	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0xf99ffdbc	sock_no_bind
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9c0e60c	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0xf9dd280f	page_readlink
++EXPORT_SYMBOL vmlinux 0xf9e73082	scnprintf
++EXPORT_SYMBOL vmlinux 0xf9f2a84c	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0xf9f61c22	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0xf9fc68b1	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0xfa1d23a0	neigh_destroy
++EXPORT_SYMBOL vmlinux 0xfa273b20	key_invalidate
++EXPORT_SYMBOL vmlinux 0xfa2f76f9	param_set_ullong
++EXPORT_SYMBOL vmlinux 0xfa3fc3cd	kernel_accept
++EXPORT_SYMBOL vmlinux 0xfa41770c	generic_perform_write
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa6cd0c7	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0xfa7aa0fa	page_symlink
++EXPORT_SYMBOL vmlinux 0xfa8ac42b	set_user_nice
++EXPORT_SYMBOL vmlinux 0xfaa9fcd4	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfaf05c96	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0xfafbba5b	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0xfb0443fb	acpi_get_parent
++EXPORT_SYMBOL vmlinux 0xfb1b10fb	pci_set_master
++EXPORT_SYMBOL vmlinux 0xfb28de91	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0xfb35878d	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0xfb5f1146	udp_del_offload
++EXPORT_SYMBOL vmlinux 0xfb5ffde5	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb71d439	intel_gmch_probe
++EXPORT_SYMBOL vmlinux 0xfb809c52	security_path_mknod
++EXPORT_SYMBOL vmlinux 0xfb80c7a0	acpi_walk_namespace
++EXPORT_SYMBOL vmlinux 0xfb90addc	inc_nlink
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfb95fdd2	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbbd0225	mapping_tagged
++EXPORT_SYMBOL vmlinux 0xfbbd1d4b	eisa_driver_register
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbcb4b70	dev_alert
++EXPORT_SYMBOL vmlinux 0xfbcc4869	kthread_bind
++EXPORT_SYMBOL vmlinux 0xfbcdb318	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0xfbd71298	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0xfbdab3e8	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0xfbe9989b	ns_capable
++EXPORT_SYMBOL vmlinux 0xfbeda68f	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc0991cc	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0xfc0da562	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0xfc144d1b	pci_dev_get
++EXPORT_SYMBOL vmlinux 0xfc23cac5	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc44d234	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0xfc479321	write_one_page
++EXPORT_SYMBOL vmlinux 0xfc4dec8a	bio_init
++EXPORT_SYMBOL vmlinux 0xfc562165	acpi_run_osc
++EXPORT_SYMBOL vmlinux 0xfc65459a	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0xfc71fd1d	km_state_expired
++EXPORT_SYMBOL vmlinux 0xfc734327	queued_read_lock_slowpath
++EXPORT_SYMBOL vmlinux 0xfc79b823	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0xfc7d0e6b	vfs_readf
++EXPORT_SYMBOL vmlinux 0xfc872fd1	get_ibs_caps
++EXPORT_SYMBOL vmlinux 0xfc9c1fbd	mutex_unlock
++EXPORT_SYMBOL vmlinux 0xfcac0d40	acpi_install_interface_handler
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcdb9472	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcf95c78	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfcfe4ad8	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0xfd17d7d2	dentry_open
++EXPORT_SYMBOL vmlinux 0xfd33b5fa	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xfd479372	sock_release
++EXPORT_SYMBOL vmlinux 0xfd5f431c	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0xfd7e2d08	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0xfd85b071	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfd9e2871	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0xfda51935	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0xfdaa162a	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0xfdb23ed8	put_disk
++EXPORT_SYMBOL vmlinux 0xfdb9b629	ioread32be
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfdc37c05	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xfdeb1d49	dm_get_device
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfdfd6c90	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe047ce6	acpi_enter_sleep_state
++EXPORT_SYMBOL vmlinux 0xfe13c522	acpi_install_gpe_raw_handler
++EXPORT_SYMBOL vmlinux 0xfe3b2176	inet_put_port
++EXPORT_SYMBOL vmlinux 0xfe40503f	write_inode_now
++EXPORT_SYMBOL vmlinux 0xfe51f2e7	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0xfe5791ac	__get_page_tail
++EXPORT_SYMBOL vmlinux 0xfe5d30e9	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe5e7cb2	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe83834e	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0xfe9ebbbb	acpi_osi_is_win8
++EXPORT_SYMBOL vmlinux 0xfeb3a246	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0xfec06358	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0xfeca7590	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfedd8ca9	vga_tryget
++EXPORT_SYMBOL vmlinux 0xfeeb6da7	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0xfeee3b85	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0xfeefd433	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0xfef2c78f	idr_get_next
++EXPORT_SYMBOL vmlinux 0xfefdbd4c	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0xff080844	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff3125d7	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xff3737ad	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0xff42eebf	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0xff480992	dump_fpu
++EXPORT_SYMBOL vmlinux 0xff4e9620	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff6cb7a2	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff794529	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0xff7dd17c	__init_rwsem
++EXPORT_SYMBOL vmlinux 0xff854971	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffac0162	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0xffb0acee	scsi_device_get
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffe1f057	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0xffe51886	lwtunnel_encap_del_ops
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-i586 0x7060bf0a	crypto_aes_encrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-i586 0xe409b491	crypto_aes_decrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x1730c895	glue_cbc_decrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x590893e8	glue_ecb_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x705a63ad	glue_cbc_encrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x8f02ac4d	glue_xts_crypt_128bit_one
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xeb72d183	glue_ctr_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xf5e9dddc	glue_xts_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-i586 0x28afd262	twofish_enc_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-i586 0x6f068d90	twofish_dec_blk
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x006d8adc	kvm_vcpu_write_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x00aaf935	kvm_disable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x02173aec	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x02ab3660	kvm_init_shadow_ept_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x06d06c2a	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0b5ccf15	kvm_emulate_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0bad50f5	kvm_apic_set_eoi_accelerated
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0c73f5fd	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0dac52bc	kvm_flush_remote_tlbs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x107b1c64	kvm_set_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x14248ada	reset_shadow_zero_bits_mask
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x175aea24	kvm_write_guest_virt_system
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x18298a29	kvm_mmu_unprotect_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x187aa44f	kvm_after_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x198d58b8	kvm_mmu_load
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x19b0ab46	kvm_apic_write_nodecode
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1b067455	kvm_get_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1cc3bcae	kvm_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1d0b7d38	kvm_x86_ops
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2124f042	kvm_read_guest_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x213bd0c9	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x215e79f4	kvm_arch_register_noncoherent_dma
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x23b14b5c	kvm_get_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x23dfa63a	vcpu_load
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x26498ac4	kvm_io_bus_write
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x291166c7	kvm_vcpu_reload_apic_access_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x296dd1ae	cpuid_query_maxphyaddr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2a3da206	kvm_set_cr3
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2bc2ad4e	kvm_read_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2bc31718	kvm_get_linear_rip
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2c78b8d4	__gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2e5b0e45	kvm_put_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2ed58f73	kvm_fast_pio_out
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2f636c31	kvm_spurious_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3038dd13	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x317f9e6b	kvm_enable_efer_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x34aff881	kvm_mmu_invlpg
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x36ff21fc	__tracepoint_kvm_nested_vmexit_inject
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3849ae3e	__tracepoint_kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x390600d5	kvm_lmsw
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x395182d1	kvm_mmu_slot_set_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3a90f3d8	kvm_vcpu_mark_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3bdd3f29	kvm_set_cr4
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3e094575	__tracepoint_kvm_pml_full
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3e1f72e0	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3e4a87f0	kvm_emulate_halt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3e547251	kvm_cpu_get_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3ec6935f	kvm_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3fa8e4eb	kvm_inject_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4005ea58	kvm_get_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x40ce1e45	__tracepoint_kvm_inj_virq
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x40edff19	kvm_get_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x40fbff85	kvm_mmu_sync_roots
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4288757f	kvm_mmu_unload
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x42a93269	kvm_get_cs_db_l_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x43aa84b7	kvm_get_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x43f4230c	__tracepoint_kvm_write_tsc_offset
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x44747ffd	kvm_release_page_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x47b87a93	kvm_emulate_hypercall
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x495490ec	kvm_require_cpl
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4a3b0708	kvm_write_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4e6afe8e	kvm_intr_is_single_vcpu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4fe49555	kvm_vcpu_read_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5021ba1e	kvm_set_cr8
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x52ad2bb9	load_pdptrs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x553895f4	kvm_get_cr8
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x55c268d4	kvm_emulate_wbinvd
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x55c3e856	kvm_rdpmc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x56c976a3	kvm_debugfs_dir
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x58953b88	gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x59c03c00	gfn_to_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x59c2939b	kvm_vcpu_write_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5c71b357	gfn_to_hva
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5d3e5fd1	vcpu_put
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5d6d398f	kvm_is_linear_rip
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5e680dc8	kvm_read_l1_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x60c9964e	x86_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x62afe52b	kvm_complete_insn_gp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x63d76a4d	kvm_vcpu_is_reset_bsp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x64020e10	kvm_set_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x68138a79	__tracepoint_kvm_nested_intercepts
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6923c14c	reprogram_gp_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6a4fcba2	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6e96a6cd	kvm_mmu_slot_leaf_clear_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6f49328b	kvm_inject_realmode_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x72342fba	kvm_inject_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x75359b91	kvm_mmu_slot_largepage_remove_write_access
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7558ceb7	kvm_arch_has_noncoherent_dma
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x770a145a	kvm_vcpu_gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x77476c7d	kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7b7bf34b	kvm_mmu_unprotect_page_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7c59e22e	__tracepoint_kvm_ple_window
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x80ecfb6b	__tracepoint_kvm_skinit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x831327da	kvm_max_guest_tsc_khz
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x831e3537	kvm_vcpu_gfn_to_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x84da12df	__x86_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x85bcce7f	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x85d39083	kvm_get_dirty_log_protect
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x86a4a57e	kvm_vcpu_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x86f74859	reprogram_fixed_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8a0b8b8a	kvm_arch_start_assignment
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8c1d23c0	kvm_inject_pending_timer_irqs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8ce4f3ab	kvm_enable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8d745798	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8ea4bfc4	kvm_cpu_has_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x909bf8cd	kvm_scale_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x92820a57	kvm_set_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x92d713dd	__tracepoint_kvm_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9390cbd6	kvm_task_switch
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x953bdf3d	kvm_requeue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9620ca4e	kvm_arch_has_assigned_device
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x96d19ef4	handle_mmio_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x96dbe382	kvm_mpx_supported
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x982cd932	__tracepoint_kvm_nested_vmrun
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x982edc16	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9a216313	kvm_define_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9c171a59	__tracepoint_kvm_cr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9e0a65d0	__tracepoint_kvm_nested_intr_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa0d812b6	kvm_set_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa0ec3a0a	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa45f7dfa	kvm_mmu_clear_dirty_pt_masked
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa9a7eb07	kvm_require_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaace487f	kvm_init_shadow_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xab82b162	kvm_queue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaba641fb	kvm_set_cr0
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xac513a88	kvm_mtrr_get_guest_memory_type
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xacf7f97c	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xadf88e94	kvm_write_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaf8fb389	kvm_set_msi_irq
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb0faa6c7	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb1e9c360	kvm_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb34ff9c6	x86_emulate_instruction
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb3d162c1	kvm_mmu_reset_context
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb90f9a9a	kvm_read_guest_page_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xba9ed435	kvm_mmu_set_mmio_spte_mask
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbdfabd28	kvm_set_xcr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbe689b84	kvm_mtrr_valid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbfb235ee	gfn_to_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc0bb28d8	kvm_vcpu_gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc1f396c9	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc23f3bc8	__tracepoint_kvm_pi_irte_update
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc2ab1665	kvm_requeue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc56d75ce	__kvm_apic_update_irr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc5857e87	kvm_arch_unregister_noncoherent_dma
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc599bc18	kvm_max_tsc_scaling_ratio
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc5e48a48	kvm_clear_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc7ef9bcb	reprogram_counter
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc8945fe5	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc9abdf67	kvm_write_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xca05e837	kvm_get_dirty_log
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcfc39653	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0459e67	kvm_has_tsc_control
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd07a49a9	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0b2727a	kvm_mmu_set_mask_ptes
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0f4c7c1	kvm_vcpu_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd47460bb	mark_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd6322c8f	kvm_vcpu_block
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd7d0486c	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd7eb738b	__tracepoint_kvm_fast_mmio
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd93bbd46	gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd9bd1b49	kvm_valid_efer
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xda11af86	__tracepoint_kvm_nested_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdb3b70ef	kvm_vcpu_gfn_to_hva
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdc130d2d	kvm_mmu_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdc93cc05	kvm_set_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xde9c017c	__tracepoint_kvm_invlpga
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe091e17a	kvm_lapic_set_eoi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe66f5c14	kvm_queue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe89b7b30	kvm_get_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xee206a58	kvm_vcpu_read_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xef6b75f6	kvm_apic_update_irr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf1f3cb3e	kvm_find_cpuid_entry
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf2f286c4	kvm_tsc_scaling_ratio_frac_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf3718a3e	kvm_before_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf48fcd75	kvm_set_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf59973e5	kvm_arch_end_assignment
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf677e684	kvm_read_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfaaa8f1b	kvm_vcpu_halt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfdc68132	__tracepoint_kvm_page_fault
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x17449176	ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x2d20655e	ablk_init
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x2d59677a	ablk_decrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x5218a988	__ablk_encrypt
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x5944d3ce	ablk_exit
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x6d27b394	ablk_init_common
++EXPORT_SYMBOL_GPL crypto/ablk_helper 0x77a167c8	ablk_set_key
++EXPORT_SYMBOL_GPL crypto/af_alg 0x11badcb8	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0x12c6ae67	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0x1dfe586c	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0x711b1105	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0x9f75cdf4	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xb7b82e23	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xbe051a56	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0xdcfcc288	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xe5f6cd24	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xe828552e	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0xf81574e1	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x3e4c6461	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x471865e9	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x79176f1a	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x6bae5629	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0xb40402b2	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x485a4399	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x9a181ad2	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xaf18d6e0	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xd6228067	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x0ca40a7e	async_xor
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x1a81282b	async_xor_val
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x3f48f7d7	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0xe875aec8	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8aaf01d4	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x6214796e	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x75cda56a	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/cryptd 0x1f61c797	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x21c0fcc2	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x2e3a01a7	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x404552f3	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x59cf6d82	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x5cd2f7fe	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x65f319db	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x7300986f	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x9bd72475	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xdead0be4	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0x4b8417ae	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x14bdd4d3	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x2730a845	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x3e837bb1	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x4ef4999d	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x63c5bfbe	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x6583d04f	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x6e0e2c41	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x6f0c1710	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xba5d4021	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x16d317c7	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x5331d8f4	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x808e603c	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x858dd163	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x970cba58	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0xbe728c06	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0x767216ac	xts_crypt
++EXPORT_SYMBOL_GPL drivers/acpi/nfit 0xa50b6b9f	acpi_nfit_init
++EXPORT_SYMBOL_GPL drivers/acpi/nfit 0xba57bfd3	acpi_nfit_attribute_groups
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x1c8984c7	acpi_smbus_unregister_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x87bd07bd	acpi_smbus_register_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xb9a141b0	acpi_smbus_read
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xe1372311	acpi_smbus_write
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x03343b38	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x13f7cf7c	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x1d977339	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x1f250a6e	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x268f8d97	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x2c290650	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x44413ffd	ahci_host_activate
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x4ee5a527	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x52857ca6	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x5acaccb0	ahci_error_handler
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x63410e83	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x638e8f99	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x7ebb3ca9	ahci_qc_issue
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x811e4067	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x82019282	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x836c0ca7	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x9a03282b	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa6caa8df	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xcaadbc0a	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xd4e5f2ea	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea8f51dd	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf50f306b	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf8fd0cb9	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x2ec2f224	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x3b0cf6e0	ahci_platform_resume_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x4d855452	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x57a6c8da	ahci_platform_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x695cf13a	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x77325042	ahci_platform_suspend
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x860efbfd	ahci_platform_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xaf6586ec	ahci_platform_init_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xb9e64e4c	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xbeedd347	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xcd1067f4	ahci_platform_suspend_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xd0596295	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xe1282980	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0xd42550cf	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x02ff9464	cfag12864b_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x0ecb2e5d	cfag12864b_disable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x305dc3c6	cfag12864b_isenabled
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x3389f926	cfag12864b_enable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x9522a342	cfag12864b_getrate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0xc48e9d95	cfag12864b_buffer
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x297798ba	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x353c96bd	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xd3f94e7c	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xf4962b2d	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x0d7ff991	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x11669dac	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3aa5757d	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x481b09e9	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x605492fc	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6e096ec1	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x7152353e	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x73d4df91	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x778c3207	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x80a30b61	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x84f12b7a	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x8a776233	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x997eb506	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc042b794	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc20447c6	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xcab6c873	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdae27c47	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdff05795	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe0dfe6e5	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe2f32b44	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe3dbf119	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe9ec636c	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xef4ec4db	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xfbc88f2f	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x05df2e8a	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x067aa9ca	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x106efc42	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x96f574ce	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xd4543697	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xff8abb6c	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x3f5f01dc	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x5b87bee9	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x6d5f535e	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x8b1e895a	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x93921bef	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x953dc4b8	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x99b9ba75	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xa36a39fb	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xb1caec7e	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xb7d366d9	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xddefa828	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xe9a18fef	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x069c8080	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x2c5505db	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x306deea0	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x32a9342c	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x3bcdab35	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x64b7d12b	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x7e6ef197	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xe6ba73d3	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xe6fb1bc3	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xf706833a	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xfa1aa5e3	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x58dfbe40	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0xa5a5ef5c	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0x1a20763f	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0xfbb4c45e	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/char/scx200_gpio 0x835313fc	scx200_gpio_ops
++EXPORT_SYMBOL_GPL drivers/crypto/ccp/ccp 0x04773b60	ccp_present
++EXPORT_SYMBOL_GPL drivers/crypto/ccp/ccp 0x9c3371ea	ccp_enqueue_cmd
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x0093666d	adf_disable_sriov
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x06935bcc	adf_init_etr_data
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x0e755c70	adf_dev_put
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x10160269	adf_cleanup_etr_data
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x1486b286	adf_init_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x24b11dd6	adf_cfg_dev_remove
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x2ec5150e	adf_dev_stop
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x30a65bb1	adf_init_admin_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x4a8b4106	adf_send_admin_init
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x4c12ea06	adf_response_handler
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x51d372cc	adf_devmgr_in_reset
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x5e36e125	adf_service_unregister
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x79d1eb10	adf_iov_putmsg
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x7e2d3a4d	adf_service_register
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x84e99952	adf_exit_admin_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x8e4fe09b	adf_dev_init
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x90f26552	adf_cfg_dev_add
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x91c11df3	adf_enable_pf2vf_interrupts
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x98950643	adf_dev_shutdown
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0x98e5c042	adf_cfg_section_add
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xa6031dda	adf_sriov_configure
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xa7cff3d2	adf_update_ring_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xa916fe42	adf_cfg_add_key_value_param
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xb6fc9819	adf_dev_in_use
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xbb4316f2	adf_enable_vf2pf_comms
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc3a77de7	adf_devmgr_update_class_index
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc406b455	adf_devmgr_pci_to_accel_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc69aed4e	adf_devmgr_add_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc903b01a	adf_disable_aer
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xc9836a01	adf_dev_get
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xcb1e4476	adf_dev_start
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xcc3b167a	adf_clean_vf_map
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xd7616933	adf_dev_started
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xf2e5f170	adf_disable_pf2vf_interrupts
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xf4103e2f	adf_devmgr_rm_dev
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xfaf7cce9	adf_exit_arb
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xfbb5f0e3	adf_enable_aer
++EXPORT_SYMBOL_GPL drivers/crypto/qat/qat_common/intel_qat 0xfec60b0f	adf_disable_vf2pf_interrupts
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x0f568e72	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x635e3910	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x7518d6ba	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xbe4aaf75	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xe65ddf08	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x0ae7aec3	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x1c44ce23	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x27f4c783	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x050ff452	vchan_find_desc
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x9e4ae1d1	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xc48915e8	vchan_tx_submit
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xe0f9bb62	vchan_init
++EXPORT_SYMBOL_GPL drivers/edac/amd64_edac_mod 0xccf72ccb	amd64_get_dram_hole_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x07db75e7	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c16e022	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0e7bbb60	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x1a180032	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x30d2e095	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x369f2af5	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3a4f9ca0	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4925daef	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4e4ee941	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6a734562	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x722ec75f	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x755ad9c8	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7d25d65b	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x801437e0	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x8fe76e3a	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x93934f34	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x993d1b3f	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xdacdf19c	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xdb7773b3	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf6533f6c	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf7d5768e	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf9c535a3	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xfccfc8ce	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x14878009	amd_report_gart_errors
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x1d34e996	pp_msgs
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x81d75507	amd_register_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0xb30b7e56	amd_decode_mce
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0xd3cc2686	amd_unregister_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x2e078db4	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x30683138	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x8fd1b1c7	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xe6ee5df9	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xf016f440	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xf8e5fb38	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0x013fbdac	cs5535_gpio_set
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0x93f8fe67	cs5535_gpio_set_irq
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xc0bb404a	cs5535_gpio_setup_event
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xd3bd9300	cs5535_gpio_isset
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xe07c0954	cs5535_gpio_clear
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x43e14f00	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0xeb584d01	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x158461db	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x805c8842	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x5a33401b	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x6d9a6da6	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xde006942	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x05876c69	i915_gpu_busy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x08a7896d	i915_gpu_raise
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x402468e9	i915_gpu_lower
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x500858b9	i915_read_mch_val
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0xe7237b0b	i915_gpu_turbo_disable
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x38c345d6	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xd60757e8	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xe7b1488d	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x028eca94	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0e1e2c11	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x13209d1c	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x14afe116	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2314bc6b	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x24bca7ca	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x40ac1caf	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x483efb3c	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4bd362c8	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4c5330b4	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5378524a	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x53df374a	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x588794f5	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5cad6909	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5d17d223	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x61d3ee80	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x66c6ada6	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6cd1dcb2	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6d455c52	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7bfab730	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9acac39a	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9c192993	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xac53d872	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb630baab	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbfc3758f	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc5c0b850	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc7c50520	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc8fa20be	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xcc753127	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd2fe9223	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xedc4e2aa	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xedf5da01	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf0229ab8	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf5c4e1e0	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf62ab342	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfed2df50	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x0e3c19d3	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x24b501de	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x40a5d88f	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x4c955733	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x7912d804	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x9f9e0985	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xd846c6dd	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x0264b2f2	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x0d2f50a4	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x0e9eb91b	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x0edac395	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x19c1308f	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x278b1e9b	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x5c1c645c	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x60f8d4c9	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xfb1391e5	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x24bf0bd8	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x01c080b6	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x2221f850	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x2b96ea92	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x4b1e072c	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x60f2083e	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x7925b756	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x930def81	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa56b1506	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc1940145	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc58172ee	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xccac2e69	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xd2d82350	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xdf31e2d3	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe424b6e6	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xed21d76f	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf34158b6	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf5c63c75	hsi_async
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x0871d636	vmbus_get_outgoing_channel
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x0928b25f	vmbus_sendpacket_multipagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x1a25cd8a	hv_do_hypercall
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x1f92cd1f	vmbus_set_chn_rescind_callback
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x206c5b03	vmbus_set_sc_create_callback
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x25a0a3d2	vmbus_cpu_number_to_vp_number
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x33cd9f28	vmbus_teardown_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x358fafa5	vmbus_prep_negotiate_resp
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x46a417ca	vmbus_proto_version
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x755a8812	vmbus_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x790c9955	vmbus_hvsock_device_unregister
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x7c2d65a0	vmbus_establish_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x86ff5fa6	hyperv_cs
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x876a0925	vmbus_close
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x915b03ad	vmbus_setevent
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x9ffcc051	vmbus_sendpacket_mpb_desc
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xa879d5fe	vmbus_set_event
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xab805148	vmbus_recvpacket_raw
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xb05573de	__vmbus_driver_register
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xbaf1e5c9	vmbus_sendpacket_pagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xdb2f6047	vmbus_free_mmio
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xe31cbb28	vmbus_open
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xeadb5fcc	vmbus_send_tl_connect_request
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xed631a71	vmbus_sendpacket_pagebuffer_ctl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xf231ea23	vmbus_allocate_mmio
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xf5ed6ce9	vmbus_are_subchannels_present
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x375aa662	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x70dd8071	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x881e25bc	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x03bca471	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x07a687b9	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x1db04eeb	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x41a0a035	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x427b4a23	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x44b65467	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x4ecad97c	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x52e8448f	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x67d9e6a8	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x76d039f9	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x8183f7f4	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x867ab3d1	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x90c3645c	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xcb6bd123	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xdcaab967	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x05a080bf	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x0afa291e	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x86b6e425	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xd06f8fda	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xdbb2b52a	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xeac95838	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xeec6c9f4	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x1d2c6a4c	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x8d050e3f	stm_source_write
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xa082f68c	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xa620c36b	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xc1c805fe	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x02c8bc01	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x0616d491	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x2f3a05ce	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x55162f7a	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x947981e3	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-nforce2 0x7b53fbf5	nforce2_smbus
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x57c0f20b	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x9352f504	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x5092d18d	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x6871ac43	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x1b5a8a9c	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x90f5092f	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xec20e96b	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x0e363ad6	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x1107a78d	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x1b1e1d45	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x4d3de512	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x68333604	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x6a58cd4e	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xa0c073a0	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xb9040d4f	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xbd712cc0	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xeaad31fa	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a900021	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x79f12894	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0x33d30d6d	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0x80c61408	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xaa1c97fb	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xba952cc8	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xe71b5791	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x004e081a	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x0cd246ad	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x17432dbf	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x1a906831	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x3d54d906	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x70c9270b	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x8ce9c9fe	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x8f39b7d9	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xa6bec60a	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xba43bf7c	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xc8bb6520	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xd3e7fd56	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x053b4e27	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0e022536	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x20e28301	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2ae2e2b6	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2bac93d0	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2f3be927	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x31bd007b	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x331c0020	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x371afac1	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3b047abf	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3ec5c03b	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3fa95870	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x43390905	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x434a85d7	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4414ae92	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x496e3e6a	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5beb37d8	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5d0ea585	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x67e9d91f	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x70f911ef	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x74f0c0f2	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7827ac13	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x79ae9d6d	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7f91105c	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x83e51801	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x93c7db45	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd3c640dc	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd3e183c6	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd42f597a	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe49baa74	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe5605a52	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0xb30da835	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xa6ddf1a6	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x128f7306	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x25fda874	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x73fddb9a	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x2e381d79	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xee5e091a	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xf6635b81	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x02c2cec9	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0xfa89b3d5	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xb49985cb	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xcddc58b4	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xde001705	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xeb0eae10	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x09a675ce	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x14186894	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x1451fba8	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x29b7b4f4	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x45a13e6b	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x51758518	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x70bf9ae4	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x9740461e	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x9a745455	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xb5a96057	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xc50c7550	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xd77d62d8	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x19934df9	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x2b2c71be	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x3f685a8f	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x4e9b5b4b	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x589a863b	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x9725ceae	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xaa4cc504	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xabf41975	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xfb0d3fc0	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x0b5acff1	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x1672e2e2	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x3c32c720	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x3c545be3	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x3ea1afe9	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x461bb9c3	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x4dd8a07f	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x751cc802	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7586c996	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x77964200	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x77cf000e	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8eff32df	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x99e9065e	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x9fd496df	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc06029ce	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xcce2dfda	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xe51c9a83	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xeb32de1e	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/leds/dell-led 0x86fd1ffb	dell_app_wmi_led_set
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x1f5d9cdf	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x699d4280	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x83ffb7e0	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xdc386a14	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xe934cdf1	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xf2baedce	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x144b083d	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x1a9ca42c	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x330e557f	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x43aaed48	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x47fa3624	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x562683fb	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x6d1803a7	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xa374ec46	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xb3414367	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xb73add31	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xefa537cd	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x64e3c0dd	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x7f5fd153	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8bf52ac0	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xac2e07c7	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xbe9744a1	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc24c7792	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc33eb5fb	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc6c45c80	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc8f0a2ab	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xcb6a6b2c	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xcf6bc006	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xebafaa5c	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xf5e51309	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xfaa45b06	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x00b74659	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2a1a7a99	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x374f45ea	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3a4dfef7	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x48991e9c	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4f124797	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x614e860f	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x647af374	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6724de29	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6726a0c1	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x68f1ea6d	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7114cfcc	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x78c57fa5	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7cb4bd6f	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x816ebfe0	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x833b99dd	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8afe3e2b	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x912566ef	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x92c55e92	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x9c59320b	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa7004101	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xaf2376ac	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb3942afe	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb4cffcbb	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb9c28744	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc0bd3171	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc773563c	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd81ad8c9	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe30b6b2a	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf6169c53	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfcb52b5f	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x040e71a4	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x11866145	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x21e11ec4	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x61134e33	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x61c3fdb3	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x67f5d020	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x90559882	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x92eea94d	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb73c1640	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x1aacf395	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x22163b69	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x3909d3a8	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x594952bd	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x62a23587	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9b2b253a	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xdc69e37a	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe004ee92	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x12e5def9	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x432c7aad	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x44470621	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x44d726bc	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x5a73ff22	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x7345b773	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xc5556c91	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x2bb88508	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0xed179843	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x09472122	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x0bc1e28f	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x1fe4ae85	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x5da80e7c	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa8813ad6	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc66ce277	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc8140be2	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xcab63c3d	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xdc55e434	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xe11e5ab8	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf37a3cfe	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x11eab9fe	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x13780c16	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x150c85ce	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2e730a21	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x33c03da6	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x619701dc	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9b4b5b29	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa2507774	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbcfdc290	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbe0497aa	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xead1e727	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x00e68319	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x0e26ab05	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x24120e25	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x3bf78a9f	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x7c80d944	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x8ad8f5fa	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xa0ed8889	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xb8eaf3a0	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xd5b2191e	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xf38b3640	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x004ccca8	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x1d665c1d	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x8b8b820d	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xa55c113f	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xaa83cd57	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xe1cf3836	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xe6a5ee4f	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x02c2ba56	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x11c6f27a	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x23b4e156	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x26411482	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x59e7dfa0	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x5f4432b8	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x63222b29	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x6ff3ffb4	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x790563fc	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7db495ba	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x89ed2023	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9660c5f4	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9ac41cf8	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc00a8e76	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xcf0027e5	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xd487620d	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xf20b5dcc	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xf217ac17	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0xe233871a	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0x5748cc9a	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0x9a212537	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x0b93390d	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/media 0x218e320c	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0x30638469	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x3f94807f	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/media 0x48021010	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x49baa1ae	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0x5c7c18ee	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/media 0x6ee5271c	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x89f2e21f	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0x8f1d062a	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x97af34cc	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x9a152d9f	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/media 0xb446b43c	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0xbe469a6a	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0xc6bec1ab	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/media 0xca5a9e33	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0xd6485858	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0xfe237747	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0xf06d1b0c	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x1378d4e0	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x2372d7db	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x2d5ee59f	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x41015f74	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x65298116	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x6e733626	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x7798bf9c	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x78e3c1d9	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x812abac8	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x84d17311	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x85b3e384	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x9c4a3d80	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xa64cb2aa	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb319ebf9	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb856eb4e	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb862e3e2	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xc0241a3e	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xda116b4d	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xe327cc92	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0f4777a2	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x22e3ea0f	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x3556e351	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x46b33331	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x518f1f8b	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x68152c1e	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x7b795665	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x811ea155	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x99e5b48c	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x9dd5dd88	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa6f8c7d4	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xb51504c7	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc2de8120	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc633f946	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xd17e9322	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe2b4c88a	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xea882697	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xeebdcc6d	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xfd49460a	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x04187190	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x1664e9c6	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x20c5c404	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x78482f92	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xb2278ab5	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xf9fbc05f	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xfa991690	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0x204504fe	radio_isa_remove
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0x2287fda4	radio_isa_probe
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0x289e740c	radio_isa_pnp_probe
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0x4c084e89	radio_isa_pnp_remove
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0xdba43fa9	radio_isa_match
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0xbba6613a	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0xe5b4efd4	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x1ee3be6e	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x2028d55d	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x2780b1bd	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x34d932ef	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x3508bc6d	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x37c163e3	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x3d3fe003	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x59ecb40b	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x89c3002a	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9266da49	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa2c98bc5	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa5985792	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb4b4e95c	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb99c1e67	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xbadc7203	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc28901b1	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xcd897d9e	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xe1a28cb0	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xfda239f0	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0xdaf6a1f7	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0x8693fec0	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0xe59e2d9a	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0xfd179429	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0xe4ff4535	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x90cef161	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x305f1ed2	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x579335d3	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x7bfcc32e	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x45d596dd	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0xc9e3a23b	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x12c68425	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x206d0865	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0x50f8b768	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x0a005a4c	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x1e02a7fd	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x31c8de84	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x4720f2e9	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x555ba821	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x5b890d2f	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x63497df0	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6c8df34c	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa6391fe3	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa778c127	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xb9b98829	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd2208459	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd928c846	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xdc4aa1ee	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xddbe2433	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe0be7a1a	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe27dbbee	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xea62bc6b	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf3ee27ad	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xfc90de7e	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0xd6aaabce	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x8ed96f7c	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1b673e30	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x36dbdb09	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3c2f0843	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3cb1df2c	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x661e25e1	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x74e9eae8	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x78311f7b	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x8a821cc5	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x99c16caf	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xb37f64d5	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xbe684805	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcaffb293	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xd9c20ee1	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xdc798b97	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xe5369f73	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xf5f75e61	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xfe2c3264	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xfeda7f0f	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x36cdf7ce	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x457b3970	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xc627d675	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xe151c391	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x346b1033	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x63ededfc	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x679a86ff	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x6b64de5f	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xb72fdb0c	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xde16b7be	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0xc9b4d2b6	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0xf91f87ab	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x18a874a1	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x23fb2818	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x2ed75657	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x31add741	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x36fa3bce	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x39a1d048	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x591f1fe8	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x63cfe8e8	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6df67b06	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7067c57c	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x76adaef2	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x780b8828	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7aec454a	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x85cfaa06	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9a66192f	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9cbded77	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xad91617e	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb1766987	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xbf2766ab	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc2c71949	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd6727c17	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd9a6c3fd	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xdcfac16d	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf5afaffc	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf642e9fe	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf7dc020f	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xff796b29	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x03ae7a96	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x0648cbf9	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x09e9f664	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x32522419	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3a9cb7a5	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x53205891	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x64367272	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6d850c2e	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8cdab8c8	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8d17c751	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x90115414	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x99026d7f	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa8b8e8c2	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xbba63ad1	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xbccc68f5	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xcbbc732d	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xcbc6e368	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe17abbed	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe2f4b47d	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xed99358d	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xee5f0879	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xef584d63	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf1e0238e	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf2866f2a	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0x10e485c8	videobuf_to_dma_contig
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0x531e0244	videobuf_queue_dma_contig_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xcd25d9bd	videobuf_dma_contig_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x19a01d0c	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x1d00a9af	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xa825c75b	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xf0b3b08c	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xf19422de	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x0410fcb4	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x0b9f3f02	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x9d8cc3e1	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1faf0dcb	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x237e6efc	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x27763018	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2bb41e7c	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2f3e8039	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x417ed183	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x50ea800c	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x676b5845	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x682c64cd	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7b9ff3d2	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7c75aad9	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xac230c38	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xad58d6b1	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xc03bc6ce	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd5472071	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xdd308236	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf9d4e5ac	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfec35778	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x725a8e21	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x7580b4a4	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xaee9991f	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd4a399fe	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x963caf3a	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0154a1e2	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0315ac17	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x08751360	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x10b07cad	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x199e577b	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1c4d7636	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1e1f9788	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1fb320b1	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x21ec24d7	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x279f9c92	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x27f2af6e	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x28eff02c	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x301dde25	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3230d169	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x401402ff	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x4afad049	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x545673cc	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x58b88a25	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5c04b524	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5e0e8543	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x61bd8a17	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x81570155	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x83d75a66	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x89135004	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8aeecbba	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xad422a7a	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb6ee056a	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc749d5cb	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc986de56	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xe065696e	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xe4fa1901	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xfceeda75	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0xf47b9e51	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x085c1c98	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x119a76b2	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1ef51dd3	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x228ccda9	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x28d20b15	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x31138e11	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x31e3d76e	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3740e82b	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3c0fb0dd	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4b62d52b	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x50b7a60b	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5238937d	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x66dadc67	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x671e9ed4	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x730224b5	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7364bdec	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7a85f5d7	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8c18364f	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8df8ce2e	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8fa601e9	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x98545b10	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9bd06477	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9f3ca3fd	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa42a7611	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xaeb6239e	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb325a2f3	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb826c674	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb9c9e655	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xbc7257e5	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd0755a60	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd8c28b5b	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xdb696b62	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xddcf5f10	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xeed73f78	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf5956f8c	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xfdd499f9	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x224e707f	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xc3cafbcb	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xf6f0c0f8	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x37072500	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x5aa2a07b	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x722c7055	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xa7b5b647	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xcb22ccfa	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xcd483133	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xe6fcbfb2	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x3ffaa62f	intel_lpss_resume
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x4b763169	intel_lpss_prepare
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0x5494accf	intel_lpss_probe
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0xa6ca9951	intel_lpss_suspend
++EXPORT_SYMBOL_GPL drivers/mfd/intel-lpss 0xe7217a67	intel_lpss_remove
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x06029d8b	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x42975877	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x54436bfe	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x61de9a1a	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x75177ac5	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xc9c4824b	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xcdfba4c1	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xf3ffa9f3	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x5e568e39	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x62d5afa7	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x8abaa2da	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x015c679e	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x22b77a9c	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x2c5c742b	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x32af55a0	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x554b454a	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xba5957a5	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xcf36fbb5	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x308d985e	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xb9f2ec86	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xdd59b5fa	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x71d66960	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x748518f8	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xa60b319f	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xb4228801	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xe6973649	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xf498c321	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x25db93d8	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x429e0667	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x5358ee65	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x551dd93a	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x790d5009	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x7a8c13d2	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x7c808968	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x8bcbfd23	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xb7ff4612	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xc2b164ef	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xd22ef437	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x72290741	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x8d82c881	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x1d8daaef	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x56bce398	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x89a32e51	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xa5bd59ba	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xeff0c190	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x05fa8aa8	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x1d3e6c08	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x2016fa8c	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x26824453	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x269c0e47	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x2b1753be	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x2fd9cf84	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3f413fe8	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x44b0dfd9	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x47468641	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x6cce8b69	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x6daa7676	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x72ee70a8	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x7313864e	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x8c3869ba	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9414a43d	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9883f959	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9aac7cf0	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9e9d17e8	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb48ca01d	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb9e07020	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xcb18a363	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd56dae81	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xdbadc438	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x0fb28a2a	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x2536843b	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x286a6c40	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x2b6fb52f	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x3d920ab8	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x3dcbef18	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x4b520938	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x5a2aaf9b	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x6d51cf79	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xa17371da	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xb76ed031	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xc7709ccf	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xe5ee0b84	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x09c839b1	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x12f11785	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2a0348ea	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3b7f86d8	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3fad64e4	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x432dcb78	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4ed2c7b0	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4f44b33f	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x606418b9	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6beee7b6	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7d4e078f	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x84adfb20	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x85ce1234	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x89dbffb1	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x998d1888	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9ab3a3a8	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9ba4e753	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9c4df5cf	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9d81c840	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa22061ca	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa5455c93	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb4387943	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbb27be26	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc3429a16	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xcf547ed7	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd1f3b54d	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xdcb5b747	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe755cea5	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xeada7fb0	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf0d4be3d	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf102e59a	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf9e66ea0	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfa0cd050	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfbd720bc	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x41100d9d	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x46b2318d	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xa9a16485	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xeaa85177	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xee48d81e	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x4cf13575	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xaca00c01	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xd8418942	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xdae77a8e	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x0e9934fc	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x4322ff3e	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x8f22bbbb	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xfdd31ae7	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0x6dfdd6b1	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x5146ba20	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x87ae991c	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x9d866ca7	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xc93a8578	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x4088d0f0	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xad0ae7ea	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xc8d86676	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xfbcc3969	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x1c865ab4	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x446937f4	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x871b42de	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x8ab7e93d	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xa090575f	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xa95c4f93	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xece8eb0b	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xf2000c40	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x082e3bef	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x30ad928d	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x30c16676	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x42f28ae5	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x48d75eb9	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x68f6473b	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x7dc348d4	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xe5a181e2	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x07b6915d	mei_stop
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x14c410d9	mei_cldev_enable
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x169f2da8	mei_irq_read_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x19e378d8	mei_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3555b6cf	mei_start
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3df7b55b	mei_irq_compl_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x3e6469d4	mei_irq_write_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x425b0c06	mei_cldev_set_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x451190fd	mei_reset
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x72431705	mei_cldev_register_event_cb
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x73e70085	mei_cldev_recv
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x7470baa6	mei_device_init
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x7733721e	mei_write_is_idle
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x7c29aed8	mei_cldev_ver
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x90983f8b	mei_cldev_send
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x932e733f	mei_cldev_driver_unregister
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xbc88229f	mei_hbm_pg_resume
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xbfa7c47c	mei_restart
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xda27124f	mei_fw_status2str
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xddfbebf4	mei_deregister
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xde915f2c	mei_hbm_pg
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xe7bf3bcf	__mei_cldev_driver_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xeb9c29f5	mei_cldev_enabled
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xecd5aa50	mei_cldev_uuid
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xf4a5c06f	mei_cldev_disable
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xf79157f5	mei_cancel_work
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xfcce16f3	mei_cldev_get_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/pti 0x19f09b98	pti_release_masterchannel
++EXPORT_SYMBOL_GPL drivers/misc/pti 0x23bde487	pti_request_masterchannel
++EXPORT_SYMBOL_GPL drivers/misc/pti 0x52a78e81	pti_writedata
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x81df6421	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xcd6e377b	st_register
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x0f6680ea	vmci_qpair_produce_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1152e318	vmci_qpair_get_produce_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x13aa5a5d	vmci_datagram_create_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1872c7af	vmci_qpair_produce_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1a195863	vmci_context_get_priv_flags
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x2e30d970	vmci_qpair_dequeue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x3ef56cd5	vmci_qpair_alloc
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4b630dac	vmci_get_context_id
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4ea2ccbc	vmci_qpair_peek
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4f146e43	vmci_qpair_peekv
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x50a255c9	vmci_doorbell_create
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x612df9ae	vmci_qpair_detach
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x677c36d0	vmci_is_context_owner
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x69ef87ff	vmci_datagram_destroy_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x6cc1a5f7	vmci_datagram_create_handle_priv
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x722d488a	vmci_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x7d540b50	vmci_qpair_consume_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x8b8ad67a	vmci_qpair_enqueue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9624c58c	vmci_datagram_send
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9973b9b2	vmci_qpair_consume_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9d16164a	vmci_send_datagram
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xccbb53d1	vmci_doorbell_notify
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xcf5ed7ef	vmci_event_subscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xdac94780	vmci_qpair_get_consume_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xe3e4b768	vmci_qpair_dequev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xe4cc159f	vmci_qpair_enquev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xe7e7c107	vmci_doorbell_destroy
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x14046eaa	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x80fb09a8	sdhci_send_command
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x8135b486	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x93bfb6d6	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x9a4d12e3	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xb6985be2	sdhci_reset
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xbcec2b31	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xd17a9cf2	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe80188e5	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xeb1a2379	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xf805748e	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xf9653fe2	sdhci_set_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xfafd30dd	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xfbf65445	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x027b1544	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x45bc8fb8	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x4e44a9b4	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x70a89808	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x8b553707	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xc4cdf8f4	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xf45b0f3b	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xfadb0b53	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xfd156ca5	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x2b61f332	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xd67fd6a4	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xe956f34c	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x394c06e3	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x471e4d33	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xb4e782b5	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0x582c22d7	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x27228d23	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x350d7138	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x368b7894	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0dddfbf8	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1ec06d86	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x209a994d	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x20a18c4e	mtd_block_isreserved
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x238582fe	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x24234ccd	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2623b360	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x279998c1	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2cd67e56	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3b710df8	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3b7149bf	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4100eaaf	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x48182ee2	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x49758698	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x534d7dac	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5af553d0	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5b6a2e6b	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5fdaf4bf	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x716aa130	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x72f4dadf	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x76a3ae73	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7aec627e	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x88e0c5eb	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8f57e9c4	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9481fc28	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9504aca7	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x97c88568	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9b10c24d	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa7d2213f	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb25f8c67	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xbdde2c45	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc1c21255	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc5947488	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcf8c5421	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd00949e7	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd93b3078	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe034e679	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe56af561	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xeb8223f5	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf4a1813a	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfab38340	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfd574137	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x0b47639d	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x29a769b4	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x46ebbc50	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x85a59ad7	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xb173f2ed	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x4b42147f	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0xee817d90	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0x18367398	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0xd71e807d	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0xf1bedc0d	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0xe986b10b	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x1a9f0427	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x244b6aad	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x597185f1	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x73d877cc	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x81330d86	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8761fc04	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x89e2b254	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8a9ddcd1	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xa87400ca	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xbdcba05f	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xc68c4d71	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xcbc4c229	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xd7ef159a	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe2696bfc	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x539d4468	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xd0be4064	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x0aebdc6f	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x39c2b2ea	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x703468ee	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x7657e928	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xb10a2384	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xce374305	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x2e367092	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x30784c24	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3472331e	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3b34bc0a	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3e35deb4	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x49b3e5ee	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x53b1d751	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x742d4592	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x74a104cb	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x7ca7a0db	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x955ca641	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x9bbadcf0	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xbba27773	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xbfdb3081	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc00aaf62	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc3127021	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xda9f7271	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xe6adf39b	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x45a6d3ba	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x866bc3a2	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x88423339	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xe7203c30	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x16e186c8	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x39e9292c	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x894dcd38	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xc1275d9e	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x00e1e674	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x016e268b	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0411142f	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x04c6a85c	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x05287079	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x08c1a53b	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x097ea613	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b454029	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x10a15f25	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x116888cf	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1183f118	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1304e7f7	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x157be27a	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1672b623	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x175cb17c	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1b24059a	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1beea9b2	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1c3c43c9	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1c442b6c	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1c983f9b	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1cddbb95	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1de1d304	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1dfa344a	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1e225115	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x23440333	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x238122eb	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2435a4f3	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2637950b	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x28228c96	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2bee12d2	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2c8dea85	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2f3f744d	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x30d49122	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x345be3f9	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x350cfaf8	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x39889206	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3a7b67e9	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3f733ac5	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x430d89a5	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4452abd4	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4549127a	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x45f72375	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x49c5f690	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4a9ba6e7	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4dbdffb3	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x508b800d	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x51d16b1f	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x51e02d81	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x544efe27	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x58c21d7f	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x601c6cb9	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x632cc59a	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x686dbb0f	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6b6a60f7	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6bf9f866	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6c59e31e	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6cfe0a52	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7031d649	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x71e0877e	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7454fa96	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x79a2e14c	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7a3d8dfe	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7a9d1c6c	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7bfba829	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7cc06096	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7d3792d7	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8760a9b5	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8a38c6b2	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8ae38476	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8b27dcee	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8c833036	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8e475971	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8fd1cc05	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x90e25779	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9a1d89a3	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9a7171b9	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9aa16c38	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9c21f692	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9c507c08	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9cba60e5	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9dd83258	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9f59731c	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa0d4ff56	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa3fb30d2	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa6b923ad	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb26db9dd	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb2a9e84f	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb32f9aad	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb42cc651	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb5abb2bb	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb6fd2eb0	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbcb920c0	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbeaa21ce	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbf35c36b	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc1ee446a	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc28d1ce1	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc2e27206	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc482a261	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc702636d	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc7f3e301	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc8d1a040	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc98c74a8	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcfe03620	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd27065f4	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd2f05ba1	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd3eb36ed	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd48ae952	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd4dd0fc1	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd54d508a	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd6e02b4c	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd7f9bf20	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd8ec9bc5	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdb981133	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe43df9cf	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe4ed4dbf	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe7e7a520	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xea0c16ae	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xee4ff104	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xef73f0f6	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xefbafb28	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf05f48c7	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf8a757cf	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfb5e826b	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfe96ce4a	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x00bee14c	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0193ca2d	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x039030a5	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09543b3d	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0c036694	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0ef43a6b	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0f5077bb	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x11034d21	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x18bac28d	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1b5e7edc	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x25167e64	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2ba566b0	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3070580f	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x34f8a741	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x35c9b4e8	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3942f16f	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3fafb252	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x48acca91	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x48f521b2	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x49958f90	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x54859489	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5767716b	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x60734889	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x609b57e3	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x61c80bf6	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6c446569	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6dd23574	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6e4341eb	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x75cd7b41	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x75ce8ba0	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x79c047c4	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x84fb4fda	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x89024fc8	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x89d09240	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8e456241	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x96ab2436	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xab01920d	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbab6b802	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbc51e448	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbda1335e	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc5ec298c	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc68b411e	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcb9c4048	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd59961ff	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe86bf8d4	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe9eb60b8	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x368d3d71	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xcf3c4756	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xd4ab3625	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x0b826d36	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x6b79a45c	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x79d206a2	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x83015cf2	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x17c2d1d2	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x82656454	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x85c8d281	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xf3d3f2a8	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x2b5e6aa9	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x2c65fad3	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x2e486e2c	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x31e9c95e	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x35d902b0	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x5d94bf24	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x76ac1766	cpsw_ale_start
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x823335eb	cpsw_ale_dump
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x8ac9a1ed	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xd6efb188	cpsw_ale_stop
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xd9ea850b	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xe0caeac2	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xe500d38e	cpsw_ale_add_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xf4513f1f	cpsw_ale_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xf460eac7	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL drivers/net/geneve 0xc3966291	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/geneve 0xc80dcd9d	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x4bd4450a	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x8548e477	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x91c4e5d4	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xd34dd4ca	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0x4fc53259	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x10f6505a	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x1e5101b2	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x45ca7c39	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x50c762b1	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x661c4dc7	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x8016c692	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x996e6041	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xabdf9351	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xb26a055f	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xc9e09776	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x110115f5	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x72aeae8b	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x96306546	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xa29884c8	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x02a29238	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x11a1a317	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x14801a6d	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x3f2b61ea	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x77b58103	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xa41daec1	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xc25eae61	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xc37bf036	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xf14c203c	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x21a200e7	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x9cbfe2fb	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xaf77226d	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xde04c6a8	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xfc73eba3	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xfdb051f3	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x02e57a47	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0d80f2f5	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x18b6bb28	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x19f77e59	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1b94d5a7	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1f2b1909	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2bdd987b	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3a551bcc	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3da4d2b2	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4e9121f4	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x52cdcc9e	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x5e0ad95f	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x66748914	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6700fef7	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6b54fc39	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6ceffc0a	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x713b1758	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x799fd28d	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7e7efa80	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x89631ca1	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa3ba7aab	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa4b1e6d2	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa5872d94	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa6169de4	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xab46d551	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc2db0a3b	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc40c620d	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc58b0c82	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd8ae0b02	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xdea6cdef	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe79a1f0a	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf5ff4c2b	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x27de142e	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0xe399c746	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x02744cb6	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x12f395e1	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x25f20861	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x40f4dd25	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x5f7325a0	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x708532e6	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x72eb5074	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x8477e988	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x8ee6b46a	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x9c32ac9b	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xad6b6b13	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb313f4eb	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xbe004205	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xd7407507	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf2f2a71f	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf55894c6	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x52d51880	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x638d1fd2	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x807f4b14	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xa81250ab	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0x648b8ca0	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x1717d30a	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x42fc727d	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x484b4445	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x8122e8ea	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xff93f41f	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x05d3c177	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x075be50e	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1b074767	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x259f0960	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x2e98ff86	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x468a4368	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x512a2413	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5ee5ab54	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x60cbdfe7	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x64d9148b	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x6eaca318	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x79b51479	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x85612065	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x87ba2bcf	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8b1cb27f	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8c70ee09	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9fe0f559	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb7cca0ea	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb8979af3	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xbe6ba3c9	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc4281c30	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc4a8fc91	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc718ba7f	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc9c005f9	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xcf2c6d6e	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd49b4b3e	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd87c56f9	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xdb2c8a98	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe48751dc	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe629f93e	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xec528445	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x169821c8	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x18e63744	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x1afe734e	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x2b24f2d7	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x2bfd8eca	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x31af212a	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x4541546f	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x49e6b93a	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x74191cd0	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x7e3e5196	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x999d6614	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x9c725b3a	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa015405c	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa02b4b0c	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xace2d602	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd0ebd0f2	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x02b87c3b	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x354e6f23	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x4974c786	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x5a2204d5	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x5ef2db6d	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x65446bba	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x6a76d0bc	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xe5668288	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x00b19007	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x01a54afe	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x0df12caa	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x21c5d4a1	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x272e527c	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x27f3116b	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2f4a1427	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x76fb245e	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x810a2be0	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x9382d1fe	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x9e763f9e	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xac359378	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xac614431	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xae336409	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc00373ed	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xd7edd9e4	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xda40cbe4	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xdad06dcf	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf91ab8d1	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x185088bc	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x27fea250	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x4d5066e9	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xa16afc5b	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xa4e3d3cd	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xaa4e5a2a	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xb34e7abd	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xc2dca333	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xd6380ede	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1283003f	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x532b595b	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5c16ed7a	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x71114084	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x027c4d6b	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1f55f5c0	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x273bccc9	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x28001ca0	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x417ec411	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x424b75c9	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x43424162	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x4b33693b	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x502450d7	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x51737db9	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x5b5e5dd6	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6325e8b8	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6d67c0b6	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x80b489ae	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x873b97af	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x88b91b16	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x89707658	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x8977a81e	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x9e6c934d	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x9f81b21f	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xb701974b	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xcc954220	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd10afef1	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd56c84ee	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xe819ea99	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf99433f1	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xfc07c65f	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x111f6732	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1af57b6e	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x24eafb80	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4b98bbe2	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x58948dc0	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6579433e	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x686211a7	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x702b0f3c	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8342b060	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x83e70b2e	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x95f92d1a	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa624e4ea	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xafcdc668	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbad29a5f	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xcd174018	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdd2c88b7	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xddd1da66	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe515e261	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xed0099b9	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xefbe8cf1	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf8ff6add	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xc646b66d	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xe2bbb89f	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xe3d6e45d	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xfbecab33	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0995c2bd	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x13d7c6cb	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x195b779b	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x252fc418	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x25d80e6c	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x2c0bac46	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3b33223c	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3c891027	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3f25dae4	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x416b0f3e	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x437502e9	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4d211637	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x50c43f03	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5281a62c	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x71aa67b5	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x79dc86e4	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7acc587b	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8428eaaf	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x884e4a8c	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8b9a230e	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8e6af544	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa1045a01	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa57d64ce	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa6a008f5	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa9b0f386	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xaa738f7b	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xbc0da504	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc2750cf3	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc5a978a9	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc656ee5f	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd852780c	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xde115a6e	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xed39f2d6	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf1ed2e04	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf58691d3	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xfc35b5c5	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xfeb1c19f	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xff8bd1b1	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x08e84124	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x114bcf82	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x1432c818	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x262dc3e5	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x3852565b	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x3a4ebdcf	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x3fbe8b93	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x658ad459	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x767197ac	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xcfbb18b4	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xd08e7603	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xde9f9433	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xfab8b37c	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0802ef03	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0951585e	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0d9e9299	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0ecc4ed8	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x16e2e277	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2d347057	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x34b101e7	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3b469f88	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x41491bc4	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x43c2a602	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x51e3391f	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5b5c7472	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x63feb0a1	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x66013ecb	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x67d7cb3a	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6a35203c	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6d62ce8e	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x70df5266	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x71019c5b	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x74b84cea	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x771ff84b	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x77b13883	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7a728f15	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7c6f0902	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7cd57708	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x80f96e0d	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x82c1f4cb	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x85dbd641	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x90f49649	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9da853f5	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xaa4566b4	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xaccbc676	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xad9c1e2a	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb7bfb12d	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb9c769ed	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc40fc5b7	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd6b74d73	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe1ba77f4	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe3b5f6f3	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe8411e66	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xea1fa65e	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xebe5b94b	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf0e30026	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf68e42a3	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf740d194	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfe362669	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x07955c83	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x1d14fd23	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x72232e5c	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x73e378e2	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x8819e2a9	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x2424e719	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x4b2f9a46	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xa1019d43	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xc25cbee7	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x23a250b5	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x2563a8b2	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x2bb1f72b	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x38f6cca4	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x437274f8	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6bd1a5e5	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x9439d0e6	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x94d6971a	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x9560d079	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xab4e71c1	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xb1793171	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xb5427fd3	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xc37fd11a	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xc469f1e9	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe228bbaa	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xee44880c	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x0fac7a1c	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x26e73b68	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x4775125f	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x069b2306	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0955d755	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0baa3b67	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x164c0638	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x195e2201	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1a21d0ec	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1fbdbb30	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2815c9a1	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x29b6eb99	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2e80ac93	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x31ec8c0c	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x322f3bdc	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x345f1e7c	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x44d93b55	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x475d4590	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4d55f648	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5126623c	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53b08ae5	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x66f3be3d	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6b6cd08f	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x80af50f2	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x84f65e89	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8914727a	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8b4d8807	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x91da5146	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x92b94e91	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x950bc0f1	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9c5a59a6	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9cc08e64	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xac44b272	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xaf6e0e42	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb6b887f8	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb902f04e	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbbac4e32	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbdd4298e	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbde8e4b4	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc3314c90	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc78be880	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc8d841f6	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xce628d05	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd764fa02	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd867bf6f	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xde2bf34b	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe4f7d4cd	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfb16b965	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x0a1e4ff0	nfc_mei_phy_free
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x76b65bb3	mei_phy_ops
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0xbc3445bb	nfc_mei_phy_alloc
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x523eae5d	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x68261738	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xcc12beca	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xe4478ee4	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x13078110	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x13ef6007	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x1ea38df2	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x50c446bc	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x76903350	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x84117b8c	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x87597b33	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xec59e269	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x47d9dcf5	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x88d5c5d4	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc4cee4aa	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x358ee3b6	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x36ec8a8a	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x523bc014	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x5756ed53	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x68758fda	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x7bf0541f	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc96fb674	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe18960ba	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe220895e	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe9a7fe16	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xf5f12835	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x0b2c7df2	intel_pinctrl_remove
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x46b2ee5f	intel_pinctrl_suspend
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x48cc48ea	intel_pinctrl_probe
++EXPORT_SYMBOL_GPL drivers/pinctrl/intel/pinctrl-intel 0x7491f000	intel_pinctrl_resume
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0x56371d34	asus_wmi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0xa7840bc8	asus_wmi_register_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/dell-rbtn 0x51552fca	dell_rbtn_notifier_unregister
++EXPORT_SYMBOL_GPL drivers/platform/x86/dell-rbtn 0xa060fe7d	dell_rbtn_notifier_register
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_ips 0x46809fa9	ips_link_to_i915_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0x56235c72	intel_pmc_ipc_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0x75068282	intel_pmc_ipc_raw_cmd
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_pmc_ipc 0xdea07053	intel_pmc_ipc_simple_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_punit_ipc 0xa6c87106	intel_punit_ipc_command
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x232b5238	mxm_wmi_supported
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x61cdf799	mxm_wmi_call_mxds
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0xe26032eb	mxm_wmi_call_mxmx
++EXPORT_SYMBOL_GPL drivers/platform/x86/thinkpad_acpi 0x706cdcef	tpacpi_led_set
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x3ecf6cfc	wmi_install_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x64ebe677	wmi_query_block
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xa9b7afd8	wmi_set_block
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xb5a6ebe2	wmi_remove_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xc5e3dddf	wmi_get_event_data
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xc9d4d6d1	wmi_has_guid
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xe2426710	wmi_evaluate_method
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x31dba70a	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x9fbbafe2	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xa74cfcb0	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0x6365870a	pwm_lpss_byt_info
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0x8b24d981	pwm_lpss_probe
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xafcf8794	pwm_lpss_bxt_info
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xb563cdb0	pwm_lpss_remove
++EXPORT_SYMBOL_GPL drivers/pwm/pwm-lpss 0xc34d815f	pwm_lpss_bsw_info
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x117d421b	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x1c1be854	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x753d4f56	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x010ebc33	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x0c8fb56c	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x1f6a078c	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x7548988e	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x9213686f	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xada97cca	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0xbfac4236	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x00f8e3a0	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x03232113	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x07374f8d	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x087dfbb8	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x09cddde9	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0aa95d1a	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x16317398	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x17d29ef3	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2227cf14	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x257ebb9a	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2b0c4777	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x31c29522	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x38b52c3d	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x482e8600	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x511a4a50	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x513b15c7	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x52523190	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x580501c0	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5c961fbc	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6455f94c	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x681a8352	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6ed16d68	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7260a758	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7b98748a	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7b9f7cef	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7f5d5546	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fc9f81c	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x81cab9e8	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8b222b51	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x90be0972	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9d1ed11d	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xac5a0117	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xac7fd436	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb0b02c02	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb5b67e92	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb817a1a4	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc316f222	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xcd394650	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd9815a38	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdbe8f452	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdf9ab35f	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe0790830	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xee3c9827	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xeed9469c	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf3752322	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf6e18c0f	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0555d8c0	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x15af867b	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x21678aad	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x3c41efd5	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x3dc67cb3	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x3e9abd98	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x45c5fdbf	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x4b25b07f	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5756f8a4	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x9eabb293	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa8562032	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb6d1bc91	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xc13556bb	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xde77f915	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xe3ab27fe	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xea2ab3c2	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x39fcbcb3	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x3cd27bad	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xb4a96cd2	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xd27ea436	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xd3b5fd73	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xdd92fe9c	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x056839f0	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x05caa17f	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0a6b5f4d	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0b756a61	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2d90c00b	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2e666db3	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2f7a8b8e	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x39130018	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3b08d922	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x487140a8	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x49483814	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4dc44373	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x53114ac6	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x583feac4	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5e388e3e	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5f3f57c3	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x61ea7211	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x63ef1982	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6ded2279	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9d17018b	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa06ca1c0	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa4bd59eb	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa7635d0c	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xaa3b89b3	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xaafd00a5	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xabe36343	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xad9ddf63	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb9e4e17a	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbc7d593d	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc4bec245	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc80172da	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd01f0f27	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd7d634cb	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd8b5836b	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xddf3e11e	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe00b94ce	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe5a18c95	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe7704ea5	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xec9ebd24	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf271398a	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf4106161	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfedd7174	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x0d19e87f	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x10edd64b	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x1a2380ad	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x21caf47c	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x5d54af2c	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x5dd1788f	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x7a40abb5	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x830f5f4b	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x8522df5c	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x936c41c6	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x9cf1c0db	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xa9eb1860	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xb89e14d8	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xbfde7414	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xd3979567	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xd53779ae	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe413b795	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x03faccc9	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x04da7c3b	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1934d2aa	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1f9e3b1f	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2770a98c	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x33569bde	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x342fb0f6	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x39b61cbd	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3f6ca483	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6f17db63	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x73410989	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7f7cdf39	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x975a6506	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9b73207b	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9d03a0fa	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa2766cd2	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa41ff7a5	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa5ba9bb2	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa6ff82cf	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb1d027fa	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xbd6f9fac	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xc9a2e39f	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xd025820f	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfacb8aba	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x12ba09dc	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x17a4f38d	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x29d76a5f	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2b940075	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x36bc1261	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4cf005f0	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x51fbbecf	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x52513e5e	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x59b16a39	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x68a31e77	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6e6547ed	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6f296d36	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x71534d58	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x73f913e9	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7576f9c3	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7978e1a4	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8381977f	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9304c44e	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9627566a	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9934192c	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9943a4a5	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9a3f775a	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9ac2d817	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xabde9572	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xada43b03	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb6d4e200	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb9ed68b8	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xba602407	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbb8a904f	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbe67a3fd	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbfc79407	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc3390435	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd42bdd5b	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd4944775	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd9a99b77	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xde263818	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xdec076c7	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe881373f	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xeeac267d	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf9099fc7	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x5274dee0	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x77128a11	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xb1fe3766	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xc37fba47	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xd8db16da	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x3bbec1df	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x4d8bf607	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x5094d571	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x60f6502a	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x676303bf	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xc7fb56d7	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x0ed1b2cb	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x3648d041	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x66bcf945	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x835ab7c6	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xae171be7	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xb87edd38	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xe4a917cd	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x53ee9a3f	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x6cf59040	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x8e77fbe5	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x91c3b18f	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xabd20046	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xb98279c3	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xe8d69fbd	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x2b69ba0d	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x41816ee2	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x6c3446ca	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xa7b83a95	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xdfa003b3	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x15a49488	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x59adc7d1	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xe2f84f17	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xf260f529	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x05b19325	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x13d7db7f	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1a3534ad	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1ab2baa0	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1b0f7cc9	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x2af30809	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x3303187c	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x3745fd10	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x4a057595	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x637db195	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x7df7f502	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8427f12f	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x84b45e03	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x88c5d52c	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xa2a89c9f	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xd3d7f8ee	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xe6a8f326	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xe8ba2355	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0x797df1fe	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x09acd413	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0d926ff5	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0e261c15	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x12400991	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x16ce019c	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1f6e7988	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x26ecd638	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x29fbd3c3	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2c3623d8	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x36c9e9d2	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4cc8fab7	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4f061c5c	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x509097e8	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x53152a92	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x59abd8d5	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5a532b9e	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x73d772e8	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x865489b8	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x90313a5d	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x93e886bb	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa65f5364	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb5a4f9dc	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb8a0449a	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbc7a9b1c	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbec8befd	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc49c3f1d	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc70661cf	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc83d461b	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd9235418	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xec6c8dd4	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf2b50a27	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf3ebfcec	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf43f1d43	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xfe9aa743	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xffedd072	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x17448d85	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x9f6b28b6	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xa6db34c0	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xd8abeeb5	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xdfe87090	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xe7663bbd	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xf27ef074	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xfa9022e8	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x1972bc4c	comedi_pcmcia_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x7fe14487	comedi_pcmcia_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xbd581abe	comedi_pcmcia_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xbf72d047	comedi_to_pcmcia_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xc45b3e14	comedi_pcmcia_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xf49cf62c	comedi_pcmcia_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xfe5adab5	comedi_pcmcia_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x05f65c4b	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x445fa836	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x5171de65	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x63beb3de	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xc0d2412c	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xc952affe	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x3e500ea1	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x0e5501c1	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x20eea3a3	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0xab4f1907	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x0ebba6c7	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x1817c821	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x197d8687	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x1e5eb79b	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x3de4c81a	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x7e93055f	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xa4c3f162	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xab7ea8ac	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb6f55e07	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xbffac573	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xca42bcf8	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xe9f06f90	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xf7e3a8d9	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x291ec78c	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x4326b693	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xe0faabd1	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x0d68fcd9	comedi_isadma_poll
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x12fba874	comedi_isadma_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x4a17474e	comedi_isadma_disable_on_sample
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x6815a033	comedi_isadma_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x703113fb	comedi_isadma_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa3d01a85	comedi_isadma_program
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa7ebb8a3	comedi_isadma_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x2fae9245	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x004cb525	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x16074163	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5837ed3e	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6d819be8	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6dc80712	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x72eee078	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x746a7df8	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x75bb7041	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x75bcd8a5	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x83edee52	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x8491fe2f	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x8d0cd8d9	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x8d259d84	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x9fb6d3ba	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xaa7f31b3	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc1d3abed	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xcc6887c9	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe844e03d	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe978b16b	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf14fbb0f	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xff82a2aa	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x716f408f	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0xf8f88e7c	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x009bbc6a	labpc_setup_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x02711086	labpc_handle_dma_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x69c48161	labpc_init_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xb7736ad7	labpc_free_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xc9b2a411	labpc_drain_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x13abc32e	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x15853eeb	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x6445e3ae	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x88254b98	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x9fcedfa6	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xb3e3245d	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xef02d995	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xf4715fc2	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x1607f6ab	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x6602a667	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x89606952	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xaf1899e0	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xd7c91625	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xf68ce562	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x1b69ae4a	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x6df48fad	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x807f0f13	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x931cb746	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xd3756738	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xd7a6022c	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xf279b62d	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0xdb3f7a6a	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x0170c75d	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x24245f0f	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x49da4deb	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x522e1821	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x8071e1a6	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x96fe4f4a	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xab992f26	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xbcfd0ba1	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xbd545f6e	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xd65d079d	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xebfb39e8	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xef9af9c7	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x2ab8daa7	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x3241c680	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x468c31ef	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x714b46f0	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8839ea58	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8b3aeb81	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x93546283	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xac4bac92	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbd57e155	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd05b57f3	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xdbd2c99c	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe5d9abed	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/thermal/int340x_thermal/int340x_thermal_zone 0x80225300	int340x_thermal_zone_add
++EXPORT_SYMBOL_GPL drivers/thermal/int340x_thermal/int340x_thermal_zone 0x88180d49	int340x_thermal_zone_remove
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x23c2e39c	intel_soc_dts_iosf_add_read_only_critical_trip
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x25ec857c	intel_soc_dts_iosf_interrupt_handler
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0x8e5c65d8	intel_soc_dts_iosf_exit
++EXPORT_SYMBOL_GPL drivers/thermal/intel_soc_dts_iosf 0xced87293	intel_soc_dts_iosf_init
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x75f68644	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x932f18cc	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xf615715a	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x0e1a641e	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xb4af29bc	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x0efa25d9	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x4a195ad4	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x10a11c7c	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x3c5fdd81	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x567d5148	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x67a70ca6	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xbd109fa6	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xe3e378c1	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x06e23b64	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x099a7328	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x135e4309	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8014ac14	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x85a6d425	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xa63fdf07	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xad087036	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xb3be77f8	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xb3e9fc5e	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xbb80906f	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xc634a04c	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xc68ab4c8	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xcf943a0d	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd6ebdb4b	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xfc47eabf	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x89ca818c	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x95bf89b8	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xd371dd12	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xecab5ea7	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x1e13b732	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x4ee43fad	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x8ffab934	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x053f0538	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x0b29362e	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x142c023e	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2e9b3327	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x40d283a6	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x41ca360c	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x57a60528	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5c1b8a08	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x781f89a6	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x8f81d24d	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xbf73e46c	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xc9013c07	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xe2094043	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xe76ba82d	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf0acfce6	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x197ce20d	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x222347ad	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x2638bac5	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x4ed0feab	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x5b753a4c	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x665726c3	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x79c193b7	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x80d6d974	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x83899740	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x8e3f9739	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x9f8d4e50	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xab8959d5	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xc5022e9a	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xcc6c3c81	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xe48907fa	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x001c6ee3	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2f6ef076	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x459ba287	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x46ae7957	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4d68bbbb	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x56f1773a	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x647e0b29	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x68494784	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7a848287	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7dafef55	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x81085b59	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x819ea4c3	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x81aeb917	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x87996053	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x93e932ec	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9d1dcbec	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa20ecf53	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xae29e269	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xbcc29252	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xbd30e71b	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc392534f	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc95c02d1	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xcd8fe390	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd93426a6	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xdbd9ef5b	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xdf20dce6	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe741b660	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xec24e7b3	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xed44eaf1	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf4e554e2	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfa3be12c	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfc72ec73	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x110b3b21	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x119c9b51	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x1c1fbbd4	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x2152eee8	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x2e945e6a	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x5918048e	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x92229c40	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa4744dba	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xc6f5135e	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xc8aca31b	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xd0f3adc9	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xd5e9c21e	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xf41939a2	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xf4f21363	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x904bc289	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0xf3e1a0ab	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x04689e6a	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x332d85da	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x4b620bb3	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x5088eb76	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x7a878d72	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x9c321c7f	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xa75d0f22	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xc0a97fd6	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xddf32718	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x7cca6f6b	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0xb61250b3	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0xf7ac8f30	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1d0ba518	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x320cc685	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x42673756	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4924cbbb	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4b7a9227	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4bbb6f3e	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x5aa5217f	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x6453f0a2	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x6c453d8c	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x72839202	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x81bd061d	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x8522066a	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x865c85d0	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xbf168dac	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xcd153f65	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd253aef2	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd6188526	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xdcbfba58	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe99889db	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xea113283	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xfeb6f02c	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x07038939	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x0e0727ed	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x0ffa1c7a	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1edc6799	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x21cb16c9	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x262ddf59	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3e388ea5	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3e7280d5	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x5ac5387b	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x61a8a546	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6c5eb942	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x7ce1c3af	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x885fd23d	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x93cccbd2	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x98c6540a	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x9c21c5a1	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x9f93a526	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xba61d582	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbc967621	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd75ff0ce	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xdd1331c4	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe47f935b	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe5cd5539	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf5a5fabd	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x22046dd6	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x2879a168	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x2a256e30	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x820fe071	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x968bf033	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xa1ed04f6	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xb697a0e3	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xb8c26001	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xbaf4c72c	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe42aa99c	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xf6776471	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xf91aa8f5	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x0c5f9f09	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x28386a4d	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x288855cf	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x3a54f6d6	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x685472e7	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x83aeb032	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xb390787a	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xc543b60e	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xf4654c3f	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x1fd3088e	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x39d97dfd	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x3b3a47bc	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x4ac4c0c4	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x4b9ef2fd	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x6534f184	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x77e5ba0f	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x87b614b1	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xa24c43e7	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xab6fd148	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xd8614637	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf48773f2	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf758aba1	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfbfa02eb	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x0ed78fc3	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x921bb2d5	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xa31a8388	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x06723ac6	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x11fcaa52	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x152f914f	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x2cba505d	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x3af21099	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x3db64f43	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x4340880f	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x572e16dd	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x063a762d	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0affb8d3	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0b8aad57	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x17bfb52d	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1c960608	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x25fb867c	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x28e660ad	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x291c422e	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2f0c6db9	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x302c83a7	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3d3e9a31	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3edb690c	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x442804e6	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d686e28	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4e543482	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x51f4137b	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x59d26f33	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5e4bc088	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x64579d77	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6990cf61	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7cc00ec8	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7dcfcd23	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8312af9d	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x87af9fe6	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8f6bd846	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x97ae55ad	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9d1f031d	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9e27eb17	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9ebed2c2	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xab26d552	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbbd1dc2b	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc8417b4f	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc89aed6f	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd5f8b888	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd8592d1d	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe1716f06	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe3a6b0c4	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xecc92f42	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xee161eb4	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xef6325a8	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xfc40ada2	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0x91f73607	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x320b1d1e	vfio_group_get_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3567743b	vfio_external_user_iommu_id
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x46f99307	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x4aea18e1	vfio_external_group_match_file
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x51a68b60	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x614d38c9	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x8a63e756	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc1d989c5	vfio_external_check_extension
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc4913442	vfio_group_put_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xccb598db	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0x7d35ff7e	vfio_virqfd_enable
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0xd0265cb5	vfio_virqfd_disable
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x08a3170b	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x107545b2	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1ad16ab9	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3af682e6	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4abaf8aa	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4cb96f77	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5f4114fe	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x6871c6a0	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x6bdea543	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x6fedede4	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x86a3c9d2	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x86d2829e	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x917994d9	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xaae953df	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb1cb4f5d	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb2e5765d	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb5a037d8	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb83316a8	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbc7bc23b	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbee7ee38	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc2a2d8eb	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xca081b3f	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xca669e7d	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd1b67b94	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd48bf270	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd8837f5a	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xdd891e84	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xde96a853	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xee16870d	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xef33960e	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0x2c63e051	apple_bl_register
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0xdab0f892	apple_bl_unregister
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x3747e201	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x727fb934	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x82abe2ac	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x9dd4b930	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xac5b5e30	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xb358dd00	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xf459efab	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x3b004c90	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x3c7b3dfd	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x444b2083	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x864baabd	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x8cce08b4	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x951b3f33	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xa5a6d04c	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xabed41b8	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xe0ccbe7a	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xef32f226	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0x81cabadd	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0xeac3fd0c	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0xf32e3c0d	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x3d9c3ce5	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0xd8837582	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/vermilion/vmlfb 0x016e6c20	vmlfb_unregister_subsys
++EXPORT_SYMBOL_GPL drivers/video/fbdev/vermilion/vmlfb 0x90c018c6	vmlfb_register_subsys
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x023a492f	viafb_find_i2c_adapter
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x22a7af24	viafb_dma_copy_out_sg
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x292da7a2	viafb_irq_enable
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x30cc9311	viafb_request_dma
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x31469540	viafb_pm_unregister
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0x79e6190a	viafb_irq_disable
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xb4f863e6	viafb_pm_register
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xcaefb732	viafb_release_dma
++EXPORT_SYMBOL_GPL drivers/video/fbdev/via/viafb 0xfff2dfd2	viafb_gpio_lookup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x0fb6a4c9	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x3c230c35	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x462f90cc	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x4a510a18	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x5cda25ec	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x6f5a2917	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x77e07694	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xa8e2f705	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xbc479f80	w1_read_8
++EXPORT_SYMBOL_GPL drivers/xen/xen-privcmd 0xe76bbcd5	xen_privcmd_fops
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x184fba4e	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x3b487b08	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xf2212088	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x13f23b2d	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x4c813a36	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x580b50ed	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x818de382	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xa67fd9bc	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xb5a797bf	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xb971e193	lockd_down
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x00e78022	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x027bcb02	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x02c023d3	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0ad9212a	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0b3dd434	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0c1521d2	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0e23121f	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0f20850f	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x10053f61	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x10aac71b	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1344cdb6	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x157d20a2	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x19f843f4	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1b9bfc63	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1f84a42d	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1f9b670f	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x21b3402b	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2597d2c3	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x27051b2c	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x275db422	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x284246d9	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2b197d76	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x30f0491d	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x32e57c32	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3341457f	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x35461568	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3799c6d8	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3d4417cf	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3eb84630	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x442493cb	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4b432b55	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4e68ed0b	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51e41705	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x54d64581	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x55f36937	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5b7bc2dc	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5d907646	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x640e2832	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x643ea1f5	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x64b11ac9	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6c05e33e	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6e2c31ca	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6e461f13	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6ecebf97	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x74153223	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x74427a49	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x75d1306b	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x76c154f0	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x786247af	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7aba72b7	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7b8f85af	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7bf37802	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7bf6bef1	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7c3357e5	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7f25a2b6	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7fa04057	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x80375b5e	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8212b12d	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x859aa745	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x85c0abc5	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8707b531	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x883079a4	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8b76bba2	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8be968a3	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8c133d37	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8e745de5	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8fffb646	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x908ec7fc	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x92432743	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x92655651	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9368fe16	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x948ed2f8	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x94ed67ac	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x97cb6a03	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x97cda902	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9aebdc8e	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa0354458	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa2dd90d3	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa61aa775	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa6c0e8d7	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8c8d3c4	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaaa14361	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xabdf9bf3	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xace7938a	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xae3a5ff4	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb51ee48b	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb9a9e1c7	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb9c0bbe1	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbcf23f0f	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc2167041	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc2258a29	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc383923b	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4f9bcf1	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc820bce7	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc82808af	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcd02e1bf	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcd05187b	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd12e66bd	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd26326a1	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2d60fd6	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd3a98795	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd40dd23b	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd651b413	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd9aeef4f	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae541f9	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdda09dbe	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe4036fb5	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe46040ad	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe53ddfaa	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeb5852e5	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xed0bbf18	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xed9ed39f	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xefe865f7	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf0232096	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf2153bdf	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf43bb142	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf5e85356	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf5f3474a	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf72b7d9f	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf75d7c39	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf7f556e2	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf87d89b9	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf987eeb9	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc85b0a6	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfd25a4be	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0xa02e9aaf	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x011cd6d6	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x030e00b2	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x04fada25	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054a7e7b	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x08f42583	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0aa30f1c	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0cf9b1c7	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0e3d03e9	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x13874aef	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x16efb8bd	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2c2817b3	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2cbef869	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2cfe0363	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x308aa8e1	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x394f97b4	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3adc8ff7	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3ed4c118	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x41c751d1	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x42a4b3e0	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x48cddcb6	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4b4e70d6	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4e95fd41	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5746fafa	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x579ebfc6	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x58037059	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5c644cf9	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5dd8cf41	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5edd7f84	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x64a872e9	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6f727a72	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x74e2f324	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x79f2f908	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7b1bbe36	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8d6ef0af	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9266a2d5	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x98e8d726	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9bc47df3	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9e30475d	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa02df320	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa4601421	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa70ad557	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa7578f18	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb0785517	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb0873ef3	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb3bae0b9	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb58d94f8	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb82b3fcc	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc9ca34d0	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xca4245b2	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcce7927b	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcee06280	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd3ff8fd0	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd576bffd	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd94bbedd	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe41c64c3	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe9ae1703	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xef73ac26	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf0e86722	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf141c0fe	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf8ba7ebc	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfc8d74dd	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xffa13bfc	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x4053f3d8	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xb1c5b86c	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xd837a9ab	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x40ac63b3	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x785ddf90	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1cb231d0	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1f57994d	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x2547166a	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x258b738d	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x5360cef2	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x687f6251	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x69909238	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa9f5379a	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xac7dffdc	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xe7d14b9c	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x88011b26	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x953a0716	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd266c89f	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8db6e2b	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xdbd9ac64	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xe167711b	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x0de04ca6	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x43d65c58	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xd61d2eb1	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x200e2b0c	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x26fe8cf0	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0xb80e2892	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xb1952324	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xd485f413	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x021957e1	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x0f8a2742	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xd4cb6873	raid6_call
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x57861324	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x57d39367	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x882ce5fc	base_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x9e0112d0	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xaedfbb15	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xc8fca8a6	base_inv_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xd11741a1	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xe3d900b5	base_old_false_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0xbe7a218b	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0xf1fd4505	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/802/garp 0x2bffd177	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0x365cddc3	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0x36d00cb8	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x623c51a9	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0xb5beb082	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0xf255cb1d	garp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x0cc1fe7a	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x251ce170	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xb80df35c	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0xbc4de6ac	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0xc58c0be8	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xf5bdac06	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/stp 0x4aa7cf33	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/802/stp 0xecdf1641	stp_proto_register
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x5b09ebc3	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x92ad3af1	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xcf1624e5	ax25_register_pid
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x04671a4d	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x14405def	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x1f9ce63e	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x3bec85f8	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x69a24ae7	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x90c1f9b4	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xabbb45f4	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xea61c326	bt_debugfs
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x13aabfbe	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x3cd1d085	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x461702a6	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x55e55a80	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x684e5252	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x7e454a83	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xd1ed5643	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xd7e9564c	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x949aa151	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0xa21ecb31	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x09d22639	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x161bcba4	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x186fc62f	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x189e6188	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1f9e2da0	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x212d9447	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x21d7a233	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x23672cd0	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x28a2fd47	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2ea676a4	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4207d90a	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x47dd46bf	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4e2d4d99	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5682f6a5	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59b2ff9a	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5ff62bc3	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6b20bddd	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6f2d2a6d	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7e0bce8a	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7fa88973	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86263d3f	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9366abb6	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9f5109bf	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa653fc7a	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xab825d57	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xbd4c071a	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc286c290	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xca369f6e	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd963cb0f	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xda4405c2	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xdc573092	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xeb805052	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xec23078f	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xff63b173	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x27644916	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x40eb58e5	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x833c1a14	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xa45af502	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xb6f08ef0	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xfd7441eb	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x4d7aef69	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x567c266b	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xa680b212	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xd0bfc877	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xd4acbdc1	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x73ef6cf9	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x79621a80	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x177b2e13	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x3832e1fa	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x394e9cf5	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x6f51c03e	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xb704d3e0	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xc00672fd	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0x225284be	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x08773103	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x0a54f4a1	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x169c580c	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x26720bd0	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x35d6f7f2	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x37882b44	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x43ce624f	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x55a7d807	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x70f33db8	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x94b992cc	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x9ab5b729	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xa535f28d	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd02bde19	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xf081aa0b	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xf366e123	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0x2bc482af	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0x0b1a94f4	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0x0931e5dc	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x22fe0931	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x6ac11a08	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x71389984	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xb3320829	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xde49dddc	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x4cc2fef2	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x015d438a	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x61a8e9bb	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x69f2d3e0	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x79d197e5	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xb3ba7346	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0xaaa1ba3e	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xa51b2ae6	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xdc042c75	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xf352866c	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xfc31acf8	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xfd1c3662	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x45272cdc	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x5ef47b96	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x64aa803c	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xb0b3f7db	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x22268596	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x32da36f9	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x3c628a2d	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x5de963fa	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x9079d27f	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xb0103fc8	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xd6d4a95d	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x16271c2e	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0xd88c1f65	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0x62285f7a	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x0b4834a0	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6ee205fc	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0x7d31c5df	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x85db6a52	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x96a7c57e	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xbc7850db	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xc89ec109	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xeff44667	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x005ccff8	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x41dd67d1	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x7d2a281b	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x9edebe81	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xc62771ee	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xdd5c06a8	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0xc83f569b	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x0464a7b7	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x06e5278b	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x0cf8c563	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x24535eb5	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x2eaf88f2	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x4b3dfdf9	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x7bf57bfe	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x7ea363c7	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8a9e799a	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8b0f659b	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x9ea3f49b	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xa1af7f36	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc8fe4597	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd57c3d8b	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xe8d51d6d	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xed9d8020	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x97ebc4c5	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x0fc31680	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x28f06b4c	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x3335ec71	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x33afd28d	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x606b7367	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x733f9ecf	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x836411e6	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x8ea67951	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xa75ee567	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xacb9c06e	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xbbda62ec	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe016e26b	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe82d426f	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe8fb7eec	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe9ce1b1a	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xebdf8959	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf2bfad87	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xfa2b31d9	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x4b7cc4e5	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xb74b722a	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xc4867726	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xc65db0e2	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x12179628	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x30a3d882	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4bb096da	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x554d4f47	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6344eaf6	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x64ca7995	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6631e1c6	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6f29e9b9	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7f55a42a	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x821618e1	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x963ad2f6	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x98c6d117	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9fe7859d	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa26757cb	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xb169b60a	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xef91cff7	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf39bf716	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x77791983	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xbe52ac5f	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xde9ebe15	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xe9aa95d6	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x019edb76	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x02c7b691	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x030b2c89	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0905d03b	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0cd1d920	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0e38bcb6	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x11eef2ff	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x12bed45b	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1497885b	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1501122a	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x20005852	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x225279e4	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2b3707e9	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3217ee93	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x32aeb884	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x35cc17ea	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x38824433	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x38d0f780	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3ec25533	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x40271632	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4a8551ba	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4d7bd2b5	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4e0d6d87	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4fdcd4ec	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x56fc6182	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5744b1bd	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x590bf4d7	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x688c3f7b	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6a18dc58	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6b183034	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6d929b3d	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6da8d2ef	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6fc5a08d	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x71c02fce	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x71f4a77c	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x720c6da0	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x74464141	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7ba6e74f	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7c3b0f05	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x826333c2	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x897d287f	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8c0827dd	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8c8e2aeb	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ceac4e4	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9110a685	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9930d027	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9c470baf	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa18500f1	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa76bd465	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa826d024	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa83f38cd	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa8d5dfce	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa9984050	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa9fd0f12	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaa8eb6cf	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaa95f5ea	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaa994d64	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xac8938b7	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaef79e88	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb57ce272	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb9cdaf4a	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbedca666	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbf17e25a	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd0a38508	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd0ba074c	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd31f1eb7	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd351e7fa	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd51a7c4f	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd5748ea2	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd9523dc9	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xde9897b7	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdf42ed48	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe9d623ee	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf24f2ef1	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf2a9802e	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf4daae57	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf73fb843	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf8e09906	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf9171a2a	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfebd5a05	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x62aee1c1	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0x86b88d92	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x4b0bc6d0	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x1ab1ab8e	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x29c8033b	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x414ecb11	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x484f040c	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x5c3bf993	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x82f896a9	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xa98c7439	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc5722872	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xe4548141	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xef078f52	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0xc752fda7	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x2197bed2	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x2cb96fbe	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x4efce692	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xf5c24355	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x59d32b27	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xd3ee0dfe	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x1850504e	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x61493732	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x7cabb592	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xcd8bfab2	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xe5a1e39e	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xf05f309d	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xf4f6c46e	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0x301d4514	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0x2c7c203c	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x0c9d5156	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x78fcb5ab	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x7ca1b74c	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xd9098c6b	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x26ed371a	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x2abdb4c6	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x2c479bda	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x43afd52c	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x46635734	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x65353623	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xdbd23f58	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xdc1b52cf	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xf4226462	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x0f0d719a	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xdce1a0be	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x396df18c	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x60372220	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x8841d39b	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x182f2e5a	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x38899178	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x3d3ad2e5	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x44b70d00	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x545af3a1	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5913b769	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x6568ed68	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x821f9fae	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x8816099d	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xa1b5258f	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xa589e200	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xb660f01b	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc4cdcb44	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc6650734	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc6e8d2c8	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe823d9f7	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xf2148cc8	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x078c0f3c	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x0b8dc623	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x35de428d	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x3a39c34c	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x4a70ad02	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xaf3c36d8	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xfe9dc676	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x084c1b98	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x0d4a6e98	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xfab92280	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0xf5eb9d93	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x228f9ec3	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xbafc7634	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xcd79fdb8	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x52138e75	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x93274566	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x9f7a0b3c	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xbf2469d7	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xf52d9db1	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xf708e9e9	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x65965bca	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x9840c372	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x993947cb	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x1bb66c79	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x5a889283	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x121be1cb	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x218f5b76	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x348d52ef	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x66e3a294	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x6d5c8993	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x76ebbcaa	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x7e8cbdfe	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x88a0682a	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8ae62bb0	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8cdd100e	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8ec9685d	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd921c110	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe04e1989	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xf8d2792f	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x4c32c169	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xb7459345	xt_rateest_put
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x8b3dbd4f	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0xb380e50f	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0xe513a354	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x2a543e9e	nci_uart_register
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x5872db14	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x7e32920a	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x29eba645	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x46ee1021	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x87a52f2b	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x98dd3078	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xa48560a7	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xe5a5e54f	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xe7144d48	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xf14231d5	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xf9fed84f	ovs_vport_free
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x0cc47186	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x1237e0ed	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x13e404da	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x175356e0	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x207cd67a	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x24177eb2	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0x2471af0e	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x39764665	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x4a9a4892	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x4c334710	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x5d7896c6	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x642c0aef	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0x6a6aa3a2	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x823f49a3	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0x8dd88186	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0x8e0d3a2b	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0x927b0d22	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0x96fafe85	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x9e94be28	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0xac96e47b	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0xbcab618e	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0xbf42ea13	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xde673448	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0xeb400bda	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0xed6d64e1	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x10ea0034	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xc596cfa7	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x20a35510	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x2d3be85f	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x74990649	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x00c01a67	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0200c470	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x026f5334	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x03b5fd07	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045f1c15	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x04e9266b	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0580270d	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05c462c0	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05c633be	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x06fa54ba	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x07180301	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x07c6a434	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0a96f86d	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b529970	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0bfa2267	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c30d8ad	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0e97bf63	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f7a6074	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x10980f37	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x10daafd1	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x128aa4ca	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x138bfabb	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x149472a5	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x15fa20ba	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x17d5da67	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1d2dcb20	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1d4823bb	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2135183c	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2253d509	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x242c00f5	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2434fbea	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2480422e	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x26b3799e	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2825e25d	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x28d178f6	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c7fcec9	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2d5f8751	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2e1e52ff	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f3bd42b	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f8ebbe0	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3106b91b	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x326076c2	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x33a6e662	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x372bb211	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3830ed29	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3907c833	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3aedab29	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3be0b1c0	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c46572e	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3ca5be6b	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f5271c2	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3fa0f0da	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x41817f4c	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4340f8d8	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4393f4b9	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4469950a	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4712be14	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4713eb72	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x477a5b79	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x49414187	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x49d312ec	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4d519a45	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x50454bc5	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x536eefb6	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53c9f796	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5700b570	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x570be699	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x579ab6ea	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5924c6ae	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5a88bd49	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5aa8ab20	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b4fb094	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5d4c7572	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5eb27393	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6247e574	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x62a29b9e	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x63262479	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6390dba0	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x653c4b40	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x66b70f79	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6970c819	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x69806ce9	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6aae2ade	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6b3f2f39	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6c7e1379	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6cafaf91	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6d977f66	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x70a5a18f	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x724b27bd	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x729598d0	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x72cd8a3b	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x72da147b	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x75330959	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7863db94	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x787ae8c5	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7885ac36	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x78bd120f	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7a44ef9c	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7a4a10ad	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7c33ef92	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x860a9a58	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x89bf0622	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x89bf517e	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8af53f8d	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8cfc9f66	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8e381ca3	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8f040a21	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x90e70310	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x92ec8bc4	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x94c08059	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x95775d72	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9734298e	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9748aad9	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98788997	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98cca89c	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9af23eaa	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b6f8bb1	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9e96f666	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa033e88e	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa0f22ab9	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa1249f7a	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa3e7c24b	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa55b2db2	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa63d4186	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa6c142f9	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa6e6b212	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa7b77c4a	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa99ef3bf	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaac916a4	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaca87a03	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xacab51fb	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xade1cea4	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xae3e2c35	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb0702d3f	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb1ead2a0	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb3febe42	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb6e88077	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb78491ed	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb8c37af6	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb9ff9cb3	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xba2ab949	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbede5eb8	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc1009317	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc47c6234	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc6ca1551	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc7830980	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc85fd101	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8881257	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcb1edd16	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcbdb3c70	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcd0ce491	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcdcfd108	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce321079	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce68a904	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce74423e	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcec51e8a	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcf7e1fd0	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd14c8eb9	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd2240298	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd3de7264	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd675eba4	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd6d89d10	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7833f7b	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd78bcc83	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe137a233	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1b072b4	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1c9890b	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1e17d13	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1fa4a7c	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe2173a7d	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe3938007	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe6e3fa6e	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe7a6f315	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe7df9830	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xec94b9b5	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xecffdc35	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xed1de463	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeec45ff6	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeedec492	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeefd2bba	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf0315656	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf064b9f4	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf113e092	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf1d98a8e	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf24ab8df	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf37256f2	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf80d4c02	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf8107784	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf89c3bf3	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf8f8c263	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9ca36c5	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9e8bd2b	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfad9bafb	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfb2607bd	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfc8f8b24	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfca072f5	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfe3b5579	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfec60b06	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfefc2e56	xdr_process_buf
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x291245aa	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x29cc914b	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x3119361d	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x34d86ef6	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x63fae660	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x71021e2f	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x74e91915	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x8995696d	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x8c31ad5f	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x8cb409ae	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbc6046e9	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xc4f8a1ad	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd7451986	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf593c40a	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf7ff3e4f	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x1736ccdc	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x17a7c359	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x223c50ad	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x36cac78d	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x4627e62c	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x612827d4	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x67b8c353	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6d269c04	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x8c05f76a	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x9bbe52f3	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xa7dead87	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xf2fe1308	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xf52e3c5b	wimax_state_get
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x080758dc	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x20069e9d	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x3cd4b67b	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x4282f998	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x53ab3c24	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x70042a55	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x7430ac2e	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x77fcc2a9	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x95a66313	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xb8b079ea	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xce3a9fd6	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd8433625	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xfc28b235	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x5b1d2022	ipcomp_destroy
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x6ca28da9	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xddb66d15	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xf3455bf6	ipcomp_output
++EXPORT_SYMBOL_GPL sound/ac97_bus 0x1deef365	snd_ac97_reset
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x9092944e	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0xf8b38984	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/core/snd 0x0b3bda26	snd_device_disconnect
++EXPORT_SYMBOL_GPL sound/core/snd 0x2b5e72db	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd 0x2c5df57e	snd_device_initialize
++EXPORT_SYMBOL_GPL sound/core/snd 0x40fcecce	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd 0x50c8a617	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd 0x81b71876	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL sound/core/snd 0xb9c87632	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0x33fe8ec7	snd_compress_register
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0x6e194856	snd_compress_deregister
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0xc4993171	snd_compress_new
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x1a4471df	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x30bb9ef5	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x5c3db75f	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x7921b554	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x9b1b5290	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x9c2313f9	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa7a954a6	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xb5999e48	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xf69c93d0	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x3b4cc209	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x4104d0b9	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x720564d7	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x79e5fb65	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x8ac395a4	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x8da5b562	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x9fe91256	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xae7bdb6f	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xb382c7ed	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xea1331da	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xfb6e9023	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x09b9e31e	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x1eb63635	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x2d33dafb	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x369da291	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xbb387ece	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xd7e631d9	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xfa124673	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x12a74819	snd_hdac_link_free_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x24fab399	snd_hdac_ext_stream_set_spib
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x2737206b	snd_hdac_ext_link_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x2c90956f	snd_hdac_ext_bus_device_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x34764284	snd_hdac_stream_free_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x37a84207	snd_hdac_ext_link_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x45cc8e8c	snd_hdac_ext_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x499dc5ac	snd_hdac_ext_stream_get_spbmaxfifo
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x4ed71f9b	snd_hdac_ext_stop_streams
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x534e51b3	snd_hdac_ext_bus_get_link
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x54d5151e	snd_hdac_ext_bus_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x5fde07a3	snd_hdac_ext_bus_ppcap_enable
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x613ab0c3	snd_hdac_ext_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x61d28f62	snd_hdac_ext_bus_device_exit
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x63c21148	snd_hdac_ext_bus_link_power_down_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x740a1ee4	snd_hdac_ext_bus_link_power_down
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x8a3a6086	snd_hdac_ext_bus_link_power_up
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x94695b14	snd_hdac_ext_link_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x965779a7	snd_hdac_ext_stream_release
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x968e6c88	snd_hda_ext_driver_register
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0x9d983c0c	snd_hdac_ext_stream_decouple
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xb57d4535	snd_hdac_ext_stream_init_all
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xb62696e3	snd_hda_ext_driver_unregister
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xc1348127	snd_hdac_ext_stream_init
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xcca4b967	snd_hdac_ext_bus_get_ml_capabilities
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd2f5c59a	snd_hdac_ext_link_clear_stream_id
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd47ee1a8	snd_hdac_ext_link_stream_start
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xd819e73c	snd_hdac_ext_bus_parse_capabilities
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xe1697ad9	snd_hdac_ext_bus_device_remove
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xeb739381	snd_hdac_ext_stream_spbcap_enable
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xed61b2dd	snd_hdac_ext_link_set_stream_id
++EXPORT_SYMBOL_GPL sound/hda/ext/snd-hda-ext-core 0xf4e90784	snd_hdac_ext_bus_ppcap_int_enable
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x05578cb8	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x06799446	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x071d8444	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x074444dc	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x090c1bf7	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1278ab2a	snd_hdac_set_codec_wakeup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x17439461	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x17827fe1	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x19628734	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1abae4e2	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1e5bbe48	snd_hdac_display_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1ea4faa5	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1f97c509	snd_hdac_i915_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x21b6165f	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x252f13ce	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x26801370	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2aada21e	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2eb47e4a	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x30c58762	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3300d865	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3317cc28	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x349b1352	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x350bcfd1	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3ebf68bf	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x40264cf8	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x41bdd040	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x45f532e1	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4a771498	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4b50fc50	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4bb72898	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4c9744a9	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x50cfeae9	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x52fdbbeb	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6906e761	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6d5ef973	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6ecafad7	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6ecee577	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x73187668	snd_hdac_i915_register_notifier
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x742c4a59	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7c484ce0	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8026da7c	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8109247d	snd_hdac_get_display_clk
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8276ca3c	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8345cafe	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8418e576	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8c5dccf4	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8d3f1505	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8e241471	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x96830f6f	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9b26741f	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9be67554	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa0b0d662	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa1c9e35c	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa30e6cfd	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa3275099	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa8017a6c	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xaadabc3b	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb024e2e7	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb0550e30	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbf32f8fc	snd_hdac_i915_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc14fe50a	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcc560f6f	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xce4d6f19	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcf9b6e49	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd19a11a5	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd4a3175d	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd8c44b68	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd92f0af3	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd9369883	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xda36f50d	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xde00bb51	snd_hdac_i915_init_bpo
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe0c69444	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe9249516	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xec4ce304	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xef87ed87	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfaa50346	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfb729f2b	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfff3e55f	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x60c27506	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x60f9df63	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xb3277964	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xd1004d1f	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xfbebac6d	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xfe7936bf	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x00297c9a	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x024b0cb9	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x089c5ab2	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x097f51c1	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0c2fdb0d	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0c8e3161	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0e9b6a1b	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1114bfa6	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1898ceb7	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x18d9cc3b	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x18fb4c6a	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1b5cf3a2	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1c9500e3	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x23597c31	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x236bc536	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2586ea0f	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x259d3a08	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x271c8455	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x272ee617	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2b03b4db	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2b191755	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x309f94ce	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x30b34aca	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x322215e7	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x33cf3439	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x36a50eaa	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3a81ced2	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3b8069ec	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3f75fe7c	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4063b4c9	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4120a803	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x421315ff	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x43251299	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x43efadd5	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x43f84a59	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4851ac2d	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x49a12cf5	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x507dc504	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x51142b03	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x524d81d5	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5310877c	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x55a08a91	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5676ca43	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x58213fa1	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x58d2c885	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x61ddc7b5	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x66186bb9	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x67dca200	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x682a86c7	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6abeff38	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6c341bcc	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6ccae7aa	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6f6a116d	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7024bfba	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x71e245d4	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x74880179	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7571e9c6	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x75d8c2a9	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7c6a2d47	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7e49bc50	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7e72e6d8	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7e8b8288	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x810ec1a2	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x87f3d94a	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x88c6bb05	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8a175abf	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8e4c1fbe	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8e5dc9a7	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9220b573	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x939d5c99	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x95d8f0af	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x96054405	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x980eddd9	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x986b989e	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x98ce1cb8	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9dd508ed	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9e02ca4a	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9fc51664	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa16396b7	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa4e67abc	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa663c02d	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa8730a90	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaa52f456	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xae2f21d6	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xae9da73d	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb062317e	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb0b74550	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb1424823	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb9d10b17	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbd31173a	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbf49d7f4	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbfcfecca	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc030815c	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc18c6d72	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc1a89478	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc215b2b9	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc31f7403	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc5ef880f	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc85afcfc	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc88de07c	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc8c1a0a7	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc906443f	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcecebe72	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd07633e7	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd312bfca	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd609d35a	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd706e873	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdad5da72	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdbb3d0bb	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdc6fad7a	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe2896621	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe4566205	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe58a84a3	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe6e551f1	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xebc35288	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xec3313d7	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xee11f546	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf23cff31	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf27d5bd4	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf446ff95	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf5156b1a	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf79910ea	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfc22e85b	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfc26353f	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x04a57a75	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x0948b396	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x2524c003	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x2fb48272	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x33c3e814	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x647208d3	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x65741abe	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x6898bd33	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x6ab6981e	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x7d61301a	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x813fb481	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x8b6bd1d8	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x98910d2c	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x9f1a7416	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x9f61fe06	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xb7aa4b55	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xba0fcbb0	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xc8138a6a	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xcbb3fb16	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xd4352441	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xd8ca8dea	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x2c1154b8	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xd165a7fa	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x590a192a	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xe9b6d1d0	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x34a287ae	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x741a381c	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xa87c12e7	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x03a49f5f	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0xf86558ef	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98090 0x55e5ea51	max98090_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x035bf29a	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x566d037f	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x6ea6900d	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xf10e578c	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x70617a04	rl6231_get_clk_info
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x7f68b24d	rl6231_pll_calc
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0x8d7fa148	rl6231_get_pre_div
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6231 0xdba4502f	rl6231_calc_dmic_clk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6347a 0xa7aa810f	rl6347a_hw_write
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rl6347a 0xade4bf4c	rl6347a_hw_read
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt286 0xf5b690f0	rt286_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5640 0x08c0f1c1	rt5640_dmic_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0x1c95b8c7	rt5645_set_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5645 0xc40e7aed	rt5645_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0x9304eb8d	rt5670_jack_resume
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0xdd12b8c6	rt5670_set_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0xdf7ce0a2	rt5670_sel_asrc_clk_src
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-rt5670 0xefa6b4a4	rt5670_jack_suspend
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x3b8a7e7e	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x70ef34dd	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x855934b1	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x92c1eaa5	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xfd99040d	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0x596029d9	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sn95031 0xf733d9c8	sn95031_jack_detection
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x25e4079c	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x5c92d987	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x4db9676e	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x6b4a7ac6	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0xa03eef43	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x135c6f77	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xa41e58f4	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xb1d692c4	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xdb735ced	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0xe18c8971	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0x6bc9d773	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x52b3ad4c	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x9e46ee5e	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/snd-soc-sst-mfld-platform 0x5e5af485	sst_register_dsp
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/snd-soc-sst-mfld-platform 0x7ef32732	sst_unregister_dsp
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x4bb8eb94	sst_context_init
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x4e4981a6	sst_configure_runtime_pm
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0x9ae9b18e	intel_sst_pm
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0xab14edd5	relocate_imr_addr_mrfld
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0xb187b89e	sst_alloc_drv_context
++EXPORT_SYMBOL_GPL sound/soc/intel/atom/sst/snd-intel-sst-core 0xed8c2189	sst_context_cleanup
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0x243d5d17	sst_byt_dsp_wait_for_ready
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0x2f804d3e	sst_byt_dsp_boot
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0x309e9ec3	sst_byt_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0x34a52aa0	sst_byt_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/intel/baytrail/snd-soc-sst-baytrail-pcm 0x39aa0ef6	sst_byt_dsp_suspend_late
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x0e66f369	sst_module_runtime_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x14c7b233	sst_dsp_shim_read64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x1b5e8b82	sst_shim32_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x22377910	sst_dsp_shim_update_bits_forced_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x236ff8ef	sst_module_runtime_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x2b2d9f4d	sst_dsp_boot
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x2ca81140	sst_module_get_from_id
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x2cfd6fbd	sst_module_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x380e6d25	sst_dsp_shim_write64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x389851db	sst_mem_block_unregister_all
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x39bfb6c2	sst_module_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x3d494cca	sst_fw_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x3e1aaba8	sst_dsp_shim_update_bits64_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x430c030b	sst_dsp_mailbox_init
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x46b786bb	sst_block_alloc_scratch
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x47b008ca	sst_dsp_shim_write_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4971e48f	sst_dsp_shim_update_bits_forced
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x49ed680e	sst_dsp_ipc_msg_tx
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4a045773	sst_shim32_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4bc7c143	sst_dsp_shim_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4cffa75e	sst_memcpy_fromio_32
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4ee8a119	sst_block_free_scratch
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x4feec3ee	sst_dsp_shim_update_bits
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x5206c882	sst_dsp_get_offset
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x55456270	sst_dsp_shim_update_bits_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x5a6918c2	sst_dsp_inbox_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x64f824d6	sst_dsp_shim_read64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x66004268	sst_dsp_dma_get_channel
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x70d3eea4	sst_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x7af199c6	sst_module_runtime_save
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x7dc6b532	sst_dsp_shim_read_unlocked
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x7e2ff6a7	sst_dsp_wake
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x7f46b3ef	sst_dsp_dump
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x8332525b	sst_module_runtime_restore
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x8a1f8630	sst_module_alloc_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x8b913ecb	sst_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x8fa202c8	sst_dsp_ipc_msg_rx
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x916ab50d	sst_fw_unload
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0x9de36cb4	sst_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xa0f97983	sst_dsp_sleep
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xa531c314	sst_dsp_inbox_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xa8022549	sst_dsp_dma_put_channel
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xad88d2d2	sst_fw_free_all
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb330c6d6	sst_module_runtime_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb5f5b87a	sst_dsp_shim_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xb89044dc	sst_dsp_outbox_read
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbb8f3154	sst_module_runtime_free_blocks
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbcec5387	sst_shim32_read64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xbf4889f9	sst_dsp_reset
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xc354ee95	sst_dsp_dma_copyfrom
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xc4d90226	sst_dsp_register_poll
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xcfcbf3c7	sst_dsp_outbox_write
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xd8dec11e	sst_fw_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xd9a2c94c	sst_shim32_write64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xdaa0ed7f	sst_dsp_shim_update_bits64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xddbfdf71	sst_fw_reload
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xec45f7fa	sst_dsp_new
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf0aaa339	sst_memcpy_toio_32
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf107b556	sst_module_free
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf3475119	sst_dsp_shim_write64
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf61082b1	sst_dsp_stall
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xf76d1e2e	sst_module_runtime_get_from_id
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xfbd0a462	sst_dsp_dma_copyto
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-dsp 0xfc806f40	sst_mem_block_register
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x24754c8c	sst_ipc_fini
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x2c84221d	sst_ipc_tx_message_nowait
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0x4d0a46c9	sst_ipc_drop_all
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0xb25b26ea	sst_ipc_reply_find_msg
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0xb655e024	sst_ipc_init
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0xbfefeced	sst_ipc_tx_msg_reply_complete
++EXPORT_SYMBOL_GPL sound/soc/intel/common/snd-soc-sst-ipc 0xd6d60d62	sst_ipc_tx_message_wait
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0x02f5c101	sst_hsw_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0x2cc77f9d	sst_hsw_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/intel/haswell/snd-soc-sst-haswell-pcm 0xd1f69f64	sst_hsw_device_set_config
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x14439ee0	skl_ipc_delete_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x1b962ab3	is_skl_dsp_running
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x1dc73a0c	skl_dsp_wake
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x31429908	skl_sst_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x3287af83	skl_ipc_set_large_config
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x77ef47ad	skl_dsp_sleep
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x7a4919d3	skl_ipc_set_dx
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x86e4af7f	skl_ipc_create_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x8ec3e6a0	skl_sst_dsp_init
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0x9c569d45	skl_ipc_init_instance
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xa3cc0dbd	skl_ipc_restore_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xe2475006	skl_dsp_free
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xe7dbed7c	skl_ipc_bind_unbind
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xe84eb99a	skl_ipc_save_pipeline
++EXPORT_SYMBOL_GPL sound/soc/intel/skylake/snd-soc-skl-ipc 0xf047e59c	skl_ipc_set_pipeline_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0006a49a	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x005f0d2e	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x00d1e816	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0204aeef	snd_soc_tplg_component_load
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0812b905	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x09bf3eb5	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0c0aef97	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0e9b4102	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0ef826b5	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0efff70a	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0f8010dc	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0fbbd5f2	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1112ff73	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1218e35b	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x129fcd0d	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x12bd3621	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x13a973aa	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x184f7574	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1c03b55f	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1c25dc04	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1c96bc54	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1ef7f8f5	snd_soc_component_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1f3c16dd	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1f5615d2	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x20fb543d	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2131a62c	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x214235e3	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x222d8266	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x26a73d2f	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x26f73201	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x29dcd1ba	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2a19e5c5	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2b7eeae8	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2cc5d1bf	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x320d6455	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x32a93eee	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3310d0b8	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3319da7b	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x34f7d41b	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x369d2d44	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x383b7ae2	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x38bf40ef	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x39120615	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3a143772	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3b28eee8	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3cf599b6	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3db829cd	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3f3708dd	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3f885e30	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x41634375	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x460e9c73	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x469ae9cb	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x473eec94	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x47c7bca4	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x49060755	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4a5cb96b	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4e4f3b72	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x55a3e557	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5684d952	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x572f1d61	snd_soc_tplg_widget_remove_all
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5a6c806f	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5caf9e79	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5ec4e522	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5f75bb76	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x60e4baa0	snd_soc_resume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x610ead24	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x61d69beb	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6228169d	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x626cdb47	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x630b7504	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x65ba9d8d	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x661b0d48	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6b07194d	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6c4b4eec	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6ded96ad	snd_soc_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6e677ec7	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6f01fa11	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x70614ee2	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x71120816	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x72b2ba80	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x736ff351	snd_soc_component_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x73cb0d77	snd_soc_tplg_component_remove
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x74bf074f	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x751e49bc	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7521aad7	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x758f2219	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7733be37	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7a484b11	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7a9fbfb2	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7b8d0095	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7bcb1d36	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7fda25fb	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8139ced5	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x82c8d5c9	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x82d83211	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x85334957	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8681f1f7	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x87026dcd	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8f20f29e	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x92d8f90a	snd_soc_tplg_widget_bind_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x92f63764	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x947486cc	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9c25db98	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9f4e078a	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9f67c60a	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa36ee769	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa3a7f569	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa4fb6dd7	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa84155fc	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa9211374	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa9bbf7b2	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xaa998422	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xad7fd526	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xae61ad2d	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb4f26e58	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbbbd45df	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbbf26953	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbc2a29b8	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbdfe3357	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbf6e25ec	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc4efa17c	snd_soc_tplg_widget_remove
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc68eb869	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8a24967	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xca9f2225	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xceb5eef4	snd_soc_new_compress
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd0451b27	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd3cca6fa	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd538435e	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd90b97d8	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdc5c78d3	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdc9477da	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe0bce1c0	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe25163cd	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe3321f8f	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe4753cf9	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe644dcb0	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe8ec5919	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb095e72	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb1aa473	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb4b194e	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xed0459dd	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xed716356	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xef32c663	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xef8bb2ff	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf0328e1b	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf06561f0	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf4c8de3c	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf566ad01	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf706813a	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf8fe0114	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf952f2e7	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfbe77abc	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfc840846	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfe22c01f	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x19458e3f	line6_read_serial_number
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x540ed7ce	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x6acc8c1d	line6_write_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8bc7e1b4	line6_version_request_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x945dc860	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x9bb7d117	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x9deea506	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xa140ef7b	line6_init_midi
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xa2fa8b45	line6_suspend
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xbd782713	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xc54c8458	line6_send_sysex_message
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xdbab7ee3	line6_read_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xe0f2718c	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xed4e02e6	line6_pcm_release
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xf72da89c	line6_pcm_acquire
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x08003b2f	i915_bpo_gpu_turbo_disable
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x0d97d346	i915_bpo_gpu_raise
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x358a54ae	i915_bpo_gpu_busy
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x451432c2	i915_bpo_gpu_lower
++EXPORT_SYMBOL_GPL ubuntu/i915/i915_bpo 0x7d4de94c	i915_bpo_read_mch_val
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x087e5cb3	rsi_default_ps_params
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x118d0ff0	rsi_hal_device_init
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x1c656cd5	ven_rsi_91x_deinit
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x1e678bb2	dot11_pkt_type
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x3c882bf0	rsi_remove_dbgfs
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x4224cb8f	ven_rsi_mac80211_detach
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x437447f4	rsi_hex_dump
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x457e8d80	rsi_init_dbgfs
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x45ca198c	ven_rsi_dbg
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x52e08a19	ven_rsi_91x_init
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x5f72d45e	rsi_hci_detach
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0x857b4856	rsi_send_rx_filter_frame
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xb25f81b8	rsi_hci_recv_pkt
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xbabe3c80	ven_rsi_read_pkt
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xc26e71fd	rsi_send_rfmode_frame
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xd6f82032	rsi_deregister_bt
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xe3a0df72	rsi_config_wowlan
++EXPORT_SYMBOL_GPL ubuntu/rsi/ven_rsi_91x 0xe8a5f63d	rsi_hci_attach
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x3fe35aea	irq_bypass_unregister_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x418873cc	irq_bypass_register_producer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x888c5be5	irq_bypass_register_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0xf6e772c3	irq_bypass_unregister_producer
++EXPORT_SYMBOL_GPL vmlinux 0x001181ec	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0x00149990	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x002a113a	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0034f3b6	xen_has_pv_nic_devices
++EXPORT_SYMBOL_GPL vmlinux 0x0042d2eb	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x004f004a	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0x0056e931	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x00632780	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x006ec128	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x0070b925	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x0078a41b	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x008d7eac	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00db3f95	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x010cb19e	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x014840af	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0x016ad45a	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x0170cb6c	efivar_work
++EXPORT_SYMBOL_GPL vmlinux 0x0178796a	__efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x01848a8e	local_apic_timer_c2_ok
++EXPORT_SYMBOL_GPL vmlinux 0x01976643	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x01c4a551	set_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x01d695e0	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x01d827d2	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x01e88b6d	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x023cc7bb	__efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0x0266ade9	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0x0272befc	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0x02744ca2	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x029e7101	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x02b76d09	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x02c5b6a0	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x02db249b	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0x02fa1242	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x02fb5332	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x03010687	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x031542a6	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0x0335d5b1	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x035b858c	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x037f865f	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x037fba25	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03aebf36	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x03ce75ee	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x03d25617	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x0402cbbf	preempt_notifier_inc
++EXPORT_SYMBOL_GPL vmlinux 0x041174ea	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x04363c3f	rio_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x043bf3c9	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x04551fb7	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x0465473a	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x047c8ddf	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x047e70e6	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x047f374b	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0x0485655f	amd_get_nodes_per_socket
++EXPORT_SYMBOL_GPL vmlinux 0x04897b9a	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x048a6846	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x04972400	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x049de012	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04abaf9b	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0x04b1ba2a	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x04bf26af	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x04c3f2c1	gnttab_empty_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x04c4be07	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04ca0531	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0x04ccb208	dax_do_io
++EXPORT_SYMBOL_GPL vmlinux 0x04d055af	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x04ecfb5c	set_memory_wt
++EXPORT_SYMBOL_GPL vmlinux 0x04f4bd8d	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0x05177e47	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x052569a5	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0x05306bfe	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x05503d5f	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x05564d79	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x05631ecd	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x056bbfed	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0x0574e17c	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x0575e31a	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x057ef9be	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0x05819e03	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0587a13d	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x059a1105	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x05a6f228	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0x05cc2363	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x05d1fc4c	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0x05eca2f1	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x05f5dd56	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x060d5ce3	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0x061f2938	rio_mport_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x064d781f	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x065b2a9d	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x06685a7e	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x0683ae53	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x06876a29	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x069194a6	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x06963c36	intel_msic_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x069b74c6	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0x06d549e6	pinctrl_free_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x07032f9e	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x071122c5	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0x0715db8b	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0x071a1d36	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0x071a761a	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0x071ee624	__tracepoint_detach_device_from_domain
++EXPORT_SYMBOL_GPL vmlinux 0x073a338b	fpstate_init
++EXPORT_SYMBOL_GPL vmlinux 0x07442711	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x0752ba4c	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x07564d37	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0x07603e3c	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x079d6530	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x07a4f537	x86_vector_domain
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07da7382	xenbus_dev_remove
++EXPORT_SYMBOL_GPL vmlinux 0x07da89f5	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0x07ddd2c3	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0x07f300c3	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x07f61c8e	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x081b6be1	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0x081dc08f	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x082333d6	rio_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x0839b333	dax_pfn_mkwrite
++EXPORT_SYMBOL_GPL vmlinux 0x08cbc119	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x08d58286	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x08ebab77	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x08f10258	gnttab_unmap_refs_sync
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x093d6ce3	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0961ebc6	__rio_local_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x0962d0e8	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x0966d674	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0x0997291f	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0x09ae8d48	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x09b09813	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0x09b50ffc	input_class
++EXPORT_SYMBOL_GPL vmlinux 0x09eb3f19	pinctrl_remove_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x09efec24	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x0a0863ce	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x0a1f36b3	rio_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x0a4fde00	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x0a57df06	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0a64775f	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x0a835b13	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0x0a8d21ae	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0x0a97fc9d	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x0a9be626	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x0ab18a40	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x0ae7e356	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x0af41b41	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x0af4e2cc	rio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0af77223	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0x0afd4610	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b24c083	xenbus_dev_changed
++EXPORT_SYMBOL_GPL vmlinux 0x0b3b1d0b	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x0b52e502	apei_resources_add
++EXPORT_SYMBOL_GPL vmlinux 0x0b84cd49	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x0b9008ae	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x0b99731f	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x0ba1f1c0	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x0bc9843d	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x0be85b16	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x0beddad2	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x0bf50669	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c4e612a	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x0c53eecc	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x0c76e67f	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x0c805f93	clflush_cache_range
++EXPORT_SYMBOL_GPL vmlinux 0x0c80e3fe	efivar_init
++EXPORT_SYMBOL_GPL vmlinux 0x0c80ec89	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x0ca1dcc5	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x0cabce8b	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x0cb3a7c2	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0ce75a41	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x0d059e64	static_key_deferred_flush
++EXPORT_SYMBOL_GPL vmlinux 0x0d064a0d	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0x0d0917e5	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x0d29b3cd	xenbus_frontend_closed
++EXPORT_SYMBOL_GPL vmlinux 0x0d3abe02	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0x0d490bc4	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d664075	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x0d6b0b5d	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0d87e885	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x0d997a31	xen_find_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x0db4cafb	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0x0db649e4	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x0dbbf17d	__remove_pages
++EXPORT_SYMBOL_GPL vmlinux 0x0dbd6fe7	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0x0dcda223	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0df925f6	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0x0e007edf	xen_evtchn_nr_channels
++EXPORT_SYMBOL_GPL vmlinux 0x0e13b070	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x0e13cb4d	apei_resources_release
++EXPORT_SYMBOL_GPL vmlinux 0x0e1b8e8e	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x0e21c949	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x0e295435	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x0e4d5a3e	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x0e6a33a0	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0x0e6b263c	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0x0e919b34	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0x0eae7484	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x0eb37246	clk_register_gpio_mux
++EXPORT_SYMBOL_GPL vmlinux 0x0edd4c03	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x0edff73f	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x0ef73c96	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0x0f289ac1	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x0f2d7d87	mce_unregister_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f344f50	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0f361b45	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x0f4a4dbc	__xenbus_register_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x0f671b8e	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x0f6e4206	gnttab_unmap_refs_async
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f795c34	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0x0f8ed4eb	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x0f989d60	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x0fa138de	xen_hvm_need_lapic
++EXPORT_SYMBOL_GPL vmlinux 0x0fb37965	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0x0fc01e9f	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0fcc1969	copy_from_user_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x0fdc5993	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0x0fe2d570	xenbus_directory
++EXPORT_SYMBOL_GPL vmlinux 0x0feae200	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0fedd8a3	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x1016f384	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x102e56f9	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x1059cd4a	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x1078abd9	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x1094725e	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0x10b873df	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0x10c1e79f	set_pages_array_wt
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x110042bd	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0x110106c1	cper_severity_to_aer
++EXPORT_SYMBOL_GPL vmlinux 0x110fc089	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x110ff7fe	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x1118bbe6	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x11373c25	acpi_is_pnp_device
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x118049f0	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0x1182f7c4	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x118494d2	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0x11ca5d39	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0x11d7589e	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x11d81720	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x11e3f7c4	rio_map_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0x1211e545	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x12157e72	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x122df96f	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x122ea412	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x1230a0ad	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0x12365e8c	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0x124c8658	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x12532dd8	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x125fda28	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x127ab74e	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0x1280ed3a	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1294999f	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0x1296df3a	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x12c8d89c	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x12c9f911	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0x12ca8e17	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x12dfb1d6	xenbus_watch_path
++EXPORT_SYMBOL_GPL vmlinux 0x12ea3c14	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x130bd388	check_tsc_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x131467b8	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131afaba	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x1331be7d	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x1332afe0	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x134fc41c	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1365cebe	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0x137d8e92	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x138aff76	gnttab_init
++EXPORT_SYMBOL_GPL vmlinux 0x139bb975	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0x13ad647f	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x13b3a97f	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0x13b89dee	pinctrl_request_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x13bb70de	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x13bc9ce7	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x13c22c20	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x13e1ab9d	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x13f51fc3	ms_hyperv
++EXPORT_SYMBOL_GPL vmlinux 0x14249545	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0x142f240e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0x143eef24	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0x1456f802	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x14579e22	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x14a54d1a	xenbus_map_ring
++EXPORT_SYMBOL_GPL vmlinux 0x14acf021	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x14c1ddcd	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0x14c94d6d	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0x15010e1f	arbitrary_virt_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0x1515313d	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0x1533f78c	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0x1540c469	efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x1541f93d	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0x15568631	lookup_address
++EXPORT_SYMBOL_GPL vmlinux 0x156f8cbd	clk_hw_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x1578beb2	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x15823fb5	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x15911eee	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x15b0606e	e820_any_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x15ff107d	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x162f78f8	rio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x164934f4	pgprot_writethrough
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x165f6bfd	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x1660c92a	pcc_mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0x1664cfca	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x16656acf	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x16743218	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x168daaa8	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0x16b4fc5c	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x16c30291	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x16dedbfe	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x16e215c6	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x17045172	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0x17093d7d	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x1716a5cc	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x1719586d	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x172cea17	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0x172d08b8	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x17395043	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0x17525196	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0x17614bf3	apei_resources_sub
++EXPORT_SYMBOL_GPL vmlinux 0x176ba8d1	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x176d7312	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x177c25ee	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x17984f0b	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0x17994d70	memhp_auto_online
++EXPORT_SYMBOL_GPL vmlinux 0x179bca0e	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x179cca1c	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x18045f43	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0x18105592	xen_remap_domain_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x1840d2b0	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1857553b	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0x18582826	amd_pmu_disable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x18c3df98	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x18c40c8c	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x18d933e0	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0x18f5e50e	arch_apei_enable_cmcff
++EXPORT_SYMBOL_GPL vmlinux 0x18f6808d	nd_blk_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x18f83fab	gnttab_grant_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0x190cff6e	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0x19274aed	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x1929f271	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x1954caac	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1959dc86	hypervisor_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x19616c1b	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x196614ce	hw_breakpoint_restore
++EXPORT_SYMBOL_GPL vmlinux 0x1990f8ff	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x199bcf72	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19ae2390	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0x19d35025	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1a003c5f	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x1a16e170	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0x1a1b53c8	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x1a1c4082	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x1a490641	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x1a4f9a90	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x1a714b1e	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x1a71b6cd	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x1a856ed2	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1a9c40f9	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x1a9cb062	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x1ab91595	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1ad5a4dd	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x1b1f2bda	speedstep_get_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x1b38b3c6	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0x1b43f5bc	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x1b4da864	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x1b52d0fa	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0x1b52db1c	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x1b68b0ac	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x1b790944	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0x1b8822d8	pinctrl_gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x1b95d0dc	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1bb5155c	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x1bc5eebe	pinctrl_gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x1c1df6b3	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0x1c21fc67	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x1c4fc462	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c5ff742	clk_get_phase
++EXPORT_SYMBOL_GPL vmlinux 0x1c6660c7	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1c88c0b3	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0x1c8a5262	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x1c8dfc3f	pci_msi_set_desc
++EXPORT_SYMBOL_GPL vmlinux 0x1c8eae55	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x1cb1253c	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0x1cc5e456	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x1ccd2284	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x1cdd5440	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0x1ce51409	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x1d04ba8f	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d37b9b1	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x1d3b41b3	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x1d4591bb	ata_acpi_stm
++EXPORT_SYMBOL_GPL vmlinux 0x1d459685	xstate_size
++EXPORT_SYMBOL_GPL vmlinux 0x1d4b6855	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d681eb5	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x1d739e1c	xen_set_callback_via
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1d7cb586	clk_register_fixed_rate_with_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x1d8b2297	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0x1d8eebf2	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x1d9da838	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x1dafa25e	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0x1dc0517c	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0x1de80a38	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x1def880e	bind_interdomain_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1df38ebd	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x1e05d1d4	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0x1e530dd7	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e6d4ec9	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0x1e728c4f	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e80cce5	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1e9b90d6	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ec9c61b	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x1ecf7a5f	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x1ed1dfdc	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x1ee4592a	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1eefdea6	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x1ef5914a	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x1f0ac8a4	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x1f1c61d1	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x1f3303b1	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x1f3d79ba	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x1f406110	rio_request_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x1f69e1f6	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x1f7d4364	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x1f7f6fac	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1f8e992f	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x1fa0ae4b	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1fa5b19a	preempt_schedule_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x1faa3038	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0x1faaffa7	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x1fae6310	__clk_get_hw
++EXPORT_SYMBOL_GPL vmlinux 0x1fba7083	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1fc48828	find_module
++EXPORT_SYMBOL_GPL vmlinux 0x200a2328	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x200cc695	__free_iova
++EXPORT_SYMBOL_GPL vmlinux 0x201bb095	acpi_dev_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x202809e0	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x204e66e6	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0x20704496	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x207233e6	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x2094fd06	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x209ec764	xen_event_channel_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0x209f710d	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x20aa6f51	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x20dfea62	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x20f2afa5	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x20f935a0	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0x20fb103c	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x20fed3b3	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0x210d9db4	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x21356c4c	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x214c592f	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x216e7d1c	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x216ff548	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x217ae1b8	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x21911248	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0x219fab35	acpi_gpiochip_free_interrupts
++EXPORT_SYMBOL_GPL vmlinux 0x21a563da	clk_get_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21b17d9b	pinctrl_lookup_state
++EXPORT_SYMBOL_GPL vmlinux 0x21b77287	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21e8d54b	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x21ed2975	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x22001f72	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0x221e43a2	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2246db6b	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0x227a2181	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x2281725e	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x2299ec81	perf_assign_events
++EXPORT_SYMBOL_GPL vmlinux 0x22a9e2e2	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x22d7a196	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x22f97be1	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0x23048011	__intel_mid_cpu_chip
++EXPORT_SYMBOL_GPL vmlinux 0x2315a82c	clk_mux_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x232fba9b	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x23526622	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2357f93b	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0x2366a2c0	errata
++EXPORT_SYMBOL_GPL vmlinux 0x23770f29	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x2396c7f0	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0x239f1f7a	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x23afa9c6	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0x23b48c20	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0x23b808b0	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0x23c2660f	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x23e5f005	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x23f663a0	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x240580a9	xenbus_probe
++EXPORT_SYMBOL_GPL vmlinux 0x243aa053	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x24614ac9	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0x24656ad9	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0x2469810f	__rcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x246b0d63	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x2472d356	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x249da32e	acpi_get_pci_dev
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24b089c5	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0x24b7f887	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x24c7698a	xenbus_write
++EXPORT_SYMBOL_GPL vmlinux 0x24da8290	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x24f45195	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x24fa11a7	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x24ff257d	pinconf_generic_dump_config
++EXPORT_SYMBOL_GPL vmlinux 0x25031c3e	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0x250d9e9e	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x252c09be	injectm
++EXPORT_SYMBOL_GPL vmlinux 0x25379e73	clk_set_min_rate
++EXPORT_SYMBOL_GPL vmlinux 0x2545c170	unregister_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x257aa0c5	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x2595a8d8	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x25b653ad	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x25bd595e	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0x25c05153	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x25f02c87	xen_p2m_addr
++EXPORT_SYMBOL_GPL vmlinux 0x26085a7e	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x26090925	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x261b46ef	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x26215a7e	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x264ae4c6	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x2657987c	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x2680a882	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x26843873	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0x2686f4eb	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x269014dd	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x26965721	slow_virt_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x26998755	ata_acpi_gtm_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x26b3c701	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26e1051e	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0x26eacab5	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0x2701b5b7	xen_unregister_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x2705501f	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0x27056f74	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x2734ccb3	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x274cf5e1	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x27545a08	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x2761369a	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0x278782d0	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x2787db00	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x278e4b2c	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0x279cb985	apei_exec_pre_map_gars
++EXPORT_SYMBOL_GPL vmlinux 0x27b58b55	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27c97f29	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x28084a7d	reserve_iova
++EXPORT_SYMBOL_GPL vmlinux 0x280ca56d	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x28278fc4	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x2844956d	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0x284aff39	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0x285cb7dd	pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0x285d1bde	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x289c0371	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0x28aa6a67	call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x28ca1c50	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x28ce407b	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0x28e64c64	xen_has_pv_and_legacy_disk_devices
++EXPORT_SYMBOL_GPL vmlinux 0x28fd1944	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x29091409	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0x290c53eb	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0x2922c452	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0x293f073e	vrtc_cmos_write
++EXPORT_SYMBOL_GPL vmlinux 0x29711dff	acpi_processor_get_performance_info
++EXPORT_SYMBOL_GPL vmlinux 0x297cec83	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x29a7b218	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x29f039ae	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x2a0a57e9	nd_blk_region_set_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x2a0b283b	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0x2a1a653f	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0x2a2cff0f	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a9bac1b	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x2aa878e4	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x2aac1ec6	nvdimm_blk_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x2ac12c47	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x2acdc2ce	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x2ae082dd	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x2ae28b56	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x2af63321	acpi_dev_resource_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x2afa5f22	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0x2b179a0b	rio_unlock_device
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b2afaf3	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0x2b2f0906	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x2b344494	acpi_device_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x2b602bb9	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x2b67f096	speedstep_get_frequency
++EXPORT_SYMBOL_GPL vmlinux 0x2b7069ff	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x2b746485	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x2b952517	clk_has_parent
++EXPORT_SYMBOL_GPL vmlinux 0x2b96316a	efivar_variable_is_removable
++EXPORT_SYMBOL_GPL vmlinux 0x2bb3c704	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0x2bc50e7c	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x2bc94f76	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa39ee	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa985e	nd_cmd_dimm_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2c1c062d	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c4609be	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0x2c630bd1	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0x2c6a0410	xen_set_domain_pte
++EXPORT_SYMBOL_GPL vmlinux 0x2c78bb6a	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x2c7d9c64	xen_store_interface
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c8b8741	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x2c8edb58	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x2cc1a7de	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x2cdc8053	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2d08b826	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d282b5d	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d6ec7bc	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x2d7d7209	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0x2d978b10	nd_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x2d9f2ce3	sched_clock_idle_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x2da469f9	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x2dd84bcb	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x2de681b6	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x2def54cd	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0x2e05bfbe	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x2e0b9823	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e4c0132	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x2e4de4c3	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0x2e58b7b6	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x2e66612a	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x2e6b9888	xen_register_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x2eb9d6ae	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ec18f52	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0x2ec53d99	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2ef0b342	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f33b37c	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f542274	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x2f56fb43	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2f64415f	unregister_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f90da7e	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0x2fc4a0b2	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0x2fd71fd9	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x300cfdcc	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0x3047ea4d	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x305399ba	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x305ecbb0	acpi_dma_request_slave_chan_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x30635782	cpu_has_xfeatures
++EXPORT_SYMBOL_GPL vmlinux 0x308a9bee	acpi_dev_get_property
++EXPORT_SYMBOL_GPL vmlinux 0x30917bf3	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0x30a4f4ca	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0x30c1ea0b	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30f26068	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x31128b8e	hv_remove_kexec_handler
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x313c80f7	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x314f75d9	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0x314ff6aa	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x316c525c	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x318a74ed	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0x31a0c2ab	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0x31a4165e	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0x31ae5f73	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31df47bb	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0x31fc7f86	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0x32047007	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0x320beb8a	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0x321dabe1	__add_pages
++EXPORT_SYMBOL_GPL vmlinux 0x3227ac46	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x325363f9	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x32557712	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x325e677c	gnttab_grant_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x3263d968	gnttab_map_refs
++EXPORT_SYMBOL_GPL vmlinux 0x326f688b	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0x327431a7	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x32924a4d	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x32ab7c5c	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0x32b60659	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x32bc0fcf	preempt_notifier_dec
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32e3b076	mxcsr_feature_mask
++EXPORT_SYMBOL_GPL vmlinux 0x333228ec	intel_msic_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x3362b03c	xen_p2m_size
++EXPORT_SYMBOL_GPL vmlinux 0x33655159	xen_pcpu_hotplug_sync
++EXPORT_SYMBOL_GPL vmlinux 0x336d4b88	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0x33784f14	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x3387c721	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0x33a332e4	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x33b96e5d	apei_exec_write_register
++EXPORT_SYMBOL_GPL vmlinux 0x33f9a08e	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0x34023c57	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x340b289d	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0x340e87b6	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3414a57f	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x3420e683	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x3424c8c7	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0x34331d5e	nd_fletcher64
++EXPORT_SYMBOL_GPL vmlinux 0x343a8a54	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0x343cd1bb	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x34415926	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x344e56af	rio_get_asm
++EXPORT_SYMBOL_GPL vmlinux 0x34519442	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x3470908d	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0x3471b417	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0x347682ce	snmp_fold_field64
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34ac50a4	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x34f58c3b	acpi_dma_request_slave_chan_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x35071656	__rio_local_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x352650ee	gnttab_batch_map
++EXPORT_SYMBOL_GPL vmlinux 0x3526b229	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0x3541de7a	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0x3549b01c	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0x355ecaac	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x35667b22	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x357839a6	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x3581f995	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x358b7b1a	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x35910f72	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x35af5c6e	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x35b6c906	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0x35d43533	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x35dcd1f7	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x35f223bf	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0x3606e5ab	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x36186567	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x363419be	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x365c64cc	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x36703958	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x36837a1c	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36b49387	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0x36b5497e	intel_iommu_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x36ba2551	intel_scu_devices_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x36bb5442	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0x36bda7b0	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x36d4e96a	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x36de2236	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x36f96a4a	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x3707a221	xenbus_switch_state
++EXPORT_SYMBOL_GPL vmlinux 0x371c33b7	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x371dc739	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0x373a6f50	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x373c7c25	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x3753484e	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0x3760773c	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0x3764af2a	rio_mport_class
++EXPORT_SYMBOL_GPL vmlinux 0x376918e2	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x3772c146	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0x378bee88	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0x37951d7a	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x37998947	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0x37c3d325	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x37d2612b	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x37f0b38e	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x380d22dd	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x386da50d	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0x38707e6c	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0x38722f80	kernel_fpu_end
++EXPORT_SYMBOL_GPL vmlinux 0x387275f6	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x388b4bbb	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x38a9c2c7	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x38afe3fa	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0x38e5bc5a	clk_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x39016642	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x391d319c	nvdimm_name
++EXPORT_SYMBOL_GPL vmlinux 0x394c1b7d	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x395b7894	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x3971a8ae	xenbus_unmap_ring
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39ca71db	acpi_gpiochip_request_interrupts
++EXPORT_SYMBOL_GPL vmlinux 0x39ceed6c	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x3a15ef89	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a3db234	divider_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a6657c1	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x3a7a674a	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x3a7d80f9	xen_max_p2m_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x3a8c3c51	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3a8f963b	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3ac2fcda	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0x3acdce52	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3afe2128	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x3b04c2e3	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3b1794d1	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0x3b469ab7	__rio_local_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x3b4722c7	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x3b504b32	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x3b547bc9	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x3b666452	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x3b7145bb	apei_exec_read_register_value
++EXPORT_SYMBOL_GPL vmlinux 0x3b76e246	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x3b8b53dd	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x3b9e3ccf	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0x3bde3415	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x3bf12586	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x3bfa6228	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x3c108d1b	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x3c28ec43	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x3c425a52	efivar_entry_set
++EXPORT_SYMBOL_GPL vmlinux 0x3c4a35f5	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x3c5c08b6	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3c797905	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x3c84887b	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x3c9252a0	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3c93ea25	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3ceae5fe	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x3cecd43f	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0x3d0706fd	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x3d3548a8	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d72b39a	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x3d7620d1	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x3d7ea99a	gnttab_grant_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x3d848799	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x3da110d9	xenbus_map_ring_valloc
++EXPORT_SYMBOL_GPL vmlinux 0x3daccfd7	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3dbee4a6	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3dd4d3a7	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3deb1447	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x3e2d6df3	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3e3fd990	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x3e54b244	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3e5b1239	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e639f99	efivar_entry_add
++EXPORT_SYMBOL_GPL vmlinux 0x3e64f944	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3e6874a9	sis_info133_for_sata
++EXPORT_SYMBOL_GPL vmlinux 0x3e6e23c6	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e757637	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0x3e7ed4dc	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x3e9cd267	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3ea5196d	apei_osc_setup
++EXPORT_SYMBOL_GPL vmlinux 0x3eb7af22	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0x3ebe33f0	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x3ed50bc2	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x3eea6fe6	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x3eedd771	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x3eef1f07	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f1bd29d	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0x3f1e163a	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x3f229c4c	oops_begin
++EXPORT_SYMBOL_GPL vmlinux 0x3f2f27a7	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0x3f54ce2c	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0x3f58b102	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x3f66a343	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x3f67e28f	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x3f84d4c9	gnttab_release_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x3f9973c7	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x3fa5af9c	nd_cmd_bus_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3fc4307f	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0x3fdbb8e5	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0x3fffc828	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0x40029c7f	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x400a024b	acpi_scan_lock_release
++EXPORT_SYMBOL_GPL vmlinux 0x4010b80f	pmc_atom_read
++EXPORT_SYMBOL_GPL vmlinux 0x401a28b8	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0x401e84c8	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x402420a0	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x402ac990	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x4032ee23	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x4053f6c3	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x40587ac4	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x40632803	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x408212ba	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0x408e9189	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x40a9ed39	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40c67137	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x40c785da	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40dc3cde	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0x40e3d4a4	xen_swiotlb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x40e5da2f	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x411ff21b	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0x412e9193	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x416000ae	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0x41729c93	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0x417ab7b5	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x418710e7	mce_inject_log
++EXPORT_SYMBOL_GPL vmlinux 0x41883cb1	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x4189496f	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x41a3d53f	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x41a83a10	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x41afeedc	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x41bdc0cb	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x41df64bd	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x41f8416d	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x4205ad24	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x4213a51a	efivar_entry_set_safe
++EXPORT_SYMBOL_GPL vmlinux 0x4226fa0a	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0x42330e7b	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0x423f36e0	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x42635d55	pm_suspend_global_flags
++EXPORT_SYMBOL_GPL vmlinux 0x4265485f	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0x42695fe6	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42c989ff	iomap_atomic_prot_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x42cd3cef	acpiphp_register_attention
++EXPORT_SYMBOL_GPL vmlinux 0x42d058fb	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x42d97efa	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x42e33a9a	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x431cb182	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x432c3563	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x43619e1a	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x437ed031	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0x438d8df2	iova_cache_get
++EXPORT_SYMBOL_GPL vmlinux 0x4395953e	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x43967426	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x439d762a	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43c00ca9	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43dc65b9	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0x43f4f959	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x43f81957	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x441743ef	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x441fa356	irq_ts_save
++EXPORT_SYMBOL_GPL vmlinux 0x4422dc6b	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0x442940dd	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0x442ab6db	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x442e73f8	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x4434ff9f	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x444935a9	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x444e0453	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0x4451a3b5	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x44991c18	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x44b26c28	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44c6b737	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x44e1e9aa	balloon_stats
++EXPORT_SYMBOL_GPL vmlinux 0x44ef69ad	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x44fd8c4b	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x45042641	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x4512b086	intel_scu_devices_create
++EXPORT_SYMBOL_GPL vmlinux 0x4517648e	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0x45274b3d	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x4541fe0d	mtrr_state
++EXPORT_SYMBOL_GPL vmlinux 0x45488dd9	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x454f1cb4	efi_query_variable_store
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x457b5106	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x459177c0	pinctrl_force_default
++EXPORT_SYMBOL_GPL vmlinux 0x459cee68	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0x459d22ef	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x45b7d6a0	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45c67b43	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0x45cc1def	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x45d14bdf	hypercall_page
++EXPORT_SYMBOL_GPL vmlinux 0x45d4efb7	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x45e3a852	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0x45ee5ddd	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x4609481c	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x460f31aa	rodata_test_data
++EXPORT_SYMBOL_GPL vmlinux 0x4617ad98	acpi_os_map_iomem
++EXPORT_SYMBOL_GPL vmlinux 0x4628c42b	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x46567b99	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x46743458	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x46779876	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0x4678157d	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x46875a63	apic
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4698d804	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x46b5036f	acpi_dev_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x46dd492a	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x46ef953c	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0x46f60798	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0x46fc4384	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x472c4bc0	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x47377d5c	efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0x47430c20	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x4743126a	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x479695b2	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47c59033	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0x47d0eea2	acpi_lpat_temp_to_raw
++EXPORT_SYMBOL_GPL vmlinux 0x47de0dc7	clk_unregister_mux
++EXPORT_SYMBOL_GPL vmlinux 0x4828e77b	acpi_scan_lock_acquire
++EXPORT_SYMBOL_GPL vmlinux 0x4862bd8c	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x48682db9	perf_guest_get_msrs
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x486f9da5	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x48814d6b	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0x4886695b	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0x488ebdc9	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x48a6a2a5	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0x48b7ed77	acpi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x490a8df6	x86_platform
++EXPORT_SYMBOL_GPL vmlinux 0x492a2eee	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x4973c3d4	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0x49778b4a	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x498298ce	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0x4982a57f	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x4986c67f	pinctrl_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x4988b887	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x49b5d820	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0x49c72176	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x49d7b3eb	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x49de88ff	xen_swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4a061e5d	clkdev_create
++EXPORT_SYMBOL_GPL vmlinux 0x4a38c124	acpi_dev_add_driver_gpios
++EXPORT_SYMBOL_GPL vmlinux 0x4a3c3cf9	microcode_sanity_check
++EXPORT_SYMBOL_GPL vmlinux 0x4a420d09	acpi_bus_detach_private_data
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a569e05	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x4a62706e	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x4a682e89	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x4a68577d	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4a754bdc	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0x4a899098	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0x4aab6097	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0x4aabd88b	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4abc1390	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4ac3484f	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x4ad3d7fb	acpi_ec_remove_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4afb573b	vrtc_cmos_read
++EXPORT_SYMBOL_GPL vmlinux 0x4b5eedb2	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x4b63d3c4	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x4b6b5be4	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0x4b6d3c84	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x4b70ff51	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x4b73a89c	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0x4b756a60	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0x4b8a01ac	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x4bbf6ee1	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x4bc71d89	rio_register_scan
++EXPORT_SYMBOL_GPL vmlinux 0x4bc74077	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0x4bd2f3fe	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x4bddc39e	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x4bedcb55	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x4bf4bff1	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x4bffb3f5	pinctrl_register
++EXPORT_SYMBOL_GPL vmlinux 0x4c252d3b	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4c27954f	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0x4c2a472b	__static_cpu_has_safe
++EXPORT_SYMBOL_GPL vmlinux 0x4c44413b	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4c491cbc	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x4c4c5020	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x4c58ec18	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0x4c598f48	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c73e2ff	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4cb8e7a2	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x4cbea3eb	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x4cda17e9	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0x4ce802f7	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0x4cf8449c	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d0b3edc	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0x4d18ac1a	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x4d2afa11	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0x4d343839	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x4d3b38c7	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0x4dbc2ae8	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4dd23091	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x4ddb65c3	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4de7fe81	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e2c2dd2	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x4e2e9ca3	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x4e386d0c	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x4e38a72c	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0x4e3b237d	xenbus_alloc_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x4e3cb913	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0x4e57723d	apei_read
++EXPORT_SYMBOL_GPL vmlinux 0x4e74e625	gnttab_batch_copy
++EXPORT_SYMBOL_GPL vmlinux 0x4e7d79f1	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0x4e97a832	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0x4ea2cc35	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x4ec9cdbf	pinctrl_force_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x4ed5185b	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f002352	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0x4f27164d	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f410d19	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0x4f4a9d49	nd_device_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x4f4bf92c	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x4f5aae4c	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4f718a1d	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4f74c695	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x4f93ae3e	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x4f98a147	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x4f9cb576	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x4faebcbb	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe00822	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x50243e2f	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x5024523b	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0x5026585c	xen_irq_from_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x50496a3a	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x50594926	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0x505a4553	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x505a9f10	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0x50610dd1	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x507de8c6	add_memory
++EXPORT_SYMBOL_GPL vmlinux 0x5080c352	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5089af21	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0x508ad59d	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x5091b075	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x5091fab0	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x50a3293f	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0x50c89f23	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x50cc0d96	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50eaf01f	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0x50eb9ead	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0x50ebedd8	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x5110032c	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x511d693c	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x514e9875	divider_get_val
++EXPORT_SYMBOL_GPL vmlinux 0x516cd7c0	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0x516d03c7	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0x51719489	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5187ac4b	xen_store_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x518c2fc6	hpet_rtc_dropped_irq
++EXPORT_SYMBOL_GPL vmlinux 0x51963dc6	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0x51966b51	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0x51a70e9a	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0x51c51289	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x51ccee1e	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0x51d19125	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x51da7e44	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0x51f62673	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x52270989	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x522c1f4b	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x526280c7	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0x5272d8bc	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0x528748ca	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x5289dcef	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x52924f20	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x529c757e	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x52a41251	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x52bcfdc2	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0x52d1ad04	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x52d8c375	clk_register_divider
++EXPORT_SYMBOL_GPL vmlinux 0x52e6bf01	xen_unmap_domain_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x52f102db	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0x52f2a95a	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x5344a970	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x53743faf	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x537ae704	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0x537ed8b4	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x5399c768	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x539f157b	pci_xen_swiotlb_init_late
++EXPORT_SYMBOL_GPL vmlinux 0x53ba8619	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x53c7a426	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x53c9c6eb	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0x53e3b340	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x53e94059	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0x53f7fbf4	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x5406df8b	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x5434d36d	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x544705b6	component_add
++EXPORT_SYMBOL_GPL vmlinux 0x544b2579	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0x544c08cd	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x5453681c	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0x545b6a0b	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x54817300	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x549ecb82	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x54d468f1	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x54d586d5	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x54e4a219	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x54ed49b0	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x54fddb89	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x550ce709	pat_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x55171ffb	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x552f6af9	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5545d32e	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x554717bb	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0x5547b74a	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0x554febd4	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0x55526907	xen_features
++EXPORT_SYMBOL_GPL vmlinux 0x5554212e	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x556e4390	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x55878af5	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0x55b4afab	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0x55d72562	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x55daacca	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x55df97ba	rio_mport_send_doorbell
++EXPORT_SYMBOL_GPL vmlinux 0x55e7f8ce	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0x55edd53d	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x5613ba8f	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x56398615	mark_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x56407ffe	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x5654f836	erst_get_record_id_next
++EXPORT_SYMBOL_GPL vmlinux 0x565887b1	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x567ab7de	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x5684c59d	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x56947347	dmi_walk
++EXPORT_SYMBOL_GPL vmlinux 0x569bcb97	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x56aae6c3	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x56b63670	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x56b646cd	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56f9c3ec	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x56fc0968	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5706c4f5	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x572e2909	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x573c29e8	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x5779d445	xenbus_exists
++EXPORT_SYMBOL_GPL vmlinux 0x57881ace	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x57f2c19d	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x57f8062c	acpi_dev_resource_io
++EXPORT_SYMBOL_GPL vmlinux 0x580d2cac	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0x582e54ca	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0x583b0207	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x5841bcf3	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5843bde5	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x584b0997	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x584bec87	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x585704ab	aer_recover_queue
++EXPORT_SYMBOL_GPL vmlinux 0x586a7bc9	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x5879f7bd	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0x587bd46f	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0x58800cd3	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58d986d6	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x58e42cdc	acpi_dev_get_resources
++EXPORT_SYMBOL_GPL vmlinux 0x58fe9409	rio_inb_pwrite_handler
++EXPORT_SYMBOL_GPL vmlinux 0x590234c9	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x591d1880	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x591f7357	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x594cde67	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0x5965593f	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x59688cf7	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x59a7083b	acpi_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x59abc352	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0x59c5665b	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x59d139b2	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0x59d3e495	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x59e1b06e	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x59fbfc7e	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x5a2204df	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x5a232f41	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0x5a24463d	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0x5a2b1b67	gnttab_free_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5a3688b7	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0x5a3ba76e	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x5a54a1a6	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0x5a5f018b	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5a64929c	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x5a65c37b	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x5a68d94d	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0x5a699c6a	fpu__save
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a98d246	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x5ada06b0	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x5ae4846c	__clk_mux_determine_rate_closest
++EXPORT_SYMBOL_GPL vmlinux 0x5af03a28	gnttab_claim_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5b1899f8	free_iova
++EXPORT_SYMBOL_GPL vmlinux 0x5b1ba244	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x5b1c8fe0	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0x5b3e341c	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x5b4a9fcb	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x5b5489e1	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x5b574650	print_context_stack_bp
++EXPORT_SYMBOL_GPL vmlinux 0x5b7cc772	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0x5b8283ff	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0x5b89a506	nd_numa_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x5b975e13	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x5b9f9977	xenbus_dev_probe
++EXPORT_SYMBOL_GPL vmlinux 0x5babf842	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x5bb5cc93	rio_release_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x5bb5f353	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x5bcd6ae6	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x5bce8ca1	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5bff693b	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x5c1bed4b	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a2c56	generic_access_phys
++EXPORT_SYMBOL_GPL vmlinux 0x5c64dce8	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5c66e90c	efivar_run_worker
++EXPORT_SYMBOL_GPL vmlinux 0x5c698553	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0x5c6da976	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0x5c7f3517	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0x5c9c7eec	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x5c9c8a41	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cb549c4	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5cc9f9f9	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x5cdc87fa	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x5ced3d7b	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x5cf246f0	dummy_con
++EXPORT_SYMBOL_GPL vmlinux 0x5cf73b2a	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x5d0d68c2	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d366dec	gnttab_cancel_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0x5d5ca512	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x5d9425cb	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5dab0db1	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5dbcfa4f	boot_cpu_physical_apicid
++EXPORT_SYMBOL_GPL vmlinux 0x5dc3fd44	xen_pci_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x5de0c33a	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x5de57de4	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0x5df921e1	irq_chip_ack_parent
++EXPORT_SYMBOL_GPL vmlinux 0x5dff6fda	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x5e3740c6	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x5e4374ec	gnttab_unmap_refs
++EXPORT_SYMBOL_GPL vmlinux 0x5e492808	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x5e515be6	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0x5e516cd3	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e6886c9	set_foreign_p2m_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x5e70479d	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0x5e74c792	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0x5e75fcd9	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0x5e77ba35	do_machine_check
++EXPORT_SYMBOL_GPL vmlinux 0x5e817007	x86_hyper_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x5ea908de	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x5eb4a4a4	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x5ed5dd98	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x5ed9ea86	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x5f20865f	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x5f2a1c0d	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x5f2ae02e	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0x5f2da8c4	check_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x5f63bc87	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x5f65e8c9	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5f6be23d	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5f8ae352	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5f9323d1	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x5fc27be9	acpi_dev_irq_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5fdfa2c1	amd_pmu_enable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x5fe34b86	acpi_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x5fe93fe4	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5feda6a0	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x5ff63fcf	nvdimm_volatile_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x5ff72d3d	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0x5ffa8f96	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x5ffc7118	component_del
++EXPORT_SYMBOL_GPL vmlinux 0x60091316	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x601354d9	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x6022a99f	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x6035b78e	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x6039fc73	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x605ad133	efivars_register
++EXPORT_SYMBOL_GPL vmlinux 0x60694e53	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x607c4a9d	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0x6091797f	synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x60930d37	save_mc_for_early
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60a88b7d	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0x60bae1e4	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0x60c41d2c	xen_swiotlb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x60c6bd87	clk_debugfs_add_file
++EXPORT_SYMBOL_GPL vmlinux 0x60cd73ed	pv_apic_ops
++EXPORT_SYMBOL_GPL vmlinux 0x60cef609	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x60d44649	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x60f07053	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0x60fbb41e	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0x61025861	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0x610bfa99	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x615b4c40	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0x6166a21b	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0x616efc71	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x61766faf	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0x61897fd7	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x618adfba	of_css
++EXPORT_SYMBOL_GPL vmlinux 0x6193d5fe	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x61b0f0c9	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x61cde409	acpi_dev_resource_memory
++EXPORT_SYMBOL_GPL vmlinux 0x6211487d	rio_mport_get_efb
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x623803c8	hest_disable
++EXPORT_SYMBOL_GPL vmlinux 0x6277f8eb	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x62a1c981	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x62a7f33a	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x62ad4d30	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0x62af7003	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x62c11598	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x62d3d7f1	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0x62e8b9f9	efivar_entry_set_get_size
++EXPORT_SYMBOL_GPL vmlinux 0x630e84e3	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x63150e06	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x6335285f	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x635ec980	apei_exec_post_unmap_gars
++EXPORT_SYMBOL_GPL vmlinux 0x637505c9	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x63987f16	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x63a2505c	clk_register_gpio_gate
++EXPORT_SYMBOL_GPL vmlinux 0x63c58328	clear_foreign_p2m_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x63e17b86	divider_recalc_rate
++EXPORT_SYMBOL_GPL vmlinux 0x63e2d25d	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0x63ea80b3	cper_mem_err_type_str
++EXPORT_SYMBOL_GPL vmlinux 0x63ee1a7c	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x6412cc45	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x641a0291	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x64256424	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0x64260749	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0x642c9caa	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0x642d5f8d	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x64318593	acpi_dev_filter_resource_type
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x64486ddd	xenbus_dev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x645b834f	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0x64737e49	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x648fa0bd	put_device
++EXPORT_SYMBOL_GPL vmlinux 0x64a70cfc	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x64b7069e	apei_mce_report_mem_error
++EXPORT_SYMBOL_GPL vmlinux 0x64e24a5e	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x64e2f179	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0x64ea14e5	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6527a231	dbgp_external_startup
++EXPORT_SYMBOL_GPL vmlinux 0x6536953b	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0x653cb02d	intel_msic_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x654721c2	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0x65650582	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x65690cde	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0x656aefe4	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x656fa969	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0x6571945c	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x658310de	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x658c8186	amd_get_nb_id
++EXPORT_SYMBOL_GPL vmlinux 0x659b0240	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x65ac1989	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65f8573c	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x6614c4ba	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x6623a53d	rio_mport_get_physefb
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x6646c841	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x66476e64	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0x664f64f1	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x665ecab0	pv_time_ops
++EXPORT_SYMBOL_GPL vmlinux 0x66757659	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x667d5841	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x6680cb0d	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0x6682b6a5	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x668b3811	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0x66915d89	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x66aa999d	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0x66bc7593	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0x66bfcec1	register_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x66c0a6a1	devm_acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x6739a503	balloon_set_new_target
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x67716bd4	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x67988a60	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x679afe0a	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0x67a156d0	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0x67a44563	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x67c39672	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0x67d60fb5	pinctrl_utils_add_map_configs
++EXPORT_SYMBOL_GPL vmlinux 0x67e3df32	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0x67ebe13d	md_run
++EXPORT_SYMBOL_GPL vmlinux 0x680342a3	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0x6822ee2b	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0x682e6bb0	hugetlb_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x6834ac43	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x6839d35a	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0x683c85ad	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0x68484c13	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x687e685f	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0x68956406	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x68a7a78e	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0x68c162d8	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0x68c9c629	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0x68e6576f	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x69037346	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x693b9234	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0x69445484	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x6945725e	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0x69659e65	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0x696bfed6	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0x697c422c	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x6999093f	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x69cb33e3	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0x6a052adb	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0x6a0b308a	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a1f50c8	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0x6a2a6a19	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x6a335d1d	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a50e925	__clk_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a65f151	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x6a823c87	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a893921	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0x6a89a5fd	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x6ab1b8bb	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x6acacd90	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6acad21f	acpi_get_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0x6ad50e2e	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x6ae5d718	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x6aeeca0f	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x6b072e85	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6b0dc565	xen_set_irq_priority
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b4cf9dc	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6b672044	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x6b69e4e3	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0x6b6b3123	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x6b7a22ec	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6bd373ed	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x6beff082	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x6bf1b90d	dmi_memdev_name
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c0968a8	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6c1251fd	apei_exec_read_register
++EXPORT_SYMBOL_GPL vmlinux 0x6c209eab	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x6c267d54	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x6c389761	acpi_bus_get_private_data
++EXPORT_SYMBOL_GPL vmlinux 0x6c3d6ac8	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c56c109	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x6c60d14e	rio_release_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x6c6538df	init_iova_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6c655913	register_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6c669537	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0x6c6ab823	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0x6c6c8674	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6cd2eb6c	acpi_node_get_property_reference
++EXPORT_SYMBOL_GPL vmlinux 0x6cdadd9b	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x6cdec16f	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x6ce3f30a	print_context_stack
++EXPORT_SYMBOL_GPL vmlinux 0x6cf33821	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x6cf56ab3	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0x6cf6a5bf	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d4e62b3	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6d65bc66	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0x6d6afacf	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0x6d9212db	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6dac0acb	hugetlb_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x6ddae823	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0x6ddc2949	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x6de789c5	xen_remap_domain_gfn_array
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e0b271e	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x6e248e83	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x6e252602	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x6e35ff9b	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0x6e51afc8	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x6e58ddf0	gnttab_end_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x6e64b90f	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0x6e6a0c76	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0x6e782c23	iomap_create_wc
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e7febbc	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e80475f	to_nd_blk_region
++EXPORT_SYMBOL_GPL vmlinux 0x6e80cd5b	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0x6e85b00b	local_touch_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6ea81c0c	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6eb01618	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x6eb50337	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0x6eb56ced	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x6eb879c6	acpi_pci_find_root
++EXPORT_SYMBOL_GPL vmlinux 0x6ec9e3e8	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0x6ecc20c2	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f2277b9	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x6f402ba6	acpi_dev_resource_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x6f50c5eb	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0x6f577ee2	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x6f60ecfa	usb_acpi_power_manageable
++EXPORT_SYMBOL_GPL vmlinux 0x6f6a8f68	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x6f71adbd	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6fb11a58	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0x6fc259a5	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6fe5318d	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x6ff72da4	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x70201233	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x702fcb07	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x702ffb9a	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0x706b5285	dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0x70705c1e	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x707f40f3	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x708d24e4	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x709e66f2	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70cce8d0	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70d499ee	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0x70f5c40b	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x71282eb4	nd_cmd_in_size
++EXPORT_SYMBOL_GPL vmlinux 0x712a81b9	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7141464c	dax_clear_blocks
++EXPORT_SYMBOL_GPL vmlinux 0x714caa7c	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x7150137a	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x7157e281	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x716b461c	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x716e73b3	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x717c0a03	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0x719311b8	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x7195bd91	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x719e17ff	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x71a5f0e1	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0x71bfa0b1	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71ef0517	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x721a2387	usb_acpi_set_power_state
++EXPORT_SYMBOL_GPL vmlinux 0x72515d5a	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x725cdc01	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x728b49f1	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0x72acd05f	acpi_driver_match_device
++EXPORT_SYMBOL_GPL vmlinux 0x72cf714d	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x72ea884e	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x73013896	xenbus_printf
++EXPORT_SYMBOL_GPL vmlinux 0x731dba7a	xen_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0x73481239	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0x734ab4d3	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0x734f0276	__tracepoint_add_device_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x734f2f4f	acpi_dev_gpio_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0x7351580b	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x738fd248	intel_msic_reg_update
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73b98231	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73ced25f	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x73d3efbd	pinctrl_get_group_pins
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73ddbe07	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x74097414	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0x74243cf2	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0x7429ba2a	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x74457e56	apei_resources_fini
++EXPORT_SYMBOL_GPL vmlinux 0x744e3a9c	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0x7452adff	user_return_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7468b74e	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0x747306f4	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x7476946a	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0x747dc7a2	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0x747f70f7	acpi_bus_trim
++EXPORT_SYMBOL_GPL vmlinux 0x74829f22	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x74910f8c	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x74a2b616	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74b9f79b	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74c011c0	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x74c03311	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x74c08941	kvm_async_pf_task_wake
++EXPORT_SYMBOL_GPL vmlinux 0x74c58efb	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0x74d007c2	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x74d3d5cc	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0x74d4e128	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x74deb10c	used_vectors
++EXPORT_SYMBOL_GPL vmlinux 0x74fab285	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x750608e6	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x750786f1	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x75189813	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0x751b3fd1	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0x7521afb6	leave_mm
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x752d9fd9	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x753a7087	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x7562de64	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0x75899ad5	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x75b057bc	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0x75b23a94	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x75b63089	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x75c2b9f1	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75d5f1c0	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0x75e0eb99	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x7609c8c8	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x761905c1	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0x7632b8f8	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0x7646a633	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0x76597668	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0x7677d668	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x768d7d92	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x7693c646	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0x76b02fe7	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x76cdefe3	rio_request_mport_dma
++EXPORT_SYMBOL_GPL vmlinux 0x76d9b876	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0x76df2183	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x76e3bce6	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0x770cf981	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x7712771a	unbind_from_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7716fc28	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x77274d72	ata_acpi_gtm
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x773c8ba2	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x77427e90	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0x7749f87d	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x7757b51a	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x775a6ef5	kvm_read_and_reset_pf_reason
++EXPORT_SYMBOL_GPL vmlinux 0x778593d5	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x77861d63	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0x778b675a	pmc_atom_write
++EXPORT_SYMBOL_GPL vmlinux 0x7790adc0	aout_dump_debugregs
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x77d1dee2	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0x77d2793e	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0x77eb63c6	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x77fd387d	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x78151326	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x7828751d	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x782adb74	hpet_rtc_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x783496ba	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0x78575bee	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x785cf1c3	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x7874b5ec	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x788def07	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0x78915e3c	acpi_device_update_power
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78e16ecb	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x78e285a6	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0x78e84890	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x78eaaab0	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x79005563	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x7908f381	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0x793187e8	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x7957f43e	nvdimm_bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x796bcefe	pinctrl_dev_get_devname
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x798f0114	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0x7991fd8d	crash_vmclear_loaded_vmcss
++EXPORT_SYMBOL_GPL vmlinux 0x7993b4ae	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x7996d1fa	xenbus_read_otherend_details
++EXPORT_SYMBOL_GPL vmlinux 0x7998bd4d	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x79a3c602	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x79a6ec76	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x79a71c48	kernel_stack_pointer
++EXPORT_SYMBOL_GPL vmlinux 0x79af53fb	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0x79b572a7	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x79dc2b5b	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x79e69460	intel_iommu_gfx_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x79effe3b	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0x79f2e354	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7a093833	set_memory_array_wt
++EXPORT_SYMBOL_GPL vmlinux 0x7a2dcd1f	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a319404	clk_register_fixed_rate
++EXPORT_SYMBOL_GPL vmlinux 0x7a4caf21	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0x7a6a48c6	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7a6bdde1	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0x7a738335	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x7a836e59	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x7a940304	nd_cmd_out_size
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7a98496c	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x7a9d5097	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x7ab3ca18	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x7ab4b49a	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0x7abb0cc4	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0x7ac0861b	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x7ac8e5b0	acpi_gsi_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7aefed21	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x7b0affe9	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1a5cdb	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0x7b1a8987	default_iommu_map_sg
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d7087	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x7b202401	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x7b2ead11	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0x7b3926c5	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x7b3ab781	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x7b45dfe2	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x7b4861a3	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0x7b52db44	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7b549f26	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7b5f5560	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7b6388be	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0x7b7b9892	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x7b89b899	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0x7b90d1a9	bind_virq_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7bd8ab03	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x7bff4171	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x7c3f1830	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7c526b06	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x7c5f8ad8	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x7c968c71	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x7c9a7371	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x7cae3568	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x7cc79872	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7cde5320	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7d00c65b	nd_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x7d03ab23	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0x7d170199	acpi_subsys_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x7d2f929d	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x7d38af40	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d5bbdba	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x7d79f647	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x7d8730e0	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x7d9785ca	devm_pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0x7d9c2402	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7dc02e02	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7de65a03	acpi_lpat_free_conversion_table
++EXPORT_SYMBOL_GPL vmlinux 0x7e1d4050	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0x7e202390	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0x7e28a395	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x7e50800e	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x7e5377d3	rio_request_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x7e58d18a	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e6a086d	dax_truncate_page
++EXPORT_SYMBOL_GPL vmlinux 0x7e6f8bff	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7ea942d7	restore_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x7ec6ba16	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0x7ecbea3f	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x7ed0dd61	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0x7eefb4bc	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7f175b79	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x7f1bb6da	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f2ba015	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0x7f32287d	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0x7f369586	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x7f36fa30	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x7f3ec087	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7f49231b	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0x7f5516ec	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0x7f56da1d	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0x7f76c044	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7f8c05ea	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x7f99b200	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0x7fab3963	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7fd1d020	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0x800a21f8	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x800ef339	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x801bf6b8	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x804a4d97	pinctrl_pm_select_sleep_state
++EXPORT_SYMBOL_GPL vmlinux 0x8054d0ff	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x8087ea40	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0x8088a3e6	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x809529fd	alloc_iova
++EXPORT_SYMBOL_GPL vmlinux 0x80b6f59d	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0x80b8e8f3	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80ef5c01	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x80f8589f	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0x80f90934	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0x81109e3b	rio_mport_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x8137e01a	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x8141d33b	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x815588a6	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x816fa3db	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0x8171b6c7	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0x81742f74	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0x819a0d8b	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x81aa5e16	__online_page_increment_counters
++EXPORT_SYMBOL_GPL vmlinux 0x81ce4ca3	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x81d525f6	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x81d702fc	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x81d832c5	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0x820e4f02	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0x822ad4c7	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0x828c8376	pinctrl_add_gpio_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x82978442	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x829ab4c4	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0x82ce18a1	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82dbec19	erst_write
++EXPORT_SYMBOL_GPL vmlinux 0x82de236b	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x8349d798	xen_swiotlb_set_dma_mask
++EXPORT_SYMBOL_GPL vmlinux 0x834c4ee0	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x835fb384	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x836666ce	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0x83880269	gpiochip_add_pin_range
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x8395b14d	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x83ba5fbb	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x83d4fff9	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x83d8c217	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x84060df9	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x84089092	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x840cb91b	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0x840de5be	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0x842f3a92	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x843d70ef	acpi_is_root_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x845289b1	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x845da564	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x8462bdcf	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x846c4778	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0x84af9f7c	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x84b48201	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x84d5e9be	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0x84e839a9	acpi_os_unmap_iomem
++EXPORT_SYMBOL_GPL vmlinux 0x84f06176	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x84f3e39e	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x8506baa8	clk_unregister_gate
++EXPORT_SYMBOL_GPL vmlinux 0x850a6e78	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0x850aa5ff	xenbus_unmap_ring_vfree
++EXPORT_SYMBOL_GPL vmlinux 0x850df8b9	clk_divider_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x852d898e	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x853be66a	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0x8574ca6c	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x858737ec	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x85942773	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x859e9910	acpiphp_unregister_attention
++EXPORT_SYMBOL_GPL vmlinux 0x85b36e69	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85cb2c45	xen_has_pv_devices
++EXPORT_SYMBOL_GPL vmlinux 0x85d7edfd	hpet_set_periodic_freq
++EXPORT_SYMBOL_GPL vmlinux 0x85e435b1	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x85e87439	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0x8606150f	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x860ef4d7	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x86186ae0	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x8644ae91	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0x864b2081	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x8652110e	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0x8654be58	hv_remove_vmbus_irq
++EXPORT_SYMBOL_GPL vmlinux 0x86623fd7	notify_remote_via_irq
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x867a1f61	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x86819bc6	irq_ts_restore
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x86931fa6	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x86a1f6e1	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x86a51007	gnttab_end_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x86c05747	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x86ce43e6	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x86faddca	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x870e16b7	xen_test_irq_shared
++EXPORT_SYMBOL_GPL vmlinux 0x87148b0b	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x873188b9	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x87338d7d	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x8759ac8e	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x87609ae3	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x878fa01d	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x87cba151	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8800449a	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x88136838	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8829314c	rio_request_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x8831f8b1	kmap_atomic_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x883631c7	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x88377fe8	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x883c2740	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x883e6999	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0x884acfed	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x88598a00	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x889965bd	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x88a9a411	clk_fractional_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88aef35f	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0x88b14fc7	xenbus_watch_pathfmt
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88ba1c93	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x88c3308b	agp_remove_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x8902641c	xen_xlate_unmap_gfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x891a5a7f	gnttab_max_grant_frames
++EXPORT_SYMBOL_GPL vmlinux 0x891d1b26	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x892757f1	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x8948b25e	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0x894f6a0f	clk_hw_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x8956aeae	apei_exec_ctx_init
++EXPORT_SYMBOL_GPL vmlinux 0x89920570	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x89b23532	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0x89b3c503	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89dffc67	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0x89f6bd87	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x8a08c1a6	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x8a14687e	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x8a1c641e	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0x8a559846	gnttab_setup_auto_xlat_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a5f86ce	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x8a78989f	irq_from_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x8a7cb9c4	platform_thermal_package_rate_control
++EXPORT_SYMBOL_GPL vmlinux 0x8a82f318	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x8a9d6752	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8adfa98c	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8ae9bfc2	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x8aef463d	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0x8b04668e	bind_interdomain_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x8b094aae	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x8b149c36	clk_is_match
++EXPORT_SYMBOL_GPL vmlinux 0x8b208a09	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x8b39f108	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8b91f7a7	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x8b9c4495	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x8b9e2f8b	apei_get_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x8ba3dd1e	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0x8baf62e7	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0x8bb6908e	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x8bb947e8	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0x8bc41382	fpu__restore
++EXPORT_SYMBOL_GPL vmlinux 0x8be5bad0	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x8bee468f	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c06a108	xenbus_transaction_start
++EXPORT_SYMBOL_GPL vmlinux 0x8c0e6f81	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x8c31c83d	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c88700b	nvdimm_bus_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x8c9d1661	arch_phys_wc_index
++EXPORT_SYMBOL_GPL vmlinux 0x8ca97a33	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8cd9f935	setup_APIC_eilvt
++EXPORT_SYMBOL_GPL vmlinux 0x8ce677ab	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0x8cf3f3eb	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d2ca103	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x8d3b091c	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x8d522714	__rcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8d58ea2f	isa_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8d6e4cd6	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x8d796fb3	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x8d888b87	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x8d91d882	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x8dcae1ae	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8dd2eedd	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0x8df7d6d1	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x8e1c5f7f	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e374355	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x8e5734a7	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0x8e7dd186	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x8eadeb7d	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8ee2ea2b	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x8ef10d67	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f34faec	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x8f3e6f81	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x8f463be4	acpi_subsys_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8f5b6f98	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f6f888f	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x8fc8a2f7	__nvdimm_bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x8fe351d9	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0x8feed925	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x8ffbd14c	irqd_cfg
++EXPORT_SYMBOL_GPL vmlinux 0x9009602a	acpi_bus_get_ejd
++EXPORT_SYMBOL_GPL vmlinux 0x90125184	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0x901cad95	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0x9022d5bc	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x90336d03	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x903bb65b	acpi_dev_resource_ext_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x9047c11a	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x9069e663	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x90739f7b	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0x907ed819	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0x907eece1	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0x909ad507	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90b5c7da	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x90de0452	platform_thermal_package_notify
++EXPORT_SYMBOL_GPL vmlinux 0x90e0a6e1	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x90e6f074	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0x9130efc5	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x9133b97e	nvdimm_bus_check_dimm_count
++EXPORT_SYMBOL_GPL vmlinux 0x91548a3e	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0x915d27a3	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x916773ba	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0x916cdf51	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0x9182fdb8	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x91933cf2	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x91b25186	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x91c159e7	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91cdc4a0	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x91d7807f	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x91de4dcd	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x91ef4444	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0x920ba18c	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x920c33d9	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0x923fa9a8	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x924929b8	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x924d50c7	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x92625b26	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0x9277ba55	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x928e947d	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0x9293c45a	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x9298086f	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0x92b16145	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x92b57248	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x92c5cfa4	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92de65bb	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x92e18acd	rio_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0x92f1db7e	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0x92f6e4b6	__ktime_divns
++EXPORT_SYMBOL_GPL vmlinux 0x9307a711	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x930f5f14	acpi_dev_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x9312d80e	evtchn_put
++EXPORT_SYMBOL_GPL vmlinux 0x9317360d	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x931d6540	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x935519ce	clk_multiplier_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9364a3b2	xen_swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x9380766a	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x93b67114	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0x93bf2fcd	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x93c8cecb	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x93f8d9e8	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x942e8c16	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x9432b036	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x943fc708	xen_setup_shutdown_event
++EXPORT_SYMBOL_GPL vmlinux 0x945afd2e	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0x945b0a66	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0x945cca62	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x945edcb4	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x948fa19f	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0x94abb745	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0x94c318be	apei_exec_collect_resources
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x950bb621	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x95270c0c	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x95381b1d	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x957ba439	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x9584ef08	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x958a3feb	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x95a06339	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95bcfdbd	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x96046076	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x962275e7	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x96471589	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x9647a408	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0x964add15	xenbus_scanf
++EXPORT_SYMBOL_GPL vmlinux 0x964b4162	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x965688b0	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0x96598ced	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0x96805dc2	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x96b3d542	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x96b80fa7	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x96b9dbb6	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x96c35b87	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0x96d93305	xenbus_match
++EXPORT_SYMBOL_GPL vmlinux 0x96dc40d1	__clk_mux_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x96e1abc5	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x96ec64a8	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x96f91d52	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0x970ab832	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x97296e2e	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x973ab8ad	cper_estatus_print
++EXPORT_SYMBOL_GPL vmlinux 0x973cde56	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x9769b7c4	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x9782d86c	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x97843d97	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x978c2b18	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x97af31a4	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x97b71bec	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x97df42f8	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0x97e41db1	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0x98067590	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x980c63de	acpi_subsys_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x98468bd9	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x984bc32e	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9852e685	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9894951e	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x989eb047	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x98ca73a5	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0x98e3cf25	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x99088155	smp_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9909f234	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0x9914ca55	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x991e65a9	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x99336e13	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0x994f5da9	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0x99535f1b	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x99576d8a	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x99694e65	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x996b96f2	ata_acpi_cbl_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x9973add9	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x99a6663d	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x99a9ff9a	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x99b182c7	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99ce0592	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x99dc903e	rio_register_mport
++EXPORT_SYMBOL_GPL vmlinux 0x99e00bf7	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0x99fa4c43	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x9a080881	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0x9a10da89	__tracepoint_extlog_mem_event
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a127dc3	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x9a173773	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x9a1edf9a	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0x9a2d10c8	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9a92866f	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9a92b43f	rio_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x9aa5fe9b	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x9aafb2b7	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0x9ab13028	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9ad73dfc	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9afdfb43	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x9b09e498	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0x9b25030f	xen_swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x9b473e01	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0x9b4da354	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x9b51eecc	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x9b5240fb	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x9b720312	acpi_target_system_state
++EXPORT_SYMBOL_GPL vmlinux 0x9b7e554f	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x9b888b01	pinctrl_dev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x9b8d3ec1	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x9b9f3648	pcibios_scan_specific_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9ba926fe	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0x9bad683f	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9bd72b78	apei_write
++EXPORT_SYMBOL_GPL vmlinux 0x9be233d5	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x9be3a239	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c09dc5c	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x9c10b6d2	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9c12fbde	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x9c1b4234	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x9c1ef578	rio_dma_prep_slave_sg
++EXPORT_SYMBOL_GPL vmlinux 0x9c265dd9	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x9c26d82a	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x9c2ba736	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x9c2e4b66	acpi_unregister_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x9c347c07	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0x9c3ff0d2	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0x9c462261	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0x9c69ad6c	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x9c850a57	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x9c87e9a8	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x9ca2a7c0	xenbus_dev_is_online
++EXPORT_SYMBOL_GPL vmlinux 0x9cb297cf	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x9cb7bb39	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cd9f36d	acpi_subsys_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x9cff4a46	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0x9d06688b	register_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x9d1cdc0d	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x9d21b269	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x9d2e45bc	rio_lock_device
++EXPORT_SYMBOL_GPL vmlinux 0x9d310893	nvdimm_create
++EXPORT_SYMBOL_GPL vmlinux 0x9d374f3f	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x9d3850e1	gnttab_alloc_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x9d452f87	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x9d62c898	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x9d67eaa3	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9d8331c0	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9dbc0b17	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x9dc7262b	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0x9de9e1e5	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0x9dfdf722	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0x9e089ee2	clk_register_fractional_divider
++EXPORT_SYMBOL_GPL vmlinux 0x9e365915	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e593bff	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0x9ebff902	start_thread
++EXPORT_SYMBOL_GPL vmlinux 0x9ec261dd	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0x9ec31990	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ee0f933	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0x9f01069e	is_dock_device
++EXPORT_SYMBOL_GPL vmlinux 0x9f675415	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x9f681a1d	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x9fad2bb5	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0x9fb6e64c	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fdd3751	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0x9fe25e30	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9fee92c1	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x9ffff24f	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0xa00ec0d0	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0xa0208e02	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xa0268ba6	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0xa04613d8	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0xa04a12df	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0xa06c9ffa	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0xa0703264	xen_swiotlb_sync_single_for_device
++EXPORT_SYMBOL_GPL vmlinux 0xa073d0ef	rio_unregister_scan
++EXPORT_SYMBOL_GPL vmlinux 0xa074f151	intel_scu_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xa08e3729	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0xa0c2f0c9	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xa11216be	xen_store_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0xa11b55b2	xen_start_info
++EXPORT_SYMBOL_GPL vmlinux 0xa14a1817	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0xa156a1f2	erst_get_record_id_end
++EXPORT_SYMBOL_GPL vmlinux 0xa1612cdf	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa19ad23d	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0xa1a9c311	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xa1ac2ec4	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa1d0218c	clk_hw_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0xa1ddc4e2	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0xa1e635a5	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0xa1f79553	xen_create_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xa1fc789e	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xa202d5aa	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0xa2282b0b	user_read
++EXPORT_SYMBOL_GPL vmlinux 0xa2335c37	pinctrl_utils_add_map_mux
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa270eefc	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xa29e59b9	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xa2b9c993	clk_register_fixed_factor
++EXPORT_SYMBOL_GPL vmlinux 0xa2ba051d	rio_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2c0f1f3	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0xa2c7be24	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0xa2d4a00b	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0xa2d82abb	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0xa2e4d38b	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0xa2ec45df	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0xa2f02fd4	acpi_bind_one
++EXPORT_SYMBOL_GPL vmlinux 0xa3003eac	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa32e6fe4	rio_mport_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xa32f60d9	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xa33143e0	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0xa33d8eae	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0xa353fffc	xenbus_rm
++EXPORT_SYMBOL_GPL vmlinux 0xa35642a7	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0xa3589d02	nd_blk_region_to_dimm
++EXPORT_SYMBOL_GPL vmlinux 0xa35b8100	iommu_get_domain_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa38d3e5c	__xenbus_register_backend
++EXPORT_SYMBOL_GPL vmlinux 0xa39f2647	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3be299f	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa3e58789	efivar_validate
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa42b53b5	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0xa4353ed3	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xa448749f	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0xa452c297	hpet_mask_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa452f2a4	xen_pirq_from_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa466de38	acpi_processor_ffh_cstate_enter
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa48620b2	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xa48a1a6c	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa4a71c35	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0xa4b058d7	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa4d59eac	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa4d9e374	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xa4db32b6	devm_acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xa4e65c54	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0xa4f9072f	nd_mapping_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xa4fb3089	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xa4fde321	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0xa5109640	efivars_kobject
++EXPORT_SYMBOL_GPL vmlinux 0xa52d2085	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa53b241e	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0xa54f9da8	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0xa5a1e594	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xa5a5603e	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0xa5db738d	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0xa5dfd322	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5f94df5	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xa60c7f79	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa62892c6	efivar_sysfs_list
++EXPORT_SYMBOL_GPL vmlinux 0xa6620bfe	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa7454122	rio_route_clr_table
++EXPORT_SYMBOL_GPL vmlinux 0xa7701a65	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0xa771bf98	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0xa78b710e	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xa799b609	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0xa7afa64e	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0xa7b74e43	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0xa7e3fff7	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa7e5c066	rio_request_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xa7ec957f	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0xa7f09630	nd_region_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xa7fae3cb	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xa801b359	efivar_entry_iter_begin
++EXPORT_SYMBOL_GPL vmlinux 0xa81bd685	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xa84c38d9	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa88c0366	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0xa89baeb0	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8b798b3	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa8c2eb1a	pinctrl_find_gpio_range_from_pin
++EXPORT_SYMBOL_GPL vmlinux 0xa8d80ab2	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xa90497c4	acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xa9078e1d	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa911b4e9	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xa9126bff	hpet_set_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa9143342	find_iova
++EXPORT_SYMBOL_GPL vmlinux 0xa91f0554	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0xa9218877	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa94430bb	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0xa9648a87	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xa973481a	pinctrl_select_state
++EXPORT_SYMBOL_GPL vmlinux 0xa979a04e	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0xa98f9974	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xa993926c	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xa9b5e470	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa9c41064	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xa9d53d01	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9e87c68	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0xaa0ce2e5	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0xaa14f2ae	xenbus_probe_devices
++EXPORT_SYMBOL_GPL vmlinux 0xaa15f525	gnttab_foreach_grant_in_range
++EXPORT_SYMBOL_GPL vmlinux 0xaa2883ef	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xaa2a72bf	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0xaa3fed0c	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0xaa64891b	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0xaa6b130f	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0xaa8833b2	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xaa8e6735	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaaa9e0a6	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0xaaaadf79	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0xaabcc740	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0xaacb5efb	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xaae0a711	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0xaae6b37d	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0xaaf93177	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xaafe8ad1	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xab01acbe	gnttab_request_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0xab132bc3	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xab1e0e93	hv_setup_kexec_handler
++EXPORT_SYMBOL_GPL vmlinux 0xab1e18e2	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xab29ad96	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0xab2fc6cd	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0xab3cbe7e	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0xab585c21	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab652e56	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab78b7e8	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0xab79f164	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0xab945a16	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xab9e45b9	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0xaba4c807	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabe36beb	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0xabe9181b	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0xabf7ffae	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0xabfbef82	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xac00c4fe	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0xac1d8384	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0xac205c9f	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xac2ba4f5	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xac39616d	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0xac665888	clk_hw_get_parent_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xac7a4b44	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0xac90ee44	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xac9ce195	kvm_async_pf_task_wait
++EXPORT_SYMBOL_GPL vmlinux 0xacafa8e7	vector_used_by_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xacb2915b	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0xacd8f65a	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xad0aff93	clk_gpio_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xad12cb82	rio_mport_chk_dev_access
++EXPORT_SYMBOL_GPL vmlinux 0xad2045a1	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0xad3a8df1	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0xad3ba0da	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0xad4e00d0	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0xad4e1032	xen_swiotlb_map_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xad629773	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0xad8098fe	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0xad8d8ab0	xen_physdev_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0xada2e6e0	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0xada50f7d	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadd14114	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0xadd82be0	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xadf031c2	gpiochip_add_pingroup_range
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xae03e49f	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xae29e0b6	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae6d856e	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae81d0f2	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0xae838882	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0xae8737a3	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0xae9348b7	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0xaeab8935	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0xaec80c0f	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0xaee1046a	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0xaf052966	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0xaf0b72e4	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0xaf1d8cfc	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xaf32d743	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0xaf3edfa7	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xaf4cd6d3	acpi_os_map_memory
++EXPORT_SYMBOL_GPL vmlinux 0xaf5d1007	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0xaf635800	rio_request_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xaf6fddfd	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0xaf9439db	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xafcb13c1	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0xafcbdacd	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0xafda4bb9	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xafdc265a	device_register
++EXPORT_SYMBOL_GPL vmlinux 0xafddb4a0	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0xb00b0153	acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xb02a4a2f	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0xb02ac411	register_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb0500c68	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0xb055bf16	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0xb0663bd1	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xb077e70a	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xb08616b2	efivar_entry_remove
++EXPORT_SYMBOL_GPL vmlinux 0xb0a03686	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0bce4f0	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xb0c50ac2	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0xb118bddc	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0xb137fc8b	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb150da09	pin_is_valid
++EXPORT_SYMBOL_GPL vmlinux 0xb15cd9f1	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xb172ffac	efivars_sysfs_init
++EXPORT_SYMBOL_GPL vmlinux 0xb173b650	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb1875a5c	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xb190d8f0	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xb1928dda	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xb1a5f2fe	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1c1fcb8	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xb1cbf19f	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0xb1d5cd99	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1e5f63a	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0xb1f8b238	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0xb1fa7c6d	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xb1ffe00e	acpi_subsys_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb23593f5	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xb24586ba	__tracepoint_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xb25675d3	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0xb2576433	xenbus_dev_fatal
++EXPORT_SYMBOL_GPL vmlinux 0xb26a1add	elfcorehdr_addr
++EXPORT_SYMBOL_GPL vmlinux 0xb26ba4d6	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xb286e136	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0xb29f097a	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0xb2c7c08b	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0xb2ce8916	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0xb2d8c231	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb2ffd242	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xb308c62d	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb30e8963	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0xb3253ed9	hpet_rtc_timer_init
++EXPORT_SYMBOL_GPL vmlinux 0xb3482856	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xb35934b9	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0xb3d1154e	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0xb3d386cc	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xb3d8f7b5	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0xb3f7b062	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0xb40d8d8f	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xb42b9c79	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xb453e510	acpi_unbind_one
++EXPORT_SYMBOL_GPL vmlinux 0xb4557e67	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0xb47e4a12	to_nd_region
++EXPORT_SYMBOL_GPL vmlinux 0xb48ccc6b	device_create
++EXPORT_SYMBOL_GPL vmlinux 0xb491cafe	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb4945cbe	dmi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xb49c1caf	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xb4aae4da	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4be311f	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0xb4ca78a1	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0xb4cd0f69	xen_swiotlb_dma_mapping_error
++EXPORT_SYMBOL_GPL vmlinux 0xb4d94e8d	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0xb4d9bdcf	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0xb4dc214d	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb4e14553	gnttab_query_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb4e52ef8	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb4ef2a99	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0xb51545d3	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb53e92a9	nvdimm_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xb5492629	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0xb54d40db	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xb55016ce	xenbus_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb57ce96e	rio_local_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xb57da8ae	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb5934d14	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5bb6a80	rio_release_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xb5d2b335	clk_gpio_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb5e65982	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xb5e896fb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb605dbc5	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0xb606d593	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0xb617ab18	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0xb6230f1f	gnttab_grant_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb640438a	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0xb663789d	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xb66421b2	acpi_str_to_uuid
++EXPORT_SYMBOL_GPL vmlinux 0xb66f4013	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6bc49a9	__supported_pte_mask
++EXPORT_SYMBOL_GPL vmlinux 0xb6c307d1	xen_swiotlb_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0xb6d904d1	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0xb6e6d99d	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb6e963c7	gpiochip_remove_pin_ranges
++EXPORT_SYMBOL_GPL vmlinux 0xb6fc4e61	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb711d130	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xb718f2f9	sfi_table_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb72702e4	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0xb7329c06	clk_set_phase
++EXPORT_SYMBOL_GPL vmlinux 0xb736916c	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0xb760ffaa	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0xb7799081	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb79a56f4	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0xb7c7f234	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0xb7d6634f	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0xb7d7c12e	hpet_set_alarm_time
++EXPORT_SYMBOL_GPL vmlinux 0xb7e1f7c6	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb7fedaf3	acpi_initialize_hp_context
++EXPORT_SYMBOL_GPL vmlinux 0xb80e79e7	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0xb8136026	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xb81cdb73	user_update
++EXPORT_SYMBOL_GPL vmlinux 0xb8382526	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xb8523ad3	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0xb85e08a2	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb8b2b1f7	mce_register_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8d3c197	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb9176155	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0xb92427b4	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb92feb10	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xb966cef5	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0xb9730627	gdt_page
++EXPORT_SYMBOL_GPL vmlinux 0xb99ac224	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0xb99b314c	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0xb99d5837	xenbus_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9b02462	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9d83633	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0xb9df5c89	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0xb9f85997	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0xba1f11d7	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba44526f	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xba8929ea	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xba94c685	cper_estatus_check
++EXPORT_SYMBOL_GPL vmlinux 0xbaa59238	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0xbaaee0b4	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbac53254	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xbadbd4b8	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0xbade0249	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0xbaf6d630	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb58b814	iomap_free
++EXPORT_SYMBOL_GPL vmlinux 0xbb612f8a	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xbb7cf9cb	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0xbbb98859	edid_info
++EXPORT_SYMBOL_GPL vmlinux 0xbbcbe5c7	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xbbd4f657	xen_pcpu_id
++EXPORT_SYMBOL_GPL vmlinux 0xbbde6ed2	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0xbbf211db	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0xbc028df6	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xbc06bafd	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xbc12f372	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0xbc2bc46c	__rio_local_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xbc4217d4	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0xbc42721f	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc9938cc	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0xbc995353	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0xbca0201a	sfi_mrtc_array
++EXPORT_SYMBOL_GPL vmlinux 0xbca537d0	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcb838a1	amd_flush_garts
++EXPORT_SYMBOL_GPL vmlinux 0xbcb9e2cc	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcd44dad	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbce2adff	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0xbcea370e	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xbd2bb45c	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0xbd2e1265	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0xbd2fea07	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd5e7828	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0xbd64679c	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xbd727d6e	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0xbd7dc938	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xbd86b127	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xbd8d80f8	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0xbd9062ab	pinctrl_pm_select_default_state
++EXPORT_SYMBOL_GPL vmlinux 0xbda682ca	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbdc84c7e	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbdd5f10f	apei_hest_parse
++EXPORT_SYMBOL_GPL vmlinux 0xbdd6a77a	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0xbdfb69a3	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0xbdfe34ca	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe3e9176	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0xbe42c8db	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe83c095	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbeb86170	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf052bef	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0xbf065b48	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xbf088126	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xbf10959a	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0xbf17fb34	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0xbf1afc90	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xbf1d869b	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0xbf241433	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0xbf395a7e	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0xbf3d6a4f	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0xbf4bdddb	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xbf5b7758	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xbf5dacb9	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0xbf909a98	xenbus_dev_error
++EXPORT_SYMBOL_GPL vmlinux 0xbf966986	mmput
++EXPORT_SYMBOL_GPL vmlinux 0xbfaf8b19	intel_svm_bind_mm
++EXPORT_SYMBOL_GPL vmlinux 0xbfb1be70	hv_setup_vmbus_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbfb4fec0	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfccd269	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0xbfd10bb7	clk_register_mux_table
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xc00131cf	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0xc00bd19f	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0xc0275db3	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0xc02a191e	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0xc02fb2b3	unregister_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xc0709478	rio_unmap_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc0900fcf	acpi_os_get_iomem
++EXPORT_SYMBOL_GPL vmlinux 0xc0a7e37d	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0d54f85	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0e75cec	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc0feac5c	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0xc1090b2e	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0xc117247c	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0xc1239bcd	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xc1255d40	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xc12e0ada	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0xc1432573	iommu_capable
++EXPORT_SYMBOL_GPL vmlinux 0xc14b1693	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0xc1551799	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc159cece	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0xc164642e	xenbus_otherend_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc17519f7	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc17d78fa	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc18578ed	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xc1b707aa	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0xc1d071f4	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0xc1d463b5	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0xc1d64306	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xc1dd3787	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc1e454d5	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xc1e6aecf	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xc1f3c1a8	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xc1f3f4a2	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0xc2092f56	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0xc2108c84	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc22e9690	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0xc24089e1	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xc24159d7	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0xc2471eb2	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xc25b8971	hv_remove_crash_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc26351f8	bind_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc275a470	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc287d96a	kvm_set_posted_intr_wakeup_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc2e4c5e9	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc2e728dc	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0xc3111bee	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xc329b6df	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0xc32e3eaf	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xc32e558d	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc34740c3	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0xc371f845	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc3755c3d	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xc37c0531	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0xc397639f	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0xc3a1f6fb	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0xc3a436b8	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xc3ab89f7	xen_swiotlb_dma_mmap
++EXPORT_SYMBOL_GPL vmlinux 0xc3c7744f	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xc41eb08d	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc43c9740	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xc4496d53	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc45746a7	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc463872e	nvdimm_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc48aa3cb	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4d60474	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xc4e27063	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0xc4fb4a19	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc504be86	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc52c93e4	register_mce_write_callback
++EXPORT_SYMBOL_GPL vmlinux 0xc52dd247	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0xc5301f85	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0xc5397da6	xenbus_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc559d226	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0xc55e18c6	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0xc56475d8	isa_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc569d8ce	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xc56bc372	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc57d4a21	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0xc57d6475	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0xc58a0834	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xc5909a1f	acpi_dev_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc5a87b5a	rio_release_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xc5a93cf9	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc5acb6e5	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc5d681f2	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc5d8e1fe	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0xc5e1de94	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0xc60e68d8	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc611ca9c	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc629b315	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc636a3cf	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc65ec101	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0xc66019cc	xen_resume_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc66b5b2a	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc675c3e4	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0xc677fcd4	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6a4a872	__clk_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc6c6d2c7	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xc7002ac4	evtchn_make_refcounted
++EXPORT_SYMBOL_GPL vmlinux 0xc7061ef3	iova_cache_put
++EXPORT_SYMBOL_GPL vmlinux 0xc71af6b3	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xc7243be9	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0xc7248865	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc7422387	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc76eeef2	acpi_subsys_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc7800950	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xc789ed32	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7a2b733	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0xc7a34a7e	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xc7b634e7	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0xc7c1f875	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7ec22a0	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xc80325e1	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0xc803515e	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0xc80fd3f3	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0xc81b765d	put_iova_domain
++EXPORT_SYMBOL_GPL vmlinux 0xc8295b48	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xc83dbcbb	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0xc844e23e	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xc850fcdf	rio_get_comptag
++EXPORT_SYMBOL_GPL vmlinux 0xc85d63ad	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0xc86bfac3	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc87e2d7a	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xc87e487a	sched_clock_idle_sleep_event
++EXPORT_SYMBOL_GPL vmlinux 0xc8907ca1	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0xc8a8e447	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8cbbf42	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc8e5f591	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc8edd5a4	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0xc904c78c	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc918d7ef	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xc935ca76	pinctrl_find_and_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc967465a	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc9705eeb	has_newer_microcode
++EXPORT_SYMBOL_GPL vmlinux 0xc9736012	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xc978fb09	acpi_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0xc9b87e0c	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xc9bb6442	__online_page_set_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc9be907f	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0xc9c3f176	hpet_register_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc9c92267	xen_xenbus_fops
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc9f5e701	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0xca06f41f	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0xca127d0c	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xca318d1c	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0xca35884f	__online_page_free
++EXPORT_SYMBOL_GPL vmlinux 0xca3dd424	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xca445d58	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca81ea9a	xenbus_transaction_end
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcac23350	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xcac75b7f	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcacec30c	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0xcaf38c5e	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb4d4e99	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0xcb51b8f7	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0xcb76fc6d	rio_mport_get_feature
++EXPORT_SYMBOL_GPL vmlinux 0xcb87014a	ioremap_uc
++EXPORT_SYMBOL_GPL vmlinux 0xcba4f1d8	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0xcbb1445a	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0xcbbee1a5	__tracepoint_remove_device_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xcbd48c3f	hv_setup_crash_handler
++EXPORT_SYMBOL_GPL vmlinux 0xcbd80818	xen_xlate_remap_gfn_array
++EXPORT_SYMBOL_GPL vmlinux 0xcbdf8cb0	xen_swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcbf26374	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xcc095948	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xcc0e559f	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0xcc2ff140	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0xcc54890d	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccea4e34	perf_get_x86_pmu_capability
++EXPORT_SYMBOL_GPL vmlinux 0xcced0d0e	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xccefa6d1	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0xccfce041	acpi_create_platform_device
++EXPORT_SYMBOL_GPL vmlinux 0xccffeb2f	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xcd0b3b80	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xcd0f2b99	xen_swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0xcd1516df	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xcd29c655	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0xcd31af39	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0xcd437cde	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xcd5d4ef9	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0xcd6290c5	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xcd64662b	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0xcd8ffa10	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcdb532e6	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcde34ce3	add_memory_resource
++EXPORT_SYMBOL_GPL vmlinux 0xcdf18dd9	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0xce03ee18	acpi_subsys_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0xce0f2680	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0xce12d037	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xce34b536	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xce5f013f	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce7fbb0e	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xcec67374	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xceeb9ca3	rio_mport_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xcef1dd0e	perf_check_microcode
++EXPORT_SYMBOL_GPL vmlinux 0xcef81d04	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf65ca4d	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0xcf867ad2	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xcfa0805a	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc04819	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xcfc602ca	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfc75cd8	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xcfc7858e	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0xcfd415dd	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0xcfd514ec	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcfd7b454	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xcfd9f717	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xcfe8e6a3	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xcff7c918	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0xcff9a69d	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd0458ccb	xenbus_strstate
++EXPORT_SYMBOL_GPL vmlinux 0xd059b50e	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd07964dd	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xd0913a6f	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xd0962d3a	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd09ad085	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0ca9143	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0xd0d0287b	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xd0d95dde	xen_swiotlb_sync_sg_for_device
++EXPORT_SYMBOL_GPL vmlinux 0xd0f6f21f	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xd0f9eea5	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xd133efbb	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xd146f329	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xd1507e59	erst_clear
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd17008fe	pcc_mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xd17da654	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0xd18a75f1	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xd1e0e571	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xd1e65fd4	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd1fbe389	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd21c32c2	__tracepoint_io_page_fault
++EXPORT_SYMBOL_GPL vmlinux 0xd2249d03	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0xd226906e	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0xd23122f0	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0xd2494639	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xd2536d45	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xd254942a	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd28285ef	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd29ebbb5	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0xd2aaeb4e	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xd2bdca65	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0xd2c1db19	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0xd2c58ab2	apei_exec_noop
++EXPORT_SYMBOL_GPL vmlinux 0xd2d1927b	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0xd2dff01a	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2e88de5	clk_register_gate
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd2f18525	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd2f7c286	clk_hw_get_num_parents
++EXPORT_SYMBOL_GPL vmlinux 0xd317a633	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0xd320ae65	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd32189ea	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0xd32e34f5	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xd32eb840	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0xd33257ae	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0xd338ede0	pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0xd35d84d1	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xd36477ee	rio_route_add_entry
++EXPORT_SYMBOL_GPL vmlinux 0xd373b73e	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0xd3797a8f	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xd3ad632d	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3d90583	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd3fb7bdd	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd40bb9c9	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd41dc330	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd42a5f17	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0xd42f032b	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0xd445c855	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd451e873	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0xd45ea32f	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0xd468c27b	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0xd47c9626	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd4b30939	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4cf632d	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xd4d90889	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xd4db0165	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xd4e312fb	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0xd4f45af5	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0xd5030f07	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xd5182ba0	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0xd521ee7a	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xd5302a44	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0xd5320f5b	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0xd544e902	pgprot_writecombine
++EXPORT_SYMBOL_GPL vmlinux 0xd54672ba	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0xd549d5c0	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd5605a45	xenbus_free_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0xd5621902	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0xd598504d	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0xd5a5b86f	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0xd5a66d28	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xd5b85c98	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5bee148	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd6221d53	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd632b65f	efivar_entry_size
++EXPORT_SYMBOL_GPL vmlinux 0xd635534d	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xd63bf47d	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0xd642a34b	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0xd647ad6b	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xd65b0b53	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd67f9603	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0xd68a630d	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xd6aa6c84	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xd6c865b6	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xd6d7290a	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0xd6e05bc8	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0xd6ec7d35	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xd6ed3a8e	cper_next_record_id
++EXPORT_SYMBOL_GPL vmlinux 0xd6ee2541	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0xd6feefa5	agp_num_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd72cb603	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0xd72feba2	xenbus_read_driver_state
++EXPORT_SYMBOL_GPL vmlinux 0xd7399d2a	efivar_entry_iter_end
++EXPORT_SYMBOL_GPL vmlinux 0xd745a835	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xd7533267	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0xd761a481	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xd764d265	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd77b6d90	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd77dd7e0	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd7943f0b	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0xd795307d	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xd7aa306c	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0xd7ab2c0c	speedstep_detect_processor
++EXPORT_SYMBOL_GPL vmlinux 0xd7b10d80	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0xd7c48df9	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7d80a2a	intel_svm_unbind_mm
++EXPORT_SYMBOL_GPL vmlinux 0xd7e803d7	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xd815cb0b	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0xd81826c8	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd8216ccc	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xd822a2a9	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0xd8250a5c	iounmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xd829eded	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0xd84fd9df	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd85fba12	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xd863681f	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0xd86a19ea	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0xd86a2131	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd88b1733	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0xd899b806	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0xd8b8fee4	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0xd8c76c4b	pv_info
++EXPORT_SYMBOL_GPL vmlinux 0xd8f07208	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0xd8fad8b0	clk_hw_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0xd9126042	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xd919806a	amd_cache_northbridges
++EXPORT_SYMBOL_GPL vmlinux 0xd923afae	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0xd928f624	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94b737e	erst_read
++EXPORT_SYMBOL_GPL vmlinux 0xd94d2cb5	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0xd94fa823	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd96d900c	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd96e734b	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0xd9803346	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0xd986dad1	kernel_fpu_begin
++EXPORT_SYMBOL_GPL vmlinux 0xd996c93c	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0xd9a8e70c	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xd9bddfb3	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd9cf8b67	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xd9f8a048	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0xda15c181	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0xda50c223	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0xda79f019	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xda821ea5	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0xdaa03af1	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0xdaa06dc1	acpi_lpat_raw_to_temp
++EXPORT_SYMBOL_GPL vmlinux 0xdaa74860	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdac9e0b9	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdb088cb1	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0xdb0952cc	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0xdb1f2af7	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0xdb261f83	efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0xdb26c84f	xenbus_dev_groups
++EXPORT_SYMBOL_GPL vmlinux 0xdb34af46	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb61b4e0	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0xdb63a944	acpi_lpat_get_conversion_table
++EXPORT_SYMBOL_GPL vmlinux 0xdb7cc0b3	acpi_pci_check_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdbbb3523	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0xdbdb54db	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xdbe67abc	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0xdbe9d084	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0xdbf0404b	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc14a211	xen_hvm_evtchn_do_upcall
++EXPORT_SYMBOL_GPL vmlinux 0xdc36b10e	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0xdc516c29	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xdc60d527	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0xdc6699cb	acpi_dev_free_resource_list
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc95098e	rio_dma_prep_xfer
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdca54ea9	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdcd7c49c	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xdcd8c10a	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0xdcdb9961	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xdd069d07	rio_mport_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xdd07d768	acpi_match_device
++EXPORT_SYMBOL_GPL vmlinux 0xdd0ca1ac	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd204b09	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd32e3d0	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd3c0e9e	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0xdda90995	acpi_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xddbbd2df	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddc17e89	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xdddf131e	xenbus_grant_ring
++EXPORT_SYMBOL_GPL vmlinux 0xdde10e8d	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0xdde2d87c	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0xddfe7094	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xde1f5e73	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0xde46e353	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xde6b323b	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xde747356	intel_msic_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xde8dd926	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0xde8e53ea	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xde9463a6	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xdeabb35a	agp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0xdec89e8f	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0xdeeec3ab	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xdef8ec6c	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0xdefd07f2	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf1882af	dbgp_reset_prep
++EXPORT_SYMBOL_GPL vmlinux 0xdf20dc98	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xdf2a1971	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0xdf4ec976	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0xdf584f07	__efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0xdf622181	clk_register_divider_table
++EXPORT_SYMBOL_GPL vmlinux 0xdf66ca81	ucode_cpu_info
++EXPORT_SYMBOL_GPL vmlinux 0xdf75282c	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0xdf7ecd10	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0xdf92ecda	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xdfadd9cc	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe027821a	rio_release_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xe027c8fa	__dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe04b7dfc	clk_register_mux
++EXPORT_SYMBOL_GPL vmlinux 0xe04d59b6	fpu__activate_curr
++EXPORT_SYMBOL_GPL vmlinux 0xe04df2c6	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe071fbe6	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0xe0745fc4	pinctrl_pm_select_idle_state
++EXPORT_SYMBOL_GPL vmlinux 0xe08938e7	rio_set_port_lockout
++EXPORT_SYMBOL_GPL vmlinux 0xe089bd8b	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0xe089cfcc	agp_memory_reserved
++EXPORT_SYMBOL_GPL vmlinux 0xe0b1c103	clk_set_max_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe0b6a9a3	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xe0c77bb5	mce_notify_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe1083ae3	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0xe10cd6ad	erst_get_record_id_begin
++EXPORT_SYMBOL_GPL vmlinux 0xe1183e83	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xe11abdf3	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xe11c830d	rio_route_get_entry
++EXPORT_SYMBOL_GPL vmlinux 0xe121cbb6	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0xe14feff3	__tracepoint_attach_device_to_domain
++EXPORT_SYMBOL_GPL vmlinux 0xe1746672	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe17d5fc8	to_nvdimm
++EXPORT_SYMBOL_GPL vmlinux 0xe1874868	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0xe188b525	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0xe199d83c	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe1ad5b5d	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0xe1bd6c99	rio_init_mports
++EXPORT_SYMBOL_GPL vmlinux 0xe1c2d2a1	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0xe1d51dde	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0xe1e598d5	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0xe2343d3b	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0xe24a499c	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe2863029	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe2914816	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0xe29349dc	copy_reserved_iova
++EXPORT_SYMBOL_GPL vmlinux 0xe295c0ff	is_hpet_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe2b25158	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0xe2e3ddee	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0xe2fea4a4	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe31e3c54	pinctrl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe31f851d	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe32ced51	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xe3465698	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xe34765b9	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe37653e3	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xe3781628	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0xe37f8517	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe38728cc	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xe3948ff4	acpi_walk_dep_device_list
++EXPORT_SYMBOL_GPL vmlinux 0xe39781d2	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0xe3b59d47	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0xe3bc7fd4	hpet_unregister_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe3bda663	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe3c3b3e6	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0xe3cca728	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0xe41534ce	bind_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0xe418fde4	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xe41f89d5	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe439815c	erst_get_record_count
++EXPORT_SYMBOL_GPL vmlinux 0xe43b92c3	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0xe4686479	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe4a0d7af	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xe4b6b9bb	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0xe4c331b6	acpi_os_unmap_memory
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4e68bc8	apei_map_generic_address
++EXPORT_SYMBOL_GPL vmlinux 0xe4f233a5	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0xe4f6ec5e	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xe4ffa1ac	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe514d401	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xe545a811	get_xsave_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe57b04e1	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe59f5805	xenbus_dev_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xe5a0579f	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0xe5a5a6f2	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xe5b8082b	cper_estatus_check_header
++EXPORT_SYMBOL_GPL vmlinux 0xe6060185	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe62e8315	efivars_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe6306c83	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe63df575	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0xe645ec05	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0xe64ad8ea	unregister_nmi_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe6561037	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0xe663623a	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0xe667df90	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0xe6750ea5	efivar_entry_find
++EXPORT_SYMBOL_GPL vmlinux 0xe68a0697	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe6f83837	acpi_bus_attach_private_data
++EXPORT_SYMBOL_GPL vmlinux 0xe701ad82	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xe703679f	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0xe7091f66	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xe70e945e	rio_dev_get
++EXPORT_SYMBOL_GPL vmlinux 0xe7119122	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0xe7232e0f	user_return_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe7632ef3	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe77e0c8c	__rio_local_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe7a48591	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0xe7b40b87	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xe7b867ba	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0xe7c7ae37	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe7ca9c6b	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0xe7dc4d47	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0xe7e3bb68	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe80f7d48	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe81ba84d	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0xe81f908d	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xe81f9179	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0xe82bea8f	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe8840056	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0xe898832f	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0xe8d97c25	get_device
++EXPORT_SYMBOL_GPL vmlinux 0xe8fb11b8	pci_get_hp_params
++EXPORT_SYMBOL_GPL vmlinux 0xe90a16f6	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xe91cc036	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe981c9db	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0xe9b86ebc	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0xe9c0744e	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe9c255dd	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xe9ce931a	kvm_para_available
++EXPORT_SYMBOL_GPL vmlinux 0xe9cff5c8	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xe9e2faca	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe9e44bec	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea19e406	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea45886d	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xea5416b2	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xea82ab83	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xea99b795	__tracepoint_map
++EXPORT_SYMBOL_GPL vmlinux 0xeae56892	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0xeaf65021	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0xeb1937a3	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xeb2798f7	xen_destroy_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xeb370805	__apei_exec_run
++EXPORT_SYMBOL_GPL vmlinux 0xeb48e5b1	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0xeb497840	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xeb833c22	xen_has_pv_disk_devices
++EXPORT_SYMBOL_GPL vmlinux 0xeb9abbee	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xeba3ff7d	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0xebb3592b	snmp_get_cpu_field64
++EXPORT_SYMBOL_GPL vmlinux 0xebb6bc65	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0xebc61165	__rio_local_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xebfaedb1	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0xec004b24	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec488507	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0xec631f34	remove_memory
++EXPORT_SYMBOL_GPL vmlinux 0xec7170e1	rio_mport_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xec727cc6	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xec85afe6	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0xeca8b7cf	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0xecab5aef	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xecb267d8	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0xecd2d65c	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xed06c5cb	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xed3892d0	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xed46d26c	acpi_register_gsi
++EXPORT_SYMBOL_GPL vmlinux 0xed5392f6	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0xed5ebce7	clk_hw_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0xed6f5427	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0xed9ce7ef	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0xedbc6f67	gnttab_end_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xedcdffd4	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0xedea6f15	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xedf39975	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0xee0421ef	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0xee1ee71f	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0xee3b93ae	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee88d7b8	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xeeac3f28	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0xeeda4d85	xenbus_register_driver_common
++EXPORT_SYMBOL_GPL vmlinux 0xeeed0038	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xef064c63	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0xef1e99a5	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xef1f6e23	apei_resources_request
++EXPORT_SYMBOL_GPL vmlinux 0xef405cc8	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xef409b74	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0xef464c28	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0xef4fc0b6	pci_msi_create_irq_domain
++EXPORT_SYMBOL_GPL vmlinux 0xef539417	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0xef6415b6	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0xef64e2ce	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0xef684b1d	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6e0818	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0xef7b462b	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xefa03727	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xefa13cd2	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefa4e93f	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0xefa735f3	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0xefbeee2f	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0xefd9ef09	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xf0337b8e	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf04eadec	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0xf054ac97	intel_msic_irq_read
++EXPORT_SYMBOL_GPL vmlinux 0xf0601a3f	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0xf0655b6d	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0xf0696401	acpi_pci_detect_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xf0698c01	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0xf06c0683	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf084c8f1	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xf094bce6	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf0956185	dax_zero_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xf0b2221a	acpi_ec_add_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4cfa3	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xf0c801c5	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0xf0cb3e87	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf0eee000	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf11d98f4	pinctrl_utils_dt_free_map
++EXPORT_SYMBOL_GPL vmlinux 0xf11efce2	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xf137e0ae	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0xf1496264	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0xf14af1ec	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0xf14e1650	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0xf14ea02e	pinctrl_utils_add_config
++EXPORT_SYMBOL_GPL vmlinux 0xf150b4ba	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0xf16800ae	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0xf1762c3b	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0xf17dbc10	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0xf17ff9eb	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf191b653	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xf19b9b24	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf1a5226f	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xf1aca361	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf1adea8b	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1b551d9	ibft_addr
++EXPORT_SYMBOL_GPL vmlinux 0xf1eafbfe	acpi_dev_pm_attach
++EXPORT_SYMBOL_GPL vmlinux 0xf2003384	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0xf20ece0f	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xf2129b95	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xf2196393	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf2716145	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf2902558	to_nvdimm_bus
++EXPORT_SYMBOL_GPL vmlinux 0xf291252d	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0xf2a37426	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2cf8350	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf2ebf8c3	xenbus_probe_node
++EXPORT_SYMBOL_GPL vmlinux 0xf2f1d86e	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf30fda27	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf32bdc5d	unregister_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf35bb0a6	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xf37042ff	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf380dbba	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0xf38b3213	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3b503fc	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3c1c980	pinctrl_utils_reserve_map
++EXPORT_SYMBOL_GPL vmlinux 0xf3dd3ec1	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf3e90c5e	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf3ebf4eb	arch_apei_report_mem_error
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf429ae34	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xf43f65d5	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0xf441dc41	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0xf446837f	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0xf47f618d	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0xf489512f	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0xf492f7d5	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4ae4e60	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf5012bc2	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0xf50a1573	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xf5107415	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf527fbd5	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xf5361b39	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf55abae9	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0xf5619509	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0xf5657e31	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0xf5785b42	evtchn_get
++EXPORT_SYMBOL_GPL vmlinux 0xf5871a31	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf5945bac	gnttab_free_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0xf59f9264	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5dc8f0c	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0xf5e0c22b	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0xf60678d1	pci_msi_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf60a78c4	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xf60e8554	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0xf615386f	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xf61c4a37	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf61c4cfc	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xf62a65bc	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xf6674ebd	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0xf66ecb99	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf6753099	device_move
++EXPORT_SYMBOL_GPL vmlinux 0xf687b9d7	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0xf6a4fcd9	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xf6c71a25	cper_severity_str
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf6f844ed	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0xf6fd74cf	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf7016530	xenbus_gather
++EXPORT_SYMBOL_GPL vmlinux 0xf76bc672	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0xf770ce6c	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xf7a63b2a	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0xf7c3f273	xen_resume_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xf7daadc3	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf7fa9591	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xf80c5008	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0xf80f01b1	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0xf82a1356	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0xf82e265c	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0xf82f16b3	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf84714fe	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xf85d1f95	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf894ba00	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0xf8aec086	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xf8b79e86	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0xf8de9ebd	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf8e6b564	hibernation_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8e80bd4	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf8e99707	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf9048ee1	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xf904e7e3	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xf9253b4b	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0xf92cda13	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf9307bc1	rio_enable_rx_tx_port
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf932c685	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0xf945420a	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf956f6a3	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xf9765833	dmi_match
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf99b8427	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9bae929	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0xf9bdf67a	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9cbfa59	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf9d9264e	xen_have_vector_callback
++EXPORT_SYMBOL_GPL vmlinux 0xf9e953d8	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xf9f04dac	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa35044a	alternatives_patched
++EXPORT_SYMBOL_GPL vmlinux 0xfa4b4a94	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa4ff3d9	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0xfa6764b3	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0xfa6d5185	clk_hw_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0xfa78f727	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0xfa9e33f7	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0xfabddf64	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xfabe12d7	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0xfadb841f	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0xfadd2eb7	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xfafaebb3	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0xfb01020f	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0xfb0760f6	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0xfb25ce06	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb54427f	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0xfb582919	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0xfb64b230	acpi_processor_ffh_cstate_probe
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb83db03	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xfb85760e	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb870d8e	nvdimm_pmem_region_create
++EXPORT_SYMBOL_GPL vmlinux 0xfb8b193f	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0xfba16ade	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfbcff401	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0xfbe89ad9	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc254d15	gnttab_free_auto_xlat_frames
++EXPORT_SYMBOL_GPL vmlinux 0xfc3b4246	acpi_bus_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xfc40122f	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xfc583f0f	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0xfc968c8b	apei_exec_write_register_value
++EXPORT_SYMBOL_GPL vmlinux 0xfcb8ad10	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0xfcb9069b	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0xfcba0305	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xfccd21e7	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xfcece769	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0xfcf654a7	rio_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xfd12c73b	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xfd507609	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0xfd5131f4	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0xfd51b281	gnttab_end_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0xfd54c210	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xfd63a376	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfd6adf20	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xfd7243c7	erst_disable
++EXPORT_SYMBOL_GPL vmlinux 0xfd77d23c	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfdc0a996	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xfdcbb464	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xfdd5f736	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xfe0c502c	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xfe1f23e3	to_nd_desc
++EXPORT_SYMBOL_GPL vmlinux 0xfe3742b9	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xfe63a5f0	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0xfe6b6a50	xenbus_dev_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xfe727411	get_phys_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfeabdaf4	xenbus_dev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xfeb1979b	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xfeba5595	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0xfec0468d	pinctrl_dev_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xfecc5c31	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfee02f24	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff02cd62	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xff03d7f4	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff291ecf	clk_unregister_divider
++EXPORT_SYMBOL_GPL vmlinux 0xff2ce747	machine_check_poll
++EXPORT_SYMBOL_GPL vmlinux 0xff538458	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0xff57c7c1	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff5e0ca3	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff64889a	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0xff676787	devm_pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0xff9905d5	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0xffa782cb	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xffb6f1e7	dax_fault
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffba4dfb	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xffc42efc	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0xffddaac8	phy_pm_runtime_put
+diff --git a/debian.master/abi/4.4.0-111.134/i386/lowlatency.compiler b/debian.master/abi/4.4.0-111.134/i386/lowlatency.compiler
+new file mode 100644
+index 0000000..d1936f3
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/i386/lowlatency.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/i386/lowlatency.modules b/debian.master/abi/4.4.0-111.134/i386/lowlatency.modules
+new file mode 100644
+index 0000000..73bc02d
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/i386/lowlatency.modules
+@@ -0,0 +1,4756 @@
++3c509
++3c515
++3c574_cs
++3c589_cs
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++53c700
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_accent
++8250_boca
++8250_dw
++8250_exar_st16c554
++8250_fintek
++8250_fourport
++8250_hub6
++8250_mid
++8255
++8255_pci
++8390
++8390p
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++BusLogic
++DAC960
++NCR53c406a
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++abituguru
++abituguru3
++ablk_helper
++ac97_bus
++acard-ahci
++acecad
++acenic
++acer-wmi
++acerhdf
++acpi-als
++acpi_extlog
++acpi_ipmi
++acpi_pad
++acpi_power_meter
++acpi_thermal_rel
++acpiphp_ibm
++acquirewdt
++act2000
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7170
++adv7175
++adv7180
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++advantechwdt
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++aes-i586
++aesni-intel
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++ah4
++ah6
++aha152x
++aha152x_cs
++aha1542
++aha1740
++ahci
++ahci_platform
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airo
++airo_cs
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++ali-agp
++ali-ircc
++alienware-wmi
++alim1535_wdt
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am53c974
++ambassador
++amc6821
++amd
++amd-rng
++amd5536udc
++amd64_edac_mod
++amd76x_edac
++amd76xrom
++amd8111e
++amd_freq_sensitivity
++amdgpu
++amilo-rfkill
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apanel
++apds9300
++apds9802als
++apds990x
++apds9960
++apm
++apple-gmux
++apple_bl
++appledisplay
++applesmc
++appletalk
++appletouch
++applicom
++aquantia
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_ps2
++arc_uart
++arcfb
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3935
++as5011
++asb100
++asc7621
++ascot2e
++asix
++ast
++asus-laptop
++asus-nb-wmi
++asus-wmi
++asus_atk0110
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati-agp
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atlas_btns
++atm
++atmel
++atmel_cs
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp
++atp870u
++atusb
++atxp1
++aty128fb
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avm_cs
++avma1_cs
++avmfritz
++ax25
++ax88179_178a
++axnet_cs
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1isa
++b1pci
++b1pcmcia
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_epp
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcma
++bcma-hcd
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_aout
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluecard_cs
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpck
++bpck6
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmsmac
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bt3c_cs
++bt819
++bt856
++bt866
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btuart_cs
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c101
++c2port-duramar2150
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_das16_cs
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc10001_adc
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++ccp
++ccp-crypto
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfag12864b
++cfag12864bfb
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipreg
++chnl_net
++chromeos_laptop
++chromeos_pstore
++ci_hdrc
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++ck804xrom
++classmate-laptop
++clip
++clk-cdce706
++clk-palmas
++clk-pwm
++clk-s2mps11
++clk-si5351
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cm4000_cs
++cm4040_cs
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmtp
++cnic
++cobalt
++cobra
++coda
++com20020
++com20020-isa
++com20020-pci
++com20020_cs
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_isadma
++comedi_parport
++comedi_pci
++comedi_pcmcia
++comedi_test
++comedi_usb
++comm
++compal-laptop
++configfs
++contec_pci_dio
++cops
++cordic
++core
++coretemp
++cosa
++cp210x
++cpcihp_generic
++cpcihp_zt5550
++cpia2
++cpqphp
++cpsw_ale
++cpu-notifier-error-inject
++cpu5wdt
++cpuid
++cr_bllcd
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc32-pclmul
++crc7
++crc8
++cros_ec
++cros_ec_devs
++cros_ec_i2c
++cros_ec_keyb
++cros_ec_lpc
++cros_ec_spi
++crvml
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++cs5535-mfd
++cs553x_nand
++cs89x0
++csiostor
++ct82c710
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_cs
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++db9
++dc395x
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++dcdbas
++ddbridge
++de2104x
++de4x5
++decnet
++deflate
++defxx
++dell-laptop
++dell-led
++dell-rbtn
++dell-smm-hwmon
++dell-smo8800
++dell-wmi
++dell-wmi-aio
++dell_rbu
++denali
++denali_dt
++denali_pci
++des_generic
++designware_i2s
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9601
++dme1737
++dmfe
++dmi-sysfs
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++donauboe
++dp83848
++dp83867
++dpt_i2o
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dtc
++dtl1_cs
++dtlk
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_wdt
++dwc3
++dwc3-pci
++dwmac-generic
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++e752x_edac
++e7xxx_edac
++earth-pt1
++earth-pt3
++eata
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++ec_bhf
++ec_sys
++echainiv
++echo
++edac_core
++edac_mce_amd
++edt-ft5x06
++eeepc-laptop
++eeepc-wmi
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efficeon-agp
++efi-pstore
++efi_test
++efs
++ehset
++einj
++elan_i2c
++elo
++elsa_cs
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++empeg
++ems_pci
++ems_pcmcia
++ems_usb
++emu10k1-gp
++ena
++enc28j60
++enclosure
++encx24j600
++encx24j600-regmap
++ene_ir
++eni
++enic
++epat
++epia
++epic100
++eql
++esas2r
++esb2rom
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++eurotechwdt
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++ezusb
++f2fs
++f71805f
++f71808e_wdt
++f71882fg
++f75375s
++f81232
++fakelb
++fam15h_power
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_sys_fops
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdomain_cs
++fdp
++fdp_i2c
++fealnx
++ff-memless
++fintek-cir
++firedtv
++firestream
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fixed
++fjes
++fl512
++flexfb
++floppy
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fmvj18x_cs
++fnic
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fschmd
++fsl_lpuart
++ft6236
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu-laptop
++fujitsu-tablet
++fujitsu_ts
++g450_pll
++g760a
++g762
++g_NCR5380
++g_NCR5380_mmio
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcm
++gdmtty
++gdmulte
++gdmwm
++gdth
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++geode-aes
++geode-rng
++gf128mul
++gf2k
++gfs2
++ghash-generic
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++glue_helper
++gluebi
++gma500_gfx
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-104-idio-16
++gpio-addr-flash
++gpio-adp5520
++gpio-adp5588
++gpio-amd8111
++gpio-amdpt
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-cs5535
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-f7188x
++gpio-fan
++gpio-generic
++gpio-ich
++gpio-ir-recv
++gpio-it87
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-pch
++gpio-rdc321x
++gpio-regulator
++gpio-sch
++gpio-sch311x
++gpio-tps65912
++gpio-twl4030
++gpio-twl6040
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mouse
++gpio_tilt_polled
++gr_udc
++grace
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++gx-suspmod
++gx1fb
++gxfb
++gxt4500
++hackrf
++hamachi
++hampshire
++hangcheck-timer
++hanwang
++hci
++hci_uart
++hci_vhci
++hdaps
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hecubafb
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfs
++hfsplus
++hgafb
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-hyperv
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++hih6130
++hio
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi504_nand
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hopper
++horizon
++horus3a
++hostap
++hostap_cs
++hostap_pci
++hostap_plx
++hostess_sv11
++hp-wireless
++hp-wmi
++hp100
++hp_accel
++hpfs
++hpilo
++hpsa
++hptiop
++hpwdt
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++hsu_dma_pci
++htc-pasic3
++htcpen
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hv_balloon
++hv_netvsc
++hv_storvsc
++hv_utils
++hv_vmbus
++hwa-hc
++hwa-rc
++hwmon-vid
++hx8357
++hyperv-keyboard
++hyperv_fb
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd756-s4882
++i2c-amd8111
++i2c-cbus-gpio
++i2c-cros-ec-tunnel
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-eg20t
++i2c-emev2
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-ismt
++i2c-kempld
++i2c-matroxfb
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-pinctrl
++i2c-mux-reg
++i2c-nforce2
++i2c-nforce2-s4985
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-isa
++i2c-pca-platform
++i2c-piix4
++i2c-robotfuzz-osif
++i2c-scmi
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i3000_edac
++i3200_edac
++i40e
++i40evf
++i5000_edac
++i5100_edac
++i5400_edac
++i5500_temp
++i5k_amb
++i6300esb
++i7300_edac
++i740fb
++i7core_edac
++i810fb
++i82092
++i82365
++i82860_edac
++i82875p_edac
++i82975x_edac
++i915
++i915_bpo
++iTCO_vendor_support
++iTCO_wdt
++ib700wdt
++ib_addr
++ib_cm
++ib_core
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibm_rtl
++ibmaem
++ibmasm
++ibmasr
++ibmpex
++ibmphp
++ichxrom
++icn
++icp_multi
++icplus
++ics932s401
++ideapad-laptop
++ideapad_slidebar
++idma64
++idmouse
++idt77252
++idt_gen2
++idtcps
++ie31200_edac
++ie6xx_wdt
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imm
++imon
++ims-pcu
++imx074
++in2000
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int3400_thermal
++int3402_thermal
++int3403_thermal
++int340x_thermal_zone
++int51x1
++intel-hid
++intel-lpss
++intel-lpss-acpi
++intel-lpss-pci
++intel-mid-touch
++intel-mid_wdt
++intel-rng
++intel-rst
++intel-smartconnect
++intel-vbtn
++intel_ips
++intel_menlow
++intel_mid_battery
++intel_mid_powerbtn
++intel_mid_thermal
++intel_oaktrail
++intel_pch_thermal
++intel_pmc_ipc
++intel_powerclamp
++intel_punit_ipc
++intel_qat
++intel_quark_i2c_gpio
++intel_rapl
++intel_scu_ipcutil
++intel_soc_dts_iosf
++intel_soc_dts_thermal
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++intelfb
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipwireless
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++iris
++irlan
++irnet
++irqbypass
++irtty-sir
++isci
++iscsi_boot_sysfs
++iscsi_ibft
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it87
++it8712f_wdt
++it87_wdt
++it913x
++itd1000
++ite-cir
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++k10temp
++k8temp
++kafs
++kalmia
++kaweth
++kb3886_bl
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks0108
++ks0127
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kvm
++kvm-amd
++kvm-intel
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l440gx
++l4f00242t03
++l64781
++lan78xx
++lanai
++lance
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-adp5520
++leds-bd2802
++leds-blinkm
++leds-clevo-mail
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-net48xx
++leds-ot200
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-pwm
++leds-regulator
++leds-ss4200
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++leds-wrap
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libahci_platform
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_cs
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++litelink-sir
++lkkbd
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lmc
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++logibm
++longhaul
++longrun
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltpc
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxfb
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac80211
++mac80211_hwsim
++mac802154
++mac_hid
++macb
++machzwd
++macmodes
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++marvell
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77693
++max77693-haptic
++max77693_charger
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mce-inject
++mce_amd_inj
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++mdacon
++mdc800
++mdio
++mdio-bcm-unimac
++mdio-bitbang
++mdio-gpio
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++mei
++mei-me
++mei-txe
++mei_phy
++memory-notifier-error-inject
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++metro-usb
++metronomefb
++meye
++mf6x4
++mga
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microread_mei
++microtek
++mii
++minix
++mip6
++mite
++mixcomwd
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmc_block
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi-laptop
++msi-wmi
++msi001
++msi2500
++msp3400
++mspro_block
++msr
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtd_dataflash
++mtdblock
++mtdblock_ro
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-sd
++mtouch
++multipath
++multiq3
++musb_hdrc
++mv_u3d_core
++mv_udc
++mvmdio
++mvsas
++mvumi
++mwave
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxc4005
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxm-wmi
++mxser
++mxuport
++myri10ge
++n2
++n411
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nci
++nci_spi
++nci_uart
++ncpfs
++nct6683
++nct6775
++nct7802
++nct7904
++nd_blk
++nd_btt
++nd_pmem
++ne
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++nettel
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfit
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni65
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_daq_700
++ni_daq_dio24
++ni_labpc
++ni_labpc_common
++ni_labpc_cs
++ni_labpc_isadma
++ni_labpc_pci
++ni_mio_cs
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicstar
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nmclan_cs
++nosy
++notifier-error-inject
++nouveau
++nozomi
++ns558
++ns83820
++nsc-ircc
++nsc_gpio
++nsp32
++nsp_cs
++ntb
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nuvoton-cir
++nv_tco
++nvidiafb
++nvme
++nvmem_core
++nvram
++nxp-nci
++nxp-nci_i2c
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_xilinx_wdt
++old_belkin-sir
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_cs
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p4-clockmod
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++padlock-aes
++padlock-sha
++palmas-pwrbutton
++palmas-regulator
++panasonic-laptop
++pandora_bl
++panel
++paride
++parkbd
++parport
++parport_ax88796
++parport_cs
++parport_pc
++parport_serial
++pas16
++pata_acpi
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cs5520
++pata_cs5530
++pata_cs5535
++pata_cs5536
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_isapnp
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pcmcia
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sc1200
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sl82c105
++pata_triflex
++pata_via
++pc110pad
++pc300too
++pc87360
++pc8736x_gpio
++pc87413_wdt
++pc87427
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcbit
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_can
++pch_dma
++pch_gbe
++pch_phub
++pch_uart
++pch_udc
++pci
++pci-stub
++pci200syn
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmcia
++pcmcia_core
++pcmcia_rsrc
++pcmciamtd
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcnet_cs
++pcrypt
++pcspkr
++pcwd
++pcwd_pci
++pcwd_usb
++pd
++pd6729
++pda_power
++pdc_adma
++peak_pci
++peak_pcmcia
++peak_usb
++pegasus
++penmount
++percpu_test
++pf
++pfuze100-regulator
++pg
++phantom
++phonet
++phram
++phy-bcm-kona-usb2
++phy-exynos-usb2
++phy-gpio-vbus-usb
++phy-isp1301
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-tahvo
++phy-tusb1210
++physmap
++pinctrl-broxton
++pinctrl-intel
++pinctrl-sunrisepoint
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl2303
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8941-wled
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pn533
++pn544
++pn544_i2c
++pn544_mei
++pn_pep
++poly1305_generic
++port100
++powermate
++powernow-k6
++powernow-k7
++powr1220
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_core
++pps_parport
++pptp
++prism2_usb
++processor_thermal_device
++ps2mult
++psmouse
++psnap
++pt
++pti
++ptp
++ptp_pch
++pulsedlight-lidar-lite-v2
++punit_atom_debug
++pvpanic
++pvrusb2
++pwc
++pwm-beeper
++pwm-lp3943
++pwm-lpss
++pwm-lpss-pci
++pwm-lpss-platform
++pwm-pca9685
++pwm-regulator
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa27x_udc
++qat_dh895xcc
++qat_dh895xccvf
++qcaux
++qcom-spmi-iadc
++qcom-spmi-vadc
++qcom_spmi-regulator
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qlogic_cs
++qlogicfas
++qlogicfas408
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quatech_daqp_cs
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r82600_edac
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-aimslab
++radio-aztech
++radio-bcm2048
++radio-cadet
++radio-gemtek
++radio-i2c-si470x
++radio-isa
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-miropcm20
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-rtrack2
++radio-sf16fmi
++radio-sf16fmr2
++radio-shark
++radio-si476x
++radio-tea5764
++radio-terratec
++radio-timb
++radio-trust
++radio-typhoon
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++radio-zoltrix
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++ray_cs
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++reed_solomon
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio-scan
++rio500
++rionet
++rivafb
++rj54n1cb0c
++rmd128
++rmd160
++rmd256
++rmd320
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-bq32k
++rtc-bq4802
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-hid-sensor-time
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-mrst
++rtc-msm6242
++rtc-mt6397
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-r9701
++rtc-rc5t583
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-twl
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7110
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7185
++saa7706h
++safe_serial
++salsa20-i586
++salsa20_generic
++samsung-keypad
++samsung-laptop
++samsung-q10
++samsung-sxgbe
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_sil
++sata_sil24
++sata_sis
++sata_svw
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sb1000
++sbc60xxwdt
++sbc7240_wdt
++sbc8360
++sbc_epx_c3
++sbc_fitpc2_wdt
++sbc_gxx
++sbni
++sbp_target
++sbs
++sbs-battery
++sbshc
++sc
++sc1200wdt
++sc16is7xx
++sc92031
++sca3000
++scb2_flash
++scc
++sch311x_wdt
++sch5627
++sch5636
++sch56xx-common
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++scx200
++scx200_acb
++scx200_docflash
++scx200_gpio
++scx200_hrt
++scx200_wdt
++sdhci
++sdhci-acpi
++sdhci-pci
++sdhci-pltfm
++sdio_uart
++sdla
++sdricoh_cs
++sealevel
++sedlbauer_cs
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial2002
++serial_cs
++serio_raw
++sermouse
++serpent-sse2-i586
++serpent_generic
++serport
++ses
++sfc
++sfi-cpufreq
++sh_veu
++shark2
++shpchp
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sim710
++sir-dev
++sis
++sis-agp
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skfp
++skge
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++sl811_cs
++slcan
++slicoss
++slip
++slram
++sm501
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smc-ultra
++smc9194
++smc91c92_cs
++smipcie
++smm665
++smsc
++smsc-ircc2
++smsc37b787_wdt
++smsc47b397
++smsc47m1
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1816a
++snd-ad1848
++snd-ad1889
++snd-adlib
++snd-ak4113
++snd-ak4114
++snd-ak4117
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als100
++snd-als300
++snd-als4000
++snd-asihpi
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt1605
++snd-azt2316
++snd-azt2320
++snd-azt3328
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmi8328
++snd-cmi8330
++snd-cmipci
++snd-compress
++snd-cs4231
++snd-cs4236
++snd-cs4281
++snd-cs46xx
++snd-cs5530
++snd-cs5535audio
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emu8000-synth
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1688
++snd-es1688-lib
++snd-es18xx
++snd-es1938
++snd-es1968
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-gus-lib
++snd-gusclassic
++snd-gusextreme
++snd-gusmax
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-ext-core
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel-sst-acpi
++snd-intel-sst-core
++snd-intel-sst-pci
++snd-intel8x0
++snd-intel8x0m
++snd-interwave
++snd-interwave-stb
++snd-isight
++snd-jazz16
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-miro
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-msnd-classic
++snd-msnd-lib
++snd-msnd-pinnacle
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-opl3sa2
++snd-opl4-lib
++snd-opl4-synth
++snd-opti92x-ad1848
++snd-opti92x-cs4231
++snd-opti93x
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm
++snd-pcm-dmaengine
++snd-pcm-oss
++snd-pcsp
++snd-pcxhr
++snd-pdaudiocf
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-sb-common
++snd-sb16
++snd-sb16-csp
++snd-sb16-dsp
++snd-sb8
++snd-sb8-dsp
++snd-sbawe
++snd-sc6000
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-sis7019
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-core
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-dmic
++snd-soc-es8328
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-ssi
++snd-soc-gtm601
++snd-soc-imx-audmux
++snd-soc-max98090
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rl6231
++snd-soc-rl6347a
++snd-soc-rt286
++snd-soc-rt5631
++snd-soc-rt5640
++snd-soc-rt5645
++snd-soc-rt5660
++snd-soc-rt5670
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-skl
++snd-soc-skl-ipc
++snd-soc-skl_rt286
++snd-soc-sn95031
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sst-acpi
++snd-soc-sst-baytrail-pcm
++snd-soc-sst-broadwell
++snd-soc-sst-byt-max98090-mach
++snd-soc-sst-byt-rt5640-mach
++snd-soc-sst-bytcr-rt5640
++snd-soc-sst-bytcr-rt5660
++snd-soc-sst-cht-bsw-max98090_ti
++snd-soc-sst-cht-bsw-rt5645
++snd-soc-sst-cht-bsw-rt5672
++snd-soc-sst-dsp
++snd-soc-sst-haswell
++snd-soc-sst-haswell-pcm
++snd-soc-sst-ipc
++snd-soc-sst-mfld-platform
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-xtfpga-i2s
++snd-sonicvibes
++snd-sscape
++snd-tea6330t
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-us122l
++snd-usb-usx2y
++snd-usb-variax
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-vxpocket
++snd-wavefront
++snd-wss-lib
++snd-ymfpci
++snic
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++softdog
++softing
++softing_cs
++solo6x10
++solos-pci
++sony-btf-mpx
++sony-laptop
++sonypi
++soundcore
++sp2
++sp5100_tco
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntpc
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_decpc
++speakup_dectlk
++speakup_dtlk
++speakup_dummy
++speakup_keypc
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++spectrum_cs
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi-lm70llp
++spi-nor
++spi-oc-tiny
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tle62x0
++spi-topcliff-pch
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spmi
++sr9700
++sr9800
++ssb
++ssb-hcd
++ssfdc
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++sstfb
++ssu100
++ssv_dnp
++st
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++surfacepro3_button
++svgalib
++sworks-agp
++sx8
++sx8654
++sx9500
++sym53c416
++sym53c500_cs
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink
++synclink_cs
++synclink_gt
++synclinkmp
++syscopyarea
++sysfillrect
++sysimgblt
++sysv
++t128
++t1isa
++t1pci
++t5403
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc1100-wmi
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcic
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tehuti
++tekram-sir
++teles_cs
++teranetics
++test-hexdump
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tg3
++tgr192
++thinkpad_acpi
++thmc50
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timb_dma
++timberdale
++timblogiw
++timbuart
++timeriomem-rng
++tipc
++tlan
++tlclk
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmem
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++topstar-laptop
++torture
++toshiba-wmi
++toshiba_acpi
++toshiba_bluetooth
++toshiba_haps
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_atmel
++tpm_crb
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_infineon
++tpm_nsc
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tscan1
++tsi568
++tsi57x
++tsi721_mport
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl-regulator
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish-i586
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++u14-34f
++uPD98402
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udf
++udl
++udlfb
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++ultrastor
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++usnic_verbs
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vboxguest
++vboxsf
++vboxvideo
++vcan
++vcnl4000
++ven_rsi_91x
++ven_rsi_sdio
++ven_rsi_usb
++ves1820
++ves1x93
++veth
++vfio
++vfio-pci
++vfio_iommu_type1
++vfio_virqfd
++vga16fb
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-camera
++via-cputemp
++via-ircc
++via-rhine
++via-rng
++via-sdmmc
++via-velocity
++via686a
++via_wdt
++viafb
++video
++videobuf-core
++videobuf-dma-contig
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videocodec
++videodev
++vim2m
++viperboard
++viperboard_adc
++virt-dma
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_scsi
++virtual
++visor
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_ca91cx42
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmlfb
++vmw_balloon
++vmw_pvscsi
++vmw_vmci
++vmw_vsock_vmci_transport
++vmwgfx
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vpx3220
++vrf
++vringh
++vsock
++vsxxxaa
++vt1211
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83627ehf
++w83627hf
++w83627hf_wdt
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83877f_wdt
++w83977af_ir
++w83977f_wdt
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++wafer5823wdt
++walkera0701
++wanxl
++warrior
++wbsd
++wcn36xx
++wd
++wd7000
++wd719x
++wdt
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++winbond-cir
++wire
++wishbone-serial
++wistron_btns
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wl3501_cs
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wmi
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x38_edac
++x86_pkg_temp_thermal
++x_tables
++xc4000
++xc5000
++xcbc
++xen-blkback
++xen-evtchn
++xen-fbfront
++xen-gntalloc
++xen-gntdev
++xen-kbdfront
++xen-netback
++xen-pciback
++xen-pcifront
++xen-privcmd
++xen-scsiback
++xen-scsifront
++xen-tpmfront
++xen_wdt
++xenfs
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xhci-plat-hcd
++xillybus_core
++xillybus_pcie
++xirc2ps_cs
++xircom_cb
++xor
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yenta_socket
++yurex
++z85230
++zatm
++zaurus
++zd1201
++zd1211rw
++zforce_ts
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++zr36016
++zr36050
++zr36060
++zr36067
++zr364xx
++zram
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc
+new file mode 100644
+index 0000000..8fbe3b7
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc
+@@ -0,0 +1,17307 @@
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0xa8cfd13e	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/atm/suni 0xefadc684	suni_init
++EXPORT_SYMBOL drivers/atm/uPD98402 0x0122d0b6	uPD98402_init
++EXPORT_SYMBOL drivers/bcma/bcma 0x5ff21f89	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/bcma/bcma 0xe6a32cd3	bcma_core_irq
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x019e3737	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x0a1276d1	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0x27c9e461	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x29970b05	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0x3438f823	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x4267110a	pi_register_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0x6950ef33	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x6ab4a48a	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x756a9c6b	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x7bd46669	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0x9ae23f26	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xb21ba07d	pi_unregister_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0xe9393069	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0xfa2c7619	pi_disconnect
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0xac24be3e	btbcm_patchram
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x08a7045d	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x32407972	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x855050a0	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x88669ec2	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xbaaafc63	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x4a3a5229	st33zp24_probe
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x7b74b69f	st33zp24_remove
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x92cc4fca	st33zp24_pm_resume
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xdc275ba1	st33zp24_pm_suspend
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xa3a9c635	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xb74c1e85	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xe9d0701e	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/crypto/caam/caam 0x1c758e97	caam_get_era
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0x06017241	caam_jr_alloc
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0x377f40cc	caam_jr_strstatus
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0x3acfa801	gen_split_key
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0x9f6a1d33	caam_jr_free
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0xc432df38	caam_jr_enqueue
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0xd07afe96	split_key_done
++EXPORT_SYMBOL drivers/crypto/talitos 0x3404c12a	talitos_submit
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x218fc792	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x48d04bde	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x5b7f328a	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x612d31d2	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x9020c2d4	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xe325b95c	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/edac/edac_core 0x7f1001b5	edac_mc_find
++EXPORT_SYMBOL drivers/edac/mpc85xx_edac 0x6ba8aafc	mpc85xx_pci_err_probe
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x01907d0e	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04dd92ce	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2656b293	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2cec6196	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4d5d4eca	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x59f93c0b	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x62fe6a0f	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x649e7f07	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x6ba4e529	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x6df6e5b0	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7034ac56	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7e431b14	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7f6e345f	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x84d7f40a	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90f8599c	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x93727ba9	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9ad51548	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9bcaf479	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa506cab7	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa92ee984	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xac5fbb8a	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb21b63af	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb78a58d6	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xbc3199a5	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xc362289f	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xda309805	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xdc5815f4	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xf981dd86	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xff17648c	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/fmc/fmc 0x16f777c4	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x3445261a	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0x4add9f03	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x67c1afe3	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x8694be77	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0x86af8877	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0x8827a0b0	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0xa93ef64e	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xb07817ed	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xe0d464d3	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xecf1d2ed	fmc_driver_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x017f3d93	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02822eb3	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x038d45e6	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x050c26ca	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06e4c60a	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0d8a1a58	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0dca1054	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0e9062e0	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fccafb1	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fec0404	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x101a3646	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x101e7f1a	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1175b315	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11ab8dc0	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11ba77e1	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12cf282d	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12e89947	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x134d8764	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13c7cd6c	of_drm_find_panel
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13cad1a6	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14f80b37	drm_of_find_possible_crtcs
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x161d074b	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x175aeb1e	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x17e9b639	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c5416a9	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1cef0e3f	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dbf3f51	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dda22c7	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1edf5068	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1f5676cc	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1f889e12	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1f9a6ff0	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20437308	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x210266e2	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x21b2bcc2	drm_of_component_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x224350a5	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22569a34	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2263c917	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x23498ef6	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x23e35389	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x242d9df2	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x24da1ee4	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x258e7fdb	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x27f497cf	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x291cecdf	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2bfe354b	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c05a7ba	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d3b4159	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2dc99b21	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e406d26	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2f541372	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3108b652	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x321a1d98	drm_agp_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x333669c2	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3368e25c	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x33c95b63	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x33f195a1	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x346127a7	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x34b805fe	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x35450922	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3599be2f	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x36390bee	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37e1e0c7	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x389c015f	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x39465de4	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x39675129	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x39a3a726	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3c1d9bd4	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d5d3750	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d652015	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d8283c8	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3dd1fc48	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3f88a23d	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x405aa157	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43297a73	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x435910c1	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x447f2875	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x46938c2f	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48253830	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x49448d09	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4a32577c	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ab19842	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4abd672f	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4b3d4349	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c8a96e8	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d5fc834	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ed46f51	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5057e13c	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51db353a	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51e0b5df	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51e51468	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x525247ef	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x53ab31c5	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54f3581e	drm_agp_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x560a9a70	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5664ec1d	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x566fd33e	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x588e3f69	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x58fbb630	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5c923b63	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5cff9f52	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d2ef7d6	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5da17aff	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5eae5c7e	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x61090b9e	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6163bba9	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x64536aae	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x664f8b3c	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67966110	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x689aeed8	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68b8235b	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69099d62	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x690bcb1f	drm_agp_unbind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6ad1ae41	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6bfcbc16	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6c1bbc85	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6faf8632	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6ffc7d08	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70725f11	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70ce4059	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x723f291a	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72c05992	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7318315e	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x742e2049	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7473e4b1	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x753ab453	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7591630b	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x76027918	drm_agp_info
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x78b50392	drm_agp_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x791d9306	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x79ef81af	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c224386	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c34f1ba	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c3ae836	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c546e36	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c60a9e2	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7cb0aeb8	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7f280af8	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7fb370f3	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x803f8917	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8164fb39	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x81d9bfe1	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8211c2e4	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x837c85bb	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x845b8d26	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x859dc66c	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x85b71829	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x863a52db	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x86943f42	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8696cf11	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x875a2e3e	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x892a6b7a	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x895d743c	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c5a607a	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d4207b7	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f044de8	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ff833d4	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x902b4d1d	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9055aa5d	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x90fb9a1a	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x913bbbf0	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9188e14a	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x930f9b52	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x93fa8318	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x94f0b58c	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x95907a61	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x95e1438e	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x977f17d9	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9796c87c	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97c335f4	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97d8c542	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97f8cb87	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x98b04900	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x99fc3763	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a5a7244	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9bb93692	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9c0c4262	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9d3501b0	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0c39153	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0c8bac3	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa335d2d8	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa374441b	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa526122a	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa6d83aa3	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa74767cf	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa7518a42	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa7dd1b3b	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa7ea0911	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa94b310b	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa9d659ad	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaa0411e6	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xab691468	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xacd45926	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad430db3	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad54daac	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad6180e7	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb17d072b	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5518146	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5a63d88	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb6084455	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb87ec255	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb8842225	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb889e82a	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb9a214f8	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbaa379a7	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbacb7dae	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbc35d08c	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbc6cac26	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbcb4abc0	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbd4313d8	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbdfee50f	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbf026334	drm_agp_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc0d2879e	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc0d5104f	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc1b8771e	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc381aa9a	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc5e243ca	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc7244055	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc7461229	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc800bc85	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc85710ec	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc8b3ad9b	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc9afcfb3	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc9f3f6c4	drm_agp_acquire
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcc4a601b	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcc85d69d	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd4fd361	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd039a4ae	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd0dca37a	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2fe8bd4	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd5b901d0	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd8f738f9	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd94217fc	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd9e6bd12	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd9f17443	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xda183c9c	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdb99f939	of_drm_find_bridge
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbd33e36	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd4417e8	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdedea442	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdef2d8c3	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdfe1b289	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe039fbcc	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe05b92d7	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe0fc9ab8	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe1243f67	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe18bf127	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe18d1f34	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe1dfa0fe	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe22b6967	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2458475	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2ffd7a5	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe344857d	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe68dbc4e	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe738644b	drm_agp_bind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe843a913	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe89799b4	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea909bae	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb3d1f58	drm_legacy_addbufs_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb87c5ef	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xec28e75d	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xec9073d6	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xecc36e63	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed462bf0	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed52a254	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xefe72b8f	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0a09bcf	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0a9cd0a	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1823833	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1b098be	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf2738c9b	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf2a2c7d4	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf43eb1e5	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf5ae6b87	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf6210e41	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf7ed3393	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfa37fece	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfa537296	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb4b057f	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfba61ac5	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbd001bf	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbfe3d9f	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfdba905d	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfde5853a	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfe54fa64	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfeac530b	drm_agp_bind_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff0cf2c6	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffbead57	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0070bd78	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x01268dc2	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0215a07e	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x05cd033b	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0688df56	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x070a7610	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x08d62486	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0b339d16	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0c359023	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0dd9a26d	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0e253af6	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x14df2a4b	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1ddf3105	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1f03577c	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1f5e1961	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x20e3e7e5	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x234431a0	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x25e4ab6b	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2662186c	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x29a66ec4	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2a2b9f2a	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2a87b9b8	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2c49a2a2	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x313879fe	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x31999872	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x31ec3cdc	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3226594a	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x390b1b61	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3b256eec	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3c6d96f5	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x41e4e073	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4225c4eb	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x43515b9d	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x45a777d7	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x46ead597	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4efeebe8	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x50ad0047	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x52c9e1ab	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x53458bab	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x555c24ac	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x55612af5	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x56acf8f2	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5a08b96e	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5c22dea1	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5cd9159e	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5ef983f0	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5f75d25c	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x620d51ee	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x63944320	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x672fb0cd	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x68b9e450	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x68d67cc4	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x69be6e38	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x69f1fc8d	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6a0efdd0	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6c61e0f6	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6d9c6929	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x731728a2	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x758636a3	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x76546e53	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x78557582	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7a10be94	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7fe48a32	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x81ac60d8	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x81fc8f1b	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x85ac9eb1	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x85d8adf7	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8683e9a1	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8e77197d	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x912a3b2b	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x916ef0ba	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x930e3753	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x954801df	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9941145c	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x99b9b3f0	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9aa15426	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9c7420b5	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9d0dc166	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9dde96bb	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9e24479b	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9e880a87	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9f024f20	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa013fc5c	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa3d749ec	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa4515fc4	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa524f946	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa5ef552a	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa713d4aa	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa73ce9e8	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa73f06e3	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8f716d4	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa994dd12	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaa8efc1d	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xabd857b7	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xad4e1644	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb344b293	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb4a3fa52	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb4c88b39	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb5317e1a	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb5bd1572	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb88e56ab	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb9ba9ef8	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb9d843d0	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb9ed76be	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbb56dd73	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbb6df2ca	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbc1f646a	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbf39494a	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc33c893b	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc4fe0290	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc58bb8a5	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc6ae6ec3	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc8b0a6ce	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc97787aa	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcc802e80	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd0aea335	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd28b3ba4	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd34fefb1	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd4f9df96	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd64000fe	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd7f38e2a	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd9d64c57	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdaa6d8a1	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdb5b146e	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdb79d66d	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xddbc9214	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe1f0febd	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe34550bb	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe6171b5b	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe726b84b	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe8d6fb05	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xefb2909f	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf4f12446	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf4f7e379	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf55d29b7	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf7d342ab	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfa6e3c44	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfabea10e	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfcd69aa8	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xff6e172f	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xff97d025	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xffb0d2c0	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x004a5f19	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x065d0ed2	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x07b4e551	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0a5411de	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x132b05be	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2e3e7574	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x315e45f7	ttm_agp_tt_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x36a33ecb	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3827ebd3	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x390d76cc	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3bafdacf	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x436f0a56	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x47fa7023	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x48b74c02	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4a272c87	ttm_agp_tt_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4c35c863	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4cb6ab8f	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x520113b4	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x52ac4d64	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5a8fdfea	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5c66187f	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5cf59609	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x625d88b8	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x67b1d568	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x71a7ea28	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x757f6562	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7ac14ac7	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7d55da85	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7d9f3d47	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x810d032d	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x81395aa6	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x828fe0fa	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x84a13931	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x89a443de	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8ba662bc	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8d14adbf	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8f571afc	ttm_prime_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9dcddc64	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa2a129fd	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa50aee01	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa73de2a9	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xac7d9fa2	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xad50fc74	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb03b35ff	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb83c6470	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbabefb8b	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc0fdd0fa	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc1c1d29d	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc5f0c2da	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc8d5a35a	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcaee12b0	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd24a5e00	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd38189df	ttm_agp_tt_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd7cabf33	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd7f51742	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8a9515b	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xda1017da	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdd953586	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdeb2df73	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe09ad4db	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe98de086	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xea112513	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xec2d9527	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf3499de7	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf3719901	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf4cfed1b	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf7eafe0f	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf897bd87	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfdc49991	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x01f2c685	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x3d2cc18d	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x92378c53	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x99d3587d	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0xd69c0549	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0xaa518674	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x07ed0790	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x0cdbad19	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x24744756	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x2cb24929	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x2d03692a	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x2f5c7950	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x8039aeb2	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x9462dba1	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x9d93f464	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xa041292c	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xcd094597	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xd3726cff	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xdc51121f	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xe68a55f3	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xf7602db0	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xff9cd93b	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x47c06e8a	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x536208d1	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x76d8c987	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0xc163ccf7	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x0f888483	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x6b5d82a4	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x7e7b2468	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xe170ee9e	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x34e031c7	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x645abc16	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x7c9ea3ca	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x860ecbc2	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x8e59c832	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x9628dd4d	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x24614286	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x35d115a8	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xb9d84f7b	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xc2b87113	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x43f06eda	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x4d9c2e32	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x6772d301	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x69a47d14	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x6b014895	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x7db4e19f	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x98370162	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc21e1f28	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xcbb95cd6	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x6d5dc0ed	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x91548470	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xb0b5efda	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xd6513b9a	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xf86ea7c2	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x0af94104	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x33490246	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x9921cdbf	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x0d1a8427	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x0e4ae754	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x1469f101	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x16e852c8	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4c04bb30	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x609d8420	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x75378485	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xa5776f33	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xa92ea0c9	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xa9e72206	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xab47a70f	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb11e9045	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc002ccdb	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc6606cb8	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd24180cb	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd47d866f	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xeecb1b69	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x4b324377	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x85f2ddcd	st_sensors_of_i2c_probe
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0x229ee184	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x6c57f449	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0xd3ebe2cc	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0x11029eb9	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x298f07d8	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xf8eeb913	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/industrialio 0x1e32a0e0	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x3489a0f3	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x4e3f30b0	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x6e42eb9b	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio 0x797867da	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0x7ec91c07	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0x8cbfad54	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0xb3a0c761	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0xb5da261d	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0xc1cb7309	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0xc22561ee	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xc60cce82	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xda1107fb	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xe584582a	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xeb08b790	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0xf011446f	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xfaf93698	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x508336fa	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0xb9035aa4	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x297b9e98	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xf316c357	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0xa4ecc61a	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x460d3766	st_press_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0xfadf6bdb	st_press_common_remove
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1ea5767b	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x32a8402c	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x4dc57e4d	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x54a10921	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x672d66d8	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xd0cac21e	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x09135d42	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x0edbbeb7	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x101a1714	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1e759d56	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1ed6313f	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x230d9e56	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x2cb1f886	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x2e2ecbe9	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x542eb8e9	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x6132617a	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x67e41efe	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x6f2fdbc2	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa9a091d5	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xbb8b1e43	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xde0744f8	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xf045b49c	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xfc6d985c	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xfe0e6677	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x06b45080	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x06bdd3db	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x06c15425	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x06d28a2b	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x07cdcea5	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x08a74566	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c3610bd	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c818efe	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x10a23fed	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x12bda65e	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x132d882c	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1615a3e9	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1744bd7e	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x245ce021	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x29578f5f	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x29f4a119	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x305bab07	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x36748d4d	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x37e06173	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x37ff3ddc	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x391bd2b2	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x409ea349	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x435d1c50	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x49886bd3	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4ac72af6	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4d79b3a1	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x520b2638	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x563371e3	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x56fe4910	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5c7d83ef	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5ca1743b	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x652dfa8a	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6901c2ae	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6d42d1b9	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6dcbf846	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7271aaa6	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x72b33fa0	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x75b5badd	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x75c95539	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x77388016	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x78dd6089	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x790cf6ac	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7b32e465	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7f0e7350	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x85e6bbfa	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x89108f99	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x892c373e	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8e29f6ec	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x908563cd	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9bdac734	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa1a0f1b0	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa24dce38	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa4b3516e	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa586addd	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa663ba0b	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xae3511c8	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaf6ebb23	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb17d3717	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb1a312e1	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb4966987	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb4f1179f	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb73f4ba1	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbf86fc56	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc23a974f	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc26c1234	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc486341e	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc4aae2ac	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67d36a8	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc7a60594	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc8b247c3	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xca87ba87	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcbe26fc7	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd09cbd41	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd35bba82	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd4f7796d	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd60cc9a2	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd6474cbf	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd9f5f8b7	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdeaee22f	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe103a195	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe98b4507	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe9c87032	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe9d689e6	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf2efa08e	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfbc1c3d3	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x57adaf42	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x5dfc07ca	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x67e48745	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x75b5236e	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x77c06346	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b01c02a	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xc1d5ed2e	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xc407230f	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xc69332a6	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xddccbf7e	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xefef5138	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xfceba45d	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xfe867eb2	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x0f7078a6	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x3676d7d1	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x4762bc33	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x5328d7a6	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x5837be9a	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x70435fc7	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x7da184b8	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x862dd961	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x92574c5d	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x9a1cd50d	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xbb121908	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x34f66f13	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x93a919fd	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x103da584	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x1678f545	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x19516e7d	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x352f8186	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6b8ddbaf	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x72ea6f82	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x7429d646	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x8f713b8a	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x917f8979	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb8b5ee89	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd40ca89b	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xdc5fec4e	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xdedb4c3c	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xeb25bf4e	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf6719fd3	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x0042f2af	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x216407c6	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x2190b0d6	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3f977fb3	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x602990fe	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x681340ed	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x740ae325	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7df0a32e	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x8681ee40	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x97effc99	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x986d1bad	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa1e9ad52	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa81c3f3c	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xc7cdcd33	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xc9285c48	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xca452fa7	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd4b6a0bb	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xdd23d72d	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf81596a2	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xfa3240c8	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xfae1d3e7	rdma_get_service_id
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x10b25944	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x3b10172d	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x7d58c58d	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x93ec78d3	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x992e5daa	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xcafd182f	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xd286509f	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xec2e36ac	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xf8dbd129	gameport_open
++EXPORT_SYMBOL drivers/input/input-polldev 0x263d30fe	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x76033188	input_register_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x99a58054	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xa6036af1	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xae30c23d	input_free_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0xc3d80db9	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x3a35eedc	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xd7100c58	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xfc98cb65	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xc5be4c9e	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x0837fe3d	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x506a892b	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x7a82b515	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x8ab11e21	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x9dd85266	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xe1f6286a	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x219a1ad0	ad7879_probe
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xc1e3d419	ad7879_pm_ops
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x1484c964	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x27fac3a8	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x4eee04a6	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x607b4a0d	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x70d08166	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x73d97de4	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8b0a6868	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa7c4fd6c	capi_message2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xabd5a50d	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc10fe128	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xd54bef01	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe8ad9bd1	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe94ed2a3	capi20_release
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x04abf6d4	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x04da3ffb	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x29251bb7	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x2c66e97b	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x48508764	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x4ffc7853	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x570666b0	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x7095d3c1	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x70fa7e1f	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x81b1b0bd	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9a85de03	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xa07dd793	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xab93d90a	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xe34aea41	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xe92e0dcb	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x097fe72e	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x15a83737	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x1a0a1120	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x4a6275ee	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x58cce221	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x595dac6d	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x72bd03be	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xb178a387	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xf9bd3d89	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0x29562993	b1pcmcia_delcard
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xaec3240e	b1pcmcia_addcard_m1
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xea620116	b1pcmcia_addcard_m2
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xf14bf8b1	b1pcmcia_addcard_b1
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x6daf7002	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x7dd1f2a2	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x8d841cf6	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xc836ddcf	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x4a804008	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0xd17c2cc1	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x17ea45c5	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x470b71e0	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x4e12f9fa	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x77e7f2ff	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x7da5b853	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xb38ff8fa	isac_irq
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x69568aba	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x8cb467d7	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x92c4babb	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x0df4d8c7	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x0fe7d343	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1f06ee6a	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2f0c670e	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2f318f70	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3347843b	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x347578a6	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3e7a6031	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7262cf61	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x73ea2946	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa6d3ba03	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc2a11d73	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc5bf8fb5	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd42e4e8e	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd795e5dd	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd7dfebd3	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd897753f	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe17b5874	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xea8e24e1	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xeda24848	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xee6804bf	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xfa81f7f2	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xfe42312f	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x0c4d0956	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x10dc0d06	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x26c59710	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x370b8283	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x66d28e22	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x6969b5d8	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7b55ca4f	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x91272803	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x9e8b3cee	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xab2d2b84	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xad29a6f5	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaec09a2b	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaf77343c	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xc04554f7	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xc0b9ef00	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca580595	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe47e0829	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe67c2d16	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xef2790fc	closure_put
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-bufio 0xa7978f56	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-log 0x0ff74b3e	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0x2c561b97	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0x3f05866f	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0xcc12bbdb	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x246c4504	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x2e586af8	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x4074b2a3	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x762abc00	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x8ac46412	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x8aca9ceb	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/raid456 0xd0af1d85	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x03b2de1a	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x11a24de6	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x36b31d5b	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x3d1ca0fd	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x42618527	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x435b2763	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x43667070	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x494b151a	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x8eaecf06	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x9004e33d	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xbe42423d	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xc346959e	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xfa80bfbb	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x204ddddc	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3c6f0fe3	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x6896abf8	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x758e133d	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0x190da31c	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x0fdb7385	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/common/tveeprom 0xd271f0d3	tveeprom_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x02657340	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x07da9f92	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0c736816	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x112bca86	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x19591134	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x22d6ce4a	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x23f566b0	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x28ee2ae8	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2960b352	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3314df55	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x38a9c898	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3f7224d5	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x49711424	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4d3b9a9c	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5342588f	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x53815b7f	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x627e48f4	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x65886421	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x681835c7	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6d26aa55	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x78d62338	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7a11cb71	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7ba5d8bd	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x87542111	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8a8d2e1a	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8e47dce5	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x975e5f30	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa20667fd	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa258c6cf	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac7f4988	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xadf2326f	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc1e39616	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd09c9aad	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xda4dab36	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdb576668	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe0eba0e0	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf3cfd82f	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfe84a9d5	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0x8187ff1e	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0xcaa895cb	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0xc9d5b3e1	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x2b9853c7	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x363c76b2	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x47c3826d	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x49c80d29	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x52e2d0cf	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x69619c61	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x94343f82	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x9631aee5	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xeefe8f20	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0x404decfa	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0x807095e7	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0x233385fd	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0xeafd1f6a	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0xecaa4921	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0xdb063d90	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0xeaf7ff95	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0xa4f0b654	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0xe554faf9	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0xc44f32ed	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0xd5d56440	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0x1ca45e0c	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x51e4bdfd	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xa9f5e451	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xbba7d749	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x02c90244	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x232d15c4	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x6cf22a73	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xcc8ba91a	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xeaec8730	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x29b719e7	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x2ede24cc	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x33f30c05	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x47d0f23d	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x4d032ebf	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x564d8c4f	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5dbb0d25	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x72cfe936	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x830bee5a	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xa5563b0d	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xbcb163c7	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xc5cf4625	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xcd5b1596	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf14d1b33	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf2d27e7c	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0xe0c412fe	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x2f54ac86	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x69bdf267	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x6eeaaeee	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x8405390e	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x9fa856ef	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xdeff0534	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x39ddb4c7	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x85e7d408	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xa8774fa6	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xc2768d86	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x218f4750	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xe36e09aa	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x11a39477	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xc3ef7aa5	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xc76c2587	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xdab1246a	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xf70c33e5	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0x1af82210	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0xd65d6752	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0x52a723c3	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0x4ffaa5b4	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0x6eacc656	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0x27206d45	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0xf23abcb2	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0xa0a31a6f	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x7a3f3fc0	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0xaf171444	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0x58df63d6	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0x87b0844d	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0xec134a25	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0xcabce788	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0xab6fb26e	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0xa65be343	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0xb45b2cfc	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0x0d06c74d	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0x0807be91	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0xde671c23	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0xe466f752	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0x1f3aacda	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0xc5f0a29c	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0xd18062c1	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0x5d193c88	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0xf5dc105d	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x69b594e4	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0x7651122a	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0x3490f7fc	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0xdc6190d3	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0x564c1289	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0x67bf60e6	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0x1f21edaa	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x39ebb10c	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0xad3f4358	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xdf0cc241	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xe49a049e	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x3c92fc16	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0x328ac184	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x55aa7db5	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0xf1fe866f	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0xa24b44ae	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0x5d715593	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x00c16cdb	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0xd3f5eeb7	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0xe3bb9f94	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0x0c9b3663	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0xe21973e9	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x956ff0e5	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x9636c8ff	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0xf54cd9c0	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0xba1fd5bb	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x7b52b740	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0x3c208ca6	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0xed358f9d	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0x77791b0f	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0x7949ac49	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x450ba910	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x711e0178	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0x0950eede	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x36fcbb79	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x4e8985a1	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0xe3a6d45d	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0xf8077162	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0x515c7780	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0xcb0bf11a	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0x1a415cf2	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x684c5413	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0x2a98e7af	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0xeafd5fad	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0xaeeb6ae6	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x0923d0b8	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x5fd2a263	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x64e1741a	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x66fc1ee8	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x7bae7a0c	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xd0d3d2e6	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xd63170ef	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x5d56d75b	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x69a8969a	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x7d4e2b32	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd3263840	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x319a744f	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x6dd90b5f	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x7d541ffd	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x4a73ec2c	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x504d09cb	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x53a274c5	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x71ca0208	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x78c242e7	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xbdf94737	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xc3e0d68a	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xddf38ec3	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xfde00a8c	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0x3b9acf32	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x0939eec6	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x0d4f628a	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x4ebb16a9	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x5876c075	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x8dafbc89	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x1b7dabaf	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x180c24aa	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x1c6df8db	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x301ffd64	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x74f900ff	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x8c69c562	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xcfe423ab	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xfe3d6f51	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x19ceaed9	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x38c4e67d	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x77445687	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x785b02f8	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xc94e20d7	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xf137c447	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x2575bb44	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x36d08d64	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x6bc9aa48	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x6ec4ceba	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x858247d2	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xa5cdfd18	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xda15d975	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0c4d236b	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0e4ef3cb	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4e433b1d	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x681559be	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x795dd6e4	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7d56285d	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x8184ca64	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x8ee8ac13	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x936cceab	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xaafec0ce	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb3a0bdd4	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb595e3f3	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xcb547eb2	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xd3c0597b	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xd5341703	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xd8482b3f	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xee1127e9	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf4088dfc	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf5e63142	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf913329a	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x1cb7d902	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2c4a4a2e	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x4d8e9ce7	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x516a4a76	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x5d62378e	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x75fe1ee2	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x91bba334	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x9d630171	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xaf018e4a	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xb4ed1dfc	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xb87d9590	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xd557e7a7	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xe955558c	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xeec759ee	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xf771054b	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xf9450204	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xfdbd4050	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1d23363a	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x277fb4bb	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x5b2dd3da	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x6bcf7b74	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x81cd8020	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x907d21d6	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x93ea5d7e	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x9a3c56b8	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xd4959162	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xeac8f4c9	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xf659c77c	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xfb69b719	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x59001252	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x5fcb7f6e	videocodec_detach
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x77024b65	videocodec_attach
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x77f0a918	videocodec_register
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x887352a3	videocodec_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x268a9a79	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x7ec084f7	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x7eedb967	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x8f4c8141	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x9eff06be	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xa7b61d36	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xc48bdc68	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x08186573	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x1aa7e314	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x5182ce1d	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x5b8e09e5	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x8760dc90	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x92d8e1bb	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xf8754188	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x4b22d942	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x7c416196	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x7cf0d9c5	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x7e935ccb	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x98dadf5f	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x9e65ad87	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xc5120588	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xf54f4ed2	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x537ab565	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x75ddc788	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0x06e8b7e5	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0x8b82bbd0	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xc06f5117	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xdd3e0140	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xdfc2702b	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/max2165 0xca119bcb	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0xe914dc98	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0xd074615b	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0xe83cd67e	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0xfb6f4467	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0x615a9a6b	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x82c0474d	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0xea77afd9	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x6395ab15	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0x91851d76	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0x4c7cde47	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x06b8b23a	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xc768fbee	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x4aebf7f3	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x5c8aa29c	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x60ba294a	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x64e02ddd	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x78fad13c	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x8e6661a7	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x90ba3d27	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xeeeacf1b	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xfeead39a	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x3ff428f0	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x76121809	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x76284e60	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xd5ab2dea	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xdf60b985	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xe33f03e8	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xfed0b043	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x251d8382	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x1e20afa7	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x38d5788a	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x5892b1b7	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x652ba2bf	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x7492e562	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x90934aa4	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xaf8dce01	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xcd14a1b7	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xd7c88fbd	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xe4429baa	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xf0d09244	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x32b136d6	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x6a93cb86	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x3e5c10a2	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x5f82ee33	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x78262bbe	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x7cd3f073	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x7e109b83	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x948236fc	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x98115f26	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xa5f87276	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xda3415c6	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x0099827e	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x223a9459	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x3ec3cadd	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x4c2a8998	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x5f7aba69	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x92c28773	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xd395cced	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xf0d01c1c	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x0c52fa94	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xbbc62e64	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xe360188b	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x5ccf5ddc	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x77085c16	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x2edd06d0	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x49124aac	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x4b6009ef	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x03bc9a0b	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x073e85d3	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x2617ddeb	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x533b3e0f	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x6da4c3ec	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x70373bbb	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x298b8b85	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0xb0f9895d	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x3ba88695	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x616c9ff3	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x9bae75c8	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x9cf78784	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xd51a770e	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xecfc8645	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0x17548050	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x028d52ca	v4l2_of_put_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x02d2e6f8	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x03f51836	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0653c1c3	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0d14e638	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0e7ec6f5	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x12e807fb	v4l2_of_alloc_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x166fb734	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16e2da7e	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x17a0f43c	v4l2_of_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x18954a37	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1a8bedd3	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1fb0d2f7	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x20031317	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x20e3b941	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x27d72784	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x317a5584	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x35e866e7	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x373380fc	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3fa0b03f	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4be51bee	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4e4fdead	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x585d9f24	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5f255e6c	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5f66bc47	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x61086087	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x61d89caa	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x63d66693	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x654961f4	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6d281b56	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6d2d5031	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7592634e	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x762e0937	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7c9c54fc	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7f93f5b0	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x834b6d17	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x86752e81	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x880c37de	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x88c39679	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x90a055ff	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9268e953	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x93058a3c	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x939e1d5a	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9cd868f0	v4l2_of_free_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa6277641	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xaa3d89e8	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb2ca887e	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb4743eea	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb59d60da	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb6e90217	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbeea2806	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd5f39646	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xda428119	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdaeb2050	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdd121dd2	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdffbe020	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe231041d	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2e30272	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe531c90b	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeb9646a2	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeca787e4	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xedc4b53b	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf11d4a3b	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf1a45f45	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf30408a1	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3788b57	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf37a293d	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf5a262f3	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf60231a3	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf74a3b31	v4l2_of_parse_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf8e62783	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfe1d6530	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfec86cbb	v4l2_queryctrl
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x0415bf27	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x23b0e19e	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x3a767ccb	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x42bdf482	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5fcabfab	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6bd7641c	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x7ee3c727	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x8d49920f	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x930f6229	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa5987a36	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xb3f1cda0	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xb490d2fa	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xd4dcace6	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2aba0322	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3803d52b	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x45bccac0	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4c0f377e	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4d438ffa	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x5ce2b981	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x605d3b48	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x629ae04b	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6672042f	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6784181d	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x7185c376	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x76b8a35f	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x9270d792	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x9c95d885	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa4564169	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa83e3c9e	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xad4b83e4	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xbea10016	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xbeb7a1b8	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xbf8bce98	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc9537dc3	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xcf1ff5c1	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd19ff8fc	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd67e1a34	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd8acb4f1	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe254eb9d	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe6940d98	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf08fafb6	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf0b77d76	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x11c87a7a	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x13689b27	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x217d761c	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x26912720	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2abe25ea	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2bb3b933	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x333c40fa	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x3b1e679f	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x3f4bf2bc	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x5109f97b	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x5d02c32e	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x6cb953b9	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7024adca	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x716d4ec9	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x71d5ca21	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x72ef578f	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7835b6f6	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x80f24dc5	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x82bb2731	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x85c1fb50	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x8ea3ca9b	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xad1e51c9	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb8e2cd17	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xccd367ea	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd6633530	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe3d6b39d	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf507ef77	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/mfd/dln2 0x3ed4fcf3	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0x843e3d22	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/dln2 0x9f55e40f	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xece43b1f	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xf94c759c	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x06082208	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x125371d4	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x219ca60a	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x50f8391f	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x55bf68fe	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x57a2a3b3	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x64da79d5	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x6d46d15e	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xa015e333	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xcce0212c	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xec9f7153	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x327b6041	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0xf8eea40d	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x1bbea26a	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x5793c5ff	wm1811_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xc8f1c7d2	wm8958_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xfacb7c4b	wm8994_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x13c026da	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x6b69edc2	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x37cbc168	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0x42c8ce69	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0xb8ae2ef5	c2port_device_register
++EXPORT_SYMBOL drivers/misc/ioc4 0x8d5f4708	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xbaf7f2a0	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/tifm_core 0x3594332e	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x39f86aa1	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0x3d1fdb2e	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x3fe23021	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x7e3513a2	tifm_add_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x8292eb2e	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0x845a3944	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0x8541fe69	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x94b33266	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x9533e8a2	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x98efcddd	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xcb5a2680	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xea220e7e	tifm_map_sg
++EXPORT_SYMBOL drivers/mmc/card/mmc_block 0x270316f4	mmc_cleanup_queue
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x4004c83f	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x420ca555	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x71974e91	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xc34dc677	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xd13059b0	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xdce0778e	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xe38fb640	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x045309a8	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x4d3df223	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x68acae18	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xb670264c	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0x83b4f6ee	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0xac72ffb7	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0x6b6f237d	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x6f0338b5	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/mtd 0x7cc3c6cb	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x168630f6	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xb15adab1	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x097c6d62	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x41c91568	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x54ac2dc3	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xb4244a1e	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xdec812ae	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xe5d794b2	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x913c7826	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xdb5e2f40	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xfd7177b8	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x09854a34	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xd00015da	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x0902661a	onenand_default_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x2701be25	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x36831dea	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x41f3c4d7	onenand_scan_bbt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x358d3a4d	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x3c93f893	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x53808281	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x5d43bda5	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x813256a5	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xba443d49	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xbf1c3210	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xc28446db	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xe28596b5	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xeaf51d0a	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x0d63893a	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x914fc744	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xcab9096c	com20020_found
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x1686d8af	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x32a89899	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x6225e116	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x6501929e	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x6ccfef95	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xa76d1685	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xa888966f	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xa93a4a7a	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xcf81938e	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xda4cc986	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0xaf6e2268	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x44adc551	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x03349e81	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x0bca4cc5	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x0caac0a2	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x138a0696	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x1e001045	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x1e098e65	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x341bbf62	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x412a7904	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x49464224	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x59ed63e1	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x631e2cec	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x768c1773	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x7f6351d5	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xb1b36535	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xdc4f8913	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xf347b078	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x05ec7ff6	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0c43a498	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0ca67cc4	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x12d51d0a	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x133c9c7c	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x18673469	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1eca4fdf	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3b880136	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4645b7dc	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x476496c3	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4d8992cc	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x538c309a	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x55df9e94	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x58136816	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x59a09a34	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x60de3ba3	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x614c86c9	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6c40cce0	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x76236da8	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x77f5a90b	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x78e8e905	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7c879af3	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x807f9a2e	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8843eb36	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9f9a0581	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa2eafcad	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa2f6119b	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa46621db	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xcbc84a55	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd683182f	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd74e91fb	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd8aee25d	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd9ac7465	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xef998571	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x0cb8af04	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x24b4ece1	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x467bf3d3	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x52fcc26e	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x871db4a5	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xeac8a862	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x42d9086c	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x5a7d0dbe	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/freescale/gianfar_driver 0x79f28897	gfar_phc_index
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b72ffff	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x10191ad0	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x12e9691a	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x16d8b78b	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x18ed6c1e	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1a7408a2	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1ac59a17	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x392ac12c	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3f6f3c1a	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x40e99e1f	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x48bd8550	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x58abcab9	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5f7dcffd	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x634b4054	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6aeebd04	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x70acb452	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7370ec7e	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x77528ba5	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7ae31d77	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9846eefc	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x997e1cd9	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x99f0570b	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa5e73c55	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa9a0a14a	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaa558940	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc63f0bfd	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xca6f8c25	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcb2e01cb	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcc87eacd	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd877fcfb	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd93b33df	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe56335dc	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xeb953c7c	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xedd2a14f	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf2d7634b	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf61573e2	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf7930239	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfb5993f1	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x04883c7f	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0c2f0069	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0e98c2f7	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0edb047b	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x10824197	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x183b4111	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1de23a07	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x213a8a27	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2812be6a	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2c44b840	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x38867d7e	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x541e7f95	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5cf50091	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6437170b	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6b8fb786	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x72b5f87d	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x75a05802	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7cac34af	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x99a17b67	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9adecbd0	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9e2264df	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa2b168d9	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xadcd6c17	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xaede583e	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb2d3518d	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb3efecfc	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc80a9218	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcd94af10	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcd99b519	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd16066bf	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdbc06d7a	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdc1f9884	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe88f903d	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xed4dd651	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xedfbc226	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf08632e3	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf23c08c3	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfe747063	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x40690181	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x4fff95e2	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x791d0f51	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x9e22b5f3	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xac451dea	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xba89b849	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xcb5c8545	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xf998e95d	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9d5e5309	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x193cda30	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x308200e0	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x44277a4a	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x6dc1e8fd	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xf64d7558	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x40654f47	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x563920f0	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x567dcc52	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x66ea29b3	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x7369c00d	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x76ee6094	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x8d3e8f66	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x948b320b	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xe03ec3ab	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xff413c8b	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x2a7a2eaa	mii_link_ok
++EXPORT_SYMBOL drivers/net/mii 0x634fbcb6	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0x6c03ff93	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0x956b591e	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0xc17c58a7	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0xd44b686c	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0xe41674e7	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0xf0cc140b	mii_check_link
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xbf8516fe	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xff049c2f	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x9a3c0540	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xeb5a6691	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xf4c4fb29	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/vitesse 0x9c16bc5f	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x052e770d	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x3a50934b	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x885ed395	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/sungem_phy 0x640a16ea	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x0d06d479	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/team/team 0x4601c2cb	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0x4e97c77f	team_options_register
++EXPORT_SYMBOL drivers/net/team/team 0x5d83d3fb	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0x923deddf	team_mode_unregister
++EXPORT_SYMBOL drivers/net/team/team 0xb95343ba	team_options_unregister
++EXPORT_SYMBOL drivers/net/team/team 0xcd40b48c	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0xd0fdee2b	team_mode_register
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x48aff3b4	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x7c86b417	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x840ed181	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xcbb72bb8	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x1c5cd379	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x3d73adc1	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x50a24b29	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x5b7c5298	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x62763292	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x6b87ab2b	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x86360ad3	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x8726d23e	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xa051d6e5	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb2971aa9	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb8da1b78	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0xaff100ae	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/airo 0x302a1969	init_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0x787eeae8	reset_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0x91a93329	stop_airo_card
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x0735987f	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x21d63857	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x23691c38	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x40001632	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x60209bf8	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x62e0e132	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x65c0b556	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x895d34e5	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xd0346824	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xd74f624d	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xe87e6c65	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xec89592c	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x36597409	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x3b770919	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x49f0fa80	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x76c879fb	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x8c2f897b	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xa319bddd	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xbf1e2ea1	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xbf538a5f	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc1c60fcb	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xd30f256f	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xdf70db58	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xe0fa94c7	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xe18223b7	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xe680fb54	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xedf0d080	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x0cafc48b	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x31b831f6	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x5f2a5053	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x65a60823	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x6c52ea42	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x87aeedf7	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x9cbe1d60	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x9ed3ecce	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xb61946e8	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xdc8c11fe	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xf47470b4	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x07f281c4	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x08e4b1ef	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1120ab7c	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1feeb62a	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2349e002	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x285fad1b	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2f6e364c	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x39a9a5e0	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x419f8666	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x421319c8	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x53301c46	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x54c426e2	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x73bbe6e7	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7b051111	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7e46d176	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x8dd71178	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x94b5b238	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x95518f1a	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xae98ab2c	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xc292f9c4	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xc6e2ef11	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe424ad6f	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf86cc416	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x004f32ba	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x04e90265	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x09c5515b	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0d8f6006	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x134dc7d4	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x139025dd	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x180f5ea8	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x183f649d	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1a83e513	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1ad6a9a9	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x20e79b9f	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x226252fc	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x232fbdb8	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2570c306	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x25d97ccb	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2776809a	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x297b8d73	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2bd9bdbd	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2e3d7dc0	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2e963871	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x36401f68	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3826ca23	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x39ec2865	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3a3b0c4a	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4181a8ae	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x441fd0d5	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4f0cba8a	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x53eed77c	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x560c9ae1	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x597cdb7d	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x59cb54e2	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x59d80b37	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5a296824	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5a809dee	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5fb70de7	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x60a415c4	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x61909bea	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x678a6582	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6ee1a041	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x70198db3	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7379a32c	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7639185c	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7c335d41	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x819148b3	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x81b2947a	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x836dee71	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x839bddaa	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x83ab57f9	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x84d69946	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x892e3d9f	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8996f028	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8b926426	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8c032392	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8c62414f	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x910a8452	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x91fbd84f	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x925d6f38	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9271b4c4	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x944ec8f5	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x95cc8e8c	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9905f57d	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x99f23293	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9e147f57	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9e253cbf	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa0437c66	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa23e6ee2	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa254e3c8	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa26e1b9d	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa2aba45c	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa2ad3081	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa2cddee9	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa48a033a	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa640b4c7	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa6516875	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa7bf6e54	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaa063195	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xac7ca4b9	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xac9571b7	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xad4a9160	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaf388a25	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb2d9e0f6	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb57fb720	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbb79fce0	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc3143787	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc3164ce9	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc86d39a0	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc88ded53	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xccb524a5	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd14e9625	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd1bcaa05	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd4771e3d	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdbacba0d	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdc3cbbfb	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdc3fdebc	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdefd41f6	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe0b86bb9	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe8ad1ed4	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xea582764	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xec6624d0	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xeceab20e	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xefe21360	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf7e17561	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf97704d2	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfa85d3d6	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfad002ff	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x0ba7ac0a	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x5edee60e	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xb637895b	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x1b1ef576	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x1d1d2ad7	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x2aaff636	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3537712b	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x457920de	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x480f3e14	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x66a2d128	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x72102faf	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x876be059	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x90eb0a63	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xbbe11bcd	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xc3477ae5	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xe538f59b	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x090b12a0	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0ad0bf9c	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0ad69602	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0b1c8cc8	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x15db1b5c	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1d41fcca	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x22ed46fd	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x31a693e4	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x374bd0c0	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x4ac1a14d	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x603e6a23	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x71533807	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8875d998	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa37e700a	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa3fa33d1	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb3a6c7d2	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb7303921	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xbbcbee12	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xbd011eb9	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc61ecf3b	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xcd5cbc14	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xdab2e3a7	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe17eed33	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe29cd2f5	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xed200c4a	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf2b32067	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x04a1a4d9	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x15379563	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x23870e19	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x254d6443	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x30c2ea2f	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x380986fe	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x39ec8b6a	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x40e6f43f	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x41141df4	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4399f23e	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4cba5d90	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5ef7f4e0	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x67a9f41d	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x7e33b594	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x7e569993	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x8ee88bf6	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb4832bcb	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb7c10f6c	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd1357973	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xea27ffe1	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf69478c2	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x018d9df6	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x019957bd	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x03238f6a	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x03c66e62	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0a96c842	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0cbe643d	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0e4143d1	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x10616935	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1686a8a0	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1763fcce	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x17f01e58	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x185bb1cf	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x196d1879	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x19af0445	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x20c24545	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2325a966	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2467db9a	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2abb0eae	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2becdf4d	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x30430e5a	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x39253442	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x39ef5752	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3a3c2b5e	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3d267b90	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3ddf083c	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x47a426b5	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x48c90528	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4d8303ee	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x50ce8824	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x55330995	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5aa23e84	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5b6f2391	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5c7e5ea4	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5d9dc45f	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5e6df73c	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x68a7894a	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x68dfe9fe	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6a66b0b3	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6eb2a0f3	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6f5605db	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x71d3b049	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7281c9cf	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x79bc238c	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7a33f9ac	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7ba655d4	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7c875e13	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7d3a1946	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x803f7744	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x80fbe174	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8609735f	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x870758f5	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x871feb21	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x88dc1917	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8dd0dd9b	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x938a5a34	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x93ac1ae7	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x94f67bc0	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x95532e9d	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x98b42dda	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa0a762b5	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa18a4477	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa2ec639a	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa43a81d9	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa7c199a9	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa99af640	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xad2b0769	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xafb05f37	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb2b405fe	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb8a3c9ac	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb99b402a	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbb77fca5	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbfb6243c	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc1ac042d	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc219c82f	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc4999257	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc629e509	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc93a9f5f	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc9d8442e	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcc7f0012	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcd12a381	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd0a2412d	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd2de639a	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd2edf895	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd3de33ca	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd6a3cf75	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd7fb9ebb	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd8a3b056	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe157d08e	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe21636ab	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe40ce4dc	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xefa8b28b	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf0bf232b	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf37c606e	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf87f6041	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf8f76e1a	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfb9b5e52	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfc1d3a2e	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfed34c3b	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x08c6664d	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x4379786d	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x95a8ab3c	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xa2b6ec39	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xb69add1f	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xcd60e86e	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xd4f50457	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x1e390e48	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x1f597d9e	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x2da5c7bf	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x347d4691	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x35a11733	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x49add6b9	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5dea5bf1	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x76700bac	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x82605b0d	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x83f004fb	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x9031f40b	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x9cc5e0a5	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xbbbe0bc6	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xbd309a81	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xd7e2072f	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xdfacfa1e	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf6702e49	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0xff8aed9d	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x03da41fd	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x04f9d132	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x08d29b5e	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0a623072	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0fd7021c	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0ff54131	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1299620f	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1fbcccd3	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2100da21	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x249980b3	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2d76d90e	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2fe2042b	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3068e590	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3166ab97	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x340a7af8	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x39c6b7e4	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x425a3877	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4500e0ac	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5080deae	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x53905ca9	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x70720a21	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x72b2ac94	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7599d7d4	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x76399a23	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x77eff227	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7e0622f2	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x82ddea6b	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x83590376	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x96d8cd49	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x9d230bd7	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa2eac4cf	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa6618889	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xaa0e1281	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xaee6e178	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb0f3189b	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc2d596e9	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe23c3421	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe3500638	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xed97b811	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xfbe1ac03	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xfee46034	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x4975ed1d	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xcdfdae1f	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xfeb68007	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xfeb852ff	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x2901bb47	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x35013451	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x351c4f73	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x8f9acaf9	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x25042ce8	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x25d0175d	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x30a109c0	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3599369c	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x35c7b698	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3e87a014	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x40f58107	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5ba46674	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5eef4230	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6037e24b	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6a520147	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6bac584c	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x7ce82154	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x83ada940	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x87b08c92	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8df84678	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9ebc2e82	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xac58df4c	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xaec91eea	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbaaad7b8	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xcd194fc6	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xce068640	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xcec8b19a	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd40b17ed	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd80d4f70	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdc7266c6	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe4560bdf	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xfac9f835	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x3a909a67	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x922f6d45	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xa6fd9afd	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xd684b2fc	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x728d847a	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x90e056ce	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xa1418a4b	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x2002a616	microread_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x3cff17ca	microread_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x3720241e	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x91a8afbd	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xe8b2bad1	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x22e3748a	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x3db7c716	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x54893135	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x7d6ab7f3	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xe18d34ae	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x0252182c	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x6216ed40	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x6329237d	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x7062b144	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x71582267	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xa060e264	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xbfc32849	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xc53b9fc3	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xe1be96a3	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xe222665e	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xe4838a36	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x01c75091	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x1ee014a6	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3750eac7	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3759e523	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3ebe5af7	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x4b67a795	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x50882a19	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x5d27e60c	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x6d9177bf	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x7c410cb7	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x9aacb2b9	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x9ac60646	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xbb686c1b	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xbde6a718	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xda9ab6cc	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xe22ea6a0	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xf2c48c32	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xf40d1af5	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/ntb/ntb 0x4a092c18	__ntb_register_client
++EXPORT_SYMBOL drivers/ntb/ntb 0x5a8a65e0	ntb_link_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x7aa6ccdd	ntb_register_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xa0e3386c	ntb_clear_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0xc30302a5	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xc5f982f2	ntb_set_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0xd29a31b8	ntb_unregister_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xd3a488c7	ntb_db_event
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x4e9913b8	nvdimm_namespace_attach_btt
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0xa215eca7	nvdimm_namespace_detach_btt
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0x731a11f2	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x00439f4e	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x14177c73	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0x2762cf30	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x31d506bf	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0x3497e232	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x459838ac	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x4cb43e48	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x59cb0832	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x5fc3274c	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0x63d5f4d2	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0x6666b3af	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x6691c32f	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0x742a4937	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x7d056d4d	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0x90f0c33c	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0xa2611ed5	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xa45cf977	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0xab4d1831	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xaba16dc2	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0xb0cf251e	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0xb45069e1	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0xb8ab5997	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0xc581e71b	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0xc6f7f5c2	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0xca4917c4	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0xd24639eb	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport 0xdca7ca15	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0xe211d7df	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0xe5b18dd4	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0xef6916a5	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0xf309c29e	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0xfa283510	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport_pc 0x4c6117bf	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0xce931812	parport_pc_probe_port
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x027efd39	pcmcia_fixup_iowidth
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x0711bddd	pcmcia_unregister_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x092ba444	pcmcia_write_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x15ae7350	pcmcia_map_mem_page
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x18b66cc5	pcmcia_disable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x1f408404	pcmcia_enable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x20f743c3	__pcmcia_request_exclusive_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x2acd7bcd	pcmcia_loop_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x4160e30f	pcmcia_request_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x42126f2c	pcmcia_request_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x515b5b78	pcmcia_loop_config
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x742f5665	pcmcia_parse_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x878ccce6	pcmcia_request_io
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x8989ef8f	pcmcia_dev_present
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x92cb7f62	pcmcia_fixup_vpp
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x9ad282d5	pcmcia_get_mac_from_cis
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xbadd209a	pcmcia_release_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xd6f11423	pcmcia_get_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xdb4917b0	pcmcia_register_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xf703d3fd	pcmcia_read_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x212db8d2	pcmcia_socket_list
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x3b153174	pcmcia_unregister_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x5aa7656e	pcmcia_parse_events
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x7a1f052b	pcmcia_reset_card
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x904e40ab	pcmcia_put_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xa8fe0b07	pcmcia_socket_list_rwsem
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xb06abcbe	pcmcia_get_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xbf1dc0fc	pccard_register_pcmcia
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcb2de67b	pcmcia_socket_class
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcf97f3bd	dead_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xdbd70227	pcmcia_register_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xf9b8eff5	pcmcia_get_socket_by_nr
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xfa4ed9da	pcmcia_parse_uevents
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0xb94585d9	pccard_static_ops
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0xf69120ab	pccard_nonstatic_ops
++EXPORT_SYMBOL drivers/pps/pps_core 0x7e64bc52	pps_event
++EXPORT_SYMBOL drivers/pps/pps_core 0x96215e27	pps_register_source
++EXPORT_SYMBOL drivers/pps/pps_core 0xb894237c	pps_lookup_dev
++EXPORT_SYMBOL drivers/pps/pps_core 0xcb58185d	pps_unregister_source
++EXPORT_SYMBOL drivers/ptp/ptp 0x4d4e1ad3	ptp_clock_event
++EXPORT_SYMBOL drivers/ptp/ptp 0x6fc81d20	ptp_clock_register
++EXPORT_SYMBOL drivers/ptp/ptp 0x75b0ac26	ptp_clock_unregister
++EXPORT_SYMBOL drivers/ptp/ptp 0x9905077d	ptp_find_pin
++EXPORT_SYMBOL drivers/ptp/ptp 0xdb18de32	ptp_clock_index
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x1005a949	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x272fddf8	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x29ffd72c	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x742b950c	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x7fa7c930	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xb529d8dd	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xc8861942	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xce93c5a4	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xd0a88363	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xd83e9c51	rproc_boot
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0x62f5fca7	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x45021bbb	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x7aefeb30	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x7ec20293	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xfeac8993	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x070a4eec	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x1c0670ca	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x2d1a67d3	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x2e3f2cd2	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x52746f12	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x847e3008	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x8e0ee43b	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xa209198e	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xbd11e841	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xc6696c56	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xf46e1d61	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xff86f296	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x001a1846	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x06ca172d	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x074f59a9	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0be1aec5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0ca50e77	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x10076c4d	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x14718517	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x29845032	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x29ab6019	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2b110724	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x35f04af2	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36ea0fd3	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x370d8c36	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3ea3ada0	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4bbe82fc	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5225beed	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5af5be97	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5c2f976b	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5d5d14d7	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x619f4284	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x69ec00b4	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6ab2ec77	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x79276738	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7c6f4d4f	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x80300900	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x809c5917	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8a0d6b98	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8e7ed785	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9267d495	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa52af9bc	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa5f1b168	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa6672aad	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb1410b21	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb2ca2b9e	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb4115240	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb447110f	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbce33475	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbf2f0ac4	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xcde6f693	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd0a5964c	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd332fbb5	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd3a03483	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd7dbfc23	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd96bf818	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdb396886	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xed0c1716	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xed7525d6	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf0eb33d9	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfcbe99aa	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xffc89cf4	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x5f4e3eb8	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x6e0fb0d2	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x93c24720	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xe2027ee2	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2b6a407c	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x02fcbbd8	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1773c9cf	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x195af245	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1cb8bcd5	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1d0d2c77	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3016b653	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3065c504	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x355d40be	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x364431e6	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3c2cce6f	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3dd73288	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x49e61f09	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5d5945ea	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x60daaf50	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x65366078	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6a392894	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x701c0679	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7daf743c	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x987c747f	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9cc5ed6c	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa6fd4cd3	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xaea764df	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb1846652	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb4316ef5	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbc614366	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbd97143c	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xce4a20e3	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd3da4725	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdb5c8628	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdcefeeab	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe165912c	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe2aa7947	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe3fbd12b	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xeb805a33	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xed1b07c7	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf810978a	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x249090d4	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x43c8e54c	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5b080e91	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xae282a10	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xbc520000	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xc9fb811f	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x0a48d5ca	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x174791e3	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x18f136ba	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x1fc78c15	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x483edb68	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x5fb4c14e	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x7483dc32	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xc5cfd1bd	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xcdb790dc	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xd35c33eb	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xd8aee946	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xe83a1aed	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x074d099e	qlogicfas408_bus_reset
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x1f55cd70	qlogicfas408_ihandl
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x31822d84	qlogicfas408_info
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3fd8cd71	qlogicfas408_detect
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xa7513fe8	qlogicfas408_abort
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xd4720fb5	qlogicfas408_biosparam
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xe76b3b20	qlogicfas408_get_chip_type
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xeb73b933	qlogicfas408_disable_ints
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf2b95199	qlogicfas408_setup
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xfea6888a	qlogicfas408_queuecommand
++EXPORT_SYMBOL drivers/scsi/raid_class 0x4e2d8232	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0x4eb8b177	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0xcafc3cc3	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x0de9d7b6	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x1c04bd13	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x2c32d3f7	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x59655657	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7b02a923	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x8673bcca	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x90945fe2	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x995c21c7	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x9b8ee30b	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xbaa99d30	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xce9382e5	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd1f433ee	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xefa35936	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x07329a90	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x09cb081f	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x119f8a9b	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1527673e	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x18a01ab3	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x359f97ef	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x470650d9	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x50789d04	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x50d0af66	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x61b32cc3	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x62ac288a	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6332c76c	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x679547f6	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6f9ff2f0	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7a3fb64d	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7c644be2	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x912b307a	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x980e9c0f	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9d0085b5	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9d884909	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa5cf6d34	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa8aea07d	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc5477326	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xcacc419a	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xddc7efec	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe4e836bd	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe787d503	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xec82ad68	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf3ce9732	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x40b6aa13	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x44eae743	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x5fe5cec0	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x665b405c	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x910d36a9	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x215fc948	srp_rport_put
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x3a399fbe	srp_reconnect_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x8a7673d0	srp_start_tl_fail_timers
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xcb104eb6	srp_rport_get
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x05440413	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x0eeae757	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x875e0e69	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x8a71049c	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xbed1da8c	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xdb6886a1	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xf6e42503	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x114ecf28	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x115b1ab5	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0x1f628256	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x4d621390	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0x4dd1b196	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x52106b67	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x5429f79a	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0x56f030f1	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0x6a68bfd2	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0x6fccfe78	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0x7d32c547	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0x8a2738e8	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x931837fe	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xacdb8f87	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0xb7d2dcf6	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0xb86b0038	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xcbff8595	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0xd129d905	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xde4b3d15	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xf4b69508	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1981283e	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1b35ace3	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1deb80f8	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x26fa7e5f	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x27e8d3c1	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x38c46da9	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x448b1653	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x48a5504a	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x54f3835c	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x57658776	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x7e44abe6	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x8202d8bb	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x8bc03388	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x927ec5ad	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x9ec44583	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa50c0e15	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xaa3f15f5	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xaed07442	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xaf1a7ebd	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xb6cfe26e	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xb9beaee4	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xbba40ca6	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xc208bb5c	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe38353bd	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x17885b1b	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xb14ed399	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x163ac4f9	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x656affc1	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x8d09b37e	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x94e696c2	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xcc20776b	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x17c07d12	ade7854_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0xad42a3a4	ade7854_remove
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0xce084654	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0x0c763e43	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x012f936a	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0d2e6439	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0d760831	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x189e6528	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1a16d4d7	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2049f2e1	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x24b51897	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x27dd435a	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2af73648	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x35ae6f83	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x39293897	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4e6d8802	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4fabf49b	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x54234de8	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x55ca6dfe	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5688ac8c	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5857eaf4	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5e0fde75	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6026c25e	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x639ac24b	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x64273dfd	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6cf7986c	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7c336e02	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x82a357bc	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x852c2349	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8e2b57a7	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8eca3f09	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x98bce753	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9ad98077	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9fd5a2c3	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa81c29e2	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xaa580fd3	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb68c32c0	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb762b7f2	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbb0ec905	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbcf84975	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc4c6cad4	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcedfcb2a	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd1abf9a8	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd5376969	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd78fae9c	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdb86bd81	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdc4d3f0e	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe1812863	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe665dc86	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe719a7f8	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xee1a9922	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf145de0d	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf23ac463	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf88d29d6	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x029fc61c	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0404ca0b	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x041ee992	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x110d6f69	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x124ad87e	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x14307e54	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x19ef82f3	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1a48e5ee	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x20d4ad74	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2449260f	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2536a593	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x26d49ae3	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x28ce581d	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2c9bab61	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2d8d917d	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2f6e2185	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3d44a488	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x47b2beb0	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x48a4713b	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4ec21d25	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x50a07bbf	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x65172792	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6e0c0370	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x777ec240	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x78532ddd	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x80e8f4af	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x92da3202	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9b81315e	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9cabaa64	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa63dc596	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa9eca31e	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xab04abae	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xafb892a0	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb7767115	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb7f53e15	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbb6e92f8	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc0d3ad46	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc49b84de	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc643783a	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc73701be	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcd65bf49	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcf4c2491	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd930fa36	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd990160c	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xda979d2b	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe04def75	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xeaccdcc6	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xee27d3f7	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xeec7c81c	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xefca234c	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xefd27439	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf1095d86	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf742ef5d	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf7c6a56f	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfffe9713	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x083af4bc	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0d4af451	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0e3de629	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x192475c7	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x30942f91	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x314000ae	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x39a8c75d	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x401c46f5	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x45399305	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4eda2d09	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5a2c028b	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5baedc72	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6cda4303	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x70f72f86	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x76d38389	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8b70b390	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa126e983	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa8eeab76	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xaa13b198	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xaaa3a29f	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb0101246	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb21f218d	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd175094e	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd2d2b616	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd873b411	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xda59a519	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xda7d46df	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xdc1909bf	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/target_core_mod 0x021724dd	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x04c1c4a4	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0bf884e6	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0ed2af41	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x111a0dfd	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1e2fcee9	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x23780beb	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2a0a2177	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2a5ca19e	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2ad50d89	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2f65ad9d	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0x32286b68	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x33aaf2cc	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0x358b1034	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3afe19a5	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3b4e66bb	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3d40ac99	transport_init_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x461d641b	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0x49c46ce2	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5fdb8a19	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x683e4983	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x68b4c021	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6ae3d7fd	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6bcc5cbe	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6dedb49b	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7091ca56	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x713bbb13	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x755df6e9	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7628ed61	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7c17b801	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dd7b1ff	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x90f5677a	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x91abe882	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x94fb26f1	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x95bc28e3	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0x98b19706	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9a9b0614	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9c93e926	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9e91fda7	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9ed9639d	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa651c8a5	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa996ed0b	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xaaa32232	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0xad90dac9	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0xaee55b2c	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb04456ac	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbb23f911	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbcd6e9ee	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc052aa42	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc183bc46	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc1ef9c6c	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc4220bcb	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc5f0d8c5	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcc484f74	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcdd03faa	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xce471529	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcef84b5f	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd2c23b13	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd5e054ae	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdbd8ac2e	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe28bc6be	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe39e8d98	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe409af16	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe4c93d2e	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xebeaf7d8	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xed2967ef	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0xee0a6ba5	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfa189eff	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xff3d0844	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0x6953c4b3	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0xfd47aab3	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0xe2a2db32	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x0163e7d3	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x2dabf451	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x40c5a555	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x541e368b	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x8a25ffc4	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xa65bd882	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xa740cc59	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xb7f9fd43	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xbd6ed433	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xd62b78b0	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xe0ed2822	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xf21f5a30	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0xb4c12e86	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0xdd8edbab	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x2e91ca97	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x367ce26a	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x59f824d9	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x7bda5e6d	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x821e9390	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x937e412c	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x0d348133	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x1aa28b5f	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x7acc4b52	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xd0c2bed3	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x02c4e90f	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x39f3c8d9	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x579df841	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x7aee200b	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xb78b4846	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xc479bd18	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd6c95482	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x85ac5ff7	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x056a6764	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x7f18a972	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x9dff28bc	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x5dda3256	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x7df3a0eb	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xdf693d96	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xef41881b	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0x3880da7d	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0x2df40e5a	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x12629fd5	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x2cc4ab4a	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x6bd0338f	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x80e9c4c5	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xa95ba08f	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xe1a33905	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x2771265f	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x67ca744b	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xad3f430d	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xb3191671	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xbf776780	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0x8d960197	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/virt/fsl_hypervisor 0x45fd1882	fsl_hv_failover_unregister
++EXPORT_SYMBOL drivers/virt/fsl_hypervisor 0x77c9b191	fsl_hv_failover_register
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x33b6e13a	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x80ead7e5	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x83bb0c24	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xa71e438e	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x957115df	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0xc203156a	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x40e8da3f	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x6c0156a6	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/wire 0x58a19d55	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0x777defa6	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x8e4dd853	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xdc473bbf	w1_register_family
++EXPORT_SYMBOL fs/configfs/configfs 0x0095f0aa	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0x03b31115	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x0f0a152f	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x13c61042	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x397bd6b4	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0x3b7b5869	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0x47e9183d	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x4ed36e75	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0x57ce0b7e	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0x5a86b7c7	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x6d252783	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0x7d2e6fa6	configfs_unregister_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0x8db73124	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0xaa352573	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0xd1855176	configfs_undepend_item
++EXPORT_SYMBOL fs/exofs/libore 0x070c9c21	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x07bfdd9e	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0x11ad2930	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x1590deaa	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x33ea3185	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xb0eb30e5	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0xbdda25ab	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0xbf128546	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0xc624889e	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0xf4601e32	ore_get_rw_state
++EXPORT_SYMBOL fs/fscache/fscache 0x0235a4a9	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x0917bd2b	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x0af5fbf0	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0x0e3ce772	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x196ca069	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x1997267f	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0x19ce7a11	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0x1de158a5	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x2647ff14	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x271ec87e	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x328173a7	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x416945d7	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0x476c353f	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x4815082c	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0x4a8dc74e	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x4c67fac5	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0x4e6c4b6b	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x50205baf	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x5807f68c	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x66e88147	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0x6a7fc46b	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x72453d95	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x7a43a10e	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x7ca620ce	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0x8801ef96	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x8aec6e1b	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xa0efbd5c	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0xa6b20f6c	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0xab6c6fc8	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0xc25b8f1b	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xc85e465a	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0xc8fec162	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0xcd154f3c	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0xcfe7761c	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0xd1a79b79	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xd2c77e9f	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xdc36c1f7	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0xde8b2013	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0xe2ee1bfb	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0xe443974a	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x04c8b019	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0x12f027f1	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x19c0eac7	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x783e631d	qtree_write_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xa1b9fa87	qtree_read_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x3771b461	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc-itu-t 0xf5b4a948	crc_itu_t
++EXPORT_SYMBOL lib/crc7 0x66213969	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0x41248eaf	crc8
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x03f599c7	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0x4feade4b	lc_create
++EXPORT_SYMBOL lib/lru_cache 0x5370a6fc	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x56fc3ea0	lc_put
++EXPORT_SYMBOL lib/lru_cache 0x619ed575	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x84e0214b	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0xbbe7c23c	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0xc48fa976	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xc6e4cd46	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0xcb990a55	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcea6747e	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0xd212c9f0	lc_get
++EXPORT_SYMBOL lib/lru_cache 0xeb13128b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0xed09c492	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0xf460a486	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0xf5ea5f5c	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0xf6acec20	lc_find
++EXPORT_SYMBOL lib/lz4/lz4_compress 0xcbc5d521	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x26c3aa22	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x7456cc61	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x11229ceb	lowpan_nhc_del
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x5c6da8d0	lowpan_nhc_add
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xd8c25433	lowpan_netdev_setup
++EXPORT_SYMBOL net/802/p8022 0x61a72cf0	register_8022_client
++EXPORT_SYMBOL net/802/p8022 0xcb92657f	unregister_8022_client
++EXPORT_SYMBOL net/802/p8023 0xb86156cc	destroy_8023_client
++EXPORT_SYMBOL net/802/p8023 0xc73de779	make_8023_client
++EXPORT_SYMBOL net/802/psnap 0x03430d81	unregister_snap_client
++EXPORT_SYMBOL net/802/psnap 0x954365e0	register_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x002dec76	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0x00a88ec9	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0x041aacb5	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x066fe1f0	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0x0f630f6f	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0x11fef0a4	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x13c2787b	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0x1411635a	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x17bf4d16	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x1a37c7e9	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x2098faa8	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x267f8503	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x35c235ee	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x39f5a95b	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x3dc26c12	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x445487ff	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x57a69112	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x5be715a0	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0x5c11111b	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0x5f96e7d3	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x64f3e2a4	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0x66db35c1	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x686a5ffa	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x6c0e1153	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x6f3aad63	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0x7aee715b	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0x7dcdbfc4	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0x93291d73	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x9aba834b	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0xa85b539b	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xb2bbca0c	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0xb67a744b	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0xbf36f661	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xcaf0afb7	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0xcd0001a0	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0xd206182d	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0xd5b2db93	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xd5bb69e0	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0xd968c5c4	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0xe4b76f5a	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfb7e445f	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0xfcd447ad	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x40deef98	atrtr_get_dev
++EXPORT_SYMBOL net/appletalk/appletalk 0x5df51f87	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0xa89df218	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0xac7a065b	aarp_send_ddp
++EXPORT_SYMBOL net/atm/atm 0x0ef5eab0	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x2b286b42	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x4033eb0a	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x4a7b7c92	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0x4fd5d012	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0x703f3799	atm_charge
++EXPORT_SYMBOL net/atm/atm 0x8d4fd3af	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xc13f6762	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0xc6fb12cd	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0xca87b453	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0xd75ce8c4	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0xdcb503b6	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0xe9c95b0a	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/atm/atm 0xfe4e1680	atm_dev_register
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x64046924	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0x70b1baf2	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0x9168b03e	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0x9de7d4ab	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0xa2e1e808	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xe2a7c4d5	ax25_ip_xmit
++EXPORT_SYMBOL net/ax25/ax25 0xebb47090	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0xfa9d0568	ax25_listen_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x077df275	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0c6b059d	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0f11a764	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0fa9b5d4	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x18f7857b	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1da943b2	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x22f6be28	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x244d49b1	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x279c13b5	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x32df2fbc	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x336577a4	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x34b665da	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x35a0a179	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x365f9387	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x514fb818	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x5ca51804	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x5ec79ef8	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x61c58f43	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x650c812c	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x651504e2	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6a230a1b	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x71f441b1	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x771b69f4	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8ebc32a8	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9287c76e	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9401dc3e	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9b1c2cc5	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9e193bba	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9f719c83	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa482c99d	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa56f1d9a	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa6e49847	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb7e3cd68	bt_sock_wait_ready
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb9c8768e	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbb0521cc	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc4e6159a	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd687bfab	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xdf2a47d3	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe57aa554	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xee98ffe1	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xff0160ea	bt_procfs_cleanup
++EXPORT_SYMBOL net/bridge/bridge 0xbf54aa6f	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x53400ea5	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x9fa7632d	ebt_register_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xa443390a	ebt_do_table
++EXPORT_SYMBOL net/caif/caif 0x0ad62b38	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x3732c2ee	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x38383ae5	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x5b549638	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xc96f6c65	caif_enroll_dev
++EXPORT_SYMBOL net/can/can 0x5708356e	can_rx_register
++EXPORT_SYMBOL net/can/can 0x6369d6b3	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0xaff71368	can_send
++EXPORT_SYMBOL net/can/can 0xd7fe5ea5	can_ioctl
++EXPORT_SYMBOL net/can/can 0xd857ca47	can_proto_register
++EXPORT_SYMBOL net/can/can 0xf1349657	can_proto_unregister
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0bfb44c2	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x0c1ebf41	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x0d05c3b7	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x0d705092	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0x0e215db6	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x1110e80c	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0x12474bdc	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0x13905c19	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x15dd2fea	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x15e43976	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x15f12e90	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x172b1871	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0x1c7ccca0	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x207e01a1	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x24952f78	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x28710a01	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x291758ae	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x2ee5c8b5	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0x319937b0	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0x37a2c899	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x3859f94e	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x39b8a8e5	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3e2ebf2a	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x45654667	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x46a7c093	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0x47a9920e	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x4ad300c2	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x4d2347d2	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0x4e61307c	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0x52577f5b	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x52fffbbf	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x546adfa5	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0x55453549	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x5a513fc4	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0x5d86e3f1	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x635fd630	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x65b8ad2d	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x672c232d	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0x68a6c884	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6e6fabcd	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x7381f2cf	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0x74b4126d	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x759bfe50	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0x7d8345f8	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0x7ff737d6	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x80ea20dd	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x828f8a0b	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x83880c45	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x85488ad7	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x85826b4f	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x8b0425c5	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0x916b5103	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0x92c62e00	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9c504205	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x9eb0d9f9	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa1ebde8f	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0xa2bcc259	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0xa2c3faad	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xa36278df	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0xa72a493a	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafac2dcb	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb08bfe77	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0xb19dc152	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xbaf1a7fb	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0xbcaf9307	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0xc0384899	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc668ccb7	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc92d4706	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xcc992b02	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0xcf93510c	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd5383217	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xd55eb511	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0xd5818d0a	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0xd6458489	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xd6a0ff96	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0xd813625e	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xd8408f20	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0xde0eb6ba	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xde625f3a	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0xe070b57d	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0xe122bed6	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0xe55d9bcd	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0xe8cb76ff	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0xec43d306	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0xedd718d9	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xf6419960	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xfe37fcb4	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0xfe9f4930	ceph_messenger_fini
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x3104fb8b	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x50312be7	dccp_req_err
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x357a6ec8	wpan_phy_find
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x4c65aad5	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x52c8f503	wpan_phy_new
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x720c7c1a	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x7927c863	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xf0e3a9a7	wpan_phy_unregister
++EXPORT_SYMBOL net/ipv4/fou 0x0c07b4a3	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0xecafeb67	fou_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xed36fb31	gue_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xed741d6f	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x145fafe0	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x172be7fe	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x31e3e07f	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x3ce2b539	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x6c3711ab	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xf76311d4	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x2bb8fe40	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xc697f5b8	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xe685bc25	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x04678f17	ipt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xf1fb8ece	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xfc7eba36	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x8e91c153	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/tunnel4 0xe2c1b467	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0x2fff4aed	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x37d29a01	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xaadba1b2	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xc8d4b509	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xd124fd91	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x15bf3fbe	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x5b8e386f	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x942b7053	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x5d418956	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0x6f9aee50	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x426b968d	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0xc6a02d20	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x362e2d67	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x442de3fa	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x6651273d	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x69f5f0cb	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x9e989e8d	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xa0f2c1fc	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xe836c50e	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xfec03013	ircomm_connect_request
++EXPORT_SYMBOL net/irda/irda 0x0064e0ea	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x0dc13003	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0x110e872d	iriap_close
++EXPORT_SYMBOL net/irda/irda 0x1870df7c	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0x1e221a9c	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0x1e6cade0	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x1f67dcf9	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0x22528211	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x3a002dc8	irlap_open
++EXPORT_SYMBOL net/irda/irda 0x3e56064f	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0x3f5407e8	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x46ff3072	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x48344186	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0x4f04a3e0	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x53180b71	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0x5d88ebf2	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x601bda46	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6b5fbcef	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x6e0ab3c7	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7b74f5ad	iriap_open
++EXPORT_SYMBOL net/irda/irda 0x7c35b557	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x82d8c9b4	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x85d88217	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0xa1d41e58	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0xa3f6c9fe	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xaa557515	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0xac128d2d	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0xb3f7c23d	irlap_close
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xc68e43be	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0xcc83491b	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xcead7dbb	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xcfa755e6	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0xd2108314	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0xd2bc0a29	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0xd6deeaae	irda_setup_dma
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe3463529	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0xe3bde43e	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xf0a694a1	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0xf5876b95	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0xf7be1e9c	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0xf91dec8c	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0xfb2d6d3a	irlmp_connect_response
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x30dbcc28	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0xae0a1fe5	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x3fee0470	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0x53af9026	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0x5d4fd5bd	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0x6d90542a	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0x9844cc29	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0x9bd04e11	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0xcdf60932	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0xf5ce6e7f	lapb_disconnect_request
++EXPORT_SYMBOL net/llc/llc 0x0a8349e5	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0x32d57583	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x38ba35d4	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0x4bb7f552	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0xa23658a4	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0xdcfeffbf	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0xee2e22bf	llc_sap_close
++EXPORT_SYMBOL net/mac80211/mac80211 0x001fa2bd	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0x0208e53a	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x02166686	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x03110016	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0x05a5f8de	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x072b89c5	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0x08c1dd15	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x157d24a6	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x17472b6f	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x193b63f7	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x1b739ca9	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x1f119999	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x2ae63e74	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x2de69a5f	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x338f44fa	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0x34239f67	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0x347cf71f	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x352be171	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x3c1572fd	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0x3f20cd10	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x3f7553e3	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x40852298	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac80211/mac80211 0x462729d8	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x4b961145	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x4c9c213e	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x4d770998	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x4e93b2d9	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x539c1042	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x59840cb1	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x61e9a6b8	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x621bf23d	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x63a13725	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0x64c2c156	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x66abc5af	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x68219ac3	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0x69de096c	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0x6c0672f3	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x6e4d6d0c	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x74c62f2c	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x76485105	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0x76b9ef28	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x7716cd51	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x7756ac8f	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0x777acb2d	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x790b0218	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x9563e7a7	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x9abad45a	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0x9d02d3c6	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0x9ee9ca50	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xa2cbde1b	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0xa5da8083	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0xad5b19ff	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0xaed86199	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xb1aaef91	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xb1add9e7	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0xb1f20143	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac80211/mac80211 0xb1f28247	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xb90462d2	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xbb723792	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xbbe1fa60	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xbbe95f07	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0xbf728ba6	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0xbfab77f9	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0xc4243cdd	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xc4400ce2	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0xced3799d	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xd75c6e77	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0xd773f4dc	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0xd8fe3993	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0xdda14dbe	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0xdf967dad	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xe3ee0e89	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xe5f7445e	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xec049d0e	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xec7cd77a	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xec9fd6bb	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xf13e1e18	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0xf5eb464b	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xf73289a1	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0xf8f496d1	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0xfa762e65	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xfdd0e125	ieee80211_queue_work
++EXPORT_SYMBOL net/mac802154/mac802154 0x09cd484c	ieee802154_xmit_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0x1872bd87	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x539a30dd	ieee802154_alloc_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x9a64a5be	ieee802154_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xa79ea0d3	ieee802154_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0xb1dcef76	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0xf1910509	ieee802154_register_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xfece8c1e	ieee802154_unregister_hw
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x015dcb2a	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x0de6d9b0	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x10aa5b32	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x4b6c9234	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x4ff35534	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x53086d31	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x733c5c0a	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x749431c8	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x8e8501b1	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x9c3dcfc9	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb8d56fef	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xdc628a49	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xfe2d8bf4	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xfede96cf	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x1cb8e27b	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x41598afd	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x6d157a7d	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x21078e74	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/nf_nat 0x8d3bfe92	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x974f9e7f	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x99c0b716	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0xded58647	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0xe214c012	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/x_tables 0x100ce88b	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x392c0131	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x5685f9d9	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x64d64fe1	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x943f53d0	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x99a76a09	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xadeb3611	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xb4862342	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xbc7e5a4b	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xc35a82f1	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/nfc/hci/hci 0x24a1a3ca	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x2fa78e55	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0x30d024d9	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x3a119cf6	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x3effc274	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0x3fcace23	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x4f72443b	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x5b4b727c	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x66e00701	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0x76c0488b	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0x818d31f5	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x934e870f	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0x9697890c	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0xa5f8e19f	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/hci/hci 0xb235eb73	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0xb302074c	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xb712a921	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0xba0e1cc8	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xdd2e1df1	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xf8d34ad3	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0xfd27efce	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/nci/nci 0x04bdbe6d	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0x0a346350	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x14793893	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0x16237dc3	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nci/nci 0x16f43935	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0x18bd34bb	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x191e6ad4	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x1a5b7c62	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x1c9f9f9e	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x2cd8985f	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nci/nci 0x35a22eb3	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x4e2d216f	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0x6279e4c4	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0x63990c18	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x6422f9c3	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0x658deb79	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0x6dd346cb	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0x78b57e9f	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xa2db8a72	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0xa62a4248	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nci/nci 0xae900c9c	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xc4cb28f2	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0xd11a91e7	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xe7c88c6e	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xe9a022df	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0xf1e0bf07	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xf5750949	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0xf82974fd	nci_register_device
++EXPORT_SYMBOL net/nfc/nfc 0x144dc514	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0x28c72523	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0x2a4580d7	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0x2f7d51d8	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0x360b829a	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0x5aa78c7f	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0x76542895	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x76b9e3a9	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x77241fd1	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0x8338a7dd	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc 0x89099bad	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0x8b91b831	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x94426ec3	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0x95073b79	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0x96d1a1a4	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x9f09df57	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0x9fb68b59	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0xa0f67faa	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0xb9006531	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0xbb92c774	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0xbeff3e60	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0xceb0abfe	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0xdbb55478	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0xea03de4d	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x54154ddd	nfc_digital_register_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xdc6429db	nfc_digital_unregister_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xdcf04cdc	nfc_digital_allocate_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xdd028ce5	nfc_digital_free_device
++EXPORT_SYMBOL net/phonet/phonet 0x0983f1fa	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0x13246561	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0x2fb953fb	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0x6463bc71	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0x677508fb	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0xc85cf093	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0xdac1e499	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0xdeaf8320	pn_sock_hash
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1395ab9d	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x195d7d30	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x3cea358f	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x41f28fc4	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x6769b271	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x7f866e2f	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8ac3829d	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x9b466a7c	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x9e698ed2	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xa54cbe97	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb9dd12d6	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xc27b6bbd	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xc404c4e8	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe122f16f	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xec2f8699	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/sctp/sctp 0x98bab6ca	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x215b401f	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x22d72bb8	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x778282f9	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x2214fa72	svc_pool_stats_open
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x5bc69e14	xdr_truncate_encode
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x9ce47257	xdr_restrict_buflen
++EXPORT_SYMBOL net/wimax/wimax 0x5b5c3e7b	wimax_reset
++EXPORT_SYMBOL net/wimax/wimax 0xee60da22	wimax_rfkill
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0ab605d4	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0x0e25adde	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x0f940201	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0x102a6d7f	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0x120eaa84	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x1a65f5fe	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0x1b4ca445	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0x1bd365c8	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x1bf65775	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x20f80e89	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x2976bd57	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0x36726f49	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0x39786802	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x3a4cc02f	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x3f5ba0f9	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x433f851a	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0x43400582	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0x43ee20e1	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x443c0853	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x44ef3942	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x45ea41cf	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0x461380e3	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x47e87bd3	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x528b66b3	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0x531b5cbe	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x576652c1	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x5bfade1a	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x5d8c8f3a	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x665d2af7	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0x66d867ca	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0x67cefee8	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x732b1aba	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x7407e485	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0x77abee4a	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0x7c27c53d	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x86df76c3	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x888893b2	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x8b05451b	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0x8c6d6c87	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x8cdaca82	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x8ddd52a3	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x900ab860	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x90b01efc	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/cfg80211 0x91d3bdbe	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0x93dddc53	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0x966ff54d	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x97b95454	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x98ecb0d0	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xa13d69d5	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa51d1a1a	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0xa8606ad7	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xab717adc	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xaec32f89	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0xb0ee0240	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0xb2e608b6	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xb6583e95	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0xb7b4fe7c	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xb82c6379	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0xb9d8964e	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xc56367df	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc8c43db4	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xcb81c0a8	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xe0bd7ec1	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xe174bba0	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe217fabd	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe3e42090	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0xe467cedd	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe86006fe	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0xeaf4e94f	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xeb6d7c6c	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xed8a53d3	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0xef8758f0	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xf0153ad4	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0xf3b97b29	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0xf4932e76	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xf7781404	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0xf88ef8fa	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0xfa566b28	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0xfc1a9ee7	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0xfc1bbb01	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xfc7d1744	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xfd167e09	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0xfee4b75a	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0xffb3125a	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/lib80211 0x17d6fa12	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x18025253	lib80211_crypt_info_free
++EXPORT_SYMBOL net/wireless/lib80211 0x1c1dcb86	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0x21d7b6a0	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x4f168f50	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0xc435c70d	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL sound/ac97_bus 0x6ba799b3	ac97_bus_type
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0x414c7e32	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x57dfe2ef	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xa9b6583d	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xa9c86a54	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xbfcedf03	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x52e906a8	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x072d978b	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x13a17752	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x2eed26bf	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x4d5ca523	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x592f6e9b	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xd7c7afcc	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xe60fb228	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xecbde43c	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0x6b84a6bb	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x07014111	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0x0d01ab9e	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0x0d150136	snd_jack_add_new_kctl
++EXPORT_SYMBOL sound/core/snd 0x18e1683f	snd_dma_program
++EXPORT_SYMBOL sound/core/snd 0x191e88cf	snd_dma_pointer
++EXPORT_SYMBOL sound/core/snd 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL sound/core/snd 0x1e7ee501	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0x2486a65d	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x29a194c2	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0x2c89ff20	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x45ec6967	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0x47956551	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x4aac369b	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0x53762122	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL sound/core/snd 0x5474e051	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0x602c96f0	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x6e256184	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0x701b9ecc	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0x70c15ac1	snd_dma_disable
++EXPORT_SYMBOL sound/core/snd 0x73718d7f	snd_register_oss_device
++EXPORT_SYMBOL sound/core/snd 0x73c2edd1	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0x745f82c3	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0x7d2f3457	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0x80d91f7b	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x81e7d80e	snd_jack_new
++EXPORT_SYMBOL sound/core/snd 0x8b7d9247	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0x8c4026ea	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x8f8b75ea	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0x90b92384	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0xa0e3c2cb	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xa30a8e27	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0xa4de13c4	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0xa79ddf6a	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0xa951ec79	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0xab4444ae	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xb84f66ca	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0xbfca6279	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0xc3a52773	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0xc5e7b41f	snd_cards
++EXPORT_SYMBOL sound/core/snd 0xcc5ee249	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0xce3ca308	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd 0xd598f0eb	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0xd78e57b8	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0xd8d93d80	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd 0xd9e1897f	snd_register_device
++EXPORT_SYMBOL sound/core/snd 0xdda45908	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0xddf631b0	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd 0xe0c04274	snd_card_new
++EXPORT_SYMBOL sound/core/snd 0xe642dc78	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0xe995c7ff	snd_unregister_oss_device
++EXPORT_SYMBOL sound/core/snd 0xeebc9aa4	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0xef1d9892	snd_device_new
++EXPORT_SYMBOL sound/core/snd-hwdep 0xc5df20c4	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x045385e4	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x0cc06c20	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0x12d4e9c9	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x13b3b89f	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0x18fe6afb	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x1fac577a	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL sound/core/snd-pcm 0x263bc1c1	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x27a71346	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x3b91f3af	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x40c3f1b9	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0x42fbc7e9	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0x43a709a5	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-pcm 0x44a77758	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0x4a1b60d7	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-pcm 0x4cc08cae	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0x4d9b6d35	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x4ed6d62a	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x51e35b37	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x62bd4a5f	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x63684a5d	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x70cde2a2	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0x7653bafb	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x77c20249	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x7f8fbcd3	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x87c0d295	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0x884adb30	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x89d12248	snd_pcm_lib_mmap_iomem
++EXPORT_SYMBOL sound/core/snd-pcm 0x8d6c7782	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x900176cc	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x9b0bed74	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0x9cb9613e	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0x9db27a69	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xa909fb2b	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-pcm 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xade88e76	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xb2778f52	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0xb522b794	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0xb688ac1c	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9e3a3be	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0xba5dac74	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xbc9ce065	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xc2247d26	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xca9b3767	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0xcae8d81c	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0xd2640166	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0xd4bd6632	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0xde6de728	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0xe1c6855e	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xe99b011f	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0xed051ee3	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0xf9810e10	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x0b57bc3e	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x157e3432	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x1ab73f48	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x489502f0	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x4c8baeae	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x5273ac64	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x609a8498	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7b1a6a21	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7d9bb17b	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x96e4ae01	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x98a92031	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xabfecaab	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xaeed3b38	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb225106d	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xbf9419aa	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xc6cd263d	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd6842929	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd89027b1	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xef7e3179	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-timer 0x18010e81	snd_timer_interrupt
++EXPORT_SYMBOL sound/core/snd-timer 0x3cbcc28c	snd_timer_open
++EXPORT_SYMBOL sound/core/snd-timer 0x5d974e2a	snd_timer_global_register
++EXPORT_SYMBOL sound/core/snd-timer 0x6781769c	snd_timer_start
++EXPORT_SYMBOL sound/core/snd-timer 0x68b0ecd6	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0x75a56da7	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0x7d603d8c	snd_timer_new
++EXPORT_SYMBOL sound/core/snd-timer 0x87be041e	snd_timer_stop
++EXPORT_SYMBOL sound/core/snd-timer 0x9ce6f325	snd_timer_pause
++EXPORT_SYMBOL sound/core/snd-timer 0xa99008bc	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0xd3e65027	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0xf2199251	snd_timer_close
++EXPORT_SYMBOL sound/core/snd-timer 0xf31793af	snd_timer_resolution
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x593f4a0e	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x10a126ee	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x11b4029c	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x1da1d27d	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x26886dfc	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x52eeb258	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x71c56f22	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x8d210191	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xd9b42d98	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xed682bbc	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x39e225ee	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x6448dc2f	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x7ab1cf58	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x983f5d66	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xa1fe06c7	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xa87d40ea	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xb8eb2c50	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xd744aeb2	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xecc8baef	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x0b3c57e7	amdtp_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x10fc2925	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x2b312647	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3fc1e071	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4ef01e6d	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4fd16f95	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x57070649	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5c5ab05d	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x62537f1a	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x642e7c43	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x713b0072	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x718394d1	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x72d7e8b9	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7ac7446a	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7bd8926a	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7d06c28f	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7f04bb7b	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7ff0d1a4	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x835b9f17	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x845f18ee	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x89c44ba9	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9164715d	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xabd7b070	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc1917a8d	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd0b32619	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd65b51c2	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd7660d29	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd887b88f	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe3084189	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe6cdb1b5	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xeb40bba8	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xecdd6dff	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x20de7a65	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x39e62daa	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x15cb40f0	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x1d682710	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x30d61384	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x5a1ae418	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xacc3c221	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xc64d0c56	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xce1ee79e	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xe9847e7d	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x0ca6fce5	snd_ak4117_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x5182b13f	snd_ak4117_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x6dba433b	snd_ak4117_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x79ccfdde	snd_ak4117_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x8605ba36	snd_ak4117_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xcf16b0d9	snd_ak4117_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x60d6f316	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x651d465b	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xb105c650	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xed33260d	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x36f0637f	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0xab13e307	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x18aabd8c	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x3f876e56	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x602ec795	snd_cs8427_init
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x6836dc31	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x98c84e15	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xf182f001	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x3893fc34	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x43d51b6e	snd_i2c_device_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x9f83a42a	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xac8d9f68	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xb7f59cce	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xbde86fc2	snd_i2c_readbytes
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x015d4037	snd_sbmixer_write
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x0dde2d91	snd_sbmixer_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x158074ad	snd_sbmixer_suspend
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x301b5676	snd_sbdsp_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x77a3d485	snd_sbmixer_read
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xb181f85c	snd_sbdsp_reset
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xb604a6d2	snd_sbmixer_resume
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xbbbeee9a	snd_sbmixer_add_ctl
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xcb8b6440	snd_sbdsp_get_byte
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xfed61fbb	snd_sbdsp_command
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x197be3fb	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3adbb813	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5fbbaa9b	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x63719097	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x6ac0d74d	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x717aa29e	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x7a6d3d44	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x8b791eb3	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x8d9c3ba7	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x94bee93a	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb0fd28b8	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb7a382f7	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xd10e599c	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xd8e9a179	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xda14dfe6	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xf57d28f5	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xfa016dab	snd_ac97_update
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x0e32e94b	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x24fedceb	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x373d7302	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x4ab2ba0b	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x63fd4548	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x69d7c4f6	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x87226240	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x8e18dabe	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x921c2795	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x41201e4a	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x65fd962f	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x977808a3	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x04adc7e4	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x18bbcd88	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x2b3f15ad	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x37a30f5c	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x39d9f7b5	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x435065f6	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x4aea5873	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x50338a37	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x6d6dd698	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x75a5d352	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x79a9fea6	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x84bf7f65	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x85041ea4	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x8ddb6411	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa136ddd5	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa342fbd4	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xdd2006ca	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xefaa904e	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf0bf29dd	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf48439a8	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xfd73a214	oxygen_read16
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x2d1287ba	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x38ee7de9	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x633396dd	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x9786aa5b	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xddc47633	snd_trident_free_voice
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x179c1f3b	tlv320aic23_probe
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x86c3263e	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/snd-soc-core 0x8f25038c	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL sound/soundcore 0x1e8fee95	register_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x3018606a	sound_class
++EXPORT_SYMBOL sound/soundcore 0x3b875dd1	register_sound_special
++EXPORT_SYMBOL sound/soundcore 0x4a4de634	register_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0x662003a2	register_sound_midi
++EXPORT_SYMBOL sound/soundcore 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL sound/soundcore 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xe027e18e	register_sound_special_device
++EXPORT_SYMBOL sound/soundcore 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x21f78b86	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x3d212d68	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x477a2630	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x793292b6	snd_emux_register
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xa826320e	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xc8ec7840	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x00c7f8f5	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x05c65e35	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x35a8fe3f	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x38866c3e	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x43be9843	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x56a82e52	snd_util_memhdr_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x6baad4bf	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xc51c511e	__snd_util_mem_free
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb9757835	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL vmlinux 0x0032793e	netif_skb_features
++EXPORT_SYMBOL vmlinux 0x00389939	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x0040acab	vme_irq_request
++EXPORT_SYMBOL vmlinux 0x008c5d6c	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0x00a2ca08	sys_fillrect
++EXPORT_SYMBOL vmlinux 0x00a5e4d2	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0x00a803b5	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x00ebb6d3	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x01139ffc	max_mapnr
++EXPORT_SYMBOL vmlinux 0x01187e57	elevator_exit
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x01893074	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0x019cd453	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x01a23f0e	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0x01ad6391	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0x01c59e8e	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0x01fa6c04	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0x021d53ac	check_disk_change
++EXPORT_SYMBOL vmlinux 0x023312f0	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x026a3bcb	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x026f8391	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0x0274a96a	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0x0274b5fc	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x0277a261	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0x0281c0fc	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x02822c99	__inode_permission
++EXPORT_SYMBOL vmlinux 0x028fcd01	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a3c236	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02abd5fb	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0x02b64e52	skb_clone
++EXPORT_SYMBOL vmlinux 0x02e29e48	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x02eabc70	down_write
++EXPORT_SYMBOL vmlinux 0x02ee26c1	free_pages_exact
++EXPORT_SYMBOL vmlinux 0x030288e0	fb_show_logo
++EXPORT_SYMBOL vmlinux 0x0316caf4	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x0351ae13	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x0374dc5f	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x037c4172	udplite_prot
++EXPORT_SYMBOL vmlinux 0x038a7530	km_report
++EXPORT_SYMBOL vmlinux 0x038bfc8d	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0x039241df	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0x03aa47a6	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x03bb191a	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0x03d0ca0a	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x03dfba07	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0x03eb6858	netif_rx
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x04074f48	ioremap
++EXPORT_SYMBOL vmlinux 0x041d72f6	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x042c7de3	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0x043685fa	seq_printf
++EXPORT_SYMBOL vmlinux 0x0445bf99	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x0462a7e8	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0x0470c10a	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x0491c699	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x04ad7675	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x04afd4fb	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x04ba6819	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x04d3bdc5	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x04e3c5e3	register_console
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04ed76c6	inode_permission
++EXPORT_SYMBOL vmlinux 0x04f1041d	lockref_get
++EXPORT_SYMBOL vmlinux 0x04f34225	tso_build_data
++EXPORT_SYMBOL vmlinux 0x04ff8c06	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x05186ca4	flush_icache_range
++EXPORT_SYMBOL vmlinux 0x051c2b36	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x0529160b	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0x0530dede	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x05440e69	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0x055f9e75	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x0576559c	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x058f0c5b	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0x05908a13	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0x05962625	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0x05a514a1	_insl_ns
++EXPORT_SYMBOL vmlinux 0x05ac6d30	ihold
++EXPORT_SYMBOL vmlinux 0x05bf7fbb	register_shrinker
++EXPORT_SYMBOL vmlinux 0x05d5eb37	of_find_node_by_type
++EXPORT_SYMBOL vmlinux 0x05df334e	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0x05ef3ea2	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x05fced8b	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x0608ef27	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x060dcf5f	get_cached_acl
++EXPORT_SYMBOL vmlinux 0x0613bd3b	block_write_begin
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x06250e85	mach_ppa8548
++EXPORT_SYMBOL vmlinux 0x0630138d	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x063c4802	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0x065eb494	security_mmap_file
++EXPORT_SYMBOL vmlinux 0x06726050	dump_emit
++EXPORT_SYMBOL vmlinux 0x0675c7eb	atomic64_cmpxchg
++EXPORT_SYMBOL vmlinux 0x067ac8a6	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x06888830	agp_create_memory
++EXPORT_SYMBOL vmlinux 0x0697ddd4	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0x06ac22a3	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0x06b6abac	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x06bcf3b4	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0x06de32de	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x06ea7c59	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x06ef1af7	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x06f9492f	vm_mmap
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x070e3183	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0x071bad2b	simple_follow_link
++EXPORT_SYMBOL vmlinux 0x0727c4f3	iowrite8
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x072fec97	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x07430e85	truncate_setsize
++EXPORT_SYMBOL vmlinux 0x074a4311	sk_dst_check
++EXPORT_SYMBOL vmlinux 0x074e9213	down_killable
++EXPORT_SYMBOL vmlinux 0x0750e2cf	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x077192de	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x0791d0e7	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07adba2f	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07e986e4	__devm_release_region
++EXPORT_SYMBOL vmlinux 0x08140a8e	__dst_free
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x0831c0d5	__skb_checksum
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x084239b1	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0x08447043	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0x086d8cdd	irq_stat
++EXPORT_SYMBOL vmlinux 0x0879be54	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0x0889814e	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x0898937b	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x08becf6f	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x08d525e1	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0x08df9457	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x08ef6fe4	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x09029fba	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0x09108013	dentry_open
++EXPORT_SYMBOL vmlinux 0x093b1beb	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0x093e5bcc	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x0940897c	irq_to_desc
++EXPORT_SYMBOL vmlinux 0x0943e925	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x095d1484	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0x0963cac3	__check_sticky
++EXPORT_SYMBOL vmlinux 0x0971832a	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0x098141cd	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0x0982551c	nla_put
++EXPORT_SYMBOL vmlinux 0x0989707e	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x098a11f2	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x098edb83	nf_log_unset
++EXPORT_SYMBOL vmlinux 0x099de129	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0x09aa8aa4	flush_tlb_range
++EXPORT_SYMBOL vmlinux 0x09aabefb	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x09bbbb91	trace_print_symbols_seq_u64
++EXPORT_SYMBOL vmlinux 0x09c1f3a2	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c67afb	flex_array_get
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09cfa0db	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x0a086594	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a295366	__napi_complete
++EXPORT_SYMBOL vmlinux 0x0a2d3357	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x0a3000bc	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0x0a3131f6	strnchr
++EXPORT_SYMBOL vmlinux 0x0a373226	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0x0a469d23	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0x0a706d10	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x0a7ab100	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x0a7c28bf	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x0a9f8980	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0adcc20f	do_SAK
++EXPORT_SYMBOL vmlinux 0x0ae53721	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x0ae6f676	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0x0b01e1a1	agp_free_memory
++EXPORT_SYMBOL vmlinux 0x0b061d6f	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b25de55	phy_print_status
++EXPORT_SYMBOL vmlinux 0x0b291008	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x0b333142	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x0b48677a	__kfifo_init
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b678685	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x0b681332	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b8e9739	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0x0b9a6c63	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0x0ba398ef	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x0bb16c5c	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc1964c	i2c_master_send
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bc58597	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x0bf44dc2	agp_generic_free_gatt_table
++EXPORT_SYMBOL vmlinux 0x0bff77c4	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x0bffb6a1	netif_device_attach
++EXPORT_SYMBOL vmlinux 0x0c117bfb	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0x0c12e626	__debugger_bpt
++EXPORT_SYMBOL vmlinux 0x0c1ee5d6	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0x0c1f1542	__kernel_write
++EXPORT_SYMBOL vmlinux 0x0c35a6d8	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c528be7	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x0c558603	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c600b08	of_find_backlight_by_node
++EXPORT_SYMBOL vmlinux 0x0c6e4504	bio_add_page
++EXPORT_SYMBOL vmlinux 0x0c843238	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x0c8a1843	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x0c9b6089	nvram_get_size
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cb07725	security_path_chown
++EXPORT_SYMBOL vmlinux 0x0cb2770f	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x0cc697bd	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x0cc8ce0f	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0x0ce8885c	pid_task
++EXPORT_SYMBOL vmlinux 0x0d0ccd2c	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x0d11f0df	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x0d179f24	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x0d219985	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0x0d3b53e8	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0dafebbb	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0x0db72bcb	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0x0dc0ace0	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x0dc1a78c	bin2hex
++EXPORT_SYMBOL vmlinux 0x0dde9d80	ppp_input_error
++EXPORT_SYMBOL vmlinux 0x0dfa610b	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x0e0a355c	backlight_device_register
++EXPORT_SYMBOL vmlinux 0x0e0e2ccc	skb_pull
++EXPORT_SYMBOL vmlinux 0x0e1e0aeb	__lock_buffer
++EXPORT_SYMBOL vmlinux 0x0e549baa	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x0e59b718	__neigh_create
++EXPORT_SYMBOL vmlinux 0x0e65a0d3	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e720271	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x0e8f30f6	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x0eaa5298	genl_notify
++EXPORT_SYMBOL vmlinux 0x0eaf451e	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0ecde9c2	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x0ee2ee25	tcp_prot
++EXPORT_SYMBOL vmlinux 0x0ee5e9c8	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0x0eea0399	strscpy
++EXPORT_SYMBOL vmlinux 0x0ef51353	arp_create
++EXPORT_SYMBOL vmlinux 0x0efa1993	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f175fe9	of_find_node_opts_by_path
++EXPORT_SYMBOL vmlinux 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL vmlinux 0x0f2a088a	follow_up
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f536977	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0x0f5faa7e	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f770393	setattr_copy
++EXPORT_SYMBOL vmlinux 0x0f79675c	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0fa60688	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fc06561	padata_start
++EXPORT_SYMBOL vmlinux 0x0fed8af8	netdev_update_features
++EXPORT_SYMBOL vmlinux 0x0ffc018b	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0x105768df	mmc_release_host
++EXPORT_SYMBOL vmlinux 0x106f13ab	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x108e4326	d_invalidate
++EXPORT_SYMBOL vmlinux 0x1096aa2f	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x10a70f37	i8042_remove_filter
++EXPORT_SYMBOL vmlinux 0x10c8f656	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x10e45698	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x10f02c41	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x1107bb83	bioset_create
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x11099f88	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0x110d2b4c	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0x11145431	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0x112d683f	kdb_current_task
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x117712bd	__nd_driver_register
++EXPORT_SYMBOL vmlinux 0x118094f3	arp_xmit
++EXPORT_SYMBOL vmlinux 0x1182d83a	cpuidle_disable
++EXPORT_SYMBOL vmlinux 0x119d23ba	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11a3c2bf	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x11ae3867	is_nvdimm_bus_locked
++EXPORT_SYMBOL vmlinux 0x11b92420	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x11c867da	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120dae86	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x12139792	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0x12186ccd	agp_generic_free_by_type
++EXPORT_SYMBOL vmlinux 0x121b4e4b	memremap
++EXPORT_SYMBOL vmlinux 0x1232399b	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0x1239ec7c	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x123c2854	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0x123dcbc4	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x124c0cdc	d_tmpfile
++EXPORT_SYMBOL vmlinux 0x1250f5be	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0x1261529a	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0x12748429	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x1278270b	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x1284dc32	inode_init_once
++EXPORT_SYMBOL vmlinux 0x128b3825	bio_advance
++EXPORT_SYMBOL vmlinux 0x12a2c654	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12ab896f	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x12b42fa6	lease_modify
++EXPORT_SYMBOL vmlinux 0x12bbc50c	of_dev_get
++EXPORT_SYMBOL vmlinux 0x12d997e7	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0x12da5bb2	__kmalloc
++EXPORT_SYMBOL vmlinux 0x12dc8da7	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0x12f20d00	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x12f7a19f	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x13077b08	dst_init
++EXPORT_SYMBOL vmlinux 0x1319126a	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x1336c865	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x135e0f49	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x136fd770	I_BDEV
++EXPORT_SYMBOL vmlinux 0x13a58b6e	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x13c79a80	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13d1c666	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x13d58c60	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x1407c6e7	kmap_prot
++EXPORT_SYMBOL vmlinux 0x1420b379	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0x1422a5f8	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x142bfe3f	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0x146d123d	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x147b6ce9	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0x147fd0cf	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0x148199dc	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x14a010e7	build_skb
++EXPORT_SYMBOL vmlinux 0x14b1fc3f	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x14b426da	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0x14bb3cc1	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x15049506	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0x15428530	request_key
++EXPORT_SYMBOL vmlinux 0x1542a354	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x157ee959	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15d3fd60	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x15dc218e	of_get_property
++EXPORT_SYMBOL vmlinux 0x15e3cae7	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x160c11f6	blkdev_put
++EXPORT_SYMBOL vmlinux 0x161d0033	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x16273076	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0x162876cd	__bforget
++EXPORT_SYMBOL vmlinux 0x1646132d	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x16540bbc	__cmpdi2
++EXPORT_SYMBOL vmlinux 0x165e69c2	dump_align
++EXPORT_SYMBOL vmlinux 0x1665feba	tty_register_device
++EXPORT_SYMBOL vmlinux 0x166b0eeb	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x1683a50b	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x168cf911	nla_reserve
++EXPORT_SYMBOL vmlinux 0x16a31ace	vfs_unlink
++EXPORT_SYMBOL vmlinux 0x16c25379	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x16de770a	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x16e7d787	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0x16ef25c0	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0x16ffabec	kfree_skb
++EXPORT_SYMBOL vmlinux 0x170a1e05	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0x170cc015	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x1710f7e9	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x1716dba5	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x175e5b2b	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0x17648396	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x1769693c	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0x176ad3d6	sock_efree
++EXPORT_SYMBOL vmlinux 0x17aa156a	__ucmpdi2
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17b755b9	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0x17b8dc93	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0x17c1c0c4	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x17c8a7c4	pci_release_region
++EXPORT_SYMBOL vmlinux 0x17de4fd6	put_filp
++EXPORT_SYMBOL vmlinux 0x17e28473	fsl_upm_run_pattern
++EXPORT_SYMBOL vmlinux 0x17f341a0	i8042_lock_chip
++EXPORT_SYMBOL vmlinux 0x181f63f1	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x1829bf48	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x18310428	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0x183401a0	sock_init_data
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x18462ebf	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x1880a556	of_parse_phandle
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x188a543d	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0x188ea314	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0x1895ffb5	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x18a48e7a	find_get_entry
++EXPORT_SYMBOL vmlinux 0x18aa0eac	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0x18b10027	ata_print_version
++EXPORT_SYMBOL vmlinux 0x18bb6135	touch_atime
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x19314f45	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0x1934daef	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x193e49ea	lookup_one_len
++EXPORT_SYMBOL vmlinux 0x1961b977	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x19723737	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x197b70f9	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x1997e57c	done_path_create
++EXPORT_SYMBOL vmlinux 0x199a5673	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0x199eb1b1	security_path_rename
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19a32978	pci_select_bars
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19ba1dc7	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19cf0984	__mutex_init
++EXPORT_SYMBOL vmlinux 0x19cf34e7	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0x19e5d1ee	d_delete
++EXPORT_SYMBOL vmlinux 0x19eacd0c	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x1a0513e6	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0x1a11a877	generic_fillattr
++EXPORT_SYMBOL vmlinux 0x1a1c6ebe	proc_create_data
++EXPORT_SYMBOL vmlinux 0x1a4f7b0d	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x1a8d6f81	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x1a9c56fa	set_security_override
++EXPORT_SYMBOL vmlinux 0x1ad42d39	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0x1ada0907	file_update_time
++EXPORT_SYMBOL vmlinux 0x1ae562e9	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0x1aece901	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0x1af62a99	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0x1afa9ab6	to_ndd
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b0b488f	security_path_mknod
++EXPORT_SYMBOL vmlinux 0x1b0e15a5	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x1b1178ea	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0x1b132009	rename_lock
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b48be10	find_vma
++EXPORT_SYMBOL vmlinux 0x1b4a41ac	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0x1b4ea06a	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x1b54bef1	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b797f92	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b8971db	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0x1b8b95ad	i8042_unlock_chip
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bc0c2e6	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0x1bc4ff03	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0x1bca2b59	load_fp_state
++EXPORT_SYMBOL vmlinux 0x1bcf98bd	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0x1bd06a0e	i2c_use_client
++EXPORT_SYMBOL vmlinux 0x1bf3f82a	notify_change
++EXPORT_SYMBOL vmlinux 0x1c12c775	tso_count_descs
++EXPORT_SYMBOL vmlinux 0x1c13ab43	mach_c293_pcie
++EXPORT_SYMBOL vmlinux 0x1c398a6c	nd_device_unregister
++EXPORT_SYMBOL vmlinux 0x1c4caa08	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0x1c52c5d0	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x1c7d712b	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0x1c7d9dda	sk_net_capable
++EXPORT_SYMBOL vmlinux 0x1c80de9c	ip_send_check
++EXPORT_SYMBOL vmlinux 0x1ca1942d	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0x1ca42427	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0x1cae6064	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x1cc75f2e	get_user_pages
++EXPORT_SYMBOL vmlinux 0x1cfda423	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0x1d065f82	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x1d1758fd	__nla_put
++EXPORT_SYMBOL vmlinux 0x1d1ad081	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0x1d21a200	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x1d242a57	inet6_protos
++EXPORT_SYMBOL vmlinux 0x1d25c576	genphy_read_status
++EXPORT_SYMBOL vmlinux 0x1d63fd29	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x1d7f4ec0	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0x1d80919f	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0x1d917c34	ps2_drain
++EXPORT_SYMBOL vmlinux 0x1da01267	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0x1daee28a	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1df8e171	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x1e04a247	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e33afbe	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0x1e406510	inet6_getname
++EXPORT_SYMBOL vmlinux 0x1e54a9e0	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x1e5db254	generic_perform_write
++EXPORT_SYMBOL vmlinux 0x1e623eac	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x1e689fb3	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e7970c8	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0x1e7ab463	inode_init_owner
++EXPORT_SYMBOL vmlinux 0x1e7b38ac	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0x1e88ed5f	of_count_phandle_with_args
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ecc130e	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x1ece04f5	bd_set_size
++EXPORT_SYMBOL vmlinux 0x1efcae09	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x1f2a2416	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0x1f32f314	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0x1f7e807f	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x1fa29e44	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0x1fa2c176	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fcf7260	param_get_short
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1fedb913	block_write_full_page
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x1ff5be04	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x202d5de6	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0x2039890e	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x204c61cb	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0x206687ad	cpm_muram_alloc_fixed
++EXPORT_SYMBOL vmlinux 0x2068ce30	d_splice_alias
++EXPORT_SYMBOL vmlinux 0x206af1ac	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0x2070b741	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x2074ac42	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0x209bc147	of_parse_phandle_with_args
++EXPORT_SYMBOL vmlinux 0x20a1206c	skb_pad
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20ae58d0	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20ce8712	vme_slot_num
++EXPORT_SYMBOL vmlinux 0x20d434fd	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0x20ddc557	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20fdc6f8	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0x2106a146	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0x2108ee04	misc_register
++EXPORT_SYMBOL vmlinux 0x211584b9	sk_common_release
++EXPORT_SYMBOL vmlinux 0x211ec8da	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0x211f7385	kernel_accept
++EXPORT_SYMBOL vmlinux 0x2127b8a2	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0x212e0db9	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0x2132ce76	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x216a5665	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x217e0aa2	d_move
++EXPORT_SYMBOL vmlinux 0x2191829f	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0x21940218	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0x21b04a90	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0x21d109ec	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x21d448cd	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0x21d6de27	of_find_net_device_by_node
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21f19335	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0x21f3dc15	cpm_command
++EXPORT_SYMBOL vmlinux 0x21f697f3	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x22031e06	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x222358e7	path_get
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x2238c4b2	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0x2239ec18	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0x2249e127	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x2256fafa	div64_u64_rem
++EXPORT_SYMBOL vmlinux 0x2263e380	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x2270f52e	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0x22756d14	block_read_full_page
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x2278e94b	slhc_remember
++EXPORT_SYMBOL vmlinux 0x228fd5c9	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x229776ee	backlight_force_update
++EXPORT_SYMBOL vmlinux 0x2298e90d	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22b6ef1e	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x22d97615	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0x22dfdd06	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x2307ae9f	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x2327979b	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL vmlinux 0x235e90f3	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x2369630a	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x23701e6b	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x2371221d	cdev_del
++EXPORT_SYMBOL vmlinux 0x237c0759	simple_rename
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23a86fdb	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23ddae18	noop_llseek
++EXPORT_SYMBOL vmlinux 0x23f2243d	mempool_free
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x2401c55a	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x240b9099	seq_release_private
++EXPORT_SYMBOL vmlinux 0x241a8ba7	input_close_device
++EXPORT_SYMBOL vmlinux 0x241ab95c	netdev_notice
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x244dd531	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0x2451e777	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x247186bb	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0x24820e65	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x24855cba	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x249d4aff	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x24d77d4c	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0x24d86520	migrate_page
++EXPORT_SYMBOL vmlinux 0x24f00380	ida_init
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x250113b4	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x25339c5f	agp_bind_memory
++EXPORT_SYMBOL vmlinux 0x25354c3c	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x2536eb4a	set_user_nice
++EXPORT_SYMBOL vmlinux 0x25516626	of_get_named_gpio_flags
++EXPORT_SYMBOL vmlinux 0x25612ad2	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x25b13df6	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0x25b3d986	tty_port_open
++EXPORT_SYMBOL vmlinux 0x25bd1e73	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0x25e186c5	clear_user_page
++EXPORT_SYMBOL vmlinux 0x25e8ed29	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x25f3bd2e	atomic64_xchg
++EXPORT_SYMBOL vmlinux 0x25f41fac	ip_defrag
++EXPORT_SYMBOL vmlinux 0x25f46a34	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0x25fe08ee	__sock_create
++EXPORT_SYMBOL vmlinux 0x2609632c	mount_ns
++EXPORT_SYMBOL vmlinux 0x261a7e90	kunmap_high
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x26457eec	param_ops_short
++EXPORT_SYMBOL vmlinux 0x26477c07	__vmalloc
++EXPORT_SYMBOL vmlinux 0x264b5a4b	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0x264d8400	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x268475a9	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0x26b760c4	slhc_init
++EXPORT_SYMBOL vmlinux 0x26bb950b	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0x26c92c8f	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0x26ca71a9	netlink_unicast
++EXPORT_SYMBOL vmlinux 0x26cf23cf	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26e7fdec	__brelse
++EXPORT_SYMBOL vmlinux 0x270ee624	of_dev_put
++EXPORT_SYMBOL vmlinux 0x2718bfb8	copy_to_iter
++EXPORT_SYMBOL vmlinux 0x27477acb	fb_blank
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x274b052d	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x27706951	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x2771d7ff	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x27725960	keyring_alloc
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x278ce0a3	of_get_next_parent
++EXPORT_SYMBOL vmlinux 0x278e89df	mmc_free_host
++EXPORT_SYMBOL vmlinux 0x279f8cbb	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0x27b902b2	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27c2af9e	generic_write_checks
++EXPORT_SYMBOL vmlinux 0x27c8e53a	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0x27da8def	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x27f35daf	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0x27f9dc73	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x27fb9e59	init_task
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x28199e4b	submit_bio
++EXPORT_SYMBOL vmlinux 0x2820e636	wake_up_process
++EXPORT_SYMBOL vmlinux 0x2873a476	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0x28890a9a	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0x289d8ceb	__register_nls
++EXPORT_SYMBOL vmlinux 0x289db3ee	idr_remove
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28a5bc85	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0x28a7159f	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0x28a7beba	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x28a9d029	tcp_connect
++EXPORT_SYMBOL vmlinux 0x28c8c75f	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0x28e6ce45	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x28ed2e55	generic_update_time
++EXPORT_SYMBOL vmlinux 0x28f784f5	__debugger_break_match
++EXPORT_SYMBOL vmlinux 0x2913f346	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x2919d4c2	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0x291dcc9c	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0x2934e0a2	blkdev_get
++EXPORT_SYMBOL vmlinux 0x29439a4e	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x294d7b7f	finish_no_open
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x2960629c	led_blink_set
++EXPORT_SYMBOL vmlinux 0x299480fc	dqget
++EXPORT_SYMBOL vmlinux 0x29af9aad	set_binfmt
++EXPORT_SYMBOL vmlinux 0x29b191ec	freeze_super
++EXPORT_SYMBOL vmlinux 0x29b85fe3	iterate_fd
++EXPORT_SYMBOL vmlinux 0x29ce8249	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0x29ddedb6	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x29e19047	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x29eafc92	cont_write_begin
++EXPORT_SYMBOL vmlinux 0x29ebc995	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0x29f08a64	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0x29fdda53	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0x2a12f184	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a73256e	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0x2aa0e4fc	strncasecmp
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2acb6138	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2adf1cd3	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x2af91d65	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b1aea28	sget_userns
++EXPORT_SYMBOL vmlinux 0x2b2693a2	agp_bridge
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b31c39d	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0x2b436d8c	default_llseek
++EXPORT_SYMBOL vmlinux 0x2b69afb0	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x2b928cab	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x2b9bc391	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2b9e53d6	vm_map_ram
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2baaf9d8	of_platform_device_create
++EXPORT_SYMBOL vmlinux 0x2be0f12d	dql_completed
++EXPORT_SYMBOL vmlinux 0x2be9350f	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x2bf466b9	lro_flush_all
++EXPORT_SYMBOL vmlinux 0x2bf95caf	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0x2bfd1982	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0x2c077b66	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x2c10a377	key_type_keyring
++EXPORT_SYMBOL vmlinux 0x2c14323a	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x2c22cf96	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x2c24c5b7	bio_map_kern
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c2bd7e9	tty_name
++EXPORT_SYMBOL vmlinux 0x2c2e852b	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x2c36d571	mmc_add_host
++EXPORT_SYMBOL vmlinux 0x2c3bc0b9	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x2c5c5a3c	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x2c69c2f4	sock_create_kern
++EXPORT_SYMBOL vmlinux 0x2c6fde7b	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0x2c791b6f	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0x2c7b1fca	down_timeout
++EXPORT_SYMBOL vmlinux 0x2c7e7155	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0x2cb1231e	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0x2ce5089f	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0x2cebb9e7	free_netdev
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d2cc9a5	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d37342e	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0x2d3afcc0	file_open_root
++EXPORT_SYMBOL vmlinux 0x2d5ea30a	padata_free
++EXPORT_SYMBOL vmlinux 0x2d7b8add	agp_generic_destroy_page
++EXPORT_SYMBOL vmlinux 0x2d7f8ea9	stop_tty
++EXPORT_SYMBOL vmlinux 0x2d81e63b	phy_connect
++EXPORT_SYMBOL vmlinux 0x2d836535	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0x2d8b9327	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x2d8fa160	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0x2d9d3e94	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0x2da6adeb	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0x2daa162b	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x2dbd4c4d	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0x2dc56fa1	mount_single
++EXPORT_SYMBOL vmlinux 0x2df9d75d	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0x2e00106f	dev_emerg
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e255782	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e2dc3aa	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0x2e398356	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x2e61d2f7	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0x2e661673	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x2e6e507e	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0x2e74a14f	dev_err
++EXPORT_SYMBOL vmlinux 0x2e84bb9d	mntget
++EXPORT_SYMBOL vmlinux 0x2eb31f1f	key_unlink
++EXPORT_SYMBOL vmlinux 0x2ec524ad	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x2ec66523	dget_parent
++EXPORT_SYMBOL vmlinux 0x2ec674ee	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0x2ecc5ceb	machine_id
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2efa6ac3	mmc_erase
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f09cdf1	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0x2f13e019	mutex_lock
++EXPORT_SYMBOL vmlinux 0x2f29a4cd	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0x2f35847e	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2f5f2a57	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0x2f6c81af	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0x2f7a9229	of_translate_dma_address
++EXPORT_SYMBOL vmlinux 0x2f9dea68	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fc037ed	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x300f0ab2	kset_register
++EXPORT_SYMBOL vmlinux 0x30226ddf	agp_device_command
++EXPORT_SYMBOL vmlinux 0x3022d766	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0x30230cbd	generic_write_end
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x303264cc	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x3046f744	param_set_bint
++EXPORT_SYMBOL vmlinux 0x30560eb3	mach_p1023_rdb
++EXPORT_SYMBOL vmlinux 0x305a18e3	fb_class
++EXPORT_SYMBOL vmlinux 0x3077f915	vfs_readv
++EXPORT_SYMBOL vmlinux 0x307975b0	vga_client_register
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x3099e85f	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30b44cc5	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0x30b8b35c	cpu_to_chip_id
++EXPORT_SYMBOL vmlinux 0x30bc8ddf	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0x30cff6a3	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0x30d8f196	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x30f76688	phy_init_hw
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310917fe	sort
++EXPORT_SYMBOL vmlinux 0x3110c230	mapping_tagged
++EXPORT_SYMBOL vmlinux 0x3137f501	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x31380354	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x315aae09	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x31837e2e	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x3191f109	__krealloc
++EXPORT_SYMBOL vmlinux 0x3196dc0c	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0x319d0a09	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x31ac95e9	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0x31b46812	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x31b470a2	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x31c4747f	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0x31e24776	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0x31f0bb78	__kmap_atomic_idx
++EXPORT_SYMBOL vmlinux 0x31f2eeff	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x321a34ee	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0x321fe3df	pci_disable_device
++EXPORT_SYMBOL vmlinux 0x32272d42	read_cache_pages
++EXPORT_SYMBOL vmlinux 0x3239a9d3	pci_save_state
++EXPORT_SYMBOL vmlinux 0x3243b800	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x325338ad	inet_select_addr
++EXPORT_SYMBOL vmlinux 0x3257baeb	__genl_register_family
++EXPORT_SYMBOL vmlinux 0x326217e9	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0x326817cd	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x3268bc80	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0x326b8e00	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0x32761610	of_get_pci_address
++EXPORT_SYMBOL vmlinux 0x327bf96e	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0x328a05f1	strncpy
++EXPORT_SYMBOL vmlinux 0x32b86435	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x32cabaf9	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0x32ceeef3	redraw_screen
++EXPORT_SYMBOL vmlinux 0x32d79921	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x32ddc69b	nd_sb_checksum
++EXPORT_SYMBOL vmlinux 0x32de1c69	ata_link_printk
++EXPORT_SYMBOL vmlinux 0x32ea35e2	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0x32f8347b	flush_dcache_icache_page
++EXPORT_SYMBOL vmlinux 0x3314ba2c	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0x33178a56	dm_put_device
++EXPORT_SYMBOL vmlinux 0x331fa4c8	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0x33233fcc	of_clk_get_by_name
++EXPORT_SYMBOL vmlinux 0x335ef16d	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0x336d5340	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0x33a988a1	nf_reinject
++EXPORT_SYMBOL vmlinux 0x33adf8c5	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x33b84f74	copy_page
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33d9438a	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x33dbfd93	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x33e0d6e1	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0x33e2920a	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x34052f60	dup_iter
++EXPORT_SYMBOL vmlinux 0x340bfdaa	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0x3412089e	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x3413dddc	__alloc_skb
++EXPORT_SYMBOL vmlinux 0x344adbd5	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x347f8922	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x34981857	scsi_add_device
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34a8d734	sock_register
++EXPORT_SYMBOL vmlinux 0x34b6b743	dquot_commit
++EXPORT_SYMBOL vmlinux 0x34b6dc2a	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x34cdaa9f	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x34fa2b13	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x35302236	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0x353de98f	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x35424368	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x355132b5	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x35523594	skb_insert
++EXPORT_SYMBOL vmlinux 0x35628855	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x357127fb	mount_bdev
++EXPORT_SYMBOL vmlinux 0x3579955f	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x35930784	icmpv6_send
++EXPORT_SYMBOL vmlinux 0x35a052ab	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35ac9031	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0x35c098c6	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0x35d6edad	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0x35dfebd4	param_ops_int
++EXPORT_SYMBOL vmlinux 0x35e4d348	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0x35e7a528	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0x3618cb2d	ida_destroy
++EXPORT_SYMBOL vmlinux 0x36212c6c	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x3627b036	of_mdio_parse_addr
++EXPORT_SYMBOL vmlinux 0x363f8812	generic_readlink
++EXPORT_SYMBOL vmlinux 0x365b8afc	module_put
++EXPORT_SYMBOL vmlinux 0x3664ff60	kernel_listen
++EXPORT_SYMBOL vmlinux 0x366f6d27	idr_destroy
++EXPORT_SYMBOL vmlinux 0x367ba856	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0x36abf945	sys_copyarea
++EXPORT_SYMBOL vmlinux 0x36ad20d1	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0x36b0e732	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36cae729	vme_dma_request
++EXPORT_SYMBOL vmlinux 0x36deb0fc	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x36e48ca6	inet_ioctl
++EXPORT_SYMBOL vmlinux 0x36ed2867	cdev_add
++EXPORT_SYMBOL vmlinux 0x36fdda67	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x370744a6	mdiobus_read
++EXPORT_SYMBOL vmlinux 0x371d2130	check_legacy_ioport
++EXPORT_SYMBOL vmlinux 0x372d586c	agp_generic_enable
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x374569f8	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0x3758413d	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0x376efa87	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0x37942d4b	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x37a1f826	phy_stop
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37b20161	security_file_permission
++EXPORT_SYMBOL vmlinux 0x37b8b39e	screen_info
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37cedbae	framebuffer_release
++EXPORT_SYMBOL vmlinux 0x37d00477	tty_hangup
++EXPORT_SYMBOL vmlinux 0x37e0153d	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x37e74642	get_jiffies_64
++EXPORT_SYMBOL vmlinux 0x37e7a6ea	mount_nodev
++EXPORT_SYMBOL vmlinux 0x37f0e0da	devm_memremap
++EXPORT_SYMBOL vmlinux 0x37f614b7	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x381ccc13	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x38363bfc	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0x384a6525	unlock_page
++EXPORT_SYMBOL vmlinux 0x385095a5	mount_subtree
++EXPORT_SYMBOL vmlinux 0x38521a64	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x3897b2d4	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38b451f2	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x38b825d1	idr_replace
++EXPORT_SYMBOL vmlinux 0x38cdf8bd	i8042_install_filter
++EXPORT_SYMBOL vmlinux 0x38dbe407	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0x38e5f2f9	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x38fb9933	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x3902216b	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0x3925e2bb	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x3952198d	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x396500b7	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39c08721	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x39cb2e08	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0x39cdf63c	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x39dca223	km_is_alive
++EXPORT_SYMBOL vmlinux 0x39e0db88	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0x39eaa650	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0x39f001d0	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x3a1ac054	set_normalized_timespec64
++EXPORT_SYMBOL vmlinux 0x3a21bd74	block_commit_write
++EXPORT_SYMBOL vmlinux 0x3a25e59f	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0x3a55cfaf	of_graph_get_remote_port_parent
++EXPORT_SYMBOL vmlinux 0x3a7debd6	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3a9f08cb	of_get_child_by_name
++EXPORT_SYMBOL vmlinux 0x3a9f8965	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0x3aa95448	fb_get_mode
++EXPORT_SYMBOL vmlinux 0x3ae880b6	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0x3af25a35	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x3afa8941	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0x3b0b946d	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x3b20b9bc	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0x3b2599d6	deactivate_super
++EXPORT_SYMBOL vmlinux 0x3b3ba79b	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0x3b500ecc	elv_rb_find
++EXPORT_SYMBOL vmlinux 0x3b51b7e0	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0x3b615a21	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b890de1	page_waitqueue
++EXPORT_SYMBOL vmlinux 0x3b8e60dd	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0x3b9ebb1d	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0x3ba38795	netdev_printk
++EXPORT_SYMBOL vmlinux 0x3bb5df5c	bio_reset
++EXPORT_SYMBOL vmlinux 0x3bc033ae	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0x3bc457ce	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x3bc920e6	down_write_trylock
++EXPORT_SYMBOL vmlinux 0x3bdbdc54	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0x3c1bd570	of_mdio_find_bus
++EXPORT_SYMBOL vmlinux 0x3c1e1a23	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c42d8d9	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0x3c481ccc	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0x3c56a8a5	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0x3c652b24	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0x3c6928ed	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0x3c75fd7d	key_link
++EXPORT_SYMBOL vmlinux 0x3c7ca42a	key_invalidate
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c9063a7	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x3ca232f7	cdrom_release
++EXPORT_SYMBOL vmlinux 0x3caa9ad8	serio_interrupt
++EXPORT_SYMBOL vmlinux 0x3cadf619	agp_backend_release
++EXPORT_SYMBOL vmlinux 0x3cb3931b	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x3cc4b0dc	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x3cc4d1fd	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0x3cdee821	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0x3cdefa70	is_nd_btt
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3ce7580e	of_graph_get_endpoint_by_regs
++EXPORT_SYMBOL vmlinux 0x3cf423e0	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0x3d02caf4	nf_log_register
++EXPORT_SYMBOL vmlinux 0x3d0b9ff4	mach_qemu_e500
++EXPORT_SYMBOL vmlinux 0x3d2e42c5	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x3d628a15	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0x3d8460ca	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0x3d866306	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x3d883cdf	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0x3d9ce9a8	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0x3dae79bb	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0x3dc02a4e	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3dd27fbc	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0x3dd3828e	__module_get
++EXPORT_SYMBOL vmlinux 0x3dfb11ae	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e0d0ffa	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0x3e1ae01d	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0x3e394152	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x3e43dcb7	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0x3e72bc57	__blk_end_request
++EXPORT_SYMBOL vmlinux 0x3e7c9d25	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0x3e882943	pcibios_align_resource
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x3eb085fe	dquot_initialize
++EXPORT_SYMBOL vmlinux 0x3eb7746c	simple_readpage
++EXPORT_SYMBOL vmlinux 0x3ed35288	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x3ee081e6	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0x3ee3b7d6	user_path_create
++EXPORT_SYMBOL vmlinux 0x3ee4304d	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0x3ee9de4a	ata_port_printk
++EXPORT_SYMBOL vmlinux 0x3eefd7db	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0x3f02c8d6	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0x3f0546a8	ioread32_rep
++EXPORT_SYMBOL vmlinux 0x3f0ba69c	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0x3f12c56a	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0x3f1fb61d	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0x3f206d0a	read_cache_page
++EXPORT_SYMBOL vmlinux 0x3f2899d9	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x3f3d66d7	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0x3f414c3e	complete_request_key
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f500bf8	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0x3f5e6f37	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0x3f616ce2	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x3f91007d	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0x3fb1cf71	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x3fdbaf49	md_register_thread
++EXPORT_SYMBOL vmlinux 0x3fe0d1c0	slhc_free
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x3ff58c6d	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0x3ff8e495	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0x4014e630	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x401db602	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4039918a	clk_register_clkdev
++EXPORT_SYMBOL vmlinux 0x4045d8c7	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x4056f42a	kill_anon_super
++EXPORT_SYMBOL vmlinux 0x4059792f	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a2d1dd	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x40a3482f	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c04161	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40c8ee52	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0x40cad967	eth_header_parse
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40f1a9ae	of_cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0x40f1ad10	tb_ticks_per_jiffy
++EXPORT_SYMBOL vmlinux 0x40fb415c	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x4102137e	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x410e045d	pci_iomap
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x414945b6	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x414f703a	simple_open
++EXPORT_SYMBOL vmlinux 0x4159c38f	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x4167adcb	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0x41684e73	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x4178634b	proc_remove
++EXPORT_SYMBOL vmlinux 0x41862ad4	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x418a5367	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x418afc4f	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x41ad525d	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0x41b79539	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x41cb0369	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0x41e7388b	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0x4212be94	mac_find_mode
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x422d26d8	km_state_expired
++EXPORT_SYMBOL vmlinux 0x423036ce	release_firmware
++EXPORT_SYMBOL vmlinux 0x42436eca	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0x42475b20	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x42595e58	vgacon_text_force
++EXPORT_SYMBOL vmlinux 0x42927eb7	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0x42961de2	skb_unlink
++EXPORT_SYMBOL vmlinux 0x429768e4	_dev_info
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42b413b1	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x42f373a0	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x42fce228	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x43300793	vfs_read
++EXPORT_SYMBOL vmlinux 0x433b2d42	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x43544266	path_noexec
++EXPORT_SYMBOL vmlinux 0x436c2179	iowrite32
++EXPORT_SYMBOL vmlinux 0x437668b6	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x4381660f	clear_inode
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x438ae13f	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0x43970466	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x43a01f90	complete_all
++EXPORT_SYMBOL vmlinux 0x43f072e5	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x43f4b8ea	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0x43f87c33	input_grab_device
++EXPORT_SYMBOL vmlinux 0x44013452	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x441716d5	of_iomap
++EXPORT_SYMBOL vmlinux 0x4421359f	nf_log_trace
++EXPORT_SYMBOL vmlinux 0x4421e6d6	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x442921d1	dput
++EXPORT_SYMBOL vmlinux 0x44366cfc	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0x443f5c55	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x44438b96	hex2bin
++EXPORT_SYMBOL vmlinux 0x444db9b6	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0x44625b08	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0x447a90a1	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0x449d889a	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44bd0d7f	request_firmware
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44eb192e	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x44ec0d95	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0x44ff8fa9	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0x4516a284	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x45283312	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x4547a8f4	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0x4558a057	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0x45725aa8	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x45871126	kmap_high
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45b4499c	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0x45b9bdb3	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x45bb67d3	dst_discard_out
++EXPORT_SYMBOL vmlinux 0x46066b6a	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x4612c59d	down_trylock
++EXPORT_SYMBOL vmlinux 0x46164d0a	dma_set_coherent_mask
++EXPORT_SYMBOL vmlinux 0x4618caf3	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0x461ebfa0	__copy_tofrom_user
++EXPORT_SYMBOL vmlinux 0x462345e1	xmon
++EXPORT_SYMBOL vmlinux 0x462a2e75	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x462ac3e0	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x466e6f3c	of_node_put
++EXPORT_SYMBOL vmlinux 0x467f72e0	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0x46a58b83	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0x46a85ed1	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0x46c6b689	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x46cb50d1	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x46d12956	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x46dded91	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x46e7f72d	nvdimm_revalidate_disk
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x4722cbb2	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0x47269f41	agp_collect_device_status
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x474eb5bd	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0x475088fb	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0x47608718	fence_init
++EXPORT_SYMBOL vmlinux 0x4762fe68	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x476bec33	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0x476e0fbb	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x4783180f	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0x47879c09	vme_lm_request
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x479eacb1	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0x47dcb3ae	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0x47e94e8f	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0x47fae7af	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x4807774d	uart_match_port
++EXPORT_SYMBOL vmlinux 0x482766a9	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0x483295a3	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0x483862ad	of_phy_is_fixed_link
++EXPORT_SYMBOL vmlinux 0x48404b9a	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x4840c8d5	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0x48535e63	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x4897ed80	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0x489f2299	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x48a771c5	cpu_core_map
++EXPORT_SYMBOL vmlinux 0x48ad77fb	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48e2c43c	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x48ee8940	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x48fd6a30	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x490b8e55	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x491a7dba	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x4935769a	of_io_request_and_map
++EXPORT_SYMBOL vmlinux 0x4951aaec	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x499643a6	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x49977619	devm_ioremap
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49bf3ad4	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0x49c02d8b	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0x49c077d3	of_get_ddr_timings
++EXPORT_SYMBOL vmlinux 0x49cd38c5	pci_pme_active
++EXPORT_SYMBOL vmlinux 0x49e032c7	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x49e0cebb	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x4a0254ac	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0x4a05ee32	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x4a073cd3	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x4a0d11b2	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0x4a21c39d	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x4a2f2acd	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x4a31aa77	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x4a4ad0f8	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0x4a595975	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x4a5f582c	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x4a7ad43f	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x4a7b08a0	of_find_all_nodes
++EXPORT_SYMBOL vmlinux 0x4aacce87	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4ad57501	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x4ad9e9c8	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0x4af1d04f	fput
++EXPORT_SYMBOL vmlinux 0x4afa43bc	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4aff0395	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0x4b01b0ff	single_release
++EXPORT_SYMBOL vmlinux 0x4b04f32d	update_region
++EXPORT_SYMBOL vmlinux 0x4b085dbf	agp3_generic_configure
++EXPORT_SYMBOL vmlinux 0x4b1ec3e2	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x4b2bcb18	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0x4b2f9867	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x4b32d43d	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0x4b55eba0	seq_pad
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b74db1c	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0x4b8326ff	ida_remove
++EXPORT_SYMBOL vmlinux 0x4ba9a3d6	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4bb282b9	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x4bb96e5d	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0x4bcf03a4	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x4bd23e47	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x4bd5b7a5	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x4be85a03	memweight
++EXPORT_SYMBOL vmlinux 0x4bed99b3	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0x4bfa7c5d	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x4bfb6cd2	seq_release
++EXPORT_SYMBOL vmlinux 0x4c11435a	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0x4c12c697	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x4c29dcbf	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x4c2ae700	strnstr
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c8d125e	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x4c931ea4	vfs_llseek
++EXPORT_SYMBOL vmlinux 0x4cbe1dc1	seq_file_path
++EXPORT_SYMBOL vmlinux 0x4cd01546	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0x4cd4472f	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4ced6e35	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x4d1c18a0	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0x4d21f4ea	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x4d24558f	agp_generic_alloc_user
++EXPORT_SYMBOL vmlinux 0x4d2d7651	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0x4d3c153f	sigprocmask
++EXPORT_SYMBOL vmlinux 0x4d45d89e	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x4d64ce29	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x4d67cf94	input_unregister_device
++EXPORT_SYMBOL vmlinux 0x4d71004a	__cpm2_setbrg
++EXPORT_SYMBOL vmlinux 0x4d791953	mempool_resize
++EXPORT_SYMBOL vmlinux 0x4d86b13d	param_ops_bint
++EXPORT_SYMBOL vmlinux 0x4d90f8a3	__nd_iostat_start
++EXPORT_SYMBOL vmlinux 0x4d95a645	nd_region_to_nstype
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4db7bfdb	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0x4db9d325	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0x4dbb18b3	led_update_brightness
++EXPORT_SYMBOL vmlinux 0x4dc2444a	loop_backing_file
++EXPORT_SYMBOL vmlinux 0x4dcd31b9	sock_release
++EXPORT_SYMBOL vmlinux 0x4dcdb47e	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0x4dd17c77	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4de6036c	get_agp_version
++EXPORT_SYMBOL vmlinux 0x4de69f21	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x4dec6038	memscan
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4df9c3b1	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0x4e0a312a	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e60610e	fsl_lbc_ctrl_dev
++EXPORT_SYMBOL vmlinux 0x4e611cfa	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0x4e6347fd	register_framebuffer
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6a6fb6	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e723aa9	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x4e983fbb	of_phy_find_device
++EXPORT_SYMBOL vmlinux 0x4e9ae323	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x4e9dffb5	ip_fast_csum
++EXPORT_SYMBOL vmlinux 0x4ea69a2e	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0x4ea8471a	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x4eb04192	dev_crit
++EXPORT_SYMBOL vmlinux 0x4eb538ee	init_buffer
++EXPORT_SYMBOL vmlinux 0x4eb8d312	nvdimm_bus_unlock
++EXPORT_SYMBOL vmlinux 0x4ecb76eb	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0x4ef4ba65	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0x4f0af11d	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0x4f1960c2	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0x4f1afb0b	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f1e2364	vfs_create
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f32988c	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f593ec4	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x4f5c8068	vme_slave_request
++EXPORT_SYMBOL vmlinux 0x4f6041ef	dns_query
++EXPORT_SYMBOL vmlinux 0x4f655dfb	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f75c909	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x4f82b729	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x4fa09b19	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0x4fcaefc2	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0x4fd45ba0	fasync_helper
++EXPORT_SYMBOL vmlinux 0x4fdbc7ac	contig_page_data
++EXPORT_SYMBOL vmlinux 0x4fdc7a37	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0x4fdee016	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x4fdee897	i8042_command
++EXPORT_SYMBOL vmlinux 0x4fe99583	atomic64_dec_if_positive
++EXPORT_SYMBOL vmlinux 0x4ff20df5	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x50001e61	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x501adb40	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x503ba658	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0x503cfe12	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0x5046f11f	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x505e8a43	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0x50612e50	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x5069cc63	dquot_release
++EXPORT_SYMBOL vmlinux 0x5072032d	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0x5082a57c	input_free_device
++EXPORT_SYMBOL vmlinux 0x509817cf	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x50995925	serio_rescan
++EXPORT_SYMBOL vmlinux 0x50b66bcb	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x50da5ddc	tty_kref_put
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x50e7885c	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x50f8e3ae	skb_store_bits
++EXPORT_SYMBOL vmlinux 0x50fe5c0d	of_find_device_by_node
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x512894b4	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x51327cbd	pci_get_class
++EXPORT_SYMBOL vmlinux 0x51503318	console_stop
++EXPORT_SYMBOL vmlinux 0x515aaf44	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x515e24a7	flush_instruction_cache
++EXPORT_SYMBOL vmlinux 0x5173aee8	agp_generic_insert_memory
++EXPORT_SYMBOL vmlinux 0x517918ea	dcb_getapp
++EXPORT_SYMBOL vmlinux 0x518cce4f	sg_miter_next
++EXPORT_SYMBOL vmlinux 0x518ddebc	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0x519b0da3	finish_wait
++EXPORT_SYMBOL vmlinux 0x51c63176	unregister_nls
++EXPORT_SYMBOL vmlinux 0x51db354e	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x51ef33b8	kstrndup
++EXPORT_SYMBOL vmlinux 0x51f2823f	bio_flush_dcache_pages
++EXPORT_SYMBOL vmlinux 0x51f3272e	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x5220f8ac	set_posix_acl
++EXPORT_SYMBOL vmlinux 0x52329449	vfs_statfs
++EXPORT_SYMBOL vmlinux 0x5247dd4b	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0x5265e0cd	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0x528c709d	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x52af562a	__crc32c_le
++EXPORT_SYMBOL vmlinux 0x52da2365	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0x5321a177	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x53289e60	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x5354b539	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x537ac7a4	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x5395a651	simple_empty
++EXPORT_SYMBOL vmlinux 0x539af73c	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x53ab861c	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0x53ac09f5	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x53d28c77	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0x53e7e751	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x53ebab1b	_outsl_ns
++EXPORT_SYMBOL vmlinux 0x53fded08	d_genocide
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x54097797	acl_by_type
++EXPORT_SYMBOL vmlinux 0x5412c7c7	up
++EXPORT_SYMBOL vmlinux 0x541e3955	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x542606b0	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0x5428e654	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0x543294d1	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x5442052e	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x5445b294	param_set_ullong
++EXPORT_SYMBOL vmlinux 0x545a4dc5	nd_namespace_blk_validate
++EXPORT_SYMBOL vmlinux 0x54626d95	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0x54787e19	blk_put_request
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54daef5d	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0x54dfadba	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x550e119b	add_disk
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x55332ce2	inet_release
++EXPORT_SYMBOL vmlinux 0x5537f0c6	seq_write
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x5564544e	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0x55670591	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x5568c553	complete
++EXPORT_SYMBOL vmlinux 0x55695279	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x557156cf	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x5577ef9e	udp_table
++EXPORT_SYMBOL vmlinux 0x55841b7c	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0x55a2f45b	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x55b47536	agp_generic_destroy_pages
++EXPORT_SYMBOL vmlinux 0x55b7f815	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x55bb69b3	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x55c30add	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x55d6c462	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0x56158320	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x56179ff2	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0x56198375	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0x561c9228	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x5625fb98	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0x562dd653	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x562fd2f8	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x563952a3	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x5641d569	sock_no_poll
++EXPORT_SYMBOL vmlinux 0x5645f8b1	generic_setlease
++EXPORT_SYMBOL vmlinux 0x56695410	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0x566b72f2	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x566df263	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x5676ede3	param_get_byte
++EXPORT_SYMBOL vmlinux 0x5676f472	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x5695fb6f	of_find_property
++EXPORT_SYMBOL vmlinux 0x56a4024e	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56dfee04	of_clk_get
++EXPORT_SYMBOL vmlinux 0x56ec0c7f	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x57034725	dm_get_device
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x57461197	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x575af70c	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x57890957	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0x579fbcd2	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0x57a3af5d	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x57ae095f	decrementer_clockevent
++EXPORT_SYMBOL vmlinux 0x57b7a2b0	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0x57c3d529	ns_capable
++EXPORT_SYMBOL vmlinux 0x57c51a6b	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x57dee6f1	downgrade_write
++EXPORT_SYMBOL vmlinux 0x57e3627b	sk_alloc
++EXPORT_SYMBOL vmlinux 0x58188520	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x582981d6	dquot_drop
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x583c8d0f	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x58493412	security_path_symlink
++EXPORT_SYMBOL vmlinux 0x584ef1d9	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0x5857b225	ioread16_rep
++EXPORT_SYMBOL vmlinux 0x58589080	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x586134da	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0x58623807	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0x58741dba	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x58772c4f	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x587b9f1c	vfs_writef
++EXPORT_SYMBOL vmlinux 0x58886848	__find_get_block
++EXPORT_SYMBOL vmlinux 0x58aac6b2	vga_get
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58d6a2b6	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x58def353	md_done_sync
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x58fe5f80	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0x5905d860	vm_stat
++EXPORT_SYMBOL vmlinux 0x5910e5d7	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x591241d0	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0x5932b12d	clkdev_drop
++EXPORT_SYMBOL vmlinux 0x59367e9e	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0x59369cf2	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0x5949c67a	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x595d0946	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x5963d589	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x599517b7	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59b3378a	completion_done
++EXPORT_SYMBOL vmlinux 0x59c7cc3e	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0x5a08e00d	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a1159f8	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x5a3874ac	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x5a3e9eaa	of_device_is_available
++EXPORT_SYMBOL vmlinux 0x5a4950f9	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0x5a4ae4e5	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0x5a4b442d	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x5a79cf09	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0x5a7f9140	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x5a8e7f31	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0x5a95ff89	sk_capable
++EXPORT_SYMBOL vmlinux 0x5aabf0d5	__frontswap_test
++EXPORT_SYMBOL vmlinux 0x5ad46740	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x5ae6c491	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x5ae75d08	scsi_device_get
++EXPORT_SYMBOL vmlinux 0x5afe7223	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5b02c0c7	phy_suspend
++EXPORT_SYMBOL vmlinux 0x5b0b95ae	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x5b19634d	div_s64_rem
++EXPORT_SYMBOL vmlinux 0x5b29a751	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x5b2d2f2c	skb_trim
++EXPORT_SYMBOL vmlinux 0x5b42372e	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x5b423c8a	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x5b8256b0	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0x5b9828c5	dma_spin_lock
++EXPORT_SYMBOL vmlinux 0x5bae0046	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0x5bb29ac0	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0x5bb62533	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0x5bc28d1a	generic_writepages
++EXPORT_SYMBOL vmlinux 0x5bedd2a2	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x5bf20145	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x5bf80882	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0x5bf81805	pmem_should_map_pages
++EXPORT_SYMBOL vmlinux 0x5c171930	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0x5c1c83ce	set_wb_congested
++EXPORT_SYMBOL vmlinux 0x5c29c357	set_anon_super
++EXPORT_SYMBOL vmlinux 0x5c2b93f1	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x5c37f319	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x5c44ba6a	dev_set_group
++EXPORT_SYMBOL vmlinux 0x5c5a3158	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x5c62dee4	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0x5c656d57	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x5c6855e0	setup_new_exec
++EXPORT_SYMBOL vmlinux 0x5c7b5085	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0x5c7d7472	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0x5c92fa25	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x5cada3ab	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x5cbdbbb1	current_in_userns
++EXPORT_SYMBOL vmlinux 0x5cc32bdc	bitmap_copy_le
++EXPORT_SYMBOL vmlinux 0x5cdcf53a	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0x5ce96127	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5d079085	flush_signals
++EXPORT_SYMBOL vmlinux 0x5d11d8ca	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0x5d1a6ee2	devm_request_resource
++EXPORT_SYMBOL vmlinux 0x5d246990	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x5d2e603a	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d58efa0	convert_ifc_address
++EXPORT_SYMBOL vmlinux 0x5d76d17f	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x5d83697b	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0x5d9208a7	make_kgid
++EXPORT_SYMBOL vmlinux 0x5da0a07b	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0x5dd0c29d	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0x5df5e421	write_one_page
++EXPORT_SYMBOL vmlinux 0x5e01fc34	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0x5e11546d	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0x5e27321b	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0x5e314cfa	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0x5e3a8a9c	__wake_up
++EXPORT_SYMBOL vmlinux 0x5e4e1bc8	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x5e585b14	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0x5e643e1e	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0x5e674ce6	__dax_fault
++EXPORT_SYMBOL vmlinux 0x5e791256	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x5e866d85	prandom_bytes
++EXPORT_SYMBOL vmlinux 0x5e928c4c	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5e95b9f2	param_get_int
++EXPORT_SYMBOL vmlinux 0x5eb0401e	proc_dostring
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ebfaa08	release_pages
++EXPORT_SYMBOL vmlinux 0x5ec87838	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0x5ecd5afe	agp_generic_remove_memory
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5ef2d136	inet6_offloads
++EXPORT_SYMBOL vmlinux 0x5efbb7b5	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f0604a3	rwsem_wake
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f0cf046	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x5f1ac43e	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0x5f1e9344	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x5f2916cb	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x5f46874b	phy_device_create
++EXPORT_SYMBOL vmlinux 0x5f4a0577	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x5f4de8c6	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0x5f5bd557	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0x5f723ff0	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x5f754e5a	memset
++EXPORT_SYMBOL vmlinux 0x5f7b0ee1	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0x5f8a2728	isa_io_base
++EXPORT_SYMBOL vmlinux 0x5f8ac2f6	bio_copy_data
++EXPORT_SYMBOL vmlinux 0x5fbf87e1	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0x5fd268cb	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x5fe3c156	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x5ff7e314	param_ops_byte
++EXPORT_SYMBOL vmlinux 0x5fffb517	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x6016558c	file_remove_privs
++EXPORT_SYMBOL vmlinux 0x6017ed05	nd_iostat_end
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x602d5993	dma_set_mask
++EXPORT_SYMBOL vmlinux 0x60307f00	iget_locked
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x606d8596	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0x6073732c	cur_cpu_spec
++EXPORT_SYMBOL vmlinux 0x60799030	of_find_node_with_property
++EXPORT_SYMBOL vmlinux 0x6088f3d0	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60b86f61	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x60cd1d9d	textsearch_register
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x60f397f6	__vfs_write
++EXPORT_SYMBOL vmlinux 0x61189ac0	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0x611b4404	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0x6121295e	seq_open_private
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x61557d94	eth_header
++EXPORT_SYMBOL vmlinux 0x6157cd0c	devm_clk_put
++EXPORT_SYMBOL vmlinux 0x615bf490	of_match_node
++EXPORT_SYMBOL vmlinux 0x6167caca	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0x61774c33	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x61b3560c	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61eef2c9	_insb
++EXPORT_SYMBOL vmlinux 0x61f0ee17	vga_con
++EXPORT_SYMBOL vmlinux 0x61f858cd	end_page_writeback
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x6220b4a2	crc32_le
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x622d73fe	udp_add_offload
++EXPORT_SYMBOL vmlinux 0x62518c95	param_get_bool
++EXPORT_SYMBOL vmlinux 0x62538167	slhc_toss
++EXPORT_SYMBOL vmlinux 0x625d9784	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0x626cd503	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x62708af5	__inet_hash
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x6274b5bb	fget_raw
++EXPORT_SYMBOL vmlinux 0x627df6c7	mdiobus_write
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x6289c08a	udp_poll
++EXPORT_SYMBOL vmlinux 0x629903d4	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0x62996d23	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x62af639f	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0x62b2f04b	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x62db7281	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0x630d1768	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0x631079c0	get_super
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x6331f24d	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0x633b55a6	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x6381c383	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0x638a5dc4	key_task_permission
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63bdd013	tty_devnum
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63dd96a3	secpath_dup
++EXPORT_SYMBOL vmlinux 0x63e42cdd	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0x63e6966a	of_get_parent
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63ecd7d2	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0x63ed678d	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x63ee79bd	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x64011a80	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x6419a66c	pci_set_master
++EXPORT_SYMBOL vmlinux 0x642f0439	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x64565307	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0x6496d76c	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64a4b84d	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x64af8829	from_kprojid
++EXPORT_SYMBOL vmlinux 0x64b44eb0	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0x64b71ec3	scsi_register
++EXPORT_SYMBOL vmlinux 0x64bfac0f	dquot_acquire
++EXPORT_SYMBOL vmlinux 0x64cd9063	sync_blockdev
++EXPORT_SYMBOL vmlinux 0x64ddc8c8	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0x64fbf218	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x6514f70a	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x652847a3	nvdimm_namespace_disk_name
++EXPORT_SYMBOL vmlinux 0x652f882a	input_register_device
++EXPORT_SYMBOL vmlinux 0x65400222	__irq_offset_value
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x6546343c	ip6_xmit
++EXPORT_SYMBOL vmlinux 0x6547c1b3	neigh_table_init
++EXPORT_SYMBOL vmlinux 0x6552d81d	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x6564bb88	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0x6565d33f	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x657123ca	input_release_device
++EXPORT_SYMBOL vmlinux 0x658423f9	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0x658bb1ca	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0x6595cf0c	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0x659adb82	key_validate
++EXPORT_SYMBOL vmlinux 0x659c2d72	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0x65bb58a2	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0x65c24d9a	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x65cabc01	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x66196a24	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x663d006b	keyring_clear
++EXPORT_SYMBOL vmlinux 0x663df9e8	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x66426082	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x664a98e9	pci_map_rom
++EXPORT_SYMBOL vmlinux 0x666ce694	elv_rb_del
++EXPORT_SYMBOL vmlinux 0x667e15a2	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0x667e6e34	get_task_io_context
++EXPORT_SYMBOL vmlinux 0x66869ec5	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x6687d59a	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x6695ed8e	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0x66b8d500	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0x66cc861a	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0x66e77ac0	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0x66eac8c1	rt6_lookup
++EXPORT_SYMBOL vmlinux 0x66ec67a4	path_is_under
++EXPORT_SYMBOL vmlinux 0x66fcc890	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0x670b47e9	key_put
++EXPORT_SYMBOL vmlinux 0x67157fdd	of_graph_parse_endpoint
++EXPORT_SYMBOL vmlinux 0x6732f3cb	of_phy_register_fixed_link
++EXPORT_SYMBOL vmlinux 0x673f815e	agp_bridges
++EXPORT_SYMBOL vmlinux 0x6743cbb5	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x6784edf1	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0x67974f31	of_scan_pci_bridge
++EXPORT_SYMBOL vmlinux 0x679f2f4d	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67bf9b44	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0x67c27335	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x67e2e572	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x67e332d2	kern_path
++EXPORT_SYMBOL vmlinux 0x67e8eb14	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x680bd375	path_nosuid
++EXPORT_SYMBOL vmlinux 0x681426b6	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0x68327444	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0x68609857	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x68698408	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68a28c4b	scsi_init_io
++EXPORT_SYMBOL vmlinux 0x68a66ec6	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x68abfd2b	dump_skip
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68bed9a7	vfs_getattr
++EXPORT_SYMBOL vmlinux 0x68cda86c	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x68e1dee3	vfs_readf
++EXPORT_SYMBOL vmlinux 0x690971ba	serio_open
++EXPORT_SYMBOL vmlinux 0x691e4485	follow_pfn
++EXPORT_SYMBOL vmlinux 0x6941a09f	scsi_print_result
++EXPORT_SYMBOL vmlinux 0x69488bb7	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0x695dc729	tty_lock
++EXPORT_SYMBOL vmlinux 0x696d3e18	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x697641fe	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0x698ea040	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x69926329	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0x699b981c	netif_device_detach
++EXPORT_SYMBOL vmlinux 0x69a0ca7d	iowrite16be
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69a7c737	register_key_type
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69be8ee1	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x69ca64e5	param_get_long
++EXPORT_SYMBOL vmlinux 0x69d4ba58	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x69d7e5b8	__debugger_ipi
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a33782a	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x6a397d85	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x6a516ef5	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x6a524a60	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x6a5e0df8	of_find_matching_node_and_match
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a62aa99	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0x6a6756a2	__break_lease
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a80a3f5	cpm_muram_free
++EXPORT_SYMBOL vmlinux 0x6a97f33d	input_event
++EXPORT_SYMBOL vmlinux 0x6ac5d287	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6acb973d	iowrite32be
++EXPORT_SYMBOL vmlinux 0x6aeaf6a8	unregister_console
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6afe28ac	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b1aab6b	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2a1538	write_inode_now
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b3605c8	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0x6b367e6b	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x6b66c889	fence_free
++EXPORT_SYMBOL vmlinux 0x6b6a9b12	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x6b7ec74a	get_acl
++EXPORT_SYMBOL vmlinux 0x6b9a4df6	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0x6b9bf103	mntput
++EXPORT_SYMBOL vmlinux 0x6baeffc8	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bca21cf	dev_add_offload
++EXPORT_SYMBOL vmlinux 0x6bd83614	no_llseek
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6bf7fa43	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0x6c02197b	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c18be50	blk_peek_request
++EXPORT_SYMBOL vmlinux 0x6c1ce5ce	strcspn
++EXPORT_SYMBOL vmlinux 0x6c3c7ebc	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c8319ed	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x6ca01cf3	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0x6ca1d1a4	atomic64_read
++EXPORT_SYMBOL vmlinux 0x6cb2a262	input_set_keycode
++EXPORT_SYMBOL vmlinux 0x6cb37127	flex_array_clear
++EXPORT_SYMBOL vmlinux 0x6cdc5c6b	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6cdd0d87	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0x6ce00c8a	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x6d00e930	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x6d075eb8	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0x6d0cf256	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d14eef8	__put_cred
++EXPORT_SYMBOL vmlinux 0x6d27d0f3	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d54e46d	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x6d5cc840	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0x6d630118	agp_alloc_page_array
++EXPORT_SYMBOL vmlinux 0x6d740223	flex_array_put
++EXPORT_SYMBOL vmlinux 0x6d81ea3b	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x6d8cc943	bioset_free
++EXPORT_SYMBOL vmlinux 0x6d9deb89	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x6da8029e	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0x6da928f4	_insw_ns
++EXPORT_SYMBOL vmlinux 0x6db6d582	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0x6dbe7fc1	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0x6dd31ef4	nvdimm_bus_lock
++EXPORT_SYMBOL vmlinux 0x6dd4a277	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6e379526	kernstart_addr
++EXPORT_SYMBOL vmlinux 0x6e49a735	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0x6e6514ed	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x6e6bb72e	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e933fed	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0x6e94cec5	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0x6e9bb384	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6eaa7438	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x6eb74dff	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x6ed26f6a	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x6edbeffe	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0x6f11b8b0	proc_set_user
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f28921f	d_instantiate
++EXPORT_SYMBOL vmlinux 0x6f3ddb99	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x6f702a71	up_write
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6fa0d84f	request_key_async
++EXPORT_SYMBOL vmlinux 0x6fa975c8	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6fe8b450	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x702ad4fe	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7054a3e4	request_dma
++EXPORT_SYMBOL vmlinux 0x7062b4cd	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0x7066e3ba	pci_clear_master
++EXPORT_SYMBOL vmlinux 0x706ad38e	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x70796d6c	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x7096d1a8	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x70aa4d0d	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0x70aef6b0	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0x70d888b7	__debugger_fault_handler
++EXPORT_SYMBOL vmlinux 0x70f5566f	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x7109928b	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x710a87f9	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0x71110072	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0x7112447a	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0x711937c4	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0x7121320c	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x712d8a98	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x712ed37b	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x7131e0ab	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0x7140a8ba	dqput
++EXPORT_SYMBOL vmlinux 0x714e26bc	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0x714e697b	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x714f20b7	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0x71597942	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0x715a8ddf	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x71771afb	__scm_send
++EXPORT_SYMBOL vmlinux 0x717f9b5d	md_update_sb
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71c90087	memcmp
++EXPORT_SYMBOL vmlinux 0x71e8fb36	md_reload_sb
++EXPORT_SYMBOL vmlinux 0x71ef67c1	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0x71f2fc1f	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0x71f65175	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x7204a907	component_match_add
++EXPORT_SYMBOL vmlinux 0x72115c9d	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0x72278c7e	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0x723a0410	send_sig_info
++EXPORT_SYMBOL vmlinux 0x723a4404	mdiobus_free
++EXPORT_SYMBOL vmlinux 0x72403d9d	tso_start
++EXPORT_SYMBOL vmlinux 0x724068df	agp_alloc_bridge
++EXPORT_SYMBOL vmlinux 0x7248f754	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0x725e7144	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x726d2756	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0x726db164	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x7279cd66	tty_port_init
++EXPORT_SYMBOL vmlinux 0x72a2086d	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x72a55efb	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x72aa9a81	__bread_gfp
++EXPORT_SYMBOL vmlinux 0x72acdbb7	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0x72b1ac94	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0x72b243d4	free_dma
++EXPORT_SYMBOL vmlinux 0x72b6fa56	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0x72d4c23c	fsl_get_sys_freq
++EXPORT_SYMBOL vmlinux 0x72d58de9	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x72de35ac	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x72eab541	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0x72ee2df3	of_n_size_cells
++EXPORT_SYMBOL vmlinux 0x72f98b62	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x72f9b4d3	simple_rmdir
++EXPORT_SYMBOL vmlinux 0x7302c073	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0x730d1692	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x73265b16	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0x733b2383	next_tlbcam_idx
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x7346ed11	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0x73510d7c	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x735d8503	add_wait_queue
++EXPORT_SYMBOL vmlinux 0x73710a3e	dqstats
++EXPORT_SYMBOL vmlinux 0x73979de6	atomic64_or
++EXPORT_SYMBOL vmlinux 0x739c6947	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0x73a10818	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0x73a78180	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0x73c0a636	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0x73db95f0	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x73e08fe9	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0x73e20c1c	strlcpy
++EXPORT_SYMBOL vmlinux 0x73e7c5d4	pci_match_id
++EXPORT_SYMBOL vmlinux 0x73ffd966	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x7417682b	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x7420cb4c	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x7433d054	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0x743e1164	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0x7449f772	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0x744bb661	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0x744c3950	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x744f8eb3	flush_dcache_page
++EXPORT_SYMBOL vmlinux 0x7457b3f6	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0x746601f3	get_io_context
++EXPORT_SYMBOL vmlinux 0x74717a0b	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x747686e7	set_device_ro
++EXPORT_SYMBOL vmlinux 0x748136df	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74dfdcb4	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74f82e6e	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0x7505bdef	memchr_inv
++EXPORT_SYMBOL vmlinux 0x751a5b7b	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0x7531a7ec	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0x7538b132	agp_off
++EXPORT_SYMBOL vmlinux 0x753ca423	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0x7549f012	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0x754c2331	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0x755464b0	agp_generic_mask_memory
++EXPORT_SYMBOL vmlinux 0x755fd82c	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0x756704ac	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0x756dd160	start_thread
++EXPORT_SYMBOL vmlinux 0x757f088f	cpm_muram_offset
++EXPORT_SYMBOL vmlinux 0x7593d385	div64_s64
++EXPORT_SYMBOL vmlinux 0x75967219	__get_page_tail
++EXPORT_SYMBOL vmlinux 0x75994700	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0x75996a12	filemap_flush
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75be856f	serio_bus
++EXPORT_SYMBOL vmlinux 0x75e74e24	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0x75e886d1	xattr_full_name
++EXPORT_SYMBOL vmlinux 0x75ff96f2	inet_frag_find
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x762b84c3	of_graph_get_remote_port
++EXPORT_SYMBOL vmlinux 0x763eed2e	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0x76414630	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x768f4bdc	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0x76983893	clk_add_alias
++EXPORT_SYMBOL vmlinux 0x769dd0ed	filemap_fault
++EXPORT_SYMBOL vmlinux 0x769e06d7	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x76ae215a	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x76be5f74	simple_setattr
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76d9bf11	crc32_be
++EXPORT_SYMBOL vmlinux 0x76e396da	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0x76f6c5ef	kmalloc_order
++EXPORT_SYMBOL vmlinux 0x77143a97	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x7714b882	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0x7714fee1	inet_frags_init
++EXPORT_SYMBOL vmlinux 0x7715b3c5	inet_addr_type
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x772b66b7	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0x77451379	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0x77480e50	free_task
++EXPORT_SYMBOL vmlinux 0x774b7128	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0x7769f94a	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x7782e6e6	PDE_DATA
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x779d4991	tty_mutex
++EXPORT_SYMBOL vmlinux 0x77b0298c	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0x77b97938	consume_skb
++EXPORT_SYMBOL vmlinux 0x77b9dee8	of_device_unregister
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77fabca8	d_path
++EXPORT_SYMBOL vmlinux 0x782567ec	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x783b977a	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0x785e08a2	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x788e53ae	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78a82619	block_write_end
++EXPORT_SYMBOL vmlinux 0x78c7f934	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x78d02b30	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78e8ea26	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0x78e8f984	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0x78f3e6e7	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x79223781	of_match_device
++EXPORT_SYMBOL vmlinux 0x792aff6e	__serio_register_port
++EXPORT_SYMBOL vmlinux 0x795f6f62	seq_read
++EXPORT_SYMBOL vmlinux 0x79659339	kill_fasync
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x79706d62	pci_find_bus
++EXPORT_SYMBOL vmlinux 0x79a25168	dm_io
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79c5d72d	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x79cae5a4	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0x79e7f4a9	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x79f9f2ed	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0x7a1aae80	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0x7a2add7d	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0x7a3399cf	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0x7a369211	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0x7a3cd3c4	set_nlink
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a56bb1a	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0x7a61525f	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0x7a69c808	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0x7a81ab22	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0x7a9506a0	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0x7a95e5ae	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7aa7d8bb	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7afa89fc	vsnprintf
++EXPORT_SYMBOL vmlinux 0x7b05e944	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x7b0d2c03	local_flush_tlb_page
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b1ade38	lz4_decompress
++EXPORT_SYMBOL vmlinux 0x7b2626bc	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x7b283ce3	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0x7b3b766d	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x7b44d608	vmap
++EXPORT_SYMBOL vmlinux 0x7b5c8440	vm_munmap
++EXPORT_SYMBOL vmlinux 0x7b7c1896	set_bh_page
++EXPORT_SYMBOL vmlinux 0x7bc780d2	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x7bdb8ba0	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x7be4827c	pci_dram_offset
++EXPORT_SYMBOL vmlinux 0x7bef0f6c	of_device_is_compatible
++EXPORT_SYMBOL vmlinux 0x7c003aef	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c34fd94	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x7c43058b	tty_set_operations
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c6f304f	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0x7c70642f	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x7c84f858	phy_detach
++EXPORT_SYMBOL vmlinux 0x7c9291d1	csum_partial_copy_generic
++EXPORT_SYMBOL vmlinux 0x7c981558	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7c9bcb64	udp_set_csum
++EXPORT_SYMBOL vmlinux 0x7ca5ca89	iunique
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7cf17aaf	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d5cc8f0	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0x7d67b743	igrab
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d84d379	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0x7db8f434	seq_puts
++EXPORT_SYMBOL vmlinux 0x7dbe05b0	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0x7dbf7739	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0x7dd05a68	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0x7dd2893f	dev_warn
++EXPORT_SYMBOL vmlinux 0x7debaee3	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7df58462	d_alloc
++EXPORT_SYMBOL vmlinux 0x7e0fc82c	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0x7e433e2c	pci_dev_get
++EXPORT_SYMBOL vmlinux 0x7e5d1edc	tty_do_resize
++EXPORT_SYMBOL vmlinux 0x7e73da9e	path_put
++EXPORT_SYMBOL vmlinux 0x7e87227e	slhc_compress
++EXPORT_SYMBOL vmlinux 0x7e8eb498	netdev_err
++EXPORT_SYMBOL vmlinux 0x7e9076fd	skb_find_text
++EXPORT_SYMBOL vmlinux 0x7ebaa052	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0x7ecb001b	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x7ede6047	skb_push
++EXPORT_SYMBOL vmlinux 0x7ee4c529	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7ee73c0c	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0x7ef8efb4	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0x7f0202c6	dquot_destroy
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f2bc1ba	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x7f327c8a	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0x7f33718a	__netif_schedule
++EXPORT_SYMBOL vmlinux 0x7f3544ce	sk_free
++EXPORT_SYMBOL vmlinux 0x7f488cef	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0x7f5448c0	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f80856d	drop_super
++EXPORT_SYMBOL vmlinux 0x7f81c930	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0x7fb42de8	inet_bind
++EXPORT_SYMBOL vmlinux 0x7fb775c0	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0x7fbcbf25	elevator_change
++EXPORT_SYMBOL vmlinux 0x7fde2edb	vme_master_read
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fe345bb	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0x7fe7599b	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0x7feaeac2	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x8031d663	kmap_atomic_prot
++EXPORT_SYMBOL vmlinux 0x803e54ba	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x804b36e7	genphy_update_link
++EXPORT_SYMBOL vmlinux 0x80547e98	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0x805490cd	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x805ca06e	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x809c03de	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x80c17799	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80d3e1b3	ps2_command
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80d98019	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x80e2c33f	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x80e66dce	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0x80eed8e7	filp_close
++EXPORT_SYMBOL vmlinux 0x80f83a38	nvm_register
++EXPORT_SYMBOL vmlinux 0x81442bed	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x8145cf31	inet_accept
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x815453c5	input_reset_device
++EXPORT_SYMBOL vmlinux 0x8156d623	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x815c56d0	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x816f5cdb	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0x81a07f4e	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x81beccc9	input_flush_device
++EXPORT_SYMBOL vmlinux 0x81c125a5	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x8203fb5e	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0x82043f98	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x822677aa	revert_creds
++EXPORT_SYMBOL vmlinux 0x822c5a8c	fence_add_callback
++EXPORT_SYMBOL vmlinux 0x824bf4b8	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x824c6c2e	pci_release_regions
++EXPORT_SYMBOL vmlinux 0x82606a32	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x82664d3a	d_rehash
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x8272fb06	thaw_super
++EXPORT_SYMBOL vmlinux 0x8277b080	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82829f79	neigh_update
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82c65abd	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0x82cd540a	atomic64_and
++EXPORT_SYMBOL vmlinux 0x82e5a238	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x82fe00f6	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x830daa8b	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0x831ed666	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x832fa791	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x833e6bf9	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0x8341021a	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0x834ab166	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x8359e879	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x8372cd2f	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x8379d22b	kernel_write
++EXPORT_SYMBOL vmlinux 0x838041f7	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x83835e37	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x83844c29	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0x8387ae62	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x83a075a1	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0x83a3e047	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0x83a698d0	seq_dentry
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83bf0f15	pci_domain_nr
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83cbf427	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x843add40	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0x844404cf	ISA_DMA_THRESHOLD
++EXPORT_SYMBOL vmlinux 0x844b99de	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x844d53b8	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0x84612eb4	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x846de109	unlock_rename
++EXPORT_SYMBOL vmlinux 0x8477beb6	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0x84826bfe	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0x84a66e7b	new_inode
++EXPORT_SYMBOL vmlinux 0x84ac8684	__invalidate_device
++EXPORT_SYMBOL vmlinux 0x84b183ae	strncmp
++EXPORT_SYMBOL vmlinux 0x84bd69bf	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x84cea3a3	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x84ee0455	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x850141ee	misc_deregister
++EXPORT_SYMBOL vmlinux 0x85039a41	param_ops_string
++EXPORT_SYMBOL vmlinux 0x85206489	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x8537b5a9	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0x8559bcb4	mmc_start_req
++EXPORT_SYMBOL vmlinux 0x855ae6cd	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x85707848	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x857abe22	key_revoke
++EXPORT_SYMBOL vmlinux 0x857ea2aa	of_phy_connect
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85c0e18b	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85e9e020	lock_fb_info
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x8600653e	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0x860be789	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0x860e8f00	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x860ec3b3	phy_device_register
++EXPORT_SYMBOL vmlinux 0x8615bde3	switch_mmu_context
++EXPORT_SYMBOL vmlinux 0x86182550	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0x8632216e	km_policy_expired
++EXPORT_SYMBOL vmlinux 0x86364bec	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0x86396674	uart_resume_port
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x865753b9	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0x865b02bc	bio_init
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x86977d43	__breadahead
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86a4889a	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0x86b0e456	of_get_ibm_chip_id
++EXPORT_SYMBOL vmlinux 0x86baeace	of_find_node_by_name
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x86ff6153	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x872818c6	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x875923e9	mach_bsc9132_qds
++EXPORT_SYMBOL vmlinux 0x8760f5e4	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0x87723b3f	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x877e87ab	register_netdevice
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x87d08024	kill_bdev
++EXPORT_SYMBOL vmlinux 0x87d70eeb	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0x88034595	d_lookup
++EXPORT_SYMBOL vmlinux 0x8813ae59	tc_classify
++EXPORT_SYMBOL vmlinux 0x88150a5f	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0x8819ab21	do_splice_from
++EXPORT_SYMBOL vmlinux 0x881c96d0	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x88279f25	cpm_muram_alloc
++EXPORT_SYMBOL vmlinux 0x883f3b32	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0x88433304	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x8849f768	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0x88609211	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0x88703f3a	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x8899c8ea	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0x889c181c	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0x88a7b8e8	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x88c97cf2	skb_make_writable
++EXPORT_SYMBOL vmlinux 0x88ccd5a9	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x88d0def4	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x891fbb10	mempool_destroy
++EXPORT_SYMBOL vmlinux 0x892ae7de	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0x892b43e5	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0x893b8ec9	neigh_for_each
++EXPORT_SYMBOL vmlinux 0x89797060	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x89944462	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0x89a1124c	giveup_fpu
++EXPORT_SYMBOL vmlinux 0x89aac2d7	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0x89ab0cd9	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89dcd670	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x89ddd747	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x89f24a02	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x89f3f744	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x8a090888	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a20af73	is_bad_inode
++EXPORT_SYMBOL vmlinux 0x8a2789b3	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0x8a307845	f_setown
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a54572a	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x8a58d22d	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0x8a6d017e	simple_lookup
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8aa85854	dm_register_target
++EXPORT_SYMBOL vmlinux 0x8aac11f1	kobject_add
++EXPORT_SYMBOL vmlinux 0x8ab4079e	atomic64_add
++EXPORT_SYMBOL vmlinux 0x8acc915a	phy_find_first
++EXPORT_SYMBOL vmlinux 0x8adc5915	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x8adf7019	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0x8b2925a9	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x8b2b7a85	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0x8b3596d8	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b3b562f	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b5c6245	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b6e1bbc	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x8b7366b6	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0x8b755e4b	kill_block_super
++EXPORT_SYMBOL vmlinux 0x8b7ad77e	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b93b1e3	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0x8ba9b274	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0x8bae1e77	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0x8bd5d003	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0x8bf2ae1f	fsl_lbc_addr
++EXPORT_SYMBOL vmlinux 0x8bfd55ea	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0x8c183cbe	iowrite16
++EXPORT_SYMBOL vmlinux 0x8c527947	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c723410	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0x8c76067d	pci_bus_put
++EXPORT_SYMBOL vmlinux 0x8c938133	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0x8cc5d1fb	get_gendisk
++EXPORT_SYMBOL vmlinux 0x8cc79cab	iowrite16_rep
++EXPORT_SYMBOL vmlinux 0x8cde5d27	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0x8cf3626a	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0x8cf8b1ab	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0x8d015dd4	__bswapdi2
++EXPORT_SYMBOL vmlinux 0x8d2a137b	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0x8d373523	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x8d43f256	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0x8d494f67	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x8d540c8a	of_find_compatible_node
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d5e478c	param_set_charp
++EXPORT_SYMBOL vmlinux 0x8d6b2ce1	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x8d72495b	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d748f57	elv_add_request
++EXPORT_SYMBOL vmlinux 0x8d9c635f	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x8daa6374	dquot_enable
++EXPORT_SYMBOL vmlinux 0x8dabc468	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0x8dc05e67	scsi_host_get
++EXPORT_SYMBOL vmlinux 0x8dc45a39	bh_submit_read
++EXPORT_SYMBOL vmlinux 0x8de0b5ac	mempool_create
++EXPORT_SYMBOL vmlinux 0x8df8c20e	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x8dff727a	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0x8e0f9e5d	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0x8e43de58	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0x8e465e2b	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0x8e6b60c9	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e888ec3	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x8e8d58da	diu_ops
++EXPORT_SYMBOL vmlinux 0x8eaaf5e6	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x8ec04552	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0x8ed7fdcb	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0x8ef51bc6	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0x8f606564	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x8f7380bd	proc_set_size
++EXPORT_SYMBOL vmlinux 0x8f85f835	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x8f97edac	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x8fa97bf2	blk_end_request
++EXPORT_SYMBOL vmlinux 0x8fb42f6c	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0x8fbf37e0	profile_pc
++EXPORT_SYMBOL vmlinux 0x8fc15bf6	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0x8fc6b932	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0x8fc9c93f	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0x8fd5768d	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0x8ffdb3b8	crc16
++EXPORT_SYMBOL vmlinux 0x9001293e	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0x901c9ba7	release_sock
++EXPORT_SYMBOL vmlinux 0x902a408d	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0x904ee8ce	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x90534a40	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x9056f63f	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x90695906	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0x9074f862	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x90a11d11	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0x90abbbba	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0x90b31616	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x90b60092	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x90c5e819	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x90c8889b	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x90cd434a	validate_sp
++EXPORT_SYMBOL vmlinux 0x90cffb3b	dump_page
++EXPORT_SYMBOL vmlinux 0x90e67228	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0x90eeaada	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0x910377ba	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0x910f813e	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0x91185b27	force_sig
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x91566ee3	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x915e1208	tb_ticks_per_usec
++EXPORT_SYMBOL vmlinux 0x9163bb66	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x91779129	send_sig
++EXPORT_SYMBOL vmlinux 0x919d1163	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x91a5510d	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x91bc00b3	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x91e53d64	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x91e7824c	__quota_error
++EXPORT_SYMBOL vmlinux 0x91ec9620	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x923e873c	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0x924b89d6	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0x92559fcb	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0x92777bb9	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0x9287e52a	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0x928b61b6	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x92a5b01d	fsl_ifc_ctrl_dev
++EXPORT_SYMBOL vmlinux 0x92a9a8b4	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92b9e545	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0x92d55dcc	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x92e3ed4e	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0x92f847cf	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x92fd5a1a	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x9302c2cf	put_cmsg
++EXPORT_SYMBOL vmlinux 0x930582f6	of_get_min_tck
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x9305f942	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0x930e75cf	sock_from_file
++EXPORT_SYMBOL vmlinux 0x93215e1d	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0x932d98c1	cpm_muram_dma
++EXPORT_SYMBOL vmlinux 0x9344e8fb	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x9391e09b	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x93afff8d	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93b83741	prepare_binprm
++EXPORT_SYMBOL vmlinux 0x93c2000d	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0x93cc7a31	led_set_brightness
++EXPORT_SYMBOL vmlinux 0x93d50b65	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x93e05ff9	page_symlink
++EXPORT_SYMBOL vmlinux 0x93ebc165	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0x93f4a8b3	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x940ab0cf	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x940f9cf6	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x94149cd0	passthru_features_check
++EXPORT_SYMBOL vmlinux 0x9449662d	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0x944c0f2a	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0x94592424	agp_allocate_memory
++EXPORT_SYMBOL vmlinux 0x9461e81e	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94989bcd	open_exec
++EXPORT_SYMBOL vmlinux 0x94b541b5	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x94c33a56	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x94d5b05a	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0x94ee0bdb	inet6_bind
++EXPORT_SYMBOL vmlinux 0x94eea794	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x950d543f	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x9514151a	_mcount
++EXPORT_SYMBOL vmlinux 0x9524b0ae	_outsb
++EXPORT_SYMBOL vmlinux 0x953a06ac	page_readlink
++EXPORT_SYMBOL vmlinux 0x953f2feb	pci_find_hose_for_OF_device
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x954ea8bc	nd_btt_arena_is_valid
++EXPORT_SYMBOL vmlinux 0x9566acce	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0x956fbec4	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x9578db54	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0x95a5c0aa	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x95bb0841	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0x95c878ae	skb_split
++EXPORT_SYMBOL vmlinux 0x95e54a77	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0x95f58d7d	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0x95f5a196	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x9603b234	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x960dfaf5	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0x96181266	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0x961918c0	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x962e7355	fb_pan_display
++EXPORT_SYMBOL vmlinux 0x96366f56	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0x96573b80	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x9661ecf6	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0x966986b7	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0x9670140c	netdev_emerg
++EXPORT_SYMBOL vmlinux 0x96871208	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0x96898769	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x96945f20	user_revoke
++EXPORT_SYMBOL vmlinux 0x96b2e4a2	of_get_next_child
++EXPORT_SYMBOL vmlinux 0x96c46040	address_space_init_once
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x97013bef	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0x971b1631	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0x97213ed7	eth_header_cache
++EXPORT_SYMBOL vmlinux 0x97255bdf	strlen
++EXPORT_SYMBOL vmlinux 0x97263e2e	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x972e16c6	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0x9732ce59	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0x9748927f	_outsw_ns
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x975537ec	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x97a0f68e	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0x97a54863	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x97a99f25	module_refcount
++EXPORT_SYMBOL vmlinux 0x97aa72be	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0x97b069b8	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0x97c8b9a7	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0x97cc4d77	devm_memunmap
++EXPORT_SYMBOL vmlinux 0x97cc50e2	skb_put
++EXPORT_SYMBOL vmlinux 0x97e01887	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x97e434be	blk_make_request
++EXPORT_SYMBOL vmlinux 0x97f7c6f1	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0x97fdbac3	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x9814c7a5	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x98193876	tcp_filter
++EXPORT_SYMBOL vmlinux 0x982d42c8	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0x983b03f7	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x98680804	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0x986c5b3e	nla_append
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x987c44e2	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x987fbd75	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x989abc55	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0x98bc99a5	register_cdrom
++EXPORT_SYMBOL vmlinux 0x98bde69c	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0x98e68eca	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0x98f16cf7	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x98fe7882	DMA_MODE_READ
++EXPORT_SYMBOL vmlinux 0x98ffa9ba	proto_register
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x995397c0	set_disk_ro
++EXPORT_SYMBOL vmlinux 0x9955db9b	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x9982d7ff	netlink_capable
++EXPORT_SYMBOL vmlinux 0x998f75e0	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x999f4daf	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x99afe916	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0x99bb8806	memmove
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d9ed32	set_cached_acl
++EXPORT_SYMBOL vmlinux 0x99e864be	dquot_resume
++EXPORT_SYMBOL vmlinux 0x99fc7e1e	input_inject_event
++EXPORT_SYMBOL vmlinux 0x9a07f491	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0x9a0ca221	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0x9a139581	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0x9a16b187	dev_change_flags
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a4447e8	msi_bitmap_alloc_hwirqs
++EXPORT_SYMBOL vmlinux 0x9a65a617	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0x9a72ba43	inc_nlink
++EXPORT_SYMBOL vmlinux 0x9a736160	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0x9aa3f3b1	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x9aa57bd9	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0x9ae569cd	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9b005eae	single_open
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b6a778f	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x9b6c0083	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0x9b6ea9a3	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x9b6eb137	ksize
++EXPORT_SYMBOL vmlinux 0x9b7540f4	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x9b7563cd	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0x9b7ac99d	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bad4e47	param_get_ushort
++EXPORT_SYMBOL vmlinux 0x9bcba33f	module_layout
++EXPORT_SYMBOL vmlinux 0x9bd343d2	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0x9bdc2c0a	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9bfa3a10	input_register_handle
++EXPORT_SYMBOL vmlinux 0x9bff11a1	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0x9c03d09c	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x9c2ab579	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x9c3bcf7a	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c84bd61	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x9c90711b	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x9ca62b1e	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cc34dce	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0x9ccbf6a7	agp_generic_create_gatt_table
++EXPORT_SYMBOL vmlinux 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL vmlinux 0x9cf7a726	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0x9cfca1af	dquot_operations
++EXPORT_SYMBOL vmlinux 0x9d065a65	d_find_alias
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d0dd1af	sock_edemux
++EXPORT_SYMBOL vmlinux 0x9d14983a	ppc_enable_pmcs
++EXPORT_SYMBOL vmlinux 0x9d224b1d	give_up_console
++EXPORT_SYMBOL vmlinux 0x9d2e3f1a	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d45766a	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0x9d5c1e09	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0x9d669763	memcpy
++EXPORT_SYMBOL vmlinux 0x9d6a54c2	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0x9d72229b	fsl_ifc_find
++EXPORT_SYMBOL vmlinux 0x9d7ce8dd	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x9d8135be	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x9d8de8d6	import_iovec
++EXPORT_SYMBOL vmlinux 0x9d8f6b26	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0x9d9244d0	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0x9da5632d	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x9dc1e082	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0x9dcf3e5e	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x9dd816e3	unload_nls
++EXPORT_SYMBOL vmlinux 0x9dee9a84	cpm2_immr
++EXPORT_SYMBOL vmlinux 0x9dfe7307	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9e04cde9	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e2f85c7	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0x9e460905	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0x9e4b4185	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e6209ac	pcibios_fixup_bus
++EXPORT_SYMBOL vmlinux 0x9e68ae6b	register_qdisc
++EXPORT_SYMBOL vmlinux 0x9e6a75c5	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e822d99	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x9e848f83	freeze_bdev
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9ebf32b9	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x9ec16ee2	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x9ec2beb5	nvdimm_namespace_capacity
++EXPORT_SYMBOL vmlinux 0x9ecfa017	ip_options_compile
++EXPORT_SYMBOL vmlinux 0x9edbd9b6	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x9edcdcb6	load_nls
++EXPORT_SYMBOL vmlinux 0x9eee0fbb	pipe_unlock
++EXPORT_SYMBOL vmlinux 0x9ef14d25	of_platform_bus_probe
++EXPORT_SYMBOL vmlinux 0x9efbc5d2	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x9f028aeb	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x9f0cdc17	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0x9f3208cf	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0x9f343957	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0x9f3ebbb3	up_read
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f46faaf	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x9f5a7b1c	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x9f600181	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x9f8133c8	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0x9f911629	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9f9f3a79	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0x9fa097ec	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x9fad875a	commit_creds
++EXPORT_SYMBOL vmlinux 0x9fb98b3e	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0x9fc69329	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x9fc8792f	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0x9fc983e0	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9fe6798a	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x9fe9f7ad	__free_pages
++EXPORT_SYMBOL vmlinux 0x9ff1085a	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0x9ff53c0d	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0x9ffc259c	cdev_init
++EXPORT_SYMBOL vmlinux 0xa0059fb1	load_nls_default
++EXPORT_SYMBOL vmlinux 0xa006ac8f	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0xa01baad4	netif_napi_add
++EXPORT_SYMBOL vmlinux 0xa0218c6d	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0xa02bf6b4	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xa036e447	of_graph_get_next_endpoint
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa06df9e1	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0xa0756800	console_start
++EXPORT_SYMBOL vmlinux 0xa07e5da2	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa0992b5f	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0xa09cae03	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0xa0a9533f	account_page_redirty
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0ddd48b	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa120ce40	param_ops_charp
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa1691e31	sock_wake_async
++EXPORT_SYMBOL vmlinux 0xa192ace0	skb_append
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1c99385	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa1f8fe75	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0xa1fe98a4	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0xa201fe2e	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa22b815e	simple_write_end
++EXPORT_SYMBOL vmlinux 0xa264eaf8	param_set_short
++EXPORT_SYMBOL vmlinux 0xa26e31c1	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa288061c	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0xa2b8b3d8	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0xa2bbed37	crash_shutdown_register
++EXPORT_SYMBOL vmlinux 0xa2c5d4aa	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0xa2ce5a4e	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0xa2da2680	d_obtain_root
++EXPORT_SYMBOL vmlinux 0xa2fdbcbe	fence_default_wait
++EXPORT_SYMBOL vmlinux 0xa303d1ff	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0xa30b9ef4	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0xa318c52f	blk_get_request
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa3627c0e	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0xa3661267	of_translate_address
++EXPORT_SYMBOL vmlinux 0xa37bf2da	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0xa3807b51	param_set_byte
++EXPORT_SYMBOL vmlinux 0xa38126d5	iput
++EXPORT_SYMBOL vmlinux 0xa381944f	dql_reset
++EXPORT_SYMBOL vmlinux 0xa38bcd2b	param_get_charp
++EXPORT_SYMBOL vmlinux 0xa38e691a	ioremap_bot
++EXPORT_SYMBOL vmlinux 0xa39afa06	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0xa39b4cf2	udelay
++EXPORT_SYMBOL vmlinux 0xa3abc422	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xa3b3dbfb	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0xa3d801fc	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0xa3e545c9	vga_put
++EXPORT_SYMBOL vmlinux 0xa3e6dd9e	vfs_link
++EXPORT_SYMBOL vmlinux 0xa3e75545	flush_tlb_kernel_range
++EXPORT_SYMBOL vmlinux 0xa3ea3cd8	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0xa3ea5334	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0xa41d1289	padata_alloc
++EXPORT_SYMBOL vmlinux 0xa420d7d6	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0xa43b1297	vscnprintf
++EXPORT_SYMBOL vmlinux 0xa44146be	netlink_ack
++EXPORT_SYMBOL vmlinux 0xa448d2c0	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0xa4649532	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa4707bdc	nvm_end_io
++EXPORT_SYMBOL vmlinux 0xa470eb8b	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0xa49bc6d4	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xa4a94d26	find_next_bit_le
++EXPORT_SYMBOL vmlinux 0xa4b94fea	iowrite8_rep
++EXPORT_SYMBOL vmlinux 0xa4cdebc1	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0xa4cea44f	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xa4d4f0e6	global_cache_flush
++EXPORT_SYMBOL vmlinux 0xa4f019ab	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0xa50f4916	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0xa517e8cb	lock_rename
++EXPORT_SYMBOL vmlinux 0xa518350b	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0xa5193069	simple_dname
++EXPORT_SYMBOL vmlinux 0xa51b60b3	pipe_lock
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa5537f93	get_fs_type
++EXPORT_SYMBOL vmlinux 0xa56b8ab2	flex_array_free
++EXPORT_SYMBOL vmlinux 0xa56d42f1	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0xa573436b	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0xa578b91d	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0xa595143d	mach_twr_p1025
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa59bb005	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0xa59ec99f	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0xa5d3e841	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0xa5ff0737	put_tty_driver
++EXPORT_SYMBOL vmlinux 0xa64483b8	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0xa64d15eb	phy_attach
++EXPORT_SYMBOL vmlinux 0xa64eb090	genphy_suspend
++EXPORT_SYMBOL vmlinux 0xa65972b8	_memcpy_toio
++EXPORT_SYMBOL vmlinux 0xa65ae954	flush_old_exec
++EXPORT_SYMBOL vmlinux 0xa67117f5	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0xa67538ef	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa69390fa	skb_copy
++EXPORT_SYMBOL vmlinux 0xa6970398	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0xa6aa60dc	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0xa6f4da20	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa7030197	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xa70df3ee	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0xa7149ab3	icmp_send
++EXPORT_SYMBOL vmlinux 0xa720678c	lg_global_lock
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa7366115	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0xa73c0de4	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0xa7402cb0	abort_creds
++EXPORT_SYMBOL vmlinux 0xa74584e4	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0xa74f4e9b	ida_simple_get
++EXPORT_SYMBOL vmlinux 0xa763f7e9	init_net
++EXPORT_SYMBOL vmlinux 0xa76c9bc5	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0xa78402c8	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xa78b0149	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0xa78d9eb7	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0xa7e94902	kmap_pte
++EXPORT_SYMBOL vmlinux 0xa7ed897e	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0xa809055c	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0xa8147e4e	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0xa81e6509	generic_show_options
++EXPORT_SYMBOL vmlinux 0xa840f126	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa87e6597	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0xa89464b7	__ashldi3
++EXPORT_SYMBOL vmlinux 0xa898b485	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0xa8bccb57	unregister_key_type
++EXPORT_SYMBOL vmlinux 0xa8c61d5f	put_disk
++EXPORT_SYMBOL vmlinux 0xa8d180d2	register_gifconf
++EXPORT_SYMBOL vmlinux 0xa8f6f45c	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa9009f6c	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa916ded3	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0xa9273e1a	epapr_hypercall_start
++EXPORT_SYMBOL vmlinux 0xa9303393	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0xa9329c71	pci_find_capability
++EXPORT_SYMBOL vmlinux 0xa9571d6d	DMA_MODE_WRITE
++EXPORT_SYMBOL vmlinux 0xa95df391	finish_open
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa9ae8963	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0xa9b1b54e	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0xa9c28ce1	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9d723d6	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0xa9d950d4	serio_close
++EXPORT_SYMBOL vmlinux 0xaa01d0d3	param_set_ushort
++EXPORT_SYMBOL vmlinux 0xaa34864d	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0xaa46e87e	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0xaa53d2f2	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0xaa5f1c70	of_graph_get_port_by_id
++EXPORT_SYMBOL vmlinux 0xaa6901ac	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0xaa6e4df5	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa79ccb1	file_path
++EXPORT_SYMBOL vmlinux 0xaa7ceea6	neigh_destroy
++EXPORT_SYMBOL vmlinux 0xaa8e1adc	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0xaaab8067	cpu_sibling_map
++EXPORT_SYMBOL vmlinux 0xaab11ac3	dquot_disable
++EXPORT_SYMBOL vmlinux 0xaabab153	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0xaac51670	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0xaacee902	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaadaa3c7	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab047ca1	nf_afinfo
++EXPORT_SYMBOL vmlinux 0xab0488aa	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xab07827c	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0xab0e6384	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0xab228e31	csum_tcpudp_magic
++EXPORT_SYMBOL vmlinux 0xab25c779	serio_reconnect
++EXPORT_SYMBOL vmlinux 0xab3af6ab	key_alloc
++EXPORT_SYMBOL vmlinux 0xab46a88f	__destroy_inode
++EXPORT_SYMBOL vmlinux 0xab694444	bsearch
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab8954ed	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0xab8b73f4	drop_nlink
++EXPORT_SYMBOL vmlinux 0xaba3ad0c	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xabb67068	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabdaa8ce	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0xabdd6463	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xabe0be6a	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0xabe4ae4b	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0xabf1d928	param_set_int
++EXPORT_SYMBOL vmlinux 0xabfcb4c3	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0xac08e94d	seq_escape
++EXPORT_SYMBOL vmlinux 0xac0ac1b5	dma_direct_ops
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac1cd1f7	__page_symlink
++EXPORT_SYMBOL vmlinux 0xac246b02	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0xac26b820	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0xac40ab61	param_set_invbool
++EXPORT_SYMBOL vmlinux 0xac4cc1bc	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0xac636977	nf_register_hook
++EXPORT_SYMBOL vmlinux 0xac64eb55	phy_start
++EXPORT_SYMBOL vmlinux 0xac733cce	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0xac80c15b	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacb6b81f	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0xacbfa3bc	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0xacc5b5d2	csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacd0bdf7	kobject_get
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xacd9bcd0	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0xacdeec48	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xacf7031d	udp_del_offload
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad09d646	free_page_put_link
++EXPORT_SYMBOL vmlinux 0xad4ac674	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0xad547243	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0xad667aea	__block_write_begin
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad961743	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0xada141e2	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0xadafd807	get_phy_device
++EXPORT_SYMBOL vmlinux 0xadbf2f44	dquot_get_state
++EXPORT_SYMBOL vmlinux 0xadc0524d	of_mdiobus_register
++EXPORT_SYMBOL vmlinux 0xadc5f73a	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0xadd7f767	vme_master_request
++EXPORT_SYMBOL vmlinux 0xaddd4770	__debugger_iabr_match
++EXPORT_SYMBOL vmlinux 0xadf0811d	get_baudrate
++EXPORT_SYMBOL vmlinux 0xadf5ad12	bdput
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xae03ef3c	override_creds
++EXPORT_SYMBOL vmlinux 0xae06021f	padata_stop
++EXPORT_SYMBOL vmlinux 0xae0e232d	fd_install
++EXPORT_SYMBOL vmlinux 0xae247f54	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0xae358236	fence_signal
++EXPORT_SYMBOL vmlinux 0xae3aaa69	__napi_schedule
++EXPORT_SYMBOL vmlinux 0xae545f06	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xae663f7c	scmd_printk
++EXPORT_SYMBOL vmlinux 0xae6c10f9	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0xae701ec1	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0xae77a595	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0xae85a27e	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0xaec40edf	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0xaec655c7	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0xaefd6bb8	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0xaf063510	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xaf0b81c2	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0xaf154407	kernel_read
++EXPORT_SYMBOL vmlinux 0xaf2a5f5b	set_blocksize
++EXPORT_SYMBOL vmlinux 0xaf2d872c	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf4be512	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0xaf9340a7	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xaf997106	local_flush_tlb_mm
++EXPORT_SYMBOL vmlinux 0xaf9cee81	fsync_bdev
++EXPORT_SYMBOL vmlinux 0xafaedbfb	nd_region_acquire_lane
++EXPORT_SYMBOL vmlinux 0xafb0fd09	gen_pool_create
++EXPORT_SYMBOL vmlinux 0xafccc064	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0xafff3d1d	mempool_alloc
++EXPORT_SYMBOL vmlinux 0xb0057787	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0xb007b783	blk_rq_init
++EXPORT_SYMBOL vmlinux 0xb00f0c55	elevator_init
++EXPORT_SYMBOL vmlinux 0xb04241b4	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0xb05fab54	dev_printk
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb0742ce4	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0xb07d5135	sock_rfree
++EXPORT_SYMBOL vmlinux 0xb081b9c3	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0xb090f966	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0a321f7	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0b52dcd	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0xb0bcbddc	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0e2bc6a	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0xb0e48f26	mmc_request_done
++EXPORT_SYMBOL vmlinux 0xb0e5ac2b	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0xb0f29264	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0xb107ea8b	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0xb1256fbc	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb13d0f11	netdev_state_change
++EXPORT_SYMBOL vmlinux 0xb15bd8fa	tb_ticks_per_sec
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb1643044	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb16ff822	elevator_alloc
++EXPORT_SYMBOL vmlinux 0xb1861e45	netlink_set_err
++EXPORT_SYMBOL vmlinux 0xb18ec087	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0xb1987d39	bio_chain
++EXPORT_SYMBOL vmlinux 0xb1bc1920	param_set_long
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1c6e787	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1cfb5e2	fget
++EXPORT_SYMBOL vmlinux 0xb1e35209	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0xb1ed24a7	sync_filesystem
++EXPORT_SYMBOL vmlinux 0xb21390a7	inet_del_offload
++EXPORT_SYMBOL vmlinux 0xb233762c	atomic64_set
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb27050c6	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0xb2752d04	touch_buffer
++EXPORT_SYMBOL vmlinux 0xb287166f	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0xb294b556	wireless_send_event
++EXPORT_SYMBOL vmlinux 0xb2aa8d56	register_md_personality
++EXPORT_SYMBOL vmlinux 0xb2bcdc5d	con_is_bound
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2d48a2e	queue_work_on
++EXPORT_SYMBOL vmlinux 0xb2ead8ba	tty_free_termios
++EXPORT_SYMBOL vmlinux 0xb3020075	unregister_netdev
++EXPORT_SYMBOL vmlinux 0xb3139b04	iterate_dir
++EXPORT_SYMBOL vmlinux 0xb32d7b7e	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0xb32e35dd	nonseekable_open
++EXPORT_SYMBOL vmlinux 0xb3382494	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0xb34ab0e4	of_device_is_big_endian
++EXPORT_SYMBOL vmlinux 0xb34e528d	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0xb363b1ef	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0xb36ea6c0	pci_iounmap
++EXPORT_SYMBOL vmlinux 0xb38ef875	page_put_link
++EXPORT_SYMBOL vmlinux 0xb392fe83	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0xb39365d6	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0xb3b1cf97	nvdimm_namespace_common_probe
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3d9581b	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0xb3d97f72	audit_log
++EXPORT_SYMBOL vmlinux 0xb3e2de4e	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb4016a43	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xb402ccfe	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0xb4174298	generic_file_open
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb44cec6e	soft_cursor
++EXPORT_SYMBOL vmlinux 0xb4519a8f	string_escape_mem
++EXPORT_SYMBOL vmlinux 0xb469ede0	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0xb46b8e10	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0xb46cf188	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb484253b	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0xb487def1	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0xb49433d7	param_set_copystring
++EXPORT_SYMBOL vmlinux 0xb4d78452	vme_register_driver
++EXPORT_SYMBOL vmlinux 0xb4dea80b	phys_mem_access_prot
++EXPORT_SYMBOL vmlinux 0xb4ef02a1	sock_wfree
++EXPORT_SYMBOL vmlinux 0xb4f99514	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0xb512a796	do_splice_to
++EXPORT_SYMBOL vmlinux 0xb528c49d	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0xb52949c1	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb59e06d8	flush_tlb_mm
++EXPORT_SYMBOL vmlinux 0xb5a44c0b	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5ad540e	blk_init_queue
++EXPORT_SYMBOL vmlinux 0xb5b27c92	sock_no_bind
++EXPORT_SYMBOL vmlinux 0xb5b55c7d	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0xb5b79df6	param_get_ulong
++EXPORT_SYMBOL vmlinux 0xb5be7d1a	blk_get_queue
++EXPORT_SYMBOL vmlinux 0xb5c1f82f	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0xb5c60128	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0xb5d66f75	ilookup5
++EXPORT_SYMBOL vmlinux 0xb5d72381	kthread_stop
++EXPORT_SYMBOL vmlinux 0xb5d890da	start_tty
++EXPORT_SYMBOL vmlinux 0xb5d9454c	printk_emit
++EXPORT_SYMBOL vmlinux 0xb5f97751	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0xb5f9eadb	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0xb61af002	from_kgid
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb630fb53	agp_backend_acquire
++EXPORT_SYMBOL vmlinux 0xb6321112	param_ops_long
++EXPORT_SYMBOL vmlinux 0xb6491d9f	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0xb662cef7	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0xb67807f9	netdev_crit
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb6896671	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xb68ec311	sock_no_connect
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6ac8fc9	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0xb6b2d015	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0xb6b4527f	bio_put
++EXPORT_SYMBOL vmlinux 0xb6d19960	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0xb6db1daf	of_get_cpu_node
++EXPORT_SYMBOL vmlinux 0xb7058545	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0xb70d2437	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0xb70ece96	__d_drop
++EXPORT_SYMBOL vmlinux 0xb730e7c9	dev_load
++EXPORT_SYMBOL vmlinux 0xb73271d7	cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0xb7440845	of_node_get
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb752fe94	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0xb753bcc8	__ashrdi3
++EXPORT_SYMBOL vmlinux 0xb75fc760	invalidate_partition
++EXPORT_SYMBOL vmlinux 0xb7655d02	__sb_end_write
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb7738d54	brioctl_set
++EXPORT_SYMBOL vmlinux 0xb77c1a15	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0xb7846939	init_special_inode
++EXPORT_SYMBOL vmlinux 0xb79a4e1a	store_fp_state
++EXPORT_SYMBOL vmlinux 0xb79ec15d	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0xb7a1a160	dump_truncate
++EXPORT_SYMBOL vmlinux 0xb7a99781	__irq_regs
++EXPORT_SYMBOL vmlinux 0xb7bb933e	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0xb7bd6cf4	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7c7fcd5	dev_notice
++EXPORT_SYMBOL vmlinux 0xb7e015c1	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0xb7f887fc	simple_getattr
++EXPORT_SYMBOL vmlinux 0xb8111206	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0xb81960ca	snprintf
++EXPORT_SYMBOL vmlinux 0xb8269c8e	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb8370414	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0xb8487e31	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0xb85979b2	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb878c5c6	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0xb8854ac8	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xb88e3393	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0xb891c9ad	softnet_data
++EXPORT_SYMBOL vmlinux 0xb8982a37	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0xb8ba4a4d	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0xb8bc7c79	iget5_locked
++EXPORT_SYMBOL vmlinux 0xb8e877e7	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xb906f3ec	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0xb91f94ba	pci_device_from_OF_node
++EXPORT_SYMBOL vmlinux 0xb93c388a	msi_bitmap_free_hwirqs
++EXPORT_SYMBOL vmlinux 0xb9484b80	dev_mc_add
++EXPORT_SYMBOL vmlinux 0xb94dca31	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0xb9600cfc	generic_read_dir
++EXPORT_SYMBOL vmlinux 0xb995ccba	tty_unlock
++EXPORT_SYMBOL vmlinux 0xb9b04498	input_open_device
++EXPORT_SYMBOL vmlinux 0xb9bb1f6d	param_set_ulong
++EXPORT_SYMBOL vmlinux 0xb9e726fb	read_code
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xba0a4b69	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0xba155f07	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0xba1b1d7c	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba54ec89	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0xba5ca2d8	of_device_alloc
++EXPORT_SYMBOL vmlinux 0xba6ad7f0	ps2_init
++EXPORT_SYMBOL vmlinux 0xbab6420d	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0xbabe1b49	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0xbac3cbf2	ns_to_timespec64
++EXPORT_SYMBOL vmlinux 0xbaf70511	i2c_transfer
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb0bd939	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb43768d	generic_make_request
++EXPORT_SYMBOL vmlinux 0xbb52b4e0	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb7cca91	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0xbb832dc8	agp3_generic_tlbflush
++EXPORT_SYMBOL vmlinux 0xbb880bef	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xbb8b8a88	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0xbb956bc3	poll_freewait
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbbf79835	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0xbbf94808	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0xbc0515ff	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0xbc111693	pci_bus_type
++EXPORT_SYMBOL vmlinux 0xbc2d6c98	tty_port_put
++EXPORT_SYMBOL vmlinux 0xbc316de4	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0xbc4aea7a	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0xbc528c9e	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0xbc6c753e	napi_disable
++EXPORT_SYMBOL vmlinux 0xbc86ec38	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0xbc98c3fb	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0xbc9e88bf	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0xbcb17391	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0xbcbb8701	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcc5ea90	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0xbccd9a9b	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0xbccfaad7	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0xbd0939d8	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0xbd0b1443	datagram_poll
++EXPORT_SYMBOL vmlinux 0xbd1b0ced	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0xbd329787	netdev_info
++EXPORT_SYMBOL vmlinux 0xbd803510	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xbd87a3a1	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbd9e5d49	__lshrdi3
++EXPORT_SYMBOL vmlinux 0xbdc196af	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0xbe0e5118	nla_memcmp
++EXPORT_SYMBOL vmlinux 0xbe12bd97	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe20f12c	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0xbe541e85	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0xbe54fab1	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xbe55321f	md_integrity_register
++EXPORT_SYMBOL vmlinux 0xbe6edf09	submit_bh
++EXPORT_SYMBOL vmlinux 0xbe8d51df	follow_down
++EXPORT_SYMBOL vmlinux 0xbead162e	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xbebd767e	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0xbec2058d	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0xbee90f2f	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0xbeec8a0a	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbef50d7e	netdev_change_features
++EXPORT_SYMBOL vmlinux 0xbf03d50f	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0xbf146162	vm_event_states
++EXPORT_SYMBOL vmlinux 0xbf1751b7	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0xbf486982	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xbf77df13	of_device_get_match_data
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf8f606f	kthread_bind
++EXPORT_SYMBOL vmlinux 0xbf925c42	idr_init
++EXPORT_SYMBOL vmlinux 0xbf9a6998	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfb8b0b7	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xbfc177bc	iowrite32_rep
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xc007ecb6	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0xc00a5cde	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0xc0130a65	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0xc016642b	__ps2_command
++EXPORT_SYMBOL vmlinux 0xc017d705	sync_inode
++EXPORT_SYMBOL vmlinux 0xc03d8f60	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0xc057597f	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0xc068440e	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0xc0716749	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0b9a023	iget_failed
++EXPORT_SYMBOL vmlinux 0xc0ba163d	bdget
++EXPORT_SYMBOL vmlinux 0xc0c51669	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0xc0c9c356	agp_generic_alloc_pages
++EXPORT_SYMBOL vmlinux 0xc0e61f0a	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0xc10fa5c0	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0xc11d8093	iov_shorten
++EXPORT_SYMBOL vmlinux 0xc122077b	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0xc12ed24c	scsi_unregister
++EXPORT_SYMBOL vmlinux 0xc13a10dc	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0xc13dcde4	blk_finish_request
++EXPORT_SYMBOL vmlinux 0xc147d948	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0xc15c7f0c	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0xc1648bfb	of_gpio_simple_xlate
++EXPORT_SYMBOL vmlinux 0xc1850fb3	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0xc19e83fc	sk_wait_data
++EXPORT_SYMBOL vmlinux 0xc19f2df9	genphy_config_init
++EXPORT_SYMBOL vmlinux 0xc1a40f75	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0xc1cab965	param_set_uint
++EXPORT_SYMBOL vmlinux 0xc1cfc602	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1e1375a	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc20ca3ea	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0xc2123633	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0xc23855a6	bdgrab
++EXPORT_SYMBOL vmlinux 0xc2424641	agp3_generic_cleanup
++EXPORT_SYMBOL vmlinux 0xc262270c	bdevname
++EXPORT_SYMBOL vmlinux 0xc275c861	napi_complete_done
++EXPORT_SYMBOL vmlinux 0xc28316de	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0xc28d1164	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0xc291d8ab	nd_integrity_init
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2a75119	vme_bus_num
++EXPORT_SYMBOL vmlinux 0xc2acc033	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xc2c0b7c8	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0xc2cb5593	put_io_context
++EXPORT_SYMBOL vmlinux 0xc2d711e1	krealloc
++EXPORT_SYMBOL vmlinux 0xc2dd37d4	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0xc2e3541a	agp_copy_info
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc2e744ce	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0xc30f45b1	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0xc331a64e	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0xc336c6ff	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0xc34e2cd2	locks_init_lock
++EXPORT_SYMBOL vmlinux 0xc3504200	pci_restore_state
++EXPORT_SYMBOL vmlinux 0xc368849f	nvram_sync
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3c44a60	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0xc3ef8892	arp_send
++EXPORT_SYMBOL vmlinux 0xc402b28b	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0xc41451f9	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0xc41bdf04	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0xc41f0516	node_states
++EXPORT_SYMBOL vmlinux 0xc42e11bb	param_set_bool
++EXPORT_SYMBOL vmlinux 0xc42e6d3e	dma_find_channel
++EXPORT_SYMBOL vmlinux 0xc43eb4e9	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0xc44188b3	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0xc44201e0	update_devfreq
++EXPORT_SYMBOL vmlinux 0xc4474dc1	filp_open
++EXPORT_SYMBOL vmlinux 0xc44f30c9	set_groups
++EXPORT_SYMBOL vmlinux 0xc45755de	find_next_zero_bit_le
++EXPORT_SYMBOL vmlinux 0xc4575854	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xc45d845d	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0xc4708199	cpm_muram_addr
++EXPORT_SYMBOL vmlinux 0xc47cdf9c	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4cf9211	i2c_release_client
++EXPORT_SYMBOL vmlinux 0xc4f141b6	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0xc4feea81	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0xc4ffbb4f	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0xc501744d	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0xc505d8b7	agp_enable
++EXPORT_SYMBOL vmlinux 0xc509bc1a	bdi_register
++EXPORT_SYMBOL vmlinux 0xc54371fa	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0xc5534d64	ioread16
++EXPORT_SYMBOL vmlinux 0xc557d904	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0xc55de23c	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0xc55f3992	of_get_next_available_child
++EXPORT_SYMBOL vmlinux 0xc569046b	of_phy_attach
++EXPORT_SYMBOL vmlinux 0xc5883044	blk_start_queue
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc5a799f9	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0xc5b983f8	security_path_truncate
++EXPORT_SYMBOL vmlinux 0xc5cae75e	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0xc5cbe4af	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0xc5d6b430	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0xc5d9c46c	agp_try_unsupported_boot
++EXPORT_SYMBOL vmlinux 0xc5e464e2	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc60bb6e6	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0xc61cc21f	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0xc61e9769	kobject_put
++EXPORT_SYMBOL vmlinux 0xc62ed114	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc647c7fe	of_n_addr_cells
++EXPORT_SYMBOL vmlinux 0xc64a26d9	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc65abeb7	agp3_generic_sizes
++EXPORT_SYMBOL vmlinux 0xc65b4ebb	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0xc663b075	__ioremap
++EXPORT_SYMBOL vmlinux 0xc66fd026	pci_get_device
++EXPORT_SYMBOL vmlinux 0xc672f6b8	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc6751972	try_module_get
++EXPORT_SYMBOL vmlinux 0xc6b22c71	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0xc6bb3c5f	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0xc6bbb30b	nobh_writepage
++EXPORT_SYMBOL vmlinux 0xc6cb6a3c	netdev_alert
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6cc7ec7	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0xc6d9615f	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0xc70fad41	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0xc713a61f	file_ns_capable
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc72d3f82	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0xc72edcb9	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0xc753343c	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc762d1d3	kill_pid
++EXPORT_SYMBOL vmlinux 0xc768de19	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0xc76c21ac	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0xc7706665	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0xc77cc1db	bmap
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc7898275	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0xc78e949b	bio_split
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc79cd752	sock_create
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7ae201e	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0xc7bd58f2	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0xc7c85ec4	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xc7ec6c27	strspn
++EXPORT_SYMBOL vmlinux 0xc7f8bdaf	inet_put_port
++EXPORT_SYMBOL vmlinux 0xc810b53f	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0xc8144e9c	vfs_setpos
++EXPORT_SYMBOL vmlinux 0xc81a1303	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0xc8276a79	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xc8339e24	string_unescape
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc84a7447	clear_nlink
++EXPORT_SYMBOL vmlinux 0xc8571bcb	idr_for_each
++EXPORT_SYMBOL vmlinux 0xc859d542	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0xc8617f7d	agp_unbind_memory
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc87c2be1	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc8982dfc	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8b2a548	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8ba3c6a	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0xc8e554aa	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0xc8f7a40e	tty_port_close
++EXPORT_SYMBOL vmlinux 0xc8fced75	__register_chrdev
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc92b38be	may_umount
++EXPORT_SYMBOL vmlinux 0xc93fbc54	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xc942770a	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0xc94bfb89	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc999f805	flush_tlb_page
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc9bbbc1a	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0xc9c1fb35	phy_device_remove
++EXPORT_SYMBOL vmlinux 0xc9d9edfd	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0xc9f09b6e	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0xc9f3c3d8	security_path_link
++EXPORT_SYMBOL vmlinux 0xc9f69fcf	follow_down_one
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca2699eb	mem_map
++EXPORT_SYMBOL vmlinux 0xca2b1cd6	ida_pre_get
++EXPORT_SYMBOL vmlinux 0xca2c035f	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0xca41eaa3	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0xca4da981	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0xca6498ee	from_kuid
++EXPORT_SYMBOL vmlinux 0xca6dbd47	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0xca7cdec5	genphy_resume
++EXPORT_SYMBOL vmlinux 0xca8c2e2b	kfree_put_link
++EXPORT_SYMBOL vmlinux 0xca8e3959	kmap_to_page
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xcaac159a	pci_request_region
++EXPORT_SYMBOL vmlinux 0xcab32b23	kernel_connect
++EXPORT_SYMBOL vmlinux 0xcac17222	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0xcacd272d	atomic64_sub_return
++EXPORT_SYMBOL vmlinux 0xcace6297	idr_is_empty
++EXPORT_SYMBOL vmlinux 0xcad43e6f	inet_getname
++EXPORT_SYMBOL vmlinux 0xcaee2312	param_get_string
++EXPORT_SYMBOL vmlinux 0xcaf21a26	inet6_release
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb1a4e00	param_get_ullong
++EXPORT_SYMBOL vmlinux 0xcb87ad6e	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0xcb884a2a	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0xcb907095	md_flush_request
++EXPORT_SYMBOL vmlinux 0xcb9f2501	powerpc_debugfs_root
++EXPORT_SYMBOL vmlinux 0xcba940bf	make_kuid
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbd9c598	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0xcbeac4be	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcc17504d	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccc2c938	nd_dev_to_uuid
++EXPORT_SYMBOL vmlinux 0xccd5fa34	__f_setown
++EXPORT_SYMBOL vmlinux 0xcce036e8	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0xccfef64f	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0xccffb448	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0xcd0529c7	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0xcd0a0f1f	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xcd13dc7c	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd381e87	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0xcd61e17e	dst_alloc
++EXPORT_SYMBOL vmlinux 0xcd7c1a85	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0xcd7ede2a	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xcd86c87f	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0xcd9c8bc3	udp_prot
++EXPORT_SYMBOL vmlinux 0xcdac446b	blk_register_region
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcde083cc	nf_log_set
++EXPORT_SYMBOL vmlinux 0xcdf03f58	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce571744	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xcea68b81	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xceab17b6	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0xceb6a6cf	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0xcec1fc0a	bio_endio
++EXPORT_SYMBOL vmlinux 0xcec722c0	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0xcecb40e8	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf116b20	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0xcf13db67	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0xcf166a26	get_disk
++EXPORT_SYMBOL vmlinux 0xcf1d7646	isa_mem_base
++EXPORT_SYMBOL vmlinux 0xcf45b8de	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0xcf75dfb1	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0xd0102555	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0xd01bed83	proc_mkdir
++EXPORT_SYMBOL vmlinux 0xd047be28	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0xd06e1c12	ppp_input
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd085492c	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0xd0951504	tty_write_room
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0ac7473	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fef3b2	agp_free_key
++EXPORT_SYMBOL vmlinux 0xd102d845	of_mm_gpiochip_add
++EXPORT_SYMBOL vmlinux 0xd1299b03	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0xd14ebfac	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd1645f0c	install_exec_creds
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd196c9be	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xd1a35359	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0xd1aa0065	of_find_node_by_phandle
++EXPORT_SYMBOL vmlinux 0xd1ba65f5	vc_resize
++EXPORT_SYMBOL vmlinux 0xd1bde299	simple_unlink
++EXPORT_SYMBOL vmlinux 0xd1c84dfb	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1d97a25	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0xd1e3f3c4	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xd1e45ee9	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0xd1f121c5	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0xd1f19023	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd2588a35	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd280dc70	of_parse_phandle_with_fixed_args
++EXPORT_SYMBOL vmlinux 0xd28418a1	of_find_i2c_device_by_node
++EXPORT_SYMBOL vmlinux 0xd284b7e5	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0xd2902f64	mmc_of_parse_voltage
++EXPORT_SYMBOL vmlinux 0xd2a1755f	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0xd2a639f6	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0xd2ac8375	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0xd2af138b	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2f69e85	fs_bio_set
++EXPORT_SYMBOL vmlinux 0xd2fc19bd	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0xd3119b11	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0xd31ccb06	of_machine_is_compatible
++EXPORT_SYMBOL vmlinux 0xd31e769e	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0xd3228181	make_kprojid
++EXPORT_SYMBOL vmlinux 0xd33bf502	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0xd33e8349	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0xd349fcfc	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0xd359b47b	devm_free_irq
++EXPORT_SYMBOL vmlinux 0xd3879b04	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xd388fb32	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3e9f952	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0xd44b7e21	to_tm
++EXPORT_SYMBOL vmlinux 0xd475b56e	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0xd47d3cc6	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0xd48dafe0	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0xd48e6ecc	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0xd4a603ae	__scm_destroy
++EXPORT_SYMBOL vmlinux 0xd4ae8772	dst_destroy
++EXPORT_SYMBOL vmlinux 0xd4af2506	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0xd4b363be	skb_seq_read
++EXPORT_SYMBOL vmlinux 0xd4b680b8	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0xd4be6895	vc_cons
++EXPORT_SYMBOL vmlinux 0xd4d5aa8c	clk_get
++EXPORT_SYMBOL vmlinux 0xd4f2f9bd	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0xd4f826e6	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0xd50e0f91	cad_pid
++EXPORT_SYMBOL vmlinux 0xd52f9e0b	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0xd53aed80	vfs_writev
++EXPORT_SYMBOL vmlinux 0xd53c4297	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd581e13d	posix_test_lock
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd5cab662	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0xd5ddee16	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0xd5e8444a	__div64_32
++EXPORT_SYMBOL vmlinux 0xd5f52d4f	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0xd60282ad	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0xd606503d	register_sysctl
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd627480b	strncat
++EXPORT_SYMBOL vmlinux 0xd62a63c2	d_drop
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd6350e97	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd65499fd	of_root
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd69065de	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0xd690ea55	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0xd6924335	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0xd69b30e0	atomic64_add_unless
++EXPORT_SYMBOL vmlinux 0xd69c6cdd	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0xd6aaa006	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0xd6b8d94f	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0xd6d63e9d	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0xd6e9b395	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd6fdc719	dev_close
++EXPORT_SYMBOL vmlinux 0xd716e529	da903x_query_status
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd761a383	ioremap_prot
++EXPORT_SYMBOL vmlinux 0xd797b9a5	vme_master_write
++EXPORT_SYMBOL vmlinux 0xd7a0c3b5	generic_setxattr
++EXPORT_SYMBOL vmlinux 0xd7b308f9	vme_irq_free
++EXPORT_SYMBOL vmlinux 0xd7b5737d	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0xd7b6b5a2	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0xd7ba7409	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0xd7e15a5e	dst_release
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd806002b	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xd808d8f5	tcp_close
++EXPORT_SYMBOL vmlinux 0xd8401b97	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0xd84c43a6	lockref_put_return
++EXPORT_SYMBOL vmlinux 0xd84c51a6	down_read
++EXPORT_SYMBOL vmlinux 0xd84db9cc	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0xd85833cb	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0xd85e5862	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0xd86e45e2	dev_driver_string
++EXPORT_SYMBOL vmlinux 0xd873905f	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0xd87b3433	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0xd886cc4a	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0xd887d8de	seq_lseek
++EXPORT_SYMBOL vmlinux 0xd89574d3	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0xd899bf56	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a1a400	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd9301f1d	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0xd940857d	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0xd9498b22	proc_dointvec
++EXPORT_SYMBOL vmlinux 0xd966ddc2	__do_once_done
++EXPORT_SYMBOL vmlinux 0xd96d14f5	dev_mc_init
++EXPORT_SYMBOL vmlinux 0xd97a2952	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0xd97f7f73	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd9bac924	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0xd9ce8f0c	strnlen
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9ddf3ff	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0xd9e8cf5d	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0xda09be72	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0xda18a86f	kobject_del
++EXPORT_SYMBOL vmlinux 0xda1a45cb	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0xda1e171f	simple_statfs
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda458a06	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0xda519436	vme_bus_type
++EXPORT_SYMBOL vmlinux 0xda68dfe7	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0xda6d58df	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0xda70fe27	pci_bus_get
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda7e2140	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda8fa356	alloc_file
++EXPORT_SYMBOL vmlinux 0xdaa57ec3	totalhigh_pages
++EXPORT_SYMBOL vmlinux 0xdabc1ea8	fsl_lbc_find
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdad1ddef	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0xdad232db	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0xdb01198e	fsl_upm_find
++EXPORT_SYMBOL vmlinux 0xdb0c3d20	iov_iter_init
++EXPORT_SYMBOL vmlinux 0xdb200ed9	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0xdb2d9e32	bdi_destroy
++EXPORT_SYMBOL vmlinux 0xdb2e883b	vfs_write
++EXPORT_SYMBOL vmlinux 0xdb3a283b	have_submounts
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb6db3c5	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0xdb6fa5a8	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdba38075	d_add_ci
++EXPORT_SYMBOL vmlinux 0xdba98d16	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0xdbf9865d	fb_find_mode
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc14622e	nd_btt_probe
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc214961	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc408fb8	tty_check_change
++EXPORT_SYMBOL vmlinux 0xdc4ac418	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdc6d91a7	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0xdc7b5d4a	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0xdc9498dd	down
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdcc9004e	register_filesystem
++EXPORT_SYMBOL vmlinux 0xdcd3bd11	param_array_ops
++EXPORT_SYMBOL vmlinux 0xdcd55d7b	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xdcd75a28	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0xdcd88a67	__frontswap_store
++EXPORT_SYMBOL vmlinux 0xdcd9cfe7	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0xdd0a2ba2	strlcat
++EXPORT_SYMBOL vmlinux 0xdd13fd06	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0xdd27fa87	memchr
++EXPORT_SYMBOL vmlinux 0xdd402f7a	dev_activate
++EXPORT_SYMBOL vmlinux 0xdd43e3c4	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0xdd4447af	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0xdd523f92	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0xdd60d616	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0xdd867907	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0xdd9030af	current_stack_pointer
++EXPORT_SYMBOL vmlinux 0xdde1fcd8	save_mount_options
++EXPORT_SYMBOL vmlinux 0xddfbf649	arp_tbl
++EXPORT_SYMBOL vmlinux 0xde0e78d9	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0xde10a68a	do_splice_direct
++EXPORT_SYMBOL vmlinux 0xde140d5b	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0xde308b59	sock_create_lite
++EXPORT_SYMBOL vmlinux 0xde30d134	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0xde387d04	agp_generic_alloc_page
++EXPORT_SYMBOL vmlinux 0xde3927cc	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0xde41138e	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0xde48e9ca	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0xde636f59	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0xde78b5d4	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde952d9a	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0xde9b17ed	agp3_generic_fetch_size
++EXPORT_SYMBOL vmlinux 0xdec3784c	seq_putc
++EXPORT_SYMBOL vmlinux 0xded931f3	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0xdef85c56	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0xdefc9afd	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0xdf14a9b3	security_path_unlink
++EXPORT_SYMBOL vmlinux 0xdf151647	simple_release_fs
++EXPORT_SYMBOL vmlinux 0xdf19e0e6	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0xdf1f0b65	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf3171aa	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0xdf3402a2	simple_link
++EXPORT_SYMBOL vmlinux 0xdf3a693d	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0xdf4e1979	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf6851a4	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0xdf74078c	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0xdf904b6d	ping_prot
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdf93b9d8	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0xdf9d1389	seq_path
++EXPORT_SYMBOL vmlinux 0xdfa84391	register_netdev
++EXPORT_SYMBOL vmlinux 0xdfbd22a5	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0xdfd2b824	sock_no_listen
++EXPORT_SYMBOL vmlinux 0xdfd3e14c	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xdfe210e7	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0xdff43ed4	__debugger
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xe0074026	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0xe0197066	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0xe01a258f	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xe01a27f3	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0xe01e8c8f	input_register_handler
++EXPORT_SYMBOL vmlinux 0xe0241605	generic_getxattr
++EXPORT_SYMBOL vmlinux 0xe03a52b4	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0xe043fffc	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe0778286	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe09c8dfa	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0xe0aaeeee	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0c0540a	nvm_register_target
++EXPORT_SYMBOL vmlinux 0xe0cfe10b	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0xe0d4701b	seq_open
++EXPORT_SYMBOL vmlinux 0xe0db26a9	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0xe0e4deef	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0xe0f25de2	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe12709d1	d_walk
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe14ce388	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0xe14fc1b0	md_write_end
++EXPORT_SYMBOL vmlinux 0xe1548af5	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0xe1561f12	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe1ae5b0b	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0xe1c256aa	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe2093784	put_page
++EXPORT_SYMBOL vmlinux 0xe20dd142	devm_release_resource
++EXPORT_SYMBOL vmlinux 0xe210e772	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL vmlinux 0xe239f114	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe2845cdf	proc_douintvec
++EXPORT_SYMBOL vmlinux 0xe294b7fb	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2b6d7d9	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0xe2be5498	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2d9fdae	mach_corenet_generic
++EXPORT_SYMBOL vmlinux 0xe2dd7c29	audit_log_start
++EXPORT_SYMBOL vmlinux 0xe2e293ef	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0xe2e8065e	memdup_user
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe2fae716	kmemdup
++EXPORT_SYMBOL vmlinux 0xe3035cd5	registered_fb
++EXPORT_SYMBOL vmlinux 0xe32fa4b4	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0xe3313b7f	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0xe34c5595	kset_unregister
++EXPORT_SYMBOL vmlinux 0xe353050d	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xe37896aa	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xe37aa91d	keyring_search
++EXPORT_SYMBOL vmlinux 0xe37fd24b	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0xe382a4a9	skb_checksum
++EXPORT_SYMBOL vmlinux 0xe391c21d	empty_aops
++EXPORT_SYMBOL vmlinux 0xe3a872dd	__lock_page
++EXPORT_SYMBOL vmlinux 0xe3bacc58	mpage_readpage
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3bc9e47	get_pci_dma_ops
++EXPORT_SYMBOL vmlinux 0xe3bd2b00	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe413e6a1	single_open_size
++EXPORT_SYMBOL vmlinux 0xe42475e8	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0xe43e05f1	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0xe475c591	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0xe484e35f	ioread32
++EXPORT_SYMBOL vmlinux 0xe484f0f2	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0xe4c17741	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0xe4c54ce7	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe4e81bf8	get_empty_filp
++EXPORT_SYMBOL vmlinux 0xe4ea882e	generic_permission
++EXPORT_SYMBOL vmlinux 0xe4f5f3df	phy_resume
++EXPORT_SYMBOL vmlinux 0xe4fe8ca1	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xe5021f9b	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0xe51533c7	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0xe51a58a8	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0xe51f40b5	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe5379c88	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0xe53df6b7	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0xe55b3264	bdget_disk
++EXPORT_SYMBOL vmlinux 0xe563e281	nd_region_release_lane
++EXPORT_SYMBOL vmlinux 0xe5691941	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0xe575db88	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe57ee079	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe587c75a	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0xe5c08479	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5d2970d	poll_initwait
++EXPORT_SYMBOL vmlinux 0xe5dd8aa2	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe61097dd	thaw_bdev
++EXPORT_SYMBOL vmlinux 0xe61a7242	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0xe66452ab	dql_init
++EXPORT_SYMBOL vmlinux 0xe666233e	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0xe6915b76	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0xe692db7f	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0xe693a6ce	vme_get_size
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe6a46280	irq_set_chip
++EXPORT_SYMBOL vmlinux 0xe6ae8a7e	dquot_file_open
++EXPORT_SYMBOL vmlinux 0xe6cc6f7f	blk_queue_split
++EXPORT_SYMBOL vmlinux 0xe6da295e	phy_device_free
++EXPORT_SYMBOL vmlinux 0xe6dd236d	clear_pages
++EXPORT_SYMBOL vmlinux 0xe6ebc016	key_create_or_update
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe719ed6b	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0xe72f585e	down_read_trylock
++EXPORT_SYMBOL vmlinux 0xe766fbc9	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0xe76ff6bb	of_find_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0xe772f7bd	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0xe775877c	md_error
++EXPORT_SYMBOL vmlinux 0xe775a0ad	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7b4c23a	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0xe7b6315e	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xe7ce7439	_memcpy_fromio
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7f9fd96	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0xe800c83c	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0xe80911d4	__devm_request_region
++EXPORT_SYMBOL vmlinux 0xe81ef1dd	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe82cc752	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0xe861fc07	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0xe86bb3f9	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0xe87b2edd	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8b32d65	inet_sendpage
++EXPORT_SYMBOL vmlinux 0xe8be997e	phy_driver_register
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8f9e0b0	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe9378d58	idr_get_next
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe9634dec	netdev_features_change
++EXPORT_SYMBOL vmlinux 0xe9c0471d	tcp_poll
++EXPORT_SYMBOL vmlinux 0xe9c45a37	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0xe9c7c599	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0xe9cd4ff7	iterate_mounts
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xea01aa8c	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea06b7d1	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0xea0d36df	agp_find_bridge
++EXPORT_SYMBOL vmlinux 0xea34a70c	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0xea34a8c0	devm_clk_get
++EXPORT_SYMBOL vmlinux 0xea3e190c	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0xea3ffe84	blk_start_request
++EXPORT_SYMBOL vmlinux 0xea649a2f	__vfs_read
++EXPORT_SYMBOL vmlinux 0xea737abb	d_make_root
++EXPORT_SYMBOL vmlinux 0xea7987f1	key_update
++EXPORT_SYMBOL vmlinux 0xea7a42f9	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xea968c96	___ratelimit
++EXPORT_SYMBOL vmlinux 0xeab23810	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0xeb33338d	noop_fsync
++EXPORT_SYMBOL vmlinux 0xeb341c8f	param_ops_bool
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb55a931	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xeb582da8	posix_lock_file
++EXPORT_SYMBOL vmlinux 0xeb6ea927	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0xeb893b94	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0xeb8d93b5	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0xebcf59ee	del_gendisk
++EXPORT_SYMBOL vmlinux 0xebe2e033	md_check_recovery
++EXPORT_SYMBOL vmlinux 0xebf995bc	mpage_readpages
++EXPORT_SYMBOL vmlinux 0xebfd8e96	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0xec041c51	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0xec11938a	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0xec126e0d	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0xec12c436	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0xec1aa6ef	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xec25e12c	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xec34fc53	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0xec359ea3	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0xec4a5113	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0xec4b50f6	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec4e761a	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0xec6c6c8b	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0xec78fcf1	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0xec7c44f6	tty_throttle
++EXPORT_SYMBOL vmlinux 0xec82905a	tcf_em_register
++EXPORT_SYMBOL vmlinux 0xec83b850	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0xec9f231c	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0xeca72398	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0xecb8fbdd	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0xecbcb8bb	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xecc34c91	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0xecd982a2	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed5b9c23	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0xed6a3d5c	proc_symlink
++EXPORT_SYMBOL vmlinux 0xed93f29e	__kunmap_atomic
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xeda2263f	of_get_address
++EXPORT_SYMBOL vmlinux 0xeda55216	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0xeda90fa0	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0xedb0e53d	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0xedbaa5a4	netdev_warn
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedc410d0	udplite_table
++EXPORT_SYMBOL vmlinux 0xede1cb53	dev_alert
++EXPORT_SYMBOL vmlinux 0xede89d94	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0xedeffff2	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xedfeb675	nd_device_register
++EXPORT_SYMBOL vmlinux 0xee13cab1	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0xee248201	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0xee25374d	cdrom_open
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee2da831	twl6040_power
++EXPORT_SYMBOL vmlinux 0xee376d87	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0xee3a4605	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0xee3fc33f	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0xee492453	sys_imageblit
++EXPORT_SYMBOL vmlinux 0xee5924c3	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0xee7169c7	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0xee7799d7	__seq_open_private
++EXPORT_SYMBOL vmlinux 0xee7b0453	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0xee7bca37	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0xee8d4986	free_user_ns
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeed3d7e0	ilookup
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xef1b9343	dev_trans_start
++EXPORT_SYMBOL vmlinux 0xef1c7e3c	dev_open
++EXPORT_SYMBOL vmlinux 0xef2523c1	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0xef44bf3e	pci_request_regions
++EXPORT_SYMBOL vmlinux 0xef591342	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0xef62ccbc	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0xef6bac20	kern_unmount
++EXPORT_SYMBOL vmlinux 0xef6e2693	agp_generic_type_to_mask_type
++EXPORT_SYMBOL vmlinux 0xef7b323a	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0xef94b11b	input_set_capability
++EXPORT_SYMBOL vmlinux 0xefd11c22	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefde1bbe	flush_dcache_range
++EXPORT_SYMBOL vmlinux 0xefeee872	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf0151bb4	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf01b6b40	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0xf02cfa29	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0xf0489f3d	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0xf058ca1b	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf065f629	ioread16be
++EXPORT_SYMBOL vmlinux 0xf0696d6e	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0bd0383	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0xf0dbf8e9	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0xf0dc280b	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf0f200e5	sget
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf10dd746	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0xf10de535	ioread8
++EXPORT_SYMBOL vmlinux 0xf10df11c	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0xf11cd6ce	down_interruptible
++EXPORT_SYMBOL vmlinux 0xf144baf7	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf158c9ac	mount_pseudo
++EXPORT_SYMBOL vmlinux 0xf15af465	dcb_setapp
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf1a61c02	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1deabf2	div64_u64
++EXPORT_SYMBOL vmlinux 0xf1e54737	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf2041c0d	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf2131955	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0xf22881e8	lg_local_lock
++EXPORT_SYMBOL vmlinux 0xf228f1e5	kern_path_create
++EXPORT_SYMBOL vmlinux 0xf22d9962	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf2554ef3	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0xf27d3312	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0xf281f682	ppc_md
++EXPORT_SYMBOL vmlinux 0xf285f14f	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0xf28b6a47	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0xf2936109	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0xf297edf8	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2b08475	set_page_dirty
++EXPORT_SYMBOL vmlinux 0xf2c22f63	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2d417c3	netpoll_setup
++EXPORT_SYMBOL vmlinux 0xf304e55f	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf31ffeba	page_address
++EXPORT_SYMBOL vmlinux 0xf322a206	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf33cc2db	kernel_bind
++EXPORT_SYMBOL vmlinux 0xf33d103f	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0xf3428223	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf34ee636	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf3585c7d	phy_disconnect
++EXPORT_SYMBOL vmlinux 0xf3617081	vga_tryget
++EXPORT_SYMBOL vmlinux 0xf361c934	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf3987c98	revalidate_disk
++EXPORT_SYMBOL vmlinux 0xf3a296a9	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0xf3bc0621	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0xf3be29f8	to_nd_btt
++EXPORT_SYMBOL vmlinux 0xf3ca8f9b	neigh_xmit
++EXPORT_SYMBOL vmlinux 0xf3d8f608	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf3eac478	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0xf3eccc58	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0xf3ed59b2	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0xf40b2297	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xf410778e	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0xf441ac43	ioread8_rep
++EXPORT_SYMBOL vmlinux 0xf4423a3b	nobh_write_end
++EXPORT_SYMBOL vmlinux 0xf4449388	timer_interrupt
++EXPORT_SYMBOL vmlinux 0xf44bc29a	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0xf468fc8e	of_get_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0xf472db33	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf479e3e2	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0xf47fac1a	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xf48e785c	bdi_init
++EXPORT_SYMBOL vmlinux 0xf48eab7e	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0xf4917aa6	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0xf495b474	proto_unregister
++EXPORT_SYMBOL vmlinux 0xf4b40694	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4c0c580	inode_init_always
++EXPORT_SYMBOL vmlinux 0xf4d1d128	__getblk_slow
++EXPORT_SYMBOL vmlinux 0xf4eef396	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf5222143	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xf52321e0	atomic64_sub
++EXPORT_SYMBOL vmlinux 0xf533bc6d	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0xf53c32cd	get_super_thawed
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf55313a0	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0xf56165dc	param_get_uint
++EXPORT_SYMBOL vmlinux 0xf58f7caf	dev_deactivate
++EXPORT_SYMBOL vmlinux 0xf595017d	sock_i_ino
++EXPORT_SYMBOL vmlinux 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL vmlinux 0xf5a53dcb	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0xf5a5ac1e	ether_setup
++EXPORT_SYMBOL vmlinux 0xf5a62ecc	_memset_io
++EXPORT_SYMBOL vmlinux 0xf5ad8dce	write_cache_pages
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5d8611d	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0xf5e1558d	crash_shutdown_unregister
++EXPORT_SYMBOL vmlinux 0xf5e6188c	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf5ed53d2	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0xf5f50497	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0xf5f9bd9f	flush_icache_user_range
++EXPORT_SYMBOL vmlinux 0xf5fc383a	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0xf632365c	d_set_d_op
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf63ceedc	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0xf63f7e41	agp_generic_alloc_by_type
++EXPORT_SYMBOL vmlinux 0xf66a86d5	tcp_child_process
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf6789a40	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0xf67e9ae4	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0xf67f9bad	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0xf68246c4	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf6ad7292	prepare_creds
++EXPORT_SYMBOL vmlinux 0xf6b79a15	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6d7daa9	of_mm_gpiochip_remove
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6eeffb0	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0xf6f27342	current_fs_time
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf70384d7	__debugger_sstep
++EXPORT_SYMBOL vmlinux 0xf71521ba	atomic64_add_return
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf760ec31	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0xf78257b7	inet_listen
++EXPORT_SYMBOL vmlinux 0xf78aaccc	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0xf7a12d87	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0xf7a3309b	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0xf7a9ca70	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0xf7cdc736	clkdev_add
++EXPORT_SYMBOL vmlinux 0xf7d0d2b4	tcp_req_err
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82a7ad5	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf84c3d48	xfrm_input
++EXPORT_SYMBOL vmlinux 0xf8625d80	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0xf86b8fa2	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0xf87655f4	blk_put_queue
++EXPORT_SYMBOL vmlinux 0xf87be57d	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0xf89f09e1	cdev_alloc
++EXPORT_SYMBOL vmlinux 0xf8a2c3b4	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0xf8abb993	dev_uc_init
++EXPORT_SYMBOL vmlinux 0xf8e398fc	memstart_addr
++EXPORT_SYMBOL vmlinux 0xf8e3e795	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0xf8ea04f7	of_create_pci_dev
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf8f4d46e	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0xf8f86f85	agp_put_bridge
++EXPORT_SYMBOL vmlinux 0xf911f3e0	do_truncate
++EXPORT_SYMBOL vmlinux 0xf9228003	get_immrbase
++EXPORT_SYMBOL vmlinux 0xf928de80	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0xf9348cbc	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xf93601b1	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0xf93604a3	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0xf9402b68	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xf964beae	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0xf9705f47	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0xf9771214	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0xf99df678	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0xf9a4525c	find_lock_entry
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9bce358	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0xf9dc5f47	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0xf9e73082	scnprintf
++EXPORT_SYMBOL vmlinux 0xf9ed821f	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0xf9f9f729	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0xfa4259e0	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0xfa4816b1	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa5683cd	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa9e2728	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0xfaa66858	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0xfaaf9c9f	kobject_init
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xfad6f9b6	udp_ioctl
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfaee8ddc	fb_set_var
++EXPORT_SYMBOL vmlinux 0xfb1066cf	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0xfb688af7	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbc27d59	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbc768fc	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0xfbd08f5d	would_dump
++EXPORT_SYMBOL vmlinux 0xfbdf9a40	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0xfbeb2557	ps2_end_command
++EXPORT_SYMBOL vmlinux 0xfc004200	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc060136	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0xfc1cdc01	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0xfc2c02fa	alloc_disk
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc3b160f	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xfc3c79d0	flow_cache_init
++EXPORT_SYMBOL vmlinux 0xfc590846	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0xfc5dbe5e	of_device_register
++EXPORT_SYMBOL vmlinux 0xfc603fd0	tcf_register_action
++EXPORT_SYMBOL vmlinux 0xfc651f30	inet_offloads
++EXPORT_SYMBOL vmlinux 0xfc65459a	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0xfc92b737	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0xfca4bb1b	seq_vprintf
++EXPORT_SYMBOL vmlinux 0xfcb6225b	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcc44952	copy_from_iter
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcf84a93	atomic64_xor
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfcfdd2c7	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0xfd1ddab2	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0xfd1e458e	km_state_notify
++EXPORT_SYMBOL vmlinux 0xfd33b5fa	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xfd40c30f	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0xfd44b09e	__elv_add_request
++EXPORT_SYMBOL vmlinux 0xfd49d065	vfs_rename
++EXPORT_SYMBOL vmlinux 0xfd518b8e	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfda2d602	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0xfdb6cedc	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0xfdb9b629	ioread32be
++EXPORT_SYMBOL vmlinux 0xfdb9c219	register_quota_format
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfdce176d	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0xfded48ed	enable_kernel_fp
++EXPORT_SYMBOL vmlinux 0xfdee3313	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe2c2b5f	km_query
++EXPORT_SYMBOL vmlinux 0xfe366cec	scsi_execute
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe5f8736	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe822d55	get_brgfreq
++EXPORT_SYMBOL vmlinux 0xfe9ca2f8	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0xfea22e83	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0xfeba6496	of_get_mac_address
++EXPORT_SYMBOL vmlinux 0xfec40801	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xfec744cc	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0xfeca7590	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0xfed3698b	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xff0c6788	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff2167ae	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0xff21c322	blk_complete_request
++EXPORT_SYMBOL vmlinux 0xff22e426	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0xff2365c8	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xff4bd2e1	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff6dea25	smp_hw_index
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff95eeaa	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffc60224	md_write_start
++EXPORT_SYMBOL vmlinux 0xffc846c6	blk_run_queue
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xfff5804c	sock_i_uid
++EXPORT_SYMBOL_GPL crypto/af_alg 0x0be2e676	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0x4173710b	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x5741c3be	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x58716898	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0x6ca6db6e	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x82483953	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0x92f6e5d8	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0xa583d6a2	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xcd5a05b8	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xe8bcf20a	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xf1548a50	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x98963912	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x485847e9	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x76bfb2eb	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x9e8516e0	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0xb2a3611b	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x1b5ee19e	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xb5f645eb	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xe8c256f0	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xf4c29d81	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x2a693db8	async_xor_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x7b05b1ce	async_xor
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x77bad084	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x3e38c0b6	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x36a90184	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x9f0d8dd4	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0xddccc6de	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/cryptd 0x0b7a546d	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x1c990c44	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x1d32704c	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x5e537522	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x7538d757	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x9ae45017	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xa1b8c464	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xc81c9844	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0xd84cad3c	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xe4ddfc79	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0x8cd5136f	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x14bdd4d3	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x1ab5ab69	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x1ae2786e	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x425101ae	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x528cd876	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x69908edf	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x7cc8418f	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x89fa2145	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xf8a0cae9	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x4f69f661	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x6e08042f	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x9c510c4d	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xab565ec5	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0xa068d1eb	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x8b7849bc	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0xd92f3340	xts_crypt
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x153f6c9b	ahci_qc_issue
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x15bc856c	ahci_error_handler
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x28034b66	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x2fc8f070	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x304c8f62	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x3094aaed	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x4267e004	ahci_host_activate
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x470cc4e0	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x6f553a63	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x79cbdbc0	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x89012a49	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x90c36dcc	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x9337e81f	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x9c1fb306	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa516d271	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa9678b31	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc284627b	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xd121b20e	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xdc4bf7d3	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe5545c48	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xec612ad4	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xee16d645	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf9264bef	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x02e30ade	ahci_platform_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x18aa7bbe	ahci_platform_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x256ab755	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x2d3e2253	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x32c0f14b	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x48dfec3a	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x69243eee	ahci_platform_init_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x6f1ba951	ahci_platform_suspend_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xa86711c4	ahci_platform_resume_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xb391f7bc	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xb703737b	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xc0ae417c	ahci_platform_suspend
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xee6d0468	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0xe093c1c5	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/ata/pata_sis 0x059e128f	sis_info133_for_sata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x0e8a11f3	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x394eef8d	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x5b495df6	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xc93fbef5	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x01ed959f	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1050b58a	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x11087d0c	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1fcdfcb1	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x2dd76df0	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x34d28f12	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3699a58f	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x498985c1	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x53f0e634	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6367b25e	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x651d2568	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x82d2e43a	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x834c6628	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x96495203	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x9a37d187	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb05b1472	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb3981547	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xba08efb8	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc6489d88	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd10d29f0	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd2b63be4	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xde311fa8	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe4c27725	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xfb026c58	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x0bf2223c	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x278081a7	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x294ecfb4	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x3ed22256	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xd5f9f9b7	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xec9d38ac	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x025c1413	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x1805c6f6	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x1c6a21f8	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x26b6964a	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x4f6f000a	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x632da96a	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x7ffa7493	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xb5030705	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xdb09e518	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xe4f7e34c	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xf6403ae5	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xfdfc87da	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x06174f74	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x1c6de27e	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x24ff1331	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x3189308a	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x41799ee3	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x51e7053f	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x6a6898bf	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x6cc71a95	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x7d441601	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x9c31874d	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xe94fa286	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x2b68ebff	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x8e1c489f	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0xcd40b805	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0x02747c7f	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x02db292e	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x37a38291	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x771c101e	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xb4cb2a93	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xe0deac92	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/fsldma 0xcc692f34	fsl_dma_external_start
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x3b0cbd95	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0xafbf0853	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0xf5194932	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x8a839cd5	vchan_init
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x8b98800a	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x97753e4b	vchan_find_desc
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xcd8c329d	vchan_tx_submit
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x00997a68	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0492fde7	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x14560c54	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x1c1e0606	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x1c7c4309	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x26334351	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x282cc5c2	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x37b7d195	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x50a7edf6	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7153b27a	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x72d2808e	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x801c8576	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x8821c263	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x8f82ce0b	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa1bed69d	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa3a0555d	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb1abbbdf	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb6ed390b	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc07df43e	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd06f3321	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd88ff29e	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf0b83cf3	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf3b27f35	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x159fe6d6	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x2642b5ec	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x2e18fbe2	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x4d4ca637	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x8e12b2dd	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xe2b540fa	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x11a239c8	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0xddb6ada3	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x7d537722	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0xb6bed1ed	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x22a56677	drm_display_mode_to_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x46d84c71	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x4847576f	drm_display_mode_from_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xa622ebae	of_get_drm_display_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xd166fc42	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xea8d30c3	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x0b9151d3	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x564fe0fa	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xd42906a9	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x06455f82	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0abf521c	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x17b070d9	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2024bd59	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x299b9b42	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x345f691a	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x42e1c51d	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x43cd95d8	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x445195ad	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x493ccd80	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4caa75f4	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x55c59246	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6610a7fe	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6e66a225	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x870126b7	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x88406916	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x97c5a080	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9dc0a0a6	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa0937832	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa09feefc	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa2217256	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa88bb121	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa9beb317	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xac1b68de	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbf57aead	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd1572986	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd264de94	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd26a3a42	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd50b8528	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xdd4a2c08	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe4126e7c	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe67ff05d	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf0786d68	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf07bb92b	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf1c5daea	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfe51cd07	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x6224880a	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x0271b27a	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x18e22595	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x1f071f73	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x37af1d51	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x5a9d72f2	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xcdeda378	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x0b75fa38	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x1ddcb6a9	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x25104224	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x2945ab30	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x6a1287fb	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x9d78c81c	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xa3b91c97	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xf0a02605	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xf68171a6	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0xa8232f1c	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x1759478f	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x21287d4e	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x4deae21b	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x5698f769	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x599809fb	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x5ae69051	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x6368a862	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x6634a2ee	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x694618c0	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa589361f	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xbdaa608a	hsi_add_clients_from_dt
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xbdc77343	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc6f8c842	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc8fab948	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc9b52377	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe2d02ec1	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf410c32e	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf4a4441d	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x045cc5e9	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x29262500	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x80d988e2	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x16c9554a	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x1955a379	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x338d6d52	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x43b9c5bb	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x4a7b3c5a	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x4bc494b9	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x516eea65	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x53f82724	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x59924d37	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x6c46122d	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x7c579fd9	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x8ce271fc	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x97ce3ffd	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xb6a92c95	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf632c0ef	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x2c04b918	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x2d51e37f	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x589ae44f	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x6492a417	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x677e57e6	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x7ddc35d6	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xb06e2779	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x031c619b	stm_source_write
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x0ede74db	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x8c4aa669	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xa7a47b57	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xb29cfafa	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x6e4a7705	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x7d456d75	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xc8ae0624	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xeef5b616	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xf751a95e	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x4dba5275	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xe4f1457e	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x122850a2	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x71b89199	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x12d8728d	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x829accd7	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x8b329884	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x44afcbad	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x4b6a57ee	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x5b6b71f0	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x60e9f974	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x89a82ff2	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x92da9d3c	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xb9e4cb03	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xd18587b6	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xe6ccea82	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xf96aae26	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0xec6a626b	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0xf8565ce0	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xbfea9ad8	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xf0e20569	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x37a5206b	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xbbb704ea	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xe122752f	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x24062768	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x2f1c29f7	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x31855361	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x442c5750	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x48b53344	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x66d2ccd4	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x83e855f8	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x94ec6b95	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xa2c3f058	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xc6d7db7b	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xc9c8cec7	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xf5ae1f3a	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x07d3a54e	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x10c704b2	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x10daae95	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x20c0652c	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x28f2fbde	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x31948040	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x356e0677	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x488ad148	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4a44e5e5	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x594efa1a	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6468fb38	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x66d66a0b	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6bafceb8	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6f4ddc15	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7ae78b50	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x8087ead7	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x89eb4fd7	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x902b1834	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9c245c5e	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb14c6066	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb309d8cb	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb476bc53	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xbeba73e3	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc0602ce7	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc65523ed	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc66df099	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xccaf5e52	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xdf808eb8	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe9fd4e31	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf986be37	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xfca16bc3	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0xeb019716	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/matrix-keymap 0x1131f8de	matrix_keypad_parse_of_params
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x8089e8c8	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x19aa4407	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x811bc851	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x8bab7ac6	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x27db46ca	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x56f34e86	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x88c18135	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0xab226ffc	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0xb00079a8	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x8c19d3df	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xb1cc99ef	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xe302a677	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xeb623406	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x1b229af5	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x4a3c6c9d	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x5323f71f	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x6457ec9e	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x669476fc	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x670e60d4	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x72d3cc42	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x73cd1441	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xa3c7d186	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xac1b93d9	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xbe79ccdc	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xdf6f1e5f	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x405e4c08	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x6587839f	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x76987395	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x7aff9733	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xb8f1b68a	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xd947f8fe	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xdae28df6	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xdd2e04ab	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xdd79beed	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x1eba2674	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x3d1e88b6	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x4901a0fc	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x599e864e	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x5c363175	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x5f95bacc	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x6a814b03	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x75713548	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7891920f	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7f7b0911	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8eff32df	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x903c5413	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xaa697db7	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xca1fc929	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xdb9b4e69	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xdd4fe8f1	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xe8ee4cde	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xf7c30910	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x44973931	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x890c531b	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x89ea926b	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xa1988d66	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xb413df96	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xd230e1b6	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x18344118	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x2f0bec11	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x922d2cca	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x9310df75	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xcebd3df6	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xd106fe39	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xd26b2c7f	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xd3258f4f	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xd4f910b9	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xdfb485ee	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xebd9b8cd	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x0a0527be	wf_register_client
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x1ae14082	wf_register_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x2fe4d182	wf_unregister_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x62648173	wf_unregister_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x75147afa	wf_set_overtemp
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x9ef3cf2b	wf_register_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xac9a0061	wf_get_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xb07002f8	wf_get_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xbcace2a5	wf_unregister_client
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xc15e9b55	wf_put_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xe05b96ca	wf_put_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xed82a14f	wf_clear_overtemp
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x0d576184	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x2f5f1a4b	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x327e5efe	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x5607f670	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x5a3134ca	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x5d170d11	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x654bb79a	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8bde951f	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8bf52ac0	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8f9e7476	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x98a363f3	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc454384b	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xda846bb0	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xf7f7439b	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x00b74659	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2a1a7a99	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x374f45ea	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3a4dfef7	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x48991e9c	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4f124797	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x614e860f	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x647af374	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6724de29	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6726a0c1	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x68f1ea6d	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7114cfcc	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x78c57fa5	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7cb4bd6f	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x816ebfe0	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x833b99dd	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8afe3e2b	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x912566ef	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x92c55e92	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x9c59320b	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa7004101	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xaf2376ac	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb3942afe	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb4cffcbb	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb9c28744	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc0bd3171	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc773563c	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd81ad8c9	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe30b6b2a	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf6169c53	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfcb52b5f	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x142c42df	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x145fe456	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x5afcdef2	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x5e78c960	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xaf25b5fa	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xba928dfe	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xcca22941	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xe0bd6323	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xf18f0a96	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x22163b69	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x3909d3a8	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x594952bd	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x62a23587	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9b2b253a	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xba38d2b8	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xdc69e37a	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe004ee92	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x1e5dd7ef	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x2bcf4c3b	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x588ed5a7	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x7b81343d	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x87ce0a6e	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xa0f0e0d7	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xfc4d4576	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0xe2d27ac4	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0xfb143e02	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x09472122	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x483d8a23	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x8f9f1064	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa8813ad6	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc66ce277	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xcab63c3d	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd0d56c48	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xe181bbf0	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xee13d997	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf37a3cfe	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf9297f24	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x11eab9fe	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x150c85ce	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2e730a21	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x33c03da6	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x619701dc	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x64cf3915	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9b4b5b29	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa2507774	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbcfdc290	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbe0497aa	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xead1e727	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x1d84d5e9	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x222f2980	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x4034fcb7	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x60256533	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x7cacc716	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x99260d98	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xa8a493fb	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xb45cffb4	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xc5373306	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xebb1172f	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x1128f613	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x474d0355	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x9f3d8f64	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xd0b243e6	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xdf5599cc	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xfbb9dc84	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xfc032bdb	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x0caab5b2	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x115bdfe3	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x1a2b55ec	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x296a82bf	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x4da62b3c	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x55bf7ee1	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x63222b29	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x70bee719	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x8fe6db54	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x92877bf6	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9cc714fe	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9f8f1f84	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xa99de691	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xb1300ee7	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xb4c01c8b	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc7c0862b	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc96b021b	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xcd12875f	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0xabbe9b9a	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0x28e1691f	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0x875560cb	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x2b3d92fd	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x2f602dc9	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/media 0x387affe4	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x3c5505dd	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x40bf1ac8	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x57670bca	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0x595f9a92	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x5a003332	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/media 0x5f5adbb9	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/media 0x6a3abeed	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x90aa4aec	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0x9f6c39b5	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0xbd00c624	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0xd6300b53	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0xdd892de6	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/media 0xe9e6832f	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0xeba05ae5	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0xfdd557fc	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0x72086858	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x04563e90	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x1582740d	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x1639b7e0	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x26a8f61a	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x3d4b2f1e	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x4566123f	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x7231b6c7	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x7540423e	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x833e5cbd	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x84a7553d	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x86cf86dd	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x913bf4fd	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xa53d183d	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xababe7a6	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb0758ea3	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb156a548	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xdfe479b6	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xe48d9e77	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf6883637	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x04e818a3	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0f1d312b	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0f557565	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x13a26138	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x13f5032f	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x4d5e78c3	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x55d48a1d	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x5d79691a	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x5e99ae5c	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x5ecde4b5	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x98e486d8	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x9e09fc6c	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xb00bba63	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xbfe2d6e8	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc3882deb	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xdc46916d	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe4f57586	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xf702135c	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xfd3c0b15	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x16a468ab	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x3ce9546b	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x4b409e98	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x65afb518	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x9395d2c8	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x9a065a73	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xb47341e6	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x077f2690	xvip_cleanup_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x0b2585ce	xvip_get_format_by_fourcc
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x2f2a9d1e	xvip_enum_mbus_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x3c7eb685	xvip_set_format_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x490bd11c	xvip_get_format_by_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x66614503	xvip_clr_or_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x7ecd5e27	xvip_enum_frame_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xc04e800e	xvip_init_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xc54d06e3	xvip_of_get_format
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xe5ea36d5	xvip_clr_and_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x3c16a6b1	xvtc_generator_stop
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x47d7900b	xvtc_generator_start
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x9ed14ef3	xvtc_of_get
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0xa8a0f912	xvtc_put
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0xc4b8d346	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0xf6aa5f87	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x03dc6149	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x1b3fb198	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x21c404a7	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x24d724cb	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x31566014	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x656ec094	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x66f76949	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x73f46178	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x808b60d7	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9aaf9bf0	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa7d41b04	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa8c3d59a	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb075791d	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb08f60ff	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc60e2e9e	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xeea7649f	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xf4a84a33	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xf6ecd870	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xf8cebbd4	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0x536633b0	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0x231f14bc	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0x3f52f876	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0x94a836b3	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0x84570c3d	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x0fa9255b	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x1659dd1f	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x41e86378	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x5c112429	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x452651eb	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x6906db69	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x61968f48	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xaca8fbb5	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0xbe257757	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x0133b936	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x265e0bce	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x34921993	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x43e07639	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x43f3d913	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x45cd42c3	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x4b69ac17	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x5e15844a	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x65e5b366	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6dab1bc9	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6e0d4f8f	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6fd87adb	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x702c6713	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x7425e82f	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa1e5291a	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa21caa9c	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xc722202d	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xcc86cf32	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd8d7a994	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xee855773	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0x9aa96b30	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x72b65575	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2b7e7ff1	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2b849650	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x32edb6db	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x39429383	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x5bc4cc5c	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x67aba3c8	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7d4dc80b	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x80866ae0	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x8916d64b	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x8c7cb408	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xa7da8393	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xaa78868b	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xaff30e18	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xb119520a	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xc620848f	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xd0b38e2c	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xe834fad0	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xf4521311	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x6d13485e	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x7e257b28	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xef112cff	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xfb701000	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x4399d288	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x617b7adc	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x929022d3	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x967e9b94	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xae04a682	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xd4df2f65	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x56764774	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x689897b6	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x0766e2a6	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x094a910d	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1a23dbe2	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x239c227b	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x424687c8	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x4677aa39	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x5883f5cf	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x5e58e9f9	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x66ae55b0	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x789b92da	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7fa9f4b1	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x824f8bdc	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x89fbf9b2	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xaa6ca779	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xab1c417e	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xae4b17c2	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc3508b9c	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc3bcdb31	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xcb10ae10	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xcf9987c5	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xdb2a7e1d	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe22f8a1e	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe58e1784	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xeacc6c88	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf556370d	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xfd038916	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xfebf64a0	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x0800893d	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x0e203deb	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x17f934bb	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x297606f2	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x357ebc51	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x36c91e78	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3cf96db0	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4b9548bd	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x5a53c10d	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x763af9b3	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x7dd9b351	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x81ae0647	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x825171bf	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x94b2d114	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x9887059e	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x9f953072	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb04ea508	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb346f89f	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xcf2f0313	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xd87ac0e8	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xdd4a2b02	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xdfa14f2c	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf55eb332	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfbfe0c76	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x41f5da45	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x517002dc	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x60f475b2	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x990a1ac3	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xa825c75b	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x4d2ba47f	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xbd430bbc	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xeb4692d0	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0b964274	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0e22bc1a	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x5715c915	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x5a5cd539	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x5a776f57	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x6689d156	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7cc6e045	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8c2e7f59	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xa80ebf0a	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xaa44ad4e	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xb6799aa0	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xb746a44f	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xbbf51205	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xc713dd23	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xc7ba4fc3	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd31cb244	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe7427a4c	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xebc579a6	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x4203cb99	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x5284500e	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x5757ecdd	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x97bd890b	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x401292ec	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0af3abee	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0fcdd89c	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3ccce7ff	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3de82d03	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x419f851a	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x4892e221	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x59d928fa	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5c6b039c	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5f7cd03e	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x6f1583ca	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x734b15ae	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x7bfdbb12	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8e54fd3b	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8f5240af	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x96efc0f5	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x9b2e232a	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x9ce8a968	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa801ad59	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xaa5a05b8	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xad10179c	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb009700a	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb3e8990b	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc13b606b	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc540c725	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc7387abf	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xe4604aae	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xead3bfa0	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xed10dda5	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xef582e39	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf13ab003	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf2f46af6	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf317d808	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x81e883b8	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x06528557	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x085c1c98	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x09327362	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0b334efc	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x10e15370	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1f0f9337	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x204fc107	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x21fe7c3d	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2270a83b	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x28d20b15	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2de98f93	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x31e3d76e	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3740e82b	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3bebd4cc	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3f3fda0b	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x470e584a	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x54a65c2d	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x59ad0d19	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5ce3ebae	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5eaaf421	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x69759b8d	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7088a3c6	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7a85f5d7	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8fa601e9	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x98545b10	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x99c81392	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9e7b7cc3	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa147ccc0	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa4b1adc1	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa703f460	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xcdecbbd3	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd053b1f2	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd393d82a	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf2ac17a3	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf5956f8c	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xfbec46c7	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x51a855a7	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x6cedba4c	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xff6b343e	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x56ad597c	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x68129d97	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x7c77dfa7	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x7d3d7f59	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xa73c6138	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xc8f7dd59	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xf5dc719d	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x43d80ccb	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x64fa9e90	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x656cb14a	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x6b7032c5	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x74a83734	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xe745d02c	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xe8bb4400	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xf7d09848	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x2a60f825	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x51fb2cf5	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xbfd55546	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x1120fefc	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x1838d9fa	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x39a8958d	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x4ce16318	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x66c194ff	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x95e51ffa	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xecb05f7c	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x262cfe08	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x38dd3420	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xad6ef7b2	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x0ebd8f40	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x1aa3b95b	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x1cb27a28	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x5c083108	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x856b580b	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xed06eb13	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x020eb8c5	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x0c204c90	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x10bd27de	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x309ad1f7	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x423fbdaf	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x67bdd7dc	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x8cd9b71b	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x9e24e833	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xdce5dde1	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xdf3570c4	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xfb00b43c	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x5c391efd	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xfacad014	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x6218f06a	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xc45b3151	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xc5c9d44d	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xd6c9a000	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xee426ab8	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x057ea128	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x189f5067	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x25c55b85	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x283f7f9e	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x2a9008cd	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3becee6b	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3e1184cb	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x47af0a04	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x521c4721	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x70b1f07f	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x778cdd5d	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x8c4fcdd4	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x99663122	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa6144b06	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa6843424	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xaba436e0	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xc076f5ce	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xcb8a518b	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd105b74c	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd4dc48d9	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xdd169e19	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xdde02d91	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe4e51a37	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf0ba6462	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x374b11e6	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x3b2266df	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x3d7f1815	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x4593cdd5	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x483e2fc6	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x65cecdcb	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x782f70f3	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x9bf9ccd7	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x9dc9a99d	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x9f92b562	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xa4fe4d20	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xdf7b2c7f	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xf284d99a	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0b582458	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0e423895	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0e489deb	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x10af0c18	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x129857ee	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x170ab5f5	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x27afa883	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x317014f3	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3c78fe7a	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x43f6f5b6	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4b0d2126	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4fe50d5a	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x65d0392d	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x673fea55	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6de27bc6	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x72090a44	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x72ee5f65	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x736e151e	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7d21d7a6	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x866172e2	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x890cdd75	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x97d4d1f3	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x984e152f	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9b019563	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa447c6b6	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xacb7bf3c	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb074634e	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbc637470	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc65bbe4a	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc7291c71	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc883a31f	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd415de45	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd447b89b	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfaadf93c	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x76c05add	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x79e8cebf	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xb349ff43	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xd017e37c	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xd3cc8318	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x330337b0	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x44dcd9c1	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x848348c3	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x9f8f1929	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x28d6b3bb	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x62b37b75	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x932430c0	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xecd2a5ad	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0x380b4c55	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x2a8280e4	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x37f43154	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x587fea8e	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xf4e0da1f	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x1f691df3	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x3bca1b35	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x477cbf8f	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x5463d83f	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x02ddc520	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x06aa2388	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x07129e99	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x4026513d	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x90f4fe65	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xc08d8bc0	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xcd5e1d09	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xe500b238	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x237de41f	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x5aaac756	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x68aad82e	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x6b7edf7f	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x767d5ff0	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x79f57dcd	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xa7721d25	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xae694c40	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x81df6421	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xcd6e377b	st_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x096ba1f6	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x0b79b686	sdhci_set_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x0e6cf774	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x2df8e15b	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x32007047	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x4263d86f	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x4dec85b8	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x525d14c2	sdhci_reset
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x84f3db53	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x9662d2ee	sdhci_send_command
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xd7ad5bbd	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xdb008598	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe0b43c3b	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xf8d44497	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x11916590	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x17baadd8	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x2a44db19	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x6e92d020	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x816a6522	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x8277ec2d	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xa21a7d53	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xe4632580	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xff0e30a4	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x1e50f534	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x2179d0dc	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xdc67f54a	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x3eed4228	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x40bf09f8	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xcd148dae	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0xaf2a24af	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x13de4230	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x7264dfe6	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xf488763b	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x04870b17	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x07405fc2	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0cb9253f	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0dcced53	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0f4d2711	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1795a484	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x22dc51f9	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x28e77f72	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2d934f60	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x33273b5f	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3cca20ea	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x48371205	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x49403654	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x50132e8b	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x632ab8b0	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x678fc6f4	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x71bdd5cb	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x71eac4e4	mtd_block_isreserved
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x814fa690	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x830ef00d	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8417dd05	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x85479d5b	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x868aee35	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8704e9b5	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x87c7f5fd	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x93f5b3b7	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9dc12222	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9f674625	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa12102df	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa7ecd083	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb5ae549d	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb8cc5e95	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc0cf9ebd	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc4911f01	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc9911d2e	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd63f2550	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xdb021cf9	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xea8d36e6	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xef91a6f4	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf1d58b51	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf23c175e	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfbef171a	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x14171069	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x7a0e7f30	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x926737ff	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xd5f6e081	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xddb41573	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x5673a22d	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x7e288ef8	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0x496ac90f	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x5560a510	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x6c88f407	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0xee188e22	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x07ee78bb	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x19f3a5e4	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x1c7def1d	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38a910c7	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5fec3681	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x65726ec7	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x6a0e260d	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8c4fcccf	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xaf542d8c	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xdcd88ced	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe7e5c462	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf0d20cea	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xfc20856f	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xffd68889	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x1e4245ab	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x5a56ae3f	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x069734c0	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x1ece70b6	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x33ac66a2	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xaf331019	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xcade5705	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xd0bd2bbe	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x012c80b1	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x052cae1f	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x08a5c760	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x121ee5b9	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x2cf07223	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x383dace4	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x413103e8	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x48c20b1b	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x4962879d	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x8318cf4e	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x83ca612f	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x9f801363	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xa180764b	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xafde8da3	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc6215cfe	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xcc98dade	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xccb368bc	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xef426fed	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x666b7f28	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x84b8e310	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x987ea1fe	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xcca4ea9e	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x42cfd5e1	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x7f1722bb	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xc91e41e4	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xfbe485de	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0x7c3ea3be	arc_emac_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0xc22266cf	arc_emac_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0582cbcc	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x05f22229	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x09562a16	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0daa8d8d	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1062c536	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1163443a	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x14b44d2c	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1c4ad88f	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1d28afca	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1ebb5adc	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1f105127	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x204c74bc	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x22f00d39	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x23b91323	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x248a2b20	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2752f958	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x277334b7	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x294b99c5	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2f7d6a0c	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x33ff8a57	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x34535802	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x356b7f27	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x35dbc8c8	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x36b623e3	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x373b2713	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x39c34c02	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x39fcaccf	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3b61b6c9	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4225e82f	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x435a3585	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x44ecbedf	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x45706089	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x46c5542e	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4e0ed115	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4e61be69	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4ea8c5f8	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x501ea1cd	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x521feade	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x524d077b	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x559e6454	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x55a83ec6	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x56373144	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x59e45bfd	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5b68045d	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5cfb7a61	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5efc6bcf	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5fd4d439	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x64958cb6	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x66ba6455	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x68c59ca7	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x690ad233	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x690ced14	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6c0a2572	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x72496f6e	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x73341abc	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x74e8423e	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x74fc62fe	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7616af88	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x762e3521	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7761a620	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7778ca80	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x78f409b9	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7a9033ed	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7b26658b	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7c42eddc	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x800768fc	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x80756213	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x817a5242	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x81fecd46	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x83cb7e45	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x85b95423	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x85ee7aa5	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x879be47b	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8cd18f4d	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8d9ed501	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8e8a2709	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8f5213b3	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8fcea6d6	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x90d63669	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x92c33f2a	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x94777b4a	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x961c5d31	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9721cb02	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x97f38ab2	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9a06b9f3	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9c1fd608	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa2c1775e	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa885b722	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xab8abc9f	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xadb4750f	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaeaa736c	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb0f86b10	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb16870f5	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb39c1eca	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb81661c0	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb8ad1e33	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbd2e8797	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc180a0a9	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc1ab18ca	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc92b770f	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xce5628a1	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd97dceea	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xda4f1ad7	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xda8eff21	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdaaf57b0	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe023c8fe	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe0ae25e0	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe48bec58	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe4d928b4	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe66790e7	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe870ca05	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xebb90a83	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xed74558a	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xee3d1ccc	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xee554df9	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xeec633c8	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xef2ea8d0	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf1e3b69c	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf81e296b	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf960b040	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfa974549	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfb2e5287	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfb92f37c	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfe81ebff	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x04f8ae5f	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09470cf7	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09543b3d	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0f4584d7	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x146d63ec	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1b10d3a3	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x21d3d93e	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2e03ab99	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2fb26813	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x313eaef5	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x32ca8c3b	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x347c092d	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3719a34d	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x400a44d1	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4bb97909	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4f11cb0c	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x52df1c00	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x531f66ae	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x578a69a2	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5b4cefa3	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5cc869aa	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x60dc781e	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x70374087	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x71f8259c	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x866c3649	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x90441d51	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x960c06cd	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9cd86b76	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa1f3b0e2	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa4307024	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xabb12a60	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xae1e37d8	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb287aea8	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc2cdeeb6	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xca337bca	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcd46686b	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcdd4ad38	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xce0958db	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcea16066	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd9543ff6	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xeef86adb	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf15ee7ee	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf2dbf76d	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf3210ee7	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xff0c226c	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xff60ff5e	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x368d3d71	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x781dac19	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xd4ab3625	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x08eae3b0	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x43c1f81f	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xc25ce98c	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xe25b9a00	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x06707735	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x0d7f6c5d	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x4d2d780a	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x97470db5	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x1f7e0c5b	cpsw_ale_add_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x3d49cd29	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x4ddf84e4	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x5536a481	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x729fa987	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x73d13c6f	cpsw_ale_dump
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x8583e6b6	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x934f9d58	cpsw_ale_start
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xb29cef96	cpsw_ale_stop
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xc771a5d4	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xf1713ef6	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xf247665b	cpsw_ale_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xf5d977ca	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xf97bc001	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xfe9d61ec	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x2e19b0ee	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x4d34543d	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x03b20478	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x3fbbd1e0	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x5dd86c74	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xae0ed7d2	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0x790165a7	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x18fd204a	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x23823556	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x8284e026	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x883c6599	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x8c8eb600	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xb0695ffe	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xc859894c	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xe71aa320	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xf341049a	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xfe88274f	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x6318757f	mdio_mux_uninit
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0xb76848d4	mdio_mux_init
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x086f3adc	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x08ac2808	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xb951335d	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xff0a726f	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x1ca1870c	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x5b281b5c	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x6ae409c3	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x73552647	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x93c2076a	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x9528e739	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xbdd9a39e	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xd00e9214	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xf0875f93	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x2c8c8716	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x44572b74	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x6de6788f	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x7a4cafe9	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x99151cbc	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xee31e614	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x04f806bf	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x09249a57	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x09903d24	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x10ac5bf5	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1b8d6ab3	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1f73bdcd	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x286ca3bb	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x34579993	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x35fbb92f	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x36f332a9	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4356b0fd	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x46d924ee	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4dfd8c05	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4f79e53b	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x52c04ab0	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x59ff84c3	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6604cb82	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8749f6c8	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8a3fa324	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa10f2652	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb3d2c160	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc714de23	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc924bb11	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xccb78cb6	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xdac21842	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xdd287d7e	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe05c6eee	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe9f35011	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf060e212	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf8bdd753	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xfab421f5	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xfb2c77e7	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x6e6f77ea	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x99fe7cfa	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x17ccfb7a	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x27100e23	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x31256b19	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x4e7d09ff	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x603fffd7	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x734c8308	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x8a4054cf	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa25d19ef	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xbfd36e26	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xc6cc924a	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xcb3b11e3	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xce46a3b9	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xda946768	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xdcc0f87b	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xe7bff0f3	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf6148a7a	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x0c5f449c	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x1458aa87	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x60edb78f	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xc0d00765	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0x2cecaf3b	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x038071ec	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x1ce8bba1	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x862d665e	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x8b5489b3	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xe3fc0611	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x002b2e74	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x024b7546	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0373b9e5	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x05d3b03e	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0b408857	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0d556623	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0f48dcb7	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x26b0f984	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x2cd8c8a5	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x4a49e71e	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x63e57df6	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x646d67ad	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x714455b1	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7f0a69b7	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x943a5e69	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9ad6ff3d	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa3023b80	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa6d9b435	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa89b5773	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb4eaf65e	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb95bac2a	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc67c31ed	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xcb9de23d	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe0d3442b	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe39a7091	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe8020fd6	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xea0a4040	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xeab643c9	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf3476c46	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf3eb8f48	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf5aea4a7	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x1b338e73	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x2bc46f61	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x390315f3	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x4500e0f7	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x4dd11627	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x50939287	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x6d26b18d	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x97e97a03	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x9f98ed31	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xabddc56d	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xb6a2b3f9	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd5c972cb	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd97f852b	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf42edde8	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xfa87056a	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xfeeb5aff	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x22a59682	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x4327d768	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x60e0d226	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x7472f3be	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x86e40942	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xa8f0c8ab	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xd890a2d3	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xfb66c092	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x037b44b3	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x0f622e28	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x1940518b	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2a62ac98	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x47a32402	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x49865ad2	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x5090e5f0	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x61386494	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x88d0b7fd	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xac7285d0	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb0cb2d86	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb6cb37f2	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb831c5cc	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb96b3417	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xbb240d7e	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc964dcd4	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf20eca4a	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf2289a6c	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf81b6cd9	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x1323f23d	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x155683bc	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x589c9eba	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x6a23f9c8	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x8db2c4cb	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xa04b0de3	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xa81f7481	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xda2d9425	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xf939a350	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x41710b24	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5d59bcec	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x72d127fa	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7e927c84	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x006639cb	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x106e6882	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x16900a49	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x2687bafe	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x27b2db91	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x29f5f4af	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x2a08f0c1	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x2caf8a9c	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x4569a133	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x45c5f9e8	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x496031f7	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x4cfbcce4	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x4ecf16db	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x5034f661	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x55660a56	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x632eebb6	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x94685e7a	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa54e9c7a	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xb0cb967b	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xb8a9a57c	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xba6fc9a5	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xbfddd9cc	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xca0ddffb	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd141c2c2	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd5da9858	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf428c863	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xfc86b83d	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0d0b6636	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2fb13f86	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x407fed30	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x59a9a169	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x696c43d3	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x69f8cd84	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79f67c83	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x7a2c1471	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x83f26611	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x98455fd5	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xac646ade	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xaf38a60e	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xaf81ca2e	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbf4b16e6	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd89b1dab	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdaf02f14	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdc2f367d	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe2092c8b	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xeaa58b04	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf62b0467	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf8ff6add	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x084a341d	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x45a644f8	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xf5816d7e	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xfbdd4989	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x01b67069	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0a915b25	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0de9988a	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x10428060	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x167ad083	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x17a670e7	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1fa1c064	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x27b8cc3f	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x2d4cd5f1	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3082edfa	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4f498c3a	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x50bf9315	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5c77640e	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x63523082	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6497bc2e	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6737dd21	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6ba72290	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6c3993e0	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x789bb4a2	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x82b457ad	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x85d07ab4	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8f433aa6	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x90147cc6	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa3a211ea	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xaaa40826	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcae18362	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcaf0b2ea	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcd356a96	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcfbd1759	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd2656c3b	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd7bf80bc	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xdde1f321	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe0333bab	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe8f424c4	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xeb4f812d	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf39ab512	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf5ccd60b	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xfa2bccc8	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2f0e1bc5	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x37221e56	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x38da1cd8	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x402eef27	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x4aa60560	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5ab7243a	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5c2c0083	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x7079c1dd	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x720140a4	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xb45b1579	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xbd772405	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xd3f39061	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xdc303cea	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0323191e	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0927da93	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x18f55c7a	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x19f8ea52	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2132e720	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x21e366da	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x254c9d7c	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x30ce8fb4	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3e1680f8	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3e4614d6	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3f96f2c6	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x46c03286	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5704c99e	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6b91cec7	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6ffd92dc	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x79c9e2ff	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x853e1c67	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8650c1e7	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x99524ffd	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9b389ba5	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9cc63674	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa3d7e91d	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa494b88b	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xabb4acac	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb1898870	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb33ae811	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb4c669e1	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb8f94d16	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbb04ec6f	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbbd8aa40	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbc053114	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc0d4fb60	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc2ebb138	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xcc0913a7	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd40ccbbe	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd661792d	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd94b959c	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd96c47cc	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdd7b3027	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdd92b685	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xea25c06a	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xec2c5a74	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf0fa47c6	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf39bffc5	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf6a04921	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfef461c2	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x1f694d5d	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x66e82e61	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xa056e1c5	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xc2f3ce0b	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xcf9f3e89	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x0d8b1f34	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x297501b5	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x456861b2	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xd45404cb	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1cccfa22	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1f0d389c	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x23a19efa	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x29561230	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x4c25462f	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6c225ba9	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6ed27ffb	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x894f2f1c	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xa050cf46	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xa6d8bea7	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xb51a3e20	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xd953f980	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe47451ed	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe82f821e	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xedcba76a	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xf690f387	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x6249739f	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x8d09606d	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xf55aebc9	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0336cb54	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x10f7282d	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x151bad6d	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x17aacd69	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1a671320	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1ccd0dae	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1fba2acb	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x21898cfd	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2e1696f1	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x32c6bdab	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3e2bb3b1	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3efa56f5	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4ab293e9	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5f076fa8	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6842c654	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x78177ede	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8709ff0e	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8addf082	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8b5057bd	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8bd4dd71	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x90f13e48	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x913f0004	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x91da5146	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9641f79b	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9d8567f0	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9e39c274	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa1439652	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa4f06200	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa5087c08	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa7580da4	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa7e3d71f	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb71f2a80	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbb452ad7	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc140a4e6	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc753cbea	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xdbb2a4be	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xdef68a7b	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe3cd4aac	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xec791504	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xee58f2c4	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf097ceef	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf11ba0e5	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf9fa3bbf	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfe838a25	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xff268a2c	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x1d38775c	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x47237c79	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x7dff7680	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x8518eab1	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x02d1e31a	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x08b76a0f	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x10f84d28	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x20b43c08	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x329e43de	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x572d0323	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xde3ff857	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xe614476f	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x25b0f905	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9d9b1247	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xadd590dc	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x1ddd2864	of_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x36ec8a8a	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x68758fda	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x69a325fb	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x87a76839	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xb60e8a00	of_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xb881ff8c	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xb9a154de	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc96fb674	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xdfb0dd6e	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe18960ba	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe9a7fe16	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xf0df09af	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x5995f5da	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x5afbcd10	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x92835acc	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x134dc6ef	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x5b475ec5	mc13xxx_parse_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x9508a78a	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xb31f5082	mc13xxx_get_num_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xba4d6f04	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x14f0771d	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x3aefa8be	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x93c9c1a9	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xe49f9467	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xf32f0481	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xf6c15bc0	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0xecec5d23	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0f3ddb3e	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x10a0d077	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x19319177	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1e4b34a7	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x23d4dc32	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x25a14310	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2623109b	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2836ec66	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x29dfc3cc	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2c4f3253	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2ced431f	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2cedd985	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x46096e3d	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x47f5d4b2	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4d6b2cc0	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4e6445b6	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4ef59f97	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x532c9e31	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5eda29fb	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5efa205d	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6220f74f	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6940b19e	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6a51c2e3	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7cbacaf1	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8131637b	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x95363cb4	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x95a27ff3	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x968530a1	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x98a92af4	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa20b31fe	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xaf90f3b7	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb66df905	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb67d85ce	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbc6d9229	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xce9fd696	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdc9b0e29	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdd224948	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdf973b69	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe498678a	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe593328d	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe6ffce3c	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe7e02536	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xebbcf090	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef261dc6	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfd0ba2ce	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xffce0389	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x02613367	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0aa43f87	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x1436b909	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x1d54409b	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x387a23f3	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x46311f84	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x4ae2e230	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x4c27113d	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x519c8883	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x70607663	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x8bb81a50	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x93dbb486	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa3cbc03a	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa57b5d1d	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb4318755	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf4ffa562	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x1471aece	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x7cc5d50d	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x849be4f8	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xc628c43a	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xf9687525	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xfa817321	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0679c590	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0ed9e9b4	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1fd9443d	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1fec9039	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2750692a	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x295f73d6	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2bab5b47	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x37b21b08	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x38a4cccb	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3b2f63c8	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3d0fe4cb	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3e9283f5	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x446aaa22	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x471da3dc	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4758b88f	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4c737307	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x54fffed0	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5931e1da	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5ed6190c	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x61fce400	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x631d5460	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x647957ac	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x664f6687	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7289cbc0	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7fa1ec7a	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8700a030	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x90b82813	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa5da00a3	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa7034fa0	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xac7cb892	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xaffb4cc6	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb0b1a022	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb39a511c	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbd2f7a70	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbd605715	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbe2eb389	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc2bd8e08	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xcd84ea76	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xdcc8acb7	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf0e61944	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf7e73ad2	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf7fdbb00	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x00a91ead	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x0ee75ec9	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2017f4de	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2dc6bc96	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x38c3d791	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4070f158	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x61f9abec	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x63c258e4	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x7094bf7e	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x9e59a72c	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x9f550380	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x9fcf88ac	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xd455d1d4	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe74dcf8e	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xeedf4d47	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xf70bddd3	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xf8fa8bcf	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x0da2c8bf	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x12ed0c93	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x130c7fcd	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x28721698	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2b755a50	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3bcdaebe	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5338ee82	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5487b687	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5f5b029f	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6400022a	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x695d0443	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7f4d7602	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x850d3edc	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x855efa0e	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8cee19c3	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x98e7e942	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9e809648	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xadf8c8e6	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb37df43b	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xbee9fcea	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xc6833fc2	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xca4527ef	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf596b2ba	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf7cb84de	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x000df035	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x04c94998	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0eb6a865	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x16dc030a	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1821d89a	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2f83804a	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x403d10b4	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4bc227b1	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x58526191	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5906af54	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5cda8c70	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5d021214	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x632e2aed	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6d9986c2	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6e18b544	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x76af442c	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7d6ad42c	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x837f3959	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x85431a87	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x861e6407	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8ac9ad41	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9cdb0a48	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa2d591a8	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa68a896d	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb4d9755b	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb5bcff02	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb883e708	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb9b945ee	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc505a1ac	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc7023995	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc8526fe1	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd1ccb3ab	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd1cff1d3	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd4b5f928	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd70dd5b7	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe336dba3	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe89c9b36	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xeb5a41c8	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf3be7e5c	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfde00c3a	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x2ce994b1	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x6a0baf56	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x745d0818	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x913aa2a4	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xd72ce549	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x223daddc	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x4ebcacf5	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x6c23751e	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xc9384bac	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xccaf5177	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xe111bc73	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x79ccfc3d	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x7ffa59d2	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xadc7d125	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xc9329423	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xcec9618b	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xde515b22	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xfc54e3c7	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x282e59c4	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x2946625a	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x2a50a32d	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x3133cf8f	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x922fed18	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xbb453cb0	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xebad586d	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x05c04642	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x465367d0	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x8b0281e5	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xc05f7fa7	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xe896f848	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x17fbfb18	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x26962f7b	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x685d9915	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x911906d0	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x01f54e23	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x03aad380	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x0753b9e5	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x18729750	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1c6c1dd8	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x2e3e4b81	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x372ec276	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x39f5528d	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x409b0d4e	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x51f98d2a	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x52f14d0d	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x724db43c	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xa7050189	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xb8003200	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xb801b76c	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xb908fee5	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xdb5d6b10	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xf61a7e5f	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0x0a69add6	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x05c7e779	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0bd980b9	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0ec65a88	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1c23c021	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x211f1d17	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x24962b0e	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x25945953	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x26a30974	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2880799b	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2efe0453	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x30cf2a2d	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x362b9f6e	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x380ce450	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3a8f7467	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4f6addb6	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6968f090	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6b10f6af	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x7d538a4e	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x86a5ffc4	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8bce8de9	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8ed391cf	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9086ecc0	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9d66eff6	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xaa43cf20	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xade3ee50	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xae2438cb	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xaf813727	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb80e8228	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbbe5cb38	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcd748bbd	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xceb10230	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd95be702	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdae2ebff	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe47b2256	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf01c29d2	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x21b484e3	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x3cbb9f6b	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x550fd24e	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x5d7c1587	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x64fd1ecb	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x662c736e	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x6cfc2679	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x811d0f7b	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x0a3a9dd5	comedi_pcmcia_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x436102f1	comedi_pcmcia_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x6a4860f6	comedi_pcmcia_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x7131b0ae	comedi_pcmcia_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x8b9e7295	comedi_pcmcia_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x92104097	comedi_to_pcmcia_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xd1fbaae5	comedi_pcmcia_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x1f0a6727	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x4f5e056f	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x9925c2fc	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xa13e5617	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xc4968128	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xf08dfa20	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0xf53b777f	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x81f737a7	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0xc61376e3	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0x701ccb2d	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x194f658e	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x1a771494	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x39ac0bd1	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x4129c962	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x53ddc8fe	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x760145c0	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x7b40748c	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb4bb59c1	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb8061fbb	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xe97527c6	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xf4946dff	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xfc178b16	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xfde91d58	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x613732e4	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x8cb596bd	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xa21186a8	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x0d68fcd9	comedi_isadma_poll
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x12fba874	comedi_isadma_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x4a17474e	comedi_isadma_disable_on_sample
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x60bf2e52	comedi_isadma_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x6815a033	comedi_isadma_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa3d01a85	comedi_isadma_program
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa7ebb8a3	comedi_isadma_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0xd32ac077	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x059030ab	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x0a06b85a	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x112e6530	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x1ed1592d	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x2d9863d6	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x314e1bc5	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x332ec3a4	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x362aabb5	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x38854c9f	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x3a6b47a3	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x421977f0	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x443ccbef	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5477e67e	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x55e67ea8	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5e4bd7ba	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x73b44d33	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x804ccef6	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x86d96e4b	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x8b6d345f	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc2abf253	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc7afc176	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x701c8b01	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0xf30e3316	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x2021acf9	labpc_handle_dma_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x35dde522	labpc_drain_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xab18a4d2	labpc_setup_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xbc53ea20	labpc_free_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xfa368428	labpc_init_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x029a013d	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x4a5fd8ea	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x5292c6a6	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x8ce3371b	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xa37c79b2	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xb4e30373	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xc8e77181	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xe627389f	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x3186569c	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x7db89f9f	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x9bc312ad	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xb922a0d7	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xbae2b674	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xe0f50d9d	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x0b59e2d5	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x18def6b5	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x1d65c62d	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x39ceb3e6	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x3e39e297	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x6629fc28	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x84cf6376	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0x3e892285	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x163249d1	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x1a55ed42	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x3b5f1ac4	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x428970ca	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x5408b74a	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x85b450f1	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x8fdfe65c	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x93665835	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xac642dc8	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xb0ad2b24	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xb49f1242	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xe0e520df	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0ef1d765	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x1648fb64	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x3ab6b7c8	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x6606bd41	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x677a7ae2	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x6e2bc685	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9594da51	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb35aaab9	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xcb969a17	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe03e357d	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xeaa5395e	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xf3a381fa	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x100f43b0	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x98462932	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xe9f256b7	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x75f79515	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xe3862dab	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x87769d85	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0xa7b30d27	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xd6f14167	imx_usbmisc_init
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xe781ca02	imx_usbmisc_init_post
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xe8742023	imx_usbmisc_set_wakeup
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x54839e02	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x771027ac	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x9e437d04	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xa453f63a	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xbe009e43	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xe6b5a494	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x03ed5072	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x07f65d50	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x1a69d0ee	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x27675733	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x2f9650f8	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x35db1610	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x7b13d0fd	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x85810f7d	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x868a0b33	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8730aeaf	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8d8fc41a	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd23cd371	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd52334ea	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd52d615f	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xf60b7b66	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x87b086ae	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x89ca818c	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x96180134	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xd371dd12	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x2fd2920a	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x58dd55c8	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x68c3a3c2	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1d590c8e	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x316a3d15	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x3eca4ecc	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x548e026c	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x57796315	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6c6e50f1	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6d99a11b	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x711de13b	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x88f533d4	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x8b8ce41b	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x8cb4c870	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x91a020c9	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9c457374	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xcac697c5	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xefb6e1d2	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x0fa52198	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x228529ab	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x37d3ff36	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x3fa62fb9	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x405829b7	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x486a2b01	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x52b169bc	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x6129f150	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x749722f3	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x9adfa782	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x9cacf703	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x9d5d9423	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xa1b4f433	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xe271ffd8	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xfd4980ee	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0de04b16	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x1f3253bb	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2eb1bbbf	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2fb76122	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4458f3a2	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x459ba287	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x45d8f456	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x47de712c	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4a382235	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4ad5d376	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x517a06e4	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5ec2ff73	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5ef98641	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6394be3a	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x68494784	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6b034d25	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x73bc38bc	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x86e61d97	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x89fd99a3	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8bbbdf09	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa562dc73	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xaf322e7a	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb8852023	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xbe5dda5a	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc30c9bb7	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc659bbc4	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xcde2b056	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xeec5d9dc	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf0bc20a5	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf7cd62f9	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfa63e868	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfddb8edc	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x0153fb7f	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x0f1f7440	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x37cf04a2	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x47d50198	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x67e73087	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x8247ab49	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x844f1c54	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa4744dba	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa8727ed7	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xb9e42756	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xcfc58b3c	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xef8c81a0	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xf4d81b3b	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xfd24b182	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x03315f9b	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0xf3aed174	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x10c4caf6	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x11de7151	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x5229d38b	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x5f7be6c3	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x89d638c0	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x8cd0fa39	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x8e1b80f0	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x8f82f6ee	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xd4b062ca	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xbd994a32	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0x2c9a8051	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x547c68fd	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x0fb541fe	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x21de8355	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2a099570	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4216118c	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4fe4747d	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x58c51dbc	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x5bf95b11	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x662f52de	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x79f22e25	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7afebb85	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x80e3bade	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x81972e13	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x8a03de1d	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x90a56f18	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x93e18b4a	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x9c33d33e	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x9d8ceec7	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xad795d1e	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe89007b4	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xeebcca74	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf204122a	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x28713a4d	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x314d6f2d	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3155a71a	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3f31b171	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4327eeb3	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x49f61144	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x5247aab2	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x58fac46d	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6313127c	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x658bfed1	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6a70d498	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x79db9026	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x88fd2141	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x90054ebc	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x984b4419	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xabebef52	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xae3f26f0	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc8f2d786	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xcf372ab3	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd1aeea39	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd9aa8ab8	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xdbad440e	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xdfdd9d1f	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf71e5305	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x16704da8	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x1b80ba6a	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x1c8f8e65	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x39cf8049	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x40cb7f07	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x69988da3	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x83d58782	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xc16593fd	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xc19936bf	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xc4ecda1e	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xc5cc5210	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xfd6e4443	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x190ca52c	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x1977d56b	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x49d98fee	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x614a1193	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xadc68fc7	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xb0d28bfd	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xc543b60e	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xd2c8eb66	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xf4654c3f	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0203eec7	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0675cca8	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x133bef4a	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x1450489d	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x3dca7e82	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x3dd3805c	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x4316edd5	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x5f695c28	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x657d2ed6	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7c806548	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x89c15e18	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xcc2295ab	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xd93ad860	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xe47e9e8b	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x349552d6	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x8487e3fa	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xe102aec0	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x0379dd16	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x587d8a86	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x66b0ff41	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x853bd0a6	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x8fae09ec	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x9221141d	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xb7ee22e9	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xc5bd3ca6	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0145afc9	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x08899e90	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0a80aeac	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0b8aad57	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x19a67c5c	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1e10d4e6	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x24db9235	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x26881573	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x28cc2766	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2aa346d9	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2ca6cf85	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3924ea3a	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x39ca9645	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x428badd1	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x43f9214d	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x46299f79	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x485a1bc9	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5e4bc088	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x661afc75	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x72c1499a	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x78abaf63	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7cf8c070	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7dcfcd23	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x87387a43	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa10355c9	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa2123a18	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa7e94ec7	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb0d94851	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb2dc218d	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb5c6f3eb	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb72ad6be	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb954e3f4	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xbee9e9a9	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc7d5a4a8	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd079b248	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd0e62f37	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd41d324a	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xdffb6fdb	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe1716f06	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe9784188	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf40bc804	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0x6e9aba0a	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1d15a788	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1f066fbd	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4b67846a	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4c54afa5	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x58895002	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x60b006cb	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x65dea736	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x71fa0aec	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x768375b1	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x7742789b	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x7877c87c	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x90e1a5ba	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x920ec237	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x947976ef	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x95052329	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x950ad970	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9a7d0b9b	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xac0d5f7a	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xac38bd98	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb0f81e37	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb32613fa	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb79f323f	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xba7cc6d5	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbcb924d6	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbddfd7ad	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xcc810991	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd1edd5fe	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe5b84253	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe785c6fd	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfe404063	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x05dc7580	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x26773c5c	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x3b8fb333	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x3df78313	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x8a07b804	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x9340d358	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xaa16b03d	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x051d5dc3	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x287cfc2f	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x34543c2b	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x4bfe8dbf	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x882b669a	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x9b18e533	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xb1d2f031	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xb8861cc0	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xcfe1128d	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xd13d96c4	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0x9000e837	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x729378ce	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x8f07467c	sis_free_new
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x01d7d212	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x14fc0926	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x1fbcdb5e	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x20479ff2	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x349871b3	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x3887f633	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7bf08cd7	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xf1979533	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xf3626c5a	w1_write_block
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xa88de361	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xe0f73bce	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xf3e3def4	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x0033e9e9	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x08ae384f	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x4d92e9f3	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x8d9e04ba	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xb42a7ab3	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xd59964bf	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xdfdc8a0e	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x056a3ec4	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0669be5e	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x071f9055	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0956a325	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0dd938d1	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x109e9ade	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x13263815	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x149e9fd6	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x14fdbd11	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x16ca3195	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x16f3e942	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1bead47c	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1ce5ab03	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2112bac9	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x21f366a4	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2224331d	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x25d9a289	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x28b36990	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2a0bf224	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2b4a7841	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2b883df3	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2bc525e2	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2ccec63c	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2cedb1c4	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2d2dd189	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2fb8818b	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x351fd055	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x358f68dd	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3997fe02	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3bd5846d	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3e5fbc59	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x412252fe	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42177403	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42bc6811	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x44c477d0	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x44db9ca0	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x471909cc	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4c58290a	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4e054809	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4ff993ae	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x529660e5	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x54dce027	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x55ec8559	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x56c0e13f	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x58626a77	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x592df306	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5d00fc3a	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5d38c30f	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5dc0fc9a	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6048ad1c	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x660f8677	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6703f473	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x67e4ab54	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x68efaa06	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x69fe9a08	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6f7818e7	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x724bc398	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x72fd5ebb	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x75526547	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x76fae4bd	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7858ff7d	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7e08ccfd	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7f25a2b6	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8322eac2	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8491c8f7	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x86d1c926	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x874dd4db	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x88d81ed6	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8c74869c	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8de450ae	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8df5fa27	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8e4274ff	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8f634a2c	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8fdbb6ab	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x908274a9	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9300d412	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9772d76d	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9a2f3da2	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9b5cc388	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9e36cec9	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa809b5be	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaaa14361	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xad239c71	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xae0b31c6	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xae17a5e8	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaed47b07	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb2e79281	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb6f70fe8	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb7db7865	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xba6b5c1b	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbade5c33	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbbb6de4d	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbcca4db0	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbe420b76	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc0ff8dac	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc16b1bdc	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc277f85d	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc36bfc43	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ecf91e	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5e5edc5	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc6ed5728	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcfd4dd34	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd3f481c6	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd62e5fda	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd7d12074	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd8a4bda5	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd9a65db7	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdb3e6faa	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdc1fef0f	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe018ddf0	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe0799ac9	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe2377a5e	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe635b21f	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xec16dd1a	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xedc2cced	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xefd93570	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf27e9c3b	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf637c18c	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf66d7a23	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf71e49e9	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf7f556e2	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf92fdc3e	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfa2d46c1	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb2f609c	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfe9557e8	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0x4e09332e	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x01d1f9e7	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x06e14d89	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x09f82131	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0b046c3e	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0defb2fe	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x17e1fe31	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x18a3b8e4	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1bbcaff9	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1e709f6d	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x20903005	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x209de9c0	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x23f1344a	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x241fed36	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2a5e73bb	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2d2740d5	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2e46bc71	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2e46cfd7	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x31826d69	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x31dec45e	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x40edcc44	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x42e08119	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x457ebb6d	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x45a35f6b	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x461b1add	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x48cddcb6	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4bdb7c59	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4cda5531	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5220ed7c	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x55617078	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5e0ced2e	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5edd7f84	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6f548a6f	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x75b6036b	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x75c9e426	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x795f6f55	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7a3b5e9c	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9785e35c	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x987827fd	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x98912735	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9d7c1666	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa02df320	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa2cd215d	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa451a17e	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa7b992b2	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa9dc2dc7	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb073e7e6	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb299a217	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb2dfc45d	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb4c886b8	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb6478c28	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xba796428	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbacf4e8f	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbde5e92b	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc82b42c8	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcc53468a	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd48555d9	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd576bffd	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd8a73ab7	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe93a196f	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf5224b86	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf915242b	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfc70991f	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x26b89d92	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x36d483da	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xd2a3d91a	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x0567addf	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x27bdd75c	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1cb231d0	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4ee69806	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x687f6251	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x7fd964f5	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x8a002b7f	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x9e7b5267	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa49be5a3	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa9f5379a	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xce8a0ff2	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xfa6d3655	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x3b2297e4	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x5d116915	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x6e759171	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x79ca2d69	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xcdeb17f0	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd10ca317	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x0517d21a	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x35cf232e	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x959e8f9f	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x2afb4bb6	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xd0aabe23	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xdfcd0360	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xc047212b	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xfdcd45f3	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x021957e1	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x0f8a2742	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xd4cb6873	raid6_call
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x57861324	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x57d39367	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x882ce5fc	base_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x9e0112d0	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xaedfbb15	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xc8fca8a6	base_inv_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xd11741a1	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xe3d900b5	base_old_false_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x14524b4f	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x303e6d1e	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/802/garp 0x8851bb07	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0xa015f110	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0xa4fdbfc1	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0xc1380370	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0xcc2c3d5e	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0xd41aa298	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x0a44d218	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x2a3931cd	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x4006d1fa	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x8ad91d6d	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0xc3f296ec	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xea276fcd	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/stp 0x100ac640	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/802/stp 0x2c1ec790	stp_proto_register
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x13c8c4fd	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/9p/9pnet 0xbda58993	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xa175837d	ax25_register_pid
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x0260d699	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x1464fe64	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x39a99c2a	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x66b04149	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x9d2bed93	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xb67f4999	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xc0cd6c18	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xfafab896	bt_debugfs
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x0d3b71fa	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x28c26df7	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x400f2655	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x97501d63	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x9ccbf0bd	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xf25865e1	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xf759e494	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xfc2b2d65	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0xa84c14eb	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0xaad448b6	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x09001824	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x21321fea	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x27047195	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x29ff8ecb	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2c038458	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2e34dcfb	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x351e93f5	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4c845709	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x57c889de	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x57dbe79e	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59ed3448	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x67bbf085	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x68e9b73c	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6b497af0	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x747cc989	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x758a611c	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x75b9a545	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7b6b3c67	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7c0ee5b3	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x81fbd57e	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x945ffd99	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x95577500	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa3f5132f	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa4104dc3	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xad74e0d9	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xaebca705	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb48918c9	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb6b0fd60	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc0b7b890	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc36f166d	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe418c8b1	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe4909c48	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe9182503	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf02f1c1d	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x1728b3c1	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x234c6055	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x304e5cd7	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x8f4577aa	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xb103ce07	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xf3991e26	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x07e43ba3	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x5e4aaadc	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x7ad3afd9	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xc869c5aa	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xd58dfa29	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xd8155ff5	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xf0a6ab19	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x1e2c5d97	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x62f711ca	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x812e5c53	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xaf8497a6	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xb88b8605	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xd13fb272	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0x24140e68	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x01d72ffd	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x2b9f9134	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x340df162	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x38b1d605	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x3b750fd6	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x5038e562	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x58d64315	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x7045e630	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xa29d6dd4	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc0810337	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd494d560	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xdadc0901	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xf9a9db57	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xfb8e5799	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xfd9d12b1	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0x67c93627	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0x710c4993	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0x1442ad67	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x04d9c4a0	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x2090d4f8	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x804b1252	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x9ccb1085	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xacce15ab	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x074734b9	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x06b636b9	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x617f8551	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x6a49df7e	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xc841619f	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xdd754fe9	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0xe9b8ef4e	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x120ea0ec	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x87fac1be	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x89591b11	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xbbda2afa	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xed88e835	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x16cfc7a6	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x4829df89	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x93873aaa	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xdd2641cd	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x0c84b5b0	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x0d67ac79	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x5d20effc	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x79f361e1	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x948067a5	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xe17dfbdd	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xeea30735	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x3cccb195	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0xa6715261	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0x2575e351	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x027c907c	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0xc8bc9d4e	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0x6eee6a24	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x78f3769b	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x8aa084c0	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x91de0942	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x93733bea	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xcd7c95d0	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0xdbacbb02	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x23edd441	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x4d68618a	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x6c44a5e7	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xb000308c	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xda3604c1	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0x56f3bd75	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x00767cfd	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x01e18168	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x27c80322	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x4015b8c9	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x40430ca4	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x49032b81	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x54020c89	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x5439efcd	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x6176cbbc	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x71097000	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x739e5958	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xbd21e7b1	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd01a0e8f	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd961ec40	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xe6c0055d	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xeff67805	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x2888b7c2	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x1bc1ff63	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x201aa80b	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x2a9f04b5	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x2cb30433	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x301516f5	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x3a92490f	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x56ec6485	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x66fd46cd	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x71a05950	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xad0efcfd	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xb7f58f73	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xcaa67fa3	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xcd1dffe5	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xd6e57dc5	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xdd44d7d4	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe925b021	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf8aa3c55	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf9fa191d	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x45c344e4	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xc3ec7708	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xd34d6711	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xdbb954bb	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x053c4489	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x0effa2da	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x1c2abf45	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4fc539bf	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6148d86d	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6344eaf6	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x86283558	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x88954d73	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x8d852de2	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa9fce7c8	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xb402dca1	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc662b762	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcd72e4da	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd9048105	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xdf4b603b	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xfa0c4863	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xfef42ba3	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x513ea74e	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x870005c7	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x9bfea1ed	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xce6222c0	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x04b88df0	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x09afdffb	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0dc03ef2	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x10e03d82	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x18498153	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1a1e262d	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x27bf2d87	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2ab608c6	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2f0a4614	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3163cbf0	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x31de9123	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x33d8aec3	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3d651b18	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x40f97c08	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4352f052	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5054ef44	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x507b87c6	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5296096f	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x542b81ee	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5b0d124c	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5e091d0c	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62628dc6	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x67268e6a	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6b6512b3	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6b819121	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6d861294	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x73bd3457	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x799bf405	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7c8350aa	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7dc14259	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8296fc8a	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x82fedb16	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x89249054	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8a66c4fc	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8e4a2a93	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90f7634b	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x99bf757b	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9b5f50c2	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9d88de44	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9ff1071a	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa1b71f96	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa46d5ede	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab74ce9f	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb1ad99c8	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb50140f6	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb74b7f4e	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb96d0517	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbb5a4378	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc173a32e	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc1b77445	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc6c7ecd1	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc8ed45a9	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcda54112	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcf54a98a	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd05c9d75	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd06272d5	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd1af0219	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xda33f308	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdabdc7b5	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdb001ad7	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdb852719	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdc64130c	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdde51e08	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdfc84282	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe0ec1341	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe1a8c771	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe2541057	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe301631d	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe793f9eb	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe8ab0f7d	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xec42e408	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xefbf655e	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf06452a3	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf0f589d6	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf50c8f7e	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf7e508fd	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf8b26791	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfb710401	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfcda7d7e	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xff40b965	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x70039e1f	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0xc7b3794b	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x26913c2a	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x5c47bacd	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x702d4a03	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x77b5565a	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x820efaad	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x8e2497de	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x8e3d220d	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xa2f340ea	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xbc310072	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xd226edb3	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xe601a5a3	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0x5b1a454d	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x15757681	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x3498c316	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xc271d93f	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xd81dc3d5	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x4793a9f9	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xa74661bc	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x0725306d	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x3e60fcb1	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xb2979f65	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xb4458361	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xc66720db	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xc93e3b6a	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xd91780b3	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0x21a3adee	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0x5562fcd0	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x383a0cb7	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x39d66788	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x806df05d	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xb28746e4	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x04402905	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x3154e8e3	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xa0170236	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xa08289ad	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xabf325f5	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xb98c84b1	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xb9e1d28a	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xc5682b6f	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xcbcc7214	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x0e568719	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xea95302c	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x018f9616	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x4f457cba	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x5f339439	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x042f928c	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x108d5700	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x10b57364	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x285a306a	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x2a145b9e	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x2be39008	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x3dc18769	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x4636ddd1	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5895c7d2	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x91630214	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x9c364b7c	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xa2cd8c9f	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc0dbfcd8	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xdcaf8881	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe6ec97fe	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xeca00d27	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xfbc3b94d	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x0a5247fc	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x1f91bb75	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x8138119b	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x94a1bd33	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xa24078b6	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xe5836caf	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xe7c7af00	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x320dfbb0	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x4051eb51	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x746e3542	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0x51dd07cf	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x3cbbcdbe	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x49e35a29	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xa991fd12	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x26cdb937	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x2f6f56b6	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x4cb33748	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x58abe380	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x920e8172	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xdbc8263b	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x6a1af3d9	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x9d7189cb	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa9c974c6	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xb830d08c	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe2d76b9c	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x0804f602	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x38151b15	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x54072c21	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x614e8a4d	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x6bcef142	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8ae62bb0	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9e5f4310	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xaa60c0e8	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xacebc998	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xb8a5bccd	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc883fb30	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd3c4669b	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd9d880d3	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe69111b7	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x00204983	xt_rateest_put
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x482b6a12	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x0b90fc90	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x104299b5	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x4aacbbec	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x0e6ce0a1	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x44af2304	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x7703cd5c	nci_uart_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x2923db68	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x2e98a5f8	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x59b16f1b	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x818b01bc	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x94dd29bc	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xa41c2f2d	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xafe505ee	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xc92f2b55	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xdb1a9b08	ovs_vport_free
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x1bfebb0d	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x2a9628a5	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3ac7b46e	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0x3ae6ce59	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x49b2947d	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x5e34d309	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x63f6a01b	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x66d4ae68	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x697175fa	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x6ac3863a	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0x6cd56707	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x6d58fc33	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x8232971e	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x96fafe85	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x9f1092fa	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0xa66f99c1	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0xaf56df8c	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xb914062c	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0xb937e7c7	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xccb25f1d	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0xe10dc918	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0xee6f071e	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0xefbc3167	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xf0d0bd7f	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0xf7311375	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x44a30048	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x5860d831	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x7ee496ba	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xa2b9b9d6	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xfd67d6f5	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x005d6c11	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x02cb4827	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x03fb1914	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05ede0ec	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x064e0956	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x09666273	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0bacdf78	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c2ccffe	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c4e9d76	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0da06165	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0dcc91cc	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x103b2a55	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1059b155	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1183a5eb	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x12db87df	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x13450da6	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1528ea29	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x16a4131e	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x177c01ec	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1a6cf760	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1afaa5ee	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2043c82e	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x206bc4b8	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x22333b34	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x22d40480	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x22d4fbd8	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x22d8d4e8	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x234e0481	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x243e2e8e	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24a04b37	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24a6a578	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x27e5a315	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2828885c	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x29deae81	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2beff011	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c39cab1	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c3ec209	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2d6012ef	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f8ebbe0	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x33536b47	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x340c0512	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x345ffa9d	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x35394f06	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x35a46592	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x36acc381	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x39e40cf9	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3be0b025	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c4d06cb	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3e089531	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f5e16f0	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f7092fa	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x43ac9caa	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x447a745b	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x451da397	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4542d14e	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4612dc50	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x46d1d66f	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x46f0bf27	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x47165ef5	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x47b40704	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x48121644	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x483324fb	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4c64797e	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4d3a25b9	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4e5ce80e	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4efbdd23	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4fc72725	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5075a172	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x507d813a	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x50e8fc77	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x51b4d3a3	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x550f8134	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x56379c75	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x563a0861	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x58480769	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5a21f774	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5a27f252	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5a878d95	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5f89eb13	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x60b2da17	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6195a948	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x62230a8d	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x63288871	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x64ca4ccd	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x64e29e7c	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x64e3559c	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x66590edf	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6702ad6c	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x685dc053	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x69e8f3cc	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6a92bdb0	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6aca546c	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6b2de454	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6d43012b	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6e944b1f	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6fc571a9	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x703113dc	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x710edd96	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x711a3c71	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x713f2a57	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x723194e7	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x745e88e7	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x754cd863	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x77811f9c	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x77b2d365	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x79129dbb	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x79f77fc3	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7a70e681	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7bfa657c	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7cdfbae7	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7e1ac005	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7e435b5d	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x818576b9	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x82545f5c	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x845aef49	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x87f01702	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x88952da6	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x88a5a8c6	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x88aa0f93	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8ad4593c	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8ba43bc7	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8cc9fe6e	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x900f661a	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x91078771	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x94c7307d	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x957f0370	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x95c260d9	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x96727883	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x97a49ac5	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x99a80a0f	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x99b9502b	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x99c11c33	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9bf2d26e	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9bf7f375	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ec9990f	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ef449af	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9f18f431	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9f3599db	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa01d9838	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa19e2d7f	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa31a1395	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa364a7c6	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa59f694f	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa623c3d4	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa82a00a7	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa83e3284	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa952216b	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaac60a5d	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xab9b4257	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xac710196	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xae8df557	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5f213b	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb12c7da9	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb3163cd8	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb3ac5ac8	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb7d113f2	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb80ca97c	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbea72d77	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf4e53c5	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc00812e2	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc110fde7	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3270ebc	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3fc0992	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc42f8711	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc7ca5e0f	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcbc1b0c0	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcd00aa9d	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xceb70b34	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcec6eadb	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd14225b4	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd50ad66e	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd76054b1	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7f3c3a8	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd85ae386	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd9fce9a1	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xda0be6c5	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdacd53a7	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdce74267	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdd6b720e	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdda49050	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe047fb26	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe0e4cfab	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe14a56c8	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1787583	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ee2859	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe3f1865b	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe4ee21b4	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe665b9d3	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe78f6c34	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe89fa7bc	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe9579db6	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeb121f9b	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xed371470	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef0c21e4	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf08b7c5c	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf4d9f1c2	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfc7ee7d3	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xff599a38	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfffa19db	rpc_pton
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x10189376	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x14d04b04	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x293dc379	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x3841203a	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x4521147d	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x4e657117	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x551fe2a5	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x5842c272	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x676e8518	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x6f945b9b	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x74e91915	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x77a616c7	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x972efc86	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xeb73ff1e	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf593c40a	vsock_pending_work
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x0f2a0e8f	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x1979d9f0	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x22894c37	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x231afa7f	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x2d198df5	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x31276d02	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x47035a56	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x47f023d7	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6b0a4220	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x8c7df265	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x976e9e0d	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x9d333e6e	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xe989a7c0	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x17151685	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x39f3fad7	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x3ac7d1f8	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x44277442	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x4c9c782e	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x50c550e2	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x567c8127	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x5fff0641	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x6089a21d	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x7397d481	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x846da35e	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd23d80fc	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xfe4c05e8	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x0bc547b2	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x6020fa3a	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x9e138618	ipcomp_destroy
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xc2851ba4	ipcomp_init_state
++EXPORT_SYMBOL_GPL sound/ac97_bus 0x4b53c2d3	snd_ac97_reset
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x0922dfe6	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0xc813ef79	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/core/snd 0x1089a9e2	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd 0x1e9bf402	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd 0x2d806744	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL sound/core/snd 0x440a63b2	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL sound/core/snd 0x71bc36ba	snd_device_initialize
++EXPORT_SYMBOL_GPL sound/core/snd 0x9e2d4377	snd_device_disconnect
++EXPORT_SYMBOL_GPL sound/core/snd 0xc87eed22	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x002edd46	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x195cc8cc	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x74fa312f	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x8a392261	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xc3d2eb57	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xc3fd1c7e	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xeedd5ef4	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xf15e3dd4	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xf47c97b3	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x07dc8356	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x45384e24	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x6c4fb495	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x6ea9acd4	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x77c11c9d	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x8bdef0f0	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x8c57aa9a	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x90436c4d	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xbd191a53	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xe3b2d1c4	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xf1bbfb56	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x0fa2adac	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x149daa58	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x3034b0d2	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x57474ebd	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xd88bacf4	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xe856895d	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xe925aecf	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x00ae2bed	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0185dc85	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x07061ef3	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x074f5db5	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0a652737	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0abb4a56	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0b85e2eb	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0cfbac80	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0e9ece59	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0f05a0c3	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x110643dc	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x134301a4	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1eaedcc2	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x205c0806	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x27381ae1	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x273ea9e0	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x277c9dcb	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x28225a88	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2e4869d1	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x34418faa	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x35ae93c3	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x405a7106	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x412c7043	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4ae9c5bc	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4ee66290	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x570dba76	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5a103ca1	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6032b96e	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x61e31243	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x61e3c8dc	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6452eb19	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x64f7d1dc	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6ff8e3a1	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x79275f3f	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7bf69390	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x82b180a1	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x83ce1b1c	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8658b574	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8a7efd91	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8b9898f3	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8d2292e8	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x95a03c54	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x95dc3864	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9c5c2ad7	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9d9d6331	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa11fda0d	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa2430a03	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa2a27c75	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa4498f94	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb276906c	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb522e704	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb523eee6	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb77b7cb9	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb903372f	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbb7a362a	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbec15014	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc15f1bf4	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc25e2a3b	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc6ce3d74	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcc1e9ef2	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcfe9c496	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd2e432f5	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd93772ac	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe6ab7a07	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe90f84ab	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xea37eaf9	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xebafd5eb	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf0a6d4eb	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf448dcba	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf59f165a	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf871cbe9	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x14987348	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x16af8b69	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x458169a3	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x50fb1425	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xc1e95bbf	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xd0d54509	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x050df6e4	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x05bfde10	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0a00c103	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0a36c608	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x10648d9f	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x11e887bb	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x127a1879	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1346ba87	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x157554b1	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x15f80630	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x16076be5	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x16904b94	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1b5b8cfd	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1f034164	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x21dce97e	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2388a5fc	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x27939625	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x28111c2e	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2d03fdec	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2e995dcb	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2f4cbd5e	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x30564e51	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x30a6480a	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x30e4f4a9	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x31eb6e27	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3360889a	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3455f3cb	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x36ad4459	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x37f63594	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38bbb87c	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x39169735	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3d2161c8	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3f4d61f4	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x421a735f	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x422337a7	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x42ec6ae0	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x485fea1d	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x48e03472	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x48ea2e88	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4b46b414	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4bc3e9f7	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4bea1cce	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4c44933e	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4e81d042	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4f459225	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x50314921	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5146ab8f	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x519048fd	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5400fc54	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x56a89f1e	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x588a2d76	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5f370954	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x61a76fba	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x61f2e816	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x64ebef01	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x65456d7f	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x65f3be25	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6bf0c0a4	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7253f0d5	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x73f1d0a1	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x74046b67	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x789cff19	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x78e0ea9a	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7a8bcda2	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x80a2219a	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8566ff43	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x883d18f1	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8852df68	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8902fa2f	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8bc5e92d	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8c76b27f	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8c9193b1	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8d8a2a06	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x96db2fe6	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x96e278d0	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a6cb8a0	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9b7210bd	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9d94d2db	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9debd2c0	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa381ad37	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa829871b	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaa16373d	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xac91ffff	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xad9d42ba	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xade49a3e	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb12306f9	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb41762d9	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb9324786	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbc195ede	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbe60d3cd	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbfb54695	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc05d6b47	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc2fd7a3f	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc32172c2	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc3d9c811	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc4deb373	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xca70f682	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xca8f17da	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcad4db85	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcc3a2e9e	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd0c56838	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd5213e3a	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd5cac4d4	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd66ca258	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd818ec5f	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd81d21ff	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd8323284	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd9960bd9	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd9d8936c	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdb56b701	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xde3bc410	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe5794613	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe6076b82	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe960e44b	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeb77a933	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xec4c2caa	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xec7b4ea7	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xed0ea7de	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf18b50b9	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf1cd3cc2	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf44b9b68	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf53c5025	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf6d64214	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfc8eec11	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x0d41de96	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x1951f004	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x33101c29	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x45743346	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x53f30d52	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x5a6e25f1	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x5dc5f875	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x5fd81925	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x66b2b88b	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x79803ffd	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x7e752b2a	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x7f4c273d	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x857e8391	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x87520565	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x8a5597d1	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xa4046b03	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xb69350e5	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xc2f6af2c	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xc664b6e1	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xca7f8c5e	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xdc2c10e1	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x7d05786f	cs4271_dt_ids
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xa7ad3c73	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xaa357a3a	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xaccf3fb3	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xdea08915	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x02deb2d5	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x877a2f62	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xfaba8195	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x4af768d6	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x7a463b28	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x46221cf9	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x47ce69da	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x54954920	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xd482f709	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x1f86ca49	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x2f57cc92	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x75e52a43	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x925e5719	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xfd4fa285	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0xc3b6b28a	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x13414b67	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x928adfbc	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x841c693a	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xa31f737b	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0x4cf73d2a	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x193affaa	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x1cb73d69	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xa291f89a	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xe89162a8	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0x89d8d6f3	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0xfa5de2b0	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x8b8ad002	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0xca2ddcd7	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x00f19f49	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x048a955e	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x050bfd86	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0929e145	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x09ea0e63	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0d6c4334	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0d744eb8	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0dbe8a7e	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0e3838d1	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0ede7104	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x10ac954e	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1508af4b	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x17aee73a	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x17e29914	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1dd74bce	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1eeb8311	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x21afe181	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x231823e0	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2620a158	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x274fba3d	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2781ae3f	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x28e6b5a1	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2931659a	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2b3efdda	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2dc73e11	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2f6a5748	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x30b13689	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x322c18fc	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3512f2f9	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x367804ff	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x37c428de	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3b0d51ac	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3b4f1bd1	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x425aced7	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x43e06d7f	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x43e80c99	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x47d5c289	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4815781b	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x493b1a4f	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4c192809	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4c56c8e3	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4ede8baf	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4fac8679	snd_soc_resume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4fe42da1	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4ffb74a6	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x549a8c43	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x54a077e0	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x54c48051	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x55667a1c	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x557efaa4	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x55cea453	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x584e719c	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x58d384e8	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5a18a8d6	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5ab4c26d	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5cbf84ea	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5eb74a1f	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x620ed7c1	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6349a40d	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x649b3bdb	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x651f0063	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x66374c38	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6d7236da	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6dcb6163	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6e8c6832	snd_soc_component_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6f04fcbb	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6ffb855c	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x74f98d61	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x75e3ba33	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x776ccef3	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x77bb9164	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7b025f80	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e9f27c2	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7fda611b	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7fe5c9e2	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x80fe79e4	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x81f03b2e	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x82b5c1d0	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x84eddbce	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x89ce5769	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8ba71e8a	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8ba995ba	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8db9375b	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x902d1ddd	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x903fd88a	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x90e252f6	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x91014c6e	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9111b74f	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x91513b52	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9d1b6ce4	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa44c1aa3	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa4f1f85f	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa580d9b5	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa7d8c97e	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa89d8b15	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xab3c3971	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xac65cc59	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xaf5bfeb9	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb05b60c7	snd_soc_component_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb334e55d	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb52f6009	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb5c38247	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb990961f	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbb6bcea2	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbbd5caff	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbbe6cbb3	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbc01035f	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbc09db46	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbcd78b34	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbd2dfb1e	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbe237576	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbeb81e95	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc01c0256	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcf651472	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcf97b0f1	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd0f0f849	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd21deb42	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd587b5e5	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd59641e5	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd657b922	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd65b5950	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd729e028	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd84fcc8c	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd9ed48aa	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdc5ed21c	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdc81130a	snd_soc_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdc82c3a5	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xddf8440a	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdffec98f	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe1440642	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe21c0f01	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe3e9039c	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe447b4c8	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe68b75eb	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe99af54f	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeac78e7a	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xebe3ef91	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xee030239	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf1358b4f	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf2c34cda	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf41843ba	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf4ba3623	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf76d79ad	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf8bf53b1	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf9b2b477	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf9fc4105	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfd8f0eb7	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfdbb668c	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x24829813	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x2712a6ad	line6_read_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x2ed06e24	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x4a97e274	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x52a2c6fe	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x77454fb0	line6_read_serial_number
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x810da0b9	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x83b8a158	line6_version_request_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x865d4cc1	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xa50e0ddd	line6_write_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xb8494f2f	line6_suspend
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xba9ea8f2	line6_pcm_release
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xc2a26a86	line6_pcm_acquire
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xce67a027	line6_init_midi
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xfbef2670	line6_send_sysex_message
++EXPORT_SYMBOL_GPL vmlinux 0x00431471	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x00632780	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x0086a036	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x009fd2af	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x00a59c78	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x00ad6d0f	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0x00d49c8b	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x00e0b028	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x00f5f182	of_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x0130833b	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0x013712af	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x01377827	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0x013ff732	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0x0161fed3	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0x01670813	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x016a7791	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x016b2818	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x01942ddc	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0x0195fba9	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x019ce93f	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0x01ae2048	clk_hw_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x01c5235d	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x01e56906	mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x02135698	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x02158fa4	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0x021ebfda	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0x02472086	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x025671cc	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x0260f2dc	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0x02772009	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x029894ec	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0x02b1053f	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x02f15154	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x0302e260	md_run
++EXPORT_SYMBOL_GPL vmlinux 0x030935a7	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0321cdbf	of_alias_get_highest_id
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x037740ce	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0x0390bda4	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03bb4630	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0x03bf5226	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0x03dea0fe	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x03f606ec	nd_cmd_out_size
++EXPORT_SYMBOL_GPL vmlinux 0x0402cbbf	preempt_notifier_inc
++EXPORT_SYMBOL_GPL vmlinux 0x04172488	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0x0443f4f9	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0x0444ddbf	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x044c4255	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x045adb68	kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x04820e08	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04b5549c	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04ed0fae	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0x04f13407	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x04f4bd8d	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0513223b	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x051c8db8	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x052f9835	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x05306bfe	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0x053a89ba	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0x053e8299	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x05544c1e	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x055dab41	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x05c90eb6	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x05e23d19	mmput
++EXPORT_SYMBOL_GPL vmlinux 0x05ead6f3	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x061dee59	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x06236a52	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0x06254c77	kvmppc_hv_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x062c0b6b	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x0640b6bc	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x064e273c	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0x066915b5	rio_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x0670622d	rio_get_comptag
++EXPORT_SYMBOL_GPL vmlinux 0x068a4a42	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x0695dfc2	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x06a096e8	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0x06a72e3a	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x06acad57	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0x06d300be	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x06dd420e	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x06f2ef6b	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x07062840	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x070a33cd	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0x072f6877	arizona_of_get_type
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x0767eddf	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x07836ffd	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x079942d1	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07c360c1	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0x07d6b304	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x07f300c3	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x082bb7fe	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x0842aa74	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x0843a161	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0x084c0666	kvm_write_guest
++EXPORT_SYMBOL_GPL vmlinux 0x0864c298	rio_dma_prep_slave_sg
++EXPORT_SYMBOL_GPL vmlinux 0x089f7b0d	rio_mport_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x08a1085b	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0x08ac5bfe	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0x08af447e	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0x08b01a54	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x08caa4d7	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x091c824a	machine_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0952af60	fb_videomode_from_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x0962d0e8	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x098809ac	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0x099b537e	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x09aa071d	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x09bb0cea	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x09bf992c	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x0a14c956	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0x0a305d6a	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0x0a31cbb0	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0x0a46522d	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x0a51ae5b	virq_to_hw
++EXPORT_SYMBOL_GPL vmlinux 0x0a62f128	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0x0a986e5c	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x0a9a54f6	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x0ab1b5be	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x0ad11963	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0x0ae6bd6d	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x0afd4610	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b10648e	user_update
++EXPORT_SYMBOL_GPL vmlinux 0x0b15c789	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0x0b180240	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0x0b1d5ae2	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0x0b453cf8	clk_register_fixed_rate
++EXPORT_SYMBOL_GPL vmlinux 0x0b580b64	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0x0b6ca76c	of_thermal_get_ntrips
++EXPORT_SYMBOL_GPL vmlinux 0x0b97ce47	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x0b984c9d	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x0b98d908	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x0baf081f	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x0beebf65	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x0bf4e8e8	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x0bf642a3	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c666e91	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x0c6c5f56	of_get_nand_ecc_step_size
++EXPORT_SYMBOL_GPL vmlinux 0x0c8fab10	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0x0caf677e	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0ce865f8	nd_numa_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x0cf88937	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0x0d00f487	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0x0d059e64	static_key_deferred_flush
++EXPORT_SYMBOL_GPL vmlinux 0x0d0ab1ae	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x0d249cd0	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d5317d8	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x0d6d1409	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0x0d706d2e	rh_set_owner
++EXPORT_SYMBOL_GPL vmlinux 0x0d73a952	GregorianDay
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0d904145	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0x0d974922	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x0da9efa1	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0de06988	cpu_first_thread_of_core
++EXPORT_SYMBOL_GPL vmlinux 0x0de2bb5c	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0e244724	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0x0e2bd917	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x0e3be0c4	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x0e525b41	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0x0e532a77	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x0e576be7	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0x0e58e6fa	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x0e5ecb88	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0x0e8520c3	of_dma_xlate_by_chan_id
++EXPORT_SYMBOL_GPL vmlinux 0x0e900b74	__rio_local_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x0ec96c57	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x0ed91f40	vcpu_load
++EXPORT_SYMBOL_GPL vmlinux 0x0f289ac1	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f3a5632	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0x0f52418b	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f7abe57	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0x0f99ec92	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0fb6e4c9	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x0fc01e9f	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0fc59ef8	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0x10056f9e	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x10271b47	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x1027f2f4	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0x10647b37	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x106bcfc6	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x106bd796	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x10bc9650	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x10cf3dcd	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x10fc3a44	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x11012c01	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x11080ca3	max_gen_clk_remove
++EXPORT_SYMBOL_GPL vmlinux 0x110f673e	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x1111c492	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0x1114011d	threads_shift
++EXPORT_SYMBOL_GPL vmlinux 0x11354b9e	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x115d784f	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x1160be07	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x1166e6ac	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x1174f7a0	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0x117e229b	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0x1198e573	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x11a39827	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0x11bb4e7c	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x11bf1650	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0x11d4621f	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x11d72f08	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x11d7589e	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x11de078d	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x11dfda7f	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x11ff0d25	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x121b8bfd	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1243d211	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x1247054d	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x124970c6	mpc8xxx_spi_tx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x12965a6d	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0x12ca8e17	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x12e8471f	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x132388d4	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x136a4ee6	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x137a7cd5	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x139a7964	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x13ad647f	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x13be8b30	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0x13e5ea13	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0x13f271a9	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0x140adb9e	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0x142f240e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0x1433330c	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x14513b6d	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x14576009	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x1464fcca	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x147db17a	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x14900b3f	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0x14a46706	rio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x14c25248	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0x14d96cdf	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0x14ed96ca	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0x14fa925e	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x1501458e	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x150e5b9a	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x152a9882	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x1535949b	nd_blk_region_to_dimm
++EXPORT_SYMBOL_GPL vmlinux 0x1541ff1c	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x154e005d	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x155151c6	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x155537f5	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x15764705	rio_mport_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x158c00e2	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x1595174d	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x159bd9d8	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x15a17183	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x15b2cce2	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x15c0850d	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x15c21e5e	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x15cedbc3	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x15f6080a	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x16043bda	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x160536d3	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1609b826	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x1620444e	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x162fda07	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x163f189b	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x165488a4	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0x1666370a	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0x167c6b75	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x168839df	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0x16a44569	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x16acd0dc	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0x16f6ab76	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x170a0397	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0x170a5cdc	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x1726c94d	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x17398347	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0x17620ba8	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x1769bd6f	of_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x17911b70	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x17957afe	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x17d85b7b	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x17e28f5c	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0x17e827b7	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x1801f9c1	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x180b0c97	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x18176970	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x182c84bf	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x182ee76d	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x18303bae	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0x18416d17	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0x1849a1f3	dev_pm_opp_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x185f0780	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x186e3e66	rio_mport_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x1895ec8a	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x18992fb5	clk_hw_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x189f8710	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0x18a481e3	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0x18b5bf4e	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0x18b909f5	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x18c21e89	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x18d4ae06	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x18efb089	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0x1902dfa7	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x190bbb86	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x19424883	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x196da5b0	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x1971681d	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0x19743d3d	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0x197b7385	of_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x19839e0d	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0x1988f654	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x1990f8ff	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x19965c0a	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x199eb82c	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19abaadd	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x19dfbe17	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x19fbe2a2	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x1a173188	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1a1c4082	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x1a271fa0	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x1a2b5f1d	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0x1a3a6bb0	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x1a47af1f	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0x1a71779c	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x1a7c4288	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0x1a8c5907	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1aa0889e	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0x1ac69d55	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1adeb0ac	dax_fault
++EXPORT_SYMBOL_GPL vmlinux 0x1aecedf1	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x1af7fcdd	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x1b28ca0a	__find_linux_pte_or_hugepte
++EXPORT_SYMBOL_GPL vmlinux 0x1b3143aa	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x1b365161	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0x1b3a59e1	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x1b518c8e	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x1b52db1c	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x1b65f1de	clk_register_mux
++EXPORT_SYMBOL_GPL vmlinux 0x1b7d1e91	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1b9de7a1	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x1ba97c63	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x1bc310bd	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0x1c0ac086	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0x1c264758	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0x1c3855d3	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x1c388a03	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x1c4fea95	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c589782	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c5ff742	clk_get_phase
++EXPORT_SYMBOL_GPL vmlinux 0x1c65bdf6	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1c97aac2	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x1ca3b877	of_scan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x1cdd5440	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0x1cf82066	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x1d08c269	of_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x1d0feffc	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x1d12fcc8	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0x1d193903	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d31ce93	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1d7fcf5e	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL vmlinux 0x1da4a08e	rio_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x1daa0127	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0x1dab69f5	nvdimm_pmem_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x1db0cf01	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x1dfbcf4c	mpic_msgr_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1e3c575a	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x1e4145ec	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x1e498b15	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e73ce69	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1f1878f6	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x1f1dab81	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x1f3c835b	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1ff9e277	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x20191fd0	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x20273ac3	rio_request_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x205d109d	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0x2061b39e	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0x2064a6e2	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0x206fef44	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0x2077be3d	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0x20a446e3	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0x20aa6f51	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x20b631da	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x20b8deab	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL vmlinux 0x20f7fe58	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0x210334e9	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x211a5c76	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0x2123900e	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0x212d7b1a	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x213a708a	kvm_vcpu_gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x213d430d	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x2148b713	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x2148f1a6	rio_dev_get
++EXPORT_SYMBOL_GPL vmlinux 0x2155414d	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0x21571a94	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0x216077c0	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x218d597d	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x21a563da	clk_get_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x21c0948f	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0x21c852c6	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21faa1d2	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0x221ae977	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x2238fba3	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0x22919ed7	kvm_read_guest
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x22ccccf6	of_get_nand_ecc_mode
++EXPORT_SYMBOL_GPL vmlinux 0x22de3842	mpc8xxx_spi_rx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x22e50f73	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0x22efd9e3	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x23089a88	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x2315a82c	clk_mux_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x231efa1f	of_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x233ae603	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x235ec0da	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x2369fc59	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x2396c7f0	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0x23979adb	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x23981055	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0x23cfa2a4	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x23d70bf9	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0x23d7fa4b	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x23d8fabe	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0x23e21333	dax_truncate_page
++EXPORT_SYMBOL_GPL vmlinux 0x23f1934d	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x24240cd9	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x24465993	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x2449bb06	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0x2454fc17	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0x246039f6	of_pci_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0x246692a5	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24ab4bf9	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x24ab6be9	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x24cb34b7	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0x24d7de7d	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0x24e32c25	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24eee3c7	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x250de997	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x25296e71	nvdimm_name
++EXPORT_SYMBOL_GPL vmlinux 0x25379e73	clk_set_min_rate
++EXPORT_SYMBOL_GPL vmlinux 0x2599ced2	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x25ab44b1	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x25c97931	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x25d88992	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x25e179d9	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x25ec8669	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x26085a7e	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x2665cf2d	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x266cf938	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x2687948d	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0x268efd43	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x2691412e	boot_cpuid_phys
++EXPORT_SYMBOL_GPL vmlinux 0x2693d60f	mpc8xxx_spi_rx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x26a75010	rq_flush_dcache_pages
++EXPORT_SYMBOL_GPL vmlinux 0x26b2aebc	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26ba942f	of_pci_get_devfn
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26cb2fb7	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x26e1051e	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0x26e9fb50	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL vmlinux 0x273fce0e	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x27413822	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0x274cf5e1	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x275117c3	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x27874bb6	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0x2787cadb	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0x2787db00	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x27981f3f	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27c84939	of_property_read_string_helper
++EXPORT_SYMBOL_GPL vmlinux 0x27cceb3f	kvmppc_kvm_pv
++EXPORT_SYMBOL_GPL vmlinux 0x27ddff88	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x27e012bb	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x281e4497	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x282ba265	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x283ae79b	dev_pm_opp_remove
++EXPORT_SYMBOL_GPL vmlinux 0x285a5f9d	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0x28d6a9fb	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0x2906a8ea	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x290f3039	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0x29133765	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x292f235b	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x29303e3f	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x294ca9e2	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x2960e9b8	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0x2981c8d6	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0x2996f84e	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x299883ff	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0x29cfd4f7	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0x29dd5782	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x2a2064f9	clk_register_gate
++EXPORT_SYMBOL_GPL vmlinux 0x2a23f405	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2a2cfa47	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x2a47be82	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x2a5b86c7	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x2a618936	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a76b769	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x2a90beb7	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b2a5ff0	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x2b428ced	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0x2b5077b4	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0x2b5c303b	smp_send_reschedule
++EXPORT_SYMBOL_GPL vmlinux 0x2b7643c7	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2b7a574f	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x2b887f16	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x2b952517	clk_has_parent
++EXPORT_SYMBOL_GPL vmlinux 0x2bb47cd5	dev_pm_opp_add
++EXPORT_SYMBOL_GPL vmlinux 0x2bcb3d0e	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa985e	nd_cmd_dimm_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c353126	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x2c74f68a	fsl_spi_cpm_init
++EXPORT_SYMBOL_GPL vmlinux 0x2c75e1ed	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c7ef1b4	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0x2c7f2baa	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x2c97c085	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x2c97f8a2	of_reconfig_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2ca676ec	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x2ca772bf	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0x2ca969ea	pcibios_claim_one_bus
++EXPORT_SYMBOL_GPL vmlinux 0x2cc8367b	of_clk_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0x2ccc2c71	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0x2cd55acf	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2ceb480f	pcibios_finish_adding_to_bus
++EXPORT_SYMBOL_GPL vmlinux 0x2cf74d70	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0x2d0fa019	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d2cafef	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2d36c57b	rh_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d72480e	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0x2d7345d7	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x2d8052a4	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0x2da4b0b5	of_console_check
++EXPORT_SYMBOL_GPL vmlinux 0x2dadb8cb	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2dc5a6d1	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0x2dd25f87	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x2de681b6	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e417818	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0x2e4cdca6	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x2e4e429b	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0x2e848311	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2e883523	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x2e8f6c15	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ec53d99	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2f03d3b6	__clk_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f0eac5d	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x2f12851d	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0x2f1796a9	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0x2f17af1b	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x2f2c918d	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0x2f3e4ed3	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f638c06	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f75e69f	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f777ddd	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x2f984296	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0x2f99b059	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0x2fc966f2	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2ffb5ff7	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0x301cf1a7	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0x3031135e	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0x3039f9cb	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x3053ca30	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x306e8078	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x3071ae7c	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x309f6eb4	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x30a197c3	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x30a4f4ca	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0x30a8235f	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0x30ba6cf9	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x30cd9181	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30d7b1a1	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x30ffbed7	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0x31002471	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0x31042b3f	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x310a5bf0	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x312c517f	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x3131035f	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0x314013a3	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x3149af10	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0x314f75d9	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0x315ca785	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x316033ec	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x3162ae50	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0x318f5311	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x321a3391	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x322c5b06	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x3230e4a6	devfreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3242f7f6	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0x3243b3a2	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x324e49cc	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x3289e5d8	dax_zero_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x32924a4d	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x329a2105	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x329a7178	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x32bc0fcf	preempt_notifier_dec
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32cfcc21	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0x32d89c94	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x33002772	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0x33189512	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x331e5c6d	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x333abbfd	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x3356c73d	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x3367b9f0	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x337786fa	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x3393549d	rio_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x33ad41e9	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x33af224a	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x33c7b12a	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0x33e76b1a	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x33f48aa1	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x34006ec9	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x340d5346	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0x3411fb4a	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x3414fff1	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0x34331d5e	nd_fletcher64
++EXPORT_SYMBOL_GPL vmlinux 0x345e2163	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x347682ce	snmp_fold_field64
++EXPORT_SYMBOL_GPL vmlinux 0x347aef35	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x3496c278	kvmppc_emulate_instruction
++EXPORT_SYMBOL_GPL vmlinux 0x34a633de	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34a9828e	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x34ac50a4	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x34ccec25	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x34eabf8c	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x351dfd4c	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0x352488b9	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x352d420d	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x354fc874	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0x3551c895	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x3565b1c1	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x35711d4e	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x35abaf98	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x35ace722	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x35b824f7	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0x35c1f277	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0x35caae5d	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0x35d02d2a	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x35f58716	of_usb_host_tpl_support
++EXPORT_SYMBOL_GPL vmlinux 0x35fabcf8	rio_unregister_scan
++EXPORT_SYMBOL_GPL vmlinux 0x35fafb05	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x3631c9f6	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x36584580	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0x36767b31	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36a33874	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x36a64e5c	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0x36bda7b0	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x36fc8aa7	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0x371dbd7c	gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x3722c566	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x3725db95	pcibios_alloc_controller
++EXPORT_SYMBOL_GPL vmlinux 0x378d5294	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0x37c38d06	irq_of_parse_and_map
++EXPORT_SYMBOL_GPL vmlinux 0x37d2c2c5	rh_dump_blk
++EXPORT_SYMBOL_GPL vmlinux 0x37d99390	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0x37f15ac6	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x38046544	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x38055278	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x381eca59	clk_hw_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x382328dd	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x38364f79	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x383f2471	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x384a6981	__gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x38639300	of_overlay_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x38836c31	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x38967378	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0x38a9c2c7	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x38b0f258	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0x38c07e28	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0x38cc9f74	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x38df20bc	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0x38e5bc5a	clk_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x39112675	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0x3919c73d	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x392d5c0d	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x39366aa8	__tracepoint_kvm_ppc_instr
++EXPORT_SYMBOL_GPL vmlinux 0x3950ae7b	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0x3951a994	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x3987a2b4	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0x399aac20	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x39a1ad43	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x39c16676	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39db1b2f	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x3a020a58	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a3a7d80	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3a3db234	divider_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a56a526	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0x3a5e68ec	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x3a65ea25	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x3a678b68	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x3a710881	to_nvdimm
++EXPORT_SYMBOL_GPL vmlinux 0x3a712df3	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x3a7c7292	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x3a867c57	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x3a92d90e	dax_pfn_mkwrite
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3ae8f89c	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0x3b05307f	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0x3b10eb10	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x3bc04f06	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0x3bdd0549	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3bddba0c	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0x3c08bbff	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3c123da4	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x3c244520	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x3c39134b	dev_pm_opp_get_suspend_opp
++EXPORT_SYMBOL_GPL vmlinux 0x3c40d4e9	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x3c8f5306	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cd26f0e	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0x3ce5f5e3	of_get_nand_ecc_strength
++EXPORT_SYMBOL_GPL vmlinux 0x3cf85476	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3cf87dc5	to_nd_blk_region
++EXPORT_SYMBOL_GPL vmlinux 0x3cfaf699	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0x3d14286c	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0x3d24c1b6	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0x3d2798af	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0x3d2b5da0	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d4d7ff8	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0x3d4f512c	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0x3daccfd7	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3dc16e1e	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x3dc526a9	arizona_of_match
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3dd4d3a7	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x3de305fb	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0x3de6b8e3	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3e15643d	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x3e18a5fc	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x3e1f72e0	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL vmlinux 0x3e2d6df3	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3e2fdb08	kvm_io_bus_write
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e65cf5d	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e757637	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0x3e9682d1	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x3eaa1de9	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x3eb46518	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0x3eca8b51	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x3ee71259	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0x3ef28d44	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3efb396c	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x3f017493	rio_mport_get_efb
++EXPORT_SYMBOL_GPL vmlinux 0x3f1cb321	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0x3f24f93e	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x3f31c33f	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0x3f4a12e9	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3f5930aa	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3f59ebf8	clk_register_divider_table
++EXPORT_SYMBOL_GPL vmlinux 0x3f64ad6c	input_class
++EXPORT_SYMBOL_GPL vmlinux 0x3f756df7	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x3f832d27	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0x3f855fd2	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0x3fa5af9c	nd_cmd_bus_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3fbae91d	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0x3fc0c892	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x3fc91e31	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x3fd1ea26	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0x3fdbb8e5	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0x40050da8	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0x40271b26	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0x403af96e	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x40529458	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x407c6f0c	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x40adafcc	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40af4740	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x40b73ecf	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0x40c9985e	gfn_to_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x40ca3da5	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40eb1bbc	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x40fc9dbc	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x412aea1e	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x414edc24	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x415b6f4a	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x41607e1d	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0x41657320	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0x417fe1ca	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x41c53cb1	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x41c95608	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x41e2a68d	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0x4205ad24	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x4207ebae	rio_unlock_device
++EXPORT_SYMBOL_GPL vmlinux 0x42109c30	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x4212f4a8	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0x424840d1	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x4263ded4	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0x426b2c92	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x427a066b	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0x427adc8c	kvmppc_handle_store
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42981381	rio_register_scan
++EXPORT_SYMBOL_GPL vmlinux 0x4298468b	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x42a2d75c	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0x42ce5e07	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0x42d12a47	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x42e33a9a	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x42e5533a	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0x42e7a533	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x4313f6a0	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x4318e5e4	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0x431c44eb	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x4320d065	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x4326595f	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x433cf239	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0x43476e6c	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4347e463	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0x434e564b	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0x43550d57	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0x43619e1a	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x4373ed40	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0x438e84a1	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x43969dbe	rh_alloc_fixed
++EXPORT_SYMBOL_GPL vmlinux 0x4397ff84	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43b466b0	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x43b4e450	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x43baff4b	clk_register_gpio_gate
++EXPORT_SYMBOL_GPL vmlinux 0x43c4a44e	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43e15719	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x43f81957	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x43f9ec17	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0x43fbdec7	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x4407be5e	rio_mport_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x44471e65	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x44703a52	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x447658b7	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x44a879e0	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44de60ae	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0x453dbe6d	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0x4560221c	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x4570b92e	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x457bbca1	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x458071b8	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x458b30e8	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x45a37827	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x45b14972	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0x45b536c7	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x45b7cb65	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45ce0079	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x45feee1a	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0x46006960	flush_fp_to_thread
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x46106e2b	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x4633ccda	of_irq_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x4635bdc9	gfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x463e2d62	clk_hw_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x4654018d	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0x46661bda	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x468231e1	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x4688c96a	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x469d4227	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x469da347	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0x469e9d0b	kvm_vcpu_read_guest
++EXPORT_SYMBOL_GPL vmlinux 0x46c83a6b	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0x46da3657	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x46e2f156	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0x47023673	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x4707e55b	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0x471540d8	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x473e2001	of_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x476f5ff3	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x47793358	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0x47805f76	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x4787ade7	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x478895e0	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x4794fadf	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0x479f74ef	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47da6c86	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x47de0dc7	clk_unregister_mux
++EXPORT_SYMBOL_GPL vmlinux 0x47dfe882	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0x47e0d76b	rio_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0x47e92e17	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x480a9276	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x480fffe3	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0x48225e84	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x48270ee6	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0x48312cdd	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0x4851c0a4	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0x4854f48b	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL vmlinux 0x4862bd8c	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x48861a06	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x4886b71e	of_platform_populate
++EXPORT_SYMBOL_GPL vmlinux 0x48952d4b	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x489fbbe4	mpc8xxx_spi_rx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0x48b6a351	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0x48cc431a	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x48f25db3	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x48fd7719	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x4908e391	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x490ff388	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4938a50a	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0x497d6211	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x4982a57f	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x4986b8fa	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x49b34f4e	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x49c65da2	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0x49e77960	rio_request_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x49e9b83b	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x49ee4d1e	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0x4a1f5cff	of_reserved_mem_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x4a2666e9	kvm_release_page_clean
++EXPORT_SYMBOL_GPL vmlinux 0x4a448d05	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x4a455b3a	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x4a46de2a	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a74ba60	of_clk_src_onecell_get
++EXPORT_SYMBOL_GPL vmlinux 0x4aa888e4	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4ac178b0	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x4ad5335a	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x4af27456	of_pci_msi_chip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4b0ffa53	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x4b23b14c	to_of_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x4b78bb3a	rio_lock_device
++EXPORT_SYMBOL_GPL vmlinux 0x4b89bb5c	clk_gpio_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0x4b907e54	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x4b954d34	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0x4b98827c	rh_init
++EXPORT_SYMBOL_GPL vmlinux 0x4b9ff680	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0x4ba58f19	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x4bf9aaca	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0x4c06b6f6	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x4c088f71	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x4c48040f	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c6470e1	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0x4c69c405	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0x4c6cb664	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4c8a70e3	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0x4c9e55e9	nd_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x4ca45896	kvmppc_handle_load
++EXPORT_SYMBOL_GPL vmlinux 0x4cb82b8b	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x4cc7eae0	of_irq_get_byname
++EXPORT_SYMBOL_GPL vmlinux 0x4ccb376b	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x4ccfedac	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x4cd33ccf	rio_enable_rx_tx_port
++EXPORT_SYMBOL_GPL vmlinux 0x4cdaa692	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4cf200e5	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d2dc76a	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x4d2e402c	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0x4d45e8c1	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x4d5546c9	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x4d624cec	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x4d6455e7	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x4d7902b6	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x4d7c8004	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x4daee45f	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x4db88524	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x4dbdc762	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x4dc2e2bb	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x4dcb78ed	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4de7fe81	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4df4dd4b	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e241cfd	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e2c2dd2	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x4e2fcdfd	dev_pm_opp_of_add_table
++EXPORT_SYMBOL_GPL vmlinux 0x4e335f46	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4e70b004	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x4ea040c7	rio_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x4eaa3318	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x4eb7e418	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x4ebe035a	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0x4ec8354d	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x4ed9331e	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4ed9e99b	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x4edb4be4	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x4ee902c8	rio_request_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x4eedd4e0	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f146011	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x4f1615f4	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x4f183fb9	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f45238a	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4f4bf92c	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x4f5c49ad	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4fa00d3f	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x4fb4dbb4	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4fe50dc1	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0x4ff25415	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0x500a05ee	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0x500fb8d0	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x5037b15f	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x503b62d5	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x503dd23e	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0x504b4fa7	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0x505786c5	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x506dd6ee	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x507596d8	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x50791005	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x50938a2d	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0x50998378	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0x50c82b44	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x50c89f23	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x50dbe5f1	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x50df5476	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x510ed41a	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x5113cc2e	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x51278df5	kvm_get_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x5142db14	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0x51467922	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x514e9875	divider_get_val
++EXPORT_SYMBOL_GPL vmlinux 0x514f2831	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x516961fd	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL vmlinux 0x51719489	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x51966b51	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0x519b8653	of_dma_get_range
++EXPORT_SYMBOL_GPL vmlinux 0x51b65a26	rtc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x51ccfc22	rio_route_get_entry
++EXPORT_SYMBOL_GPL vmlinux 0x51ce43c8	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0x51deea62	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x522b607b	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x522fe15c	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0x5248eb79	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0x525bd9c7	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0x525e42db	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x526e7071	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x527c5049	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x52924f20	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x52a3e412	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x52a5cf97	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0x52a85e92	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x52e270e0	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x52ec3bf4	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x5303c04b	fsl8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x530d29de	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x53337caa	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x5335dd11	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x536a4065	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x536d2489	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x536f90eb	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x5382ba46	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x539add6f	rio_register_mport
++EXPORT_SYMBOL_GPL vmlinux 0x53b6ed0f	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0x53c4c7c0	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0x53fc5668	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x5406c04e	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x540b5fa6	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x54181b34	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x54296231	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x54571f7b	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x546c5565	ppc_tb_freq
++EXPORT_SYMBOL_GPL vmlinux 0x546f2b22	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x5471cf9b	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x547f3ea9	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x548e00ad	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54a5ec00	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x54b1ead9	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x54d468f1	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x54d8ac27	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x54db2f6e	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x54eb4e82	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x54fc2626	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0x5510c15b	rio_mport_class
++EXPORT_SYMBOL_GPL vmlinux 0x5511bc0d	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x55125bc4	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0x551cf728	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5546fc27	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x554ea08b	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x5552c005	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x555c9f8d	clk_debugfs_add_file
++EXPORT_SYMBOL_GPL vmlinux 0x55622489	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x556b4373	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x556e4390	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x556fe8b7	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x5575a997	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x558e2bb7	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0x559988f1	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x559c6e44	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0x55a9aaf6	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x55d0a1b6	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x55f0c2af	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0x55f51ef3	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0x56056a36	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0x560899bc	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x56099fb6	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x564a7a3a	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x567529b9	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x5680b4ff	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x569a0d2f	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0x56ae47fc	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x56b63670	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56d81ad8	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0x56de4ce6	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0x56de71d7	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56eb07c9	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x56eea921	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x5718b413	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x5759c1c5	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x575e2818	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x576f75df	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57bd5e92	nvdimm_bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5805451b	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0x5807edbe	__rio_local_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x581a3ebc	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x584030a9	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x58459d12	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x58538b65	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x5892f832	release_pmc_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58a0836c	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0x58a44320	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x58a89430	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x58dffa69	rio_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x58ea42d5	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x58f27514	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0x58fe9409	rio_inb_pwrite_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5904ae58	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x5938cede	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x593b0a50	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x594996ef	kvm_get_dirty_log
++EXPORT_SYMBOL_GPL vmlinux 0x594ce360	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0x594e951b	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x596eeded	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x59902da9	of_device_get_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x59b574e0	dev_pm_opp_init_cpufreq_table
++EXPORT_SYMBOL_GPL vmlinux 0x59d3fc95	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x5a159919	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x5a5ad44f	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x5a65c37b	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x5a71f862	agp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a82619b	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x5a940f3a	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x5aa003f9	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x5aae86e2	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x5ac77c3f	kvm_write_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x5ac8f94d	kvm_vcpu_mark_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x5b30ae2c	rio_request_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0x5b58a6ac	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x5b5f5245	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL vmlinux 0x5b7d058c	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x5b8ad633	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5bed0bc5	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0x5bf30ec3	rio_local_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x5bf8dbe9	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x5c10daba	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x5c17cca4	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c617f04	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0x5c67dc4e	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0x5c8103ab	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x5c81b59f	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x5c854c6b	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x5c8e4cf5	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x5ca49328	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0x5ca4d8a3	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cc12829	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5cebf572	rio_mport_send_doorbell
++EXPORT_SYMBOL_GPL vmlinux 0x5d08d3f9	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d25a708	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x5d2df6ba	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x5d4c6ed8	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x5d5be7c6	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0x5d863e50	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x5d9425cb	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x5da26793	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x5da3121d	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5dd3c0ad	gfn_to_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x5dd98c0c	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x5ddbe65e	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0x5df21f8d	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x5df71cd4	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x5dff6fda	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x5e0b8b97	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5e11c4ab	nd_device_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x5e44225d	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x5e4bb456	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x5e515be6	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5edbbe74	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0x5ee6ee92	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x5efed88a	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x5f01e25d	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x5f5b2c2c	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x5f5eded9	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0x5f88aa97	dev_pm_opp_find_freq_ceil
++EXPORT_SYMBOL_GPL vmlinux 0x5f9debab	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x5fc8cec5	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x5fe2aff5	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0x5feecf63	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0x60076255	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x60091316	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x6035b78e	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x603d078d	dev_pm_opp_enable
++EXPORT_SYMBOL_GPL vmlinux 0x603fede6	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x60662bd7	power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x60927ee7	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60a275fe	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x60a38940	rio_unmap_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x61086eb1	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0x613b44e5	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0x61502e46	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x6150f2a5	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0x615632a0	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x618c8fd6	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0x6197edd0	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x61a4c9b4	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x61a90c54	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x61bbaf4f	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x61c62e6e	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0x61c7ff35	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x61d078fb	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x61d0e585	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x61dea6b5	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x61eebd4e	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x62086848	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x62104fd0	dev_pm_opp_of_remove_table
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x623f32ff	of_get_nand_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0x6263f0f4	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x626a6fa2	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x62827c2f	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0x629d04cd	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0x62b8df27	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0x62d59c9e	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0x63150e06	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x631ed28e	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x632accb4	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0x632b16be	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x632ef701	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0x63304e8b	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x6359b1c9	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x635c2e43	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x6362a239	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6382df9e	__nvdimm_bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x638ea54d	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0x638f739b	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x63cca1cf	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0x63e17b86	divider_recalc_rate
++EXPORT_SYMBOL_GPL vmlinux 0x64052fe2	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x640b07eb	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x640da889	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x6412af09	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x6416d7d2	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0x641e9b73	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0x64256424	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0x6428da4f	rh_attach_region
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x644902aa	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x6451b45e	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x64559654	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x645adbec	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0x645d9448	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0x6469ad71	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0x64717e49	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x6476c24f	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x6486fe2e	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x649ee2d8	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x64a70cfc	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x64aee960	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x64e24a5e	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x64f53299	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x6502765b	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x65044317	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x650f0161	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x65181427	rio_request_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x651a2900	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x652ee3de	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x652f10ea	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x6566d770	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x65690cde	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0x6590d3c9	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x65946489	nvdimm_blk_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x65b46d9d	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65d7bba4	of_dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x65e8d1a5	mark_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x65fc2974	kvm_vcpu_gfn_to_hva
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x66574cad	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x66601bc5	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0x667d393e	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x66afb53b	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66d9d6d8	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0x66e73c93	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x6749405d	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x67503b04	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6771cb12	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x67a4ae23	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0x67c615d1	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x67cc05a4	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x682e6bb0	hugetlb_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x6832083e	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0x68340017	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x684794c6	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x68493cdb	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0x685d43e1	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x686e64db	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0x687b3226	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x68821297	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x6894d184	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x68956406	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x68db51bf	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0x68facb10	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0x691bab0d	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x6937ff42	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0x69433c6b	nvdimm_create
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x6945725e	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0x694e4679	nvdimm_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x6979d974	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x697cbbb4	threads_per_core
++EXPORT_SYMBOL_GPL vmlinux 0x69860fd1	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x69ab121d	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x69cc7a5b	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0x69d182bb	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0x69ee2e06	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0x6a05a04f	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6a33d31b	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x6a3b1520	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x6a3f7db4	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a68a010	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a85843a	of_dma_is_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x6ab3781f	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x6aef7e15	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x6af3429c	of_irq_parse_and_map_pci
++EXPORT_SYMBOL_GPL vmlinux 0x6af78170	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x6b1d09f4	clk_hw_get_parent_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b2df735	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x6b3073ad	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x6b36d341	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x6b48a910	switch_booke_debug_regs
++EXPORT_SYMBOL_GPL vmlinux 0x6b4c6b36	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6b53123c	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6b9240f7	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x6b9f4eb2	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0x6ba45308	rio_map_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0x6babf2bf	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0x6be822ef	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x6bf04ad9	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c0a9f67	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0x6c209eab	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x6c2d5470	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c67cbee	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x6c6c2c7d	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0x6c7932c6	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cb271e5	pcibios_free_controller_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x6cca0286	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6cd76aad	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d309a54	to_nvdimm_bus
++EXPORT_SYMBOL_GPL vmlinux 0x6d43f2d2	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x6d4afa5c	rio_dma_prep_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x6d5fa811	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x6d74237c	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x6d878845	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0x6dac0acb	hugetlb_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x6dc9553c	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x6de20b5b	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e51afc8	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x6e5311e3	of_fixed_factor_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0x6e6bc173	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6ea5b056	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6eb09a46	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x6ed918e9	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x6eed1f7b	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x6ef8c577	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0x6f13f8bd	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f29eb02	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x6f685671	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0x6f6d83ca	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6f8ba03e	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x6f8dab0a	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6f94b3c0	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x6fa4c24c	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0x6fb72258	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x6ff76cd1	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x70344986	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x70406cb7	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x7044adda	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0x7045dc1a	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x705ac0cd	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x70772331	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x70858f25	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x7089d408	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x70a032c2	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x70ae3eff	of_pci_range_parser_one
++EXPORT_SYMBOL_GPL vmlinux 0x70b5a87a	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70c7e27b	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0x70cc96c4	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70fbd39d	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x711d62cd	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x7120eabb	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x712751e3	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x7128f9cb	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0x712dde0c	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x7166ab60	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x717188cc	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0x7177ae19	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x71989280	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x719e17ff	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x71a770d8	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x71c7940a	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71e088f1	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0x71ea83cf	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x71f4246d	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x71fed21f	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0x720ff1d1	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0x72149622	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x7215a821	of_pci_range_parser_init
++EXPORT_SYMBOL_GPL vmlinux 0x721b2c42	kvm_vcpu_init
++EXPORT_SYMBOL_GPL vmlinux 0x721e5c6a	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x72204678	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x7223042a	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x7228a96a	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x722db225	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0x72369c0a	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x723e6fee	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x72515d5a	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x7263be5b	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x7265a8a5	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0x7272b9fd	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x72b4e852	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0x72c7da98	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x72e9686a	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0x7319e51f	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x73230542	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0x7330e14b	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x7330f351	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0x73549a5e	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x737d013c	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x73a3c074	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73b4eb61	device_register
++EXPORT_SYMBOL_GPL vmlinux 0x73b77274	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0x73b98231	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73dbabdc	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x73e640a8	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x73f22f99	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x740563ee	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x7434873c	clk_hw_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x744811af	clk_register_fixed_rate_with_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x74523236	to_nd_desc
++EXPORT_SYMBOL_GPL vmlinux 0x745e9605	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7468b74e	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0x746e7604	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0x74858423	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74d007c2	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x74d3afc3	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0x74de8b11	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x74f9a185	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x74f9be86	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x75329035	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0x75465c76	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0x75629804	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0x7576fb5c	nvdimm_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x757a86c5	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x758dece6	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x759139cb	of_pci_check_probe_only
++EXPORT_SYMBOL_GPL vmlinux 0x75969459	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0x75a1a3ed	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0x75c2b9f1	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x75c6065c	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0x75c9d8c3	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75ce0d7c	of_fixed_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0x75d979e7	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x75d9ff39	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0x75eaf137	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0x75f2a044	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x75fb045a	of_reserved_mem_device_release
++EXPORT_SYMBOL_GPL vmlinux 0x761ed6ec	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x762c0858	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0x763247c1	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x763b6f41	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x764a301e	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x764cea49	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x768a6e7e	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0x76a52d18	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x76aa879d	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x76b13828	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x76cac824	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x76d9b876	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0x76ed09a4	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x76fe74d3	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0x77062a7a	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x770ce718	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x770cf981	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x77221f7c	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x7730474a	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0x77361599	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x7757b51a	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x775a6e1e	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0x7780c2fa	kvm_vcpu_write_guest
++EXPORT_SYMBOL_GPL vmlinux 0x77849177	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x778d70b3	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x77a38860	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0x77a42f4b	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x77b0675b	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x77c4a3ff	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0x77d00656	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0x77d73615	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0x7811d6e7	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x78151326	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x7820c45c	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x785cf1c3	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x788615a6	clk_register_fixed_factor
++EXPORT_SYMBOL_GPL vmlinux 0x789d410b	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78c5e058	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x78fe2616	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0x792eb63e	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x796e0a7b	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0x796e76c4	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x7992f4f5	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x79a6cbab	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0x79a7c58e	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x79b12645	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x79b94488	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x79c480da	rh_dump
++EXPORT_SYMBOL_GPL vmlinux 0x79cd2243	of_get_fb_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x79cfb499	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0x79d13779	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x79dc2b5b	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x79fbc74b	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0x7a29e5f0	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a376494	kvm_read_guest_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x7a486133	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x7a6dbef3	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x7a7806bc	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0x7a8235e5	of_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x7a856265	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x7a8ce663	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL vmlinux 0x7ab3ca18	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x7ab652b1	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x7ac2636b	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0x7ac485a8	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0x7ac99aa8	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b60f9f5	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0x7b7a63e4	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7b7e4b3b	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x7b843038	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x7bada63b	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x7bc7fdd7	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x7bd5875d	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x7bd6e779	kvm_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x7bffedd9	of_cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x7c549b8b	kvm_vcpu_read_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x7c7c81f2	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0x7c962770	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0x7c9a7371	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cf19c71	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x7cfaf403	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7d00c65b	nd_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x7d26d659	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d5f9ee4	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x7d73bf7c	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x7d8dad91	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7d93c1d8	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7db01b24	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x7dbe80ce	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x7dc1e388	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0x7dd12fac	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x7dd3d17a	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x7dd97cfe	of_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7dff171c	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x7e04c907	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x7e17ba7b	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x7e469950	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0x7e49d6b7	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e782b62	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7ebd4eb0	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x7ec98ce5	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7edebeff	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0x7ef854c5	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x7f008202	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f286a84	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0x7f2c1657	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7f4e70f3	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x7f6d0198	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x7f7bc710	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7fe052e6	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0x7ff60f4f	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8001526f	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x80064f4a	dummy_con
++EXPORT_SYMBOL_GPL vmlinux 0x80115bad	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x80281e2c	phy_pm_runtime_put
++EXPORT_SYMBOL_GPL vmlinux 0x803bc2ca	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x80761247	nd_cmd_in_size
++EXPORT_SYMBOL_GPL vmlinux 0x80787912	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x80a37dbe	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x80b3e566	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80e1c549	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x80e5792d	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x80ee3e6b	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x812891dc	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x8128aba7	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x815588a6	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x816a55b6	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0x81749701	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x81abe698	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x81c3aaee	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0x81d5156a	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x81e70a82	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x81eb8d8c	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x81edc2cd	kvmppc_emulate_mmio
++EXPORT_SYMBOL_GPL vmlinux 0x82028b95	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x820cdf3f	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x821ebcf7	fsl_spi_cpm_bufs_complete
++EXPORT_SYMBOL_GPL vmlinux 0x822ad4c7	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0x82330cd5	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x8257cc22	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0x82869163	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0x82a365e9	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0x82ab1bad	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0x82c52bea	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0x82c920f2	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82d89dce	cpu_add_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0x82f2eb3f	of_overlay_create
++EXPORT_SYMBOL_GPL vmlinux 0x8327dd59	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0x8337b9b5	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0x8347949d	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0x83555774	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0x835b2ac5	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x83661ced	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x836d61d0	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x836de55d	isa_bridge_pcidev
++EXPORT_SYMBOL_GPL vmlinux 0x837fe4d8	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x838faccd	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x83a05b3e	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x83a18ac7	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0x83a2f2ff	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0x83c19c1f	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x83cc2813	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x83e53062	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0x83ea1f53	of_platform_depopulate
++EXPORT_SYMBOL_GPL vmlinux 0x83eabaa4	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0x841da239	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x84377cf9	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x8452961f	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0x845caa43	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x845fe240	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0x8464205e	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x84843f40	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x8490116d	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x8506baa8	clk_unregister_gate
++EXPORT_SYMBOL_GPL vmlinux 0x850df8b9	clk_divider_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x853ecf72	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0x85657d4b	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0x857146fd	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x8574ca6c	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x857967a3	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0x85798f61	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0x858737ec	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x8587852d	rio_mport_chk_dev_access
++EXPORT_SYMBOL_GPL vmlinux 0x858b5471	clk_register_divider
++EXPORT_SYMBOL_GPL vmlinux 0x858e87f5	rio_mport_get_physefb
++EXPORT_SYMBOL_GPL vmlinux 0x8591791f	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x85a7894c	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x85c5bead	devm_power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85ce9c98	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x85d58ed7	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0x860bba10	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0x8610154d	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8636e91c	of_mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x863726ef	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0x863864de	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x86432dad	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0x86465335	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x86489884	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x864bd332	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0x8652110e	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0x86613fda	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0x86656b8f	dev_pm_opp_get_opp_count
++EXPORT_SYMBOL_GPL vmlinux 0x866a841b	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0x86738fb4	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x867d5ebf	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0x8684362c	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x8691147e	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0x86c342b3	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0x86c57129	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0x86cdfe76	fsl_spi_cpm_reinit_txrx
++EXPORT_SYMBOL_GPL vmlinux 0x86d1898e	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x86d6de91	mpic_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x86e175fa	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x86e342e2	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x86fdc402	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x870b385e	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0x871d02ee	rio_mport_get_feature
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x87447e1e	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x8749930d	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x87671f37	__clk_get_hw
++EXPORT_SYMBOL_GPL vmlinux 0x878e44a3	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x87be3a8e	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x87d3835d	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x87ed50ca	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x8804af3d	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x8843ae97	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8854130a	of_clk_del_provider
++EXPORT_SYMBOL_GPL vmlinux 0x887dca3a	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0x88824f09	of_property_count_elems_of_size
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88abb487	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88bb1eac	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0x88bca795	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x88fc345c	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x891e785e	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x89458528	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x89490f0f	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x896f0a81	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x897ac439	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x89a927ac	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x89b37637	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89cc1c8a	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x89e22d3b	__clk_mux_determine_rate_closest
++EXPORT_SYMBOL_GPL vmlinux 0x8a023da8	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8a2508d4	thermal_zone_of_sensor_register
++EXPORT_SYMBOL_GPL vmlinux 0x8a554a36	mpc8xxx_spi_strmode
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a5f86ce	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x8aa59750	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0x8aad05b3	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8abadcdd	kvmppc_sanity_check
++EXPORT_SYMBOL_GPL vmlinux 0x8abea573	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0x8aded8de	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x8b0ead42	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x8b149c36	clk_is_match
++EXPORT_SYMBOL_GPL vmlinux 0x8b46e270	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x8b548840	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x8b6791b9	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x8b70e8ea	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x8b710c9b	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8b91f7a7	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x8b97896a	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0x8bb7a8e6	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x8bf45080	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8bf4d4b7	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c1f4bd2	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x8c42bd6a	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8cc90b6e	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0x8ccc645c	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8ce547d8	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x8cf037f2	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0x8cf45e51	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x8d1a9adf	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0x8d3e183a	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8d3f7acf	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0x8d4d23be	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0x8d4f1d55	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0x8d6d459b	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8d6f42f9	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x8d7172fc	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x8d80b9d9	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0x8d8261e4	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d9c0742	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL vmlinux 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x8dab4462	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0x8ddd6452	dev_pm_opp_find_freq_exact
++EXPORT_SYMBOL_GPL vmlinux 0x8dec856b	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0x8dfd5821	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x8e0f7558	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0x8e1034f0	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x8e13ed25	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x8e1674b8	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x8e191bc4	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL vmlinux 0x8e257573	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0x8e26ac49	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x8e2b25c2	videomode_from_timings
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e337909	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0x8e36b48a	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x8e4e6955	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x8ea15d14	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0x8ecdfb32	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x8ee84aa8	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f17d350	of_clk_parent_fill
++EXPORT_SYMBOL_GPL vmlinux 0x8f4bc27d	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f77cdbe	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0x8f7ae31d	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0x8f7ce655	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x8f7cf125	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x8f8972bd	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0x8f9658ae	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0x8f9a3304	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x8fa08737	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x8fa19d9b	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8fbc00ec	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x8fced602	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0x8ff1cb72	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0x8ffa8f8c	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x901fbf66	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0x9022d5bc	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x9025cbe7	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x90666f3d	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x9077d5ea	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90a14876	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x90b8875c	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0x90ba5109	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0x90e0c466	of_dma_router_register
++EXPORT_SYMBOL_GPL vmlinux 0x90f6d3c4	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0x911d4d03	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0x91363574	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x913bd4ab	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x913d95d5	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x9147d4dd	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x915ab143	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x9160091b	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x9190aee0	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0x91abfb31	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x91b33c12	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0x91bbb295	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91cef70d	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x91ffbefb	early_find_capability
++EXPORT_SYMBOL_GPL vmlinux 0x92259a55	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0x923372d5	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x92702c25	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x92866852	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0x92af3ad7	to_nd_region
++EXPORT_SYMBOL_GPL vmlinux 0x92b57248	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x92bb2e45	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92f6e4b6	__ktime_divns
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x93263ce2	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x933db6e2	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0x9340e417	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0x93467bcd	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9349ce64	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x935519ce	clk_multiplier_ops
++EXPORT_SYMBOL_GPL vmlinux 0x93668aba	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x938177ce	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x93a2cb47	reserve_pmc_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x93bf2fcd	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x93d79bd2	of_clk_add_provider
++EXPORT_SYMBOL_GPL vmlinux 0x93fe613d	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0x94012a0a	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x9401c176	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x940df19b	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0x94144234	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x941d315f	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x942ef75b	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0x942fe9c4	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x9432b036	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x943a14d8	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x949bf396	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x94abb745	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0x94ce66f4	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x952faf63	fsl_spi_cpm_bufs
++EXPORT_SYMBOL_GPL vmlinux 0x953d59a2	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x953fd479	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x95523d7f	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x956c6d15	of_reconfig_get_state_change
++EXPORT_SYMBOL_GPL vmlinux 0x958dbfdb	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x95a577f4	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x95a57a75	of_devfreq_cooling_register_power
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95ec5d8c	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x962517b1	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x96275598	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0x962adadd	kvm_vcpu_gfn_to_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x962bba53	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x962e4b13	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x9633c45b	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x964db2f0	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9655b911	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x965cecac	rio_request_mport_dma
++EXPORT_SYMBOL_GPL vmlinux 0x9660da55	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0x96645b10	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0x96b67432	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x97084c3e	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0x9739f49f	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x973b8917	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x974f11f9	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x975d7245	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x9767d300	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x9773a091	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x977542b2	dev_pm_opp_free_cpufreq_table
++EXPORT_SYMBOL_GPL vmlinux 0x97799c61	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x977b0659	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0x97856454	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x978ffa8a	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x97a0a69f	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x97d697af	nd_blk_region_set_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x97dc3075	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x982cd486	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x9835aa9f	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0x983c7494	rh_detach_region
++EXPORT_SYMBOL_GPL vmlinux 0x9840437c	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0x9847df1d	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x989eb047	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98faf97e	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x9909f759	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x992dc7ca	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x993e7a67	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x99731420	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x997fd8cd	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x998652ed	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0x9986904e	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0x998d7958	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0x998d8d61	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x99a9ff9a	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99ce0592	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x99cf5ce2	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x99d19fa4	kvm_init
++EXPORT_SYMBOL_GPL vmlinux 0x99dba068	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x99e3f9cb	of_get_regulator_init_data
++EXPORT_SYMBOL_GPL vmlinux 0x99e5a21a	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a1c1d16	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0x9a1c9851	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0x9a49d937	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0x9a663b6c	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9aad6540	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x9ac58acc	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x9ad16f3b	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9afb0df5	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x9b122fe7	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9b23535c	dev_pm_opp_set_sharing_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x9b2a62c6	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x9b511ffa	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x9b572a99	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x9b7c1c13	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x9bdfabed	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x9be233d5	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9bf2df14	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0x9c0574a6	__rio_local_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x9c0c7477	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0x9c162149	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x9c1e6b74	kvm_vcpu_block
++EXPORT_SYMBOL_GPL vmlinux 0x9c23bba6	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0x9c8b5a09	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0x9c8b9bab	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0x9ca806cf	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0x9cb1667d	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cce761e	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9cd7f705	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0x9cd8b6d9	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x9d0c93be	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x9d0ee2f8	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0x9d1be01b	rio_release_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x9d265351	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0x9d4e02d4	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0x9d722926	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0x9d73e4b7	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x9d7607f5	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x9d8331c0	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x9d845427	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x9d9acb03	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9dbe9c96	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0x9de51041	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x9df5f1d5	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x9dfdf722	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e8cd3ba	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9eaef33a	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9f07cbde	fsl_rio_mcheck_exception
++EXPORT_SYMBOL_GPL vmlinux 0x9f2f4db1	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0x9f351245	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0x9f3c1760	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x9f3ffcb2	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0x9f6f3f73	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9f96aa09	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0x9f9eff6a	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x9f9fed55	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9fac90ea	of_regulator_match
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0xa00864c4	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0xa01dc3f9	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0xa0208e02	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xa02360b7	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xa02786a7	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0xa0456812	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0xa064fb7e	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xa06c3e64	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0xa071e996	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xa07246f0	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa0a27fff	pci_address_to_pio
++EXPORT_SYMBOL_GPL vmlinux 0xa0b4d300	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0xa0e85e2e	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0xa0e9838e	rio_release_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xa0f5fdd4	rio_mport_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xa0f96ac0	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0xa10b1174	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa10cf111	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa111ca3b	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xa11a9e05	rio_mport_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xa127fa53	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xa13cc977	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0xa13d495f	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xa16a033a	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0xa175605e	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa19989ec	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0xa1bb1134	of_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xa2300d65	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0xa2364ded	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa24dd48f	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0xa259fdc9	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa287d979	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0xa2880efc	pcibios_free_controller
++EXPORT_SYMBOL_GPL vmlinux 0xa28aaf29	rh_create
++EXPORT_SYMBOL_GPL vmlinux 0xa29c1990	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2dbaec1	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0xa2e6c1e1	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0xa2e8a56a	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa30f9505	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0xa32fc4fd	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xa3425bd0	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0xa346820e	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa35bc064	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0xa36baf0d	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0xa36ebf8a	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa38a0a84	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3a2d9af	walk_system_ram_range
++EXPORT_SYMBOL_GPL vmlinux 0xa3b25246	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3c00a72	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0xa3c8e87e	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xa3cc6d9f	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0xa3deb765	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0xa3e600d8	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa415f6dd	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa416763b	of_property_read_u32_index
++EXPORT_SYMBOL_GPL vmlinux 0xa4170362	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0xa41fd1e4	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xa438418a	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa45b094c	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0xa463e885	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0xa46e8346	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa49264e7	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xa492dc5d	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xa4a3c3aa	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0xa4b058d7	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa4c2a3ec	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xa4d1dbb1	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0xa50e00e1	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0xa50f6fa1	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa52b1fb6	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0xa547543e	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0xa54cb5ad	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0xa54e6e71	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0xa551887e	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0xa5833897	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa59d83c3	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0xa5b00659	ppc_proc_freq
++EXPORT_SYMBOL_GPL vmlinux 0xa5ca40a7	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xa5cbee21	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5efe460	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xa615a361	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0xa615e531	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0xa617f46d	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa63ce2c0	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xa64c1b24	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0xa684e074	rio_release_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6d42c31	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xa6dd08c9	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa7037774	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0xa726c46f	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0xa7299333	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0xa7333179	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0xa73b97c4	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xa73c3733	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0xa74e220b	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0xa763ba0e	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xa77c45ed	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0xa79d09e8	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0xa7a2dd95	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0xa7bd7f23	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0xa7c03c35	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0xa7d5302f	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0xa7d9457f	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0xa817957e	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa86ec636	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xa8a0e504	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa8a8e6c8	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa8adea51	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8dd6c14	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0xa8f5e24f	dev_pm_opp_disable
++EXPORT_SYMBOL_GPL vmlinux 0xa8f68b3d	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xa8f9d68d	kvm_put_kvm
++EXPORT_SYMBOL_GPL vmlinux 0xa90c4e73	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0xa91603b1	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xa92388c5	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa957a11e	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0xa973a7a2	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0xa9928dd4	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0xa9a92c94	dev_pm_opp_is_turbo
++EXPORT_SYMBOL_GPL vmlinux 0xa9aef2e1	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL vmlinux 0xa9afca57	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xa9bcd78e	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0xa9d32b23	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9e95321	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0xa9f26a5e	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xaa095804	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0xaa17a2e2	rh_alloc_align
++EXPORT_SYMBOL_GPL vmlinux 0xaa2a72bf	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0xaa6f4ba9	rio_release_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xaa80c554	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaadc0a7a	kvmppc_prepare_to_enter
++EXPORT_SYMBOL_GPL vmlinux 0xaafe8ad1	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xab29ad96	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0xab2f123a	kvm_vcpu_write_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xab3f8b07	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0xab593659	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0xab59d373	kvmppc_free_lpid
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab5f28fd	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab84216d	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0xab945a16	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xabaa69fe	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xabadc92d	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabd3d40c	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0xabf48df9	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xac1e20c7	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0xac1eb506	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0xac20c629	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0xac2fd46f	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xac6b03e5	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0xac6edc94	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0xac994875	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xacaf38cd	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xacb5da82	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0xacb96b35	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xacce904c	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0xace10793	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xace8d918	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0xacf0f18d	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0xacf8ded5	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0xacfb36b1	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0xad1485f0	fsl_spi_cpm_free
++EXPORT_SYMBOL_GPL vmlinux 0xad532f51	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xad64cca0	device_del
++EXPORT_SYMBOL_GPL vmlinux 0xad6eb19b	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xad73b1b0	of_gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xad8e3693	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0xada37a8f	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadd53aa5	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xadf6cc1a	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0xae20c8a4	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae81922b	of_overlay_destroy_all
++EXPORT_SYMBOL_GPL vmlinux 0xaea2fda5	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0xaebbb7d4	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0xaec93c0c	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0xaed6886a	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xaedb51ae	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0xaef545b9	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xaf5d6862	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xaf67ee0f	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0xafa69aed	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xafaba70a	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0xafabea38	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0xafbe0359	arizona_of_get_named_gpio
++EXPORT_SYMBOL_GPL vmlinux 0xafd76f72	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0xafdc93e3	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0xafec59e4	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0xb0059238	rio_release_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xb0060154	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0xb0209286	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb048073d	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0xb056052b	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0xb060b3aa	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xb060e9fb	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0xb077e70a	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xb07bfc15	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xb07c7f7a	of_usb_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xb090cb0c	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0xb0913148	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xb09a4ef1	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0xb09eea31	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xb0b1b328	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xb0b61dfc	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0ec4aa9	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xb1080e22	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb17ed4f5	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb18a17d2	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xb18ca123	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0xb18d1633	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0xb18d2a6d	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0xb1943652	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xb1a3ce96	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xb1a64079	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1baecf0	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xb1bc9807	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1c1b6e6	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0xb1c6d4c2	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb21ff02e	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb2256567	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0xb244f77f	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xb2999682	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xb2a25363	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0xb2c42e0f	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xb2c72857	nvdimm_bus_check_dimm_count
++EXPORT_SYMBOL_GPL vmlinux 0xb2f87ffd	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0xb2f9c95a	generic_access_phys
++EXPORT_SYMBOL_GPL vmlinux 0xb3097ab1	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0xb31cb48d	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xb353cb6d	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xb363da09	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0xb3a46133	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0xb3b0022b	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0xb3b34e17	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0xb3b87ce9	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb3ca26a2	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb3cf00ec	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0xb408f245	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0xb409755d	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0xb40d8d8f	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xb41cfd12	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xb41e942f	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0xb424be0a	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0xb426ea28	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xb4380a26	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0xb43d1086	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0xb453f11e	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0xb45692d7	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xb45ba050	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0xb470aa91	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0xb4822bfd	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xb4832f56	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xb488588e	tb_to_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb4a3b715	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0xb4a55091	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xb4ad8f28	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4e4f1ef	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb4f637e7	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xb4fed9b2	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xb50b4018	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0xb51db05d	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb52c17e2	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb54d40db	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xb562dece	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0xb5747bad	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0xb5841645	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb599445a	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0xb59cf324	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5aa10af	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb5c8edf4	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0xb5d7f2d8	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xb5e4ac7b	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xb5e896fb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0xb5e9aa3b	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0xb5ee4bd8	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0xb5f00222	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb60b5707	of_i8042_aux_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb63fa319	of_pci_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0xb657e9ed	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0xb682082a	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0xb682975a	find_module
++EXPORT_SYMBOL_GPL vmlinux 0xb691037f	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0xb6a1478c	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6e6d99d	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb6eaceb1	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL vmlinux 0xb6f01164	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb7010425	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb711d130	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xb716c763	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xb7263953	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xb7329c06	clk_set_phase
++EXPORT_SYMBOL_GPL vmlinux 0xb7351227	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0xb73d0e92	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xb74ffd18	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xb74ffd91	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0xb769547b	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xb786e77d	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb7877374	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0xb79fb656	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xb7c80ceb	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0xb7ced82f	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xb7dc4835	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xb7dd8e58	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xb7ecd470	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xb7f58e1a	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb809b9ee	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xb80f02e5	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xb82beb7b	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0xb83d3777	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0xb83e2235	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb871c107	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb883206b	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb8b7d4a1	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0xb8bdb30b	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0xb8c33dc8	kvm_vcpu_gfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0xb8ca3858	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8e4e81c	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0xb8ec24b0	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xb9007143	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9014d95	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb9176155	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0xb91d92b7	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0xb92361d4	of_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xb92427b4	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb9339fbf	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0xb9431a00	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb9599d56	rio_get_asm
++EXPORT_SYMBOL_GPL vmlinux 0xb963d6f4	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xb96b3bc6	of_get_display_timings
++EXPORT_SYMBOL_GPL vmlinux 0xb96d81c3	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0xb99c4e0a	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xb9ae7475	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0xb9b40afd	of_get_videomode
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9dea956	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xb9f3af3a	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xb9f7d92d	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xba0cd21f	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0xba0fac0e	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0xba150b47	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0xba2a2270	of_thermal_get_trip_points
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba341ab6	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xba4fd098	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0xba8081a9	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xba8929ea	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbacaf340	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0xbad2be0c	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0xbadf8dbf	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xbaf6d630	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xbafb8c86	clk_fractional_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb152bee	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xbb27bd01	of_usb_update_otg_caps
++EXPORT_SYMBOL_GPL vmlinux 0xbb68910f	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0xbb735189	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xbb7cf9cb	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0xbba9c353	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xbbb66daf	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xbbcc17e1	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xbbef74bf	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0xbc1229c0	device_move
++EXPORT_SYMBOL_GPL vmlinux 0xbc18dad6	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xbc2cb5f7	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xbc337827	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xbc53cf5f	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc9dc4cd	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcb265ea	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0xbcc3968e	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xbce21d7c	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xbd0b665c	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0xbd15c90f	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xbd19d439	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0xbd1fde92	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd4daf95	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd5d7ed2	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0xbd5f9e75	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0xbd60dcf0	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xbd78ff65	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xbd8498ea	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0xbd96f3a2	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0xbd9997cb	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xbdbda716	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbde1af16	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xbde8dc00	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0xbe099dc1	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe25273b	of_devfreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe762934	kvm_flush_remote_tlbs
++EXPORT_SYMBOL_GPL vmlinux 0xbe96dfd8	of_reconfig_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbe9b3d00	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0xbea4d3bb	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbea8fd53	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0xbeb6426f	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0xbec44edb	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0xbec662bc	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xbed9b475	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbeefef50	clk_gpio_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xbeff4023	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf1cc04b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xbf36631b	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0xbf482d60	user_read
++EXPORT_SYMBOL_GPL vmlinux 0xbf6bb5b1	of_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0xbfbba388	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xc00131cf	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0xc004898e	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc00f5748	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0xc01b039f	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0xc02bec3c	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xc037ccc4	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xc050645b	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc061367e	mpic_msgr_get
++EXPORT_SYMBOL_GPL vmlinux 0xc065a455	cpu_core_index_of_thread
++EXPORT_SYMBOL_GPL vmlinux 0xc07256ac	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc08d8959	clk_register_gpio_mux
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0bb4307	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0d948ab	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0xc0d948f5	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0e75cec	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc0fb6946	of_clk_src_simple_get
++EXPORT_SYMBOL_GPL vmlinux 0xc108e84a	dax_do_io
++EXPORT_SYMBOL_GPL vmlinux 0xc10a5c95	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc10c64ee	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xc15511c3	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xc174a374	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc18578ed	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xc1d57170	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0xc1da4936	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0xc1dd3787	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc1de3fa2	__rio_local_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xc1ec9936	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0xc1ef6f08	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xc20b629b	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc2409ba0	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0xc24cc02d	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc24ea38e	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0xc25c2bfa	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc26baa84	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xc26d496c	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0xc2725986	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc282ec82	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0xc284c656	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0xc28abb67	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0xc29da806	nvdimm_bus_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xc2c1b960	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0xc2c25342	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xc2dd5f38	__clk_mux_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0xc2e62f7f	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xc2e728dc	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0xc30ad0d2	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xc30ae58a	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0xc32bc403	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0xc3352d2b	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc33c5c94	dev_pm_opp_get_freq
++EXPORT_SYMBOL_GPL vmlinux 0xc33eedac	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc36c1fa9	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc377d199	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0xc37dfa21	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0xc3966f4e	dev_pm_opp_get_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc39f4665	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0xc3b21502	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0xc3c7744f	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xc3d73a38	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc3f2e79b	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0xc3f582dd	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xc4146ea4	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc435a062	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0xc450d341	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc4569249	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xc4614b35	clk_register_fractional_divider
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc48aa3cb	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc495bb50	pcibios_scan_phb
++EXPORT_SYMBOL_GPL vmlinux 0xc499ccf9	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0xc4a20df5	of_display_timings_exist
++EXPORT_SYMBOL_GPL vmlinux 0xc4afec88	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0xc4b4e49a	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4e02715	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0xc4eb4e95	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0xc5014b3b	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0xc519ae43	of_prop_next_string
++EXPORT_SYMBOL_GPL vmlinux 0xc5246705	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0xc525d5e7	max_gen_clk_probe
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc56229fd	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xc569d8ce	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xc571810c	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc57693e6	of_irq_parse_one
++EXPORT_SYMBOL_GPL vmlinux 0xc58a1687	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xc5a2c19f	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc5be5715	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0xc5d681f2	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc5e0d6e5	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0xc6016c72	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0xc606cd3c	boot_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0xc612de47	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc6137ed9	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc620676f	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0xc623f546	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0xc627431a	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xc63c72b1	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc657afdf	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc66f6f09	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0xc6713c9d	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0xc675a113	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xc685db2d	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xc68aa252	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xc68faa6b	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc69fef9b	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0xc6a0c994	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xc6a4a872	__clk_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc6ae6a6a	of_pci_msi_chip_add
++EXPORT_SYMBOL_GPL vmlinux 0xc6b738ac	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0xc6f6710d	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0xc6f7fb39	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc70e4b59	kvmppc_claim_lpid
++EXPORT_SYMBOL_GPL vmlinux 0xc7116604	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc7381dfb	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xc73e4e92	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0xc776b470	of_dma_configure
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7b2fcf3	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7c694d3	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7e67207	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc7e71317	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xc7fbc15e	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0xc800dc88	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc81ab8a8	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0xc83d4468	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc855b4a5	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0xc874497c	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc87e2d7a	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8c15b64	of_get_display_timing
++EXPORT_SYMBOL_GPL vmlinux 0xc8c6099c	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc8f979cc	get_device
++EXPORT_SYMBOL_GPL vmlinux 0xc9054849	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc9163e8a	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0xc9251876	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0xc9494d67	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0xc94b60ff	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc96dfae2	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0xc97d1140	cpufreq_cooling_get_level
++EXPORT_SYMBOL_GPL vmlinux 0xc97e9bff	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0xc97f2484	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0xc97ff5a7	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc985dcc8	kvmppc_pr_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc996777a	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xc9bb29b3	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0xc9bda6c1	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xc9bf9ef4	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc9c44c0b	cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc9fc61a1	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0xca06f41f	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0xca082a3f	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xca164819	__rio_local_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xca2026cf	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0xca3b0db5	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcacfb3be	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0xcaf6ab39	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0xcb00a253	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb2f3ba8	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0xcb38c0b8	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb5ee621	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0xcb8b43fd	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0xcb9c8b56	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xcba97213	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0xcbd06738	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0xcbda45b6	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbe801d4	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcc040518	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0xcc0e071f	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xcc0f1009	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xcc204450	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0xcc3e1764	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0xcc44961f	kvmppc_alloc_lpid
++EXPORT_SYMBOL_GPL vmlinux 0xcc637dcc	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcc6978a0	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xccadff63	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xccc6add8	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccdaaccb	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xcd1645c2	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0xcd1ac387	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xcd3dd3d4	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0xcd6492ab	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcdaf72b3	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcdb1b365	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcde9e7db	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xcdf552ac	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xce199180	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xce3a5d29	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce713b01	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xce80a0dd	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xcea2f348	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0xceb0b9f1	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xceb4745f	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xceb9f999	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xcec32bfe	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xcec70746	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcee32990	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0xcee97e6d	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xceeb72cd	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0xcf1805f7	cpu_remove_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0xcf2a5e55	of_fdt_unflatten_tree
++EXPORT_SYMBOL_GPL vmlinux 0xcf419204	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf867ad2	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xcf898d80	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0xcf993f54	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0xcfa862ae	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0xcfaba83b	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xcfaf1fab	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfc70335	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0xcfd3221a	clkdev_create
++EXPORT_SYMBOL_GPL vmlinux 0xd03905cc	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd03fe24e	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0xd04e1ff3	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd08cdb67	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0xd08d797e	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0f287b3	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0xd0f31b46	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0xd10f18a0	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xd114913b	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xd1212592	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xd1264ea9	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xd133efbb	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xd14cdcf8	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd1888a24	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xd1a6f3e9	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xd1c4d4b0	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd225f4cd	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0xd233ca08	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0xd239660e	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0xd25ceb67	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd2aaeb4e	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xd2ac2413	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xd2b6b356	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0xd2c2bf68	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0xd2c4c3b0	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xd2cb2761	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0xd2ce191e	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0xd2de8b76	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0xd2df9582	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd30f4f83	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0xd314462d	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xd324b8ae	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xd33462c1	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0xd33bab82	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0xd356d605	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0xd375c241	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd3912e50	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3b6924a	kvm_vcpu_read_guest_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xd3cb813a	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xd3de515a	kvmppc_st
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4152b48	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd4238e36	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0xd4394912	of_clk_get_parent_name
++EXPORT_SYMBOL_GPL vmlinux 0xd43da1e7	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0xd43f443f	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd45b57d7	mpc8xxx_spi_tx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0xd4744582	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0xd4870f6f	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0xd4ae64f1	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xd4b30939	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0xd4bf1ec6	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4d4ff73	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xd4ed726e	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0xd50c403e	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0xd53f2641	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd55a144c	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0xd5b82f86	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0xd5b85c98	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5c33955	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0xd5e1f861	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0xd5f6e5c8	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd60efc24	of_pci_parse_bus_range
++EXPORT_SYMBOL_GPL vmlinux 0xd624bbef	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0xd62946a2	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0xd62d20cb	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0xd62e29aa	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xd635534d	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xd65eb6bf	of_pci_find_msi_chip_by_node
++EXPORT_SYMBOL_GPL vmlinux 0xd664e738	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0xd66d6a7b	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd68f958a	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0xd6a07583	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0xd6c1b7fa	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xd6d09984	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xd6f6296e	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xd6feefa5	agp_num_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd6ff56ed	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd7250f29	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd7419d34	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0xd7681511	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd769cfab	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xd77501dd	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd780d259	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0xd78f1c12	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0xd7a2c896	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7f4cf6b	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xd7fc3e98	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd83c3e62	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd8449e09	__rio_local_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xd84698e9	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0xd8656076	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd87efbbb	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd8ac4a0a	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0xd8c73e87	nd_region_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xd8ca123b	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0xd8e4b192	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0xd8ea793e	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd92b7c57	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd9456175	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0xd94aa457	display_timings_release
++EXPORT_SYMBOL_GPL vmlinux 0xd95a22ce	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd96cdc52	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xd97078b6	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0xd9709a21	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0xd988891a	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd9add274	of_pci_get_host_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0xd9d07a66	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0xd9e3f612	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xd9e48533	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xd9f5ac57	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0xd9fdf4d9	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xda0648ab	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0xda08afd3	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0xda0a4d22	mpic_msgr_enable
++EXPORT_SYMBOL_GPL vmlinux 0xda178ee8	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0xda17ff4d	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xda1e197c	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0xda25e1dc	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0xda8cb2e5	threads_core_mask
++EXPORT_SYMBOL_GPL vmlinux 0xda8e6180	rio_route_add_entry
++EXPORT_SYMBOL_GPL vmlinux 0xdaa509cc	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdaa53904	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0xdaa62e5d	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0xdabd32ce	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0xdad0f1b0	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xdae715e0	videomode_from_timing
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdaf9af8e	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0xdafb93c0	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0xdb088cb1	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0xdb0ad3dc	nd_blk_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0xdb0fabe6	fsl_spi_cpm_irq
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb47af1e	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0xdb6dcfab	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0xdb7b6cd4	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdbe39d4d	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdbf863af	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0xdc0fa970	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xdc1443f9	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xdc3c94b5	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0xdc4b51da	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdc4e574d	nvdimm_volatile_region_create
++EXPORT_SYMBOL_GPL vmlinux 0xdc53b472	clk_hw_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0xdc6de389	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdc78bb63	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdcd3c10e	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xdcdf7ecc	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xdcebeb14	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xdcfa7277	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0xdd074f68	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xdd0d4c85	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd211ae0	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd335914	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd6df2aa	cpu_add_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0xdd729424	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xdd7deb94	dev_pm_opp_find_freq_floor
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddd22317	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xddf5150f	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0xde05df56	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0xde0c0acb	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xde2455f1	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0xde37bbd8	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0xde46e353	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xde7f7960	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0xde9463a6	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xdea9a43a	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdeb8cdb4	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xded2b6f0	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0xdeeec150	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0xdef58811	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xdf0b291b	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0xdf0c3252	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf19b8cf	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0xdf225098	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0xdf2b0a27	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0xdf3f9cb9	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0xdf5d3321	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xdf8104ec	of_prop_next_u32
++EXPORT_SYMBOL_GPL vmlinux 0xdf838701	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xdfc48f6b	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0xdff8e9ca	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0xdffddcea	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xe003f624	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe00af5ef	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe00d8b1e	of_resolve_phandles
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe036b3e9	mpic_msgr_put
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe07cdb49	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xe089cfcc	agp_memory_reserved
++EXPORT_SYMBOL_GPL vmlinux 0xe0937f94	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xe0b1c103	clk_set_max_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe0bd831f	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xe1021e7c	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0xe1083ae3	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0xe121cbb6	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0xe149e294	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xe14ab62d	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0xe16b2161	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe17ec2f1	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0xe19eb1c4	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe1b23ae4	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0xe1bd6c99	rio_init_mports
++EXPORT_SYMBOL_GPL vmlinux 0xe1c15a13	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0xe1c869d0	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0xe1ca2eb9	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0xe1f01857	dax_clear_blocks
++EXPORT_SYMBOL_GPL vmlinux 0xe203bcf3	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0xe2134a54	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0xe227f6f1	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0xe23b6342	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xe24fb196	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0xe261d5fc	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0xe2695907	of_get_pci_domain_nr
++EXPORT_SYMBOL_GPL vmlinux 0xe2801f20	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe2a91b24	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0xe2b1b822	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xe2dd84df	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0xe2ea3cc3	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0xe2eeeb65	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe3180646	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0xe32bfccb	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe3399f9d	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0xe34d65d6	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0xe35490d7	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0xe38e63d5	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xe3ca39b5	of_irq_parse_raw
++EXPORT_SYMBOL_GPL vmlinux 0xe3cae1f1	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe3ce1539	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0xe3dba396	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0xe3e483f6	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe3eb5945	max_gen_clk_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe3f6902c	agp_remove_bridge
++EXPORT_SYMBOL_GPL vmlinux 0xe3f86ba1	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe44fde7e	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe48934ed	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0xe48f621f	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe4a0d7af	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xe4bc0f61	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xe4c031f8	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4c92e1e	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe4d7c9dd	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xe4e89c51	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0xe50b6514	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0xe50dfcde	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0xe514025e	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0xe55a873a	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xe56dcafb	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xe57709f4	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5a007c2	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe5a99c48	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0xe5c411ee	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0xe615eeb4	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0xe61ef1a0	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe66316d9	of_alias_get_id
++EXPORT_SYMBOL_GPL vmlinux 0xe66c0a4e	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0xe67f6a68	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe68c6879	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0xe6b4731c	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe6bd7c34	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6d9c1ac	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6e80ef9	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0xe6ec86ee	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe6f83295	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xe7096294	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0xe7145917	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0xe7274eae	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe765712f	gfn_to_hva
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe7756bd7	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe78eefe3	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0xe7b8fb0b	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0xe7d10cd6	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0xe7ee3e41	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xe7f18b3c	threads_per_subcore
++EXPORT_SYMBOL_GPL vmlinux 0xe7f3c29a	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe7f7cc85	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe80f8cb5	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xe812d58e	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe8276dcf	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe859cbb0	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0xe85ac969	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe85c55e7	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe8786d80	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0xe87f77d3	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0xe892796c	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0xe8a677ee	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe8a7e723	of_irq_parse_pci
++EXPORT_SYMBOL_GPL vmlinux 0xe8b00f2e	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0xe8c3ca30	rio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xe8f9f725	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0xe8fd9081	rio_set_port_lockout
++EXPORT_SYMBOL_GPL vmlinux 0xe913ad47	of_modalias_node
++EXPORT_SYMBOL_GPL vmlinux 0xe922216d	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe95aa6d4	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0xe95f9168	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0xe982d0be	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0xe98d81e3	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0xe990431c	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xe9ac17eb	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0xe9cc7efa	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea17192d	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xea1dc964	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0xea21075f	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0xea2c6fc6	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xea38ff49	dev_pm_opp_of_cpumask_add_table
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea47fb49	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xea724617	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0xea7f023e	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xeadbe509	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xeaf1ee3a	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0xeb0ea5a6	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0xeb129e11	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0xeb50e82a	cpufreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xeb5aeda5	fb_sys_read
++EXPORT_SYMBOL_GPL vmlinux 0xeb60f187	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0xeb66b9f9	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xeb6794f8	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0xeb8ae736	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0xeb9abbee	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xeb9dcb15	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xeb9efcd7	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0xebadded3	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0xebb3592b	snmp_get_cpu_field64
++EXPORT_SYMBOL_GPL vmlinux 0xebc51ce9	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0xebcd8255	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0xebd23848	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xebdb31d4	analyse_instr
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xebf133f6	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0xebf60f2f	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xebf9f29e	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xec10ed8f	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec851810	of_css
++EXPORT_SYMBOL_GPL vmlinux 0xec98e6f7	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xeca3dab1	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0xecc0b7b7	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xecc7f4ae	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xecd6b123	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0xecdbc8a9	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xecf0b9e8	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0xed038aee	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xed06c5cb	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xed0cc5ca	clk_register_mux_table
++EXPORT_SYMBOL_GPL vmlinux 0xed60b5ec	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xed6d8c58	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0xeda9e9d7	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xedbacc69	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xedcc2c4a	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xedd7ca35	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0xede3d7b5	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0xede530d3	of_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xee04adc7	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xee0afca9	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xee19e183	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0xee348406	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0xee354c28	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0xee37ac86	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0xee5456a5	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee99c3ae	vcpu_put
++EXPORT_SYMBOL_GPL vmlinux 0xeeb6723f	cpu_remove_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0xeec245e5	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0xeec4e273	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0xeed0f8aa	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0xeed2aa2a	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xeede249e	rio_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xeee5f6ab	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0xeee6a24f	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xef0dad99	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0xef120397	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0xef2085db	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0xef409b74	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0xef464c28	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0xef610c25	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef8ada96	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefa89524	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0xefb510d6	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xefe456af	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xefe9cb56	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xefefa3fb	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xf00775b8	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xf0145113	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf06fef38	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf078450c	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0xf07a2f77	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xf07d2194	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0xf080c62c	of_platform_default_populate
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0c85c3a	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf0ebf4a5	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf100eaf9	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0xf1027b78	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0xf12145ef	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0xf135f1ae	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0xf141d973	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0xf149df6e	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0xf158f170	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0xf15af653	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf15e3eae	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0xf15facc2	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0xf16a7f9f	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xf18316a8	nd_mapping_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xf184b034	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf18b06cb	component_del
++EXPORT_SYMBOL_GPL vmlinux 0xf1a62b6f	of_i8042_kbd_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf1a87aa0	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b2a0cf	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1decc5f	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xf1ee0dd5	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0xf1f6577f	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0xf1fd8de9	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf203f211	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xf20a02fa	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0xf2196393	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xf21a60ea	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf2423538	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0xf24df2cb	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xf25a7bec	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf2902672	of_irq_to_resource_table
++EXPORT_SYMBOL_GPL vmlinux 0xf2a1c633	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2d03356	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0xf2e86dd7	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf3012f6c	rh_free
++EXPORT_SYMBOL_GPL vmlinux 0xf305bad9	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf30fda27	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf3316ee7	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xf332d2ce	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xf33bf5bb	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0xf340b3d5	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0xf345fbb8	dev_pm_opp_of_cpumask_remove_table
++EXPORT_SYMBOL_GPL vmlinux 0xf346de14	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf35410f0	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf37b7c80	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf38dfd32	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf39fe87f	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3cf7a17	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf3fe1aa1	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0xf44ba3ab	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xf47c5201	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0xf481e63f	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0xf48b095d	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4aadbe5	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0xf4b333d1	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xf4c4e11f	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0xf4c8f179	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xf4da3546	kvmppc_init_lpid
++EXPORT_SYMBOL_GPL vmlinux 0xf4e75ecf	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xf4f715ee	clk_hw_get_num_parents
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf511f70a	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xf5411b82	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf554248a	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0xf5605b12	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xf591a0be	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5b4fadd	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0xf5bcf1b2	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0xf5db09e0	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0xf5e7f053	rh_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xf638b6c7	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xf6412398	fb_sys_write
++EXPORT_SYMBOL_GPL vmlinux 0xf6491328	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0xf64a5747	rio_route_clr_table
++EXPORT_SYMBOL_GPL vmlinux 0xf6584d63	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0xf65e2440	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xf6623d31	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0xf6794f54	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0xf68d58e8	kvm_clear_guest
++EXPORT_SYMBOL_GPL vmlinux 0xf6b6c326	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xf6bf1321	kvm_read_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xf6c511ea	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6d331e7	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf6fe1ace	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0xf70181ee	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xf70380e5	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0xf7344fdf	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xf7769208	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf78045c7	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0xf7871887	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf7b21c33	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0xf7dab452	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf80d0127	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf80efb57	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0xf81a3371	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xf82ac2c8	of_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf82f16b3	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf872841a	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf8b75c40	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0xf8d47ba2	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0xf8e6b564	hibernation_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf914a072	of_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0xf91eac65	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf92fdc1c	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf9664668	of_get_nand_on_flash_bbt
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf99c6b29	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9f04dac	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xf9f9719f	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0xfa086cfc	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa22a46b	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0xfa3c50ff	component_add
++EXPORT_SYMBOL_GPL vmlinux 0xfa46ebef	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xfa4ecbf9	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xfa61d076	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0xfa67f6d9	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0xfa69b721	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xfa76caac	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0xfa7a32c4	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xfaa74443	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xfab60503	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0xfad018de	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfb062d99	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xfb272353	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0xfb309716	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0xfb310720	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb33b1d9	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0xfb5133bc	of_clk_get_parent_count
++EXPORT_SYMBOL_GPL vmlinux 0xfb52b77d	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0xfb603e15	kvmppc_ld
++EXPORT_SYMBOL_GPL vmlinux 0xfb680fd3	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb743d41	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xfb83db03	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xfbb19e73	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xfbbb1cd8	put_device
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc1d7ff2	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0xfc21a4c7	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0xfc2fcfa1	devfreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xfc69b456	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xfc8f2b90	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xfca37152	dev_pm_opp_of_get_sharing_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xfcaf5e01	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xfcc2dda0	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfce42ba5	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0xfce476a6	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xfcf965f3	of_property_read_u64
++EXPORT_SYMBOL_GPL vmlinux 0xfd03f142	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xfd11a3f6	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0xfd165cd2	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xfd3c9d7c	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0xfd59958b	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0xfd616ef4	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd81d973	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0xfdbeb1fd	device_create
++EXPORT_SYMBOL_GPL vmlinux 0xfdd98738	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0xfdd9e083	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0xfdef1d75	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0xfdfc5a78	thermal_zone_of_sensor_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfdfdb517	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0xfe23694b	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xfe552188	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0xfe7f439b	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfe9cf813	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0xfea4d414	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0xfea545d6	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0xfec6d2a5	mpc8xxx_spi_tx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfed370f1	of_irq_find_parent
++EXPORT_SYMBOL_GPL vmlinux 0xfedcc293	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff006fd9	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xff03db0d	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff128437	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0xff1474bb	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xff291ecf	clk_unregister_divider
++EXPORT_SYMBOL_GPL vmlinux 0xff3b50cf	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff6b9111	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xff6e42ca	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0xff8862d7	rh_get_stats
++EXPORT_SYMBOL_GPL vmlinux 0xff8c2c94	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0xff8d2e7c	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xff9ec7b3	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xffb5f22c	dev_pm_opp_get_max_clock_latency
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffb827b3	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0xffba4dfb	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xffc174c3	of_thermal_is_trip_valid
++EXPORT_SYMBOL_GPL vmlinux 0xffc4f410	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0xffe55afa	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xffedfc06	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xfffde3d6	fat_add_entries
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc.compiler b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc.compiler
+new file mode 100644
+index 0000000..d1936f3
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc.modules b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc.modules
+new file mode 100644
+index 0000000..28cfb98
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-e500mc.modules
+@@ -0,0 +1,4333 @@
++3c574_cs
++3c589_cs
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_dw
++8250_mid
++8255
++8255_pci
++8390
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++BusLogic
++DAC960
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++ac97_bus
++acard-ahci
++acecad
++acenic
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7170
++adv7175
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++ah4
++ah6
++aha152x_cs
++ahci
++ahci_ceva
++ahci_platform
++ahci_qoriq
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airo
++airo_cs
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++ali-ircc
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am53c974
++ambassador
++amc6821
++amd
++amd5536udc
++amd8111e
++amdgpu
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apbps2
++apds9300
++apds9802als
++apds990x
++apds9960
++appledisplay
++appletalk
++appletouch
++applicom
++aquantia
++ar1021_i2c
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_emac
++arc_ps2
++arc_uart
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3722-regulator
++as3935
++as5011
++asc7621
++ascot2e
++asix
++ast
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++ata_generic
++ata_piix
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atm
++atmel
++atmel-flexcom
++atmel-hlcdc
++atmel_cs
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp870u
++atusb
++atxp1
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avm_cs
++avma1_cs
++avmfritz
++ax25
++ax88179_178a
++axnet_cs
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1pci
++b1pcmcia
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_epp
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm-keypad
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcma
++bcma-hcd
++bcmsysport
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluecard_cs
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpck
++bpck6
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmsmac
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bt3c_cs
++bt819
++bt856
++bt866
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btuart_cs
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++caam
++caam_jr
++caamalg
++caamhash
++caamrng
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++cap11xx
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_das16_cs
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc10001_adc
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipone_icn8318
++chipreg
++chnl_net
++ci_hdrc
++ci_hdrc_imx
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++clip
++clk-cdce706
++clk-cdce925
++clk-max77686
++clk-max77802
++clk-palmas
++clk-pwm
++clk-rk808
++clk-s2mps11
++clk-si514
++clk-si5351
++clk-si570
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cm4000_cs
++cm4040_cs
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmtp
++cnic
++cobalt
++cobra
++coda
++colibri-vf50-ts
++com20020
++com20020-pci
++com20020_cs
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_isadma
++comedi_parport
++comedi_pci
++comedi_pcmcia
++comedi_test
++comedi_usb
++comm
++configfs
++contec_pci_dio
++cordic
++core
++cp210x
++cpia2
++cpm_uart
++cpsw_ale
++cpu-notifier-error-inject
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc7
++crc8
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++csiostor
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_cs
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++db9
++dc395x
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++ddbridge
++de2104x
++de4x5
++decnet
++deflate
++defxx
++denali
++denali_dt
++denali_pci
++des_generic
++designware_i2s
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++digicolor-usart
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9601
++dmfe
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++donauboe
++dp83848
++dp83867
++dpt_i2o
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dtl1_cs
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_wdt
++dwc3
++dwc3-pci
++dwc_eth_qos
++dwmac-generic
++dwmac-ipq806x
++dwmac-lpc18xx
++dwmac-meson
++dwmac-rk
++dwmac-socfpga
++dwmac-sti
++dwmac-sunxi
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++earth-pt1
++earth-pt3
++eata
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++echainiv
++echo
++edac_core
++edt-ft5x06
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efs
++egalax_ts
++ehset
++elan_i2c
++elo
++elsa_cs
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emac_arc
++emac_rockchip
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++empeg
++ems_pci
++ems_pcmcia
++ems_usb
++emu10k1-gp
++enc28j60
++enclosure
++encx24j600
++encx24j600-regmap
++eni
++enic
++epat
++epia
++epic100
++eql
++esas2r
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++ezusb
++f2fs
++f75375s
++f81232
++fakelb
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdomain_cs
++fdp
++fdp_i2c
++fealnx
++ff-memless
++firedtv
++firestream
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fixed
++fl512
++flexcan
++flexfb
++floppy
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fmvj18x_cs
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++friq
++frpw
++fs_enet
++fsa9480
++fscache
++fsl-corenet-cf
++fsl-diu-fb
++fsl-edma
++fsl_elbc_nand
++fsl_hypervisor
++fsl_ifc_nand
++fsl_lpuart
++fsl_pq_mdio
++fsl_qe_udc
++fsl_upm
++fsl_usb2_udc
++fsldma
++ft6236
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu_ts
++g450_pll
++g760a
++g762
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcm
++gdmtty
++gdmulte
++gdmwm
++gdth
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++gf128mul
++gf2k
++gfs2
++ghash-generic
++gianfar_driver
++gianfar_ptp
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-74x164
++gpio-74xx-mmio
++gpio-addr-flash
++gpio-adnp
++gpio-adp5520
++gpio-adp5588
++gpio-altera
++gpio-amd8111
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-fan
++gpio-generic
++gpio-grgpio
++gpio-ir-recv
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-rdc321x
++gpio-regulator
++gpio-syscon
++gpio-tps65912
++gpio-twl4030
++gpio-twl6040
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mouse
++gpio_tilt_polled
++gpio_wdt
++gr_udc
++grace
++grcan
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++gxt4500
++hackrf
++hamachi
++hampshire
++hanwang
++hci
++hci_uart
++hci_vhci
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfs
++hfsplus
++hi6421-pmic-core
++hi6421-regulator
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++hih6130
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi504_nand
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hopper
++horizon
++horus3a
++hostap
++hostap_cs
++hostap_pci
++hostap_plx
++hp100
++hpfs
++hpilo
++hpsa
++hptiop
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++htc-pasic3
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hwa-hc
++hwa-rc
++hwmon-vid
++hx8357
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd8111
++i2c-arb-gpio-challenge
++i2c-cbus-gpio
++i2c-cpm
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-emev2
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-kempld
++i2c-matroxfb
++i2c-mpc
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-reg
++i2c-nforce2
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-piix4
++i2c-rk3x
++i2c-robotfuzz-osif
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i40e
++i40evf
++i5k_amb
++i6300esb
++i740fb
++i82092
++ib_addr
++ib_cm
++ib_core
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibmaem
++ibmpex
++icp_multi
++icplus
++ics932s401
++ideapad_slidebar
++idma64
++idmouse
++idt77252
++idt_gen2
++idtcps
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imm
++imon
++ims-pcu
++imx074
++imx6ul_tsc
++imx_thermal
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int51x1
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipwireless
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++irlan
++irnet
++irtty-sir
++iscsi_boot_sysfs
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it913x
++itd1000
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++kafs
++kalmia
++kaweth
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks0108
++ks0127
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l4f00242t03
++l64781
++lan78xx
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-adp5520
++leds-bcm6328
++leds-bcm6358
++leds-bd2802
++leds-blinkm
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-ktd2692
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max77693
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-pwm
++leds-regulator
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libahci_platform
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_cs
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++lis3lv02d_spi
++litelink-sir
++lkkbd
++ll_temac
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lmc
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac80211
++mac80211_hwsim
++mac802154
++mac_hid
++macb
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mailbox-test
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++marvell
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max5821
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max77693-haptic
++max77693_charger
++max77802
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++md5-ppc
++mdc800
++mdio
++mdio-bcm-unimac
++mdio-bitbang
++mdio-gpio
++mdio-mux
++mdio-mux-gpio
++mdio-mux-mmioreg
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++metro-usb
++metronomefb
++mf6x4
++mga
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microtek
++mii
++mii-bitbang
++minix
++mip6
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmc_block
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpc85xx_edac
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi001
++msi2500
++msp3400
++mspro_block
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtd_dataflash
++mtdblock
++mtdblock_ro
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-sd
++mtouch
++multipath
++multiq3
++musb_hdrc
++mv643xx_eth
++mv_u3d_core
++mv_udc
++mvmdio
++mvsas
++mvumi
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxc4005
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxser
++mxuport
++myri10ge
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nci
++nci_spi
++nci_uart
++ncpfs
++nct7802
++nct7904
++nd_blk
++nd_btt
++nd_pmem
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_daq_700
++ni_daq_dio24
++ni_labpc
++ni_labpc_common
++ni_labpc_cs
++ni_labpc_isadma
++ni_labpc_pci
++ni_mio_cs
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicstar
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nmclan_cs
++nosy
++notifier-error-inject
++nouveau
++nozomi
++nps_enet
++ns558
++ns83820
++nsc-ircc
++nsp32
++nsp_cs
++ntb
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nvidiafb
++nvme
++nvmem_core
++nxp-nci
++nxp-nci_i2c
++nxp-ptn3460
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_xilinx_wdt
++ofpart
++old_belkin-sir
++omap4-keypad
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_cs
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++palmas-pwrbutton
++palmas-regulator
++pandora_bl
++panel
++panel-lg-lg4573
++panel-samsung-ld9040
++panel-samsung-s6e8aa0
++panel-sharp-lq101r1sx01
++panel-simple
++parade-ps8622
++paride
++parkbd
++parport
++parport_ax88796
++parport_cs
++parport_pc
++parport_serial
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_of_platform
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pcmcia
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sis
++pata_sl82c105
++pata_triflex
++pata_via
++pc300too
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_udc
++pci
++pci-stub
++pci200syn
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmcia
++pcmcia_core
++pcmcia_rsrc
++pcmciamtd
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcnet_cs
++pcrypt
++pcwd_pci
++pcwd_usb
++pd
++pd6729
++pda_power
++pdc_adma
++peak_pci
++peak_pcmcia
++peak_usb
++pegasus
++penmount
++percpu_test
++pf
++pfuze100-regulator
++pg
++phantom
++phonet
++phram
++phy-bcm-kona-usb2
++phy-exynos-usb2
++phy-gpio-vbus-usb
++phy-isp1301
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-tahvo
++phy-tusb1210
++physmap
++physmap_of
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl2303
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8941-wled
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pn533
++pn544
++pn544_i2c
++pn_pep
++poly1305_generic
++port100
++powermate
++powr1220
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_core
++pps_parport
++pptp
++prism2_usb
++ps2mult
++psmouse
++psnap
++pt
++ptp
++pulsedlight-lidar-lite-v2
++pvrusb2
++pwc
++pwm-atmel-hlcdc
++pwm-beeper
++pwm-fan
++pwm-fsl-ftm
++pwm-lp3943
++pwm-pca9685
++pwm-regulator
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa27x_udc
++qcaspi
++qcaux
++qcom-spmi-iadc
++qcom-spmi-temp-alarm
++qcom-spmi-vadc
++qcom_spmi-regulator
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qlogic_cs
++qlogicfas408
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qoriq-cpufreq
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quatech_daqp_cs
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-bcm2048
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-shark
++radio-si476x
++radio-tea5764
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++ray_cs
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++reed_solomon
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio-scan
++rio500
++rionet
++rivafb
++rj54n1cb0c
++rk808
++rk808-regulator
++rmd128
++rmd160
++rmd256
++rmd320
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-as3722
++rtc-bq32k
++rtc-bq4802
++rtc-cmos
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-generic
++rtc-hid-sensor-time
++rtc-hym8563
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max77802
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-msm6242
++rtc-mt6397
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-r9701
++rtc-rc5t583
++rtc-rk808
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-snvs
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-twl
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtc-zynqmp
++rtc_cmos_setup
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7110
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7185
++saa7706h
++safe_serial
++salsa20_generic
++samsung-keypad
++samsung-sxgbe
++sata_fsl
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_sil
++sata_sil24
++sata_sis
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sbp_target
++sbs-battery
++sc16is7xx
++sc92031
++sca3000
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++sdhci
++sdhci-of-arasan
++sdhci-of-at91
++sdhci-of-esdhc
++sdhci-of-hlwd
++sdhci-pci
++sdhci-pltfm
++sdhci_f_sdh30
++sdio_uart
++sdricoh_cs
++sedlbauer_cs
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial2002
++serial_cs
++serio_raw
++sermouse
++serpent_generic
++serport
++ses
++sfc
++sgy_cts1000
++sh_veu
++sha1-powerpc
++shark2
++shpchp
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sir-dev
++sis
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skfp
++skge
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++sl811_cs
++slcan
++slip
++slram
++sm501
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smc91c92_cs
++smipcie
++smm665
++smsc
++smsc-ircc2
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4117
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als300
++snd-als4000
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt3328
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-cs4281
++snd-cs46xx
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1938
++snd-es1968
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm
++snd-pcm-dmaengine
++snd-pcm-oss
++snd-pcxhr
++snd-pdaudiocf
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-sb-common
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-core
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-es8328
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-ssi
++snd-soc-gtm601
++snd-soc-imx-audmux
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rt5631
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-xtfpga-i2s
++snd-sonicvibes
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-usx2y
++snd-usb-variax
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-vxpocket
++snd-ymfpci
++snic
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++softdog
++softing
++softing_cs
++solo6x10
++solos-pci
++sony-btf-mpx
++soundcore
++sp2
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_dectlk
++speakup_dummy
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++spectrum_cs
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi-lm70llp
++spi-nor
++spi-oc-tiny
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tle62x0
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spmi
++sr9700
++sr9800
++ssb
++ssb-hcd
++ssd1307fb
++ssfdc
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++ssu100
++st
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++svgalib
++sx8
++sx8654
++sx9500
++sym53c500_cs
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink
++synclink_cs
++synclink_gt
++synclinkmp
++sysv
++t1pci
++t5403
++talitos
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc3589x-keypad
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tehuti
++tekram-sir
++teles_cs
++teranetics
++test-hexdump
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tg3
++tgr192
++thmc50
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timeriomem-rng
++tipc
++tlan
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++torture
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_atmel
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps65218-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tsi568
++tsi57x
++tsi721_mport
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl-regulator
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++uPD98402
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udc-xilinx
++udf
++udl
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_fsl_elbc_gpcm
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmisc_imx
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vcan
++vcnl4000
++ves1820
++ves1x93
++veth
++vf610_adc
++vga16fb
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-ircc
++via-rhine
++via-sdmmc
++via-velocity
++via686a
++videobuf-core
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videocodec
++videodev
++vim2m
++viperboard
++viperboard_adc
++virt-dma
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_scsi
++virtual
++visor
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_ca91cx42
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vpx3220
++vrf
++vringh
++vsock
++vsxxxaa
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83977af_ir
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++walkera0701
++wanxl
++warrior
++wbsd
++wcn36xx
++wd719x
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++windfarm_core
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wl3501_cs
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x_tables
++xc4000
++xc5000
++xcbc
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xhci-plat-hcd
++xilinx-tpg
++xilinx-video
++xilinx-vtc
++xilinx_emaclite
++xilinx_ps2
++xilinx_uartps
++xillybus_core
++xillybus_of
++xillybus_pcie
++xirc2ps_cs
++xircom_cb
++xor
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yenta_socket
++yurex
++zatm
++zaurus
++zd1201
++zd1211rw
++zforce_ts
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++zr36016
++zr36050
++zr36060
++zr36067
++zr364xx
++zram
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp
+new file mode 100644
+index 0000000..3928581
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp
+@@ -0,0 +1,17117 @@
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0xa8cfd13e	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/atm/suni 0x5d690ae3	suni_init
++EXPORT_SYMBOL drivers/atm/uPD98402 0x42553762	uPD98402_init
++EXPORT_SYMBOL drivers/bcma/bcma 0xef55c265	bcma_core_irq
++EXPORT_SYMBOL drivers/bcma/bcma 0xfc43a862	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x1331e37e	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0x16562069	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x2f2ec99c	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x32ae94fa	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0x40faa540	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x4267110a	pi_register_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0x507745ba	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x6db48bdc	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0x92350ebd	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xaefa79b4	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0xb21ba07d	pi_unregister_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0xc2e6ea89	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xdb97007f	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xf9e1e367	pi_init
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0x9e14d6d8	btbcm_patchram
++EXPORT_SYMBOL drivers/char/apm-emulation 0x129e74f2	apm_get_power_status
++EXPORT_SYMBOL drivers/char/apm-emulation 0xdf3329b8	apm_queue_event
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x0e4631c4	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x28a3674f	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x71014a67	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x839ab028	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xb4c9e9a7	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x2fc896a1	st33zp24_probe
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xa6c57f3d	st33zp24_pm_suspend
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xb742d315	st33zp24_pm_resume
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xec73679d	st33zp24_remove
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x173956f2	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x5afd3f92	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x73b72395	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x467cb88a	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x5bb87b46	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x9b29fc96	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xd0a8a937	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xed87dc89	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xfe065543	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/edac/edac_core 0x973fe285	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04dd92ce	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x14d7f94e	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x1e1d0c52	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x1e7f84e5	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x202d52d2	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x27e05032	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2a60b933	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x43994ba3	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x43c71474	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4d5d4eca	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x59844d4e	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7008c76c	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x756490ff	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7e431b14	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x89f4175c	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x970e8ef5	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9f213035	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xad8464c7	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xae0925a3	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xafcd8c21	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb023a34f	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb3084171	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb410c1f9	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xc1b2b937	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd549d608	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xdc745a5d	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xe77f0d24	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xf8fd695b	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xfba28d27	fw_fill_response
++EXPORT_SYMBOL drivers/fmc/fmc 0x1b7ad5f4	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x23a940c4	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x4b1cd3b5	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x62520db9	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0x7c59f025	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x8096ced2	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0x9ec88b6d	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xa08fe49b	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0xa8c090f2	fmc_driver_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xc64b83da	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xf98f68b8	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x012d2a3e	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02481838	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x033f411f	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x035bb489	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x05307e11	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0749cf86	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x08bd9f1e	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x09998c38	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0baaf61a	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0bacf8fa	drm_agp_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0bbda8c9	drm_of_find_possible_crtcs
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0d8f1d19	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0e96e0ca	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fccafb1	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x10543f20	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12e9c5cd	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13275d26	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x16b418f5	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1700f075	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x197f5631	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a2861d0	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1ae25e4d	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1af458ce	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1b73be9b	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1bbdf993	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1bd7b581	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c48846e	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1e71d256	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1f54da5b	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1f7755d1	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20d40629	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x212064ec	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x214f9830	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x224350a5	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22c449cb	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x230b7afc	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2452e6d4	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x261025c8	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x27ad4d30	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2b456a33	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2b875134	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c6792c2	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d3436a3	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2da3a0f2	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2dbfb229	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2f248d78	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2f58e63d	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2fca52d6	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3204f760	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x32e2fe8e	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x338d9909	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3440a250	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x346127a7	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x372ed8cd	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37b5c883	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x389c015f	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x39c8d7d3	drm_agp_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ad53a0e	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b6dbaf3	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ba73803	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3cd4c769	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d8283c8	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3f9b8d97	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3fc4535c	of_drm_find_bridge
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4185e9cc	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43bf1b1b	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x447e03c4	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4573b09c	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x457486b4	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x464e3e6e	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x46650bcb	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x46d9de56	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x46fc07cb	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x47d08b44	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c0028e2	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d49302c	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4dd5d82d	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4e092bff	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4e44a462	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4eeec163	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5024eb4a	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50cf5c53	of_drm_find_panel
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51db353a	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x522f7286	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x543bc14c	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54c1ada1	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x554d66bf	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x55c80461	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x56af0f39	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x588762b1	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59edad33	drm_agp_info
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a268d54	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5b4a2725	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5b628739	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5bd908ae	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d3d80fe	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d802d04	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5dd834ba	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5f80e9e0	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5f8cade8	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x61760971	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x61d3246f	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x61ff67ba	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x623d4609	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x626fe8bb	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x62b72dbb	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x630caab9	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x63b37462	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x63ded0ad	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x64a33e17	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x665c1806	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x673cc9e6	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67f69161	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68b54ec5	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68e940ff	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69696fb6	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69a56008	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6b836249	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6c51856c	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6d39d783	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6d5f28ac	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6da8378c	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6db66aad	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6ed5bdaf	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f2f55c1	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70bf2a8f	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70e612d4	drm_agp_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x71263b95	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x723785e7	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7318315e	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74a7673f	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74eac32b	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x753f99bb	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x78206c23	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x79250ee5	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x797e15bc	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7987cd89	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b160c3e	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b32e83b	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c425504	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7deb1f6f	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7f4d90f4	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x80a57e9e	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x80d3d0e8	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x80d46e67	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8126a91e	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8146a3c3	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x81fb20b1	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x837c85bb	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x839bec96	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x860b29ba	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x864d3edf	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x87a0a4ac	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x88fff3a3	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x89119355	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8abcd9b8	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ad8ef62	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8adafa65	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c606381	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8cf191e3	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f6d9b60	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x90169ad0	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x909791b7	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x909f2c0d	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x93084d0c	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9313f836	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x940dfe5b	drm_agp_bind_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9568c53a	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x977cdf68	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97936d44	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x989d7193	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a824fbd	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9b23b5df	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9c4b9ad2	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9e40e457	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa03abc0a	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa03f2531	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa15a8253	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa29eb83a	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa31bfe49	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa335d2d8	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa33b1342	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa382021f	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4ebc086	drm_agp_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa7f9e7fd	drm_agp_acquire
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa8869c80	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa9411773	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xab10c837	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xadd41838	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae620466	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae83b084	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaf1d0784	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb0909a40	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb125c4f4	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb128ed28	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb19e8a38	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb1ba9c3d	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb2392663	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb32ef28c	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb336fd2f	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3c663e3	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3cafc35	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb525cb24	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb58d4cca	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb77eea0a	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb83cbdb4	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb9398e18	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb9deb24b	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbbd193eb	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbbdb9902	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbc9b940c	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbd5ac725	drm_legacy_addbufs_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbd873ca1	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe3c427d	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe97ba67	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc16ea9ef	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2001508	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2f87238	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc30abdfa	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc853658d	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc8ae0956	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc8af7734	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc9b2e630	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca157209	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb015fe9	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xccd77615	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd624cc1	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xce5432f1	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xce7442da	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xce9803aa	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcea8de9d	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcedb149d	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf34731f	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd4d47f79	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd557dc31	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd58e4bf4	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd724da75	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd754f6ba	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd90ab18f	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd967b851	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdac455e3	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc45cf71	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdca8d136	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd9a7c6e	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xde52f986	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2e82ce2	drm_of_component_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2ffd7a5	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe83ef772	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe8c0cb4a	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe9d60728	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea69ec22	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea6d1845	drm_agp_unbind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeabbc768	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb609dc1	drm_agp_bind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb87c5ef	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xebe1082a	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xec245d31	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xec9b2201	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xede47303	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xee12b897	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xee1736e4	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xee64bff5	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xee7d6899	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1591bd3	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1b098be	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf29fbca9	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf3a320ac	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf3b0439e	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf5b44230	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf60ddd45	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf765e8b3	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf7a4622e	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf7afacc2	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf85bccb8	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf90b4291	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfa5ddec1	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb4ad8ee	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc241fbc	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc5499c3	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc7455da	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc764ab5	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc7fc43b	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc887d64	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf7d979	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd2aabee	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfdd69dbb	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfe8bd176	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfed58cee	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffa9e704	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x01533137	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x030d06a6	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x03127352	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x032b8585	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x03a143cb	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x081a81c4	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x090b8e6c	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0a00cb4c	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0afc3640	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0b041224	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0c58a7d2	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0cce0757	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0ff36431	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1339dced	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x138df3fb	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x155ae67a	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x175dcc3d	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x199c986d	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1a9316a2	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1aa2327f	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1aa9527f	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1c7c67d7	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1f3b8cf3	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x200fdffc	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x238c0d6a	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x26a81554	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x29c8fba0	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2a4d5c84	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2d34a645	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x36af83b3	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x398e07b4	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x39f265e9	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3a7af9b0	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3b558a15	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3c94513b	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3caed7b8	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3e4eb0f2	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3ef8485d	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x436b76a9	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4432d26c	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x445a30d3	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x461f75d0	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x488fc4be	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x48e146b4	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4cc8b515	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x50161ec0	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x51723de9	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x54584f17	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x546b4d45	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x56625ca3	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x58dc09bd	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5e7c8175	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5edfe26a	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x600de998	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x61357072	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6199d59b	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x61a9ced2	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x634e1a8b	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x63dc2e03	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6679bf5a	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x66e971f3	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x677f6161	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x68d4316f	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x69aa539c	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6b44c801	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6c970d6f	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6ee5776b	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x75397635	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x78df32dd	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x78e57600	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x79ffab76	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7ce9218f	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7d3d7b16	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7ec66bb8	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8038e77f	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8066227f	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x82234849	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84742f32	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84ee5ae1	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8593ff75	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8a815efd	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8b79e2b3	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8cf424ea	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8dea6bbf	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x945c8dd0	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x957dca6a	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9cb1407f	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9cb713e4	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9d444e7c	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9e13ca99	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9f49badd	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa0cf0f50	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa22aecbf	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa340df8c	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa3e04c88	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa7356e73	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa7f77ea2	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaa7a48bb	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaa8ecbf2	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xac2d9807	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb1bb98ef	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb236ad72	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb4d0a1cd	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb6679ac2	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb902a635	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc352a95e	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc476b77f	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc49fba5f	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc5252e40	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc553d29a	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc77e7758	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc87a73ed	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc87eab88	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc9dbf096	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xca6a191e	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcaf6555a	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xce4d6093	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xce995fc6	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd4f425cf	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd5048806	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd75814d7	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd9c9c436	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xda9353a0	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdafc7722	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdb7644f2	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdbe755e8	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xde9d23d5	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdebfd4f1	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdf3ec4be	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xec2adfc0	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf316b971	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf3b73d08	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf40310fc	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf64794ea	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf7123ffa	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf8d766de	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf96f8d3a	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfba18034	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfe50afdf	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfef00bde	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfef04768	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xff9a351e	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x03f491f9	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x07c91bf5	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0aead641	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0ceb76ca	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0e1c0dfe	ttm_prime_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x111694fb	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x132b05be	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x216b08af	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x23c5ff8d	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2bc32617	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2d8786bd	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x38a279f0	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x39800037	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3ccdba03	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3fe437ba	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x44fd0f06	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x463179c7	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x47b1a10d	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4ae9437c	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4cdc68c7	ttm_agp_tt_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4d674fc1	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4eaae86e	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x519b4ce3	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x52b20b7f	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5704cbb1	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x579705ea	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x58d27fca	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5a8fdfea	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5cf59609	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x60cd1418	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x621115ea	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63ee259a	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x668eee11	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x67b1d568	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6c4478ba	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x707f652b	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7215f34a	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7d55da85	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8076df2b	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x84a13931	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x89a443de	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8d14adbf	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8e3c2f58	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x902d65a8	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x962d78f7	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9c5db822	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa13e566f	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa1725535	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa2337831	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa265b99b	ttm_agp_tt_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa2a129fd	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa563b21c	ttm_agp_tt_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa73de2a9	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb794f943	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb83c6470	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc04b5102	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc5f0c2da	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc71b63f5	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc9bb1e02	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcb2cbf56	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd7f51742	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd93f78be	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe1b846f9	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe4909605	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe7ad1bce	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe9cf9d23	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xece65422	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf03595ea	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf7ff8b6a	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x1eed9b12	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x3915292f	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xa5e7e1f8	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0xfa98c72a	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0xfcfd839c	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0x9fba339d	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x29b0d001	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x32f0b592	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x37e1a1be	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x4205b93b	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x6ddeee3f	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x83243a6e	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x8d335f34	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x93f394e6	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xa5468868	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xacdcd235	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xaea94d63	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xd48406d8	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xdd9f763e	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xdfea7b1a	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xe47dea9a	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xfe1ddd9a	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x0b1a08e3	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x7d56d838	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x43c3bb2f	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x533f5fa9	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x0cfe8154	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x3d98df4d	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xcc539a03	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xdf4a5c7f	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x1ef0fb48	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x1efc8275	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x24d177df	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x8792e6b1	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc6618a24	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xcb0bb0ed	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x2116b6f6	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x6065c63c	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x99dd859c	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xd8358991	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x238c6267	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x2396285f	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x57de82cb	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x6e1900e2	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x9ee57d46	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc66577d8	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xf3a67f37	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xf72f6395	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xfd6c543a	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x3af07919	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x5a199405	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x6bf772fe	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x83460f53	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x8c65c1ae	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xc5c77c21	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xd0508fb7	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xf9c5b3a1	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x06721fd8	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x13b1dacd	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x2b671806	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4188d75a	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x457880be	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x60d0c116	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6330258e	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6cfae357	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x7422b5bb	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x818a7188	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x85d85d45	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc6bc0540	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xcc1599f0	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xcc6de77a	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd4176fb8	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd4fd8fb3	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xe975e309	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x7171ddb5	st_sensors_of_i2c_probe
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xd435d971	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0x15f1f4b2	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0xef1c662d	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0xfd1a7179	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0xea05ffa0	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xdbead554	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xf78ddb05	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/industrialio 0x05af6f3e	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0x1a1de9bc	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x2b4deae2	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x31ddf5b4	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0x4f389235	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x50008d79	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x53cfd9ab	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0x5cc52946	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x67bd7d78	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x726c6243	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0xa15e3fb5	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xa5bb430b	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0xa6aa973f	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0xc000ee2a	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xda766f3f	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0xde4b5448	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xf6eb6008	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0xc5f4329b	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0xf374289d	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x74f7bcd6	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xd7eeb137	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0xf171f867	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x24a567b1	st_press_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x4b98969f	st_press_common_probe
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x133bd986	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1ea5767b	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x32a8402c	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x701361af	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x8ccc1a84	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xf298ec5b	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x028b8869	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x15677a9a	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1d8f2093	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1dbbb44d	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x20449aa3	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x6c852213	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x6f543411	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x7c348587	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x80da2129	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x828af252	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x8d4b8b35	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x8f8c2ee1	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x913f1c55	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x994560d8	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa2ef602e	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xc1da56c5	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xc3b0403b	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xdec41a86	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0145ae6d	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x020d6767	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x063c0297	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x09732287	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0e2d9144	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0f759549	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x12b44ac4	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x16f43341	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1920bbe5	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1bbb5be3	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1cb50cee	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1d61edb0	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x249f643e	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x25feb9f5	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x26471304	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x29d34f4c	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x34cdb330	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3623aee5	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3845d76b	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3b534f35	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x40116af0	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4070ec9a	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x40ab5e79	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x40e1cc29	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x43364abd	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x43e47158	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4747914d	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x49f8310c	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4b8d9f9a	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4cd2cc27	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4fa28539	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x520b2638	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x526714db	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x54a39df7	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5a0c1fb9	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5e0cf57b	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5e93ec64	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x63d38c5f	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x65a0dfd8	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x702bdfc7	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x71d8512f	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x72819f16	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7323222e	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x74f6f22e	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x76d65725	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7726ca73	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x78bdc5fb	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x79740e27	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7e48d695	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x820199c5	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8a18fb20	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8c5e3fc0	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8d0cf383	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x91c827b6	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x93181f98	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x93f777b4	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x95b387e2	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x97060665	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x99cd43e7	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9adb7092	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9edd2bdd	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa23299e4	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa3929b17	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xae32fd24	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb1048d86	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb1a312e1	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb672ddaa	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb78418cd	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb7e88346	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbdb7ece8	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc3b0891a	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc4cf0d0b	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc630bad5	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcaf4efcf	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcc4907cf	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd30071a2	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd4feebb1	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd51149d7	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd79c728a	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd99785bb	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdc44bd43	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdd225bfc	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xea52f663	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xebf5e094	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfa508e51	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x1573f647	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x1a246a72	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x25b0ba8c	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x30846c86	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x39d425bd	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x515262ed	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x604cdcab	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x89fd0476	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x91e8d78b	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xb561e8e2	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xcbeb8ebc	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xda3addaf	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xe81eb813	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x05d497d9	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x5328d7a6	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x6615fd30	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x79469f7d	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x7d133c54	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x8c4484a1	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x8f747852	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x9a1cd50d	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xa014f86e	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xdad6db0e	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf6c1b0b6	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x4fc98aa6	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x6d01e846	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x15243dd1	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x30eb301a	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x330b8476	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x41f12dce	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x599bad46	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x67f45c68	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6805294b	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x7a649804	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x8b70d01a	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x92c5e629	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb1a7753c	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd23a9061	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd594680b	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xe9133ea0	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf3091eb3	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x015cf147	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x13443ee1	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x2d1b9ba1	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x2e88df6e	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x4a5aa925	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x586604f4	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5a9befda	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5d043236	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x8903ae33	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x8d3cec38	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x8ed5e118	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x92ca246a	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x9680ed58	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x994821b7	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa15e3024	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xb403fdfc	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xba473f2c	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xc8d0ad20	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xcbab717b	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xcc5fb1e7	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd9026b1f	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x393426fd	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x745522d3	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xa150f579	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xda244571	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xded7aaea	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xdf211b52	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xf7f94eef	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xfa6ae38e	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xfbb13df9	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/input-polldev 0x2129d558	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x9aff20cf	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x9cba6614	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xb6a722e6	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xe694aada	input_register_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0xdc0841a3	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x0fe2527c	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x3d6a99ca	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xb5d7094d	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x011427f8	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x17ce7f4b	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x2737ef5b	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x28d7546a	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x4153754c	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x9f42ec8b	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xaab1cb67	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x215b2f18	ad7879_probe
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xfa784896	ad7879_pm_ops
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x0a205933	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x161840e8	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x481516ab	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x5bbafd8b	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62f9e147	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7d43c839	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f6924aa	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x94fe587b	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x98eac0a0	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa7c4fd6c	capi_message2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc10fe128	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe8ad9bd1	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xf0ec0aee	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x1166d21f	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x3630b302	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x40591cf6	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x65d0b40a	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x6719f22f	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x7f48bde2	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9cec3701	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9d67959a	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xb118a9a3	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xb1c761e4	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xbc3f3158	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xbdecbae1	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xe4b673d5	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xf498f99b	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xffa9d254	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x01f1bfb9	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x0eab1a1b	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x1704fe96	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x1a26d438	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x9782cb70	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xb15405d0	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd07ebbb8	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd9aee56c	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xdd3fc16e	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0x29562993	b1pcmcia_delcard
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xaec3240e	b1pcmcia_addcard_m1
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xea620116	b1pcmcia_addcard_m2
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xf14bf8b1	b1pcmcia_addcard_b1
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x0310a44b	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x0cca7df7	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xad1fd393	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xf11a5d89	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x04c23dc2	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x499e73a3	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6a04d6dc	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x0253d67c	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x17f873b5	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x467f650a	isac_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x77322151	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xc91186c5	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x992470cf	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xb4a2350f	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xc6eafa5a	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x24bbea31	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3b374195	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x43417c05	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x49089907	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x52750a1c	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x56bcab56	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x5778c481	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6444c7a8	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x691d69d8	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x761ea866	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x86ecb20c	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a6eca66	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x9077dc06	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x9cd4cc38	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa0c90f3d	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb142e5af	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb3f659c7	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xcb8a6995	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xcfbdfd21	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd11fc074	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe31ddf80	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xeb11bb69	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf6019995	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x0c4d0956	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x0efa2951	closure_put
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x10dc0d06	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x66d28e22	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x6969b5d8	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7ad2c040	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7b55ca4f	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x9e8b3cee	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xab2d2b84	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xac097021	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xad29a6f5	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaec09a2b	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xaf77343c	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xc04554f7	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xc0b9ef00	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca580595	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd1a02451	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe47e0829	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe67c2d16	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-bufio 0xa7978f56	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-log 0x23524201	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-log 0x83c39c8d	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0x949e5564	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0xfe9a61f4	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x0e118cbf	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x29eabf27	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x358cbcb0	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x4fca5c58	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xe6caaf7e	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xfeb7a81b	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/raid456 0xf7c97b73	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x040cf1a5	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x3f647275	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x43443728	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x63485b3b	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x65d3b911	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xb4a6c404	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xbc1af1c3	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xcb0641f6	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xcc8c3035	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xdef2180c	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xe549a74e	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xe696b174	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xed3b50a0	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x35306197	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x903a0f52	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xa13757b6	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc72da78d	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0xf86b0cca	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x4a2405fc	tveeprom_read
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x5eacf2ea	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x09b765e1	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0aab97b9	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0cdddc43	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x14d08350	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x169fd2a7	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x16f75efb	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x19591134	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x22d6ce4a	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x28ee2ae8	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2c625e88	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3005d8bd	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x34e53620	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3f7224d5	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x436936b9	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4d3b9a9c	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5978d63b	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x65886421	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x69a9ac6c	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6ccdc299	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x73769df9	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x75274f0e	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x76262ff6	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x78d62338	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7979fb89	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7ba5d8bd	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8e47dce5	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x920028d3	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x92e5d612	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x96f1af9c	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9e8d298e	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xab9622a8	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb0b1ea95	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc131dc03	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc8368b5b	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xcbe1d471	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdb576668	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xed481421	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xed81e0dc	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0xf8a2aa5d	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0x7f5ba161	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0xf50a3373	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x25984ae5	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x358b1b8c	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x37b71878	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x3bf7874d	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x63cc6938	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x93f7e480	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xa7b8b16f	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xaea3da1d	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xe1ee624a	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0xc7b1bd13	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0x5fc3021f	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0xfc299dd0	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0x92555d83	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0x33b0510c	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x0afa59e3	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x3df245f8	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0xeaf7426c	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0x95b33b4f	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x07192c91	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0xc0b6ff8a	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0x3fcda2af	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x2408fb3f	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xce4b918b	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xdc19a293	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x0774d0f3	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x25de784d	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x70d49cba	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x8c4783e2	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xd1c6ac49	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x03891652	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x1d45d5df	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x2bf3d67a	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x354463c1	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x35bafe83	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x38b8e7b2	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x40c00f4a	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5d3c1f26	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x723a9d28	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x767ea19f	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x868a3c7f	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xdec14efe	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xe0a8d410	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xee72c573	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xfdbad58b	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0x2da0ec4c	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x09674575	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x102352e3	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x24e79c30	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xb6898c95	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xf0492ab8	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xfb010400	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x87d5ab26	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xa8804454	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xdc4c59e2	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xee265411	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xb65b9c0c	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xeba649f0	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x3c0713c2	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x42879b19	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x49dc9a3a	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x4e06a1ac	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x92fc8cd8	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0x002e5b85	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0xdb5697a9	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0x28b9b2dc	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0x09d58189	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0xd54ad8b5	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0x523f229f	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0x47c98818	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x7a209d3e	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x43876a1c	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0xe4c5ab0d	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0xf754289e	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0xd5597302	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0x71a74eae	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0x4789de8d	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0xd88a6935	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0x7a7226fb	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x8ea488f5	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0xb9983da4	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0xb94a657f	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x3261609f	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x3d589d48	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0x74f7560d	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0xc0311c98	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0xcda218d4	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0x3db38d5f	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0x6db6f4b4	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x32c1d64b	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0xc71cc9c4	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0x5af969d0	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0x7728b898	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0x25aa701e	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0xccf648ad	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0x245be5d5	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x40cee44f	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x5867de9b	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xa781f244	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xdbf50f26	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0xba77a2d4	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0xd5b90ff2	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x2d023f5c	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0x5f31d108	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0x0c8413c9	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0x48a5bc15	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x270e3707	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0xfd3e6a16	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0xf9849d0b	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0x948e244c	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0xe4233028	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x0d05140c	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x0e5c2c16	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0x9e9c6f89	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x6a017622	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0xbc602402	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0x992f0518	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0xfa5b9f2c	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0x17d3aad8	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0x331b7b1b	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x0d5c3d91	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x394995f9	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0x5bb91991	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x744a5054	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x91939d8c	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0x12a0fa57	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0xc114fdd9	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0x2b42e69f	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0xecc4aac6	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0x05210a13	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x333816bc	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0x2f21315b	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0x27e729dc	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0xc5051553	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x36603b5a	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x400eea3e	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x507d4d18	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x71152096	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x8e4cd845	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x9c71516a	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xc6c7d8b6	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x1cce4a32	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x27149415	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xdadd029c	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xedacd8d7	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x3b5ac3e4	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x809be7e8	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xa1feae55	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x0409f3a9	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x535eb9ba	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x7dca2364	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xa1f3f06e	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xa62e2649	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xaa91ef8d	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xbaa5d98f	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xc505f918	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xd9a1dcdf	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0xfb888142	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x02ba98cc	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2a927778	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x4cad8468	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xbf2a5c02	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xd2f874cb	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xbb7f6deb	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x282a624b	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x33379378	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x5459f0f7	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x70656b21	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x8fedb5e6	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xaca556f4	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xf183ca8d	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x24a63b41	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xf703ace2	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x099defa4	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x8e006bce	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xa42b4275	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xfe2a0ef0	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x0445a520	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x05ef6abc	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x0ab718c1	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x171548fe	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x44849459	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x53b1aa09	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xa023dd37	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x01292129	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x01958bd7	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0932d4bf	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0c5dae01	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0c675c6c	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x127b597d	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4a89c528	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x56bed297	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6f633b5b	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x73d7ff38	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x93f4056d	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xaa1ffaa5	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xaab9a70a	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xbe4e7070	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc03c6b8a	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xd9296874	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xdd7f7c5c	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe648b4f3	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xef575c2c	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xefb2b2bb	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x0b7b2420	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x1f68578e	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x1fd12693	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x29172e11	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x34cb39b4	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x42a922fa	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x447fc2ee	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x6115a3a3	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x67385d32	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x7bef5244	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x875904cb	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa372376c	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xb0949c1a	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xb4841404	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xc68de535	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xc898623c	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xe1207869	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x10f7410e	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x10ff008b	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x28971448	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x57b97f4d	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x6a42752b	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x6cd8dbcb	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x811b71ae	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x96ccf269	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xacd74a9b	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xb2a8cce4	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xd93eea96	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xf8bc43ed	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x6ccf0049	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x6c3af5ed	videocodec_unregister
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x85057ba3	videocodec_attach
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0xa1f529b3	videocodec_register
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0xb6c93c37	videocodec_detach
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x1aa8a2d9	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x499050df	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x56fbffb3	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x6949667c	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x95811550	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x9fb404e6	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xcc4167a0	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x05eb6ae6	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x1fff7d3a	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x25c4dd1f	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x2b67064d	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x3068d448	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x667a245a	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x7689d9e1	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x2a7aa025	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x3e5fb922	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x55058bc6	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x67015637	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x83d9b60a	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x887eb941	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x950070eb	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x98f80302	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x4bc21b81	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x641233ed	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0xba995aef	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0x383b7269	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xb13a4652	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xb7dea7fc	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xf9fae556	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/max2165 0x60fd2974	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0xaf2616a3	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0x19a9bdb9	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0x21e10a9c	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0x157d20b3	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0x1b440b74	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x6cd22399	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0x2d453c9b	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x750a1a79	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0x64dd80b5	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0x0f67289d	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x0fe1fd16	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xc8293624	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x14c6c6dc	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x16723177	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x1fb8637e	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x45fcaaef	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x5ab5b363	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x817d5764	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x94e84801	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x99cef694	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xe49597a8	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x120cae0a	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x15cd535d	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x18d0e12f	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xacdf2b2d	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xc5cf5c14	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xd05aaeef	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xf1cfbf8c	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x7aa03e2f	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x0961848c	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x283662aa	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x3b88bcbc	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x3fc73147	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x561445e6	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x6f9a4d8b	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x75a51d0a	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x8ee57596	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xa9f793f8	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xd92ac2a6	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xdd5ec94d	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x223154a1	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x582868b4	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x5588572b	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x6a476190	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x84278b97	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x8f0a1403	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xb094c9c8	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xccab860f	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xd2cce6c8	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xdc3ea782	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xe5bd5594	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x438acd7e	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x65ca40e3	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x7d286d6b	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x813cdf24	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xa5f28495	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xa73e1058	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xb1722497	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xd78e6bc3	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x166d088b	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xd6b2ffde	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xd78d63f0	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x10e58be5	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x3b228a2f	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x0e3fb33f	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x5a70a440	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x67dfc476	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x279e889d	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x64c12876	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xa9661e08	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xb926a6d0	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xcde15e28	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xd06c290e	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x4fa73a57	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x56f5aa10	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x0b5ce97b	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x160f1cef	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x320312eb	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x69334c90	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x758df6e4	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xf099fef7	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0x8f310052	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0643c5a6	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x08ed703d	v4l2_of_free_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x09d795ac	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0af82c9e	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0b7d9986	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0c6ee9f2	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x120a0399	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x15e49b10	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x17d2745c	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1ccb976e	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x22c87317	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x252be421	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x268f1ad2	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2b4d2d80	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2c14d17d	v4l2_of_put_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3506a132	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x35cfab12	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3a22c649	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3abad828	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3c92d95d	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3cdabed1	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3e407ef1	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x40b1348c	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x41828d51	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x449cea7b	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x53ccb74f	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x58c998cb	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x593d9dc5	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x599cf4fa	v4l2_of_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5a6bdac5	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x631671ba	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6aedc544	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6dcc01fb	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6e05867b	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6e23b74e	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x834f5801	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x83d58555	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x848f712d	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x86d1522a	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8a2e42c4	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8aff4536	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8bdf8ca3	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8fbe5da1	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x939151e1	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x98e51d31	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa3f0bad5	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa5366a55	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa8514e8d	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xab561a90	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xac4fa60e	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xad418b9b	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb005e449	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb17ad9af	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb5ac304f	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb98d54bc	v4l2_of_parse_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xba2ae530	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5a583f	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbcfb3f4c	v4l2_of_alloc_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc950f16b	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xca4de680	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcde13d72	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd357d93a	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdb9620bf	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdecdcb36	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdf595f56	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe3a7a93f	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe8536184	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe9bbdc43	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeaeda9a0	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xebd99706	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xee31b59c	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfa989b73	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfdc29bc1	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x0166e791	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x0df53b52	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x37155f61	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x39650806	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5b5c17c8	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5e32d5ec	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x89a25b66	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x8c9b5da4	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa26b47f5	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xb140b5ee	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xbc86d4de	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xbd88dc98	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xccc45746	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xe6416b9e	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x05271393	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x067676e9	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x08926cdf	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x08fe1086	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x16ef2199	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x225b2dc2	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x22d1340a	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x239587e4	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x23adfcff	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x28707b2e	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2e067b48	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x37b8a8cf	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x418b05eb	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4721a3d2	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x58120c52	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x69f38828	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6b91f186	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x756bb072	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x832b475e	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8532e09b	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x85c597c1	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x87c9fcca	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x96f31d57	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xaf94e287	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xbf0010ef	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc2c892d9	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc7797629	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdb83b9d8	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xfceb965e	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x07ec5b1a	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1981fcbd	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2cfe9386	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x41f133cf	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x459b0ec6	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x47f5f994	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4ab05d48	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x53617d03	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x642507cb	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7c7d49cd	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x8cd3717f	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x8e024a74	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xa0459e12	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb098a8a1	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb4c05a1c	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb7ff010c	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc1cb395e	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc5661e4f	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc9595550	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xcab3c858	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd32f51b1	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xdbdb7a4c	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe5a7641c	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xec7b5795	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf168d115	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf33e90e4	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xff0298dd	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/mfd/dln2 0x807909b3	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0xa87600db	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/dln2 0xd60e8218	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x07e82859	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x11ce356c	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x1c434636	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x2d933189	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x4cb5a8aa	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x5bc6caa5	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x61751803	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x7ae28860	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x97eb918c	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xaeab79bf	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xb0f0c7f3	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xd916a169	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf6ab7eb2	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x6dd8e1c1	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0xc3b68c5b	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x4763ae84	wm1811_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x869d6237	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xd801aca9	wm8958_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xea3b1730	wm8994_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x57c1ba5c	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x695dedee	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x37cbc168	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0x27b59c29	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0xe9d53e4a	c2port_device_register
++EXPORT_SYMBOL drivers/misc/ioc4 0xa27ba3bf	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xb2c66acd	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/tifm_core 0x00f8126f	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x21996685	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x39f86aa1	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0x5aca857e	tifm_add_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x64d56bd1	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x8c1d6541	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x9b3e0458	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x9de372f7	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0xac2ef4b0	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xbbdd2876	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xd53afd69	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xdf57a4d7	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0xfbc4b44d	tifm_eject
++EXPORT_SYMBOL drivers/mmc/card/mmc_block 0x64badc34	mmc_cleanup_queue
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x37f009b0	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x4809ac6c	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x50b316cc	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x772b10d3	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xc9b8755d	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xcd78d1e0	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xfe0e4d14	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x4b9ce21f	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x8e4e991f	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xa2c6ed08	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xc7b1ebd1	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0xae37755a	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0x58004079	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0x7c989425	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x16ce9fae	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/mtd 0x6881da23	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x2b5bd34d	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x8ba22952	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x13a14092	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x65bde34b	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x7e1b8eff	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x84d59e41	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x9b3352e0	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xb26f21a4	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x69c7cf4d	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x8452c99b	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xc22c347b	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x189d5e39	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x65791289	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x2eb0e9d7	onenand_default_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x39f0bb41	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x5b0ddf13	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x93dd3f27	onenand_addr
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x5528d902	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x5f0e24e6	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6327050d	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6591ce2a	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x712772f4	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x8b03a024	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x8bfbc243	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xa0abfc98	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xad314250	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xb0d20f0d	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x2bd5206f	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x8c04de42	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xf9663596	com20020_found
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x23dba2b2	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x25a23267	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x352b213f	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x6cf35e2a	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x6d3b7200	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x788985c4	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x9944ad22	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xaeb27358	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xb5f00af9	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xfdfce5bf	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0xacf99153	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0xe1c5571d	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x0bbaf9b2	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x3b3024f5	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x52b96a05	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x5517369a	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x585f9ca7	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x5c7bc16d	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x619bc724	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x6855bc04	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x7e1d83a2	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x947d4d81	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xa94fa28e	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xb3f9e4ca	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xb8128a3c	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xbd7c09f2	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xbeeb3cab	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd0f5da74	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0019b081	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x028bf510	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0d505ec6	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x2813642e	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x287f6723	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x2ae5f017	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x2bcf0b19	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3856b0b0	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x493beb41	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50f5155c	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x5118a2cb	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x556972c5	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x59f39023	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6ce3ad3b	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6dbf4786	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8574bb15	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9874d089	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9d305c59	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa4341e24	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa5f9f244	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xaafbf9f7	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xad4ff4a1	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb62e65cf	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xbe821ef8	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc31fe90e	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc34b98ea	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xcb9c06b9	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xcca67b40	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xcd12b6bd	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd087e41a	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd1e52d6e	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe20a44c0	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf1e17dde	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf5346df5	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x098fe98e	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x32c78ad4	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x60657651	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xbb12191d	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xd09f6b67	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xe7a5fe35	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x66799694	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xb0129373	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x03e648ce	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1109a4a1	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x121df6ef	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x17fdcd67	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x352fc4f6	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3576746f	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3be30237	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3df62a08	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x402a4528	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x470c90f3	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5058cd91	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x518c9ec6	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5610af4f	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5983d4d4	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5acc69be	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5c1a54a4	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5ea41f42	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x65e2b48f	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x680c2bdd	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7d4b90fc	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8a4b15e4	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8c646280	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa15909a6	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa302be5c	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa5a77141	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaad6329f	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xab22dd16	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb0234569	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb0473a5c	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb053846b	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb739841	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbd247015	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc436c8f4	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc673846f	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd315eea8	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe5c7521b	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe99b1118	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfc86be00	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0bf8b68d	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0f6e58a7	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0fbe7737	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x19c25660	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2640cf3d	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x28b9d5ba	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2b005155	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x374a9c47	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x518d550e	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5b8fc4a6	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x61f821a4	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x64fa8889	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6fe39818	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x720d3be0	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x75e1d64b	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7b1c0980	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7f2ad514	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8d9d787d	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9053c880	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x91f69b9d	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9cdcc24f	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9e204e68	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9f349ef2	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa0f4d6f6	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa4f65669	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa9614472	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xaa0ff92a	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb03e08ee	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb57131d8	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb8b2ca26	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc064ad3d	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc13bba3b	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc3d64739	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe21366ca	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe9f2193e	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf5a90d0e	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf98a8123	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc4052f9	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x2c16129d	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x449b1842	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x69813353	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x9f8c8744	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xa2292ea5	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xc4952f7a	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xcb5c8545	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfff690fe	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x755706a6	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x4781354e	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x809fabb3	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x8c521f99	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xe725d20a	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xf8040501	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x0037046d	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x00867d99	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x0af4e5d4	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x23210ba1	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x63a4fbe9	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x9aac8949	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x9f03f8a5	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xbf2509d4	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xdb0b503a	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xde262005	sirdev_receive
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x10131943	mii_link_ok
++EXPORT_SYMBOL drivers/net/mii 0x78abe5dd	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0x88dd512f	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0x8c67f8e1	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0xa07b56a0	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0xa5c9eb26	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0xc28b05a1	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0xe3bbb07a	mii_nway_restart
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x430fcfe3	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xd45b431a	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x0f235414	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x17e23847	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xf38cef99	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/vitesse 0x5140cba4	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x35706b5a	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xc8e61c9b	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xefefc858	register_pppox_proto
++EXPORT_SYMBOL drivers/net/sungem_phy 0x93c19436	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x1688dfb2	team_mode_register
++EXPORT_SYMBOL drivers/net/team/team 0x3e194418	team_options_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x8189a551	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/team/team 0x8b8935cf	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0xce0641cc	team_mode_unregister
++EXPORT_SYMBOL drivers/net/team/team 0xee06c6c9	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0xf068f5cb	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0xf41a5195	team_options_register
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x8e480a0a	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xadb5db8e	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xd38bfaaf	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xdc4df6c6	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x0032dc9e	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x2093513c	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x21583e8b	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x2707ba29	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x3e110d39	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x4b5c3bb6	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x57aea446	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xa64c1eea	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xbc7ccdb2	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe29a312f	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe7256ef7	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0xfc982217	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/airo 0x4dd8642e	stop_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0x629b0600	init_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xd4edb341	reset_airo_card
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x0ae30de7	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x2d3b2631	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4bf6039b	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x6b4c5665	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x6c27bd5f	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x76e0eae2	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x7aa2e70a	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x95906021	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb2584357	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xc244f6ec	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xc53297d4	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xf8c8d00e	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x008ccb5a	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x21f5b3d6	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x3210041f	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x51b16380	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x55ac3bb7	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x573ace21	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x6d56a000	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x94886842	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xad17a1c4	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xae049ba0	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xaf56282a	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc380f638	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc7625268	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xe1141748	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xfdacf3bf	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x2ac1a7c3	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x5eb1163f	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x8021ab92	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x98e70b39	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xb78c6df5	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc8c1733b	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcf810d0e	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcfd27c83	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xd8743cb0	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xd9d83427	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xf4f7067b	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x147f8509	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x185cab23	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2843ad98	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2b54949f	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x39a7d68b	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x497ff85b	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x5353620c	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x603c63e0	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x6c35fd4f	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x6d150a40	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x758f0fbd	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7aa9d877	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x8e6ac933	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9285a6b1	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x98148440	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x984fc4ee	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9d0095c4	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xab95bd01	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xaed641f4	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xcd8e8a64	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe1a33ae0	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe628854c	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf11e6307	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x02aa6a2e	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x05904272	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x086be4ca	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0870fe93	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0b238616	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0cd94071	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0f711e0d	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x10d7d72b	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x116f0ee9	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x160bb256	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1980f297	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1c5ea9cb	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1d6b3384	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x24de8f42	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2535ffcb	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x274ff8c9	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x299abc5a	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2d3b0133	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2d612e5d	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2ebc58af	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3019dce9	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x30d9cc85	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x335a96b6	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3c837648	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x41194e86	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4192410a	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x42e98429	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4e4d5acd	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x508bf59b	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x50adfede	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x50fda9e4	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x51b1648b	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x54587c46	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x55d700af	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x56fe6e38	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x57d92d75	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x57f335ed	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x58275e39	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5d8a5180	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x62c5337e	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6362bcb4	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x666cef9e	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x66728b34	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6888c209	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x68c72e53	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6a8fe889	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6adc9f61	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6c35ee28	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6cd9765a	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x71c1d45c	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7a80e3f6	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x81f16793	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x868d6ddd	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x88f459b1	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8b235ad8	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8b24558a	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8d6214f8	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x906e4ded	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x955f99ae	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9b3a279a	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9ec1aed9	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9fa155da	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa8d4a7f4	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaa1d69e2	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaba58b4a	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb08f6824	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb0c57608	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb2ab5a38	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb498003c	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb4c713cd	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb53c1ea3	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb6635700	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb6adaa92	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb6fecf12	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbb13ef97	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbb76e8e2	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbd81ed62	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbe55daf1	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbef8c1b2	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc1919c9c	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc43d882b	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc52eedc2	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc59ac80e	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc6804c2f	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc8ebea7c	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcb63006d	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcd9a284e	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcfa2a7b4	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd28a16f0	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd2d24e3f	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd475597e	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd6d64c2b	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdbd4662d	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdc31b7ba	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdc86278f	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdd592342	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xde4e1d4b	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe372656f	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xee45700b	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf5e98395	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf77483fa	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf890079a	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfb4d1c77	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfce4efd8	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfe4b736e	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x638c6fa8	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x9f0fd786	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xeaaf6458	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x06a01444	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x1c666f71	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x48a68b42	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x524a84b9	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x5d7aa6ba	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x7936c7e1	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x80b5fe8c	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xc0f75263	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xe2fcaf06	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xe362b178	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xfa09da4c	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xff230abe	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xff2446d9	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x02402af4	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x05640dd1	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0ad69602	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x11bcef40	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x18934de2	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x20e3fccb	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x225157db	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x2dd00135	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x327fba8e	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x49588382	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7704b20a	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8327f0a8	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8603eec4	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8d10c838	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x96360770	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x979c6ead	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x994265a0	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9d16d245	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa0e7b912	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb6a78866	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc0e9d3d7	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc6930af6	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc866a0c4	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xdbd4fa9a	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xdcde3e44	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xff8b855e	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x1246c7f4	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x246b64c5	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x2d6c1511	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x2f12b0cf	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x38c64c88	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x445fdd47	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4f982a27	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x6454c2ce	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x655b5af6	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x7474b058	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x74a6ddcb	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x74d3ab56	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x8c6e8eb9	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x8deedfb0	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xc5b86438	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd0695a54	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd6baf466	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xe36a458a	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xee53f8ea	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xfa26c97e	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xfd906023	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x02d03642	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0bf99571	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0ddee55b	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x14c9d8d2	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x180ce01f	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x19fbff74	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1b462714	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1e319b83	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x225b41f7	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x22fcd177	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x246b2e09	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x256b61e4	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x26bca088	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x287821d1	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x28c6ee32	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2fcd76c0	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x31752ef0	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x35378a02	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x390ed6a8	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3cc50d42	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3cd8a535	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3d6c7c10	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3f4fd393	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x428ab396	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x47190c34	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x472e2121	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x48ca7359	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4926a826	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4a6d1695	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4c3ac897	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4c747e09	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4dd3c632	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4f6654ff	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5070ca75	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x50810e33	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x513352d8	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5c1d1f4b	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x67736ccf	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6b135643	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6edf526f	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6f13cdd6	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x72d4afed	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x73c82c4a	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7471df96	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x758d4fb1	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7c29d603	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7ee071da	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8205785f	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8263d0c5	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x87b6bce7	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x87e3cc44	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x89272b35	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8ab26c6d	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8b718503	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8be975d0	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8d3bc513	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8f426e44	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x93079ccf	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x95151e34	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x95d6f8a6	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9832f1ce	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x992cff92	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9a147271	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9a453042	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9adb8c38	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9f0990c2	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa2f679b6	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa75149af	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa7911224	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xaad27ff6	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xacc08e76	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb2c0759e	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb410781f	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb4bec26b	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbf564883	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc6ac5a3e	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc6c02dee	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc9712361	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcb87080c	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd2ef641f	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd4fa67be	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd66d7b20	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd675a581	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd7a8e0d4	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd7d3ae30	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd855ee95	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdbb94a1f	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdc6ca60c	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe0e7cf72	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe7518cdc	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xeb56ff47	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xec90dbe0	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xee7ddea8	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf50478be	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf5ead12f	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf656823a	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf68f7518	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfd89076b	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfea47b31	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x08c6664d	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x4379786d	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x95a8ab3c	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xa2b6ec39	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xb69add1f	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xcd60e86e	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xd4f50457	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x194890b6	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x59d51819	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5dea5bf1	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x610a64ff	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x6a75fb05	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x6f0b62a4	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x8b873acc	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xaf2e92bd	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb3e046a5	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xc05e09d4	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xcb8792c9	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xce07517a	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xce0d19b5	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xd6ccbf0d	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xe148bb98	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf02b38b3	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf9d21c74	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0xbf878306	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x02637d39	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x06d984dc	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x10ab4447	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x18aada53	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1d178a6f	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x25599e75	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x346449a2	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x38ac4918	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3ccc9379	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x43c93e0c	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4c89e674	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x5cd8f39c	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x617fd86f	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6899da24	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6a604029	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7f5203be	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x81b2e3d5	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8531d2e8	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8c3b9dcb	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8ecf1951	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x9328acc8	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x95c1cffd	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa21945ab	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa671c86a	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa72b2e92	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa9ade2ba	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb199c00e	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3c83ba3	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb43d2a5f	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb7d2edba	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc71914a2	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xcafbf78d	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xcd445662	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd0249ce3	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd147f18b	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xda5526f5	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe0b35787	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe1800683	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xec345800	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xee43ca16	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xfde21b01	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x54e91fe7	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x75282873	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xbef2dc2a	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xd8ba84f3	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x50b1f0f3	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xc56537df	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xcc909681	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xfc5fd94b	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x048b1c18	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x163083b8	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x200d0d04	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x24690e01	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3536add5	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3626f688	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x37d0d8b4	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3a0d2a45	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3e233d05	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4145a463	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x43e2f591	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x46c301ee	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x51d40085	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x52fce918	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5377a7d9	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x53a1d3de	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6662ac00	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6ce89378	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6f253f1c	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x741dc920	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x7aa1a6e5	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8835e1e5	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8e4ad8c4	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x95d2d4a7	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbf4e9912	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe2e0e6c8	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf11d2d31	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xfd4ba999	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x733f3efd	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x87865598	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xa3c70211	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xddb59788	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x16a4b5ea	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xc8d9f53c	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xdcaa4e7c	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x592fb517	microread_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0xedc6aafd	microread_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x09dadced	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x66a2c78c	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x7b533a02	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x473998d4	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0xb7cca5b3	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x44de713c	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x6e03336e	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xbd820041	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x09d9b66f	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x3fac2d75	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x47180e41	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x7770621c	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x807fdac3	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x95ade8e4	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x9da8edc5	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xa4f27285	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xb6d1b078	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xd378122a	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xd8450038	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x0a1fa725	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x1026abc8	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x19c7c42a	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x1b3ccb25	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x2d94f1b8	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3967d91c	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3c1978f0	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x4d029226	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x60dbb878	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x7eaaf991	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x7fa1cbf3	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x969c1286	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xa1f675ef	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xb697e016	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xd3d4db48	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xdc4aa940	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xdf205abc	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xe2acfe3a	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/ntb/ntb 0x505b19b4	__ntb_register_client
++EXPORT_SYMBOL drivers/ntb/ntb 0x5d19c755	ntb_link_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x5d972f31	ntb_set_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x72e9894e	ntb_register_device
++EXPORT_SYMBOL drivers/ntb/ntb 0x96a82e89	ntb_db_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x98c9cea4	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xbefa674c	ntb_clear_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0xf1b9951f	ntb_unregister_device
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0x63daed31	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x07171981	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x09e9fee9	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x11c9bb65	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0x198abfcd	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0x1e094537	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0x224eaae3	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0x2a3fe82e	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x34850fa9	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0x47170b58	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0x473135f2	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x51383502	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0x575c06a1	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x580265cd	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x5ea34b71	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0x5faf8c2f	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0x68360cfa	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0x7183a63c	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x8b5be4c1	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0x8e373717	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x97ccbb6d	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0xa23a3756	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0xb4469ef3	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0xbd9794d3	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0xbfef7ee6	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0xd368445b	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport 0xda0d13e7	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0xea3fc6a1	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0xea4ca501	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0xeb524588	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0xf942464d	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0xfa127052	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0xfc0abaf4	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport_pc 0xd2fdd306	parport_pc_probe_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0xe85ad029	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x03d3f904	pcmcia_request_io
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x09c9397c	pcmcia_dev_present
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x0afc7fa6	pcmcia_register_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x0c0bbfa1	pcmcia_get_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x1bf6cd36	pcmcia_release_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x460bf936	pcmcia_read_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x46cf2822	pcmcia_fixup_vpp
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x5d3e53a8	pcmcia_write_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x69dad294	pcmcia_disable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x6cf1c0ad	pcmcia_request_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x6e09136b	pcmcia_get_mac_from_cis
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x742f5665	pcmcia_parse_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x9b32bb41	pcmcia_loop_config
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x9c16df50	pcmcia_unregister_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xa12f1397	pcmcia_map_mem_page
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xac09cccf	pcmcia_fixup_iowidth
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xb40dd095	pcmcia_request_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xc6a6f53f	pcmcia_loop_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xccfcbdcc	pcmcia_enable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xfe2cb77a	__pcmcia_request_exclusive_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x0279d82a	pcmcia_get_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x0a8bb294	pcmcia_parse_events
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x173c549a	pcmcia_get_socket_by_nr
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x212db8d2	pcmcia_socket_list
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x22bd109f	pcmcia_socket_list_rwsem
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x30ce1f7a	pcmcia_put_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x843916ba	pcmcia_register_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x9c99ea67	pccard_register_pcmcia
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x9d3b7535	pcmcia_parse_uevents
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xb7159aa7	pcmcia_socket_class
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcf97f3bd	dead_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xf80e2b65	pcmcia_reset_card
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xfac36f9b	pcmcia_unregister_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0xab887fb8	pccard_static_ops
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0xb4023694	pccard_nonstatic_ops
++EXPORT_SYMBOL drivers/pps/pps_core 0x38691574	pps_register_source
++EXPORT_SYMBOL drivers/pps/pps_core 0x5d4c2001	pps_event
++EXPORT_SYMBOL drivers/pps/pps_core 0xc026bed9	pps_unregister_source
++EXPORT_SYMBOL drivers/pps/pps_core 0xd1892fcd	pps_lookup_dev
++EXPORT_SYMBOL drivers/ptp/ptp 0x3c6b48e2	ptp_clock_unregister
++EXPORT_SYMBOL drivers/ptp/ptp 0x7580ace2	ptp_clock_index
++EXPORT_SYMBOL drivers/ptp/ptp 0x9db8a332	ptp_clock_register
++EXPORT_SYMBOL drivers/ptp/ptp 0xb3bff2c2	ptp_find_pin
++EXPORT_SYMBOL drivers/ptp/ptp 0xef01da08	ptp_clock_event
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x1f5f50ab	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x38bcac9c	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x4ac28159	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x53d7572c	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x83d88a77	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x95b2eff2	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xab06da24	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xb7206bc2	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xcbe42876	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xda00d91a	rproc_boot
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0x087d2c83	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x7e32f4eb	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x81127521	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x8fe96b34	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xdd75b98d	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x1237c79f	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x19a001c1	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x25e6ad8c	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x2b9f0b28	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x4c57950a	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x6da3cdf3	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x70e2dff8	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x91c4e871	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xb7b6f162	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xbd95e0c4	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xbddfad7a	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xe210bb5a	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x00cf6b94	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x02e942c5	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x06ca172d	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0be1aec5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x14718517	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x15f63e23	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1791d17c	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1e769627	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x28907969	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2b110724	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x30968738	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x315d77cf	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x38f65af3	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3b54d539	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4c0cce48	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4c27b1ad	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4fbc436b	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5f195c00	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x618bbd8d	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x61d7fc7b	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x630b87ee	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x63608bb6	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x647e0617	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x74bcb850	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7791373d	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x801145a7	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x845d5db2	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8a0d6b98	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x981e363b	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x98237e7f	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9a3e683b	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa1c2cee9	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa2d938ad	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa32a756b	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xadcfba38	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc20e415a	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xce12b508	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd0a5964c	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd3a03483	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd4335fb8	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd4d5d7ff	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd5169a21	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd722f8f3	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdfafd231	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe01aefb1	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe13302c7	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe68b44bd	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe8aa804a	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf708fe15	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfb1fb947	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x223cf8de	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x6e7fa64a	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x91dffb32	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x938b788f	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0xa761c547	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x033663d7	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x04df46c5	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1b1a3ffd	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1b4ed244	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1ce410bf	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3061d976	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x30c8a58f	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x31802d9e	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x347be573	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x379920cf	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3e3c1194	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x471ad10f	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x65756400	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6b889847	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6e4082e4	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6f51f3a1	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x767cde1f	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7df696aa	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7f6a2b96	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8011dd80	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x85966916	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8cac988c	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x91d9c08d	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9ab30d39	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa40fa629	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa4b6f1d5	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa5265687	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa5abd949	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xaaff5c7e	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb39a9d05	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbd2ddf95	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc16b86a8	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcd99d16a	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf3779c83	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xff0b48e0	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xff0cde23	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x273e764e	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x4271cc92	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5ba58741	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x9768e8a4	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xd3e18120	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xde27c16f	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x07687e16	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x094494cf	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x0c60ec8f	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x0f84f45f	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x11d7bdda	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x381e875c	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x5fbc28ef	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x803fb15b	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xacc81082	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xae91614e	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xd0017bad	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xf75ae556	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x1f55cd70	qlogicfas408_ihandl
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3fd8cd71	qlogicfas408_detect
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x7d7927c9	qlogicfas408_biosparam
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x8446894a	qlogicfas408_bus_reset
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xae0657e3	qlogicfas408_abort
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xb095c099	qlogicfas408_disable_ints
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xc7bcc389	qlogicfas408_queuecommand
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xe76b3b20	qlogicfas408_get_chip_type
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf2b95199	qlogicfas408_setup
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xfe15d252	qlogicfas408_info
++EXPORT_SYMBOL drivers/scsi/raid_class 0x1d1e442b	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0x234df9ce	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0xbb7d4439	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x04a6853f	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x37f08f6c	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x3fb2385e	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x42d085b5	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x4d2bb653	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x821e1262	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x83ae8d42	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x95f13565	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xa82453d4	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xb73df3d1	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xcbbd20a8	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd8c8f8a0	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xec577a42	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x05e0a5c6	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x095fba4a	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x242960c0	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2b5aa29c	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2da96b8b	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x3334d1d5	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x3a03de02	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x464ecae4	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x47b6396d	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4b45b42c	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4d56f47f	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5ea3c241	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6170a5fb	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6232800d	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6c38aaaa	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x735109aa	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x75c50300	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7ccebf27	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x87beaa23	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa5860f23	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xaf38d713	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb7f2e40f	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xbe1deb21	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc8834c6a	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xde410f43	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe65d29b7	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe9055b19	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xec927aa7	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xed3d0365	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x5aa21c12	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x5f8d8df5	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x6cf05e39	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x9de1b052	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xcfea052a	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x1bc65cea	srp_reconnect_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x3dff587c	srp_rport_get
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x654ac748	srp_start_tl_fail_timers
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xa61cb11a	srp_rport_put
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x15006d7a	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x3ddefc1f	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x9ed35e0a	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xb1ce6d3c	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xc375ac94	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xdbe9f180	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xf1fd0677	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/ssb/ssb 0x044d8d7f	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0x1859aba6	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x1e4ad83c	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0x297e4925	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x3e74f212	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0x3fb80d28	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0x50196a09	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x53ac67fd	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0x601c1216	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0x681a3db1	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0x7f46593c	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0xb8a261de	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xc6572dab	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xdd2c483d	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0xe337390f	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0xe3701602	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xe81a700e	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0xef4d3b0b	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0xf64b85c6	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0xfa712d15	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x06a36695	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x09d45768	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0e21d2d7	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1585fb20	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x28a70c0a	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x2c1caeac	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x2c28d375	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x2e10c90c	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x36f7af36	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x419c0004	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x47f970c5	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x4fc65eca	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x8d66cb12	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x8ef25283	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x9cecab67	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x9d767401	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x9eae1ead	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xc00c2559	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xc1e61665	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xd2d5acc4	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xda35533c	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe406dcd5	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xf68a6892	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xfc094db4	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x2847c2e6	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x9a850adf	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x0df71a38	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x4585809e	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x4629ca8d	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x606436fe	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x963056eb	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0xa0142ca0	ade7854_remove
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0xcb1373a9	ade7854_probe
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0xbfeeb5e4	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0x32429b4f	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x03845e8c	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x05384341	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x05ca343e	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0d7a1e14	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0e0d5f75	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x12cc7b9e	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x194ccf45	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1cea55d0	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x24d8392c	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2d96c5a2	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2fecd32f	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x30496c4f	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3593b78c	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x37cd2765	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3e3a807b	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x41b5b46f	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5e716684	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x69a26d73	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x70341f07	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x72fd1516	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x78083c23	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7c09414d	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7ed6f77f	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x832ba33a	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8565470c	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9045691a	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x90c1bbc1	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9147d71a	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x91d6bfaf	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x95e185d2	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x97dc8553	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x99fc067c	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9d32a64b	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9d5f6bbc	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa03b4768	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa776a3c5	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xabdf4731	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb995fefe	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbbf98910	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbc5fbb65	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc2332dcd	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc602f9b6	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcaf4d3de	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcc134e21	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd5026e6b	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdb833450	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe646a9c7	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfa4bfd2c	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xff8fd8ef	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xffcac2d2	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x041ee992	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x050f5b2f	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x09c15884	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0bac00ef	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0fb1cfe3	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x10ca4bf7	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x12cf3ef2	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x13095a93	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1951d3e9	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1d29381e	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x24d921d3	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x25f407dc	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x27b15bc4	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x286dbdbe	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2b8ad6cb	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2cc1708a	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2d798e17	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x307bdd22	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x35b7ecf1	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3c721572	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4414e6d0	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5204165d	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5621ea63	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5835a11a	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5cdf4dc3	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x619093a0	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x64f1a7b3	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6aeb2610	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7e03468a	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8aa5ae25	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8c8175d0	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x93eb990b	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x94bf3958	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9cef3f42	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9e7c08ad	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaf5aaee1	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb2e985f2	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb5e398df	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb8c798e8	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb994194b	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbc8d7894	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbf943cdb	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc664dc6d	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc70b766a	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcd86cd95	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xceb97414	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcf4c2491	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd54ec06e	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd6aa4e57	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd96ead0f	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdb302099	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xeb309fbf	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xeb659937	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf2333f7c	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xffd8ff25	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0676f30f	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x1a7469b4	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x256ec393	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x2a9f4d7e	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x37c2c58f	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x381013d1	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3c003325	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4deaf58f	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5a354d77	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6a71a952	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x741e9556	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x770aebdf	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x7a05aef5	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x7d4e1c77	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x7f693d3d	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8cdbccc2	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x90fa8dbe	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x9901a96f	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa2b846b8	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa83dc76b	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa85d056e	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb839a923	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xbfbf9e02	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc0625ef2	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc91c757b	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe1707c04	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf046c59d	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf3eed53c	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0655953f	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x08301aa6	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0x104f9210	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x13139598	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x14d009f0	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0x15d12c77	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1de9ced3	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0x223cd211	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2ae0dc50	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2d8885dd	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2f5e219e	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3163d422	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x39f2161f	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3aa43372	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3f3ee6b2	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x46eeca50	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x49553e19	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4b48298f	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x51476bff	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x54ad580d	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x591a974e	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5c1d7297	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5e9a922b	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5fa69c58	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x677033e2	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6c5a3022	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x70dfe769	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x727e242a	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0x795b1f9d	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7b7b75a0	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7e023681	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8086e03c	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8b0cd247	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8bc64aae	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8c0fabc3	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8f628fb1	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9132011c	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9150e966	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x93046cd6	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x94c3cbf1	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9adec9cb	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9fcfd193	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa116f68e	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa5d50bc0	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa6909fc0	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xab7bb61e	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0xadcecab1	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb243dcb4	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb5665dce	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0xba6a6ce6	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbc9d8db1	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc04f0a14	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcca79a74	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd08bf0c8	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd8292d38	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd85d74ab	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd9377f3c	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe86e5419	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe942e1d6	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xecd525f4	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0xef9e4df5	transport_init_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf16c7903	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf279e1f7	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf2dcde56	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf5464d28	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf9da0ef9	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfc00c87b	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfc0fa249	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfe07e91b	target_undepend_item
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0x8385c9f8	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0x2d91c784	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0xed263fa8	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x349e6135	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x3e1f26e0	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x50039179	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x5e2b5237	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x6ef14451	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x91707356	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x9be0de6a	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xc09b3e7e	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xe5f367a1	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xf7717dba	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xfb4b46c0	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xfe646d53	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x86013dc0	usb_serial_resume
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0xb45e4f01	usb_serial_suspend
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x2e91ca97	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x367ce26a	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x59f824d9	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x7bda5e6d	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x821e9390	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x937e412c	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x8bf509a8	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x9df83247	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xe50a0137	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xe561119d	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x696ad551	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6f427953	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8be12c9b	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xab057e4f	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xc26d1d56	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xddc222d1	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xfe8da473	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/syscopyarea 0xf99aba6d	sys_copyarea
++EXPORT_SYMBOL drivers/video/fbdev/core/sysfillrect 0x974b4f64	sys_fillrect
++EXPORT_SYMBOL drivers/video/fbdev/core/sysimgblt 0xd5dff20c	sys_imageblit
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb00715c3	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x0a7e2d9a	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x0bb600ce	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x2d7327a8	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x05629394	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x30a14c47	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xadc61810	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xb5436341	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0x938eca99	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0x14a8f5fc	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x3499abe9	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x38068f15	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x94f3dd0b	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xd271f84b	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0x326c169b	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0x9fa71de7	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x23072c0b	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x42a41fb2	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x4c58c342	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x7359ac96	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xea2cfeb1	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0xea721a6f	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x1e5d12c7	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x57270a12	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x676a8ab3	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xab34558b	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x277db8ed	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x835b61aa	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x45c878de	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0xd9f944c1	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/wire 0x65abe903	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0x9b394ed0	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xbd6c5149	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xda313d3d	w1_register_family
++EXPORT_SYMBOL fs/configfs/configfs 0x342129b1	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0x3e34f5e9	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0x7e91ceca	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x8194f75a	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0x89315c47	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0x9a0d6002	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xa0d4cc19	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0xa6a26970	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xb74e0b68	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0xb8c96328	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xbc6d5bea	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0xc7ffb246	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xcb7e026a	configfs_unregister_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0xe7b527cb	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0xef72896b	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/exofs/libore 0x0a7c65ec	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x49d93c4e	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x605b5820	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0x73a382bd	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x9afe5f26	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xb0a84ce7	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0xb3cf40df	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0xc431ed82	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0xcc75587a	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0xf74d6b16	extract_attr_from_ios
++EXPORT_SYMBOL fs/fscache/fscache 0x01d077bd	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x02d6fdb9	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x06df3c5f	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0x11d53682	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x12d921ab	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0x12ef0828	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x1b097b74	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x25bedd13	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0x26e54a63	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x2727c859	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x273c15a9	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0x2e90934f	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x30ae0a22	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x34983125	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x3844e304	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0x3a1ddd4c	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x3d768a11	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x3d768d85	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x3e6a10d3	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0x400a9143	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x4adc0b58	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x4d81cf10	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0x578e9bfc	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x61eb386a	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x72453d95	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x72be6d26	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x73a816de	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x84acfcae	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0x861d91de	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x89db85f0	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0x994783f8	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x9d85f5aa	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xb2677932	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xbc00901e	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0xc06e745e	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0xc834ffcd	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0xe085e979	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0xe5297c58	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0xf4ae9ab7	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0xf564a1f8	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x5c98c4e0	qtree_write_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x78bff4a0	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0xb7c5e0f9	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xf39c04ca	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xf77975dd	qtree_read_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x3771b461	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc-itu-t 0xf5b4a948	crc_itu_t
++EXPORT_SYMBOL lib/crc7 0x66213969	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0x41248eaf	crc8
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x03f599c7	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0x04146390	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x4db78850	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x4feade4b	lc_create
++EXPORT_SYMBOL lib/lru_cache 0x56fc3ea0	lc_put
++EXPORT_SYMBOL lib/lru_cache 0x619ed575	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x84e0214b	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0xbbe7c23c	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0xc48fa976	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xc6e4cd46	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0xcb990a55	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcea6747e	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0xd212c9f0	lc_get
++EXPORT_SYMBOL lib/lru_cache 0xeb13128b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0xf460a486	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0xf5ea5f5c	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0xf6acec20	lc_find
++EXPORT_SYMBOL lib/lz4/lz4_compress 0xcbc5d521	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x26c3aa22	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x7456cc61	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x5c463a80	lowpan_nhc_add
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xb8c8a333	lowpan_nhc_del
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xd559dfb1	lowpan_netdev_setup
++EXPORT_SYMBOL net/802/p8022 0x4146d9bd	unregister_8022_client
++EXPORT_SYMBOL net/802/p8022 0xd5c9ba3f	register_8022_client
++EXPORT_SYMBOL net/802/p8023 0x05586c61	destroy_8023_client
++EXPORT_SYMBOL net/802/p8023 0x9018955b	make_8023_client
++EXPORT_SYMBOL net/802/psnap 0x6d64b383	register_snap_client
++EXPORT_SYMBOL net/802/psnap 0xf9838159	unregister_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x041aacb5	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x06432389	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0x0d76cc03	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0x0f326b4a	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x0f630f6f	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0x1902fc54	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0x1a37c7e9	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x1cddcb08	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x22069708	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0x26d9771a	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x2ce7db0f	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x37646521	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x3b5523bb	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0x3cfb9032	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x3dc26c12	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x40247fe1	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x40bcb8c4	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0x413dfdc8	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x5a8829dc	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x68ea4a2f	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x6d7c1110	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x7f17405a	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0x873f53af	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0x8e980d6e	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0x98ea70ec	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0x9cade4a8	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0xb450f120	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0xb7298006	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0xbfbf36e6	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0xc113d371	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0xc327736c	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0xc3f173f2	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xc77ea5e7	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xcae992a0	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0xdb486bc5	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xe471f3c2	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xe5d9248d	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xea69980d	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xefcf79f5	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0xf36d30c7	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0xf436de92	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf50c56d8	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x35e87a0e	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0x3ea762b0	atrtr_get_dev
++EXPORT_SYMBOL net/appletalk/appletalk 0xb3bc0417	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0xb91b3005	aarp_send_ddp
++EXPORT_SYMBOL net/atm/atm 0x13ea67b4	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0x20cb0929	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0x24182a16	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0x2af22466	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x2c7d60cf	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x302d64f6	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x46202440	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0x4b126d6e	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0x559abc92	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0x5d44b603	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x89e9a7ad	atm_charge
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xa12fb1dd	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xaf26fee4	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xca87b453	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/ax25/ax25 0x17a38f65	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x2b965f9e	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x71bb8860	ax25_ip_xmit
++EXPORT_SYMBOL net/ax25/ax25 0x7346a75c	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xb462ac34	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xc1d9b3ec	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0xc5bfd9e2	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xdd910355	ax25_header_ops
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x00f51d57	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0107bded	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x057fd0b0	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0754e424	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x089a2359	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0edd010e	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1094d41d	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x12eb5da0	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1e38b095	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x21555191	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2c884bb8	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x326a5d58	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3cd37390	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3e0fd26b	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x484042b8	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x60c1fca1	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x643ebae8	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6abe5ef4	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x704bd142	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7341efb5	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7b8d4f77	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7dc6f4b5	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7ebe4dd1	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7ee437b4	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x836f244c	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x85228a29	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x88439ff2	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8914b169	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8a4e3bdf	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8b3f3655	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8f86daa1	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x93d5fa0d	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9a8f5bae	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb837934d	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc74e37a	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcdddaf7f	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd8f9e513	bt_sock_wait_ready
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe41cb632	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf5b35999	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf60ea4bd	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xfcf332c4	bt_sock_recvmsg
++EXPORT_SYMBOL net/bridge/bridge 0xd88c451e	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x1161ef7b	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x5fe477b6	ebt_do_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xd58f111d	ebt_register_table
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x1f5accc1	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4353365e	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x53775f09	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x580c3266	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x900538a1	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/can/can 0x07f7e6f9	can_rx_register
++EXPORT_SYMBOL net/can/can 0x2b4e9c0a	can_proto_register
++EXPORT_SYMBOL net/can/can 0x2c7cdbb8	can_ioctl
++EXPORT_SYMBOL net/can/can 0x84951160	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0xba9f07c8	can_proto_unregister
++EXPORT_SYMBOL net/can/can 0xe49f335d	can_send
++EXPORT_SYMBOL net/ceph/libceph 0x00b86d28	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x021f00a1	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x031b2bbc	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x040fa54c	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x06162949	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0a817911	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x0bbd3ca7	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x11154060	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0x18313813	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0x1d720f64	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0x1f424fee	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x2168e61d	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x241b0e1e	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x251afb95	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x26b84ff2	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x26f68be4	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x27e086a0	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x296662cb	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x2b46a6f3	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x2bec97b4	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0x3666ace5	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0x379ccb04	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x414d054b	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x47a9920e	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x50547ba8	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x5bcf6cac	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0x6075609d	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x644869e9	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0x6596f7b8	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6bb2678f	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x6bfc2d01	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0x6ed01565	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x70ae8ac3	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0x70d7d261	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0x75cc084c	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x818c0971	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0x819cb798	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x81be9f64	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0x85c5e5db	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0x8867fd77	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0x8c6e20e2	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x8e28d3a8	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0x905babbf	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x92353b50	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x949f3ae3	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0x9936f7b9	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9bb9f58d	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa1ebde8f	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0xa248e67a	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0xa371a4c4	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0xa41a2b65	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xa43ee505	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xa4625c6b	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0xab7bf5d0	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0xaccc3990	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb19dc152	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xb3ecc460	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0xb4532637	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb9f52620	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0xbbea8122	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0xbc7ac6d8	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0xbdbb697f	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0xc3209d3b	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0xc4114f92	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc61a9376	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc7b0e35d	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xd0c4719f	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd5383217	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xd661aaed	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0xd6a02374	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0xd813625e	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xde0eb6ba	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xe0fa2e40	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0xe1f3b6b6	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0xe33d3857	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0xe4c0a07c	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0xe55d9bcd	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0xe5adba2a	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xe956366f	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0xef77c5d1	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xefd323a9	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0xf1602ead	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0xf412a168	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xf6539c4d	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0xf834f6df	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0xf94106b6	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xfb443981	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0xfca0b391	ceph_con_keepalive
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x077d69ef	dccp_req_err
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x1570864c	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x1c4431bd	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x75b30020	wpan_phy_find
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x96f2a97d	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xb0d405b2	wpan_phy_new
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xb19c6da0	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xbcb99317	wpan_phy_unregister
++EXPORT_SYMBOL net/ipv4/fou 0x0c07b4a3	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0x3de0d2b8	gue_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xbd93aa67	fou_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xed741d6f	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x04142052	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x1d765dfa	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x70ca751b	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x7c8cba7a	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xa4daf0b6	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xaa3ab913	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x297599d9	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x9d00b5ab	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xa05dda27	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x4c035573	ipt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x54745145	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x6c7acfe7	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x56d169ff	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/tunnel4 0x8641a63c	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0xc1c38002	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x47acd61b	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x5c568dbf	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x8999597f	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xfd4afd6e	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x24ba9657	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xbd48cc9c	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xd638845a	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x260ea823	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0x9d1c6a64	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x62f7def8	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0xc54308a5	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x1ca0d72b	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x49164dfc	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x5479e827	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x6dc033e3	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x7c27e456	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x94084351	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xb4286315	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xeed0c57a	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x0064e0ea	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x0fefc426	irlap_open
++EXPORT_SYMBOL net/irda/irda 0x14dbd812	iriap_open
++EXPORT_SYMBOL net/irda/irda 0x1ce323f6	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0x1e6cade0	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x1f29b03a	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x3e56064f	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x4abd6944	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x54d5114c	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0x601bda46	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0x671894b0	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6b5fbcef	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x6e0ab3c7	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x7f917bfa	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0x7fb79a85	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x833228c4	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0x85d88217	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x87bd2f9f	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x8dc30877	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x95f2906f	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0x96ca2443	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0xa1d41e58	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0xaa557515	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0xab124182	irlap_close
++EXPORT_SYMBOL net/irda/irda 0xaba36ea5	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xc4da366a	iriap_close
++EXPORT_SYMBOL net/irda/irda 0xc68e43be	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0xcead7dbb	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xd2108314	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0xd3ab24da	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0xd7a75acb	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0xda2eca9f	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe3463529	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0xe3bde43e	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0xe4dcc79c	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xe8b7ea24	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0xe9eab36b	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xeaee2cda	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xf0a694a1	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0xf39b7fe0	irda_setup_dma
++EXPORT_SYMBOL net/irda/irda 0xf51c123a	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0xf5876b95	hashbin_remove_this
++EXPORT_SYMBOL net/l2tp/l2tp_core 0xe4f2958a	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0x8c3a211c	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x0eace82f	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0x52161690	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0x6b1b47ca	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0x7e880853	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0xac08e222	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0xb0330ffa	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0xf58f26d6	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0xf873e134	lapb_data_request
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x4f579903	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x91e1f1d0	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0xac8ea329	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0xc8de73f4	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0xe69f899f	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0xe8494f6a	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0xed7600fd	llc_sap_find
++EXPORT_SYMBOL net/mac80211/mac80211 0x02166686	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x0969698b	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x09fa9be7	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac80211/mac80211 0x0e352f89	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0x0f6a8145	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x1154dbd0	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0x12da068b	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x19ac8b85	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x1a260557	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x1a99ca9c	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x25d22e61	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x266a0199	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0x2bf40b1f	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0x2bf66197	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x2ee20991	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x34092359	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x37396c25	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x3d37b0d5	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0x3f5eaf95	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x3f70277b	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x3f7befc5	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x3ffea022	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x4292978b	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x438381f3	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x4b0dabf0	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x4b3d5b3d	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x4c2d435f	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x4e11c242	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0x5c02fda1	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x5cef079a	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x6059ac9b	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0x60a128f0	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x64c2d9b8	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x67067b44	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0x69de096c	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0x6a51299a	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0x6c2a5001	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0x6dd0f35d	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x7366dfbe	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x75f7f65b	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x76b9ef28	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x7a0ac069	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0x7da32e63	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x7fb165ce	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x81712ec4	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0x840593b2	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0x86704849	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x8780f252	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x88cf0dd9	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0x8ab3d881	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x99e234fa	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac80211/mac80211 0xa4024698	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xa70a8d9c	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0xa78ec948	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xb1aaef91	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xb3042623	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0xc17cb508	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xc26253c5	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xc345e36c	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xc3fc1469	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xc52b27a9	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0xcbb27913	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0xcce49160	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0xcdc65cad	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xcdf19cce	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xd2ffc829	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xd526e38b	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xd5d65fb7	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xd8b4a1af	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xdc20bc5f	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0xddc347ae	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xe3237c89	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xe4c03328	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0xe7a73d2f	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0xe7f28cf7	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xe9cd0514	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0xf0c085ac	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xf3d9490b	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xf877021c	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xfa344128	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0xfd6320d8	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0xfeecbeb6	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac802154/mac802154 0x04d66327	ieee802154_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x394c02e2	ieee802154_register_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x3f8cd798	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0x828ac945	ieee802154_xmit_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0x8ec273b3	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x91f2d714	ieee802154_unregister_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xa4ad6d7c	ieee802154_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xe291714f	ieee802154_alloc_hw
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x053f70da	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x153ecaaf	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x3d8d39b5	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x465f5757	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x571827ac	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x7dbaa274	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x8fff8bee	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x9968dcc8	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb6a5325e	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd207f586	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd7c09fec	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xf3450293	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xfa0b9811	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xff913b2e	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x05a5219b	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x634435c3	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xd689e623	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x1de30ea9	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x45d66a8a	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x4e0c8f1e	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0x512777d0	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xc61bcaa0	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/nf_nat 0xfb08099f	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/x_tables 0x0a8cc7dc	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x12aa0d06	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x230667c6	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x29e67994	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x596697f1	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x65d25b29	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x7f3da1e1	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x9fa7c310	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xc521fb58	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xfe8735f3	xt_unregister_targets
++EXPORT_SYMBOL net/nfc/hci/hci 0x05497334	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x18c727ce	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x390b8dd7	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0x401d4498	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x46acdf26	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0x4f9511e0	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0x585793d0	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x59b85f85	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0x5a23afe7	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/hci/hci 0x6b92e700	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x6dbfb290	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0x6e493998	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x7c6f7137	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x92521442	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0xa9705dc8	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0xac91c74b	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xaf1a38cd	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xe2b5fa69	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xecedd8d8	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xef5781f2	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0xfd4da8d1	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x01e20717	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x034d1cb7	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x04b2c07d	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x051578e1	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x11b16aea	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0x1c0cecd2	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x2174f5ed	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x2a247849	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0x2d547cc1	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0x2ec0dc9f	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x41c22b26	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x4713793c	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x4de6bc86	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0x4e63c13f	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x5b15dcc0	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0x630710dc	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x711026d7	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x87e714e5	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x925dc325	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0x92eefb8a	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0xa1381ee2	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0xb114cc5c	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0xb832a5ea	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xbbba12e8	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0xbc16b50f	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xdc8a5e8e	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0xdcd09901	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0xf07c211a	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nfc 0x03301d06	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0x03a1e42a	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0x10eb9abf	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x1370c683	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0x22232db9	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0x30a13caa	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc 0x45a3ba62	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0x477fee41	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0x502e8432	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0x6e7d38ae	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0x6f918525	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x78579bf0	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x790f9be0	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0x828ec8b2	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0x84d1334c	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0x918033eb	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0x9f7d1172	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0xb54c85b2	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0xbeea3338	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0xc716cd04	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0xc7f3d542	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0xcf640d9a	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0xf988bb4d	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0xff3ae546	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x0dcc6730	nfc_digital_allocate_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x195b5517	nfc_digital_free_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x8bab9a5b	nfc_digital_unregister_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xcfd69982	nfc_digital_register_device
++EXPORT_SYMBOL net/phonet/phonet 0x01d2685a	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0x141f8331	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0x2dbba966	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0x314a3dc8	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0x3caa0ea3	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0x4991fb52	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0x653a06c1	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0x973d16ac	pn_sock_hash
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x0ba81263	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1873987a	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1cfb549f	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x3870771a	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x38a87bfd	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x59315b16	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x69cca208	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xbf3b895c	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xca1deec2	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xca703460	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xde547731	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe14173bb	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xef2f4e1a	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf45e241b	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf731e7bc	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/sctp/sctp 0xd72a79c9	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x3ef60858	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xd9e0d0b3	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xf832d648	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x344306bc	xdr_truncate_encode
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x7c635b56	svc_pool_stats_open
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xaf305059	xdr_restrict_buflen
++EXPORT_SYMBOL net/wimax/wimax 0xd2e067f2	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0xe524f067	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x00f4836f	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x0708934b	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0754ef6e	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0c041ae7	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0x124bff8f	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x14789728	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0x1749cbc6	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x18e97e4f	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x1f4b80b8	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0x214fe238	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0x231ab4fa	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x24f4bcc5	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x25baa8d6	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0x2770f8b3	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x2c05064a	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x314ae5d7	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0x31841ea8	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x31e563e4	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x37ea5c8c	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x3b9cfc34	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x45f1dc9d	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x462084b4	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x4abb13c8	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x4d032cf3	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x4eb0d392	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x4edbf5e1	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x5134dbf6	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x51bd3814	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x540714ee	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x59906673	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x59ad5dee	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x5c8e21a8	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x60fc7044	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0x66edc866	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0x67eb360e	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6b1c029a	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0x6ce016bb	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x7522058b	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0x7529ac17	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0x7b262b94	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0x7e42bc39	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x86a76780	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x88f912a2	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x8b26cfc7	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x8b683a7a	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x8ca55a86	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x90dbc73d	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x9293b0f5	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0x9528820f	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0x95524a7b	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0x966ff54d	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x983b714b	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x9aa4d707	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x9f078719	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa6c4e47a	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xa8778e64	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0xab63abda	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xafe3f270	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xb16b19e9	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xb2b0caa4	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0xb435f4f7	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xb7533737	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0xbab53b56	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xbb2a090c	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0xc27fa247	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc802f9bd	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xd135513e	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0xd418633c	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xd67bab4b	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xd87211ee	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0xdb1c9017	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xdb57b4f1	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xe295c312	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xe30a11aa	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0xe888e067	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0xeb6d7c6c	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xec3be221	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0xec6d7abd	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xed00ee13	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xf12295b2	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0xf132bdec	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0xf5adf2d2	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0xfa3b1add	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0xff14b771	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/lib80211 0x30b29002	lib80211_crypt_info_free
++EXPORT_SYMBOL net/wireless/lib80211 0x3451cd13	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x68ff36f3	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0xad0aaec1	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xdafc0fbd	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0xe9ac64ec	lib80211_get_crypto_ops
++EXPORT_SYMBOL sound/ac97_bus 0x7246de4a	ac97_bus_type
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0x20877380	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3f5f8310	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x525c7f76	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x52677353	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xc709a9fb	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6817fc04	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x072d978b	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x13a17752	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x2eed26bf	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x4d5ca523	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x592f6e9b	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xd7c7afcc	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xe60fb228	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xecbde43c	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0xf003daba	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x03a7f113	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0x0aed3b99	snd_unregister_oss_device
++EXPORT_SYMBOL sound/core/snd 0x0c6d8731	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0x0cf338f9	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0x0d75cb82	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0x0d8459c4	snd_register_device
++EXPORT_SYMBOL sound/core/snd 0x13614bdc	snd_register_oss_device
++EXPORT_SYMBOL sound/core/snd 0x160a9b11	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0x185d8043	snd_jack_new
++EXPORT_SYMBOL sound/core/snd 0x18e1683f	snd_dma_program
++EXPORT_SYMBOL sound/core/snd 0x191e88cf	snd_dma_pointer
++EXPORT_SYMBOL sound/core/snd 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL sound/core/snd 0x1cd7a0a7	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0x1fce7506	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0x226f3c03	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x258e223c	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0x27a63b9e	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0x2a4b250c	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x3aa8a9ed	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0x3c90c30b	snd_jack_add_new_kctl
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x4b4bd472	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0x4bb95841	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0x55bbb9b4	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0x5a760ee4	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0x5d298bb9	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0x6008ca89	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL sound/core/snd 0x602c96f0	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x62100074	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0x6474ffed	snd_cards
++EXPORT_SYMBOL sound/core/snd 0x6e8a2679	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0x70c15ac1	snd_dma_disable
++EXPORT_SYMBOL sound/core/snd 0x76773c66	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0x78613a11	snd_card_new
++EXPORT_SYMBOL sound/core/snd 0x7c5c406f	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0x7cd91664	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL sound/core/snd 0x8ecc646e	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x93c725ba	snd_device_new
++EXPORT_SYMBOL sound/core/snd 0x94156a48	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd 0x98f32194	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xa8531d22	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0xa897e0c3	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0xb12cf0eb	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xc015faeb	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0xce3ca308	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd 0xd1157735	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0xd1ce46fa	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0xe4a072a6	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0xe58ada61	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0xe8eb643c	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0xef6dcc3e	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0xf383cb35	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0xf99a75ab	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0xfc5056f7	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd-hwdep 0x693e2761	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x00107ba9	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x013d0d92	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x02d06185	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x0356f50c	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x08d37056	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL sound/core/snd-pcm 0x09085326	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x14a4e430	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0x16c1690a	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0x1ac43ee5	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-pcm 0x1bf40c7e	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x2004bc2f	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-pcm 0x2665d978	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x2a4b8471	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x2ae36ac9	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x300eb2e9	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x30a412c7	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0x31bdc6b2	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x3a2b17a4	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0x3b91f3af	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x3c4706e5	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0x41dd133b	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x4973ff25	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0x4d9b6d35	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x4ed8142c	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x5584f99b	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x56fd9415	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0x5c2d3c7e	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x5cb5d6d1	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x5fc1f1ba	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x6f66d052	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ff937c9	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0x721063dd	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0x7bf94256	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x85eeab2c	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0x89416e94	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0x89c05849	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x94add672	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0xa34cafff	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xa6d7991c	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xa81be3bc	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xade88e76	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9a4a05e	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0xbf79e254	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0xc77b819f	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0xdebdf361	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xe95e9399	snd_pcm_lib_mmap_iomem
++EXPORT_SYMBOL sound/core/snd-pcm 0xeba3ef3b	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0xec61b2b2	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0xf1951f0b	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0xfcfa383e	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x0e7aba73	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x18d5bec7	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x1a68c793	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x282141ce	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x2d8604c7	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x4c43a7cb	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x4e197fc4	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7b567429	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7bf5cc8e	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7e4396e5	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x9a3033dc	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xa18be892	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xa7abfe4f	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb59fd8c0	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb940ed35	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xc35d1c69	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd9a18679	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xe42b893c	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xebc980a0	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-timer 0x06317d15	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0x0813d5bd	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0x0ff44c61	snd_timer_pause
++EXPORT_SYMBOL sound/core/snd-timer 0x151ce8bc	snd_timer_open
++EXPORT_SYMBOL sound/core/snd-timer 0x3f41c486	snd_timer_stop
++EXPORT_SYMBOL sound/core/snd-timer 0x463b8016	snd_timer_close
++EXPORT_SYMBOL sound/core/snd-timer 0x58226fde	snd_timer_global_register
++EXPORT_SYMBOL sound/core/snd-timer 0x8fba4126	snd_timer_new
++EXPORT_SYMBOL sound/core/snd-timer 0xbcfbdeab	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0xc3632859	snd_timer_resolution
++EXPORT_SYMBOL sound/core/snd-timer 0xe50d7fbd	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0xf5348b75	snd_timer_interrupt
++EXPORT_SYMBOL sound/core/snd-timer 0xfed367fe	snd_timer_start
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x96d3d1d9	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x0927ac82	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x0af537f8	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x0e0c784d	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x29b44d21	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x54ab3ddc	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x5c7df695	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xa9e3717d	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xe9a8f449	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xf70d4e5c	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x1600c590	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x1beef8bb	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x27b74cda	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x396a97ff	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x6272dd6c	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x711ce7a4	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xb0702ed8	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xb128bf16	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xc353d07e	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x0623f7ab	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1787950c	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1eb6754b	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x23b5d517	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x27aaaec5	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x29f25d09	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x349631e3	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x48bee181	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4ab7ac96	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5c55668a	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x65b9a13b	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x6673320b	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x78ea26ba	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7e3279df	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x81fd45f4	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x82c08106	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8dfbbe2f	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x99af8b90	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x99ed93f4	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9abe8215	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa100e5f7	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa582fb7b	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa63c7c4f	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xab0d20b6	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xacd7dcb0	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xacde5717	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xad24cb3a	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd847c509	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xdebdfbbe	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe177121c	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe9738dd4	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xeec99e00	amdtp_stream_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x5b64b375	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x5d87e44c	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x5f4426b9	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x994d9fba	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xa3d70e24	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xaa278f40	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xae099cb5	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xb13d05ac	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xbbd8f54f	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xce023106	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x1c45c1fa	snd_ak4117_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x53d6cda4	snd_ak4117_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x653482ba	snd_ak4117_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x8bfbd4ba	snd_ak4117_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xd3ec3f7c	snd_ak4117_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xd5d18180	snd_ak4117_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x3c541f0a	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x9eff1ddc	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xc9a0bd11	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xd8b785fb	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x4182aca4	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x469264a8	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x0e386961	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x9ff5a392	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xa98d13ec	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xd5eeaf4c	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xef63e0da	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xfac1f54d	snd_cs8427_init
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x094a529c	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x0f674094	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x21c35d58	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x898feaac	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x94b1155c	snd_i2c_device_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xe5267f6f	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x0310e269	snd_sbmixer_resume
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x09760803	snd_sbmixer_read
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x3974aed8	snd_sbdsp_command
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x4ad2a789	snd_sbmixer_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x516f6f01	snd_sbmixer_add_ctl
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x5fccde66	snd_sbdsp_get_byte
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x6a6e9be5	snd_sbdsp_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x6f2bc06f	snd_sbdsp_reset
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x97f84423	snd_sbmixer_write
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xf3cabf38	snd_sbmixer_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x02cfd8d9	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x0418945d	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x28a8eebc	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x2cd4de9d	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x472c3883	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x61eb21a3	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x6a6a5cdb	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x905989b9	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x938f50b4	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x93f06047	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x97f1ca4f	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xa9e8e8fe	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb09f04d9	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xc586dd0a	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xd43a4d35	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xf4c37766	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xff4f0b7d	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x02fb03fa	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x311dfa9c	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x3212f5d7	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x5bdb6bf4	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x701dba3d	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x7181e2ff	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xd1a80cde	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xd23f081c	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xfee705de	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x2081a4e0	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xae2329ce	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xb1219ce7	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x06376376	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x068db1d9	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x12e9e26f	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x2c109b8c	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x354b4f16	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x4c5d27fa	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x59c91ce9	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x5cce9745	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x64762674	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x68bd359c	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x6919709a	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x6eb0add7	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x6efb37a1	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x8ab3496f	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x8cf5dd4f	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x99c816f8	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x9dcc5f50	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb6a5a7ee	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xe1a786ef	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xfc8c5b07	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xfc960b70	oxygen_write32
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x12ab1cfe	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x40eaec26	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x693366a0	snd_trident_free_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x782ee108	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xef07cd83	snd_trident_start_voice
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0xc653b0d6	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0xcfe2a2a1	tlv320aic23_probe
++EXPORT_SYMBOL sound/soc/snd-soc-core 0x67fde271	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL sound/soundcore 0x2de1a681	sound_class
++EXPORT_SYMBOL sound/soundcore 0x403f18fd	register_sound_special
++EXPORT_SYMBOL sound/soundcore 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x82cb982d	register_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL sound/soundcore 0xa0a9bf1d	register_sound_special_device
++EXPORT_SYMBOL sound/soundcore 0xb909dd38	register_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xef799900	register_sound_midi
++EXPORT_SYMBOL sound/soundcore 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x0d688882	snd_emux_register
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x65fe2b49	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x83210301	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xb98b04c8	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xcd7f62ea	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xf0ced7a1	snd_emux_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x284fcebc	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x39c93197	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x3ab6ef22	__snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x4cb78af1	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x70155057	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xd9b98f83	snd_util_memhdr_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xe6ac7e1e	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xeed7abc5	snd_util_mem_alloc
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x4b0005d0	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL vmlinux 0x0013d8d1	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x0022b8af	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0x003ed69a	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x0047321b	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x004c3707	cont_write_begin
++EXPORT_SYMBOL vmlinux 0x00506125	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0x0059e224	of_get_ddr_timings
++EXPORT_SYMBOL vmlinux 0x007d92f8	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0x00cbffa7	sock_register
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x00e283f6	keyring_search
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x01139ffc	max_mapnr
++EXPORT_SYMBOL vmlinux 0x0113d2dc	path_nosuid
++EXPORT_SYMBOL vmlinux 0x012a97fc	xor_altivec_4
++EXPORT_SYMBOL vmlinux 0x012f31de	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0x013faa62	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0x014ac3c1	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x0176c2c9	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x0186e2de	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x01c6c68b	d_find_alias
++EXPORT_SYMBOL vmlinux 0x023bc969	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0x023f7448	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x02428fc1	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0x025c9b70	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x02722247	poll_initwait
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02cd6740	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x02d3c891	bio_split
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x02ee26c1	free_pages_exact
++EXPORT_SYMBOL vmlinux 0x02f7e889	input_set_keycode
++EXPORT_SYMBOL vmlinux 0x0303ff59	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0x030c741c	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x0320f140	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0x032fd2cd	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x035d418f	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x03857e87	sk_common_release
++EXPORT_SYMBOL vmlinux 0x03865e57	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0x03942800	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0x03c365aa	genphy_update_link
++EXPORT_SYMBOL vmlinux 0x03c8250e	finish_no_open
++EXPORT_SYMBOL vmlinux 0x03fc92f0	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x04040842	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x0430f2fd	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x0462d17b	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x046ae8ed	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x0479bc21	acl_by_type
++EXPORT_SYMBOL vmlinux 0x04877438	of_parse_phandle_with_fixed_args
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x049e883a	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0x04afa9f7	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x04afd4fb	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04ed5dcf	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0x04f1041d	lockref_get
++EXPORT_SYMBOL vmlinux 0x04fba853	kmap_high
++EXPORT_SYMBOL vmlinux 0x05186ca4	flush_icache_range
++EXPORT_SYMBOL vmlinux 0x051f901f	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x0527efc8	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0x0530dede	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x0553b06d	dst_destroy
++EXPORT_SYMBOL vmlinux 0x0559e36a	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x056ffb94	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0x059a642c	pci_domain_nr
++EXPORT_SYMBOL vmlinux 0x059d7ae8	input_reset_device
++EXPORT_SYMBOL vmlinux 0x05a2ad2d	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x05a514a1	_insl_ns
++EXPORT_SYMBOL vmlinux 0x06015832	padata_start
++EXPORT_SYMBOL vmlinux 0x0602dd9d	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x06245603	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x06439a44	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x065d6f51	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x06643149	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0x06710ddd	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x0675c7eb	atomic64_cmpxchg
++EXPORT_SYMBOL vmlinux 0x067ac8a6	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x0685d2a7	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0x068e8cb3	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0x06971944	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x06b3520e	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0x06c93e21	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0x06da6890	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x06e35cd0	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0x06e503aa	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x070c77fe	fget_raw
++EXPORT_SYMBOL vmlinux 0x07145054	pci_find_bus
++EXPORT_SYMBOL vmlinux 0x072183aa	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x0727c4f3	iowrite8
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x0744e6eb	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x07492058	ata_print_version
++EXPORT_SYMBOL vmlinux 0x074e9213	down_killable
++EXPORT_SYMBOL vmlinux 0x0774e57b	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x079aa2a7	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07bb99f8	load_nls
++EXPORT_SYMBOL vmlinux 0x07bcd65b	sk_wait_data
++EXPORT_SYMBOL vmlinux 0x07c9ae73	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07f8cd70	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x07f93ba6	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0x081095d6	fsync_bdev
++EXPORT_SYMBOL vmlinux 0x0821c129	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x08336724	__dst_free
++EXPORT_SYMBOL vmlinux 0x083c7477	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x087816e2	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0x087ce27a	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0x0880c2fe	md_error
++EXPORT_SYMBOL vmlinux 0x0886e9cc	vme_slot_num
++EXPORT_SYMBOL vmlinux 0x088a438c	ping_prot
++EXPORT_SYMBOL vmlinux 0x088b0a24	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0x088b7b65	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0x089e54d4	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x08c09994	elevator_init
++EXPORT_SYMBOL vmlinux 0x08c96258	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0x08de35a8	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x08df9457	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x08e7f7de	input_set_capability
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x08ff1d0e	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x0903d381	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0x0937129f	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x093cf574	elevator_change
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x097371ee	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0x09788c37	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x0982551c	nla_put
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x098eefcb	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0x0993d653	sock_rfree
++EXPORT_SYMBOL vmlinux 0x09bbbb91	trace_print_symbols_seq_u64
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c67afb	flex_array_get
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09e63aa2	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0x09f63c1b	sync_filesystem
++EXPORT_SYMBOL vmlinux 0x09f7034e	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x0a0d29ca	bio_map_kern
++EXPORT_SYMBOL vmlinux 0x0a11e86c	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a3131f6	strnchr
++EXPORT_SYMBOL vmlinux 0x0a373226	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0x0a38e202	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x0a40fb1e	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x0a4143e2	init_special_inode
++EXPORT_SYMBOL vmlinux 0x0a469d23	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0x0a4a791f	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x0a65744f	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0x0a958f83	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x0a95a3e2	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0aa55ae7	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0x0aac227c	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x0aac8fe6	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0ad63fa5	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0x0afa071d	of_graph_get_next_endpoint
++EXPORT_SYMBOL vmlinux 0x0b0bc8c9	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b2e2e4b	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x0b365ab0	__alloc_skb
++EXPORT_SYMBOL vmlinux 0x0b3bdfad	agp_alloc_page_array
++EXPORT_SYMBOL vmlinux 0x0b417ebf	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0x0b48677a	__kfifo_init
++EXPORT_SYMBOL vmlinux 0x0b4f60bc	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b7e615b	dev_crit
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0beb39c0	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x0bf55c5d	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x0c040818	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0x0c12e626	__debugger_bpt
++EXPORT_SYMBOL vmlinux 0x0c1fa88e	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0x0c361063	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c6e2326	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x0c906b0a	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0x0c9b6089	nvram_get_size
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0caec0b2	of_match_node
++EXPORT_SYMBOL vmlinux 0x0cd019d2	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0x0cd4354c	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0x0cdadb18	do_splice_from
++EXPORT_SYMBOL vmlinux 0x0cf924bd	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x0cfab9e2	skb_insert
++EXPORT_SYMBOL vmlinux 0x0d028292	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0x0d0f60b3	inet_select_addr
++EXPORT_SYMBOL vmlinux 0x0d187ca9	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x0d2a18f3	vme_register_driver
++EXPORT_SYMBOL vmlinux 0x0d2e3b11	tty_mutex
++EXPORT_SYMBOL vmlinux 0x0d35586f	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0x0d35bd15	neigh_for_each
++EXPORT_SYMBOL vmlinux 0x0d394587	skb_append
++EXPORT_SYMBOL vmlinux 0x0d53ae18	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d65afd2	generic_show_options
++EXPORT_SYMBOL vmlinux 0x0d84dce5	param_set_bool
++EXPORT_SYMBOL vmlinux 0x0d858f07	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0da13254	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0x0dadaa2f	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0x0db31aa2	phy_detach
++EXPORT_SYMBOL vmlinux 0x0dbf38b8	mol_trampoline
++EXPORT_SYMBOL vmlinux 0x0dc0ace0	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x0dc1a78c	bin2hex
++EXPORT_SYMBOL vmlinux 0x0dcc4a7a	twl6040_power
++EXPORT_SYMBOL vmlinux 0x0dcd9098	pcibios_fixup_bus
++EXPORT_SYMBOL vmlinux 0x0dced4b9	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0x0dd4d547	sync_inode
++EXPORT_SYMBOL vmlinux 0x0ddd7326	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0x0ddf4bdd	of_graph_get_endpoint_by_regs
++EXPORT_SYMBOL vmlinux 0x0ded11b9	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0x0e0f4061	genphy_resume
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e835bd2	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0x0e8f30f6	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x0e9e66bf	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x0eaf451e	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x0eb91a8f	from_kuid
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0ed21f4d	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0x0ede338a	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0x0ede4186	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x0eea0399	strscpy
++EXPORT_SYMBOL vmlinux 0x0ef20db1	kernstart_addr
++EXPORT_SYMBOL vmlinux 0x0ef2cfbf	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f20d2e7	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL vmlinux 0x0f3c2db8	seq_vprintf
++EXPORT_SYMBOL vmlinux 0x0f410d10	dst_discard_out
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f4ccb6f	nf_reinject
++EXPORT_SYMBOL vmlinux 0x0f5faa7e	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x0f674b3f	vga_client_register
++EXPORT_SYMBOL vmlinux 0x0f691ff9	scsi_host_get
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f84d858	icmpv6_send
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x10048bf8	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0x1005f4ac	nvm_register_target
++EXPORT_SYMBOL vmlinux 0x1012fc13	touch_atime
++EXPORT_SYMBOL vmlinux 0x1036c13d	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0x103e8e64	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0x1043a5d9	input_free_device
++EXPORT_SYMBOL vmlinux 0x105aca19	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0x106f13ab	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x107cd00b	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x10a024c8	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0x10b54890	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0x10c7dc8b	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0x10cb5236	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0x10d9a1b5	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0x10da839e	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x110d182c	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x1111a4bc	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0x11145431	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0x111bc8f1	igrab
++EXPORT_SYMBOL vmlinux 0x114ca9c4	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0x115effb2	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x11663cec	adb_register
++EXPORT_SYMBOL vmlinux 0x116e4893	simple_open
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x117af11c	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x1182d83a	cpuidle_disable
++EXPORT_SYMBOL vmlinux 0x1186e5b0	of_find_node_opts_by_path
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11acab0a	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0x11cc71c0	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0x11f16e44	dput
++EXPORT_SYMBOL vmlinux 0x11f58a80	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120007a9	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0x12000ff4	pci_disable_device
++EXPORT_SYMBOL vmlinux 0x12022d96	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x12241d9d	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0x122cd836	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0x12326f05	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0x126bab9d	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x12932f3f	generic_readlink
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12bdd3c6	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0x12da5bb2	__kmalloc
++EXPORT_SYMBOL vmlinux 0x12e5ef0c	rtas_set_power_level
++EXPORT_SYMBOL vmlinux 0x12ef923f	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x12fa790a	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x130aa651	security_path_mknod
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x131f5dbc	__get_page_tail
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x13716d2c	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x1382ee9c	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x13bc8a59	devm_ioremap
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13f08f12	dquot_enable
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x14059764	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0x1407c6e7	kmap_prot
++EXPORT_SYMBOL vmlinux 0x140c09b0	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0x1420b379	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0x142c847e	mem_map
++EXPORT_SYMBOL vmlinux 0x1453aff0	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x147643ff	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0x14802e34	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x1491929e	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0x14929cf9	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x14a1a3a4	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x14f06d63	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0x14f4c634	param_get_bool
++EXPORT_SYMBOL vmlinux 0x15476bd9	dquot_acquire
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x15534cd3	bdevname
++EXPORT_SYMBOL vmlinux 0x15613230	__mutex_init
++EXPORT_SYMBOL vmlinux 0x156133bf	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x1567de3d	deactivate_super
++EXPORT_SYMBOL vmlinux 0x1597b3d8	blk_get_request
++EXPORT_SYMBOL vmlinux 0x15b7baaa	of_node_put
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15c43ea3	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x15c8c235	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0x15d35dae	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x15d3fd60	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x160bd45c	rtas_token
++EXPORT_SYMBOL vmlinux 0x160bd59a	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0x160d0e79	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0x16182846	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0x161d0033	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x162dbc51	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x16540bbc	__cmpdi2
++EXPORT_SYMBOL vmlinux 0x1667a5c2	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0x166c2612	try_module_get
++EXPORT_SYMBOL vmlinux 0x167b86a1	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0x16807c5e	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0x1683a50b	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x168cf911	nla_reserve
++EXPORT_SYMBOL vmlinux 0x1691f24e	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x16ab5ff3	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x16c32b8f	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0x16cb83ad	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x16dd60a1	simple_link
++EXPORT_SYMBOL vmlinux 0x16de64d2	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0x16e287ae	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x16f733d5	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0x1706292f	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x1711edef	current_fs_time
++EXPORT_SYMBOL vmlinux 0x174afb1a	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0x175b5c7b	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0x17648396	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x176eb26a	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0x17751f11	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0x177c93dd	of_find_node_by_type
++EXPORT_SYMBOL vmlinux 0x178d6b01	__f_setown
++EXPORT_SYMBOL vmlinux 0x1792d8aa	dev_notice
++EXPORT_SYMBOL vmlinux 0x179b8a2e	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0x17a205df	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0x17aa156a	__ucmpdi2
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17b36e1e	md_register_thread
++EXPORT_SYMBOL vmlinux 0x17c2f74a	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x17d9d3f3	sync_blockdev
++EXPORT_SYMBOL vmlinux 0x17e0dacd	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0x17e28473	fsl_upm_run_pattern
++EXPORT_SYMBOL vmlinux 0x17f341a0	i8042_lock_chip
++EXPORT_SYMBOL vmlinux 0x180d57de	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x180fef0c	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x182a6a84	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0x182d2a43	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x182fadc3	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x187b32e4	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0x1885f588	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x188d2852	tcp_connect
++EXPORT_SYMBOL vmlinux 0x188ea314	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x189f742a	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x18a23799	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0x18c2227f	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x18f8214c	agp_generic_destroy_pages
++EXPORT_SYMBOL vmlinux 0x19300bd8	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0x194dbae4	param_get_short
++EXPORT_SYMBOL vmlinux 0x19576656	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0x19610e1f	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0x197f0ce5	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x19992f0e	flush_old_exec
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19b7252d	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0x19ba1dc7	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19be8f76	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0x19cfd623	macio_release_resources
++EXPORT_SYMBOL vmlinux 0x19db1506	neigh_update
++EXPORT_SYMBOL vmlinux 0x19df6918	dev_change_flags
++EXPORT_SYMBOL vmlinux 0x19eec936	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x19f3fde9	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0x1a0181d4	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x1a04803b	from_kprojid
++EXPORT_SYMBOL vmlinux 0x1a0dd948	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0x1a11e6c1	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x1a336178	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0x1ac63842	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0x1ac7507e	notify_change
++EXPORT_SYMBOL vmlinux 0x1ad0a0f6	md_write_start
++EXPORT_SYMBOL vmlinux 0x1ad457d3	napi_disable
++EXPORT_SYMBOL vmlinux 0x1ae6e846	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0x1ae71c99	vc_cons
++EXPORT_SYMBOL vmlinux 0x1af62a99	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0x1af7c39a	inet_ioctl
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b0be459	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x1b132009	rename_lock
++EXPORT_SYMBOL vmlinux 0x1b60a6ef	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b748d04	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b850932	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0x1b8b95ad	i8042_unlock_chip
++EXPORT_SYMBOL vmlinux 0x1b9779a2	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x1ba3828e	cdev_alloc
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bb8d68c	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0x1bb98e10	netlink_unicast
++EXPORT_SYMBOL vmlinux 0x1bc4ff03	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0x1bca2b59	load_fp_state
++EXPORT_SYMBOL vmlinux 0x1bd38dab	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x1be00a35	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x1bed19af	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0x1bee6763	macio_release_resource
++EXPORT_SYMBOL vmlinux 0x1c0eb4c7	sk_alloc
++EXPORT_SYMBOL vmlinux 0x1c12944a	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0x1c3b1072	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0x1c4a6e0d	mount_single
++EXPORT_SYMBOL vmlinux 0x1c5b2c15	pmu_wait_complete
++EXPORT_SYMBOL vmlinux 0x1c6bc09d	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0x1c751e1f	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0x1c80de9c	ip_send_check
++EXPORT_SYMBOL vmlinux 0x1c88e91d	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0x1cc59d80	netlink_capable
++EXPORT_SYMBOL vmlinux 0x1cde7177	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0x1ce699c9	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x1d0003d3	page_symlink
++EXPORT_SYMBOL vmlinux 0x1d03e28b	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0x1d1758fd	__nla_put
++EXPORT_SYMBOL vmlinux 0x1d3ef359	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0x1d410f1b	inet_release
++EXPORT_SYMBOL vmlinux 0x1d459c70	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x1d488cd5	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0x1d4d7994	of_graph_parse_endpoint
++EXPORT_SYMBOL vmlinux 0x1d4f3186	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0x1d6cb3dd	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x1d8694ef	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x1d8bb316	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x1daee28a	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x1db6610b	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x1db7ec53	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x1dbf22c9	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dc7cc5d	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1de3d382	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0x1e06b99f	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0x1e203931	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e300621	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0x1e5979ff	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ecfeb0d	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0x1eea1ba2	get_acl
++EXPORT_SYMBOL vmlinux 0x1f40aaa4	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0x1f6f62ef	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0x1f754b3f	dev_set_group
++EXPORT_SYMBOL vmlinux 0x1f765bee	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0x1f7e807f	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x1f7e87be	del_gendisk
++EXPORT_SYMBOL vmlinux 0x1f892504	address_space_init_once
++EXPORT_SYMBOL vmlinux 0x1f9a1eba	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0x1fb2f06c	input_grab_device
++EXPORT_SYMBOL vmlinux 0x1fb35fc1	kmap_atomic_prot
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fcd62dd	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fe7b5bc	md_flush_request
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x20010dd2	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x20020556	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x20030ecd	ioremap
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x20353f78	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x20354ba1	dquot_file_open
++EXPORT_SYMBOL vmlinux 0x20421305	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x205878bd	param_set_ulong
++EXPORT_SYMBOL vmlinux 0x206cfe11	phy_disconnect
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x207373c0	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0x2097da29	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20ad55ac	input_register_handle
++EXPORT_SYMBOL vmlinux 0x20ae58d0	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20d13802	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0x20d8ee83	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0x20da09f6	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20f61d41	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x21099971	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x21168853	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0x21315344	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x2135f32a	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x2140ad3b	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0x214159cd	put_cmsg
++EXPORT_SYMBOL vmlinux 0x2157965d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x216047cc	seq_putc
++EXPORT_SYMBOL vmlinux 0x217d3d00	__break_lease
++EXPORT_SYMBOL vmlinux 0x2181272a	agp_unbind_memory
++EXPORT_SYMBOL vmlinux 0x21827f38	of_get_property
++EXPORT_SYMBOL vmlinux 0x218c7fd8	cdrom_release
++EXPORT_SYMBOL vmlinux 0x21924c97	path_is_under
++EXPORT_SYMBOL vmlinux 0x21ae900d	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x21b6d013	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x21c7cb72	bdi_register
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21f19335	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0x222abce8	ppp_input
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x2253be5d	arp_create
++EXPORT_SYMBOL vmlinux 0x2256fafa	div64_u64_rem
++EXPORT_SYMBOL vmlinux 0x225c7af6	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x22740eb8	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x2278e94b	slhc_remember
++EXPORT_SYMBOL vmlinux 0x227e35a7	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x229346f9	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0x229756f5	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x22a3b122	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22cae020	netdev_printk
++EXPORT_SYMBOL vmlinux 0x22dfdd06	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x22e21d10	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x22e636e4	udp_prot
++EXPORT_SYMBOL vmlinux 0x22e92682	param_set_invbool
++EXPORT_SYMBOL vmlinux 0x22ecb63e	seq_printf
++EXPORT_SYMBOL vmlinux 0x22f6529c	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x23018548	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0x230371e4	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x232abfe5	generic_setxattr
++EXPORT_SYMBOL vmlinux 0x23309922	unlock_rename
++EXPORT_SYMBOL vmlinux 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL vmlinux 0x235506c4	dquot_drop
++EXPORT_SYMBOL vmlinux 0x235e90f3	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x23615c7a	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0x236ce0e4	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0x236e9325	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0x23763c94	mntget
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23aedd50	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0x23b91f63	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23bc7feb	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0x23dc276e	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0x23e93d7f	d_make_root
++EXPORT_SYMBOL vmlinux 0x23f2243d	mempool_free
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x240839bb	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x241b1acb	input_register_device
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x2440b433	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x244cdb61	set_nlink
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x246254cd	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x246f0d0a	key_put
++EXPORT_SYMBOL vmlinux 0x247ad64a	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x24855cba	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x249d4aff	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x24c88d56	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0x24d1b002	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x24d8fd8c	audit_log_start
++EXPORT_SYMBOL vmlinux 0x24e897ca	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x24f00380	ida_init
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x250113b4	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x251270c6	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x2527a087	vme_slave_set
++EXPORT_SYMBOL vmlinux 0x255c9ccf	kernel_write
++EXPORT_SYMBOL vmlinux 0x25624a1b	of_phy_register_fixed_link
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x2589363c	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x25bd34f9	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x25c3ae6b	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0x25d9f57b	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0x25e85806	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x25f1c7d0	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0x25f3bd2e	atomic64_xchg
++EXPORT_SYMBOL vmlinux 0x260015d5	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0x261b0083	security_path_unlink
++EXPORT_SYMBOL vmlinux 0x262e72b9	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x263fee1b	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x2642de73	page_address
++EXPORT_SYMBOL vmlinux 0x26477c07	__vmalloc
++EXPORT_SYMBOL vmlinux 0x264a21c6	mpage_readpages
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x2660e213	cdev_del
++EXPORT_SYMBOL vmlinux 0x267315fa	__ps2_command
++EXPORT_SYMBOL vmlinux 0x2699b277	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x269d48dc	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x26af2a75	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x26b760c4	slhc_init
++EXPORT_SYMBOL vmlinux 0x26bb950b	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0x26bbeb44	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0x26cbcd6f	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0x26e479b0	input_open_device
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26ea64e9	devm_memunmap
++EXPORT_SYMBOL vmlinux 0x26f7a530	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x26f986e1	of_dev_put
++EXPORT_SYMBOL vmlinux 0x26f9c3c1	key_unlink
++EXPORT_SYMBOL vmlinux 0x26fa4421	of_graph_get_remote_port
++EXPORT_SYMBOL vmlinux 0x26fb0060	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x2716529e	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x272234a9	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x272468e6	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0x272c9acd	pmu_battery_count
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x275820a5	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0x275cbfdb	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x2771d7ff	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x277f7794	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x2781f8ae	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x279056e1	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x27a23ba6	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27be2d19	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0x27c85752	dquot_get_state
++EXPORT_SYMBOL vmlinux 0x27ca9589	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x27cac991	vfs_read
++EXPORT_SYMBOL vmlinux 0x27de4c45	of_mdiobus_register
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x280984c7	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0x28133c9f	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x28136755	agp_put_bridge
++EXPORT_SYMBOL vmlinux 0x2815fd5e	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x2819e7d6	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0x282e5fe0	d_alloc
++EXPORT_SYMBOL vmlinux 0x28891318	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x289db3ee	idr_remove
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28a7beba	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x28aeb1f3	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x28b153b1	skb_trim
++EXPORT_SYMBOL vmlinux 0x28bb11ba	sock_no_listen
++EXPORT_SYMBOL vmlinux 0x28bf12d3	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0x28d1a7d2	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x28e388d9	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0x28e6ce45	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x28f784f5	__debugger_break_match
++EXPORT_SYMBOL vmlinux 0x28fcaf9f	flush_tlb_page
++EXPORT_SYMBOL vmlinux 0x29049d2c	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0x2905c8af	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x29260d1b	put_disk
++EXPORT_SYMBOL vmlinux 0x293a2144	dquot_initialize
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x295531a9	__blk_end_request
++EXPORT_SYMBOL vmlinux 0x295c2365	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0x295ef798	do_splice_to
++EXPORT_SYMBOL vmlinux 0x2963a439	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x2968f0ac	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0x2975778c	kernel_bind
++EXPORT_SYMBOL vmlinux 0x2983621e	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0x29a06e33	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0x29a19861	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x29a3a0d1	__scm_destroy
++EXPORT_SYMBOL vmlinux 0x29aced5d	__devm_release_region
++EXPORT_SYMBOL vmlinux 0x29b67018	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0x29b79328	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x29be662c	udp_poll
++EXPORT_SYMBOL vmlinux 0x29cae3bf	phy_device_register
++EXPORT_SYMBOL vmlinux 0x29cf5f7e	setup_new_exec
++EXPORT_SYMBOL vmlinux 0x29fdda53	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a375d61	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x2a3ff0ee	serio_reconnect
++EXPORT_SYMBOL vmlinux 0x2a71fde4	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x2a7cac99	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x2a801dce	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x2aa0e4fc	strncasecmp
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2abdc4f3	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0x2ac885bc	pci_iounmap
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2ad0a17a	tty_throttle
++EXPORT_SYMBOL vmlinux 0x2ad22484	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x2ad313f2	empty_aops
++EXPORT_SYMBOL vmlinux 0x2ad61983	param_get_string
++EXPORT_SYMBOL vmlinux 0x2ae5cede	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b0e43eb	set_posix_acl
++EXPORT_SYMBOL vmlinux 0x2b12925d	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b5159f3	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x2b653df8	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0x2b6cf66b	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0x2b7b462a	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x2b7c635c	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x2b88fd8e	pci_get_device
++EXPORT_SYMBOL vmlinux 0x2b91c90a	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0x2b9c9f64	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2bc409e5	sget_userns
++EXPORT_SYMBOL vmlinux 0x2bd72558	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x2be630f1	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0x2be72621	fb_show_logo
++EXPORT_SYMBOL vmlinux 0x2bebde99	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0x2bf9bd6b	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0x2c14323a	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c2c8658	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0x2c3a743e	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x2c6b50a0	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x2c6ef1d7	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0x2c710885	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0x2c7b1fca	down_timeout
++EXPORT_SYMBOL vmlinux 0x2c86128d	i2c_release_client
++EXPORT_SYMBOL vmlinux 0x2c8a4bb7	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0x2c909674	skb_pad
++EXPORT_SYMBOL vmlinux 0x2c9d7ef6	bdget
++EXPORT_SYMBOL vmlinux 0x2ca793d2	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0x2cc62020	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x2cc7e2c8	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0x2ccbdc94	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x2cd4d20e	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0x2cec447e	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0x2cff2773	netdev_err
++EXPORT_SYMBOL vmlinux 0x2d0b559b	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d470267	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x2d6909de	seq_open_private
++EXPORT_SYMBOL vmlinux 0x2d6f603f	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0x2d783f30	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0x2d7b7d57	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x2d807643	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x2d9ba07e	inet_addr_type
++EXPORT_SYMBOL vmlinux 0x2d9cec76	param_get_ushort
++EXPORT_SYMBOL vmlinux 0x2de3fabb	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0x2dec94fd	inet_frag_find
++EXPORT_SYMBOL vmlinux 0x2e008b6c	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x2e083fe1	agp_bind_memory
++EXPORT_SYMBOL vmlinux 0x2e28f1f7	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e2dc3aa	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0x2e5568e2	phy_print_status
++EXPORT_SYMBOL vmlinux 0x2e664074	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x2e6678d1	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0x2e7b8662	get_super_thawed
++EXPORT_SYMBOL vmlinux 0x2e88d0b0	of_find_compatible_node
++EXPORT_SYMBOL vmlinux 0x2ea522f0	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x2eb08b82	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x2ebb5ff5	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0x2ec524ad	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x2ef0ee61	vme_slave_request
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2efebec0	override_creds
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f2bbcbb	vfs_link
++EXPORT_SYMBOL vmlinux 0x2f34b8e9	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0x2f397d0a	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2f47d0f7	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0x2f700f0a	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x2f73f4ed	blk_make_request
++EXPORT_SYMBOL vmlinux 0x2f7911c7	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x2f7bca0e	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0x2f7d1877	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0x2f7ec038	km_policy_expired
++EXPORT_SYMBOL vmlinux 0x2f872b15	register_shrinker
++EXPORT_SYMBOL vmlinux 0x2f8a9e40	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x2f8f0cf5	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x2f9659f4	tcp_child_process
++EXPORT_SYMBOL vmlinux 0x2f9cb70d	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0x2fa21d2b	of_create_pci_dev
++EXPORT_SYMBOL vmlinux 0x2faa499e	seq_lseek
++EXPORT_SYMBOL vmlinux 0x2fad9a75	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x2fae96de	rtas_data_buf_lock
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fd5f0d3	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2fe36097	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x30032aab	netlink_ack
++EXPORT_SYMBOL vmlinux 0x300f0ab2	kset_register
++EXPORT_SYMBOL vmlinux 0x3016c719	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x30184eeb	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x30226ddf	agp_device_command
++EXPORT_SYMBOL vmlinux 0x3023fe06	km_state_expired
++EXPORT_SYMBOL vmlinux 0x30284817	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x3029e069	revalidate_disk
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x3036acd6	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0x30464c7b	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0x306dfce6	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0x307be96d	free_page_put_link
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x30885d55	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0x308cab97	pmac_resume_agp_for_card
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30b234af	current_in_userns
++EXPORT_SYMBOL vmlinux 0x30b8b35c	cpu_to_chip_id
++EXPORT_SYMBOL vmlinux 0x30de4b4b	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0x30e65a76	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0x30f3acf3	pci_dev_get
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310917fe	sort
++EXPORT_SYMBOL vmlinux 0x310b7096	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x31208b9a	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0x31380354	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x31713e56	bio_chain
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x317ee5a3	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x318b77aa	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x3191f109	__krealloc
++EXPORT_SYMBOL vmlinux 0x31973137	cdrom_open
++EXPORT_SYMBOL vmlinux 0x31c5224b	of_find_node_with_property
++EXPORT_SYMBOL vmlinux 0x31f0bb78	__kmap_atomic_idx
++EXPORT_SYMBOL vmlinux 0x31ffa225	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x32181b3a	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0x3226d8fc	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0x3239d492	fb_blank
++EXPORT_SYMBOL vmlinux 0x3248681d	fasync_helper
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x325fde95	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0x3263300b	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0x327b9c1b	pmu_poll_adb
++EXPORT_SYMBOL vmlinux 0x328a05f1	strncpy
++EXPORT_SYMBOL vmlinux 0x32943c7b	register_cdrom
++EXPORT_SYMBOL vmlinux 0x329f1260	of_mm_gpiochip_add
++EXPORT_SYMBOL vmlinux 0x32b8c77e	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0x32daaef0	invalidate_partition
++EXPORT_SYMBOL vmlinux 0x32dbaefb	write_one_page
++EXPORT_SYMBOL vmlinux 0x32f9af1d	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0x334b85ee	agp_free_memory
++EXPORT_SYMBOL vmlinux 0x3396f6f2	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x3399a693	tc_classify
++EXPORT_SYMBOL vmlinux 0x33b84f74	copy_page
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33c9ef60	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x33dbfd93	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x33e3b384	iterate_fd
++EXPORT_SYMBOL vmlinux 0x33ee61dc	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x33fc88b6	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0x34158413	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0x341dbfa3	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x34266a2f	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x342c5b36	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x344adbd5	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x347b3a13	tty_hangup
++EXPORT_SYMBOL vmlinux 0x348640d5	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0x349318d4	set_page_dirty
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x349d0445	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0x34aff994	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x34bb7fd4	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0x34cb98e4	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x34e53572	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x34e90e03	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0x34f00baf	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x351707cd	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x353de98f	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x355bfe1f	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x357855e6	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x357be0ca	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0x358dbb5e	generic_read_dir
++EXPORT_SYMBOL vmlinux 0x359700f2	redraw_screen
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35c32767	xor_altivec_2
++EXPORT_SYMBOL vmlinux 0x35cee5c5	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0x35e9fe77	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0x35fbd6a1	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x361176b5	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x3618cb2d	ida_destroy
++EXPORT_SYMBOL vmlinux 0x3625e424	dquot_destroy
++EXPORT_SYMBOL vmlinux 0x36497663	dev_mc_add
++EXPORT_SYMBOL vmlinux 0x365724f3	touch_buffer
++EXPORT_SYMBOL vmlinux 0x365a2fbb	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x365c673d	get_empty_filp
++EXPORT_SYMBOL vmlinux 0x365ee6df	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0x366f6d27	idr_destroy
++EXPORT_SYMBOL vmlinux 0x367ba856	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0x3686b71b	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0x3692ee58	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0x36a2e218	generic_file_open
++EXPORT_SYMBOL vmlinux 0x36a65359	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x36b0e732	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0x36b42c68	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36c6cff0	netif_device_detach
++EXPORT_SYMBOL vmlinux 0x36e28ed9	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0x36fdda67	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x37078fdf	vga_put
++EXPORT_SYMBOL vmlinux 0x37093d41	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0x370db1a7	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x3717230c	of_translate_dma_address
++EXPORT_SYMBOL vmlinux 0x371d2130	check_legacy_ioport
++EXPORT_SYMBOL vmlinux 0x37383edd	rtas_get_power_level
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x3755ccca	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x375c7f6b	__find_get_block
++EXPORT_SYMBOL vmlinux 0x377d36ee	release_sock
++EXPORT_SYMBOL vmlinux 0x377d39e5	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0x3791c856	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x379cac59	dev_deactivate
++EXPORT_SYMBOL vmlinux 0x37a6c6df	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37b30a79	dev_alert
++EXPORT_SYMBOL vmlinux 0x37b8b39e	screen_info
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37d87952	sock_edemux
++EXPORT_SYMBOL vmlinux 0x37e0153d	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x37e74642	get_jiffies_64
++EXPORT_SYMBOL vmlinux 0x37f614b7	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x37f6fee5	fsl_lbc_find
++EXPORT_SYMBOL vmlinux 0x38196e74	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x381c287a	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0x3835a236	agp3_generic_tlbflush
++EXPORT_SYMBOL vmlinux 0x38428be5	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0x384462e3	simple_readpage
++EXPORT_SYMBOL vmlinux 0x385ef1ce	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x388726bf	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38b825d1	idr_replace
++EXPORT_SYMBOL vmlinux 0x38dc6a7e	d_splice_alias
++EXPORT_SYMBOL vmlinux 0x38f18c2c	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x38f270b1	framebuffer_release
++EXPORT_SYMBOL vmlinux 0x38fb9933	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x390787de	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x39995443	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39c08721	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x39c2c358	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x39cdf63c	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x39f429f9	__lock_page
++EXPORT_SYMBOL vmlinux 0x3a1ac054	set_normalized_timespec64
++EXPORT_SYMBOL vmlinux 0x3a221582	skb_checksum
++EXPORT_SYMBOL vmlinux 0x3a2b4bc5	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x3a4a95eb	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x3a65d29f	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x3a715a4a	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0x3a94b063	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3ab8a709	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x3ad55782	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x3af2fdbe	md_write_end
++EXPORT_SYMBOL vmlinux 0x3afd929e	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x3b2053a8	dm_get_device
++EXPORT_SYMBOL vmlinux 0x3b615a21	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b76504f	phy_start
++EXPORT_SYMBOL vmlinux 0x3b8ee8b8	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0x3bb1619d	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x3bc4d7bd	pci_bus_type
++EXPORT_SYMBOL vmlinux 0x3be33caf	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0x3bebaa7b	inode_init_owner
++EXPORT_SYMBOL vmlinux 0x3c057da2	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x3c39d188	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c5dce1c	sk_free
++EXPORT_SYMBOL vmlinux 0x3c652b24	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0x3c75494f	posix_test_lock
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c8375b9	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x3caee02f	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x3cbac32b	make_kgid
++EXPORT_SYMBOL vmlinux 0x3cbb3ea4	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0x3cc28c1e	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x3cc4b0dc	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3cffedbb	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0x3d0e1968	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0x3d1a8bd5	arp_tbl
++EXPORT_SYMBOL vmlinux 0x3d1cc6d0	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0x3d1ea90a	ilookup5
++EXPORT_SYMBOL vmlinux 0x3d36b927	skb_store_bits
++EXPORT_SYMBOL vmlinux 0x3d37b0b3	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0x3d519992	vm_map_ram
++EXPORT_SYMBOL vmlinux 0x3d54ee56	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x3d57b0f0	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0x3d62acc7	filp_close
++EXPORT_SYMBOL vmlinux 0x3d6c308d	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x3d79fc65	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x3d9d0818	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0x3dc02a4e	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0x3dcb590c	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3dd588d1	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x3dd6a5dd	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x3de3d4eb	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3dfe3077	serio_rescan
++EXPORT_SYMBOL vmlinux 0x3e0a55ca	do_splice_direct
++EXPORT_SYMBOL vmlinux 0x3e0c2205	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0x3e646488	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e9ccb48	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x3e9d990b	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x3ea2fa69	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0x3eb707ad	elv_add_request
++EXPORT_SYMBOL vmlinux 0x3ec7eff1	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0x3ed6bd33	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x3ee56480	abort_creds
++EXPORT_SYMBOL vmlinux 0x3eeb5640	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x3eeb7776	d_delete
++EXPORT_SYMBOL vmlinux 0x3f0424ec	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x3f0546a8	ioread32_rep
++EXPORT_SYMBOL vmlinux 0x3f074e60	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0x3f0769b1	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0x3f2d94b3	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0x3f3022eb	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x3f3772cf	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x3f406a3b	enable_kernel_altivec
++EXPORT_SYMBOL vmlinux 0x3f43bc70	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f5c9170	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x3f616ce2	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x3f793054	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x3fa8b240	kill_anon_super
++EXPORT_SYMBOL vmlinux 0x3faf56e4	input_inject_event
++EXPORT_SYMBOL vmlinux 0x3fb1cf71	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x3fc3e4e3	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0x3fc90f99	dev_err
++EXPORT_SYMBOL vmlinux 0x3fd955b7	bio_flush_dcache_pages
++EXPORT_SYMBOL vmlinux 0x3fe0d1c0	slhc_free
++EXPORT_SYMBOL vmlinux 0x3fe7a428	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x3ff14922	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x3ff8e495	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4038d708	kernel_read
++EXPORT_SYMBOL vmlinux 0x4039240f	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0x4059792f	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x4097c632	__page_symlink
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a2d1dd	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c1534b	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d14e8d	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x40d52bf5	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40d889ee	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0x40f1ad10	tb_ticks_per_jiffy
++EXPORT_SYMBOL vmlinux 0x410b32d0	of_get_cpu_node
++EXPORT_SYMBOL vmlinux 0x4132c229	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x4133223d	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x4153e0aa	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x415d8ba8	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x4164d1bf	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x418a5367	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x419f9b7a	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0x41efe3e6	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0x4215bd1b	input_close_device
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x422fd07f	agp_generic_type_to_mask_type
++EXPORT_SYMBOL vmlinux 0x423fc69c	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0x4244b4cc	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x42595e58	vgacon_text_force
++EXPORT_SYMBOL vmlinux 0x4261e3fc	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0x4275620a	mac_find_mode
++EXPORT_SYMBOL vmlinux 0x429a1492	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x429be6d3	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42ab89a4	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0x42b0846d	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x42bb960a	__inet_hash
++EXPORT_SYMBOL vmlinux 0x42fce228	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x43356531	__module_get
++EXPORT_SYMBOL vmlinux 0x4338a6b6	I_BDEV
++EXPORT_SYMBOL vmlinux 0x4349e0bf	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x43527c72	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0x436c2179	iowrite32
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x439742ae	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0x43a01f90	complete_all
++EXPORT_SYMBOL vmlinux 0x43a323c3	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0x43b8cd27	i2c_transfer
++EXPORT_SYMBOL vmlinux 0x43cbaa6e	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x43d147d7	agp_generic_alloc_by_type
++EXPORT_SYMBOL vmlinux 0x43d8a449	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x43e60501	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x44031dc8	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x44366cfc	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0x443c9472	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x44438b96	hex2bin
++EXPORT_SYMBOL vmlinux 0x444e4e7d	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x445294d2	mount_bdev
++EXPORT_SYMBOL vmlinux 0x4457a2dd	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0x447deedf	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0x44a10344	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44d0734d	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x44d57adc	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0x44d6ffb2	clear_nlink
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44eb192e	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x4500a9fc	of_phy_find_device
++EXPORT_SYMBOL vmlinux 0x451f08ca	phy_device_remove
++EXPORT_SYMBOL vmlinux 0x45218fc3	agp_allocate_memory
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x456a1e70	bh_submit_read
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x458929ea	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x45a30c15	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0x45b91f5d	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x45bb52e0	km_query
++EXPORT_SYMBOL vmlinux 0x45d3bba6	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0x45d4ddcb	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x45e2c072	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0x45ef718d	seq_write
++EXPORT_SYMBOL vmlinux 0x45efa600	inet_listen
++EXPORT_SYMBOL vmlinux 0x45f8881a	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0x46005ae0	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0x460dd3c4	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x4612c59d	down_trylock
++EXPORT_SYMBOL vmlinux 0x461cddbc	udp_del_offload
++EXPORT_SYMBOL vmlinux 0x461ebfa0	__copy_tofrom_user
++EXPORT_SYMBOL vmlinux 0x46214596	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0x462345e1	xmon
++EXPORT_SYMBOL vmlinux 0x4623f3a4	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0x46284b8d	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0x462a2e75	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x46389fd5	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0x465757c3	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x4658d3ce	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x46690ca2	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x46c74cac	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0x46cdbc9c	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x46d12956	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x46de1cfb	mmc_release_host
++EXPORT_SYMBOL vmlinux 0x46e8d54c	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0x46f1b83e	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x4713189c	param_set_ushort
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x4757ac8c	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x475ff27f	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x47608718	fence_init
++EXPORT_SYMBOL vmlinux 0x47711109	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0x47794a25	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x47811d31	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0x4791bd7a	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x47a5166b	of_platform_device_create
++EXPORT_SYMBOL vmlinux 0x47b84ffa	vme_master_request
++EXPORT_SYMBOL vmlinux 0x47bda8d9	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x47c62a9b	set_anon_super
++EXPORT_SYMBOL vmlinux 0x47ca47e4	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0x47d81db6	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0x47e7195a	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x47eaeab0	scsi_register
++EXPORT_SYMBOL vmlinux 0x4808610e	set_blocksize
++EXPORT_SYMBOL vmlinux 0x4812d742	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x481ce6ce	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x483e8987	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0x48404b9a	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x48465cdc	end_page_writeback
++EXPORT_SYMBOL vmlinux 0x484a7074	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0x484e9307	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0x484f4328	nf_log_unset
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x486ef23c	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0x4881efab	pmac_get_partition
++EXPORT_SYMBOL vmlinux 0x489bbd09	flush_icache_user_range
++EXPORT_SYMBOL vmlinux 0x489e795c	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0x48aa7df7	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48baff3c	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0x48c8708b	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x48e65314	of_mdio_parse_addr
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x490da710	of_find_all_nodes
++EXPORT_SYMBOL vmlinux 0x4911f848	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0x4918e345	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0x4953b154	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x4955db4b	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x496d5943	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0x49722b8b	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x4973edf2	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49cfa972	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0x49de971f	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0x49e7f8ca	of_mdio_find_bus
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x49fcfada	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x4a07554d	sock_i_ino
++EXPORT_SYMBOL vmlinux 0x4a140188	lookup_one_len
++EXPORT_SYMBOL vmlinux 0x4a150716	agp_collect_device_status
++EXPORT_SYMBOL vmlinux 0x4a381012	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0x4a38dfaf	sock_efree
++EXPORT_SYMBOL vmlinux 0x4a6e153e	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0x4a717c6d	commit_creds
++EXPORT_SYMBOL vmlinux 0x4aa22c72	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0x4ab1dfc0	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4abbebdb	submit_bh
++EXPORT_SYMBOL vmlinux 0x4ac12431	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0x4ac2471c	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0x4ad650a8	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0x4ad85f2c	dma_direct_ops
++EXPORT_SYMBOL vmlinux 0x4adc88f0	backlight_device_register
++EXPORT_SYMBOL vmlinux 0x4ae151a6	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x4af4a976	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x4afc8302	skb_clone
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b0238cc	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0x4b085dbf	agp3_generic_configure
++EXPORT_SYMBOL vmlinux 0x4b1ec3e2	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x4b3bbb5d	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b65aa37	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0x4b7f3efd	serio_interrupt
++EXPORT_SYMBOL vmlinux 0x4b8326ff	ida_remove
++EXPORT_SYMBOL vmlinux 0x4b8fe3b9	proto_unregister
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4bb9fa83	inet_bind
++EXPORT_SYMBOL vmlinux 0x4bbf51a9	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0x4bcf03a4	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x4bd22623	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0x4be08bf6	generic_fillattr
++EXPORT_SYMBOL vmlinux 0x4be3b50a	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0x4be3b6d7	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x4be85a03	memweight
++EXPORT_SYMBOL vmlinux 0x4beb1a74	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0x4beb3057	sock_i_uid
++EXPORT_SYMBOL vmlinux 0x4bed99b3	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0x4bfc4546	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0x4c11435a	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0x4c168057	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0x4c29cd6f	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0x4c29dcbf	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x4c2ae700	strnstr
++EXPORT_SYMBOL vmlinux 0x4c2b25ed	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c3a3406	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0x4c5f8f38	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0x4c7061fa	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x4c7a2c24	tty_kref_put
++EXPORT_SYMBOL vmlinux 0x4c7dd80e	nf_log_register
++EXPORT_SYMBOL vmlinux 0x4c7e4941	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0x4c7e86bb	blk_end_request
++EXPORT_SYMBOL vmlinux 0x4c821dda	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x4ca25530	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0x4ca78a1f	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0x4ccef2aa	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4ced0cfc	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0x4cf0482d	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x4d1b98de	iunique
++EXPORT_SYMBOL vmlinux 0x4d3c153f	sigprocmask
++EXPORT_SYMBOL vmlinux 0x4d423bd1	console_stop
++EXPORT_SYMBOL vmlinux 0x4d45d89e	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x4d4ab0c2	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x4d4b5af3	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0x4d5cfb02	keyring_clear
++EXPORT_SYMBOL vmlinux 0x4d666bab	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0x4d78d6e4	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0x4d791953	mempool_resize
++EXPORT_SYMBOL vmlinux 0x4d83b295	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x4d891d20	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9967e0	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4da2cb83	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0x4daa323b	udp_ioctl
++EXPORT_SYMBOL vmlinux 0x4db7bfdb	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0x4dd8e39b	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x4ddddd26	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4dec6038	memscan
++EXPORT_SYMBOL vmlinux 0x4df0aeab	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4e000244	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x4e0acdb4	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0x4e0bb0f4	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x4e127222	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x4e2db603	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e40eeb1	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0x4e4b4d9b	of_get_next_available_child
++EXPORT_SYMBOL vmlinux 0x4e5c5fbc	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x4e6379c4	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e8ec25b	udp_add_offload
++EXPORT_SYMBOL vmlinux 0x4e9dffb5	ip_fast_csum
++EXPORT_SYMBOL vmlinux 0x4eaf10f7	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0x4eefbed4	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x4efb6c06	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0x4eff85fb	path_noexec
++EXPORT_SYMBOL vmlinux 0x4f0d120f	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f33f81f	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f4ae05e	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0x4f4bb2c6	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0x4f51222f	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0x4f512dba	vfs_statfs
++EXPORT_SYMBOL vmlinux 0x4f6041ef	dns_query
++EXPORT_SYMBOL vmlinux 0x4f620ecd	agp_generic_alloc_user
++EXPORT_SYMBOL vmlinux 0x4f6258aa	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f85e79f	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0x4f8fae08	mdiobus_free
++EXPORT_SYMBOL vmlinux 0x4fadc242	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x4fdee897	i8042_command
++EXPORT_SYMBOL vmlinux 0x4fe99583	atomic64_dec_if_positive
++EXPORT_SYMBOL vmlinux 0x50085837	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x5012ca8b	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0x5050a755	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x5050c098	phy_driver_register
++EXPORT_SYMBOL vmlinux 0x50590245	of_device_register
++EXPORT_SYMBOL vmlinux 0x505fe73b	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x506612ef	netdev_features_change
++EXPORT_SYMBOL vmlinux 0x509817cf	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x50afb4ce	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0x50b66bcb	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x50f58edc	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x51177368	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0x5118858f	vme_dma_request
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x511a6ca7	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0x511e34c8	nf_afinfo
++EXPORT_SYMBOL vmlinux 0x513ab975	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0x515e24a7	flush_instruction_cache
++EXPORT_SYMBOL vmlinux 0x515f95c2	bio_copy_data
++EXPORT_SYMBOL vmlinux 0x51671bce	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x5176d6af	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0x51776f51	load_nls_default
++EXPORT_SYMBOL vmlinux 0x518629fd	d_rehash
++EXPORT_SYMBOL vmlinux 0x519b0da3	finish_wait
++EXPORT_SYMBOL vmlinux 0x519bca83	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x519e30f8	downgrade_write
++EXPORT_SYMBOL vmlinux 0x51a43585	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0x51d0e127	pci_match_id
++EXPORT_SYMBOL vmlinux 0x51e55335	giveup_altivec
++EXPORT_SYMBOL vmlinux 0x51e59d00	padata_free
++EXPORT_SYMBOL vmlinux 0x51e9331d	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0x51ef33b8	kstrndup
++EXPORT_SYMBOL vmlinux 0x51f94adb	vfs_readv
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x52039f57	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0x520b0bad	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x522b95df	simple_write_end
++EXPORT_SYMBOL vmlinux 0x5230054f	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0x524e54cf	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0x525ee924	param_array_ops
++EXPORT_SYMBOL vmlinux 0x5275d4c2	inode_permission
++EXPORT_SYMBOL vmlinux 0x527830ff	pmac_xpram_read
++EXPORT_SYMBOL vmlinux 0x528c709d	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x529d2edf	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x52af562a	__crc32c_le
++EXPORT_SYMBOL vmlinux 0x52e34a3a	netif_device_attach
++EXPORT_SYMBOL vmlinux 0x52f67ade	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0x52f9bc64	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0x53068eb1	key_task_permission
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x53234e55	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x533a95eb	of_get_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0x5351ab1a	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0x5359916d	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x5389584a	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0x53a266ea	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0x53be79c7	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0x53d6ea6b	sock_release
++EXPORT_SYMBOL vmlinux 0x53dc2093	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0x53ebab1b	_outsl_ns
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x5411962a	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x5412c7c7	up
++EXPORT_SYMBOL vmlinux 0x541f7173	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x544d5bd8	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0x5469b5c6	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0x5472ac2d	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54abfaea	flush_hash_entry
++EXPORT_SYMBOL vmlinux 0x54b72454	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0x54bc6449	seq_dentry
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54d45597	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54e88dcd	unregister_key_type
++EXPORT_SYMBOL vmlinux 0x54ed07ba	pci_bus_put
++EXPORT_SYMBOL vmlinux 0x55075c29	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x55467ede	fsl_upm_find
++EXPORT_SYMBOL vmlinux 0x55503930	vfs_unlink
++EXPORT_SYMBOL vmlinux 0x55543fb0	proc_set_user
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x5568c553	complete
++EXPORT_SYMBOL vmlinux 0x5577ef9e	udp_table
++EXPORT_SYMBOL vmlinux 0x55b956c0	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x55dd90ba	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x55f34978	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x56185f15	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0x562d39aa	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x563952a3	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x563f3393	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x56569027	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0x5657e8a8	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x565ab334	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x56721689	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0x567851e6	__frontswap_test
++EXPORT_SYMBOL vmlinux 0x5689402c	kfree_skb
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x56952301	mach_chrp
++EXPORT_SYMBOL vmlinux 0x56c0a7fd	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0x56c2b95b	rtas_progress
++EXPORT_SYMBOL vmlinux 0x56c5ba86	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x570109aa	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0x5704aac5	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x570d94d3	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0x5710b864	phy_attach
++EXPORT_SYMBOL vmlinux 0x57195595	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0x571e0c27	single_open
++EXPORT_SYMBOL vmlinux 0x5724a73e	simple_follow_link
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x5735bd44	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0x5746ebde	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x5751247b	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0x57528f91	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x57c51a6b	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x57c9c2aa	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x57ccb5d8	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0x57d0bb22	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x57f152aa	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x58227e6d	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x582d9d4d	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0x583127b1	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x5848e804	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0x584a2999	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0x585522bb	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0x5857b225	ioread16_rep
++EXPORT_SYMBOL vmlinux 0x58623807	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x588edf01	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x589a3e63	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0x589c5b5b	flow_cache_init
++EXPORT_SYMBOL vmlinux 0x58b47ef2	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58bc7aba	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0x58be4430	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0x58d0a2d5	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x58fc2e53	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0x5905d860	vm_stat
++EXPORT_SYMBOL vmlinux 0x5911b90d	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x591241d0	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0x59239022	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x5927b11b	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0x5929d9f7	register_netdev
++EXPORT_SYMBOL vmlinux 0x59429a0e	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x5959a7f7	dquot_commit
++EXPORT_SYMBOL vmlinux 0x595ac960	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x595d0946	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x596d6840	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0x597ddd73	dev_warn
++EXPORT_SYMBOL vmlinux 0x5988a427	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x599f5711	cdev_init
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59b3378a	completion_done
++EXPORT_SYMBOL vmlinux 0x59c99a3f	blk_run_queue
++EXPORT_SYMBOL vmlinux 0x59cedeb0	of_device_is_compatible
++EXPORT_SYMBOL vmlinux 0x59d8223a	ioport_resource
++EXPORT_SYMBOL vmlinux 0x5a046285	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a102f32	inet_sendpage
++EXPORT_SYMBOL vmlinux 0x5a1fdf06	import_iovec
++EXPORT_SYMBOL vmlinux 0x5a36a52a	do_SAK
++EXPORT_SYMBOL vmlinux 0x5a419407	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0x5a4cbeee	__register_chrdev
++EXPORT_SYMBOL vmlinux 0x5a691091	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0x5a6a8add	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0x5a7b42e8	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x5abdc721	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5b19634d	div_s64_rem
++EXPORT_SYMBOL vmlinux 0x5b43f1f1	rtas_service_present
++EXPORT_SYMBOL vmlinux 0x5b524c7f	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x5b5712a5	dev_load
++EXPORT_SYMBOL vmlinux 0x5b73ed1c	thaw_bdev
++EXPORT_SYMBOL vmlinux 0x5b88e21f	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x5b9828c5	dma_spin_lock
++EXPORT_SYMBOL vmlinux 0x5b9b3a23	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x5bb9daec	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0x5bbeb969	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0x5bd5d2b3	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0x5bd8165a	__d_drop
++EXPORT_SYMBOL vmlinux 0x5bddb81c	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0x5bdf463a	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x5bf1abb4	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0x5c265cba	sg_init_one
++EXPORT_SYMBOL vmlinux 0x5c37c147	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x5c37f319	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x5c5293f2	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0x5c6d231f	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0x5c81a80e	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0x5c85556b	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x5c94e17b	xfrm_input
++EXPORT_SYMBOL vmlinux 0x5ca10397	lro_flush_all
++EXPORT_SYMBOL vmlinux 0x5cc1d19f	irq_to_desc
++EXPORT_SYMBOL vmlinux 0x5cc32bdc	bitmap_copy_le
++EXPORT_SYMBOL vmlinux 0x5cc3f40e	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x5cd9e760	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0x5cdcf53a	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0x5ce12074	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5cff9bab	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0x5d03ec61	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0x5d067e06	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0x5d10cca9	sk_capable
++EXPORT_SYMBOL vmlinux 0x5d1b5ce9	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0x5d3dd465	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x5d40bd38	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0x5d492fed	dst_init
++EXPORT_SYMBOL vmlinux 0x5d50bf19	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d6234b3	register_netdevice
++EXPORT_SYMBOL vmlinux 0x5d774e3a	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0x5d7780a3	led_set_brightness
++EXPORT_SYMBOL vmlinux 0x5da2f67c	vfs_writev
++EXPORT_SYMBOL vmlinux 0x5dc8a7ee	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0x5dd1425a	get_gendisk
++EXPORT_SYMBOL vmlinux 0x5dd41d5a	of_iomap
++EXPORT_SYMBOL vmlinux 0x5de7602e	bdi_init
++EXPORT_SYMBOL vmlinux 0x5e087be7	param_set_bint
++EXPORT_SYMBOL vmlinux 0x5e0cb8e1	pci_release_region
++EXPORT_SYMBOL vmlinux 0x5e27321b	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0x5e29888e	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0x5e30079f	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x5e3a8a9c	__wake_up
++EXPORT_SYMBOL vmlinux 0x5e3dcdc5	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0x5e3fff84	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x5e4b6fc2	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x5e5d93a8	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x5e866d85	prandom_bytes
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5eb0401e	proc_dostring
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ec50fb1	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x5ec932af	security_path_chown
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5ed0708b	of_node_get
++EXPORT_SYMBOL vmlinux 0x5ed77e8e	__check_sticky
++EXPORT_SYMBOL vmlinux 0x5ee4d7c8	generic_write_end
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f079b2a	md_update_sb
++EXPORT_SYMBOL vmlinux 0x5f07fe76	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f0aa4f1	skb_copy
++EXPORT_SYMBOL vmlinux 0x5f21f985	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0x5f54f424	dquot_release
++EXPORT_SYMBOL vmlinux 0x5f5accc5	inet6_release
++EXPORT_SYMBOL vmlinux 0x5f63331b	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x5f6c19ef	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x5f754e5a	memset
++EXPORT_SYMBOL vmlinux 0x5f806242	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0x5f8a2728	isa_io_base
++EXPORT_SYMBOL vmlinux 0x5f8b8d7d	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0x5f9857be	of_match_device
++EXPORT_SYMBOL vmlinux 0x5fb357b1	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0x5fc2be2f	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0x5fd268cb	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x5ff014b7	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x6007f3b3	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0x600a7ee9	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0x6011cc22	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x6026c87f	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x60600039	vm_mmap
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x60731535	__seq_open_private
++EXPORT_SYMBOL vmlinux 0x6073732c	cur_cpu_spec
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x609f5a3c	seq_release
++EXPORT_SYMBOL vmlinux 0x60c63804	inode_init_once
++EXPORT_SYMBOL vmlinux 0x60c6a7b6	kfree_put_link
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x60f22bfc	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x6106acad	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x616b825d	dql_init
++EXPORT_SYMBOL vmlinux 0x6193d217	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x619f4dd7	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0x61b30053	put_tty_driver
++EXPORT_SYMBOL vmlinux 0x61b3560c	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61c25110	md_check_recovery
++EXPORT_SYMBOL vmlinux 0x61d59fa4	path_put
++EXPORT_SYMBOL vmlinux 0x61ecfb73	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0x61eef2c9	_insb
++EXPORT_SYMBOL vmlinux 0x61f1daf0	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0x61fec807	from_kgid
++EXPORT_SYMBOL vmlinux 0x6209a83d	nf_log_set
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x6220a325	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0x6220b4a2	crc32_le
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x62290f61	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x623d7182	_chrp_type
++EXPORT_SYMBOL vmlinux 0x6241f605	giveup_fpu
++EXPORT_SYMBOL vmlinux 0x62425a8b	genl_notify
++EXPORT_SYMBOL vmlinux 0x62538167	slhc_toss
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x628332e8	pmu_power_flags
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x628ce6fe	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x62ab5619	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0x62aba682	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x62ea9af4	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0x62f65007	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x630ae12c	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x633582e7	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x63552a4e	vmap
++EXPORT_SYMBOL vmlinux 0x6360298c	key_alloc
++EXPORT_SYMBOL vmlinux 0x636f8435	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0x63789e73	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x6381c383	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0x6387af3a	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63aed704	textsearch_register
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63e3b384	vme_irq_free
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63efc982	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0x63f48cba	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x64028cf4	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x64069325	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x6413ddd5	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0x64147132	datagram_poll
++EXPORT_SYMBOL vmlinux 0x64337a0c	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0x6434b8b7	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0x64565307	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0x6466c45a	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0x646cc6ab	pmu_poll
++EXPORT_SYMBOL vmlinux 0x646ef81c	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x64746b80	blk_queue_split
++EXPORT_SYMBOL vmlinux 0x647f0f4c	user_path_create
++EXPORT_SYMBOL vmlinux 0x64814938	napi_complete_done
++EXPORT_SYMBOL vmlinux 0x648f3f67	tty_name
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x649a2cdc	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x651065df	of_mm_gpiochip_remove
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x6531cec1	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0x65400222	__irq_offset_value
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x6555ef6d	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0x65826a5c	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0x65bb58a2	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0x65ce407e	ihold
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65ec0d2d	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x66002161	skb_pull
++EXPORT_SYMBOL vmlinux 0x6611fcd7	of_device_is_big_endian
++EXPORT_SYMBOL vmlinux 0x661d5813	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0x66227eae	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0x66282930	tty_lock
++EXPORT_SYMBOL vmlinux 0x66324110	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0x663a65ba	soft_cursor
++EXPORT_SYMBOL vmlinux 0x663f88cb	file_remove_privs
++EXPORT_SYMBOL vmlinux 0x6657c39d	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0x665f03ec	sget
++EXPORT_SYMBOL vmlinux 0x66682eea	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x666d6d61	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0x6676e9d7	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0x6680b512	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0x6696ca5a	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x66b51445	vga_con
++EXPORT_SYMBOL vmlinux 0x66bf7b85	__netif_schedule
++EXPORT_SYMBOL vmlinux 0x66cbf14b	pmac_xpram_write
++EXPORT_SYMBOL vmlinux 0x66cd16a0	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x66cd325d	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x66d25684	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0x6702b470	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0x6702de31	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x670439b8	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x67062d54	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0x672882b2	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0x673f815e	agp_bridges
++EXPORT_SYMBOL vmlinux 0x6765ef34	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x677e6bf8	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0x679e00aa	of_scan_pci_bridge
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x681105e1	follow_down
++EXPORT_SYMBOL vmlinux 0x6822cdb7	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0x68327182	mntput
++EXPORT_SYMBOL vmlinux 0x685c374d	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x685ee8b0	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x68609857	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x6865e12e	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0x68682cc8	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x6884439e	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x688581c1	inc_nlink
++EXPORT_SYMBOL vmlinux 0x689847f0	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x689ee73f	bio_put
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68d83163	of_io_request_and_map
++EXPORT_SYMBOL vmlinux 0x68f31c9d	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0x69066746	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x690b53a2	da903x_query_status
++EXPORT_SYMBOL vmlinux 0x691338d0	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x69227f88	set_wb_congested
++EXPORT_SYMBOL vmlinux 0x69418333	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0x6967ca64	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x69a0a752	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0x69a0ca7d	iowrite16be
++EXPORT_SYMBOL vmlinux 0x69a942a5	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69b5f837	uart_resume_port
++EXPORT_SYMBOL vmlinux 0x69c850dc	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x69d7e5b8	__debugger_ipi
++EXPORT_SYMBOL vmlinux 0x69eb859b	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a0b2bba	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0x6a157bf5	user_revoke
++EXPORT_SYMBOL vmlinux 0x6a3e35cd	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x6a58eefd	tty_write_room
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a62fd6d	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0x6a6cbe76	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a898d56	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0x6a937a58	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x6aa18e72	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x6ab2f3db	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0x6ac09ac9	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6acb973d	iowrite32be
++EXPORT_SYMBOL vmlinux 0x6acbaef7	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0x6ad3109f	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0x6ae2ac1c	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0x6aedbdc6	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6af5baef	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0x6af932d9	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b23bab0	of_get_child_by_name
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b31d741	generic_perform_write
++EXPORT_SYMBOL vmlinux 0x6b4c4f46	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0x6b66c889	fence_free
++EXPORT_SYMBOL vmlinux 0x6bb0c7a7	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6be6f969	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0x6bf266a4	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0x6c0450df	cdev_add
++EXPORT_SYMBOL vmlinux 0x6c097a27	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c1ce5ce	strcspn
++EXPORT_SYMBOL vmlinux 0x6c36cc0c	__sock_create
++EXPORT_SYMBOL vmlinux 0x6c40b600	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x6c40c77a	sk_net_capable
++EXPORT_SYMBOL vmlinux 0x6c4c2f89	param_ops_byte
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c545652	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c8750d0	sock_create_lite
++EXPORT_SYMBOL vmlinux 0x6c9191df	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x6ca1d1a4	atomic64_read
++EXPORT_SYMBOL vmlinux 0x6ca669f8	registered_fb
++EXPORT_SYMBOL vmlinux 0x6cb37127	flex_array_clear
++EXPORT_SYMBOL vmlinux 0x6cc0b3a1	vfs_writef
++EXPORT_SYMBOL vmlinux 0x6cdc5c6b	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6cf7553d	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d148356	sk_dst_check
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d30e044	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x6d4e9532	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x6d65855d	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0x6d740223	flex_array_put
++EXPORT_SYMBOL vmlinux 0x6d9db2c0	dst_release
++EXPORT_SYMBOL vmlinux 0x6da928f4	_insw_ns
++EXPORT_SYMBOL vmlinux 0x6ddf1dcf	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x6de53e11	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6df9d740	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x6e25c667	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x6e3513a3	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x6e3b819f	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0x6e4b5b52	param_set_long
++EXPORT_SYMBOL vmlinux 0x6e6514ed	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e7e04f2	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0x6e80409a	d_move
++EXPORT_SYMBOL vmlinux 0x6e858117	serio_close
++EXPORT_SYMBOL vmlinux 0x6e87517e	netdev_warn
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6eafb104	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0x6eb0032c	kunmap_high
++EXPORT_SYMBOL vmlinux 0x6eb74dff	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x6eb8486c	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x6ed2ebe4	i2c_use_client
++EXPORT_SYMBOL vmlinux 0x6ed90314	blk_register_region
++EXPORT_SYMBOL vmlinux 0x6ef638f1	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x6efe2ff3	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x6f14f3b5	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f2741e2	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0x6f2ed729	__vfs_read
++EXPORT_SYMBOL vmlinux 0x6f360f22	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x6f36fb1b	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0x6f4380b1	mapping_tagged
++EXPORT_SYMBOL vmlinux 0x6f4f59c8	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x6f658bbd	freeze_super
++EXPORT_SYMBOL vmlinux 0x6f78d7ee	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x6f88ad81	security_file_permission
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6f8a0387	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x6f8c9923	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0x6f8f6101	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0x6fa4aa88	nvm_register
++EXPORT_SYMBOL vmlinux 0x6fb245a5	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6fcdda40	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0x6ff5151c	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0x6ff70912	macio_dev_get
++EXPORT_SYMBOL vmlinux 0x6ff8f6aa	get_task_io_context
++EXPORT_SYMBOL vmlinux 0x70336048	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x7051581b	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7054a3e4	request_dma
++EXPORT_SYMBOL vmlinux 0x7062b4cd	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x70a33285	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0x70b83713	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0x70d888b7	__debugger_fault_handler
++EXPORT_SYMBOL vmlinux 0x70f86c70	pmu_queue_request
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x7124ccbc	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x712e4e1c	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x712ed37b	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x7138b901	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0x7151eec7	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x71590c1a	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x7169be68	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x71742a31	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0x717f828d	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0x719f225b	stop_tty
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71afdf66	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0x71b7f2a0	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0x71c5fc3e	kern_unmount
++EXPORT_SYMBOL vmlinux 0x71c90087	memcmp
++EXPORT_SYMBOL vmlinux 0x71d438e7	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x71f65175	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x722a0837	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0x723c1d41	padata_stop
++EXPORT_SYMBOL vmlinux 0x729df2fe	d_genocide
++EXPORT_SYMBOL vmlinux 0x72a0e6f2	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x72a26c38	inet6_bind
++EXPORT_SYMBOL vmlinux 0x72a6e222	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0x72b243d4	free_dma
++EXPORT_SYMBOL vmlinux 0x72b31661	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0x72b69fa0	file_open_root
++EXPORT_SYMBOL vmlinux 0x72b6fa56	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0x72d37379	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x72d58de9	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x72e74544	save_mount_options
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x72ecd066	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0x72ee1bf0	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0x72f6759f	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x731a01e6	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0x732c7f3e	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x732d454c	follow_up
++EXPORT_SYMBOL vmlinux 0x732f00d4	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x73494012	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x7354202b	iget5_locked
++EXPORT_SYMBOL vmlinux 0x735d8503	add_wait_queue
++EXPORT_SYMBOL vmlinux 0x73710a3e	dqstats
++EXPORT_SYMBOL vmlinux 0x73979de6	atomic64_or
++EXPORT_SYMBOL vmlinux 0x739d065e	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0x73a9db71	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0x73c93591	dev_emerg
++EXPORT_SYMBOL vmlinux 0x73e20c1c	strlcpy
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x741369b2	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0x74141f4d	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0x741c65f5	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0x741cb170	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0x745dce24	__vfs_write
++EXPORT_SYMBOL vmlinux 0x74689bc5	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x7481924e	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x749fdb0c	of_get_pci_address
++EXPORT_SYMBOL vmlinux 0x74b725ef	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0x74b9bc57	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74c5f1c8	input_event
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74e7705f	of_count_phandle_with_args
++EXPORT_SYMBOL vmlinux 0x74f3a074	init_net
++EXPORT_SYMBOL vmlinux 0x74fe8730	sys_ctrler
++EXPORT_SYMBOL vmlinux 0x7505bdef	memchr_inv
++EXPORT_SYMBOL vmlinux 0x751a5022	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x75234a06	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x75271b2b	proc_remove
++EXPORT_SYMBOL vmlinux 0x7538b132	agp_off
++EXPORT_SYMBOL vmlinux 0x753a3c77	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0x754c0fc7	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0x755ba752	devm_request_resource
++EXPORT_SYMBOL vmlinux 0x75678edb	read_code
++EXPORT_SYMBOL vmlinux 0x756a6c44	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0x756dd160	start_thread
++EXPORT_SYMBOL vmlinux 0x756fb286	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x7593d385	div64_s64
++EXPORT_SYMBOL vmlinux 0x75994700	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0x75a4a715	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x75bae4f7	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75da1b95	agp_generic_insert_memory
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x7616a2fa	dev_open
++EXPORT_SYMBOL vmlinux 0x76252c78	phy_resume
++EXPORT_SYMBOL vmlinux 0x76294b68	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0x763b6bef	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x7662f990	proc_create_data
++EXPORT_SYMBOL vmlinux 0x7667d548	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0x767e0f43	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0x76ae215a	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x76c2bb29	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0x76c2f5de	note_scsi_host
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76d9bf11	crc32_be
++EXPORT_SYMBOL vmlinux 0x76e0f362	tso_start
++EXPORT_SYMBOL vmlinux 0x76f6c5ef	kmalloc_order
++EXPORT_SYMBOL vmlinux 0x76fb4b83	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0x770de7d8	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x7710c21e	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0x7713d4ee	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0x7738e8a1	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0x774ed568	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x775088e8	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0x77535de1	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0x775a130e	__sg_free_table
++EXPORT_SYMBOL vmlinux 0x778a1f63	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77ba7fba	bioset_create
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77cde4db	dquot_operations
++EXPORT_SYMBOL vmlinux 0x77e8f456	param_set_short
++EXPORT_SYMBOL vmlinux 0x781e7408	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0x782567ec	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x782c288f	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x783b977a	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0x786e3024	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x787f15a2	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x788fe103	iomem_resource
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78a0a74d	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0x78b21663	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0x78ca7328	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x790a1db4	pci_pme_active
++EXPORT_SYMBOL vmlinux 0x79277391	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0x7931892a	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x7940e88f	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x79427ff4	elv_rb_find
++EXPORT_SYMBOL vmlinux 0x7943044b	get_io_context
++EXPORT_SYMBOL vmlinux 0x7945749e	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0x795a22a3	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x79848b3c	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x798a9bcc	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x79934b02	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0x799585c5	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79cdc2b4	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0x79f30efc	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x79f6ac37	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0x79fd4fa3	install_exec_creds
++EXPORT_SYMBOL vmlinux 0x79fe4cbb	write_inode_now
++EXPORT_SYMBOL vmlinux 0x7a192833	phy_device_free
++EXPORT_SYMBOL vmlinux 0x7a2add7d	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a5659f1	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0x7a70e3b2	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0x7a78cc12	key_revoke
++EXPORT_SYMBOL vmlinux 0x7a89b88a	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x7a9404d5	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0x7a95e5ae	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7a9b2fa7	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7aaf929e	pci_restore_state
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7ad95e55	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x7afa89fc	vsnprintf
++EXPORT_SYMBOL vmlinux 0x7b100894	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b1ade38	lz4_decompress
++EXPORT_SYMBOL vmlinux 0x7b283ce3	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0x7b365042	dev_close
++EXPORT_SYMBOL vmlinux 0x7b3f4a4d	input_register_handler
++EXPORT_SYMBOL vmlinux 0x7b5c8440	vm_munmap
++EXPORT_SYMBOL vmlinux 0x7b867914	PDE_DATA
++EXPORT_SYMBOL vmlinux 0x7b94ea0c	netdev_alert
++EXPORT_SYMBOL vmlinux 0x7be3f865	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x7be4827c	pci_dram_offset
++EXPORT_SYMBOL vmlinux 0x7be8fb92	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0x7bfd470f	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x7c003aef	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c35ace1	mmc_add_host
++EXPORT_SYMBOL vmlinux 0x7c37ba29	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c5d35c8	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0x7c62cd5e	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0x7c8d311e	seq_path
++EXPORT_SYMBOL vmlinux 0x7c9291d1	csum_partial_copy_generic
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7c99b913	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0x7cac28c0	tcp_prot
++EXPORT_SYMBOL vmlinux 0x7cad6a2c	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0x7caed410	single_open_size
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7d0a7a80	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d192c49	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x7d206994	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x7d2ddd5a	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0x7d525532	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x7d546437	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0x7d628ab8	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x7d696971	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0x7d6b0369	of_phy_attach
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d80f508	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0x7d8de46d	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x7d8ee9bd	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0x7d9103d7	fb_pan_display
++EXPORT_SYMBOL vmlinux 0x7d94a1ba	migrate_page
++EXPORT_SYMBOL vmlinux 0x7d968392	pci_request_regions
++EXPORT_SYMBOL vmlinux 0x7d97e46d	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x7d97eb9a	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0x7d9b23a2	rwsem_wake
++EXPORT_SYMBOL vmlinux 0x7dc97879	rtas_get_error_log_max
++EXPORT_SYMBOL vmlinux 0x7dcb0931	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x7def627b	macio_register_driver
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7df8a422	get_agp_version
++EXPORT_SYMBOL vmlinux 0x7e0105ad	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0x7e35084e	f_setown
++EXPORT_SYMBOL vmlinux 0x7e3d7da0	param_ops_bint
++EXPORT_SYMBOL vmlinux 0x7e3fb211	of_get_named_gpio_flags
++EXPORT_SYMBOL vmlinux 0x7e76a6e7	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x7e793e9f	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0x7e8199d0	fd_install
++EXPORT_SYMBOL vmlinux 0x7e87227e	slhc_compress
++EXPORT_SYMBOL vmlinux 0x7ea44488	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x7eb32de2	dev_uc_init
++EXPORT_SYMBOL vmlinux 0x7ebb1318	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x7edb3bb5	vme_bus_num
++EXPORT_SYMBOL vmlinux 0x7ee3cb98	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7ee73c0c	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0x7eeec200	of_graph_get_port_by_id
++EXPORT_SYMBOL vmlinux 0x7efc1634	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0x7efd19f9	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f06396f	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0x7f071605	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x7f167f40	would_dump
++EXPORT_SYMBOL vmlinux 0x7f1d812c	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f4a640c	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x7f4daf0c	agp_create_memory
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f656042	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x7f8b27c0	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x7f9dfd32	of_get_address
++EXPORT_SYMBOL vmlinux 0x7fc7244a	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0x7fde2edb	vme_master_read
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fe7b516	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0x7fed7a20	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0x801103a3	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x8060f13f	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0x807dacf9	bio_init
++EXPORT_SYMBOL vmlinux 0x80841606	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0x8085a0f8	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x808959ad	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0x80aa096c	phy_find_first
++EXPORT_SYMBOL vmlinux 0x80ac83c0	dev_activate
++EXPORT_SYMBOL vmlinux 0x80b19b63	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x80c796e7	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0x80c88af4	tcp_req_err
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80cabcd3	vm_event_states
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80fc7950	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x811e7d52	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0x81278559	input_flush_device
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x815ce4cf	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x81819480	cpu_sibling_map
++EXPORT_SYMBOL vmlinux 0x81a07f4e	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x81beca00	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x81c0a84f	rtas_set_indicator
++EXPORT_SYMBOL vmlinux 0x81c62495	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0x81c95229	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81f1069f	of_find_matching_node_and_match
++EXPORT_SYMBOL vmlinux 0x81f2c3df	vfs_rename
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x82281b81	simple_dname
++EXPORT_SYMBOL vmlinux 0x822c5a8c	fence_add_callback
++EXPORT_SYMBOL vmlinux 0x822f411f	drop_super
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x827f198b	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x828344b1	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x829069c0	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82addba0	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x82b2122c	send_sig
++EXPORT_SYMBOL vmlinux 0x82c16d59	lock_fb_info
++EXPORT_SYMBOL vmlinux 0x82c18c24	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0x82cd540a	atomic64_and
++EXPORT_SYMBOL vmlinux 0x82d6f1e8	kern_path
++EXPORT_SYMBOL vmlinux 0x82d84cb4	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0x82e5a238	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x82eedca3	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x82fa3369	eth_header_cache
++EXPORT_SYMBOL vmlinux 0x830b57b8	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0x831a3fe0	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x832fa791	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x833ceb8e	filp_open
++EXPORT_SYMBOL vmlinux 0x836fa556	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0x8372cd2f	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x838a7b83	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x838b6957	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0x8393aa34	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x839e0a0b	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x83a3369a	param_get_uint
++EXPORT_SYMBOL vmlinux 0x83a9822b	kernel_connect
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83be68b9	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0x83c4d950	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83d05b6c	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x83e45be0	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x8418d41b	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0x841d6e04	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0x841db4ef	down_write
++EXPORT_SYMBOL vmlinux 0x84369b78	give_up_console
++EXPORT_SYMBOL vmlinux 0x844404cf	ISA_DMA_THRESHOLD
++EXPORT_SYMBOL vmlinux 0x8450907a	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0x845b362b	seq_release_private
++EXPORT_SYMBOL vmlinux 0x84a69fdc	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x84b183ae	strncmp
++EXPORT_SYMBOL vmlinux 0x84bd69bf	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x84c11f91	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0x84c6c1c0	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x84ed7af5	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x84fff4a9	poll_freewait
++EXPORT_SYMBOL vmlinux 0x8505f689	blk_peek_request
++EXPORT_SYMBOL vmlinux 0x853c31e7	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0x8541bccc	intercept_table
++EXPORT_SYMBOL vmlinux 0x854e1c0b	sg_nents
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x8589dd8f	param_ops_long
++EXPORT_SYMBOL vmlinux 0x859e78f4	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0x85a7b8a2	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85ebf80e	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x85fa7e1b	is_bad_inode
++EXPORT_SYMBOL vmlinux 0x86087f2d	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x86182550	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0x861e17ae	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0x862ee4d0	dma_set_mask
++EXPORT_SYMBOL vmlinux 0x863ed438	__bforget
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x8670d5ef	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0x867984cd	iget_locked
++EXPORT_SYMBOL vmlinux 0x8689b35d	genphy_config_init
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86a4889a	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0x86bb3c53	register_quota_format
++EXPORT_SYMBOL vmlinux 0x86bc22d8	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x86c3063b	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0x86d150c0	dm_put_device
++EXPORT_SYMBOL vmlinux 0x86db1cbb	rtas_flash_term_hook
++EXPORT_SYMBOL vmlinux 0x86f9da1d	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x870094d3	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x87339f4e	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x873ce421	elv_rb_del
++EXPORT_SYMBOL vmlinux 0x87704747	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x87862af2	key_link
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x87b7515c	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0x87ba6f03	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x87bb50d8	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0x87d20695	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x87d67608	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0x87dcedf7	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0x881c8f91	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x8836f2a9	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0x884607a3	init_task
++EXPORT_SYMBOL vmlinux 0x885392b6	misc_register
++EXPORT_SYMBOL vmlinux 0x88580065	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x886cb0a4	macio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x887d0a4d	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0x88a7b8e8	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x88b6dcd8	of_phy_connect
++EXPORT_SYMBOL vmlinux 0x88b9f1e6	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0x88bbb6cf	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x88c0ed29	msi_bitmap_free_hwirqs
++EXPORT_SYMBOL vmlinux 0x88cb2dda	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0x891fbb10	mempool_destroy
++EXPORT_SYMBOL vmlinux 0x8936ea13	set_disk_ro
++EXPORT_SYMBOL vmlinux 0x89453a5c	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x895aed43	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0x896486f0	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x89797060	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x89960165	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x89993c32	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x89b3107b	isa_mem_base
++EXPORT_SYMBOL vmlinux 0x89b5dd6d	no_llseek
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89ea35f7	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a23d7be	contig_page_data
++EXPORT_SYMBOL vmlinux 0x8a243274	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a5c94eb	key_invalidate
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a84249d	alloc_file
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8aac11f1	kobject_add
++EXPORT_SYMBOL vmlinux 0x8ab4079e	atomic64_add
++EXPORT_SYMBOL vmlinux 0x8abd366c	macio_dev_put
++EXPORT_SYMBOL vmlinux 0x8abe422a	ether_setup
++EXPORT_SYMBOL vmlinux 0x8ad840f3	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0x8b16f4ee	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0x8b1b0781	start_tty
++EXPORT_SYMBOL vmlinux 0x8b32e5ca	simple_lookup
++EXPORT_SYMBOL vmlinux 0x8b36dd94	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b612577	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b8f3a4f	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0x8bbbfeae	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0x8bd611cd	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x8bd6498a	phy_stop
++EXPORT_SYMBOL vmlinux 0x8bd6ae23	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0x8bfda102	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x8c059238	fb_get_mode
++EXPORT_SYMBOL vmlinux 0x8c09c5ed	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0x8c0bce2d	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0x8c0c6b44	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0x8c183cbe	iowrite16
++EXPORT_SYMBOL vmlinux 0x8c5763b6	unregister_netdev
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c63bb84	file_ns_capable
++EXPORT_SYMBOL vmlinux 0x8c64dfd6	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0x8c72cb15	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0x8c8a82fc	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0x8ca7347f	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0x8cb83526	netdev_notice
++EXPORT_SYMBOL vmlinux 0x8cbc7b9e	block_write_end
++EXPORT_SYMBOL vmlinux 0x8cc79cab	iowrite16_rep
++EXPORT_SYMBOL vmlinux 0x8cc8ceec	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0x8cdbc869	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0x8d015dd4	__bswapdi2
++EXPORT_SYMBOL vmlinux 0x8d06dc0e	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0x8d0e93b9	param_ops_int
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d5a1626	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0x8d6b2ce1	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x8d72495b	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d9f1762	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0x8dafff7b	dump_emit
++EXPORT_SYMBOL vmlinux 0x8dcdfbd5	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0x8ddfb948	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0x8de0b5ac	mempool_create
++EXPORT_SYMBOL vmlinux 0x8df5da63	memstart_addr
++EXPORT_SYMBOL vmlinux 0x8dffafa6	__kernel_write
++EXPORT_SYMBOL vmlinux 0x8e235e7a	padata_alloc
++EXPORT_SYMBOL vmlinux 0x8e38595b	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0x8e39c4c8	dcb_getapp
++EXPORT_SYMBOL vmlinux 0x8e4d3c1f	xattr_full_name
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e7d4fa1	simple_getattr
++EXPORT_SYMBOL vmlinux 0x8e96b84d	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0x8eb03965	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x8ec04552	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0x8ef224de	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0x8f1fada1	mmc_erase
++EXPORT_SYMBOL vmlinux 0x8f469097	phys_mem_access_prot
++EXPORT_SYMBOL vmlinux 0x8f6fec84	fsl_lbc_ctrl_dev
++EXPORT_SYMBOL vmlinux 0x8f728efb	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0x8f85f835	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x8fb41c96	init_buffer
++EXPORT_SYMBOL vmlinux 0x8fb54e6c	generic_writepages
++EXPORT_SYMBOL vmlinux 0x8fbf37e0	profile_pc
++EXPORT_SYMBOL vmlinux 0x8fc15bf6	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0x8fc3809a	scsi_device_get
++EXPORT_SYMBOL vmlinux 0x8fc3ed1a	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x8ff98a9f	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x8ffdb3b8	crc16
++EXPORT_SYMBOL vmlinux 0x901905fa	ps2_command
++EXPORT_SYMBOL vmlinux 0x9022ee45	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x90263d21	have_submounts
++EXPORT_SYMBOL vmlinux 0x90297f19	proc_symlink
++EXPORT_SYMBOL vmlinux 0x90431db7	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x9085904e	skb_put
++EXPORT_SYMBOL vmlinux 0x909724bb	vfs_readf
++EXPORT_SYMBOL vmlinux 0x90a6d497	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x90b83c14	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0x90c5e819	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x90e42c12	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0x90f1b023	msi_bitmap_alloc_hwirqs
++EXPORT_SYMBOL vmlinux 0x90fd5dff	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0x910b568c	tty_register_device
++EXPORT_SYMBOL vmlinux 0x912557ce	rtas_busy_delay
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x9154a5bc	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0x915e1208	tb_ticks_per_usec
++EXPORT_SYMBOL vmlinux 0x91621d6a	allocate_resource
++EXPORT_SYMBOL vmlinux 0x9168c033	rtas_get_sensor
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x91717c38	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x9180baf7	d_path
++EXPORT_SYMBOL vmlinux 0x918400ac	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0x9187e245	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x918929ce	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x919d1163	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x919de20a	security_path_link
++EXPORT_SYMBOL vmlinux 0x91ad6284	con_is_bound
++EXPORT_SYMBOL vmlinux 0x91ba6855	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0x91d3a852	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0x91db384b	tty_free_termios
++EXPORT_SYMBOL vmlinux 0x91dd1e42	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0x91eccdba	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x91f5ddd0	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x921932d3	udp_set_csum
++EXPORT_SYMBOL vmlinux 0x9229ec52	dquot_disable
++EXPORT_SYMBOL vmlinux 0x9231eba9	agp_find_bridge
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x923f14b8	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0x92462af3	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0x92946581	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0x92a5c398	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92af9ae1	of_find_device_by_node
++EXPORT_SYMBOL vmlinux 0x92db856b	agp_bridge
++EXPORT_SYMBOL vmlinux 0x92e0f69b	netdev_info
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x9309de94	cuda_request
++EXPORT_SYMBOL vmlinux 0x931a2c65	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0x93215e1d	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0x9330cb9f	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x93383391	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x93658bbd	icmp_send
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x9380b1c1	bio_reset
++EXPORT_SYMBOL vmlinux 0x9390b91d	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x939d6769	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0x93a5c1ad	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0x93a5f69d	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0x93b0e455	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93dec66e	iov_iter_init
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x940f9cf6	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x94139224	of_find_node_by_name
++EXPORT_SYMBOL vmlinux 0x94579a51	skb_push
++EXPORT_SYMBOL vmlinux 0x9470cfee	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x94885c34	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0x948eb89f	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0x9491f552	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94ae23d7	of_cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0x94b2590f	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0x94b406c5	make_kprojid
++EXPORT_SYMBOL vmlinux 0x94b93a82	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x94cbd061	dql_reset
++EXPORT_SYMBOL vmlinux 0x94d9e6e4	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x94eea794	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x94eefb06	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x94f1bd15	sock_init_data
++EXPORT_SYMBOL vmlinux 0x94f3baa8	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x950f4d97	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x9514151a	_mcount
++EXPORT_SYMBOL vmlinux 0x9524b0ae	_outsb
++EXPORT_SYMBOL vmlinux 0x9528dc89	seq_open
++EXPORT_SYMBOL vmlinux 0x953f2f1f	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0x953fac70	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x954634ab	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0x9548624c	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0x9556ed82	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0x9583587a	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0x9595b96b	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0x959c1e27	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0x95a7c53a	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0x95a88dab	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x95aab7aa	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x95ac10bb	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x95b733b1	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0x95ce6cf2	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0x95cf7060	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0x95eb488f	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0x95f41c5c	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x960dfaf5	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0x960fc1c8	console_start
++EXPORT_SYMBOL vmlinux 0x96142a68	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0x961eacdc	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0x963274b5	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x96354053	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0x96569b35	new_inode
++EXPORT_SYMBOL vmlinux 0x96573b80	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x9658cc83	neigh_table_init
++EXPORT_SYMBOL vmlinux 0x9661d2b7	netlink_set_err
++EXPORT_SYMBOL vmlinux 0x966aeb81	phy_connect
++EXPORT_SYMBOL vmlinux 0x967e2121	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x967e6fb4	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0x968247d8	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0x96898769	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x969b3af8	netdev_crit
++EXPORT_SYMBOL vmlinux 0x96ac22ac	inode_init_always
++EXPORT_SYMBOL vmlinux 0x96bc1dd7	tcp_filter
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96d76ea3	__scm_send
++EXPORT_SYMBOL vmlinux 0x96da8a98	inet_frags_init
++EXPORT_SYMBOL vmlinux 0x96dbcca2	ioremap_prot
++EXPORT_SYMBOL vmlinux 0x96dce98c	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0x96eb5ea7	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0x971f8f74	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0x97255bdf	strlen
++EXPORT_SYMBOL vmlinux 0x972ae0aa	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0x97323ed4	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0x9744ba69	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0x9748927f	_outsw_ns
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x976074f8	of_find_node_by_phandle
++EXPORT_SYMBOL vmlinux 0x9764ec5b	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0x9768d776	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0x9769790b	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x97795b45	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0x9779e291	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0x977ed62f	path_get
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x979c3b2a	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0x97b44b0e	__skb_checksum
++EXPORT_SYMBOL vmlinux 0x97d77be6	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0x97dfcafb	force_sig
++EXPORT_SYMBOL vmlinux 0x97e41374	agp_backend_release
++EXPORT_SYMBOL vmlinux 0x97eb65ab	of_get_min_tck
++EXPORT_SYMBOL vmlinux 0x97ed45f6	kthread_bind
++EXPORT_SYMBOL vmlinux 0x9814c7a5	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x984110cc	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0x9848f91c	pid_task
++EXPORT_SYMBOL vmlinux 0x984ae618	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0x984d1efe	bioset_free
++EXPORT_SYMBOL vmlinux 0x9864fd8e	arp_send
++EXPORT_SYMBOL vmlinux 0x986631aa	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x986c5b3e	nla_append
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x9890e870	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x98933554	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0x98a72cd6	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x98d64c61	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x98e0a8fe	consume_skb
++EXPORT_SYMBOL vmlinux 0x98e68eca	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0x98f7b5b4	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x98fe7882	DMA_MODE_READ
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x993aaf7d	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x993e303a	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x995b86b7	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0x996d770f	truncate_setsize
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99a02dcb	pci_iomap
++EXPORT_SYMBOL vmlinux 0x99afe916	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0x99b91fe7	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x99bb8806	memmove
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99f25d1a	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0x9a0216d7	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x9a106b38	unregister_nls
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a202388	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0x9a39c114	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x9a6e9bf3	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x9a82c1c7	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0x9a99ba4a	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x9a9f7e1f	get_cached_acl
++EXPORT_SYMBOL vmlinux 0x9aadd8d5	of_device_alloc
++EXPORT_SYMBOL vmlinux 0x9ab2863f	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x9ae5f1de	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9af2198a	agp_generic_mask_memory
++EXPORT_SYMBOL vmlinux 0x9b0d3d16	key_validate
++EXPORT_SYMBOL vmlinux 0x9b0fc500	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0x9b2a2500	generic_permission
++EXPORT_SYMBOL vmlinux 0x9b2f9637	pci_request_region
++EXPORT_SYMBOL vmlinux 0x9b31725b	flush_dcache_icache_page
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b39936d	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0x9b3aa286	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0x9b56a493	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0x9b5d6ac7	of_dev_get
++EXPORT_SYMBOL vmlinux 0x9b6a7fd9	scsi_unregister
++EXPORT_SYMBOL vmlinux 0x9b6d8d6f	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x9b6eb137	ksize
++EXPORT_SYMBOL vmlinux 0x9b77d73c	register_framebuffer
++EXPORT_SYMBOL vmlinux 0x9b95936b	seq_file_path
++EXPORT_SYMBOL vmlinux 0x9b970d15	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba39a5a	of_phy_is_fixed_link
++EXPORT_SYMBOL vmlinux 0x9ba6d903	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9ba92079	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0x9bce482f	__release_region
++EXPORT_SYMBOL vmlinux 0x9bd25a41	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0x9bda3ae5	find_lock_entry
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9c1c0bf7	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0x9c49fcd5	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0x9c6dcccb	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x9c6f70da	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x9c75657e	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x9c914052	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0x9ca409c1	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x9ca50e29	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cc403eb	led_update_brightness
++EXPORT_SYMBOL vmlinux 0x9ccde1a2	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0x9ce1cb94	d_drop
++EXPORT_SYMBOL vmlinux 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL vmlinux 0x9cff312f	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d14983a	ppc_enable_pmcs
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d49c3e9	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0x9d518dfc	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x9d573948	kill_fasync
++EXPORT_SYMBOL vmlinux 0x9d58869a	genphy_suspend
++EXPORT_SYMBOL vmlinux 0x9d59679c	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0x9d5db732	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0x9d651f22	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0x9d669763	memcpy
++EXPORT_SYMBOL vmlinux 0x9d687763	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0x9d6a54c2	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0x9d7ce8dd	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x9d8682c0	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x9d8e0fb9	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x9d98b721	blk_start_request
++EXPORT_SYMBOL vmlinux 0x9dbc0ced	arp_xmit
++EXPORT_SYMBOL vmlinux 0x9dbe5700	tty_check_change
++EXPORT_SYMBOL vmlinux 0x9dc9ac4e	set_security_override
++EXPORT_SYMBOL vmlinux 0x9de64473	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x9decb9b8	block_write_full_page
++EXPORT_SYMBOL vmlinux 0x9df272a8	inet6_protos
++EXPORT_SYMBOL vmlinux 0x9dfe7307	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9e048cf0	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e0de620	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x9e116995	dump_align
++EXPORT_SYMBOL vmlinux 0x9e1cfc90	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x9e372fa3	may_umount
++EXPORT_SYMBOL vmlinux 0x9e3d7e48	d_instantiate
++EXPORT_SYMBOL vmlinux 0x9e4cd3a3	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e672ff6	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x9e68c3b7	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0x9e702a28	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e858422	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x9e89761d	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0x9e97375d	rtas_busy_delay_time
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9ea2eba7	kmap_to_page
++EXPORT_SYMBOL vmlinux 0x9ec38cd7	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0x9ec3e35f	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x9ee78840	udplite_prot
++EXPORT_SYMBOL vmlinux 0x9eef37fc	mpage_readpage
++EXPORT_SYMBOL vmlinux 0x9f040357	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0x9f04f1b6	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x9f06bcf1	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0x9f2ebebd	fb_class
++EXPORT_SYMBOL vmlinux 0x9f464929	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f49c2b8	tcp_poll
++EXPORT_SYMBOL vmlinux 0x9f5df6a7	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x9f680326	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x9f911629	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9fc9dd84	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9feb84cd	macio_request_resources
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0x9fff9c92	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0xa000b606	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0xa011936d	file_path
++EXPORT_SYMBOL vmlinux 0xa027c505	bio_add_page
++EXPORT_SYMBOL vmlinux 0xa030eb2a	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xa0402767	register_qdisc
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa05affa9	unlock_buffer
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa06df9e1	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0xa075ae69	free_buffer_head
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa0adba4a	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0ed753b	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0xa0f6c000	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa11226c7	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0xa11f1aa1	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa1320b98	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0xa13c3470	clear_user_page
++EXPORT_SYMBOL vmlinux 0xa13ca95f	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0xa13e4a24	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa177aa28	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xa181bd4d	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0xa1ad0889	__lock_buffer
++EXPORT_SYMBOL vmlinux 0xa1b6eb80	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1bf505d	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1c99385	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa1f8fe75	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa223a9d5	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0xa227b317	powerpc_debugfs_root
++EXPORT_SYMBOL vmlinux 0xa22d8819	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0xa24adb8c	dentry_unhash
++EXPORT_SYMBOL vmlinux 0xa26aeab4	dquot_alloc
++EXPORT_SYMBOL vmlinux 0xa26bb789	lease_modify
++EXPORT_SYMBOL vmlinux 0xa26be9a6	flush_tlb_range
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa28e98ef	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0xa28fa8a0	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0xa293763a	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0xa29f1a85	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0xa29f9c3c	skb_find_text
++EXPORT_SYMBOL vmlinux 0xa2a537bc	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0xa2b18b8b	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0xa2bbed37	crash_shutdown_register
++EXPORT_SYMBOL vmlinux 0xa2bfbc22	__block_write_begin
++EXPORT_SYMBOL vmlinux 0xa2ccaa3f	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0xa2fafe3f	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0xa2fdbcbe	fence_default_wait
++EXPORT_SYMBOL vmlinux 0xa303d1ff	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa31ecf11	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0xa3278175	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0xa33e5fd1	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0xa361fd0d	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0xa3638ab5	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0xa373e68e	request_key
++EXPORT_SYMBOL vmlinux 0xa38e691a	ioremap_bot
++EXPORT_SYMBOL vmlinux 0xa39b4cf2	udelay
++EXPORT_SYMBOL vmlinux 0xa3abc422	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xa3ae90af	bio_advance
++EXPORT_SYMBOL vmlinux 0xa3aed484	component_match_add
++EXPORT_SYMBOL vmlinux 0xa3b3db42	kill_pid
++EXPORT_SYMBOL vmlinux 0xa3e75545	flush_tlb_kernel_range
++EXPORT_SYMBOL vmlinux 0xa40c165e	__put_cred
++EXPORT_SYMBOL vmlinux 0xa4266c4e	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0xa42c66da	block_truncate_page
++EXPORT_SYMBOL vmlinux 0xa43b1297	vscnprintf
++EXPORT_SYMBOL vmlinux 0xa4481c04	adb_client_list
++EXPORT_SYMBOL vmlinux 0xa4490864	tcf_register_action
++EXPORT_SYMBOL vmlinux 0xa44ab337	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0xa4604fa9	tty_port_init
++EXPORT_SYMBOL vmlinux 0xa46408d0	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa48e4adf	lock_rename
++EXPORT_SYMBOL vmlinux 0xa4938733	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0xa49d5bbf	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0xa4a69371	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0xa4a94d26	find_next_bit_le
++EXPORT_SYMBOL vmlinux 0xa4b94fea	iowrite8_rep
++EXPORT_SYMBOL vmlinux 0xa4bdedf5	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0xa4cc790e	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0xa4d21ce9	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0xa4d4f0e6	global_cache_flush
++EXPORT_SYMBOL vmlinux 0xa4d74f3e	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0xa4df11b9	switch_mmu_context
++EXPORT_SYMBOL vmlinux 0xa4ee8543	pmac_register_agp_pm
++EXPORT_SYMBOL vmlinux 0xa4f136c4	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0xa4fe48d9	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0xa5091af4	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0xa5292287	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0xa533f4db	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xa537929d	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0xa548b5df	netif_skb_features
++EXPORT_SYMBOL vmlinux 0xa54b476b	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa55f3f6c	kill_litter_super
++EXPORT_SYMBOL vmlinux 0xa569a279	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0xa56b8ab2	flex_array_free
++EXPORT_SYMBOL vmlinux 0xa57df037	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0xa57e9c9c	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0xa587965a	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa5a633b9	sg_last
++EXPORT_SYMBOL vmlinux 0xa5aa70a8	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0xa5bc2d24	security_path_rename
++EXPORT_SYMBOL vmlinux 0xa5c490ca	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0xa5cef8ad	release_resource
++EXPORT_SYMBOL vmlinux 0xa5d010c5	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0xa5f6c40f	fget
++EXPORT_SYMBOL vmlinux 0xa5f73abe	filemap_flush
++EXPORT_SYMBOL vmlinux 0xa6071b59	param_set_charp
++EXPORT_SYMBOL vmlinux 0xa649843c	mutex_lock
++EXPORT_SYMBOL vmlinux 0xa652c4ef	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0xa65972b8	_memcpy_toio
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa6970398	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa705ce04	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0xa71336ff	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0xa720678c	lg_global_lock
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa74323e0	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0xa744c57b	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xa74f4e9b	ida_simple_get
++EXPORT_SYMBOL vmlinux 0xa75a9f6c	__sb_start_write
++EXPORT_SYMBOL vmlinux 0xa76aeed2	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0xa771d3e7	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xa78d9eb7	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0xa7cd526d	ns_capable
++EXPORT_SYMBOL vmlinux 0xa7e7ed59	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0xa7ef783a	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0xa7fa43f1	kill_pgrp
++EXPORT_SYMBOL vmlinux 0xa7fb0dc5	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0xa7ff311c	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0xa8062ef1	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0xa8152a6e	vfs_getattr
++EXPORT_SYMBOL vmlinux 0xa815b73d	locks_init_lock
++EXPORT_SYMBOL vmlinux 0xa8188772	param_get_byte
++EXPORT_SYMBOL vmlinux 0xa82585dc	register_md_personality
++EXPORT_SYMBOL vmlinux 0xa83f77e4	build_skb
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa848fe8e	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0xa861ab6e	__ioremap
++EXPORT_SYMBOL vmlinux 0xa86f78a7	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa89464b7	__ashldi3
++EXPORT_SYMBOL vmlinux 0xa8980828	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0xa8b4497f	kern_path_create
++EXPORT_SYMBOL vmlinux 0xa8bf2221	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0xa8c4530f	__inode_permission
++EXPORT_SYMBOL vmlinux 0xa8c683dd	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0xa8c82ad9	param_ops_short
++EXPORT_SYMBOL vmlinux 0xa8d84a2f	agp_copy_info
++EXPORT_SYMBOL vmlinux 0xa8f96860	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa900dc93	revert_creds
++EXPORT_SYMBOL vmlinux 0xa9083d07	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0xa90e48fe	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa9201760	__register_nls
++EXPORT_SYMBOL vmlinux 0xa9273e1a	epapr_hypercall_start
++EXPORT_SYMBOL vmlinux 0xa93a3948	param_get_ullong
++EXPORT_SYMBOL vmlinux 0xa9571d6d	DMA_MODE_WRITE
++EXPORT_SYMBOL vmlinux 0xa957cefb	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa977f50d	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0xa98d6227	devm_release_resource
++EXPORT_SYMBOL vmlinux 0xa9a04712	ip6_xmit
++EXPORT_SYMBOL vmlinux 0xa9c20043	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9e86440	tty_port_close
++EXPORT_SYMBOL vmlinux 0xaa00b451	fb_find_mode
++EXPORT_SYMBOL vmlinux 0xaa0544d1	d_invalidate
++EXPORT_SYMBOL vmlinux 0xaa18db58	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0xaa3264b1	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0xaa46e87e	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0xaa4df512	pmu_batteries
++EXPORT_SYMBOL vmlinux 0xaa6901ac	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0xaa6d699d	input_release_device
++EXPORT_SYMBOL vmlinux 0xaa6e4df5	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa787920	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0xaaa459fc	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0xaabf40e5	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0xaabf5600	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0xaacb3eeb	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0xaacbd934	agp_alloc_bridge
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaadaa3c7	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0xaaf4acf1	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab14f008	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0xab228e31	csum_tcpudp_magic
++EXPORT_SYMBOL vmlinux 0xab35ec32	genphy_read_status
++EXPORT_SYMBOL vmlinux 0xab519bfb	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0xab60562c	md_integrity_register
++EXPORT_SYMBOL vmlinux 0xab694444	bsearch
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab6edab5	tso_count_descs
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab7984be	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0xab7b4196	scsi_init_io
++EXPORT_SYMBOL vmlinux 0xab89c568	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0xaba3ad0c	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xabc7a79d	ata_port_printk
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabdd6463	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xabfcb4c3	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0xabffa77a	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac26b820	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0xac344110	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0xac3c6e00	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0xac4cc1bc	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0xac52b569	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0xac6d9920	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xac871afa	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0xac87faf0	dqput
++EXPORT_SYMBOL vmlinux 0xac8ef9aa	passthru_features_check
++EXPORT_SYMBOL vmlinux 0xaca1f1a2	set_bh_page
++EXPORT_SYMBOL vmlinux 0xaca99bdf	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacadb324	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xacb5a501	set_device_ro
++EXPORT_SYMBOL vmlinux 0xacc5b5d2	csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacce5154	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0xacd0bdf7	kobject_get
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xacef0f3f	set_user_nice
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xacf7ff70	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0xacf8d9b3	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0xacfd3632	param_ops_uint
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad06dd19	blk_init_queue
++EXPORT_SYMBOL vmlinux 0xad23c22a	tcp_close
++EXPORT_SYMBOL vmlinux 0xad4402b6	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0xad50cebb	i8253_lock
++EXPORT_SYMBOL vmlinux 0xad547243	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0xad7f43f6	scsi_host_put
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad8af904	d_tmpfile
++EXPORT_SYMBOL vmlinux 0xad8e7320	agp_enable
++EXPORT_SYMBOL vmlinux 0xad961743	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0xadc9c46b	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0xaddd4770	__debugger_iabr_match
++EXPORT_SYMBOL vmlinux 0xade0e611	bdi_destroy
++EXPORT_SYMBOL vmlinux 0xadee88da	update_region
++EXPORT_SYMBOL vmlinux 0xadf42bd5	__request_region
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xae1ee80b	set_groups
++EXPORT_SYMBOL vmlinux 0xae358236	fence_signal
++EXPORT_SYMBOL vmlinux 0xae38d662	macio_request_resource
++EXPORT_SYMBOL vmlinux 0xae3c28df	of_root
++EXPORT_SYMBOL vmlinux 0xae545f06	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xae642cd1	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0xae6c9c59	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0xae77a595	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0xae7f1db3	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0xae85a27e	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0xaec07bd6	follow_pfn
++EXPORT_SYMBOL vmlinux 0xaec655c7	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0xaec69eb6	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xaee46b43	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0xaeef44d1	dma_set_coherent_mask
++EXPORT_SYMBOL vmlinux 0xaef72271	scsi_add_device
++EXPORT_SYMBOL vmlinux 0xaf063510	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xaf0b5ef2	pipe_unlock
++EXPORT_SYMBOL vmlinux 0xaf0b81c2	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0xaf2d872c	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf46db06	register_key_type
++EXPORT_SYMBOL vmlinux 0xaf480ff1	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0xaf58d9ac	pci_clear_master
++EXPORT_SYMBOL vmlinux 0xaf6b6720	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xaf72e4fa	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xaf781ea0	km_report
++EXPORT_SYMBOL vmlinux 0xaf910a24	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0xaf9340a7	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xafa950b9	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0xafb0fd09	gen_pool_create
++EXPORT_SYMBOL vmlinux 0xaff24dfb	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0xafff3d1d	mempool_alloc
++EXPORT_SYMBOL vmlinux 0xb00f2083	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0xb02133db	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xb028ad9f	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0xb04241b4	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0xb0487747	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb060806d	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0xb062647a	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0xb081b9c3	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0xb09b2e6a	thaw_super
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0ab53d9	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0b877a7	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0xb0e0a649	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0fe0a49	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0xb10358dc	default_llseek
++EXPORT_SYMBOL vmlinux 0xb125974e	blk_free_tags
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb12fea99	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0xb13d585b	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0xb1442e99	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0xb15bd8fa	tb_ticks_per_sec
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb1668fe2	blk_init_tags
++EXPORT_SYMBOL vmlinux 0xb171335c	request_firmware
++EXPORT_SYMBOL vmlinux 0xb172a31e	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0xb173f30c	request_key_async
++EXPORT_SYMBOL vmlinux 0xb17fb1c9	nonseekable_open
++EXPORT_SYMBOL vmlinux 0xb1817307	complete_request_key
++EXPORT_SYMBOL vmlinux 0xb18d0731	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0xb1a6ee84	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1c6e787	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1e6a2cb	ata_link_printk
++EXPORT_SYMBOL vmlinux 0xb206f9cd	dget_parent
++EXPORT_SYMBOL vmlinux 0xb2114945	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0xb233762c	atomic64_set
++EXPORT_SYMBOL vmlinux 0xb25f69a0	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb2760ecc	netif_napi_add
++EXPORT_SYMBOL vmlinux 0xb2836b9d	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0xb287c8e3	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0xb2b50882	get_disk
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2ca6314	kill_block_super
++EXPORT_SYMBOL vmlinux 0xb2ce23eb	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0xb2d48a2e	queue_work_on
++EXPORT_SYMBOL vmlinux 0xb2d56b12	eth_header
++EXPORT_SYMBOL vmlinux 0xb2de769a	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0xb2f82933	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0xb32b7d01	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0xb32d7b7e	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0xb3382494	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0xb35478ce	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0xb360c01a	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0xb37ccdf6	mount_subtree
++EXPORT_SYMBOL vmlinux 0xb3c67363	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3d5637f	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0xb3e18b27	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb3ffe016	set_binfmt
++EXPORT_SYMBOL vmlinux 0xb4135832	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0xb415cf7b	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0xb4182dd5	__free_pages
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb4519a8f	string_escape_mem
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb4887385	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0xb49422e0	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0xb4b98a40	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xb502862a	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0xb52f1317	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0xb531709e	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0xb53a4336	kmap_pte
++EXPORT_SYMBOL vmlinux 0xb5457153	sock_wfree
++EXPORT_SYMBOL vmlinux 0xb54862ec	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb58d4eeb	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xb58f8dc5	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5bc5fa3	__frontswap_store
++EXPORT_SYMBOL vmlinux 0xb5d9454c	printk_emit
++EXPORT_SYMBOL vmlinux 0xb613d81a	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0xb616dc1a	down_write_trylock
++EXPORT_SYMBOL vmlinux 0xb618ad14	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0xb63248a5	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0xb632600f	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0xb64a7bed	param_set_ullong
++EXPORT_SYMBOL vmlinux 0xb65060ea	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0xb65896d8	agp_generic_create_gatt_table
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb6896671	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb69859ce	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0xb6a10e71	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6b9a59c	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0xb6c0d03d	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0xb6f05d75	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0xb71041c3	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0xb716069b	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xb720778d	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0xb722e550	generic_setlease
++EXPORT_SYMBOL vmlinux 0xb72f2c92	ps2_drain
++EXPORT_SYMBOL vmlinux 0xb731070e	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0xb731959b	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0xb7451021	__napi_complete
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb753bcc8	__ashrdi3
++EXPORT_SYMBOL vmlinux 0xb760cc88	tty_set_operations
++EXPORT_SYMBOL vmlinux 0xb762b973	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb78f2d92	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0xb78fd332	agp_generic_remove_memory
++EXPORT_SYMBOL vmlinux 0xb79a4e1a	store_fp_state
++EXPORT_SYMBOL vmlinux 0xb79ec15d	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0xb7a99781	__irq_regs
++EXPORT_SYMBOL vmlinux 0xb7bb06b1	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7f806ab	dump_page
++EXPORT_SYMBOL vmlinux 0xb81960ca	snprintf
++EXPORT_SYMBOL vmlinux 0xb8269c8e	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb830d394	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0xb83ce7c1	vfs_llseek
++EXPORT_SYMBOL vmlinux 0xb847468c	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0xb852b25c	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0xb8633530	vme_lm_request
++EXPORT_SYMBOL vmlinux 0xb8711e2e	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb8877c60	dqget
++EXPORT_SYMBOL vmlinux 0xb88ff1ad	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0xb894f380	nf_register_hook
++EXPORT_SYMBOL vmlinux 0xb8964185	machine_id
++EXPORT_SYMBOL vmlinux 0xb899bf33	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0xb8a39948	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0xb8ba4a4d	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0xb8e877e7	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xb9032cb8	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0xb9078c5a	ip_defrag
++EXPORT_SYMBOL vmlinux 0xb93a4983	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0xb945f315	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0xb94bbb15	devm_memremap
++EXPORT_SYMBOL vmlinux 0xb963e200	blk_rq_init
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xb9f75ad8	mdiobus_write
++EXPORT_SYMBOL vmlinux 0xba112c41	agp_generic_destroy_page
++EXPORT_SYMBOL vmlinux 0xba11a357	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0xba14a8f4	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0xba285222	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0xba37f3cf	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba5bf06f	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0xba604a77	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0xba75e1f3	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0xba785a01	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0xba9dc373	bmap
++EXPORT_SYMBOL vmlinux 0xbab75382	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0xbab9f61f	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0xbac3cbf2	ns_to_timespec64
++EXPORT_SYMBOL vmlinux 0xbadf0752	pci_release_regions
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb1453ce	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0xbb2a2d1b	down_read
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb4a5f43	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0xbb52b4e0	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb6f47d3	cad_pid
++EXPORT_SYMBOL vmlinux 0xbb823abb	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0xbb958ad8	dquot_resume
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbbb8667a	release_pages
++EXPORT_SYMBOL vmlinux 0xbbc943ae	pci_bus_get
++EXPORT_SYMBOL vmlinux 0xbbcca100	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0xbbd1e826	find_get_entry
++EXPORT_SYMBOL vmlinux 0xbbf0bf7c	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0xbbf79835	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0xbbfc2d84	find_vma
++EXPORT_SYMBOL vmlinux 0xbc1683ed	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0xbc316de4	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0xbc3419d3	flush_tlb_mm
++EXPORT_SYMBOL vmlinux 0xbc34757f	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0xbc54b84d	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0xbc62d381	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0xbc6515e4	vga_tryget
++EXPORT_SYMBOL vmlinux 0xbc8e57bf	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0xbcadb92d	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcd726f3	put_filp
++EXPORT_SYMBOL vmlinux 0xbcd8e26b	register_gifconf
++EXPORT_SYMBOL vmlinux 0xbcf150f9	xor_altivec_5
++EXPORT_SYMBOL vmlinux 0xbd01f9c4	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0xbd2885ab	seq_read
++EXPORT_SYMBOL vmlinux 0xbd2b77ae	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0xbd337d6a	get_pci_dma_ops
++EXPORT_SYMBOL vmlinux 0xbd4b14e3	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0xbd5a1ca6	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0xbd5ceed2	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0xbd6c0f8d	iget_failed
++EXPORT_SYMBOL vmlinux 0xbd6d3c3a	skb_make_writable
++EXPORT_SYMBOL vmlinux 0xbd75563f	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0xbd803510	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xbd81c8c8	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0xbd821c1e	unlock_page
++EXPORT_SYMBOL vmlinux 0xbd8d541d	flush_hash_pages
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbd9e5d49	__lshrdi3
++EXPORT_SYMBOL vmlinux 0xbda7ac1e	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0xbde0fb46	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0xbde93167	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0xbdfd8c86	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0xbe044409	alloc_disk
++EXPORT_SYMBOL vmlinux 0xbe080aab	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0xbe0e4119	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0xbe0e5118	nla_memcmp
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe45f56a	read_cache_pages
++EXPORT_SYMBOL vmlinux 0xbe494a5a	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0xbe593a0d	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0xbe61fa74	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0xbe63ee40	request_resource
++EXPORT_SYMBOL vmlinux 0xbe64c248	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0xbe68f270	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0xbe6fc74c	prepare_creds
++EXPORT_SYMBOL vmlinux 0xbe7e82ec	scsi_print_result
++EXPORT_SYMBOL vmlinux 0xbea07c7b	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0xbead47e3	clear_inode
++EXPORT_SYMBOL vmlinux 0xbee13d08	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0xbee90f2f	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf3a43ee	elevator_exit
++EXPORT_SYMBOL vmlinux 0xbf3c72c2	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0xbf486982	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xbf542850	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0xbf5b50d3	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf8ceb5d	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0xbf901814	kthread_stop
++EXPORT_SYMBOL vmlinux 0xbf925c42	idr_init
++EXPORT_SYMBOL vmlinux 0xbf939f52	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfb8b0b7	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xbfc177bc	iowrite32_rep
++EXPORT_SYMBOL vmlinux 0xbfeb3d9f	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xc00e7e49	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0xc0105225	ps2_end_command
++EXPORT_SYMBOL vmlinux 0xc01a3f6e	of_graph_get_remote_port_parent
++EXPORT_SYMBOL vmlinux 0xc02fd80c	of_get_next_child
++EXPORT_SYMBOL vmlinux 0xc04fe986	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0xc05119fe	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xc05e0bf2	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0xc065c878	of_parse_phandle_with_args
++EXPORT_SYMBOL vmlinux 0xc068440e	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc07fb765	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc08a1332	of_get_mac_address
++EXPORT_SYMBOL vmlinux 0xc08fa355	seq_pad
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0ca76f0	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0xc0ce60ea	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xc0d11911	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0xc0d84ced	cuda_poll
++EXPORT_SYMBOL vmlinux 0xc0e3b79d	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0xc0f294c3	led_blink_set
++EXPORT_SYMBOL vmlinux 0xc0f6eef1	generic_make_request
++EXPORT_SYMBOL vmlinux 0xc11d8093	iov_shorten
++EXPORT_SYMBOL vmlinux 0xc13a10dc	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0xc143f443	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0xc14a85dd	of_get_parent
++EXPORT_SYMBOL vmlinux 0xc150da93	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0xc1658667	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0xc1660866	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xc16dc744	wake_up_process
++EXPORT_SYMBOL vmlinux 0xc1822395	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0xc1826787	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0xc187c304	mmc_put_card
++EXPORT_SYMBOL vmlinux 0xc1932293	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0xc1ab8b5a	drop_nlink
++EXPORT_SYMBOL vmlinux 0xc1c95e87	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1d90443	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0xc1dd4a7f	adb_request
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc20ce63f	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0xc212bc19	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xc2424641	agp3_generic_cleanup
++EXPORT_SYMBOL vmlinux 0xc2457745	sock_wake_async
++EXPORT_SYMBOL vmlinux 0xc2504fce	mmc_free_host
++EXPORT_SYMBOL vmlinux 0xc25f493f	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0xc2a53eb3	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0xc2a6ceb4	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2acc033	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xc2b3b6ac	__invalidate_device
++EXPORT_SYMBOL vmlinux 0xc2b40071	keyring_alloc
++EXPORT_SYMBOL vmlinux 0xc2c0b7c8	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0xc2d711e1	krealloc
++EXPORT_SYMBOL vmlinux 0xc2df1031	pci_get_class
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc3096268	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0xc30c73b6	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0xc31d77d4	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0xc3244b9b	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0xc368849f	nvram_sync
++EXPORT_SYMBOL vmlinux 0xc3ac10c1	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0xc3b3a849	inet_shutdown
++EXPORT_SYMBOL vmlinux 0xc3c04b9f	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3c8b0c9	generic_write_checks
++EXPORT_SYMBOL vmlinux 0xc3d6902b	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0xc3dd44da	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0xc3f91aa9	param_get_charp
++EXPORT_SYMBOL vmlinux 0xc3fe64e1	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0xc41f0516	node_states
++EXPORT_SYMBOL vmlinux 0xc4267f46	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0xc45755de	find_next_zero_bit_le
++EXPORT_SYMBOL vmlinux 0xc47cdf9c	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0xc4930507	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4af05da	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0xc4d38742	rtas
++EXPORT_SYMBOL vmlinux 0xc4ea55a4	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xc519de11	__init_rwsem
++EXPORT_SYMBOL vmlinux 0xc522614c	__sb_end_write
++EXPORT_SYMBOL vmlinux 0xc52e66b6	nvm_end_io
++EXPORT_SYMBOL vmlinux 0xc53d4b46	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0xc5534d64	ioread16
++EXPORT_SYMBOL vmlinux 0xc553c258	i8042_install_filter
++EXPORT_SYMBOL vmlinux 0xc554c669	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0xc55866d4	netif_rx
++EXPORT_SYMBOL vmlinux 0xc55de23c	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0xc5718627	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0xc59640c6	of_find_backlight_by_node
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc5b16b10	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0xc5b23e39	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0xc5bdbc62	module_layout
++EXPORT_SYMBOL vmlinux 0xc5d9c46c	agp_try_unsupported_boot
++EXPORT_SYMBOL vmlinux 0xc5e8f7e0	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0xc5fc9b9c	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc60473d0	vfs_fsync
++EXPORT_SYMBOL vmlinux 0xc61e9769	kobject_put
++EXPORT_SYMBOL vmlinux 0xc61fef38	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0xc62a7b42	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc63f1560	file_update_time
++EXPORT_SYMBOL vmlinux 0xc64a26d9	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc6538e5e	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0xc65537d0	memremap
++EXPORT_SYMBOL vmlinux 0xc65746fc	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0xc65abeb7	agp3_generic_sizes
++EXPORT_SYMBOL vmlinux 0xc6628439	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0xc669fb9c	blkdev_get
++EXPORT_SYMBOL vmlinux 0xc66aa591	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0xc672f6b8	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xc68699d7	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0xc68cbbe3	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0xc6b22c71	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0xc6bf1b19	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6d2ebe8	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0xc6d7662e	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0xc6f03b1a	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0xc6fe193c	simple_empty
++EXPORT_SYMBOL vmlinux 0xc7072aec	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc727d52f	of_platform_bus_probe
++EXPORT_SYMBOL vmlinux 0xc73aac7d	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0xc73d27f3	block_write_begin
++EXPORT_SYMBOL vmlinux 0xc74b22d1	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc77805ce	scsi_execute
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc782355f	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc7898275	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0xc795e23e	cpu_core_map
++EXPORT_SYMBOL vmlinux 0xc799bbf5	skb_unlink
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a0d72f	inet_offloads
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7bc80f5	seq_escape
++EXPORT_SYMBOL vmlinux 0xc7ec6c27	strspn
++EXPORT_SYMBOL vmlinux 0xc7f3467e	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0xc8206548	param_set_uint
++EXPORT_SYMBOL vmlinux 0xc8276a79	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xc82ebc30	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0xc8339e24	string_unescape
++EXPORT_SYMBOL vmlinux 0xc8383dbe	of_n_size_cells
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc840a963	iterate_dir
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc8571bcb	idr_for_each
++EXPORT_SYMBOL vmlinux 0xc858d969	tty_port_open
++EXPORT_SYMBOL vmlinux 0xc85a5719	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc880bd37	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8b0c0ce	module_refcount
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8bf07d6	ip_options_compile
++EXPORT_SYMBOL vmlinux 0xc8cf1608	cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0xc8e0181c	__neigh_create
++EXPORT_SYMBOL vmlinux 0xc90307d5	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0xc909bf4c	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc9301819	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0xc93fbc54	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xc951dc67	mmc_start_req
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc965f30c	open_exec
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc9a54c43	inet6_getname
++EXPORT_SYMBOL vmlinux 0xc9ae8248	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0xc9aee356	__brelse
++EXPORT_SYMBOL vmlinux 0xc9b376e1	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0xc9b85235	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0xc9b8c308	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0xc9c60f03	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0xc9c6520a	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0xc9c8e911	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0xc9e4920c	decrementer_clockevent
++EXPORT_SYMBOL vmlinux 0xc9eca88f	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0xc9f79b1a	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xc9fda80c	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca0f5be1	dst_alloc
++EXPORT_SYMBOL vmlinux 0xca18d829	softnet_data
++EXPORT_SYMBOL vmlinux 0xca2a46d2	__kfree_skb
++EXPORT_SYMBOL vmlinux 0xca2b1cd6	ida_pre_get
++EXPORT_SYMBOL vmlinux 0xca3462e0	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0xca363d15	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0xca3b28c6	store_vr_state
++EXPORT_SYMBOL vmlinux 0xca41eaa3	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0xca44008f	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0xca59091c	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0xca5f5c5f	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0xca825895	pmu_suspend
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xcab96da0	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0xcac08e3c	write_cache_pages
++EXPORT_SYMBOL vmlinux 0xcacd272d	atomic64_sub_return
++EXPORT_SYMBOL vmlinux 0xcace6297	idr_is_empty
++EXPORT_SYMBOL vmlinux 0xcad08e48	mmu_hash_lock
++EXPORT_SYMBOL vmlinux 0xcae71621	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0xcaeff474	unload_nls
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcaf87ea1	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0xcb021f74	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb3d2bae	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0xcb42e7b9	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0xcb554069	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0xcb62ded8	bio_endio
++EXPORT_SYMBOL vmlinux 0xcb6882be	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0xcb6fdff1	page_waitqueue
++EXPORT_SYMBOL vmlinux 0xcbab9e6d	kill_bdev
++EXPORT_SYMBOL vmlinux 0xcbb4f308	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0xcbb99beb	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc1b85f	filemap_fault
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbeac4be	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcbfd6e67	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0xcc007ec1	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0xcc0ea31b	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0xcc17504d	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc262e33	ppc_md
++EXPORT_SYMBOL vmlinux 0xcc37c074	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0xcc409af1	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc9cf00c	__bread_gfp
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccc47b73	agp_backend_acquire
++EXPORT_SYMBOL vmlinux 0xcccc42a7	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xccd1c882	d_walk
++EXPORT_SYMBOL vmlinux 0xccdacf3e	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0xccf7f5c1	pci_map_rom
++EXPORT_SYMBOL vmlinux 0xccfc0082	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0xccfef64f	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0xcd0100de	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0xcd0152b3	md_done_sync
++EXPORT_SYMBOL vmlinux 0xcd0529c7	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0xcd066e77	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0xcd0b82c9	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0xcd106328	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0xcd13dc7c	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd4993c3	inet_getname
++EXPORT_SYMBOL vmlinux 0xcd508f20	dentry_open
++EXPORT_SYMBOL vmlinux 0xcd5a4fa7	macio_enable_devres
++EXPORT_SYMBOL vmlinux 0xcd68effd	_dev_info
++EXPORT_SYMBOL vmlinux 0xcd7ede2a	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xcd86c87f	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0xcd86f323	module_put
++EXPORT_SYMBOL vmlinux 0xcd932214	free_netdev
++EXPORT_SYMBOL vmlinux 0xcd9586cc	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0xcd9d0fe3	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0xcdc08bf3	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcddcd436	iterate_mounts
++EXPORT_SYMBOL vmlinux 0xcdeb8123	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce2b500a	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0xce316fc8	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0xce39033c	nobh_write_end
++EXPORT_SYMBOL vmlinux 0xce409cda	pmac_set_early_video_resume
++EXPORT_SYMBOL vmlinux 0xce513c38	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0xce57dbea	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce5d8f7f	agp_generic_enable
++EXPORT_SYMBOL vmlinux 0xce7677e0	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xce79e192	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xcead0d16	audit_log
++EXPORT_SYMBOL vmlinux 0xcead77f1	free_user_ns
++EXPORT_SYMBOL vmlinux 0xceb16d9b	inet_put_port
++EXPORT_SYMBOL vmlinux 0xced2cdaa	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcef778e1	blk_put_request
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf0e48d9	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0xcf1e1e23	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0xcf2b3f71	ppp_input_error
++EXPORT_SYMBOL vmlinux 0xcf47fb99	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0xcf5a7974	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0xcf5d7502	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0xcf74b87c	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0xcfa3d2a5	get_phy_device
++EXPORT_SYMBOL vmlinux 0xcfb8c96b	simple_rmdir
++EXPORT_SYMBOL vmlinux 0xcfbe6c44	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0xcfe5a868	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0xcff465ff	of_device_get_match_data
++EXPORT_SYMBOL vmlinux 0xd035376e	___pskb_trim
++EXPORT_SYMBOL vmlinux 0xd04ec7f9	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0xd054b47a	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0xd05c7040	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd0868acb	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a45fa5	pmu_enable_irled
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0b25667	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0xd0bc718d	dev_get_flags
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0f7b987	param_get_long
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fef3b2	agp_free_key
++EXPORT_SYMBOL vmlinux 0xd1247cc4	of_translate_address
++EXPORT_SYMBOL vmlinux 0xd1262886	rtas_data_buf
++EXPORT_SYMBOL vmlinux 0xd144e169	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0xd1570c0f	ilookup
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd18e7f8a	agp_generic_alloc_page
++EXPORT_SYMBOL vmlinux 0xd196c9be	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xd1ac33bd	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0xd1b683e5	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0xd1c84dfb	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1e3f3c4	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xd214512c	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0xd22bd3fe	security_path_truncate
++EXPORT_SYMBOL vmlinux 0xd23b542d	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd259ae8f	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd283de92	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0xd28cf8f6	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0xd29e4d72	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0xd2a941d4	sg_init_table
++EXPORT_SYMBOL vmlinux 0xd2af138b	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2dcd729	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0xd2e0c10b	vme_irq_request
++EXPORT_SYMBOL vmlinux 0xd2f3b79e	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xd2f836d1	mount_ns
++EXPORT_SYMBOL vmlinux 0xd2fc19bd	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0xd304fef0	vga_get
++EXPORT_SYMBOL vmlinux 0xd3187da4	pcibios_align_resource
++EXPORT_SYMBOL vmlinux 0xd3189043	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0xd31ccb06	of_machine_is_compatible
++EXPORT_SYMBOL vmlinux 0xd32d3209	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0xd33ed336	param_ops_string
++EXPORT_SYMBOL vmlinux 0xd34c304a	dma_pool_create
++EXPORT_SYMBOL vmlinux 0xd392a6d3	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0xd3b4f053	noop_llseek
++EXPORT_SYMBOL vmlinux 0xd3bc03b5	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3c1190b	inet6_offloads
++EXPORT_SYMBOL vmlinux 0xd3e6f60d	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0xd3f053f9	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0xd3fdb4db	locks_free_lock
++EXPORT_SYMBOL vmlinux 0xd409383c	pmu_request
++EXPORT_SYMBOL vmlinux 0xd40d326a	uart_match_port
++EXPORT_SYMBOL vmlinux 0xd418e1c0	adjust_resource
++EXPORT_SYMBOL vmlinux 0xd43df311	brioctl_set
++EXPORT_SYMBOL vmlinux 0xd44b7e21	to_tm
++EXPORT_SYMBOL vmlinux 0xd4525788	km_is_alive
++EXPORT_SYMBOL vmlinux 0xd45df039	block_commit_write
++EXPORT_SYMBOL vmlinux 0xd46cb561	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0xd48986fb	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0xd497383c	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0xd4bc6465	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0xd4d5b10c	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0xd4de3169	dm_register_target
++EXPORT_SYMBOL vmlinux 0xd4eb34e8	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0xd526a6cd	agp_generic_free_by_type
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd587db8c	block_read_full_page
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd59d1a66	up_write
++EXPORT_SYMBOL vmlinux 0xd5b0d398	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0xd5b9ee2a	bdput
++EXPORT_SYMBOL vmlinux 0xd5c482a4	blk_complete_request
++EXPORT_SYMBOL vmlinux 0xd5c812ad	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0xd5e45fe3	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xd5e8444a	__div64_32
++EXPORT_SYMBOL vmlinux 0xd5e942f9	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0xd5f52d4f	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0xd5f753bf	vfs_setpos
++EXPORT_SYMBOL vmlinux 0xd6031dcd	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0xd606503d	register_sysctl
++EXPORT_SYMBOL vmlinux 0xd60bb403	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd627480b	strncat
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd668ab91	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0xd668e544	mount_nodev
++EXPORT_SYMBOL vmlinux 0xd6695dba	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0xd66d87d7	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd69b30e0	atomic64_add_unless
++EXPORT_SYMBOL vmlinux 0xd6a769c3	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0xd6bf61f2	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0xd6c41851	do_truncate
++EXPORT_SYMBOL vmlinux 0xd6d63e9d	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0xd6dfe100	neigh_xmit
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd7046408	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0xd70c05a7	netdev_change_features
++EXPORT_SYMBOL vmlinux 0xd72a2ab0	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0xd7461f9a	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd78671ad	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0xd797b9a5	vme_master_write
++EXPORT_SYMBOL vmlinux 0xd7997312	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0xd79b015e	__getblk_slow
++EXPORT_SYMBOL vmlinux 0xd7a2380d	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0xd7a6bca8	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0xd7b6b5a2	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd7ef311a	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0xd7f49bac	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0xd809b779	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0xd80b710a	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0xd8269994	freeze_bdev
++EXPORT_SYMBOL vmlinux 0xd837bf04	d_alloc_name
++EXPORT_SYMBOL vmlinux 0xd84c43a6	lockref_put_return
++EXPORT_SYMBOL vmlinux 0xd8543fe4	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0xd875554d	copy_to_iter
++EXPORT_SYMBOL vmlinux 0xd88fd012	param_ops_bool
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8b08a68	sg_miter_next
++EXPORT_SYMBOL vmlinux 0xd8bbd287	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0xd8c5c1d1	__get_user_pages
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd9026511	tty_do_resize
++EXPORT_SYMBOL vmlinux 0xd9153da0	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xd91c1ecb	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0xd9214e79	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0xd92514ca	agp_special_page
++EXPORT_SYMBOL vmlinux 0xd943f181	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0xd9498b22	proc_dointvec
++EXPORT_SYMBOL vmlinux 0xd94b6f3c	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0xd95c441f	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0xd965e27c	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0xd966ddc2	__do_once_done
++EXPORT_SYMBOL vmlinux 0xd97b9ea7	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd9b948eb	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0xd9bac924	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0xd9ce8f0c	strnlen
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9ea3b1f	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0xd9f009fd	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0xda103105	of_find_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0xda18a86f	kobject_del
++EXPORT_SYMBOL vmlinux 0xda3c5ba0	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda53b345	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0xda72cc0c	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda82b354	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda92dab3	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0xda9757e0	km_state_notify
++EXPORT_SYMBOL vmlinux 0xdaa57ec3	totalhigh_pages
++EXPORT_SYMBOL vmlinux 0xdaae02e5	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0xdaaed687	devm_free_irq
++EXPORT_SYMBOL vmlinux 0xdac2e5c4	i2c_master_send
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdada7b9b	tty_unlock
++EXPORT_SYMBOL vmlinux 0xdae81bff	netdev_state_change
++EXPORT_SYMBOL vmlinux 0xdb12387c	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0xdb30f8c9	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0xdb37c806	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb74f0ec	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb9b7cf4	blk_start_queue
++EXPORT_SYMBOL vmlinux 0xdba7c384	validate_sp
++EXPORT_SYMBOL vmlinux 0xdbad3473	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0xdbc164e1	prepare_binprm
++EXPORT_SYMBOL vmlinux 0xdbcd19e0	flush_dcache_page
++EXPORT_SYMBOL vmlinux 0xdbf87890	copy_from_iter
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc119a56	phy_init_hw
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc214961	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdc551cc6	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0xdc70d6e9	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0xdc942659	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xdc9498dd	down
++EXPORT_SYMBOL vmlinux 0xdcac49a9	param_get_int
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdcefb9a5	pmu_resume
++EXPORT_SYMBOL vmlinux 0xdd0a2ba2	strlcat
++EXPORT_SYMBOL vmlinux 0xdd11cafd	dev_trans_start
++EXPORT_SYMBOL vmlinux 0xdd1ee4c5	down_read_trylock
++EXPORT_SYMBOL vmlinux 0xdd27fa87	memchr
++EXPORT_SYMBOL vmlinux 0xdd35ba06	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0xdd4e18a0	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0xdd4ea0b1	finish_open
++EXPORT_SYMBOL vmlinux 0xdd51b24e	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0xdd546ae0	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xdd6af9c0	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0xdd9030af	current_stack_pointer
++EXPORT_SYMBOL vmlinux 0xddb9a79a	simple_unlink
++EXPORT_SYMBOL vmlinux 0xddefbdc5	vfs_write
++EXPORT_SYMBOL vmlinux 0xde3788b8	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0xde41138e	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0xde463d35	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0xde48e9ca	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0xde4cf182	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0xde558295	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0xde74146c	padata_do_serial
++EXPORT_SYMBOL vmlinux 0xde91448c	load_vr_state
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde9abb5a	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0xde9b17ed	agp3_generic_fetch_size
++EXPORT_SYMBOL vmlinux 0xded73fec	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0xdeedffdb	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0xdefb15fc	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0xdf0f1e30	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0xdf263cb0	security_mmap_file
++EXPORT_SYMBOL vmlinux 0xdf27248a	kernel_listen
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf2ff68b	dup_iter
++EXPORT_SYMBOL vmlinux 0xdf3a693d	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0xdf3c0eb6	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0xdf45713d	eth_header_parse
++EXPORT_SYMBOL vmlinux 0xdf4571a4	vme_bus_type
++EXPORT_SYMBOL vmlinux 0xdf4c2ecf	key_type_keyring
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf5c8911	mmc_get_card
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf80deaa	param_set_int
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdf93b9d8	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0xdf953733	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0xdf99b418	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0xdfc9bfa9	irq_set_chip
++EXPORT_SYMBOL vmlinux 0xdfd71dc2	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0xdfe564b0	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0xdff43ed4	__debugger
++EXPORT_SYMBOL vmlinux 0xdff56e64	adb_poll
++EXPORT_SYMBOL vmlinux 0xdff5be94	netdev_update_features
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xe013ebed	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0xe04a4092	of_device_is_available
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe0820765	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe094ef39	sg_next
++EXPORT_SYMBOL vmlinux 0xe0a680ab	get_super
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0cfc921	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0xe0d27f0f	proc_set_size
++EXPORT_SYMBOL vmlinux 0xe0d32dd9	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe126f6ac	of_device_unregister
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe1814ed7	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0xe195a2c2	skb_seq_read
++EXPORT_SYMBOL vmlinux 0xe1ae3943	pci_find_capability
++EXPORT_SYMBOL vmlinux 0xe1c04ad6	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0xe1d183d1	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0xe1d8a09a	single_release
++EXPORT_SYMBOL vmlinux 0xe1fbbd99	param_set_byte
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe208b860	__genl_register_family
++EXPORT_SYMBOL vmlinux 0xe20d59c7	read_cache_page
++EXPORT_SYMBOL vmlinux 0xe2163806	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0xe218e814	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL vmlinux 0xe231ff46	of_find_net_device_by_node
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe24c5991	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe2651d7d	vc_resize
++EXPORT_SYMBOL vmlinux 0xe2662bea	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0xe2703167	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0xe27d702b	make_bad_inode
++EXPORT_SYMBOL vmlinux 0xe2845cdf	proc_douintvec
++EXPORT_SYMBOL vmlinux 0xe28bfaa6	kernel_accept
++EXPORT_SYMBOL vmlinux 0xe2907824	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2ba72db	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0xe2be5498	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0xe2cfb029	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2d65132	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0xe2e8065e	memdup_user
++EXPORT_SYMBOL vmlinux 0xe2ebcf97	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe2fae716	kmemdup
++EXPORT_SYMBOL vmlinux 0xe2fca23a	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0xe2fccd5b	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0xe30ba653	update_devfreq
++EXPORT_SYMBOL vmlinux 0xe30daafb	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0xe3254520	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xe32ad77a	netif_napi_del
++EXPORT_SYMBOL vmlinux 0xe34a9a8b	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0xe34c5595	kset_unregister
++EXPORT_SYMBOL vmlinux 0xe350761b	make_kuid
++EXPORT_SYMBOL vmlinux 0xe359e3b8	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0xe3609ef8	pci_save_state
++EXPORT_SYMBOL vmlinux 0xe384b209	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0xe388510d	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0xe3aec898	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3c7936e	neigh_destroy
++EXPORT_SYMBOL vmlinux 0xe3d45e2c	get_user_pages
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3e82621	free_task
++EXPORT_SYMBOL vmlinux 0xe410c5c4	inet_del_offload
++EXPORT_SYMBOL vmlinux 0xe41368e7	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0xe4156e72	d_add_ci
++EXPORT_SYMBOL vmlinux 0xe45e68de	nobh_writepage
++EXPORT_SYMBOL vmlinux 0xe4624800	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0xe47d389f	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0xe481c5ea	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0xe484e35f	ioread32
++EXPORT_SYMBOL vmlinux 0xe49e036c	scmd_printk
++EXPORT_SYMBOL vmlinux 0xe4c17741	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0xe4d185c0	put_io_context
++EXPORT_SYMBOL vmlinux 0xe4e564f5	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe4fbeb28	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0xe4fe8ca1	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xe51cdd08	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe557e510	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5849e2a	up_read
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe592f912	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0xe5a94a8f	of_n_addr_cells
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5ddb7cc	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe5ed87bb	vm_insert_page
++EXPORT_SYMBOL vmlinux 0xe5f42963	d_obtain_root
++EXPORT_SYMBOL vmlinux 0xe5fb5469	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0xe638064b	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0xe64168b5	mmc_of_parse_voltage
++EXPORT_SYMBOL vmlinux 0xe66d7afa	security_path_symlink
++EXPORT_SYMBOL vmlinux 0xe693a6ce	vme_get_size
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe6a2a062	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0xe6b790aa	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0xe6b872b0	follow_down_one
++EXPORT_SYMBOL vmlinux 0xe6b88851	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0xe6cdcac1	flush_signals
++EXPORT_SYMBOL vmlinux 0xe6dd236d	clear_pages
++EXPORT_SYMBOL vmlinux 0xe6ebc016	key_create_or_update
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe71886b2	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0xe72ba6d7	dcb_setapp
++EXPORT_SYMBOL vmlinux 0xe73c7f13	pipe_lock
++EXPORT_SYMBOL vmlinux 0xe7425156	sock_create_kern
++EXPORT_SYMBOL vmlinux 0xe74fbc60	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0xe75add59	tty_register_driver
++EXPORT_SYMBOL vmlinux 0xe760b7c2	tty_devnum
++EXPORT_SYMBOL vmlinux 0xe79cf4ab	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7aeca38	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0xe7b6315e	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xe7bf317d	fsl_lbc_addr
++EXPORT_SYMBOL vmlinux 0xe7c4a439	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0xe7ce7439	_memcpy_fromio
++EXPORT_SYMBOL vmlinux 0xe7d0a4c3	i8042_remove_filter
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7e35b89	__breadahead
++EXPORT_SYMBOL vmlinux 0xe7ea5dfd	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe82cc752	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0xe852b531	input_unregister_device
++EXPORT_SYMBOL vmlinux 0xe8651ba8	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8aca7a3	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe907b3dc	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0xe90fb944	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe9378d58	idr_get_next
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe969f09a	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0xe96c4c99	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xe9a681ff	fb_set_var
++EXPORT_SYMBOL vmlinux 0xe9ab4b42	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0xe9b57421	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0xe9becdc5	vfs_symlink
++EXPORT_SYMBOL vmlinux 0xe9ca213a	skb_split
++EXPORT_SYMBOL vmlinux 0xe9ec1422	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xea015542	mach_powermac
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea1adaa3	__serio_register_port
++EXPORT_SYMBOL vmlinux 0xea2795f0	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0xea2e4577	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0xea653409	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0xea695041	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0xea6bada1	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0xea7370ee	put_page
++EXPORT_SYMBOL vmlinux 0xea7987f1	key_update
++EXPORT_SYMBOL vmlinux 0xea968c96	___ratelimit
++EXPORT_SYMBOL vmlinux 0xeab3c95a	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0xeab93944	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0xeacef85f	generic_update_time
++EXPORT_SYMBOL vmlinux 0xeaea03b9	bdget_disk
++EXPORT_SYMBOL vmlinux 0xeb018851	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0xeb3164c2	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb46e33c	dev_add_offload
++EXPORT_SYMBOL vmlinux 0xeb55a931	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xeb6ea3a1	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0xeb8ca594	inet_accept
++EXPORT_SYMBOL vmlinux 0xeb8d93b5	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0xeba1f73b	page_put_link
++EXPORT_SYMBOL vmlinux 0xeba220ea	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0xeba2a1f7	rtas_indicator_present
++EXPORT_SYMBOL vmlinux 0xebbf6919	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0xebca120c	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0xebca45b8	get_fs_type
++EXPORT_SYMBOL vmlinux 0xebcd0165	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0xebd18deb	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0xebfa7d22	napi_get_frags
++EXPORT_SYMBOL vmlinux 0xec1aa6ef	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xec33a092	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0xec4b14a0	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0xec54f8e1	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0xec88775c	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0xec99b125	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0xeca2b9bf	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0xecb53d0a	bdgrab
++EXPORT_SYMBOL vmlinux 0xecbb926f	xor_altivec_3
++EXPORT_SYMBOL vmlinux 0xecbcb8bb	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xecc3dbed	__dax_fault
++EXPORT_SYMBOL vmlinux 0xecd553da	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0xecd982a2	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xecee2580	of_get_next_parent
++EXPORT_SYMBOL vmlinux 0xed053874	simple_rename
++EXPORT_SYMBOL vmlinux 0xed1d4042	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0xed278f43	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0xed334cda	dump_truncate
++EXPORT_SYMBOL vmlinux 0xed3984ef	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed7e5d6f	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0xed8050c1	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0xed85e37a	d_lookup
++EXPORT_SYMBOL vmlinux 0xed8ecf48	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0xed93f29e	__kunmap_atomic
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedb48057	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0xedb62536	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0xedb7475a	of_gpio_simple_xlate
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedc410d0	udplite_table
++EXPORT_SYMBOL vmlinux 0xedf027b9	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xee0065ce	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0xee0361e0	register_filesystem
++EXPORT_SYMBOL vmlinux 0xee246cad	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee3496c3	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0xee3a26ff	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0xee4e24a2	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0xee51090a	done_path_create
++EXPORT_SYMBOL vmlinux 0xee59412f	adb_try_handler_change
++EXPORT_SYMBOL vmlinux 0xee66afe3	bd_set_size
++EXPORT_SYMBOL vmlinux 0xee77686d	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0xee832c23	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xeea0dfd9	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeec2d844	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0xeec39719	param_get_invbool
++EXPORT_SYMBOL vmlinux 0xeed3b2a0	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0xeed5b234	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xeef26e05	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0xeef5d680	loop_backing_file
++EXPORT_SYMBOL vmlinux 0xeefba181	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0xef08c058	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xef3fbb96	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0xef585820	agp_generic_free_gatt_table
++EXPORT_SYMBOL vmlinux 0xef6aca2a	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0xef7122e2	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0xef8c34c4	of_get_ibm_chip_id
++EXPORT_SYMBOL vmlinux 0xef924757	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0xef93938b	netdev_emerg
++EXPORT_SYMBOL vmlinux 0xef9e00cc	udp_proc_register
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefde1bbe	flush_dcache_range
++EXPORT_SYMBOL vmlinux 0xefe6e1a4	kdb_current_task
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf000e1fb	fs_bio_set
++EXPORT_SYMBOL vmlinux 0xf01c752f	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0xf04f6548	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0xf04f65ab	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf065f629	ioread16be
++EXPORT_SYMBOL vmlinux 0xf0665f1e	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0xf073f267	sock_create
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf09144d8	account_page_redirty
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0cddc41	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf0f136cd	pci_set_master
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf10de535	ioread8
++EXPORT_SYMBOL vmlinux 0xf1167677	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0xf116ff53	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0xf11cd6ce	down_interruptible
++EXPORT_SYMBOL vmlinux 0xf120872a	dql_completed
++EXPORT_SYMBOL vmlinux 0xf1248677	of_parse_phandle
++EXPORT_SYMBOL vmlinux 0xf1340e28	sock_no_poll
++EXPORT_SYMBOL vmlinux 0xf138f4c7	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0xf13935a5	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0xf141ee9a	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf1500152	__quota_error
++EXPORT_SYMBOL vmlinux 0xf159747c	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0xf160a685	iput
++EXPORT_SYMBOL vmlinux 0xf175c80c	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf1989895	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0xf19e9355	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0xf1b74867	simple_statfs
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1deabf2	div64_u64
++EXPORT_SYMBOL vmlinux 0xf1e95d4b	wireless_send_event
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf2001ee4	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf2256bd9	rt6_lookup
++EXPORT_SYMBOL vmlinux 0xf22881e8	lg_local_lock
++EXPORT_SYMBOL vmlinux 0xf22b9972	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0xf22f9a4e	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0xf23deb12	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf24ee8d0	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0xf2527456	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0xf274b7bf	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0xf27563cb	irq_stat
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2b1faff	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0xf2b8135d	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2d538b0	pci_device_from_OF_node
++EXPORT_SYMBOL vmlinux 0xf2ddbcd0	submit_bio
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf322a206	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0xf326161b	of_find_property
++EXPORT_SYMBOL vmlinux 0xf32866aa	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf33aae69	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0xf343fb77	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf346affa	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf36a644a	dump_skip
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf3ab17d3	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0xf3bd1951	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf3e9f7b6	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0xf3f626d7	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0xf40b2297	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xf426be89	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0xf437218b	seq_puts
++EXPORT_SYMBOL vmlinux 0xf441ac43	ioread8_rep
++EXPORT_SYMBOL vmlinux 0xf4449388	timer_interrupt
++EXPORT_SYMBOL vmlinux 0xf444f40f	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xf446e3e7	ipv4_specific
++EXPORT_SYMBOL vmlinux 0xf4482638	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xf45388f1	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0xf459ff02	pci_find_hose_for_OF_device
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf4751e26	ps2_init
++EXPORT_SYMBOL vmlinux 0xf4914910	sock_from_file
++EXPORT_SYMBOL vmlinux 0xf4bb4a35	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4d50de9	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0xf4e1ace2	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0xf4eef396	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf5143a81	add_disk
++EXPORT_SYMBOL vmlinux 0xf514b737	mmc_request_done
++EXPORT_SYMBOL vmlinux 0xf5222143	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xf52321e0	atomic64_sub
++EXPORT_SYMBOL vmlinux 0xf52c555c	of_find_i2c_device_by_node
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf54c51a2	dma_pool_free
++EXPORT_SYMBOL vmlinux 0xf57136fb	check_disk_change
++EXPORT_SYMBOL vmlinux 0xf5881926	setattr_copy
++EXPORT_SYMBOL vmlinux 0xf59453c9	__pagevec_release
++EXPORT_SYMBOL vmlinux 0xf59b8008	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0xf5a62ecc	_memset_io
++EXPORT_SYMBOL vmlinux 0xf5b41647	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5d0adda	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0xf5e1558d	crash_shutdown_unregister
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf5ee198b	mdiobus_read
++EXPORT_SYMBOL vmlinux 0xf610a3ac	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0xf62b1f00	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf64ec733	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0xf66f7026	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf6789a40	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68b6d3e	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0xf69715cc	secpath_dup
++EXPORT_SYMBOL vmlinux 0xf6996098	unregister_console
++EXPORT_SYMBOL vmlinux 0xf69f3722	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0xf6a540d8	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf70384d7	__debugger_sstep
++EXPORT_SYMBOL vmlinux 0xf709853c	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0xf71521ba	atomic64_add_return
++EXPORT_SYMBOL vmlinux 0xf736af61	dev_addr_init
++EXPORT_SYMBOL vmlinux 0xf7496af2	set_cached_acl
++EXPORT_SYMBOL vmlinux 0xf7553c7e	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf784403c	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0xf78ea967	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0xf7a9b531	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0xf7f0a4d3	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0xf801b80b	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0xf80debc5	pmac_suspend_agp_for_card
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf85288a7	mutex_unlock
++EXPORT_SYMBOL vmlinux 0xf869fa0c	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0xf88b9f7a	bdev_read_only
++EXPORT_SYMBOL vmlinux 0xf8bf2083	page_readlink
++EXPORT_SYMBOL vmlinux 0xf8de93a0	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0xf8e6da6b	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0xf8ef514e	vfs_create
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf90e5e7e	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0xf918f56d	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0xf92c5e81	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0xf9348cbc	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xf93999b4	backlight_force_update
++EXPORT_SYMBOL vmlinux 0xf93e41f0	md_reload_sb
++EXPORT_SYMBOL vmlinux 0xf94b0436	phy_suspend
++EXPORT_SYMBOL vmlinux 0xf94e1ecb	sk_stream_error
++EXPORT_SYMBOL vmlinux 0xf968439e	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0xf99dc29c	tso_build_data
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9bfd0bb	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0xf9e69780	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0xf9e73082	scnprintf
++EXPORT_SYMBOL vmlinux 0xf9f9f729	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0xfa0fa8a1	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa554829	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0xfa598fc2	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfaa7c9fa	misc_deregister
++EXPORT_SYMBOL vmlinux 0xfaaf9c9f	kobject_init
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xface39b9	mpage_writepages
++EXPORT_SYMBOL vmlinux 0xfadb5750	pmu_unlock
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfaee1783	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0xfb0ef56c	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0xfb176b84	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0xfb5cf667	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbe7c97d	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xfbee350f	mpage_writepage
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc1282bd	blkdev_put
++EXPORT_SYMBOL vmlinux 0xfc155177	noop_fsync
++EXPORT_SYMBOL vmlinux 0xfc240f16	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0xfc256f8d	fput
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc3a98c1	blk_finish_request
++EXPORT_SYMBOL vmlinux 0xfc3b160f	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xfc4f3194	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0xfc65459a	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0xfcaaad84	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0xfcb4f8a9	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcc97ee6	tty_port_put
++EXPORT_SYMBOL vmlinux 0xfccb3634	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0xfccecf70	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcf84a93	atomic64_xor
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfd0c5038	adb_unregister
++EXPORT_SYMBOL vmlinux 0xfd33b5fa	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xfd6ed1b8	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0xfd8da476	phy_device_create
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfda75de1	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0xfdaa5866	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0xfdb6cedc	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0xfdb9b629	ioread32be
++EXPORT_SYMBOL vmlinux 0xfddae3c8	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0xfddbfa93	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0xfded48ed	enable_kernel_fp
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfdfc394f	dev_printk
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe4374c5	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0xfe4e8945	serio_bus
++EXPORT_SYMBOL vmlinux 0xfe5d26a0	dma_find_channel
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe6290a7	release_firmware
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe84ef13	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0xfe8a2f28	send_sig_info
++EXPORT_SYMBOL vmlinux 0xfe93acc7	simple_setattr
++EXPORT_SYMBOL vmlinux 0xfe9743fa	nf_log_trace
++EXPORT_SYMBOL vmlinux 0xfe9e4ca5	proto_register
++EXPORT_SYMBOL vmlinux 0xfeca7590	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xff12a0e7	serio_open
++EXPORT_SYMBOL vmlinux 0xff157272	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0xff1765c7	rtas_call
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff243f4f	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0xff41746a	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0xff41fdf1	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0xff51bf2c	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0xff59b78f	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0xff5d3d2f	agp_generic_alloc_pages
++EXPORT_SYMBOL vmlinux 0xff64304c	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0xff643ee7	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0xff645943	pci_select_bars
++EXPORT_SYMBOL vmlinux 0xff66298f	register_console
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff6dea25	smp_hw_index
++EXPORT_SYMBOL vmlinux 0xff771259	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0xff8ab4c7	dm_io
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffa41d44	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0xffacfe1c	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0xffae6290	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xffc27482	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0xffc863b1	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffdb82bc	sg_free_table
++EXPORT_SYMBOL_GPL crypto/af_alg 0x319fd22f	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x34b314cf	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0x58716898	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0x7928186e	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x926e5432	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x968246c3	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x9fd7cbb0	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0xa943459f	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xc0760c9d	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0xde8ad655	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xf277557c	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x478b0830	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x3aa47af5	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x69e6330f	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x3e288ce7	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0xcafbf2e7	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x1eb31d27	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x3e673629	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x55d5eabd	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xa08619f1	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x5d351715	async_xor
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x87cdee9b	async_xor_val
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x4af48425	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0xd77d775d	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0xb174c8e9	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x06df7138	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x12370431	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/cryptd 0x0bd62a53	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x4d3a017c	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x5152fab4	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x7b61514a	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x83c46f12	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x946ae189	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xa487f6c3	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xd9341ef7	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xe62fd351	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xf6819294	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0x77bcc42c	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x14bdd4d3	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x46e0fdee	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x544fdf88	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x5e071253	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x8bdc1866	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xbc15db47	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xc7d447f3	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xc7d6422c	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xe20b1340	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x8f5241b3	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xc380f6ed	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xc76d2f19	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xd359decd	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x3b317afc	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0xf686b218	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0xeb14603f	xts_crypt
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x064da59d	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x0c940ac4	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x13c35059	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x19d29bd0	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x19ec9db4	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x280fc483	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x2ba43067	ahci_error_handler
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x3480d7de	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x384fa991	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x5540fcd5	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x58db456a	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8de11fdb	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8fca2e07	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x91f52b04	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x9df250d7	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa696d240	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa85af9f9	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xba13ef5a	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xd68e50ce	ahci_host_activate
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xedd7bc94	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xef53fa98	ahci_qc_issue
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xeff09d82	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf9be058a	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x1005aa5f	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x2ee6629d	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x4d03e0fc	ahci_platform_resume_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x5239bd9b	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x54be4c12	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x6e460335	ahci_platform_suspend
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x6f9f8338	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x95f20c92	ahci_platform_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xacfd505b	ahci_platform_init_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xc8670e8a	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xd054bd54	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xe278dd96	ahci_platform_suspend_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xe8271d7c	ahci_platform_ops
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0x7d2d7dba	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/ata/pata_sis 0xd15e4907	sis_info133_for_sata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x02784832	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x8cca8df5	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xb6bdcbce	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xba97f553	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x00797cb7	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1236d9f5	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x15583ea1	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1810f4ad	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1ee7f309	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x51b220df	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x56afc583	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x5cfe21bb	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x67275e22	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x67930759	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x69534bac	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x7ed6f542	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x93b4d668	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x94e168b9	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xad9998f5	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc64379eb	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd56034cf	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdc079ddd	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdce67a2a	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdf3f2fa3	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdf87a9ae	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe78be1b0	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xeb917390	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf27af690	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x48f983ff	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x5ef3dc5a	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x65834bf7	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x8e9d67ac	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x950588c8	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xd4727921	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x0503a2b3	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x1a3e0673	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x1e182a8e	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x3722bce2	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x5ad66c00	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x66971174	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x6ddd6a43	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x7359680b	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x91e8bb46	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xc5ef60b8	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xed9f0983	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xff887083	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x0e367572	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x23fff086	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x727c0569	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x7d183496	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x7ec080d8	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x9670204b	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x970ee10c	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x986d4174	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xc6840241	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xc8f06ce2	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xfdf38816	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x014383c2	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x4ca39e0e	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0x17d7a599	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0x5fe8c1ee	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x16896b6d	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x2a8c9348	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x6cc9df47	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x7353b2a9	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xd0b18841	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x4105ca1d	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0xeea93409	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0xfc5f232b	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x122d3276	vchan_init
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x46dbec0c	vchan_tx_submit
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x9d97c312	vchan_find_desc
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xf5462a59	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0375dda4	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x15b98634	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x18bf58cd	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x1ce690b3	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x26d7ba7a	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3a73d462	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4dc7f48e	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x71a90343	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x9d8f5b62	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xad327f84	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xaf2676aa	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb8e21abb	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xbf6eedab	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc3e74b73	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc408f035	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe11e659c	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe5929b21	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe8da8d39	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe91e4041	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xeb300433	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf30e5062	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf99f770a	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xfdb32683	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x09357be8	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x10340390	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x872be618	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xacce3285	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xaf61b4dc	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xfb318bb5	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x6fcb008e	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0xec402f83	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x980dbf75	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0xbd5f9ce9	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x0cf9efe4	drm_display_mode_from_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x1b6823d5	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x30f0898b	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x32233f52	of_get_drm_display_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x76688a97	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x949dde54	drm_display_mode_to_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x08e76213	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x3f9fc0e0	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xe4008b5f	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x08503d48	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0e1d1631	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0eaa725b	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x12574785	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x1e293403	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x23a554f1	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x33d64347	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x34ad1489	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x355ffcaa	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x370c974e	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3be3418a	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4522b8c2	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5d404c95	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6041410a	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x656f1060	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7ab9d9f3	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7ac0ecc2	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7bef26ec	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x809ec55d	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x86149347	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9a9ff668	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa056a4b0	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa07dc58f	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xaf242e90	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb914489d	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbe7b9da5	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xcd04b230	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd144c309	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd3debd5c	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd426091c	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xdc59c70d	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xdcfc4a16	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe1510b2f	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe33eee93	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf5421a37	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfcd73700	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0xbbd70d78	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x0279de88	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x19289247	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x2674adb8	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x4f3d8e38	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x97690bd3	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xedda06bf	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x1f2918b5	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x38b34abf	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x5cdfa639	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x770bb8a6	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x7cef0865	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x9170f50e	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x985e0597	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xd5c69ab3	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xebe75918	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0xd9c09739	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x011297d5	hsi_add_clients_from_dt
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x0750b7c0	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x2a5cb9a8	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x3f30238c	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x4e939faf	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x53bb0fab	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x6d6ee2b2	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x82700542	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x8a0bff8d	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x97692b19	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa8c6438a	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xb490ffef	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xdbba3c7b	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xdf5958b0	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe22ae675	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf2827193	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf8197809	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xff0eeae3	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x13b6114f	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x4323667c	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xd674fc4e	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x0be8e981	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x199a504d	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x40a7e915	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x429ff488	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x47168c74	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x5d0885c2	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x5d22fe62	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x643b3403	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x68e845f8	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x6fa17129	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x73e2531d	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x92360805	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xabeb7a3e	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xfbd0d91b	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xffee8e78	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x19737b97	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x1bc40a14	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x1be77730	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x20e52b62	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x274de624	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xceadbd57	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xe0fb4ee9	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x1c621af4	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x5bc3c549	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x614ba40f	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x65511e48	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x6eb41898	stm_source_write
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x16b317d9	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x51c350ce	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x651bd56a	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x7bd79680	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x7cfcd248	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x67ae6069	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x8d534762	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xbfa8df1c	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xf23ad893	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x32ca515e	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xbe38147e	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xcafad2a5	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x1cff40b0	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x460bcd1c	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x58632c3d	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x5deca9d8	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x6c18cdcf	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x781d3ca8	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x9f6634d3	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xaaf98c3c	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xc12132b1	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xcdd07951	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x39ce5670	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x40e77aa3	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0x32d2cd3e	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0x69ca3398	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x0c386e22	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xb04db85b	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xedb24d04	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x00218d1c	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x09dd63c9	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x18f94008	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x1d555fc6	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x26268e10	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x43405689	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x734fa13a	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x7b9afda9	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xa48c18d5	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xab50d643	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xabfe0c28	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xf740438e	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x10a423b0	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x200adb47	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2097363d	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x270104c5	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2e97fbd8	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3054230d	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3c3c4781	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5d02cc58	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x63841f9a	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x66e0e9ad	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6a45e4b9	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x760efae5	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7e837fc8	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x828e2b65	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x92132cc3	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9a5364f0	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9a684ac7	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa2e5a357	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa3a822e5	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb7825764	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb97efb0c	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb9a23899	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc1607ba3	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc8defea2	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd32e8205	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd8bf7a2a	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe92f7d07	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xeca6e5d5	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf68a4e12	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf698b87c	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xfdeb58f4	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0xc3ba6857	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/matrix-keymap 0xd1542659	matrix_keypad_parse_of_params
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xf6dc002d	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x40ce8049	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xa7f80dca	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xc86eff5b	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x3d87841a	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x7e829bb8	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xf444da0a	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x1b41e62d	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x43b5abc5	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x1b3cee8b	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x55307dcb	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xa7650d38	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xcd2a6493	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x35452fc0	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x391f5367	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x46008126	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x503ed726	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x54ae544b	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x59d813a5	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xae23cb9f	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xbac5aa2a	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xc05ae210	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xdff742ea	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xe4513204	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xf9ef2f5e	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x33c099c0	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x3aee451c	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x4b711eba	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x716749de	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x71d29441	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x82a3b4cf	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xb5120734	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xd0f83431	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xdc5c66a9	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x0d36d599	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x11d91fee	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x255719a7	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x383f000b	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x3c47d677	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x4336d84b	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x50b76fc8	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x55bc9f47	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x55f93e76	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x723a390d	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x747f7c7a	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x84e2fe0c	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8eff32df	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xb6be3c23	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xbaf0a5c8	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc0664d41	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xcdf449b0	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xf27c3e6d	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x26120482	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x2968cedf	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x58058af9	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x87a3698c	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xb5b32e46	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xf6b1ab3f	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x1abd8d19	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x1bd2c97e	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x215b0e46	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x43a7f197	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x55e1bf14	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x607bbc12	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x6192a036	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x67a7bd5c	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xa5d29e49	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xa6461f32	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xdc8acf35	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x0a0527be	wf_register_client
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x10c761ca	wf_register_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x2152110b	wf_register_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x4aebf0b8	wf_unregister_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x6b1c0de7	wf_get_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x75147afa	wf_set_overtemp
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x7b4a423d	wf_get_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x8bb57348	wf_put_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xbcace2a5	wf_unregister_client
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xbd3ae11b	wf_unregister_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xed82a14f	wf_clear_overtemp
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xfdc63fc0	wf_put_control
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x0452e3bc	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x1c840e50	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x269b5809	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x5d38e33c	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x74c0dd1a	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x9779a00e	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x996ce9d8	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xa348c294	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xac5aec61	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xd3850c73	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xeafdf8ee	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xef18d013	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xf9cca8f3	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xfd9301d4	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x00b74659	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2a1a7a99	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x374f45ea	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3a4dfef7	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x48991e9c	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4f124797	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x614e860f	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x647af374	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6724de29	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6726a0c1	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x68f1ea6d	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7114cfcc	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x78c57fa5	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7cb4bd6f	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x816ebfe0	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x833b99dd	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8afe3e2b	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x912566ef	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x92c55e92	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x9c59320b	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa7004101	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xaf2376ac	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb3942afe	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb4cffcbb	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb9c28744	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc0bd3171	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc773563c	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd81ad8c9	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe30b6b2a	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf6169c53	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfcb52b5f	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x1ba8650f	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2a34e2f7	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x32895b99	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x4bcb9e42	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6341a215	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x673a770d	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x7884fa39	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xa84a15fb	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xd9c274a0	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x22163b69	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x3909d3a8	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x594952bd	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x62a23587	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9b2b253a	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xdc69e37a	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe004ee92	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xf1a6a385	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x32db2089	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x486fa597	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x6c521fb8	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xc4d999ea	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xc54f8594	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xecd1ea5a	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xf693022a	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x1416b3a2	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x91d15b57	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x09472122	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x13f5cf07	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x48370dc1	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x697fa190	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa8813ad6	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc2965224	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc66ce277	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc9db99de	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xcab63c3d	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xef20a37f	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf37a3cfe	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x11eab9fe	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x150c85ce	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2e730a21	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x33c03da6	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x619701dc	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x78454bd4	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9b4b5b29	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa2507774	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbcfdc290	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbe0497aa	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xead1e727	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x18d5b35d	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x23c2a740	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x41fcebec	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x69f17e5b	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x6c58e1da	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x6d5cf2b0	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x713ddf0a	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xbbe71b80	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xbf501089	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xd75b6761	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x36892e07	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x4bcc9791	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x534a8814	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x585b098e	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xa0ada185	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xa65de06b	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xe4eefd9d	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x11e4a3b4	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x13539a36	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x13fe706f	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x195c31d8	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x43f7f3e6	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x471662f0	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x4d32e5a7	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x5c7a7562	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x5edd1c6c	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x63222b29	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x6b02daae	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x70a158c4	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x8ac5bb8a	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xa3b1a9c6	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xca3055a4	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xd2f5c425	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xdda7a156	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xf3b25bf2	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0xd86c0bdd	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0xf7fb7132	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0x6256d951	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x0e13452f	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/media 0x30c36462	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x3d41cf44	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x45c33e2a	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x56a6a69a	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x5705ee1d	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x5927f7a3	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0x5fca9acb	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x65535a4c	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/media 0x66441e0e	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x6cecbc00	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/media 0x713d93e8	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0x78bb7bfb	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x7fdf237d	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0xd1e90f29	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0xea1885aa	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0xeff7b885	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0xf4ad46ad	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0x35395907	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x0eb05e9c	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x155aa6ea	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x199695f4	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x1c66f84c	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x24bf5396	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x2623400c	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x31569230	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x4ff08210	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x5ecbfeac	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x98d8e9d3	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x9f431298	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb2a9ae60	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xc07b6521	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xc4479aff	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xc4aef5e0	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xcdde3dd4	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd1f13c97	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xe51e3a10	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf0f7fbb6	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x03deec89	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x174f83f6	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x41ac522c	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x480a2b69	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x6956e2ef	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x73447918	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x73bf8fe9	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x8f275be8	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x991da1b0	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x9eec518a	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa3c7b543	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa6168ceb	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xb10fe57c	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xb46ab54e	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xb4e3f9a0	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xbba56120	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc5335c02	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc60c074c	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xee3aa9cf	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x02a17910	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x041b5044	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x1295130e	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x1b9dd816	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7d687451	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xd95d05f4	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xee846836	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x0b2585ce	xvip_get_format_by_fourcc
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x33b46c09	xvip_enum_mbus_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x3c7eb685	xvip_set_format_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x490bd11c	xvip_get_format_by_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x4be7dcc7	xvip_cleanup_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x91288c2c	xvip_enum_frame_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xadcbec8f	xvip_clr_and_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xb0b97a94	xvip_clr_or_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xbc4bc80f	xvip_of_get_format
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xe47e5623	xvip_init_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x3c16a6b1	xvtc_generator_stop
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x47d7900b	xvtc_generator_start
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0xa8a0f912	xvtc_put
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0xaa9e8cc1	xvtc_of_get
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x7a670a86	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0xb36cfe5f	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x03dc6149	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x071dcfb0	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x267d6ae8	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x32e4b433	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x5029e5cc	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x55156d72	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x5fe6ca33	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x83da00f8	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x8d2a08a3	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9618d7a0	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x962d6cbb	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa3c775fc	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa748657c	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa8c3d59a	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xba90f0b0	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc60e2e9e	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xd43b6fad	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xd67d2801	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xfbeb9c71	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0x1554f98b	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0xac5d4518	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0xd4d1201e	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0x9dc09985	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0xeec1c928	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x8adf71a4	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x7b7cc7f7	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xc4ab1357	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x0d7e8a17	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x244c6534	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x883c279a	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x61b28dc4	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xb1f51497	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0xa90a243e	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x15843588	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x1a17a4ad	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x1c86f7f7	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x2157090d	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x4b608e27	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x4bd8f7d6	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x73c552ec	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x7d98f818	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x93673796	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x94fa09ea	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x9770486c	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa32b9eb1	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa8b35dd3	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xb4262bb7	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xb51e64b5	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xcf9e1449	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd3935bcf	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd8721572	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe73ab82e	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf79dc2f6	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0xd6066d6b	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x5abce24f	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x01f364c7	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x08ff0bfb	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2d8a6a3c	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2db39ff8	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x353718b9	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3edb82eb	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x54cd05b3	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x55aaae9b	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7d1ac969	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x939d1be0	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9851c178	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9a592559	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xaec44801	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xbb920c4e	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xd0bb2f8a	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xdf0ac43f	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xe641725f	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xea799805	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x25d0098d	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x702857ba	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x7f719916	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x9be4aa5c	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x0b982264	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x41c7ed49	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x45cf0daf	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x8d26fdd3	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xa4cc829e	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xe96cea29	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x0dd49bc8	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x300c2e6d	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x01d14044	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x04c1848b	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x0a47fb0b	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x0aa6c32f	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x2fd107d8	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x471e68e2	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x474deed5	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x4c899bec	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x5900c4c4	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x607c6964	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6c9e4b8d	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x756f8a51	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7a175345	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x92585b23	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9e86dbf0	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xa58b7430	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xa6cec68c	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xaf4735a8	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb2c9132f	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb84c0a32	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xbbdf23ee	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc73e9113	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xcc7492d1	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xdfbd8b63	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe2a27930	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe707eeac	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf1cafb9a	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x011992ee	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x0b2f9143	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x0e3df072	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x1f6d229f	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x297e8cbd	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x33db3e8b	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3eea63c2	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x47fb66df	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4b44afff	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6611a7e5	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x832a4d2e	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x96fdbf8c	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xaad89471	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb1baa381	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xbd5dc058	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xbe90cd0a	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xc582a78c	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xca39c16a	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xd7604770	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe2364c9b	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe2983b14	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xec28da21	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf483bbbb	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfe8e31a2	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x4afa44e0	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x513744f3	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xa825c75b	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xc52c828e	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xfb89e643	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x94cbc716	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xa773aacb	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xf20b4fe4	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x23a7b599	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x251d3f1d	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2e1ce797	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x506cb43e	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x50e4a26b	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x53c1eafd	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x640032e0	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x6d528783	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x85669784	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x881cccbf	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8dbe1835	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x9cc4fa1c	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xa231471e	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xa953b8a1	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xbcccc7f6	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf4b1626b	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfaef9701	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfe633ada	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x09bff1cd	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x98daeb1d	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xe1b8f167	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xee070d1a	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0xf2fccfde	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0180ec58	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x05ddfd6e	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x145ca2bc	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1566c670	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x18610084	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x2bca2756	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3749cdba	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3a65fd29	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x4593601f	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x51240b85	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x553c1a07	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x55af66a0	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x6160cf9d	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x64cbe522	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x87ca1334	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x89d2a826	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8e830f67	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8eca5447	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x9b92903c	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x9fcb4dcd	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa0929c81	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa78e7ee4	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa89a7ae1	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb535af89	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb5a639db	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb5fb2033	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc7b48cc5	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xcb058d2e	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xd9c04d94	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xe3b62269	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xeb2091a9	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf54cade4	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x8451844a	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x085c1c98	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0af88a22	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0c7e10a9	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x18f08ec0	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x23fb985d	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x28d20b15	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x31e3d76e	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x331300ea	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3740e82b	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3a645829	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x46a85850	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4904ee1d	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4e8eafe5	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5d9aede2	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x66773d89	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x69bd7eb9	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x70479ab0	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7a85f5d7	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x81bd05ed	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x81f6dafa	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8b5c2e70	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8fa601e9	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x940bdfff	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x96871533	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x98545b10	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9c6f7aea	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb0f3d5c6	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xba926b3d	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc06061bb	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd29bb589	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd2a8ae26	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd3588160	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xde633a51	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xed18bcab	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf3fb60bc	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf5956f8c	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x06ddeb9f	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x7566d898	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xbb5be15f	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x0332a9bb	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x13641be9	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x69ccb100	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x7e69fe78	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x89f7e02e	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xefa45da0	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xfab85508	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x0b6b6782	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x19691dbc	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x3a387dff	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x7441ab50	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x75e62241	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xafdd6943	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xc0b38c0a	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xf92cb420	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x086dc77c	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x6421edff	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x7d48a7bc	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x2f9740c9	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x38faa8aa	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x462c42c2	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x547225ac	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x6e477171	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xb444c932	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xd6a454a5	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x4c54335b	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x6665911f	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xdd7b09ae	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x19d1d691	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x3a3b7f88	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x4b6468d9	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x596b9db1	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x64808343	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x7db348b0	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x010f38ee	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x09d967f8	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x1464e2a8	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x16728cef	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x19d1b210	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x4c8780b3	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x877f7cd6	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xd4e40620	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xd59afb92	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xe53f7674	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xfc476a9c	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x36e6f727	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xd8bf8b2e	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x26ab3b5b	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x2cd2342d	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x84978e95	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xbecbb34c	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xddf9eb38	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x00954581	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x014b8150	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0874f44d	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x219f8b05	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x2cae5a2c	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3189df55	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x42814799	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x43d9d3c5	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x47eb807d	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x58ad9b38	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x6782325a	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x871745ad	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9a4852b7	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9ce6c0b2	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa536fede	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa8cd3103	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xaab129fb	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xc3899667	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd1288f24	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd51c745c	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe102a99e	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe80fac21	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf25f7819	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xfdf28398	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x02b02598	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x07a2c29b	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x2370d90b	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x35f50c41	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x4ed7af25	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x7da7145d	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x8508d4a7	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x927d406a	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x9a5322c2	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xb09ea690	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xdab68a99	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xdc8ab3e1	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xf8b442ed	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0777595e	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0d73ee9b	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1a0eb146	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x26e2020d	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x30464c27	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3a95e204	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4393b4a5	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4575057d	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4ab0751d	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4e15f45f	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x638b1905	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x63c9d5a5	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x69a65822	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6b076690	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x769b5a1f	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x791e90ff	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7c5ba49d	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x858e6723	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8977715a	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8c224917	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8df5f247	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x952f1d3f	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9885c57b	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x99936d7d	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xab7e1bc1	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xade50289	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc49419ae	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc6a8418c	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xcf630d94	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xdc1183fa	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe8326c05	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xeb5a3b91	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf854e993	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf94ea851	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x1072b2a8	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xaf088064	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xbaceece2	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xc7d0d7c1	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xddb71ff1	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x12e8f107	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x380f4de5	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xc6506a80	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xd84935d1	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x2838ca8e	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x323d216f	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x54b448a5	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x804cc5dd	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0x3163deef	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x2c02b395	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x41331870	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x7d0f0bb8	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xedba502c	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x161e7a49	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x3f503f28	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x6f2ef379	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xc700ee77	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x1ce45262	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x509a04c5	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x75e13a81	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x95f8e0aa	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xaa814461	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xaf1a786f	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xb7ece333	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xcd3e3ba4	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x13d80795	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x218ddbcf	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x5993f8c9	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x59ab7efb	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x7ee8a115	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xc7bc272a	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xca9f1536	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xe7a41568	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x81df6421	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xcd6e377b	st_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x07279a8d	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x0be00793	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x1e9de02a	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x4074f1ba	sdhci_send_command
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x49cf1138	sdhci_set_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x5c2969b3	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x601310b4	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x972e47b9	sdhci_reset
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xab70dac9	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xb0711196	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xbc0621b7	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xbc5b2ecb	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xcd46fc02	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe6a5796c	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x05c0878d	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x0f93e9f5	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x1c1d1ea1	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x4088b156	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x80d10c80	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x8b17233a	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xa39dad81	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xca234813	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xce815b24	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x520f16a6	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x6d26334e	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xaf113330	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x33c9cf82	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x4d9b8452	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xbe624bd4	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0xdc5ce2d5	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xa7493283	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xe07a4325	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xf184b38e	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0c8a897f	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0e794551	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0fc1724a	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1163b42f	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1a687848	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1e542d38	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x352d322e	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x37a015ca	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4abba11d	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4c49e28d	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x67d60c10	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x72aa5cbc	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x75b8bc50	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7b1f1d2e	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7b40ade3	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8098db45	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x88dab013	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9468ee37	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x964a4b89	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9bad3e98	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9f3aae1f	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa2517eef	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xaa443fb8	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xaa8cc6f8	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xae1c5d7a	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb25719c6	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb661598f	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xbf0fd402	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc86557f2	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xce8d9740	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd3c16738	mtd_block_isreserved
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd7ee16d7	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xdb00bacd	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe0461755	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe04c1437	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe5e67acc	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe9d0f31b	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xec406d3c	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xeea53334	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf64d3c28	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfaa4b784	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfd4a8bbf	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x85827759	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xa1556526	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xa2b92b4d	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xaf4a68e4	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xfc6ced64	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x5a3f2034	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0xb7769a7e	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0xf8f88b56	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x5d824ccb	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x8b371f89	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0xfbef9212	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x0de8edda	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x1d14ae75	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x263a66b4	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x58205b52	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x61a6e5ee	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x64d938c0	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8e4da05f	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x922151eb	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x9f5a03ea	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xa5f92b0f	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xccd7d58b	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xdf177a31	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xefc1b491	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ad3d37	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xad5e7664	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xb693e0d9	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x2e2d0b95	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x44da817a	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x50c833a9	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x6214209c	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x81fad2d9	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xda02f872	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x0e4ddbe6	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x1d714edb	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3300c163	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3c33bcd4	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3f852d27	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x48a546be	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x51a224a3	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x58a4c7d3	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x5d8bbc79	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x643b6415	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x6473a75f	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x69eed595	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb266e726	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb43a1860	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb8f092aa	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc0097a8e	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xf17a3d78	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xfd54d1fc	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x69cdbacc	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x6dcb1696	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x8d1ab52e	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xe97e0576	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x13e94d78	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x810233ff	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x8cdd1363	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xc9297bff	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0x0fd3d199	arc_emac_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0xbed1595d	arc_emac_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x000ec23c	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x03fd34be	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x07971949	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x09d7ee2d	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0c05762c	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0e416baf	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1057d907	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x12d8f5af	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x17c66cc0	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x19a062cc	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1b473186	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x22abd6be	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2399c29a	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x249830cb	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x27e3f2f4	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2f0316f4	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2f3c5828	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2fca1b54	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x30604a50	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3150ef54	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x31fc7dcf	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3396dbd1	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x33afcadc	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x34953ded	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x44ca3eff	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x45aae56e	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x45fdf3b8	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4682138b	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4730f67e	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x49e5ef24	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4a08e89b	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4b2b5009	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4c190c2d	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4ce8f9f7	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4da2077c	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4e2d3f1d	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x51f3f3ba	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x527d4020	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5324dc85	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x53587230	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x55b760b7	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x58cc0438	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x58e29334	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5a46c9cb	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5d788536	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5ea44986	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5f00a96b	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x610b288b	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x61348a3e	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x61584235	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6179954c	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x63f1aa96	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6ada5973	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6efaf7f4	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6fa99dae	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x727132d7	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x72b8d88e	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7522891f	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x76bdef61	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7a82863a	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7b4d4837	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7c0916cf	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7c2c79f9	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7d4187ed	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7e1ffafe	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7ff6c33c	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8e310ed7	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8f6eff4c	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x92a247fe	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9504d737	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x96740324	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x96e72410	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9c0da571	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9cbbd227	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9dec050c	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9e4729cf	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9f229b74	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa89cb0df	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa92238fd	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaa6ba908	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaa757f01	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xacc69aa4	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xad548a98	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaff0637a	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb2fddd68	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb68eaccc	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb7be82f2	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb8a94636	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb96e1c5d	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb844b03	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbd1d13d0	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbe0e5227	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbea237eb	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc1ed82ce	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc301c03b	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc3b0d0bf	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc8deea89	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xce0e3790	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcea8f095	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcf014248	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcfac5ad8	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcff9b67d	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd2bf29bb	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd409f961	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd56d1bbc	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd5eb7c37	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd640455e	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd8d206a3	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd9564178	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd97cdf40	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdb763086	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xde4c9fb6	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe24ed9a7	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe30b84cb	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe62c315a	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe78f802b	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe84d8a48	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xecc6a625	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf2a51c23	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf717c2a1	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf7dc743c	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfbc176da	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfc9d1383	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfdc4bafd	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0861073b	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0d465118	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x10a84e76	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x14b0e809	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1d6167e2	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x24870034	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x24e15268	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x28e81e36	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x394b98c3	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x39bbdb8e	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3af4dad9	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3c1660d5	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x41678b4f	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x52262e0b	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x53b6b8d0	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5ca19971	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5d7bdb4c	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x62810d4a	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7e0e0b35	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x856e51e6	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8ad655f2	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x901c1dc4	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9073fd0e	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x916aba47	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x977a4d2f	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa3b9d5fd	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa49108a1	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xacf01131	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xae9ca9e0	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb4b03c33	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb5a5c323	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb6e42315	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb78011fa	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc1bb4f45	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc4a9f873	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc5939f76	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc655a2e7	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd5d09cea	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xda12d423	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xda35e14d	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe05c1ba0	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe593330c	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xec3c0ae1	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xece72018	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xef280389	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfd1ca6c4	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x368d3d71	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x958c3e15	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xd4ab3625	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x1c3ba199	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x5fe956a1	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x9a716c39	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xdf38b048	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x5d4dcb36	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xaa426b91	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xf8539d12	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xf8c16bcb	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x0bc79b4a	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x173af516	cpsw_ale_dump
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x3ca5e168	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x42688ede	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x455cced7	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x56c1fd35	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x68df89f7	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x72265047	cpsw_ale_add_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x85d05df3	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x880303a9	cpsw_ale_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xb95f5200	cpsw_ale_start
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xbf9f1820	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xc6c8ba5f	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xcd0f81fb	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xef93e1ee	cpsw_ale_stop
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x7fe28661	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x8db3a01a	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x5189eb47	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x72c17ac1	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xa3d739e5	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xab5c2c85	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0x0832864a	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x097cab94	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x119bb1e5	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x207bf708	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x25bbd623	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x86b84165	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x9d5aef04	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xaf601a76	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xbf8f505a	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xdcdaf572	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xdf54733a	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x3ecc86a5	mdio_mux_init
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x6318757f	mdio_mux_uninit
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x1b2515ef	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x2baea590	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x423f3e96	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xe3538e89	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x23ca447e	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x399e2f2a	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x4400c1ee	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x6382bae2	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x9a4910b2	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xbb3993bd	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xbed10b2b	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xc685ce7f	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xfce9a804	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x17fc5b58	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x316536a7	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x5db55dfe	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x6e15a81e	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xdf6a41cd	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xeab2bba9	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0215d67c	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0629058c	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x088d260d	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1a3d8489	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x20a9805e	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x21ec0505	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x23bd9fa1	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2c3917b7	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2f77a60e	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2fcaf390	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3b960033	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3e0199ec	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4243625c	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x42f6d46f	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4cfe5ee9	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x5679e978	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6c84eeb4	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x798a31de	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8af8054c	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8daa529e	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x96c83ce3	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9f88fbd5	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa9e77981	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb6bfee97	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc05cfa28	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc5d7052a	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc6cf7456	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xced5b9ad	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe0e89082	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xeda0292c	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf5a3f453	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xff716430	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x2160af92	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x69927418	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x0191a769	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1979d4cc	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1a975b66	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1e7f9d54	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x234477c5	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x24febf7d	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x591c94ba	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x6486e12e	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x6bee9a10	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x701a603c	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x75e33084	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x7a71600d	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x9bcb8d5c	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa34b58a6	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb0eec953	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xc56b5a3c	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x636cbdeb	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x7e69f091	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x8b024d85	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xa5f2d784	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0x3ed34b84	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x6abab4f2	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x8472a204	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x9450aa96	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x9f704c79	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xc065e4bf	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x002b2e74	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0d556623	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0f48dcb7	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x12041151	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x124749c7	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x2c6d2f40	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x2f0d07fa	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x2f330453	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x3c74af6a	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x4afce436	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x6ceb625c	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x6dd123cf	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x6f4ed91c	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x6fd351ae	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x74c5d47a	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8a2a2f1a	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8becbf89	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x906cfabf	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc60bebe0	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc67c31ed	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xcab3282f	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xcb6589e0	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xcc90708a	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd9357464	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe0d3442b	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf5aea4a7	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf68b9cce	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf8298821	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf948354a	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf95c2483	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf97bdf2d	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x0185f941	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x05321494	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x09999117	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x0bc53546	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x1e7e2b1f	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x2bcdb2e6	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x312b72a4	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x646cab76	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x971890d1	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa42d386b	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xb10fd90b	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xc403ce48	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xce9e2568	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd8292634	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xee4bad34	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf91e87a5	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x015b54ec	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x02ed11d4	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x1efff6d3	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x2c056d51	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x792a7a81	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x95bb0e87	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xda1a19d3	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xe5d617c5	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x14eabb38	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2cffa12c	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x34217b4b	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x35c60589	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x3bbc1c7d	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x3c0f3113	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x72dc2b38	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x8a221ed1	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x8c392a91	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb57159d7	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb5ee8cf2	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc1b89d60	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xd2c8f526	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xd5c3a0a2	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xdfcec450	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xe0232809	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xe2ba7dc0	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xeeece196	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xfe7a110c	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x20ca8740	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x36dbd93f	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x39a74518	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x4cf53106	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x4d6cf3c1	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x63d6ec33	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x71793d34	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xb2b9841c	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xe84771a0	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1cc2b02c	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x351e59f9	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x74ab97f9	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd536029d	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x06bbf6b9	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x077cf7ea	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x19fe8871	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x20280c60	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x2f0c1a7a	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x330ca159	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x332e5a26	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x384f38aa	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x39f624de	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x540b14d0	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x60bda7c4	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6154b8b7	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x665f8db9	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6b5d7dcd	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x704a8f9e	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x734b64bc	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x764131ee	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7db527b1	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x8f0cea04	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x9c6c3a24	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xbca880dd	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xbe2af881	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd8729a05	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xec8a6491	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf27a4fb2	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf7acff2d	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xfcab938f	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x03a01d5b	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0c9bd796	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0d0b6636	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x108829e7	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x43225389	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4b2b7677	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4be60c4b	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4e5b4a4a	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x643d26c8	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x677268d3	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x72b251e0	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x818233e8	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8922cad1	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8ef92c0a	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x959d501b	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x99373873	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xadc3c2ba	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb2dafab8	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbdc02683	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe6838f3e	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf8ff6add	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x14db75ba	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x16fa507b	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x23d5372d	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xf83d8c93	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x02f33992	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0a5cce2c	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1364f660	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x14d7914c	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1745d635	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1ac89d12	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x260f6c47	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x31074dba	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x32984656	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3b33e790	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x41f1f55a	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4441fd04	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x56f36de8	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5f99cbfa	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x658f6643	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6b05a77b	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7d0943a2	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7e669156	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7f0e75ca	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8cdf7450	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x98e14fd0	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x9cd7e74c	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa907fdea	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa9d86ecb	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb178410e	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb75ca269	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb82c94a2	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xbb7f6056	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc7907370	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcf103a44	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xda68d08f	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe256642e	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe82e107c	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe9013640	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf3b50ee9	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf6bbf978	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf97203a2	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xfda9d92d	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x02ccd828	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x16234a6d	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x1bbdbe03	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x26c61a20	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x3b02c42f	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x7e163872	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x8b632754	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x8e40a739	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xd96aecba	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe156677a	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xeac66a7e	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xf0a79821	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xfd4a5fc2	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x033d9f28	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x05dd4a5a	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0733a7ee	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0c2731e3	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1785d100	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1dd539f1	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1ef38a18	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1f092bd8	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x28d82a31	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2abff4f7	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2df6e7f5	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2f294204	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x349d32d8	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x359ad914	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x36aefed7	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x43a19249	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x44fab946	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4c2ce4b7	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4c3d97b0	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x52b971fa	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x54d540d8	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5a5e1eda	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5ab35ab4	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5fc87429	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x60098d49	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x66837830	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6734d08c	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6ac8cba5	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6e4ebe10	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6fb78a4e	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x71a3250c	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x741521ab	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x77446da1	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7b473c29	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7bbc15a3	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8bdec5c6	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x973e4a83	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x99b1951f	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9bd6e3f5	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xaa307add	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc0fd85b0	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd71216c7	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd7aeb16d	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf6b9139e	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf6e624f2	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfe2eb6a8	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x05267edb	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x3940cbfe	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x3ac4e736	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x4a4de4bd	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x4ff36d6d	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x0b538954	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x5349e8fb	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x551215e2	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xacf822c2	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x16593a1d	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x339aa22f	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x377246b7	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x3b9f266a	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x44db37d7	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x67bdd632	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6f2c787b	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x7183abcf	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x72cb7e2e	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x8b13d474	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xba3c4de0	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xbab95c8b	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xd62e92db	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe398f030	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xf6bbf6b6	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xf78ec26c	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x0bf06243	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xbceeb66a	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xf52ca801	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x00c3e22d	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x091c2f68	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0fc7d65d	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x12ea7173	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x142b99b1	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x194bf52b	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1acf673a	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x278c24e3	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x31b1cea8	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x36c0775a	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4274b670	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x443463c6	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4871122c	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4efd1a40	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4f1e38ec	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5e1507a4	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x67a6bcfe	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x67eb877a	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6df6f340	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x75eb301d	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7bd9ed00	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7c95439c	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x81e6f583	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8552fbd8	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x86461f16	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x89abff22	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8eeeb844	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x91c8f183	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x91da5146	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x96d2e92e	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x970f4f42	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa0cc2aef	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa8142f82	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb2ddb151	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb3ca7265	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb8cddd86	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbe57681b	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc3d03c2c	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd12478f5	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd2622a88	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd327824f	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd7ddcbcf	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe62f3f85	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe93244ab	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfe74a64c	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x4f0290d9	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x897c9b53	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x9bdcb8ae	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xc5713955	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x03777999	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x20a51be6	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x3e2b1a00	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x742d502f	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x8d3e3083	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x9ae24bee	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xadcb6d79	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xd91eb59a	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x094a1832	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x7e9224c5	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xcd19b5a1	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x03ab4c92	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x0a531db5	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x0de5bd06	of_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x36ec8a8a	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x68758fda	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xb1e962a1	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xbf0f9caf	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc2edb3f1	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc96fb674	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xd9788966	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe18960ba	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe250f913	of_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe9a7fe16	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x191d027d	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x52891427	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x7990163f	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x15d534df	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x82ab4b58	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xa0dafac4	mc13xxx_get_num_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xbcc54d48	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xf000f095	mc13xxx_parse_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x66a73efe	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x6f72a5c5	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x7dc4df33	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xbc581c42	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xea801e27	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xeb4d79ff	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0x7d786b7f	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x064de1f4	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x07373bf8	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0990942e	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0b92d58f	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0f5069b1	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x14fc09a4	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x18bddc62	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1a2e17fc	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x251734aa	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2c848e0d	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2cecfc89	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x47be2b48	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x58d1b3f2	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5aff0a49	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5bd38613	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6d1b3429	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6e79a8f3	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7411e7ae	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x78fc11fa	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x79d91d9b	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7e5b8813	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x84e14953	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x873d72df	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8f6dde16	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x93559fd7	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x96930c64	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9873dde5	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9c8a1ab6	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa534d243	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xaf3c35de	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb8d2b4d6	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbe2af7c6	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc0421953	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc4f41321	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd1a0593b	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd1a8f127	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe2ebe416	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe4420853	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe618223e	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xea7f7c7f	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xed5ae9cc	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf0f02096	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf2e4dbb4	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf42bdf10	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf5906d36	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf7d8c6f7	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x098e1741	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0cd485a2	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x19339eb4	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x25878177	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x51c60b11	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x76b6ad55	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x9c91a085	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x9cddedbc	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x9f9f02c5	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa4f7a07d	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa5ca2e09	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb6e482c0	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xd40ce817	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xe032d0c0	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xe0fdf14a	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xe895b9ba	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x344c8bab	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x836aa08a	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x920e74aa	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xa05431be	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xc2de42f0	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xe16847c4	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x064aed01	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0844ef28	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0b120d76	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x13a79b91	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1849d960	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1cb50b25	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1e153fdb	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1eb64bac	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x22ffe130	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2472af16	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x26ba718a	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x29d9394c	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2a4fa0ff	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4a40f765	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4d0030e9	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5b7fffbe	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5f7a3df7	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6266f014	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6b8eed41	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7308b41d	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7bda81f8	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7e314df4	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7e7f00a7	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x837c3fae	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x95c62dae	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9b29d25b	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa912598d	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa963ae8b	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb3e465d7	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbe63a9fd	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc40a784d	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc749c1d3	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd93cb5bd	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xdd969687	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe0fd8c00	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xeda97498	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xee1f07a5	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xefdec00b	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf56d9458	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf8ae992f	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfd88cc76	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfe2a5013	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x10ff2d63	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x213f6975	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x21febd66	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x3ee2cdc5	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x55f6939c	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x64da90f2	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x65b8ba1d	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x7ddec794	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x88e2d1f8	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x9288e31a	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x93576a56	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x96d3c4b5	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x97745fa7	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xace3dfd9	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xc81ffa99	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xdaa5c0b6	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xebdbb6d1	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x068276ce	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x126b9da8	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2077d00f	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2681fca0	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2a199086	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x43833d78	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x51a922e2	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5533218a	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x64c2db0d	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x70f7b085	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x73e5ff60	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x85adc840	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8c283423	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x91e84830	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9a530847	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xc11f5d50	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xca5b9358	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xd112fe2d	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xd89da89b	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf0bf6d95	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf2d55375	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf97cf2f5	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xff0903c4	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xff4c9ea0	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0a411d40	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1ac47883	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1b434743	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x209caa2e	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x26718e8c	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x335796cc	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3437adb5	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x38aaade4	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3c04a53e	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3c7eabe5	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x46f178e8	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4bbd05a3	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x518534c2	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x551d63fd	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6175f734	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x61ee519a	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6ab9df5b	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x750158e8	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7fc4a3f0	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8098b8a7	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x890afbda	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x94251b70	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x969cfd1c	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x97e1d7b4	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa406be6b	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa90a0f28	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xac54fcea	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb03a8785	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc32c7fff	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc7ac9736	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xcdfef018	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd19dc58c	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd2b83af1	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd4cc858d	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd88946af	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd8a690fe	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe2880ba0	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf037b4cb	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf154abfc	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfc72c79a	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x235e81c7	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x6163aa45	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x79b462f1	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xc6ad232a	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x8023a4c1	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x1e9a128e	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x31cf3d08	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x5ad43bff	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x5fadbc11	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x68b90a7f	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xcaee7948	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x02c6d7c6	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x284095bd	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x2bcc7f02	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x7756d0cc	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x8aa55a02	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xb543ae32	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xd2fd41a2	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x54be2775	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x598fd56b	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x6d112429	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x841fa279	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xd88782f3	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xdf203e22	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xf8e783e9	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x1c10b7f1	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x252a24e0	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x32279ed4	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x69e96c53	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xfd1f299f	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x44c2da04	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x53615356	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x99cef505	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xaad9f751	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x039bd53f	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x502dd9e2	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x5233c406	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x57a203a4	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x5a38d2d8	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x64872558	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x6ff4b9b1	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x7a0db7ac	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8db5b787	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x9f0b3c1c	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xadb4a812	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xb385f52f	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xc39ab384	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xc96c4552	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xcf19d19c	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xd02d28a1	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xea5869be	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xf51ea89e	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0xef169ef5	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0d69fef9	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x160ff058	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x39abfc37	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3a98892c	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x42eca2f5	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x47b3d001	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x50c875b0	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x596c930c	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x64d06d73	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x68ba1340	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x86bdb591	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8a617452	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x965a577a	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9f9005b3	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa4b9dda3	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xaacb7d89	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xabdb406f	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb3faf9ba	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb59a70ff	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb797a884	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb921e101	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb63acb1	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbc7f3d4f	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc3b913bb	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc5368726	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd10b5552	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd33f46db	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd621825d	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe027480f	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe03a26d8	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xee4c9758	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xee6c48ac	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf0d8c7c9	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf282bfdd	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf61cbc04	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x20617869	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x2def1c17	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x3cb89bb8	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xbd54010d	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xcd35a458	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xe66bd7d1	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xea3d3838	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xfe84c779	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x151f3de1	comedi_pcmcia_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x335e374c	comedi_pcmcia_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x562ac7ce	comedi_to_pcmcia_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x893f6247	comedi_pcmcia_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x949dd347	comedi_pcmcia_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xb2bac4f2	comedi_pcmcia_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xcbf03014	comedi_pcmcia_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x19c53329	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x2d8478c8	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xcb63588f	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xddc073a1	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xfbdcd99e	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xffe4f667	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0xf22784da	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x0b97ae95	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x568de563	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0xe9715967	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x0102e65d	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x07e8996a	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x10c0a52d	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x272f5147	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x2c4e6305	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x2ef19fbe	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x46cb71d5	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x6bf6d319	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x76933dc3	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x7ef64a85	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x91b13d0a	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xa82bfc32	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xecd60650	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x8957615d	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x9900bddf	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xa7aa7862	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x0ab7ffd8	comedi_isadma_poll
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x12fba874	comedi_isadma_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x3789f086	comedi_isadma_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x4a17474e	comedi_isadma_disable_on_sample
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x7040990c	comedi_isadma_program
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x7a458207	comedi_isadma_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa228e27e	comedi_isadma_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0xed7117b5	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x0025f9b7	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x0a4b8d37	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x24169c6b	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x242c1b86	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x27328a5f	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x45a51804	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6c770f96	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x868e110a	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x985c7abb	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x9ebf9705	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x9f19dbde	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xbeaa744e	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xbed16d24	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc209a05b	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc442bf5a	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc9dda3fa	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd32a3f20	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xdeb52380	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xef65ef28	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf44b06e9	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf8c71c6d	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x5ac81757	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0xe5662149	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x5a445af7	labpc_setup_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x7baa7df7	labpc_free_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x87d1ec7b	labpc_init_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x8dfdfd45	labpc_drain_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x94df3c42	labpc_handle_dma_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x0a5b03ef	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x35348ba4	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x656142a7	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x8156c048	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xaa49eef6	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xab4f47ae	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xb39fd175	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xcaa20d7e	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x24389c58	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x2d2b87b5	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x40f88e2c	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x9ae8685d	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xa4cf75a7	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xd92f453e	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x3bdf5c32	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x51d57776	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x5ee66a19	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x6dd0a0a7	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x78af2b74	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x9add504a	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xf6f71df0	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0x5e8d6fbd	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x176f453f	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x1975c345	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x21486f86	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x46d27fe1	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x4d9b39a0	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x546a1eab	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x7a2fcd3b	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x94843bad	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xa204a533	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xb7ca50b2	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xb97108e9	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xf788f099	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0df35342	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0ef1d765	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x128423d7	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x27c3c84b	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x3023c21b	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x3519f9c2	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x5f82d1e5	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x65f27caf	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x99f6fc04	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb35aaab9	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb4f1d892	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbe6a88a0	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x184c1a8f	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x2238c6ae	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x7139ebcb	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x6bcc5ee0	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x6ed8b40a	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x56645c62	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x5e2490e9	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0x31f6fd04	imx_usbmisc_init_post
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0x380f6bf7	imx_usbmisc_init
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xf4faa12f	imx_usbmisc_set_wakeup
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x2abe152b	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x2c964e00	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x373f28d0	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x3ead16b9	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x52e97e63	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xc6b0780f	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x064e7ce4	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x3e365f01	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x4e12e6c1	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x56670fa2	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x597b5ffc	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x5fb4171f	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x7bfd7512	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x86067455	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8bf3ff41	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8dd4c9e9	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xb0899652	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xca176829	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd48dd944	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xf397fd40	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xfd354f37	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x692041fb	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x8cb70cf7	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xe6c01343	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xfb39f842	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x178e08b7	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x5de90360	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xd7acf8ab	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x38f9eb49	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x3dd2dd69	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x43db8b39	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x460c315f	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x559eac15	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56d0cab4	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6b6df5d5	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7a77a1a2	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa4630a26	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb946e341	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xbdbdee01	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xc29fcb39	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xdb9488f6	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xdc854b5a	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf74e6dfe	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x07131e7c	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x0d5c1d2a	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x0d5e8abe	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x339d9580	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x3ec263ca	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x3f8f5a3a	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x48f79420	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x62102b70	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x699f5a2d	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x7371e849	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x9efdd6b9	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xbb060cc3	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xc06b37fb	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xd5d85384	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xde399053	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0366a17a	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x06760efc	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x1c1b9de7	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x28898624	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x354c9595	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x3d3c53e6	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x475cdd94	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5401fe98	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x58bc90de	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x69c87599	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x746f7d1f	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x79de03eb	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8081455a	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x80a62eb4	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8634ce02	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8e13d687	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8f856728	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9cce3751	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa220f976	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa87ecafe	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xbb0564f7	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xbe98bf3a	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc17e0a42	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc8c96bed	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xcca0947c	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xcedc9212	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe3a52516	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe4722cbe	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xee5893ea	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xee91b561	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf448adad	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xff44323a	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x33ffa769	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x3a44a75c	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x91cc2399	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x9816a5ef	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x9e71542d	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa2baca3d	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xc58d42fd	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xc5df9f15	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xd681a380	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xdc6499e9	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xe1ac8da3	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xe5a7413f	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xec8d3b6a	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xf30f50a9	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x212ec26b	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x6d43a45e	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x2b2731e5	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x356ebc96	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x47768888	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x5a0e31af	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x7400f582	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x898d901d	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xa338b59c	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xbaaadf0d	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xea008951	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x170e180c	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0xf1471fbc	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x7d0c1a25	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x0223e8cd	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1b71fd27	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1ce3afa2	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x213e4cd7	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x29f44a5b	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2f4d8009	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x33355e9c	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x5113fcf4	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x59ebbbb5	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x69e69bca	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x72ce4979	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7d34505c	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x8d91f4b5	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x90b42bca	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x9b8408b1	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xa1e416ee	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xb4fde177	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xb9650288	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xcd27f649	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe74c684e	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xfd7546ec	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x038ec5ff	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x03defc9a	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x22c40e9a	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x39bced9f	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3b243a09	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x401f9155	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x51dd86f1	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x582344d7	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6274d659	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6f3d8195	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x7956cf0e	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x80ac7bf5	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8f5c724f	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xaa5cda93	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb672786b	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbbdaaa30	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc0656b8d	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc0767bb9	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc9faeeb3	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd3850166	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd52cd7a3	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xdbab3e24	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xed8d5bcf	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf51fe777	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x0313f5f8	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x1c5ce39a	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x221434b5	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x30483ce7	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x8ad483dc	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x8d74b79b	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x91557f74	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x97a98130	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xa31a04f5	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xb8afbdcc	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe3d9c46a	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xed07750d	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x1b7ac2bc	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x2614c7e0	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x293441c9	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x561cd543	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xa618017a	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xb7e61171	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xc543b60e	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xd53fadcf	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xf4654c3f	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x37f51c34	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x3fbf1133	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x476fd17e	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x4cfaf8d6	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x4dcbc30b	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x828be957	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x93868cce	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x9ce5f14d	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xaf51bafa	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xc0d02907	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xd0095693	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xe932ffe3	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf10b5dd5	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfc4f0308	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x1a518bb4	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x78cc600c	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x7e5f9aa8	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x03e2b202	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x09860eda	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x12fa27a5	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x61010bfa	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x7fd84f31	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xb893f126	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xc40d58f6	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xe3ca9123	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x048c3729	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x091e440e	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0a7039d2	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0ac2ea2b	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0b8aad57	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x11030b56	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x21b93c28	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2983399b	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x347e50df	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3916d823	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3cb7f1ca	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x41d3989e	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4a1cc3df	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x59b4e4ab	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5e4bc088	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x61ccc67a	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x64ee820f	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x684e4e49	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x737e17ea	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7c718522	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7dcfcd23	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x80f4261d	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x85fb7658	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x88b3575a	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x90d5cedd	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x93d118f6	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa1666136	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa415bb2b	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa7e8e4a6	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa817d17e	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb28042ab	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb5afb2a4	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xba4ee6bc	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xca81fc2c	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd0209f62	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xda7fd552	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe14b53a9	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe1716f06	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe256fea4	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe9c21bb1	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf03bb036	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0xd4390fe0	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x08434497	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0cb9794b	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0e06affe	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x157a43a5	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2a069562	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2aac62d3	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3c489fcd	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3e156eba	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x44a2bff3	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x44a37390	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4f24473c	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x580af781	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x663bd3b2	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x6cfc6e1d	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x74a11fe9	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x798c31d0	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8d0be03d	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x94b0a0a3	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9ae61183	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa365aee5	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa65e3cde	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xad54c8ee	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb0f81e37	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbc405a13	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd2c84fac	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xdd2ef8cb	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xddd4a584	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe4726153	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xee94bf48	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xf4b9e5dd	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x1ba28bcf	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x202113a0	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x5a4f01bc	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xa2a9e003	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xaa1d3230	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xeeaa0cb3	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xf570a0de	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x1c2a1e06	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x1f99b13b	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x25be8a63	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x3ea8ed44	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x4c4cc19a	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x58f94eb5	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x629bb7af	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x6b5d7b14	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xd86d3331	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xeea8448f	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0x81f6f064	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0x94682cca	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0x9e54344f	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x1d1fd5b8	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x2a34f714	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x01b1728e	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x0f7c3a48	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x29fe5b4b	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x2f0639ae	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x31d7cdfe	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x3311eda8	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x58aab2af	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xe60acccc	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xe8dc421d	w1_next_pullup
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x557e0f6e	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x7dc1ffeb	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x84762201	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x37aed838	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x66dbda44	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x7742b79a	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x9fb4fa8b	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xa4019b86	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xa5afdbaa	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xae17cfc7	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x004b588d	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x00ea3847	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x035cb8f4	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x04d90625	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0529550f	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x05813a87	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0726e388	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x079a8921	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x08518dc0	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x105a314f	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x149815fb	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x160d49ef	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x167a2138	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1729989d	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x182ea210	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1ad38bc6	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1d22cf1b	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1f4ef98f	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26efb6d1	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x296b0ff5	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2c337742	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2cac7340	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2f9ae066	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3000458a	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x368d4f1f	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ae79462	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3b18a5a8	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42ff8795	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x45f2fbb5	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x47a15942	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x484196dd	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x484b0b3e	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4a6c6095	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4ba6c596	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb75915	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x515faad1	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5649a726	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x58dfb7a9	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5ac5b054	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5c06e049	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5fafe3fa	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x611a7297	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x636e511c	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x66b7f6e3	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x66c618f3	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x67183f90	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x693dd9e6	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x69dba60e	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x71ef7617	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x71f9727e	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7776bcd8	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7a7a8ceb	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7b200e9f	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7e700cde	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7f1f6f9d	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7f25a2b6	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7fa6314b	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7fad8622	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7fc85f5e	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x82ef71f2	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x83a0240f	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8896d4c2	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90273d14	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9230fd60	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x93202ba6	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9469b89c	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x94b7dc99	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x96057114	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x996bb12a	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9c44232c	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9d4b57bc	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9f6e2204	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa131327b	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa48bc21b	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa631d376	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa67d75bd	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa81effc2	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaaa14361	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xadddfc53	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xae69aa01	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb0af7871	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb5a80049	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb86f6b23	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbbe15854	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbcf071ae	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbdc894a4	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbe41a180	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbffb0580	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc0c2fdab	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc36b767b	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4d4d176	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4e17142	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc64b1ed8	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc7f304de	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc8556a20	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcaef1b41	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcdb8545d	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd16bd73a	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2048660	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd3428452	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd546c95a	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd7028c2f	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdc798d49	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdcb98f0b	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xddbec7f5	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xddda10bc	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xde989d43	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe13f13d8	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe6748c7b	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe88ef1d7	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeac049c6	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeb887b92	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeb89175e	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xedf61583	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xee1c6e01	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xef64e1a2	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf173cd39	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf1bc00b2	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf7f556e2	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf9c3cf28	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfcf5bc02	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfd2092ba	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfd663828	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfda59ba0	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfe48a5d2	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0x5c4cc2dc	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x032cccc6	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x04513ce7	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0edadd08	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x14a9fed9	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x157394da	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x163f1512	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x179b6e8e	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x19936836	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1b33b493	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1cf8efc0	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x327cfb26	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x36f1b74d	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x372c5439	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x38d0628e	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3f478f8c	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x41c41587	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x42beef63	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x44260b89	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4754096a	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x48cddcb6	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4a6c6ee8	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x525bd9e9	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x549b5e20	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5ac0bb1f	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5edd7f84	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x61017fbb	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x64d0de3b	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x668767fc	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x68d378ef	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6ce48180	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6dc75774	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x72760ed5	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x750435c9	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x75b5fdfe	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7859c122	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x794dbfc0	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7e8fb310	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x81bde26f	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8e723a90	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x90c5672d	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x92636b52	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9cd86eab	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa02df320	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa26e0d82	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa7796d0c	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb196ba88	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb34788ea	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb38c4486	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb7317a7c	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb7ba54a3	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb8388456	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb97ec95d	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbda2275c	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc2dbb93d	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd43b2e2e	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd576bffd	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdd6fe05a	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xde67ee91	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdfaeead6	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe3e53d45	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf77f0c2d	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf8e77568	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x5ef20fc1	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x7a20ed02	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xbc61e83b	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x36fc451d	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x906b87c1	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x0dc442dd	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1962d922	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1cb231d0	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x42373c79	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4c1f834c	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x53d5ec66	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x687f6251	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x988995e8	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa9f5379a	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xefbcd5c4	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x52a4aa69	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x536486f7	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x6342d1fa	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x73494b52	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x83266054	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xf6d51b41	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x2b51fe37	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xd63651bf	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe06f1460	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x298cff2b	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0x3b12b8b8	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xd4f6a6d0	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x6feb145f	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xffeac87b	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x021957e1	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x0f8a2742	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xd4cb6873	raid6_call
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x57861324	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x57d39367	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x882ce5fc	base_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x9e0112d0	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xaedfbb15	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xc8fca8a6	base_inv_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xd11741a1	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xe3d900b5	base_old_false_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0xea82f1e0	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0xf4a7b874	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/802/garp 0x05976c4c	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0x590911e3	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0x983cfaa3	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x9d3a8301	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0xd2aade93	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0xf9109256	garp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x04586d19	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x17bf5550	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0x1a2aef93	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x51326f4b	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xaa8a2ec8	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xe4c6c7da	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/stp 0x3e79e382	stp_proto_register
++EXPORT_SYMBOL_GPL net/802/stp 0x6d16d77c	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x463a1810	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x5b3c63ac	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0x7b08656e	ax25_register_pid
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x194b4047	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x23f5df80	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x442671fa	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x4f49113d	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x7fd6b0a9	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xac32c1d1	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xe573f396	bt_debugfs
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xe7ffc025	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x304607a4	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x40f8f4e1	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x45d27463	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x5f0a28a1	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x661f0946	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x6ed9dbe9	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x953593af	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x9ad4f314	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x34288db2	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x4da9247f	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0661e07e	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0f6c66e9	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x139eac39	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x180292b1	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x199dbe8f	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1bd8963d	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x210947e2	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x22cb087b	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2e0838e4	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x35e51350	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3cfd7b05	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3dd70b8e	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x46493085	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x47310a23	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4fed39f5	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6fd1ceac	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x725a2ec7	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x773b56d7	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7fa35758	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x91e2d518	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa0dc86d3	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xaa98ef3b	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc0b7b890	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc34b3955	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc6bbbf67	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc751dea0	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc8bb8255	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd4af966d	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd502fceb	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe64e9b6f	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xec1deb6b	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xee9bb5e9	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf10ed438	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xfc739f95	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x12111b1c	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x3bdbef13	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x99dc72b5	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xbc7bf5de	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xec839ec6	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xf36b7cfc	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x0479c70c	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x123ebda5	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xad95dd77	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xd58dfa29	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xf05acfbe	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x199a59ac	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xf4e96905	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x3715a260	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x69c45962	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xac3b1d13	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xcd88ed9d	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xd5837910	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xecdabb48	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0xe46664c0	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x0d45f4a2	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x32d30ce8	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x52bf4f06	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x59d5795c	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x5a0bc8fe	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x7a04a028	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x95494e6d	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x9ddbfa4c	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xace2d35b	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xb6ca9c8d	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xbc9ac006	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc3335fee	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd1d2cdb8	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd501faa2	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xeb25f93a	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0xe836af81	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0xd5e4c31c	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0xf686608c	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x2c21de7b	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x533d6c25	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xb7f8c0e8	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xc5596e0f	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xf4fc0057	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x4245122b	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x0b5b14ab	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x3837f5f8	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x5b8ee9ef	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x6a590d6b	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x7c7ad21a	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0x403f47bf	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x0d170102	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x14ab102f	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x32931a99	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xa56f4891	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xc18b56e8	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x53e574cf	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xb8c24e76	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xce6c8e2a	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xfe3fe177	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x2029aea1	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x2bee1bec	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x690d4c12	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x7f981c2d	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x94f4a6bd	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x9e49b0a9	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xfbc22a3e	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x6067101f	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0xeddd2eec	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0xbd496fd5	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x388e04cd	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x763b78fe	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0xde43e10b	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x2281621e	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x7adef029	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xb4f46dab	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xca29128f	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xf9b7de50	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x191335f5	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x2cb6c2ab	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x367f437b	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x90cfba5e	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xb294bfd0	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xd3093048	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0x91c2ef5c	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x14bc6b03	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x182d67b2	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x30524b2e	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x3ec9fb09	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x45201e2f	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x6bddb011	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x83fb5f5a	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x868f07a3	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x9802a539	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xac523e93	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xadc0493d	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xbbda0be6	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd7fd0a02	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xdc6a088a	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xf752db79	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xf809b468	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x84ea7b1a	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x0a034d89	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x26af235e	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x2a81b412	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x301516f5	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x4fc8e41d	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x59333157	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x5af78a4d	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x62b8cbe7	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x8233c6f1	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xa5d47047	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xad0efcfd	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xb6632ea6	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xcabed2eb	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xd295d52c	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xd4b3aff4	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xd6cb9939	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xeb80a705	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf9fa191d	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x0e65b33b	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x5de66b1f	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xe98606a9	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf6b240c5	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x0d56bbfd	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x0fe4548e	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x18f41d60	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x253d1505	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x2fde1c00	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3f69e1e7	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x44ddd5fe	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x52d8009a	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6344eaf6	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x672f2de3	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x74436392	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7b8af055	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x8e106cc8	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x8fafe0fd	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9470c5ea	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf0ed8723	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf900fdd9	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x0fbe441b	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x68690450	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x9a72fe23	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xd807f943	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x009465cf	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x023b3cef	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0493bc99	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x09e3940b	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0b2c6fde	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0fd8dfeb	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x15b2f825	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x168915bd	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x19391f4e	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1b18e623	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1ed9e2aa	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1f944aa1	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1ff93e6d	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x22c9f1c4	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x22efc886	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x23ffe544	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x24bf773f	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x292e84a1	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2c164269	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2db65b59	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2dff8130	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2f71ca2d	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2f8bf89b	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x315ac50b	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x317936d5	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x351a724c	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x35ae0cd8	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x35c1b31b	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3b07f74c	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3d755b6c	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3e396caa	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x44f2b7b5	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x47a79a57	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x496b0f69	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x50c8bdfe	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x52e4754c	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5bc5b793	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5ed88e44	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x652aca9e	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6c8252e7	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7205e1c2	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78c82629	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7ca89fbe	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7cb5c1ba	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8257c509	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x83d60f66	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x861cf7ac	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x86fbec88	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x889a5b65	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8a66c4fc	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x906d15db	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x92dd45c4	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9485b1df	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9c9ecd18	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9fe07178	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa20cf617	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa46aa143	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa706d192	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa8e3d251	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa9c871a6	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb47ba726	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc023bb03	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc0988246	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc44e1b6e	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc4b14178	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc6dac098	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc77d838a	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd3462cf4	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd46031eb	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd4d98039	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd6d4d140	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xde2e64b6	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe36a13b4	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xeab9cb0c	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf00a3b98	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf648ba26	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf65e295c	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfa883de6	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfbd14637	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xff40b965	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x1720eb3c	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0x24ac212c	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x2365a416	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x26f1a0c5	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x344fe118	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x3b7b45dc	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x663a01b0	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x6cdb6b27	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x7e34ab4a	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc86a1472	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xdec76521	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xf4f0d9ac	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xfa5464ae	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0x3f08ebce	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x36d977f8	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x4b1b1d6b	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xb73e778e	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xe94f524b	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x8f099adc	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xb4d26e81	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x2713958f	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x33d7ad05	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x5816b31c	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x6cd47d02	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x8d939d00	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xb1443373	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xc9006d5b	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0xb63d2a43	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0x610ab0b8	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x04beb8b9	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x5156ec5e	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x9d4f37b3	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xc6f33d99	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x20a97015	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x27baa391	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x3949aeca	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x401be17a	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x6ab9d561	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xb31cb2ab	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xd76a831b	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xe0fc7906	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xf83d0249	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x1217c1a2	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x81828f0a	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x5f339439	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x8d311c38	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xf660808e	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x06c988ce	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x15d143a9	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x262c665e	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x29740e35	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x35cdc3a3	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x3960f117	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x3c01ae57	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x408905cc	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x95fb2c79	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xb1f2bcf7	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xd1c3e4ec	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xd83ed4f8	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed5a39ae	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xee052bff	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xee1ee892	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xf5222690	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xfff15ad1	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x355f5e19	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x49b8d55c	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x4bed9e64	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xc9dfec97	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xcdc6d87a	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xe8e348d8	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xfd7e01e2	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x2658b27c	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x3d56c3fc	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xcb889f16	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0x011c0d0f	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x1f466c34	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xd101d736	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xd1d5a236	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x3466a8ef	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x4fa7fccb	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x845032b9	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xa94b2d94	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xd2a5a3ab	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xd6c717a3	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x543b5e83	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x59ce00e0	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xeb9d233f	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x7181206d	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xc94746ed	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x043aa047	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x1971ac15	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x23664290	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x31c6adb6	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x337fe9c7	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x43cb7650	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x4b0fe8fe	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x68ef7100	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x85f83c56	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8ae62bb0	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x909a49f3	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x90a48c6c	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc8cb7766	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe75fc9ce	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x00204983	xt_rateest_put
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x482b6a12	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x05b03587	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x4c4e3b46	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x62ac436d	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x66bf954c	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x6e19cecc	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0xc29f9c8a	nci_uart_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x1b36fcd1	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x400d5efd	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x487206ca	ovs_vport_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x7b27a6fb	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x9b56a402	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xebd3566b	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xeca6dd8a	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xf6673015	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xfc67b218	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x071858e0	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x0e9d6f31	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0x227ca31c	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3624b890	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0x3bcf1147	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x412f375d	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0x4622b59b	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x4c5dc4f9	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x56291506	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0x5d43d924	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x6ac3863a	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0x6e1b825e	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x7d2fec21	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x84068777	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x8f68d5c4	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0x96fafe85	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x9a19919e	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0x9de7a49b	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xa4388430	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0xa7a77eaa	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0xac7411e1	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xbc0ae2c6	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xd4bff02a	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0xeaa858a6	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0xf1e110db	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0xffd0cb7b	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x7ac1fae4	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x8c90abc9	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x25847552	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x51a29677	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x51da5a34	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x00655283	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x014184f1	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x03229a6d	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x032837ce	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0395e2cb	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x06bc6376	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x083dcf2a	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x098675d7	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0a6e29be	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0aae2f2d	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c2d8f16	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c7a82c3	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0ce2e141	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0d9860b9	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0da06165	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0ec34a4c	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x107c2811	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x112fe11f	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x115d9c72	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x12aa2b96	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x13b41738	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x148d8681	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x16e06ecc	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x177c01ec	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x184e317b	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x18bc9a17	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x198d9a80	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1bd2baed	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1cb4aeb5	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1cba063b	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1dbba9d3	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1ddd3370	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1f2eae2b	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x21baa7c1	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x21d9bf04	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2277efdd	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x22b6700c	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24377f2d	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x247bb3e3	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24871b8f	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x25a01156	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x26802667	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2863d977	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2981af9d	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2ebc071b	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f16d236	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f8ebbe0	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3095b690	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x30ca2db1	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3167f743	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x32c70d70	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x32f3b725	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x33a1cab2	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3a10a237	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3d139c05	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3d4af0a5	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3e24363d	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3fec6a59	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4326cf98	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x43f00f80	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x44a216be	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x468891fc	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x46b1c2b1	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x49ebbef9	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4ac9eabe	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4b7b82a2	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4b7ba500	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4e0d91a6	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4f77c191	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4f92018c	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x51dfcfe3	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x52f53eea	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53240e55	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x561dc78d	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x56722984	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x594981de	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5958b353	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5a6d2192	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5a981c1c	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5ab80705	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5ad71c9f	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b06ea1b	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5c3fbbc4	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x60251e64	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x60633dd0	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x606f4d6e	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x625f414b	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x62b3fe59	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6433beb7	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x665e28b1	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x694d194b	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x698eeacc	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6c1fba02	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6c6bd40c	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6cf15782	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6e9ded41	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7149866b	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x714e4def	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x715da0bb	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x735fdfe9	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7374c442	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x740b29ac	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x742ee5f1	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x74b1073c	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x754ed40e	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7916d7b9	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7a7356f2	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7e138ebd	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x81e8a61f	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8243ac0c	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x84530c33	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8ac3e1d5	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8f1419a1	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8f59e3c1	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x917d9745	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x91e98491	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x92c391c1	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b31bc9c	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9bac95c1	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ef449af	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa091eb74	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa1642dde	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa29afd8c	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa333a2cf	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa3a3c438	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa3e416e2	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa6377265	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa951e030	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa9846864	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa3f98f6	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa44c61e	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa989781	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xab8413fa	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xac7e141e	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xae9985fc	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb1151186	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb12f8137	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb27d6224	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb3806a9f	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb416fedb	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb5111e77	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb60416a2	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb6e27311	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb95661c0	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbb4621da	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbc8fca16	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf2e83e7	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbfc2bf42	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc1b2ba21	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc2055a5b	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc2f0f6e7	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc329f368	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc45f5dfe	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc6839282	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc7841f2c	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc875fe46	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcdc6e0bb	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcede4c8c	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcff879b2	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd045163a	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd05b23c2	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd29e1740	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd60d766c	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7f3c3a8	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd9b41cac	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdacc4b5d	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdb1835f2	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdd6b720e	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe0553557	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe2ebf7da	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe39e3a29	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe400a167	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe4ed2e72	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5a51338	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5d3e211	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe64ea3ef	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe6b509ab	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe767b270	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe7b95ebe	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe8e5f15e	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe9508a1e	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xee7049a4	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeb7666f	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeece4644	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeed7f7f4	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef0c21e4	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf26c9954	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf3f7becb	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf4f40765	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf5e5bf9d	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf6884939	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf710e4cc	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf74954fa	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf87d07d5	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf978d372	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa479b6f	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfb1081b1	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfb870d77	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfe8ea5cc	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0b29901a	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x32f02015	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x46985726	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x50280e28	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x518a24c9	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x74e91915	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7b0c81c4	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa28ac180	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xb4c9e1d4	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbe949f5a	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd3d6a55c	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xe58670c1	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xec04cb2b	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf593c40a	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xfd218a32	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x05d16b40	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x09bc6cc3	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x246635cb	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x38de14e0	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x5cdb74bf	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x789e48c7	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x7b0e0d89	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xa3724cce	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xb892ab2d	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xd5a41c55	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xdf0b8c41	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xe574b13c	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xee4b22bd	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x1ca5b6dd	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x24c8c485	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x26c9dc2a	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x2d5a87b9	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x46dfe53c	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x4fd0e86a	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x68ef4af7	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x796cd468	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x7d0d0e4a	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x83705839	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x8fe873ae	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xa5d031c9	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xe86450ac	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x0e9bcf9d	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x9d46c552	ipcomp_destroy
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xb9cbb9a1	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xe8924e33	ipcomp_input
++EXPORT_SYMBOL_GPL sound/ac97_bus 0x179196f3	snd_ac97_reset
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0x07f3d137	aoa_fabric_unlink_codec
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0x260112c7	aoa_snd_ctl_add
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0x3ebdeddc	pmf_gpio_methods
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0x6569d21f	aoa_get_card
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0x6e28d5c6	aoa_codec_unregister
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0x7b9a09c5	ftr_gpio_methods
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0xe1e7b768	aoa_snd_device_new
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0xf74c929c	aoa_codec_register
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0xf95b3e0c	aoa_fabric_unregister
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0xfb0535cd	aoa_fabric_register
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0x1ca7316e	soundbus_unregister_driver
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0x26db6f7a	soundbus_register_driver
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0x3dad7c97	soundbus_remove_one
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0x5566b8d8	soundbus_add_one
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0x6770de00	soundbus_dev_put
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0xf4ab82c8	soundbus_dev_get
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x2b847b68	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x7809cf75	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/core/snd 0x1b71c113	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL sound/core/snd 0x8d468996	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd 0x9136f542	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL sound/core/snd 0x9798569d	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd 0xa2cd0332	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd 0xa6b89683	snd_device_initialize
++EXPORT_SYMBOL_GPL sound/core/snd 0xbbd9fdbf	snd_device_disconnect
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x1125c8dd	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x213154ac	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x257c9c17	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x3c04dca2	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x3f85e239	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x4cefcb53	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa5c6cab8	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xbd4d5858	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xd8479acb	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x09174f07	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x18fdfbfa	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x20cee061	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x31327b62	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x5070bda2	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x524a96be	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x6da3141d	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x8ddcc93e	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x9c969acc	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xd2a612b0	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xf532479b	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x347a4303	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x6891ad26	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x6c723f26	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x738298b6	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xe60397a0	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xf637f4ca	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xf8463de4	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x04a509ac	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x05de6ab9	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x07bbafc5	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0be9fc1c	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0ca639f4	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0dc2a36a	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0dcf7e06	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1083f5f5	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x11291b35	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x11b140dd	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x11c38a0b	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x19b46ae1	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1a9eb326	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1bc99982	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1e2b36fe	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1e8048fc	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3025eaf5	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x373c2d8d	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x38abcc2a	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3acd3498	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3da339a9	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3e4e1a9f	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3ebc3b41	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x44fd6e64	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x45e24ca3	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4618c2a5	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4fbf5c3a	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x524d1ae8	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x56d7cfef	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x57792a10	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x57bcf5c8	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x59f90d11	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5fac6985	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x61ca5ae6	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x67b76738	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6eb33f40	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6ecdec23	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6ef77a0a	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6f4ec37d	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x71eac033	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x732b9aa5	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7daab2ed	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8041e812	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8621e515	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x917b281c	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9332d2a1	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x98008d4e	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa733e742	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xaa7dbf66	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xac8cc7d3	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xadafc229	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xae8497a4	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb4291668	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb79587bd	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc5f9f304	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcabb9a02	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcc4682ef	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd16ec04c	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd24a52e4	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd2d50166	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd3f50e19	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd3f5a74e	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd70b7218	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdb12430d	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe06c6c29	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe85f78e8	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xea4e38d3	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xed0e08d4	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf25472f1	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf4fdba6b	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfc04ddca	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x19aa44b7	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x1de73c50	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x9cba7685	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xbc97e002	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xc41239c5	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xd93f18a3	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x022a554d	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x04b774c7	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x05a54393	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x08631db6	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0c48b6a6	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0d9b1f78	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0fcb60ef	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x132f9767	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1407af3c	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x14aa7bdf	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1678ce90	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x175e61a8	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x18cac919	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x18d1613b	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1c4d6d7f	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1e9d270e	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1fd70f4e	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x247af6fb	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x26de33dc	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x28341ea1	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2ae4b718	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2d1dceaf	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2d5c707d	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2d80502f	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2d9e6ab4	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2fb95697	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x30273242	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x31cf0aee	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x343970c9	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x34c5d2cd	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x34f5465b	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x364596ff	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3cffe349	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3d2cfee8	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3e2cc43a	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3f17d3a8	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x43e8c24d	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x46466f60	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4aab4ff1	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4dc346e3	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4e451337	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4fe7a86e	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x502cec8b	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x51883a12	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x51bc120d	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x52d4b2e9	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5350421e	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5388128c	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x56c8a6a7	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x56ce32c5	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x56ff3042	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x578057d1	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x588a717a	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5c349fdb	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5cb3a937	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5cdc6ffa	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5ebc572d	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5f654d7e	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x68eff341	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6a2b35d4	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6f4f8066	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x70a2620f	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x72089d4a	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x738163f9	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x739d75ce	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7b400fd3	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x82b50250	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x844907ae	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x85a28b67	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x866accc3	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x86cf05eb	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x892d91ef	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8a519951	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8cccb8db	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9131e2d8	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x913f7a3f	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x917a0f69	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9249b326	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x93636846	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x978a5b1b	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9b467ba7	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9d05f22c	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa119df8b	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa6252127	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa73bf860	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa9339659	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaa210856	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xadf0839f	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb023b910	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb2d919a4	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb5077129	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb60186c5	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbacd5c1d	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbc94cc25	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbdefdc4f	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc0037b8a	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc0992af1	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc0c7ab7e	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc0ec040f	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc154462d	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc2d083ed	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc9554231	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xccc0a43d	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcccd2aaf	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcfbdb12a	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd5a5e9c6	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd6532737	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xda6e5842	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdaffe3b2	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xde0dec4b	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdf2dd9ee	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe1501d85	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe1f587b3	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe28e0d7d	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe4688f2b	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe9d73b00	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xef5b2bfe	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf1151ef8	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf1e6a05b	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf33bc3cf	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf41e6560	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf548d7a8	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf76d3588	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfc3eb963	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x0fd32247	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x129f437a	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x22514ec3	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x3353d2a3	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x338bf5e8	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x3f3ce77d	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x492cc152	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x4ef90590	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x6280fdac	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x646ff026	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x6ebe47e1	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76a0e22d	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x9c5bdfd1	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x9de4a653	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xabaf31b2	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xaca0086a	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xb1db0686	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xdce40841	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe8d7dd77	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xf3d1a15b	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xfe2a4404	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x25fe753f	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x7d05786f	cs4271_dt_ids
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x9c8b4548	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x9ba10bba	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xede489c4	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x4925aa98	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x8a5fbe15	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xe1544613	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x9630ebcb	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0xf58d342d	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x0709aa8e	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x092590c8	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x5e4ac00f	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x639256d0	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x113e4745	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x2929ecda	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x81fa92fa	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x8fccc63f	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xf3adb9e3	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0x6af35edb	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x95536740	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0xe26fe03c	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x450f6a3e	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xb64cf344	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0xd8c0aeeb	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x2d5af79f	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x605b9125	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x76b342d1	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xf0c52b22	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0x5c1dbae6	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0xdf0bf074	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x48dc22fa	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x4a1ba819	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x028fc1a7	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x04aa1a75	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0501f455	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x077c9b3c	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x08161212	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0856383a	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0942393c	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0acaf993	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0d6bc7f1	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0f486aab	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0fd2cfe1	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0ff331d3	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x107e93a3	snd_soc_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x11944ea4	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1427ad99	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x15bc7d38	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1621ea3c	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x18a6a16e	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x196ddd69	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1a9be63e	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1b8ab3a9	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2099c62c	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x22586e3b	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x22cf6c41	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x236f0a05	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2513ecad	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x26189b9a	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x272d992f	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x298105ce	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2b82dc29	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2dc37349	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x31fa8d70	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x350ddac7	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3603ed5b	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x364b8b93	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x39f59dd5	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3a170253	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3dc21d80	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3ea0fab3	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3f478b97	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x45558ee9	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x475dc378	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4aff4248	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4d5ae04e	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4e678d4e	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x533267bd	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5616fc28	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x579d5968	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5b40bdf7	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5d9435bc	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5f34ff31	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x62a55d2e	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x633f39f5	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6487b297	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x669ff24c	snd_soc_resume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x697305db	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6b6bedc8	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6b7dc498	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6d9195de	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x70b07b23	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7265fe54	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x73257c17	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x74943c30	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7759d546	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7c3e9cf9	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8111b837	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8139f520	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x82463cb2	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x82da10b7	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x84ccaac7	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8816241c	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8a664b7d	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8b4371fe	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8e738ffa	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x904b94b2	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x904e62aa	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9067f75e	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x94ac8c2b	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9517abc9	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x95fabe7b	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x986f8d22	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x99d373b6	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9a788bd6	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9ac2ebc7	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9cc4af23	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9d1c4280	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9d4d9def	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa1e8dd62	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa6b9203a	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa71b8f48	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa825e900	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa8a40661	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa8aeacab	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa9972d86	snd_soc_component_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xad9a970b	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb0c10a9f	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb2bd31f1	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb2df43eb	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb414a774	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb5bd0c1a	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb75292cb	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb88fb8f0	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbbc9669e	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbcc97d10	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbdabd6ad	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbe4c9900	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbe858fc6	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc33bed67	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc71d4478	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8882009	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8f84265	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8face1e	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xca72e03d	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcc2cd9aa	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcf26d511	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd10cef95	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd1ae1440	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd26c4bb5	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd315a5ea	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd3a868f0	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd561909b	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd741d04f	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd7f8b2a4	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xda71bb80	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdc721a6f	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe00b3783	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe1001634	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe2a282cf	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe2c5cc8b	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe381fc71	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe39194df	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe43762fe	snd_soc_component_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe5294ed9	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe6104663	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe9252899	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe92c6614	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe9e37fe9	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeaad2727	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb418b88	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xec5a553c	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeec827f0	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf2173da0	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf4684710	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf6ee33a4	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf884f961	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf97a3d03	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf9fe973f	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfb7cbde7	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x07b8147d	line6_write_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x0d7b054e	line6_suspend
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x0efdf8f4	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x1435a642	line6_read_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x2f90696f	line6_version_request_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x48329c32	line6_send_sysex_message
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x5c123c21	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x60a206e7	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x6d5ef324	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x90760794	line6_read_serial_number
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x9216e82b	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xa2fc1f6a	line6_init_midi
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xb3854403	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xb799e629	line6_pcm_release
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xc8087eac	line6_pcm_acquire
++EXPORT_SYMBOL_GPL vmlinux 0x00131cd5	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x001d2494	pmf_put_function
++EXPORT_SYMBOL_GPL vmlinux 0x00324e45	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x004c389d	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x00632780	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x007c8787	of_reserved_mem_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00c94d59	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x0106ce4e	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0x010c1082	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0x010cfbba	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0x01109fce	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x0122b542	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0x013a3f99	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x01609ac6	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x017b763c	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0x0195fba9	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x01a6fd85	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x01d0e9c6	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x01e4bc57	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x01e932e0	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x02037c1b	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x021ebfda	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0x0220c8a7	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x022ddfec	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x02377234	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x025c2e11	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x02683aed	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x02dbc475	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x03091811	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x0321cdbf	of_alias_get_highest_id
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x038c752b	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03b3ad51	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x03bd8c94	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x03eb2b7f	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0x03f7f520	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0x0414b1a6	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0x04360d87	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x04404710	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x0467f94a	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x046d2e9f	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x048619a5	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x048eedd0	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04b1aef4	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0x04b5549c	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x04bc5e8e	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04f4bb66	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0x04f4bd8d	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0x04faf07d	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0x04fdc31d	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0x051487d4	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x051ba4a2	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x05306bfe	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x0563087a	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x05650d85	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x05664ee4	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x057f575a	of_dma_get_range
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x05b6ac55	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x05def827	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0x05ec6ce1	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x061dee59	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x0629c3af	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x0631e113	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0x06493058	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x066e1529	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0x06b41328	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x06e0e67b	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x070b3820	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x070eb3ee	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x0735499e	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x0738f669	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x074e5e21	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x0766e148	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x077b627c	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07c6e2ef	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x080daadb	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x081c7393	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0x08271c03	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x08281252	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x08311335	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x0836ac12	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x0842aa74	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x086c9b83	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x086f439e	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0x087c9dfc	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x0889c046	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0x0894a2be	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x0898db2a	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x08d2b3a2	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0x08d4f36c	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0x08ff946c	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x09187723	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x091c824a	machine_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x0924ea92	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x094672dd	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x0952af60	fb_videomode_from_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x0967c2b2	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x096e37b3	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x098c87e2	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x09a5c74b	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x09f27cbc	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x0a01c140	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0a2daf30	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x0a2fdabf	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0x0a30b5bc	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0x0a33fe1a	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x0a51ae5b	virq_to_hw
++EXPORT_SYMBOL_GPL vmlinux 0x0a7deb5b	cpu_remove_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0x0aa063f5	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0x0aa83566	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x0ab70701	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x0abdbbcd	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x0ae050a4	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0x0ae58772	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0afd4610	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b283b46	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x0b41ef00	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0x0b4a3f74	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x0b57699f	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0x0b896098	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0x0b97a68b	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x0ba27f3e	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0x0bc680bb	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x0bdbecb3	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x0bf88e34	of_overlay_create
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c1ddde6	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x0c24fe18	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c3c5f32	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0x0c6f47ae	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0c70ebf7	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0x0cbbc2cc	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0cd38c24	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x0cdfb77e	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x0ce05931	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0x0d059e64	static_key_deferred_flush
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d5881cf	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x0d6c2f8f	of_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x0d73a952	GregorianDay
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0d8ace7b	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x0da0bd5f	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x0dba264b	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x0dbb6e25	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x0dd40cac	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0de06988	cpu_first_thread_of_core
++EXPORT_SYMBOL_GPL vmlinux 0x0e040383	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0x0e08716f	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0x0e1453f9	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0x0e23e71d	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x0e5d2d6d	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x0e81af3d	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x0e822bc9	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x0e958e1c	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x0e988747	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0x0ecb45a5	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x0edf17a4	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x0ee02b03	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0f094b07	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f289ac1	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x0f2d0411	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f4c746b	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x0f57645b	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x0f5b92c4	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f872e0b	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x0f9d10d4	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x0fa516b3	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x0fc01e9f	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0fd09f3b	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x0ff7ceaa	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x10293e70	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x102bd569	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x1052f93c	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x10750c28	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x109e04e4	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0x10c24e02	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x10dddac1	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x10fb646a	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0x110437b2	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0x1114011d	threads_shift
++EXPORT_SYMBOL_GPL vmlinux 0x114273f0	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x11578ce3	flush_altivec_to_thread
++EXPORT_SYMBOL_GPL vmlinux 0x11623e73	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x118e6580	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x11d46d5f	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0x11d7589e	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x123963c7	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x126c9ddd	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x1291893a	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0x12a46bf2	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x12b929ad	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x12c4d73c	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x12c59d85	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x12ca8e17	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x12e160bc	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x12ed3574	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0x12f33bd9	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x1322c57e	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x13354608	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x136a4ee6	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x13c56fd5	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x13d496ea	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x13dc3d5d	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x13e5ea13	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0x140b3884	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x14110433	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x1429c35c	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x142f240e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0x14353d40	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1443f116	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x14600ecc	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0x14cacbfb	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0x153da79b	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x15487496	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0x156262e1	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0x1571d359	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x158d52b2	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x159a6b8e	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x159e77f8	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x15b13a84	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0x15c0eea5	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x15c21e5e	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x15f8d5c8	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x160c78a1	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x160d287c	rio_map_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0x1626b5d1	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x162f679b	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x16907c24	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0x16bf7aa3	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x16c33104	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x16c7325e	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x16c77cb2	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x16e10f93	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x16f0a279	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0x170a0397	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0x1714bf7c	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0x171eab9e	rio_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0x17405494	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0x174ae6be	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0x174cbcc0	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x1750af1d	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x17538da1	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x175676aa	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x179bd98a	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0x17b1ba21	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x17c15cfe	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x17f45f3d	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x17f9da02	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x18044f61	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0x180689ed	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0x1818fda0	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x1843d2ae	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x184757bf	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0x184bb35f	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x18516b8c	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x18570516	pmac_i2c_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x185b8fd9	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1868ad55	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x187c2708	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x18bb3d93	early_find_capability
++EXPORT_SYMBOL_GPL vmlinux 0x18bc44e4	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x18cd723e	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1902dfa7	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x1941d5ab	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x1990f8ff	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19baa00f	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1a1c4082	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x1a20b6cf	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x1a8c5907	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1aa67138	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x1aabc8f0	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x1aae8bbb	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0x1aba5640	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1af038ff	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x1afa6c05	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0x1b52db1c	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x1b546841	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x1b607c82	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x1b757cca	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0x1b787ccd	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x1b878730	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0x1b9a10e8	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1ba22e17	of_resolve_phandles
++EXPORT_SYMBOL_GPL vmlinux 0x1bb3b485	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x1bcd4d29	find_module
++EXPORT_SYMBOL_GPL vmlinux 0x1c0854e6	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x1c090d35	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0x1c299d3c	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x1c40267a	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1c8bfc7c	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x1cc6689c	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x1cdd5440	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0x1cde2d5f	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0x1cf82066	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x1d02d7aa	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x1d0695f3	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d33741f	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0x1d53809a	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d59de1e	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d79d7c7	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1dacf09a	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x1db71ac8	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0x1dd6e24f	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x1dfbcf4c	mpic_msgr_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1e300e4e	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0x1e439d2d	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x1e4aba24	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0x1e55b2dc	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e692ea2	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0x1e72e80d	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1e994a05	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ee7212d	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x1f079104	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x1f488906	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x1f5362da	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x1f62339e	pmf_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1f93b407	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0x1fe78055	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0x202b196e	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x2049bab8	__destroy_context
++EXPORT_SYMBOL_GPL vmlinux 0x2053ffd3	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x20688b3b	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x20aa6f51	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x20cede87	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x20e0986a	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x2119049b	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x211925ce	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0x21450fb2	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0x2155b669	device_move
++EXPORT_SYMBOL_GPL vmlinux 0x21c4ff44	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x21c8904d	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21d7b91b	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x21de5003	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0x21e4ec59	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0x2201df54	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x22221276	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x2267e000	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0x226cc993	of_get_nand_on_flash_bbt
++EXPORT_SYMBOL_GPL vmlinux 0x227038c7	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0x227dba9b	dax_truncate_page
++EXPORT_SYMBOL_GPL vmlinux 0x228b543f	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x22946c7e	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x22a6d879	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x22b2b266	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x22e87cf6	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x22ee7544	of_device_get_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x22f2b612	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0x2307093a	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x2321aca2	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x2349ec4c	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x236bcdb6	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x237452ef	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x2386c409	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0x239c058b	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0x23b18da4	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0x23cfa2a4	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x23d882b8	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0x23da1788	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x23f589bb	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x23fa7c4a	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x2406dae3	pci_address_to_pio
++EXPORT_SYMBOL_GPL vmlinux 0x2414a3e4	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x24158e6a	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x24261047	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0x242b6494	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x24329295	fsl8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x2451a647	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x24647660	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x246af214	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x24948a6b	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x24aa5a8c	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24cbbf08	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x24ccc7c8	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0x24e1a998	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x24f8bedd	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0x25152211	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x2529b892	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x252bf5e9	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x253109b6	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0x2579160f	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x257e34dd	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x2580afb4	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0x25936d59	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x25977389	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x25b0c779	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0x26085a7e	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x2614ab3f	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x261fbd79	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x26479f60	rio_get_comptag
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x2668a8ce	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x267402a6	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0x268efd43	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x2690b2ba	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0x2691412e	boot_cpuid_phys
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c4efe4	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26cacbd5	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x26e1051e	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0x27093c57	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x270c18e3	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x270db6f0	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x272cf922	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x2745d5bc	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0x274bf8bb	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x2758eb70	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x2776911c	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0x2787db00	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x278c8bce	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x27a48c3a	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27c2b7d2	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0x27df23ad	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0x27f466c9	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x27fc4c3a	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x28531885	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0x28970181	of_pci_msi_chip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x28ad4375	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x28afa2d7	__rio_local_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x295ea08e	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0x2969c455	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0x29723eb6	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0x297a2d2e	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x29cb1e74	pmf_unregister_irq_client
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x2a06b422	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x2a1ba066	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x2a1eaf0d	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0x2a3e6b28	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0x2a5c8d55	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x2a650fdf	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a7740e1	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x2aad9c1d	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0x2ac386e7	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x2b0b8f17	of_alias_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x2b132ca7	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x2b22e9fa	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b433900	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x2b4cb0c9	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0x2b5c303b	smp_send_reschedule
++EXPORT_SYMBOL_GPL vmlinux 0x2b649eea	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x2b7a574f	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x2ba5f19a	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0x2ba8338f	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x2bbec2c8	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2bc75446	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x2bdd090f	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2bf0ce86	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0x2c08d9ff	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0x2c129e78	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x2c13816b	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x2c1c8f62	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c23e7d3	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c35340e	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2c389734	rio_request_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0x2c56aa5d	of_irq_parse_pci
++EXPORT_SYMBOL_GPL vmlinux 0x2c639325	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0x2c7abd6f	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c8d103f	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0x2c8eabd6	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0x2c97c085	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x2c97f8a2	of_reconfig_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2cb1a757	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0x2cb601e7	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0x2cbc7f5c	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x2cc3e675	pmac_i2c_close
++EXPORT_SYMBOL_GPL vmlinux 0x2cd8dcae	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x2cddcb07	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d27b9ab	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x2d2d2137	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0x2d391ca6	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x2d3ccc7d	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d66d648	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x2d6a745e	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2d7db8c5	unlock_media_bay
++EXPORT_SYMBOL_GPL vmlinux 0x2d8d7868	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x2da483a3	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x2dc39ba2	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0x2dc5a6d1	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0x2dcc2dd8	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0x2dd3a65b	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x2dda82ec	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0x2de681b6	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x2ded3031	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x2e0dad63	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x2e18c541	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e49aa34	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x2e58b5c7	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0x2e8c2b11	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x2e99821c	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ef4d512	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x2ef6b5bf	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x2ef77b57	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d8fd8	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f37f1af	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f4e02a4	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x2f52078c	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0x2f635abd	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f9a532b	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x2fb64de7	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x2fbb55a1	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x2fec1ffc	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0x2fee3ef3	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0x2ffb5ff7	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0x3012b8ba	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0x30293211	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30412842	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0x30420428	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x305bdc6d	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x305d3034	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x3061d8ac	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x3088442c	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x30a4f4ca	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0x30b34135	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x30b6eec4	rio_mport_get_physefb
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30d33f4e	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3116c766	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0x3118383e	of_irq_parse_and_map_pci
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x313842c1	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x314013a3	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x314f75d9	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0x31960b5b	of_platform_populate
++EXPORT_SYMBOL_GPL vmlinux 0x3196fc6a	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c5b085	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31d07045	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x31f205e8	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x320d0118	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0x32230b59	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x322c5b06	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x325bc9d2	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x325e05dc	mpc8xxx_spi_rx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x32719d7f	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0x3277cc3d	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x328b14c3	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0x32965e69	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0x32a6c8cd	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0x32bb24a8	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0x32c2dfed	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32d572d5	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x32ee1cf8	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x332f3adf	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x3330de96	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x33330f2b	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x3338160e	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x3362cb2f	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0x33755f8d	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x33762af3	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x337786fa	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x3394ec12	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x33b79b3c	lock_media_bay
++EXPORT_SYMBOL_GPL vmlinux 0x33c2f30d	rio_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x33d8d7fd	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0x34058999	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x340d5346	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0x3412a69f	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x3436e55f	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0x343a79f0	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x343e726a	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x344353cb	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0x34537fdb	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x347682ce	snmp_fold_field64
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34ac50a4	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x34f4a333	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x34f5eda2	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0x35139e63	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x35252138	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0x353571de	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0x354fae4d	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x35ca1697	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x35ced1f6	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x35ef68ba	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0x3610f57f	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0x36114903	dax_clear_blocks
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x363495fd	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x3634ecc9	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0x36351b6a	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0x3637a9c9	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x36584580	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0x366437e6	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x367cb638	rio_mport_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x368bcaa0	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36bda7b0	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x36de18da	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0x36ef49e9	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0x36f1ae98	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0x37171d0b	pcibios_free_controller_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x371f2ac8	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x372fd664	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x3738dfee	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x3742c272	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x37887ed8	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x378bf8f9	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0x378e17f0	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0x3791595d	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x37bad6bf	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0x37cb2e57	of_thermal_get_trip_points
++EXPORT_SYMBOL_GPL vmlinux 0x37ced78b	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0x3823a6cc	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x38364f79	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x384627bf	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0x384e5900	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0x38639300	of_overlay_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x3877ceb3	rio_mport_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x388cb6a6	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x389afd1e	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0x38a9c2c7	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x38b9e3d6	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x38c144a7	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x38caaaca	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x38fd0abc	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x39041864	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x391d3786	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x392f6e55	of_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x393bfe6c	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x39422c54	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x3979b687	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x39800390	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0x39843752	__rio_local_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x39992715	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x399b4364	of_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x39b36842	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39d1741e	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x39d1bd3a	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x39db1b2f	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a55e107	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3a55e133	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x3a58fb45	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x3a67be2b	pcibios_claim_one_bus
++EXPORT_SYMBOL_GPL vmlinux 0x3a7f879c	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3a8b589f	component_del
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3a9db366	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3af7e70f	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x3b27e844	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0x3b2d3632	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x3b4cf4e2	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x3b72513f	rio_unmap_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0x3b9051cb	thermal_zone_of_sensor_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3b951a97	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x3b9c9fa3	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x3be4c647	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x3becd67d	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x3c0d6898	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x3c0e0da8	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0x3c173455	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x3c18483b	rio_request_mport_dma
++EXPORT_SYMBOL_GPL vmlinux 0x3c27be5a	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0x3c38a4df	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x3c536340	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0x3c59cb3c	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x3c64048c	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0x3c7465ab	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x3c903f2b	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3cb09726	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x3cb65f07	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cea9f17	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0x3cebccc5	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0x3cf5397e	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3d1e32dd	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x3d2fea49	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d455075	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x3d7fbe36	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x3dab8ba4	devm_power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x3daccfd7	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3dae390e	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x3db83e0e	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x3dc0aa24	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0x3dc526a9	arizona_of_match
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3dd4d3a7	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x3ddd0077	of_get_nand_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0x3de54780	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3dec3ac7	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x3df9c693	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x3e0111a7	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x3e18aa87	of_property_read_string_helper
++EXPORT_SYMBOL_GPL vmlinux 0x3e348bbe	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x3e50cb8a	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x3e56da87	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e7651e3	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x3e8087a4	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0x3e892794	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x3e972b31	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x3ed5a1e3	pmf_find_function
++EXPORT_SYMBOL_GPL vmlinux 0x3eee80c8	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0x3ef53135	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f044564	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x3f07620e	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0x3f07bb9d	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0x3f1ad71f	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x3f1b8c3c	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3f1cb321	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0x3f2b7667	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0x3f9a62c2	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0x3fd30de9	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x3fd85bc9	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3fdbb8e5	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0x4011ea85	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x401cae97	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0x402f6934	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x406a5662	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x406e0a84	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0x407353ab	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0x407a858a	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40cd0ea5	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40e74665	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x40fd9433	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x410c0974	mpc8xxx_spi_rx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x41140158	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0x415a8ac0	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x41661a3f	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0x4168ce09	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x417b1e8e	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x4187bd39	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x41abd3cb	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0x41bea765	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x41c2e9b4	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x41df1db0	of_pci_get_host_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x41ef1f6a	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x4205ad24	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x422dd7b9	rio_mport_chk_dev_access
++EXPORT_SYMBOL_GPL vmlinux 0x423d892d	__rio_local_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x42433baf	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x42635d55	pm_suspend_global_flags
++EXPORT_SYMBOL_GPL vmlinux 0x426b2c92	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x427a066b	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0x427fc1d9	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42848400	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0x4285f632	of_pci_find_msi_chip_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x4297a30b	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0x42b364ef	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x42e33a9a	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x42ed1c67	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0x43003593	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0x4301e5b6	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4313f6a0	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x435ff32a	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0x437bed3b	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0x438d1b33	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0x438e1805	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43ad3115	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x43c56d23	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43eca894	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x44027906	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x4403835a	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x440ad449	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x441b2982	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x441d46b6	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x443272e6	of_get_nand_ecc_step_size
++EXPORT_SYMBOL_GPL vmlinux 0x4472bb47	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x4473472a	of_irq_get_byname
++EXPORT_SYMBOL_GPL vmlinux 0x447a1aa4	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x448a38fa	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x44ae32de	of_pci_parse_bus_range
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44ca050f	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x44eff47d	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0x45055840	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0x452ac09a	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x4548e50b	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x454959de	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0x455d9ecb	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x45894da6	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x45899f64	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x45b830a4	mmput
++EXPORT_SYMBOL_GPL vmlinux 0x45b86875	of_irq_parse_one
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45c276f3	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x45e6a573	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x45e974db	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x46462b37	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x465a57f2	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x46661bda	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x46711185	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0x4688c96a	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4689efec	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x468e0142	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x46beb983	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x46cbf877	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0x46e2b09b	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x470034b3	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x470bcb3d	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x475718aa	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x47702ffa	of_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x477d778d	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47c56131	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x47e34575	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x47e9f05f	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x4817bfcf	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4832a13d	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0x483a1b33	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x484beae0	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0x4862bd8c	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x486fbc4f	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x48ba5824	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0x48c70cb1	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0x48d0f1af	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x4943a338	__init_new_context
++EXPORT_SYMBOL_GPL vmlinux 0x494a81e2	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0x4958f879	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x4968f003	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x49809dd5	mpic_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x4982a57f	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x499cbd8d	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x49a40880	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x49b44ba0	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0x49c88812	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0x49e319fb	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x49ee443b	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0x49f1f3cd	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4a0ac6a1	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0x4a1718d2	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x4a2547c2	threads_core_mask
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a75050d	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4a8bf801	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x4a8f9674	of_get_nand_ecc_mode
++EXPORT_SYMBOL_GPL vmlinux 0x4aabc058	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4b37fb85	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4b38a846	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0x4b53c70f	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0x4b7d0f01	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4b8042df	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4bb79dbc	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0x4c17075d	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x4c351835	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0x4c3d02dd	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0x4c46deb3	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c69e282	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4c7f7dc0	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0x4c9a0c1d	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4c9e47b9	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0x4cb36a8a	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x4cb37082	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x4cc28b6c	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x4cf04d83	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d0e8d0b	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x4d4480fb	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0x4d492f49	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x4d4fb685	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0x4d7c895d	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4d7cf320	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x4d94739e	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x4d9f450a	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x4db6bdbc	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0x4dbca541	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0x4dbf4aa4	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x4dbff5f8	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4de7fe81	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4df3922a	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x4e0e4a2b	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e299f3c	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x4e2c2dd2	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x4e6721b4	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x4e87ce84	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x4e914dcc	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0x4edf0bfe	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x4edfef47	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f0d59d0	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x4f19197d	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0x4f25c8c8	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0x4f278e69	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f3411f1	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x4f344960	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0x4f420baa	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x4f4bb552	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x4f4bf92c	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x4f5e76a2	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4fab643c	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0x4fcc824b	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fdfd6c6	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4fe47fad	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x4fe6bfcc	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x4ff05559	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0x4ffc8058	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x500700f9	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x5019bcbd	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0x501d6677	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x50463e40	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x5052e995	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0x50603c4f	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x506b89e9	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x507044a3	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0x507596d8	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x50a4fcb4	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x50aab298	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x50b8908d	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0x50be2520	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x50c89f23	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x50c93c72	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x50d5d231	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x5100e1fe	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0x51162738	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x51237ee7	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5139671d	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x5140a232	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x51467922	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x51719489	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5185d91d	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0x519176a6	rio_register_mport
++EXPORT_SYMBOL_GPL vmlinux 0x51966b51	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0x51a34187	cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x51a43904	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0x51a9c6fd	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x51b65a26	rtc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x523ee0f7	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0x5251dc95	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0x52573864	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x52a767fe	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x52c0d5d8	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x52dbba66	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x52e0eaac	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x52edbe99	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x5335dd11	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x53485f30	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x53746221	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0x538aac73	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x53a8e800	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0x53bf6561	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0x53c776ba	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0x53d482c9	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0x53ed3f2b	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0x53f64a60	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x5405bd77	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x541c18e8	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x541e99c7	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x542d84ea	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x5462a669	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0x546a724b	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0x546c5565	ppc_tb_freq
++EXPORT_SYMBOL_GPL vmlinux 0x5471cf9b	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x54786162	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x547a38a0	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0x5491e6fc	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x5492ca18	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5496b9a7	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x54d04c29	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x54d468f1	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x54dafc47	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0x553b475f	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x553f023b	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x55632179	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x556fe8b7	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x557c8923	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0x55890930	flush_fp_to_thread
++EXPORT_SYMBOL_GPL vmlinux 0x55aad850	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x55ab3d71	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x55c1c505	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x55e36cdb	dummy_con
++EXPORT_SYMBOL_GPL vmlinux 0x55e71fa5	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0x55e8209d	of_reconfig_get_state_change
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x55eed7cf	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x55f0b062	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0x55f51ef3	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0x5607281a	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x560930b9	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x5637a7a5	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0x564f9343	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x5667c3e7	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x5673a7d6	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x567c3099	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0x56a1f09a	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0x56b63670	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x56b9529f	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56fdb5ef	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x57396574	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x574b32ca	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x574d5872	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x574f8b72	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0x5761bb0f	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x57959b86	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x579a4875	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57a2637b	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0x57af6bba	rio_route_get_entry
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x57d579d3	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x57f0c329	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0x57f7b85c	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0x57f8a567	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0x5802052b	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x581736e8	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x581af145	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0x58330fb7	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0x5843a037	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x5848cbc1	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x5870c37c	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0x587d82d7	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x5892f832	release_pmc_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58a58fd9	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x58ad78a7	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0x58b019f0	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0x58b5c899	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x58b61400	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0x58d89208	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x58fe9409	rio_inb_pwrite_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5906dc19	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x593b0a50	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x59492a41	of_pci_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0x5956ee39	rio_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x5966cf5d	put_device
++EXPORT_SYMBOL_GPL vmlinux 0x5979c2f4	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0x59a43330	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0x59ac379c	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x59b1ce8a	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x59b91e16	of_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x59b985b9	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x59bfb8a3	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x59df23e9	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x59e8dca8	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x5a076b4a	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x5a0e3d86	of_irq_parse_raw
++EXPORT_SYMBOL_GPL vmlinux 0x5a22b3f4	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x5a25f887	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0x5a27f5ba	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x5a2e3bbd	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x5a303b76	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x5a595505	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0x5a5aa577	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x5a649f9e	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0x5a65c37b	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5ad13bad	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5aebd124	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x5b01ca5a	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x5b03094a	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x5b1a442c	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x5b266bb3	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x5b2df634	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x5b3f9bd4	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x5b587ff5	rio_lock_device
++EXPORT_SYMBOL_GPL vmlinux 0x5ba05c92	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x5baef3ed	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x5bb56c40	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0x5bc4a53e	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bda2129	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5c1a30de	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0x5c2e6de2	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0x5c4201fd	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c63315e	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0x5c64c142	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0x5c67d009	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0x5c74b921	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0x5c7ade1f	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0x5c89598a	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x5c9a6002	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x5c9b4fa3	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5d0059c5	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d480ad2	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x5d4cf4d8	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x5d51bcf7	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0x5d70b3fc	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x5d7ddd2f	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0x5d908696	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x5d9425cb	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5da73f4f	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x5de30043	of_property_read_u64
++EXPORT_SYMBOL_GPL vmlinux 0x5dff6fda	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x5e2b9336	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x5e370619	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x5e3e54bf	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x5e497050	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5e509ffd	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0x5e515be6	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e8b735d	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x5eba5217	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0x5ee04637	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x5eeb71cb	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0x5eeb8952	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0x5f0ab166	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0x5f1cf605	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x5f3bd0e0	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x5f4487b0	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0x5f5f601a	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x5fb6deec	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0x5fdfdee2	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x5fe0715b	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x5fe403ac	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0x60048016	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x600c71e1	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x6011fc1d	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x601a97ad	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0x602b5691	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x6035b78e	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x603d678d	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0x6044ea29	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x6079e5ec	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0x607bcff3	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x6081e539	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6090793f	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0x60a0d5ba	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x60ef3bb6	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x60f71b86	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0x6119ab14	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x6127f4eb	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0x61766467	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x618e5bb6	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0x61a90c54	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x61bdc0f5	of_platform_default_populate
++EXPORT_SYMBOL_GPL vmlinux 0x61c1b0aa	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x61c5f9a4	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x61f78b54	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0x6210299e	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x6216bd73	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x62460340	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x625819d7	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0x626ee58f	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6272d2fc	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x6298c8bd	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x62a580ce	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x62d59c9e	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0x62dad5a3	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0x62f20000	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0x6328bfd1	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x63408b76	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x635bb645	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0x637394bb	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x63780d35	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0x63880ff1	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0x6388d07d	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x639af444	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x63aaa546	pmf_call_one
++EXPORT_SYMBOL_GPL vmlinux 0x63ab62b4	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x63b972f4	pmac_low_i2c_lock
++EXPORT_SYMBOL_GPL vmlinux 0x63e40249	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0x63f1f7b5	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x64065d30	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x64256424	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0x642e1323	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x643a701f	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x6453f77c	pmac_has_backlight_type
++EXPORT_SYMBOL_GPL vmlinux 0x645c7596	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0x6465774e	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x649fa1c0	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x64a70cfc	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x64be618a	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0x64dab417	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x64e24a5e	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x64f79845	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x6503f906	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x650c3bf9	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x650ebf9f	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x652bff48	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x654f93d1	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0x655b30de	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0x655bbea2	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0x65690cde	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0x65a6b1bb	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x65ab1d82	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x65b173ad	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0x65b4cf6b	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65e70baf	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0x65fbff36	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0x6601392c	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6601d1f2	of_reserved_mem_device_release
++EXPORT_SYMBOL_GPL vmlinux 0x66063d19	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x667c4088	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0x667d393e	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x667deb0e	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x669a0869	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0x66a3dc07	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0x66a69080	rio_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x66afb53b	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66d1777a	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66debc66	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x66fcf009	rq_flush_dcache_pages
++EXPORT_SYMBOL_GPL vmlinux 0x6720a009	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0x67219808	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6759ecf0	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x67c5b02a	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0x67c9b510	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x67eb7fc8	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x67ecc608	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0x67f3252b	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0x6806ca6b	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0x6807d800	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x6845fc6d	pmac_low_i2c_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x68604895	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0x6881c818	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0x68956406	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x68b1f5c2	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x68bc577e	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x68c8d94f	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x68fa7b22	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x69089e2e	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0x69228ce6	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x692b8c70	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0x69310bad	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x6945725e	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0x6956918b	component_add
++EXPORT_SYMBOL_GPL vmlinux 0x695bfa56	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x695ca796	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x695ef253	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0x697bc445	pmf_get_function
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x697cbbb4	threads_per_core
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x6991e936	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x6994369e	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x69998894	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x69a94492	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x69ab121d	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x69d9b371	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0x69e8b8a5	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0x69ed8d48	device_register
++EXPORT_SYMBOL_GPL vmlinux 0x6a0b0a27	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x6a1e09b7	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0x6a27b83e	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x6a2e4d46	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x6a3d5fd8	mpc8xxx_spi_tx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a6c48ac	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x6a7700d1	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a86a2c6	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x6ab3781f	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x6ad6d585	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0x6ae2d2e5	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x6ae7fd8e	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x6aedd246	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x6b028c6d	get_device
++EXPORT_SYMBOL_GPL vmlinux 0x6b0ea39c	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b3d2d64	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x6b5af61d	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x6b7108dc	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x6b73bb75	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6bc2b7e7	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x6bc4a605	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0x6bccc585	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x6bcd2365	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0x6bd8d5b5	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x6c03fce7	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c209eab	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x6c266b21	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x6c42e77a	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c4f3e07	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cb64638	irq_of_parse_and_map
++EXPORT_SYMBOL_GPL vmlinux 0x6cc89236	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6d104379	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0x6d1b1796	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d3c2a99	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x6d423685	of_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x6d510e73	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x6d52fb8e	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x6d55c72f	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0x6d59b7c5	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0x6d74237c	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x6d7718a6	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x6d8c51e8	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e0d5440	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6e159f10	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0x6e22f0b6	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0x6e322820	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x6e43bd57	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x6e51afc8	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x6e6111e3	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x6e682f15	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0x6e7388ba	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0x6e77ae41	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6ea631cc	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x6ea7d7b1	rio_enable_rx_tx_port
++EXPORT_SYMBOL_GPL vmlinux 0x6eb1e6d5	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0x6ebd478b	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x6ec9f8e7	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0x6ed23d61	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6f0717d0	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6f0b765e	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f311954	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0x6f3ad70d	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0x6f42c58c	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6f9017c1	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x6f9037b1	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x6fbbddf0	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x700936b3	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x701639e5	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0x7016eb72	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x701a3e60	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x703716a4	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x703cf559	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x703e3e32	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0x705e4e86	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7073c16b	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x70965f5d	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0x70b5a87a	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70da1567	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x70e805fb	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7112881e	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0x712905cd	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x713a8525	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x713f5d8b	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0x714986d9	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x716764cc	of_get_regulator_init_data
++EXPORT_SYMBOL_GPL vmlinux 0x71739da8	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71dd6a4a	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x71de211b	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x71f24a10	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0x720c81ce	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0x722e3112	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x72511839	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x72515d5a	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278c4f0	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x728d8ced	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x7290605c	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7299d5f8	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x72bd896e	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x72d3c2db	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0x72d7622c	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x72dd40c0	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x73075e65	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x730edb5d	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x732ddf9c	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x7352a8ff	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x736ed3f6	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x73787bfd	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x737d1bb0	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x739aa1a1	pmac_i2c_setmode
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73b98231	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73cfe26f	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73db2016	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x73e29b64	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0x73f0d856	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x7410c262	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x742853ea	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0x74304fa7	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x744411ff	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x74471008	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7468b74e	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0x748b8cd8	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74b79688	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74c5a23a	pmac_backlight
++EXPORT_SYMBOL_GPL vmlinux 0x74d007c2	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x74d56d76	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x74e390e7	rio_dma_prep_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x74e7f6df	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0x74fba9d7	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x7505d09f	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x7506efe5	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0x750f410c	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x750f9839	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x752073ea	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x752d50af	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x75329035	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0x75442d06	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0x754a1cb8	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0x758799b1	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x759139cb	of_pci_check_probe_only
++EXPORT_SYMBOL_GPL vmlinux 0x759278e2	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7597c6c0	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0x75a1195c	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0x75a702d2	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0x75c2b9f1	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x75c9d8c3	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75d17d0b	pmac_i2c_open
++EXPORT_SYMBOL_GPL vmlinux 0x75d46eb6	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0x75f2a044	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x75f90332	rio_request_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x75ffd571	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0x76066068	rio_release_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x7612e902	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0x761ed6ec	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x762923ad	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0x762c0858	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0x763f8357	pmac_backlight_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x7640b206	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x765df5e0	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x76bdfaa5	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x76d71da0	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x76f215ef	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0x76f37d70	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x76f6d3cb	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x770cf981	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x772e74db	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x77610894	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x77742122	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x777482db	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x77782335	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x7785c199	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0x778ccf4e	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x77bcdb9a	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x77d4a4c7	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x77e146d6	rio_set_port_lockout
++EXPORT_SYMBOL_GPL vmlinux 0x781213bc	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x78151326	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x7820b2ef	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x784ca5a7	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x784dbabb	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0x784dbf54	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x785361d3	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x785cf1c3	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x787d89ef	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x7899339c	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0x789e4292	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78dbfdf0	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0x79075a0e	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0x790f4ed3	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7910567b	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x7934c678	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x79480197	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x796a9cba	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x79708f61	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x797daad1	thermal_zone_of_sensor_register
++EXPORT_SYMBOL_GPL vmlinux 0x797e4664	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0x79812c39	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0x79c4bfda	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x79dc2b5b	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x7a0a8f0d	user_read
++EXPORT_SYMBOL_GPL vmlinux 0x7a29e5f0	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a3aa5a7	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x7a45d02f	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x7a8b131b	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7ab1bb44	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7ab3ca18	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x7ae5cbfc	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x7aeb70d3	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x7af49e21	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x7b0668b6	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b38b237	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x7b39948c	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x7b3ade7e	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x7b454255	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0x7b880d34	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0x7bd5875d	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x7bdfd3df	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x7be11751	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x7c17ea2a	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7c2240a3	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0x7c4add71	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x7c5335f9	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0x7cba6c82	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7ceecd11	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x7cf6c0a4	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x7d1304d5	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x7d19f8d4	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0x7d24ee7d	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0x7d2b8814	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0x7d36cba9	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x7d588a98	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d87186a	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7db7da37	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7dc1e388	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0x7dc30ccd	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x7dd12fac	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x7dd7366c	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7de3bed7	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x7df855ba	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x7e01d6cb	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x7e17ba7b	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x7e1dd2b7	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x7e40d11b	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x7e4a3d5a	rio_route_add_entry
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e642d8a	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7e9d3e73	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x7edebeff	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0x7ef2fc3e	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0x7f008202	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f2fbaed	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7f4a3d5e	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0x7f66bc6a	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x7f6980f4	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x7f7bc710	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7f807d10	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x7f831643	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x7f8d27aa	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x7f98864b	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x7f9ccf18	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0x7fa18074	of_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0x7facc250	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7fdc72fe	mpc8xxx_spi_tx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x7fe13c77	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x7fe4c360	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x7ff2b8c1	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0x80427ee5	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0x8049ed62	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x804ea02d	__find_linux_pte_or_hugepte
++EXPORT_SYMBOL_GPL vmlinux 0x805042bb	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x80809726	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x80a64cfa	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x80a8a6be	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0x80ac831b	rio_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80e94ed8	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x80f1a677	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x8100fc0e	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x810e609f	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x8129f17c	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0x8130b656	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x81387014	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x813d922c	rio_request_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x813f9ef9	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8148bf5a	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x814c022a	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0x814d5273	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x815641a4	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x815d0810	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x81793952	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0x817aa091	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x818a6491	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0x81a09bb4	pmf_call_function
++EXPORT_SYMBOL_GPL vmlinux 0x81abb0d7	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x81bd8224	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0x81bf4635	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0x81c6ba7c	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x81cd7ac8	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0x81e15db9	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x8206005c	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x8216b275	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x82207f98	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x82270f27	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x822ad4c7	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0x822d11a0	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0x824b3da0	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x824c84cf	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x82560d6e	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x825db2e9	of_irq_to_resource_table
++EXPORT_SYMBOL_GPL vmlinux 0x8267f3ca	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x827c0e96	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x827d7a4d	of_get_fb_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x8281993f	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8297a75d	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0x82a5ab06	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x82a985c0	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0x82ba473f	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x82d5804b	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82ec98d5	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0x82fb2ffd	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x82fc0e5e	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x8324ad5b	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x83497fa0	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x83664acb	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x836d61d0	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x8396f8c6	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0x83ab4a5e	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x83b595a0	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x83ccf444	rio_request_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x83d559ce	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x83f517ef	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x83ff330c	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x841da239	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x841f7719	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0x8443e54d	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0x8475cc67	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x85302ece	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x853bd46b	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0x853ecb45	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0x854dbc42	generic_access_phys
++EXPORT_SYMBOL_GPL vmlinux 0x856832c5	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0x8574ca6c	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x858737ec	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x85a816d3	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x85bcdfc3	of_thermal_is_trip_valid
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85cad788	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x861a8cff	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x863400e8	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x864a6f64	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x8652110e	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x86d3e33f	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0x86e18b39	pmf_do_functions
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x86f8f96e	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0x8724a64a	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x8727fcdb	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x8733a77b	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x873a6389	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x87447e1e	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x8772fd82	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x878ea6a9	mpc8xxx_spi_tx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x8795f2d4	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x87b65b34	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x87ce870b	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x87ded105	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0x87ecfbfe	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0x87f4bedc	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x87fda8e6	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0x8804af3d	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x8819caa2	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0x881dad12	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0x882e08b2	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x883c2f44	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x88605956	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x88987bd3	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x88a2d521	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88fec0f8	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x89008de3	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x89022e19	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x89055b4a	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x8932e4bb	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0x893c9b6c	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x8953daf5	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x89788b31	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x89b468aa	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89e822a7	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0x8a17ea59	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0x8a1ef667	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x8a325748	of_get_pci_domain_nr
++EXPORT_SYMBOL_GPL vmlinux 0x8a554a36	mpc8xxx_spi_strmode
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a5f86ce	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x8a63f59b	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x8a68f2a1	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x8aaac3f4	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8ac0da69	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0x8af78f75	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x8b35d005	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0x8b428e41	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0x8b5a0aa4	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x8b646c95	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0x8b65db2d	rio_local_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x8b70e8ea	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x8b7ab438	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8b91f7a7	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x8b9526f7	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x8b991115	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x8be506d1	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x8bff232d	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c3b852d	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x8c5d2905	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c72a384	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8caebfa1	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x8cb11d56	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0x8ccbffd0	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8cec16ab	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0x8cf3835b	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x8cff30cf	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x8d04ac93	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x8d4605ac	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0x8d512dda	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x8d78960c	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d88b680	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0x8d9177e0	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x8d94fc5f	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0x8da17b42	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x8dab4462	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0x8dc89ece	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x8dca0b01	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0x8dcc1455	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x8dfd5821	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x8e13ed25	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x8e1f30e9	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0x8e2b25c2	videomode_from_timings
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e3579d1	rio_mport_send_doorbell
++EXPORT_SYMBOL_GPL vmlinux 0x8e370722	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x8e3d39df	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0x8e7156e5	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x8e893858	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x8e959503	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x8e9599ae	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0x8e97164f	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0x8ea3895c	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0x8eb4e54d	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0x8ede01ca	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x8ee84aa8	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8eeadaae	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f0abf1a	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x8f1caeea	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0x8f2f375c	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0x8f64ed30	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0x8f6a65da	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0x8f6b3615	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f736277	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8fa01a6e	of_prop_next_u32
++EXPORT_SYMBOL_GPL vmlinux 0x8fa49d18	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x8fb20c2a	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x8fced602	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0x8ff6d391	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x90027a04	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0x9022d5bc	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x905c54c3	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x906079b7	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x9065e685	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x9069dd04	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x9077d5ea	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x908e55f1	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90a609d9	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x90b8f2d9	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0x90c5a370	cpufreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x90c80d84	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x90e010db	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0x90e244c9	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x90f385bb	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x911827e0	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x911e546e	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0x9166e585	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x917fe53e	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x91965753	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x91c3e10f	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91d7a592	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0x91d90064	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0x91eb0973	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x91ec17b9	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x92134026	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0x92211a0e	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x923d7364	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x9254b7e2	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x9280ea81	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x92b57248	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92e31443	rio_release_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x92e7be34	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0x92f6e4b6	__ktime_divns
++EXPORT_SYMBOL_GPL vmlinux 0x930d7ad4	rio_release_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x9337b121	__rio_local_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x93520081	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x93552271	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x935d4fc7	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x9360774a	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x9375c755	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0x9396b61b	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x939daa81	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x93a2cb47	reserve_pmc_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x93bf2fcd	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x93e10cd2	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0x93f585b7	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0x9410b727	of_irq_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x94219653	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0x9432b036	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x945b4440	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x94abb745	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0x94c2d37f	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x94e09882	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0x94ed923e	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x94f5768f	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x950a9ff1	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x95156028	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x95695777	of_pci_get_devfn
++EXPORT_SYMBOL_GPL vmlinux 0x95868e5c	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x95953b65	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95cb50fb	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x95f8b7a5	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x961990ef	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x96434782	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9655b911	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x967dda1d	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x9685f04d	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x9697ec54	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0x96a5d2f0	of_pci_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x96e62551	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x96f33408	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x972c869f	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x974c8ab9	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x9759e417	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x976a167c	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x978c916c	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x979c43c1	dax_do_io
++EXPORT_SYMBOL_GPL vmlinux 0x97c2731c	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x97c56c03	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x97d69893	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x97ebd307	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0x982cd486	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x982d06be	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x986a25a4	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x98866151	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0x989eb047	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x98c17a3f	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x98c84e5d	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x98cf1096	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x98dd8f97	of_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x98e60e93	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x992058f5	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9923c77c	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x992c5ec7	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x994d9bb2	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0x994ff461	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x995d03e1	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x996219c7	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x998113e7	phy_pm_runtime_put
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x999b0273	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x999d69bf	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0x99a76f2e	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0x99a9ff9a	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x99b71976	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99ce0592	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x99e588f2	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x9a0d1e21	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a19a4d6	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x9a274704	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9a49d937	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0x9a72733f	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9a8eb30d	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x9aac2cae	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x9aad6540	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9ac5d775	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x9ac7df64	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0x9ae9dd1b	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9aee82f1	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9af9dc67	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0x9afc2312	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x9b13c259	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x9b21adba	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9b593e18	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x9b9f8dc1	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x9be233d5	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9bf7c45e	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x9bf97958	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x9bfb0a35	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0x9bfe9c50	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0x9c42d3e1	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0x9c437c22	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x9c4f477f	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0x9c50d83a	device_create
++EXPORT_SYMBOL_GPL vmlinux 0x9c6fba37	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cce8fba	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9cd4fb97	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x9ce1ec67	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0x9cf76296	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9d0b0bcf	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x9d284ce9	dax_fault
++EXPORT_SYMBOL_GPL vmlinux 0x9d8331c0	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x9d848060	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x9d96bfbd	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x9da4c7cd	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9dc2100d	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0x9ddcd339	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x9df3247c	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x9dfdf722	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0x9e131d11	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0x9e23a6a2	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0x9e28a7fc	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e574b44	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x9e669778	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9e79d147	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9e7db457	of_thermal_get_ntrips
++EXPORT_SYMBOL_GPL vmlinux 0x9e8fd67e	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x9e957ab0	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x9ea9384f	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9eaf9af3	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x9ecc9e53	rio_mport_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x9ed4b9ff	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9f2a5e45	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9f3c101f	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0x9f4d89c1	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0x9f4e741f	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x9f624f52	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x9f6252d4	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x9f67cbb6	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0x9f7bd494	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x9f8e974e	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0x9f9820d1	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fd26be9	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0x9fdc3472	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9fffdfb5	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0xa00d50cc	rio_mport_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xa041d336	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xa0466f41	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xa05d8f27	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0xa071e996	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xa07dd7a0	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa0858f38	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xa0a3d7c4	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0xa0ab0347	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0xa0df2e10	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xa0e46049	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0xa111b58e	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa14f1ff0	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0xa1767b76	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa190a5a9	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xa1bad50e	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0xa1d1cd96	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xa2109526	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0xa21467da	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xa238f5b2	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0xa241c3ce	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0xa2567b36	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xa26519dd	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2d6d5f2	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xa31186d2	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0xa32aae0f	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0xa3429fda	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0xa35c0012	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0xa36474c9	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0xa36d0082	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xa37fae62	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0xa37fd2d6	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3a2d9af	walk_system_ram_range
++EXPORT_SYMBOL_GPL vmlinux 0xa3b123de	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3d74c23	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa3ee061c	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0xa4297286	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xa442782d	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0xa46b1d56	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa4929627	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0xa4b058d7	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa4cc339b	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0xa4dd1901	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xa517e281	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa52f02aa	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0xa53be3f8	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0xa54c1b15	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0xa550a215	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa56715ea	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0xa56e8176	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0xa58fd333	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0xa5a4fc01	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0xa5a600d5	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0xa5b00659	ppc_proc_freq
++EXPORT_SYMBOL_GPL vmlinux 0xa5e7e6a2	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5efe460	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xa5fcba71	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa649155e	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa64f8392	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0xa65513ff	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0xa65be306	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0xa662219e	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0xa6781de3	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xa6782545	of_platform_depopulate
++EXPORT_SYMBOL_GPL vmlinux 0xa6786733	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0xa6817310	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xa69353a4	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xa693a581	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xa69edc2e	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6bbb931	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xa6dafa72	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa6ea722c	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0xa6fd06d2	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0xa71f8037	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xa72d3e2b	__rio_local_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xa74cd26f	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa7523096	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0xa779239d	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0xa79fb7c2	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xa7b833a8	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0xa7c73b76	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0xa7cf54c5	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0xa7d2062f	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0xa7e498b8	__rio_local_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xa7eada40	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0xa7ebebaa	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0xa7f344ae	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0xa7f9fd35	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xa800be91	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0xa8244fba	of_property_count_elems_of_size
++EXPORT_SYMBOL_GPL vmlinux 0xa8351769	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xa843bf1c	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa87e09e8	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xa8a2d87d	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0xa8a930c4	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0xa8aeef3e	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0xa8b5b3ff	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8be0b4a	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa8c8f9ea	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0xa8cb6e10	dax_zero_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xa8cbd34c	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0xa8cf8b96	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa8dcab55	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xa909f30b	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0xa90c0a0a	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0xa91603b1	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa9715729	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0xa9774bd3	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xa9e16298	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9f6ec95	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xaa0abbe6	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0xaa0c5a7c	of_prop_next_string
++EXPORT_SYMBOL_GPL vmlinux 0xaa1e6013	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0xaa1f6be5	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xaa2423df	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xaa273c20	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xaa2a72bf	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0xaa643af4	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0xaa6f1358	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0xaa79ed75	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xaa7b31fd	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0xaa8d5dd9	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xaa98ac79	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaad27f49	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xaafe8ad1	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xab0c4bc1	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0xab0ebdb1	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0xab107007	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0xab29ad96	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0xab3866c3	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0xab42dfcb	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab6b6e24	pmac_i2c_get_controller
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab6ccfe5	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0xab6f807b	cpu_add_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0xab85e810	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xab8950a0	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xab945a16	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabc81522	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0xabd3d40c	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0xac01d5f3	of_get_nand_ecc_strength
++EXPORT_SYMBOL_GPL vmlinux 0xac13b37a	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0xac224395	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xac238eee	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xac629180	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0xac8b0111	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0xaca09f4d	of_usb_host_tpl_support
++EXPORT_SYMBOL_GPL vmlinux 0xacb3a398	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xacb8ca4b	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xacd86df4	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xace8cb8c	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0xad73b1b0	of_gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xad934d96	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadd7a204	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0xade94bc8	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xadfdb817	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0xae03869c	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0xae237398	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0xae2c25f9	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0xae2cacb0	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae81922b	of_overlay_destroy_all
++EXPORT_SYMBOL_GPL vmlinux 0xae895d73	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xae9382d2	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0xae980e9e	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xae9e1871	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0xaea21284	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xaea82c69	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0xaeac4d8d	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0xaeca3802	of_scan_bus
++EXPORT_SYMBOL_GPL vmlinux 0xaeddf315	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xaee23717	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0xaef7d633	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xaf013f85	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0xaf0e2d99	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0xaf339ecf	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0xaf38a119	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xaf3e26b1	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0xaf8fcf5e	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xafa0fe1d	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0xafd2d77d	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0xafd55a86	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xb0087df9	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0xb0259a0a	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0xb03014bf	agp_remove_bridge
++EXPORT_SYMBOL_GPL vmlinux 0xb03ebc11	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb045e816	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0xb04e8036	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xb0729a27	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0xb0749553	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0xb0776eb3	rio_unregister_scan
++EXPORT_SYMBOL_GPL vmlinux 0xb085cd95	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0xb0913148	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xb0a8af43	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0d52d07	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0xb0f0a897	of_pci_range_parser_one
++EXPORT_SYMBOL_GPL vmlinux 0xb1054fcb	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0xb11298ac	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0xb124fe08	md_run
++EXPORT_SYMBOL_GPL vmlinux 0xb13155b5	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb1434233	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0xb151eecb	rio_dev_get
++EXPORT_SYMBOL_GPL vmlinux 0xb1776638	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0xb182c568	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1d43e53	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1f29dd2	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0xb202c1c3	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xb219cbfd	rio_register_scan
++EXPORT_SYMBOL_GPL vmlinux 0xb2208140	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb2256567	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0xb258f761	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0xb288a472	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0xb2b89a02	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xb2cc445a	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0xb2d3d50d	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb2fcd0fc	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xb3047da1	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xb35a8a16	pcibios_scan_phb
++EXPORT_SYMBOL_GPL vmlinux 0xb3864d23	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0xb394e400	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xb399160b	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0xb39a1aec	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0xb39b0c8d	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xb3c0100d	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0xb3c39294	of_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xb3e48e8d	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0xb3eb695d	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0xb3febfbe	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xb40d8d8f	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xb42005af	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0xb4236126	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0xb444dcfe	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0xb488588e	tb_to_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb490bac5	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0xb4910876	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xb4acdc98	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4bd2b58	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb51f98d7	pmac_i2c_adapter_to_bus
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb52f6d3b	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb53076ea	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb5476a29	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xb54d40db	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xb5640fe6	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0xb57c50eb	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0xb58351ac	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xb586068c	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5aa10af	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb5c8edf4	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0xb5cf2891	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0xb5cf8048	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0xb5e896fb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0xb5ef3d74	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb60b5707	of_i8042_aux_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb6407e18	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xb691037f	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb7019d47	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0xb711d130	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xb721f82a	cpu_remove_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0xb73ff574	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xb751e835	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xb75b75c8	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xb78e2564	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb79fb656	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xb7bb1362	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xb7c15f46	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xb7ed2e3a	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0xb7f62536	input_class
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb809b9ee	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xb80f02e5	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xb80f03b0	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0xb83cd863	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb84b772e	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xb85518c2	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0xb883206b	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb88530df	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0xb8883049	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xb88d1f4f	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb88fb2ad	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xb893be36	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xb8aeab00	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0xb8c0b52a	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8d3886e	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xb9176155	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0xb92427b4	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb93d9b3e	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0xb94288a9	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0xb9554b91	arizona_of_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xb961abf1	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb96b3bc6	of_get_display_timings
++EXPORT_SYMBOL_GPL vmlinux 0xb977e6f5	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xb99431a0	pmf_register_irq_client
++EXPORT_SYMBOL_GPL vmlinux 0xb9b40afd	of_get_videomode
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9cfafc8	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xba07fc0d	of_dma_router_register
++EXPORT_SYMBOL_GPL vmlinux 0xba0954b8	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xba158769	rtas_cancel_event_scan
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba402666	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0xba67b697	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xba8542ac	agp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0xba8929ea	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xba8e0d7c	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0xbab66788	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbaecd8c1	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb1b2834	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xbb6d0763	of_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xbb7cf9cb	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0xbb7d312c	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0xbbcbfd79	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xbbf0d7a9	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0xbc0f3ef6	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0xbc259699	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0xbc3fc80d	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0xbc5095ee	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0xbc5b375f	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc79f19b	rio_mport_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcb3abd8	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0xbcd0168e	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xbcf01d60	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0xbcf3f0cd	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0xbcf7b269	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0xbd2c69ac	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd73682c	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xbd7d241a	rio_mport_get_efb
++EXPORT_SYMBOL_GPL vmlinux 0xbd823dbd	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0xbd8c5546	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0xbda27e93	user_update
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbde8dc00	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0xbdf04637	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xbe091a4a	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe2712bc	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xbe275630	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0xbe5bbf43	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe6ec091	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0xbe70e7f9	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0xbe909f3c	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xbe96dfd8	of_reconfig_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbe9f2f9a	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbebbf598	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xbec8c13e	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0xbec9871c	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbeeac8f3	of_dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xbeee1d26	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xbf02e3c4	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf106cd7	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0xbf1152a4	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xbf1cc04b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xbf322287	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xbf33ef24	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0xbf582a36	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0xbfaa65f6	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfc5db12	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0xbfc98020	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0xbfcf66b2	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0xbfd4ab18	of_fdt_unflatten_tree
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xc00131cf	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0xc02bec3c	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xc05b91af	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc060c26e	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0xc061367e	mpic_msgr_get
++EXPORT_SYMBOL_GPL vmlinux 0xc065a455	cpu_core_index_of_thread
++EXPORT_SYMBOL_GPL vmlinux 0xc0750e75	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0xc07ac5fb	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc08b1bc4	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xc0a83b48	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0e09e10	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0xc0e17744	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xc0e75cec	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0xc0e7cf6a	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc0f532b8	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0xc10323e4	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xc13244c1	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0xc1444efe	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0xc161027b	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0xc16b70e0	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc175c017	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xc17baa8b	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0xc17fcec6	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xc18578ed	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xc1a2fbd6	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xc1ac131c	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0xc1c873aa	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0xc1cb27ea	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xc1d7e9b3	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0xc1dd3787	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc222ffa9	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc22a9a00	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xc244458a	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc2899bed	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0xc2ad582a	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0xc2b6bf37	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0xc2c25342	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xc2e728dc	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0xc30b3a36	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0xc31cb213	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc365524c	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0xc36d0c9a	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xc37013f9	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0xc37120e7	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc3a730e8	of_dma_xlate_by_chan_id
++EXPORT_SYMBOL_GPL vmlinux 0xc3aa0a68	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0xc3b43464	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xc3b83445	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xc3c7744f	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xc3ec0688	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0xc3ed476a	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0xc3f4d4dd	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xc4133b65	pmac_i2c_get_dev_addr
++EXPORT_SYMBOL_GPL vmlinux 0xc41fb015	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc430fe46	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc4398102	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc448aba3	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0xc44a0101	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc465ac6a	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xc46d4261	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc47ca3cc	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc47ec678	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xc48aa3cb	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc495ce7e	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0xc4a20df5	of_display_timings_exist
++EXPORT_SYMBOL_GPL vmlinux 0xc4bf263d	pmf_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc51a8a3e	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xc51bcd4b	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xc51d9a42	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0xc535e958	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc58014b4	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc58698bb	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0xc58a1687	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xc58d9872	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0xc591505d	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0xc5942d8b	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0xc5a2c19f	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc5be5715	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0xc5c51471	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0xc5ca93d6	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0xc5cb70a6	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0xc5da6c8d	of_css
++EXPORT_SYMBOL_GPL vmlinux 0xc606cd3c	boot_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0xc60a5d71	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc627431a	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xc62aa507	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0xc636c289	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc683dc62	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0xc68aa252	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6bd7603	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xc6e106c7	of_pci_msi_chip_add
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc74a6afe	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xc7539563	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0xc7574605	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0xc7612f76	rio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc765cfcf	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0xc773f169	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0xc785bb73	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc78c2a85	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0xc79aa2c5	rio_request_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7c4343c	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7c7f65a	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc7c97770	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xc7d52934	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0xc7dee16e	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7f7134c	of_cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xc845b1c8	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc87e2d7a	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xc8872b04	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xc88c702f	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xc8901483	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8b5fd6d	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xc8c15b64	of_get_display_timing
++EXPORT_SYMBOL_GPL vmlinux 0xc8c4a014	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0xc8cb1bc1	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xc8d94660	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0xc8de6574	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc8dfecbc	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xc8e1a7d2	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xc8f77f02	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xc8fb92ec	of_usb_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc914fd76	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0xc9274d3b	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc94317b7	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc9775dd1	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xc979082a	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0xc97d1140	cpufreq_cooling_get_level
++EXPORT_SYMBOL_GPL vmlinux 0xc97e9bff	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0xc987d63f	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc99f6c4a	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0xc9bf4a0b	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc9cbdd16	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc9fbe48b	pmac_i2c_match_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xc9fd04d3	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0xca06f41f	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0xca37f247	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca8c6456	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcacc82a0	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0xcadec66e	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0xcaf0fda2	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xcb03796c	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb4238fb	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0xcb469b0f	rio_unlock_device
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb5ad1f7	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0xcb5c100e	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xcb5ee621	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0xcb8a27bf	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0xcb8e6c0c	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0xcbd2cff6	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbe98057	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcc0f1009	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xcc207440	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0xcc26a7a8	of_mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0xcc392799	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcc5cddc4	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0xcc763ff9	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcca9151c	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0xccb23974	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccd893d6	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0xccec6ef2	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0xccfb314a	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0xcd045a5a	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0xcd04829a	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0xcd0b4333	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcd1645c2	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0xcd25bcbf	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xcd606430	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcd6492ab	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0xcd6b4079	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xcd6ea7f0	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0xcd71905d	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xcd761f8e	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdc55e56	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcddb7318	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0xcde99e57	of_usb_update_otg_caps
++EXPORT_SYMBOL_GPL vmlinux 0xcdea86c4	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xcdeb02e8	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0xcdee34f2	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0xce09f8d3	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0xce372532	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0xce3f8250	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xce407f5d	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0xce4ff3b0	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0xce5082f2	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce754228	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0xcebb760a	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0xced51941	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcee6b939	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0xcef282b4	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0xcf030ccb	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf5968c3	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0xcf5ff1f7	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xcf6d315e	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xcf733e2d	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xcf867ad2	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xcfb0f4bb	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfd63f2d	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0xcfdfa1f8	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0xcfe279f1	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xcfe3e31f	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd0534156	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd0578abd	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0xd058f0de	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd0698087	arizona_of_get_named_gpio
++EXPORT_SYMBOL_GPL vmlinux 0xd06b0444	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd098177a	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0f8b366	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0xd11bfe23	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xd13119f2	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xd133efbb	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xd13f27c1	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0xd14297c4	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0xd163faec	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd1822f0b	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd18fa4ab	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd1a28c6c	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0xd1e6386c	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd1fc05ec	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd23775a8	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0xd24a560f	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xd267d2de	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0xd26f0ad1	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd2aa5248	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0xd2aaeb4e	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xd2ba68d1	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0xd2ca18d1	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2e8176a	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xd2e9d20c	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd2f7b515	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0xd338402e	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0xd34f2105	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xd3556393	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd3595ea8	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xd37ba6f5	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0xd39a1262	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xd3ac8ff6	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3cabe1d	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd3d1929e	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0xd3fa0439	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd407cb28	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd4435ecd	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd44baafb	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xd49640cd	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd4b30939	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4d68cbe	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xd4f9e975	pmac_i2c_get_bus_node
++EXPORT_SYMBOL_GPL vmlinux 0xd5200aa5	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0xd525aa94	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xd547dc26	rio_release_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xd54fd9f7	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0xd55d3dbc	pcibios_alloc_controller
++EXPORT_SYMBOL_GPL vmlinux 0xd56447b9	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0xd5651c6f	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0xd56e298d	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0xd58cdeb2	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0xd59ec5aa	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xd5a961b3	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd5b85c98	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5c41300	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0xd5cb3184	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0xd5ddba57	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd62608d6	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd635534d	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xd660b23a	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd698bd2f	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0xd6b8a589	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0xd6ce08e8	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0xd6d8d136	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0xd6feefa5	agp_num_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd70bb12c	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0xd70fae32	to_of_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0xd7109225	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0xd71c9b9a	of_irq_find_parent
++EXPORT_SYMBOL_GPL vmlinux 0xd7260c3a	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xd72e1059	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd76dcee5	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0xd77a0bf6	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd78cc2ee	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xd79edba5	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd7aabeea	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7df0779	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xd7fc3e98	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd8081ede	power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xd8101e9a	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0xd81db1c8	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd83fb8f5	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0xd840bea8	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0xd84ef47d	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0xd85d80d0	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0xd87062e7	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd879a61c	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0xd87a8074	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd88741a6	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xd89d064a	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xd8a2ad14	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0xd8b027d3	pmf_do_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd8efaa42	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xd8ffb0e5	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0xd91ae4a4	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xd9266981	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94aa457	display_timings_release
++EXPORT_SYMBOL_GPL vmlinux 0xd96731c1	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd98287aa	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0xd99ecef1	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xd9a03dff	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xd9b1b613	rio_mport_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xd9b54bad	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd9bc8bf6	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xd9d49f7e	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0xd9dbe3ea	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xda0a4d22	mpic_msgr_enable
++EXPORT_SYMBOL_GPL vmlinux 0xda3aac85	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0xda452d1d	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0xda70f829	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0xda74daaa	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xda92fee8	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0xdae715e0	videomode_from_timing
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaf15614	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdaf9af8e	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0xdafe8a3e	rio_release_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xdb088cb1	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0xdb0f6588	mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0xdb1a0469	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0xdb38c9fd	of_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb46966a	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0xdb6ff415	check_media_bay
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb8b0e76	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0xdbb31eba	isa_bridge_pcidev
++EXPORT_SYMBOL_GPL vmlinux 0xdbb52197	pcibios_finish_adding_to_bus
++EXPORT_SYMBOL_GPL vmlinux 0xdbc41088	rio_dma_prep_slave_sg
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc0f470f	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0xdc24133e	of_regulator_match
++EXPORT_SYMBOL_GPL vmlinux 0xdc2f8f4d	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0xdc461430	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xdc714d88	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0xdc7cc78f	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc8b2cfb	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdd0bb7f3	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd5d9382	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xdd601b4c	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0xdd654e95	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0xdd69ea31	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0xdd729424	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xdd7e279d	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0xdd8d956d	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xdda9bf53	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0xddaba5d5	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddbf62d1	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xddd85c5d	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xdde15a84	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0xdde3e4ee	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xde19fabf	of_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xde1b65c7	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0xde1f1c7a	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xde200c37	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xde29238f	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0xde3dd92a	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xde5d6d5d	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xde7585ae	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xde81afd6	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0xde9463a6	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xdea3674d	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0xdebec061	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0xdedb933d	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0xdf0c3252	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf10f04b	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0xdf19b31e	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0xdf1d2145	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xdf2280d1	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0xdf6469e8	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0xdf88419b	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0xdf9713cf	rio_route_clr_table
++EXPORT_SYMBOL_GPL vmlinux 0xdf9e6ce0	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0xdfadc947	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0xdfaff15d	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe030360d	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0xe036b3e9	mpic_msgr_put
++EXPORT_SYMBOL_GPL vmlinux 0xe055c1ce	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe07ca631	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0xe089cfcc	agp_memory_reserved
++EXPORT_SYMBOL_GPL vmlinux 0xe0b21b2b	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xe0cc138b	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe0d98f54	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0xe101fe78	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xe1083ae3	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0xe111ed84	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0xe121cbb6	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe1a2968e	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xe1bd6c99	rio_init_mports
++EXPORT_SYMBOL_GPL vmlinux 0xe1ca2497	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0xe1d7847a	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0xe1fb4e81	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0xe20c797c	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xe20ec0a6	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0xe216b8aa	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xe2209e83	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xe23b6342	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xe2604ca6	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0xe267852c	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe28d6191	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0xe2b484c9	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0xe2d6dc3d	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0xe2e33766	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0xe2f92ff1	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe324c93b	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0xe34c8e29	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xe360fcdd	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0xe401d6a1	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe41a0418	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0xe41f29a7	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xe424c368	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe4395f4f	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe44839ec	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0xe44e254f	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe464bafe	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0xe4650185	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe47bb261	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe4a0d7af	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xe4c031f8	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4ca5e04	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0xe4f54dd3	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe5041465	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0xe50ab7a9	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0xe513a622	dax_pfn_mkwrite
++EXPORT_SYMBOL_GPL vmlinux 0xe52fdb53	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0xe54c9ce3	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe55cccb4	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0xe56d1991	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe63d3fe1	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe659ebd0	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xe671f33c	pmac_i2c_get_channel
++EXPORT_SYMBOL_GPL vmlinux 0xe67d2745	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xe68120ea	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6c91789	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6e68af5	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe713d194	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0xe7145917	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0xe727261e	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0xe7435ec7	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe76deb64	rio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xe7731187	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0xe7772da8	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe7e10ff0	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xe7f18b3c	threads_per_subcore
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe804be77	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0xe8136b03	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe8295791	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0xe833925e	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0xe83846f7	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xe83c88b5	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe852e3f1	of_dma_is_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xe85bf7ad	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe85c55e7	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe86cf402	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0xe8823968	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0xe8a1ca79	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe8befaa9	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xe8cc480a	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0xe8d15cbc	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0xe8df0f12	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0xe9019d67	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe9122648	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0xe925ce8b	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe949aba1	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0xe950d630	rio_mport_get_feature
++EXPORT_SYMBOL_GPL vmlinux 0xe95970cd	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0xe97a9221	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xe988639a	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0xe995cdbf	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0xe9a394a3	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xe9b806d1	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0xe9bf81b2	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xe9d6f583	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xe9ffa90b	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea3382a7	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea55d540	of_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0xea59e3a4	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0xea5ab564	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0xea6ff3d3	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xea7f0317	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xea9ffc3a	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0xeac6c897	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0xeacbe789	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0xeaeb0b37	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xeaf2b40d	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0xeaf5c3d0	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xeb1232b7	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xeb156eb2	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0xeb20f04a	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xeb4fa8d1	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0xeb59bc5b	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0xeb6668e8	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xeb818a3b	rio_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xeb8232ad	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0xeb873ef9	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xeb8ae736	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0xeb9abbee	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xebb3592b	snmp_get_cpu_field64
++EXPORT_SYMBOL_GPL vmlinux 0xebc907f4	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xebcff2b5	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0xebd2fcb5	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xebdb31d4	analyse_instr
++EXPORT_SYMBOL_GPL vmlinux 0xebdb4a60	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0xebe8da0c	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xebf747aa	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0xec0626ef	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0xec131735	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec438c08	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0xec5e394c	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0xec67c170	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xec67f959	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xec6b6d7a	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xec787388	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0xec90dd70	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0xecada5f8	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0xecd1505e	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0xed06c5cb	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xed0c9486	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xed20b937	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xed6ff5cc	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0xeda1e18b	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0xedb62d1a	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xedbc8e1c	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0xee06027f	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xee266181	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0xee297f30	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xee3a0813	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0xee4a5e4f	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0xee4bb253	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xee5d01d7	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xeedf1895	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xef004b62	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0xef302165	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xef30da36	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0xef409b74	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0xef464c28	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0xef47d3d9	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xef942120	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefbe39a1	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0xefdbbcc7	of_modalias_node
++EXPORT_SYMBOL_GPL vmlinux 0xefe969b9	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xeff4a5ac	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0xf0229870	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf05b55bf	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xf063dee0	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf076ec5e	pcibios_free_controller
++EXPORT_SYMBOL_GPL vmlinux 0xf08babfd	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0d25224	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf0e5f357	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0xf0f10f0e	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xf0f2f7ca	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0xf0f44387	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf147805c	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xf14ecc29	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0xf158f170	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0xf167cdd4	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0xf16c905c	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0xf1827755	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf194da75	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0xf19613d0	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xf1a23f60	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xf1a62b6f	of_i8042_kbd_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1f451b4	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0xf2196393	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf2266c5b	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0xf2491a60	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xf2560a4e	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf26e743d	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2aeb299	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xf2bc411b	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xf2c172be	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xf2dce357	rio_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xf2ebad95	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf30f9ec3	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0xf30fda27	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf3146860	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf3285cd0	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf33934f5	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0xf3532f86	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xf361a2f9	of_dma_configure
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf37bb863	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf3866e49	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3b58f52	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3c185d4	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xf3c27e1e	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0xf3d681cd	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf3f2ec87	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xf4149040	rio_mport_class
++EXPORT_SYMBOL_GPL vmlinux 0xf4279574	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0xf4517626	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xf469a39a	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xf46dc91f	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xf48363b7	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0xf485734d	rio_get_asm
++EXPORT_SYMBOL_GPL vmlinux 0xf48892e2	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4b333d1	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xf4cdfd72	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0xf4fb067b	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf50762c8	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf515abf1	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0xf51f966e	macio_find
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5bcf1b2	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0xf5c01d81	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xf5dba021	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xf5e1788f	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0xf5e3fbc3	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xf607999b	of_property_read_u32_index
++EXPORT_SYMBOL_GPL vmlinux 0xf6135f65	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xf61e0d63	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0xf62dc9ae	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0xf65ad08f	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0xf65bd316	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0xf6b64bd6	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6d099f0	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xf6dafb45	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf6dd55cf	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xf6dffa7e	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xf6e101d8	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf6f33faf	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0xf7014f40	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0xf7023a4f	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0xf73a0d3c	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xf74798ec	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xf7b70d51	pmac_i2c_get_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xf7d0d0dd	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0xf7dae5ad	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf8058437	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xf81095f0	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0xf815dde2	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf81ec85a	of_console_check
++EXPORT_SYMBOL_GPL vmlinux 0xf8228c96	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0xf82f16b3	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf846506f	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf87c597d	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0xf87cd561	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf882f0fb	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf8b36190	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0xf8d0588b	pmac_i2c_find_bus
++EXPORT_SYMBOL_GPL vmlinux 0xf8e6b564	hibernation_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf911938f	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xf91eac65	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0xf91fe42d	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf92f0b78	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf9451cd5	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0xf94d8995	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0xf95228fe	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf989589a	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9a057bc	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0xf9c1bd7a	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0xf9c1ed35	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xfa0561f3	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0xfa1e4dc2	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa535c75	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xfa6397bd	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xfab60503	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0xface9ced	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xfacf62a8	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xfad18aa1	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0xfae7c7c2	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xfaf4a179	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0xfaf6bd8f	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xfb1eb1e7	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0xfb2b0d7f	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb33e7b0	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xfb525dfc	pmac_i2c_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xfb52b77d	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0xfb6d63e0	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xfb6e3b4f	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfba8af45	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0xfbaee8cd	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfbded78f	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc174e11	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0xfc368b5e	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0xfc36e4e6	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xfc5a41b6	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xfc604090	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0xfc626275	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0xfc725f7b	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0xfc879e17	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xfc8ae125	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0xfc8b8e50	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0xfcaaf38e	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0xfcf0710e	mpc8xxx_spi_rx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0xfcffb4e1	pmac_i2c_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0xfd19f697	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xfd25c5ca	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0xfd490148	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xfd511512	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xfd6ef889	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd7fe2f0	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0xfdd9e083	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0xfdf729c5	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0xfe2c68a4	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0xfe597a2a	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0xfe5a9988	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0xfe62aac9	cpu_add_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0xfe6b324d	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0xfe6b4b69	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xfe839349	of_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfe9b182d	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0xfec25f2e	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfeea796a	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0xfef1a9b2	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff4e35ba	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0xff5155db	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff5e80d5	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff66b080	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0xff7fe382	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0xff81eb55	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0xffb2aafd	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffc1fb7b	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0xffdd7d6c	of_pci_range_parser_init
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp.compiler b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp.compiler
+new file mode 100644
+index 0000000..d1936f3
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp.modules b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp.modules
+new file mode 100644
+index 0000000..3c43d2c
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc-smp.modules
+@@ -0,0 +1,4318 @@
++3c574_cs
++3c589_cs
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_dw
++8250_mid
++8255
++8255_pci
++8390
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++BusLogic
++DAC960
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++ac97_bus
++acard-ahci
++acecad
++acenic
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7170
++adv7175
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++ah4
++ah6
++aha152x_cs
++ahci
++ahci_ceva
++ahci_platform
++ahci_qoriq
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airo
++airo_cs
++airport
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++ali-ircc
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am53c974
++ambassador
++amc6821
++amd
++amd5536udc
++amd8111e
++amdgpu
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams
++ams369fg06
++analog
++anatop-regulator
++ans-lcd
++ansi_cprng
++anubis
++aoe
++apbps2
++apds9300
++apds9802als
++apds990x
++apds9960
++apm-emulation
++apm-power
++apm_emu
++apm_power
++appledisplay
++appletalk
++appletouch
++applicom
++aquantia
++ar1021_i2c
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_emac
++arc_ps2
++arc_uart
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3722-regulator
++as3935
++as5011
++asc7621
++ascot2e
++asix
++ast
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++ata_generic
++ata_piix
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atm
++atmel
++atmel-flexcom
++atmel-hlcdc
++atmel_cs
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp870u
++atusb
++atxp1
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avm_cs
++avma1_cs
++avmfritz
++ax25
++ax88179_178a
++axnet_cs
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1pci
++b1pcmcia
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_epp
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcma
++bcma-hcd
++bcmsysport
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluecard_cs
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmac
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpck
++bpck6
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmsmac
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bt3c_cs
++bt819
++bt856
++bt866
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btuart_cs
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++cap11xx
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_das16_cs
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipone_icn8318
++chipreg
++chnl_net
++ci_hdrc
++ci_hdrc_imx
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++clip
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cm4000_cs
++cm4040_cs
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmtp
++cnic
++cobalt
++cobra
++coda
++colibri-vf50-ts
++com20020
++com20020-pci
++com20020_cs
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_isadma
++comedi_parport
++comedi_pci
++comedi_pcmcia
++comedi_test
++comedi_usb
++comm
++configfs
++contec_pci_dio
++cordic
++core
++cp210x
++cpia2
++cpsw_ale
++cpu-notifier-error-inject
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc7
++crc8
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++csiostor
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_cs
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++db9
++dc395x
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++ddbridge
++de2104x
++de4x5
++decnet
++deflate
++defxx
++denali
++denali_pci
++des_generic
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++digicolor-usart
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9601
++dmfe
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++donauboe
++dp83848
++dp83867
++dpt_i2o
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dtl1_cs
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_wdt
++dwc3
++dwc3-pci
++dwc_eth_qos
++dwmac-generic
++dwmac-ipq806x
++dwmac-lpc18xx
++dwmac-meson
++dwmac-rk
++dwmac-socfpga
++dwmac-sti
++dwmac-sunxi
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++earth-pt1
++earth-pt3
++eata
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++echainiv
++echo
++edac_core
++edt-ft5x06
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efs
++egalax_ts
++ehset
++elan_i2c
++elo
++elsa_cs
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emac_arc
++emac_rockchip
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++empeg
++ems_pci
++ems_pcmcia
++ems_usb
++emu10k1-gp
++enc28j60
++enclosure
++encx24j600
++encx24j600-regmap
++eni
++enic
++epat
++epia
++epic100
++eql
++esas2r
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++ezusb
++f2fs
++f75375s
++f81232
++fakelb
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_sys_fops
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdomain_cs
++fdp
++fdp_i2c
++fealnx
++ff-memless
++firedtv
++firestream
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fixed
++fl512
++flexcan
++flexfb
++floppy
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fmvj18x_cs
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fsl-edma
++fsl_elbc_nand
++fsl_lpuart
++ft6236
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu_ts
++fusb300_udc
++g450_pll
++g760a
++g762
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcm
++gdmtty
++gdmulte
++gdmwm
++gdth
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++gf128mul
++gf2k
++gfs2
++ghash-generic
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-74x164
++gpio-74xx-mmio
++gpio-addr-flash
++gpio-adnp
++gpio-adp5520
++gpio-adp5588
++gpio-altera
++gpio-amd8111
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-fan
++gpio-generic
++gpio-grgpio
++gpio-ir-recv
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-rdc321x
++gpio-regulator
++gpio-syscon
++gpio-tps65912
++gpio-twl4030
++gpio-twl6040
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mouse
++gpio_tilt_polled
++gpio_wdt
++gr_udc
++grace
++grcan
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++gxt4500
++hackrf
++hamachi
++hampshire
++hanwang
++hci
++hci_uart
++hci_vhci
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfs
++hfsplus
++hi6421-pmic-core
++hi6421-regulator
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++hifn_795x
++hih6130
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi504_nand
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hopper
++horizon
++horus3a
++hostap
++hostap_cs
++hostap_pci
++hostap_plx
++hp100
++hpfs
++hpilo
++hpsa
++hptiop
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++htc-pasic3
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hwa-hc
++hwa-rc
++hwmon-vid
++hx8357
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd8111
++i2c-arb-gpio-challenge
++i2c-cbus-gpio
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-gpio
++i2c-hid
++i2c-hydra
++i2c-i801
++i2c-isch
++i2c-kempld
++i2c-matroxfb
++i2c-mpc
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-reg
++i2c-nforce2
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-piix4
++i2c-robotfuzz-osif
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i40e
++i40evf
++i5k_amb
++i6300esb
++i740fb
++i82092
++ib_addr
++ib_cm
++ib_core
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibmaem
++ibmpex
++icp_multi
++icplus
++ics932s401
++ideapad_slidebar
++idma64
++idmouse
++idt77252
++idt_gen2
++idtcps
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imm
++imon
++ims-pcu
++imx074
++imx6ul_tsc
++imx_thermal
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int51x1
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipwireless
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++irlan
++irnet
++irtty-sir
++iscsi_boot_sysfs
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it913x
++itd1000
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++kafs
++kalmia
++kaweth
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks0108
++ks0127
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l4f00242t03
++l64781
++lan78xx
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-adp5520
++leds-bcm6328
++leds-bcm6358
++leds-bd2802
++leds-blinkm
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-ktd2692
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max77693
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-pwm
++leds-regulator
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libahci_platform
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_cs
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++lis3lv02d_spi
++litelink-sir
++lkkbd
++ll_temac
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lmc
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac53c94
++mac80211
++mac80211_hwsim
++mac802154
++mac_hid
++macb
++mace
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mailbox-test
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++marvell
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max5821
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max77693-haptic
++max77693_charger
++max77802
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++md5-ppc
++mdc800
++mdio
++mdio-bcm-unimac
++mdio-bitbang
++mdio-gpio
++mdio-mux
++mdio-mux-gpio
++mdio-mux-mmioreg
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++mesh
++metro-usb
++metronomefb
++mf6x4
++mga
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microtek
++mii
++minix
++mip6
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmc_block
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi001
++msi2500
++msp3400
++mspro_block
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtd_dataflash
++mtdblock
++mtdblock_ro
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-sd
++mtouch
++multipath
++multiq3
++musb_hdrc
++mv643xx_eth
++mv_u3d_core
++mv_udc
++mvmdio
++mvsas
++mvumi
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxc4005
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxser
++mxuport
++myri10ge
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nci
++nci_spi
++nci_uart
++ncpfs
++nct7802
++nct7904
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_daq_700
++ni_daq_dio24
++ni_labpc
++ni_labpc_common
++ni_labpc_cs
++ni_labpc_isadma
++ni_labpc_pci
++ni_mio_cs
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicstar
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nmclan_cs
++nosy
++notifier-error-inject
++nouveau
++nozomi
++nps_enet
++ns558
++ns83820
++nsc-ircc
++nsp32
++nsp_cs
++ntb
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nvidiafb
++nvme
++nvmem_core
++nxp-nci
++nxp-nci_i2c
++nxp-ptn3460
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_xilinx_wdt
++ofpart
++old_belkin-sir
++omap4-keypad
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_cs
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++palmas-pwrbutton
++palmas-regulator
++pandora_bl
++panel
++panel-lg-lg4573
++panel-samsung-ld9040
++panel-samsung-s6e8aa0
++panel-sharp-lq101r1sx01
++panel-simple
++parade-ps8622
++paride
++parkbd
++parport
++parport_ax88796
++parport_cs
++parport_pc
++parport_serial
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_of_platform
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pcmcia
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sis
++pata_sl82c105
++pata_triflex
++pata_via
++pc300too
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_udc
++pci
++pci-stub
++pci200syn
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmcia
++pcmcia_core
++pcmcia_rsrc
++pcmciamtd
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcnet_cs
++pcrypt
++pcspkr
++pcwd_pci
++pcwd_usb
++pd
++pd6729
++pda_power
++pdc_adma
++peak_pci
++peak_pcmcia
++peak_usb
++pegasus
++penmount
++percpu_test
++pf
++pfuze100-regulator
++pg
++phantom
++phonet
++phram
++phy-bcm-kona-usb2
++phy-exynos-usb2
++phy-gpio-vbus-usb
++phy-isp1301
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-tahvo
++phy-tusb1210
++physmap
++physmap_of
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl2303
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8941-wled
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pmu_battery
++pn533
++pn544
++pn544_i2c
++pn_pep
++poly1305_generic
++port100
++powermate
++powr1220
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_core
++pps_parport
++pptp
++prism2_usb
++ps2mult
++psmouse
++psnap
++pt
++ptp
++pulsedlight-lidar-lite-v2
++pvrusb2
++pwc
++pwm-beeper
++pwm-fan
++pwm-fsl-ftm
++pwm-lp3943
++pwm-pca9685
++pwm-regulator
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa27x_udc
++qcaspi
++qcaux
++qcom-spmi-iadc
++qcom-spmi-temp-alarm
++qcom-spmi-vadc
++qcom_spmi-regulator
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qlogic_cs
++qlogicfas408
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quatech_daqp_cs
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++rack-meter
++radeon
++radeonfb
++radio-bcm2048
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-shark
++radio-si476x
++radio-tea5764
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++ray_cs
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++reed_solomon
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio-scan
++rio500
++rionet
++rivafb
++rj54n1cb0c
++rk808
++rk808-regulator
++rmd128
++rmd160
++rmd256
++rmd320
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-as3722
++rtc-bq32k
++rtc-bq4802
++rtc-cmos
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-generic
++rtc-hid-sensor-time
++rtc-hym8563
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max77802
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-msm6242
++rtc-mt6397
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-r9701
++rtc-rc5t583
++rtc-rk808
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-snvs
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-twl
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtc-zynqmp
++rtc_cmos_setup
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7110
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7185
++saa7706h
++safe_serial
++salsa20_generic
++samsung-sxgbe
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_sil
++sata_sil24
++sata_sis
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sbp_target
++sbs-battery
++sc16is7xx
++sc92031
++sca3000
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++sdhci
++sdhci-of-arasan
++sdhci-of-at91
++sdhci-of-esdhc
++sdhci-of-hlwd
++sdhci-pci
++sdhci-pltfm
++sdhci_f_sdh30
++sdio_uart
++sdricoh_cs
++sedlbauer_cs
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial2002
++serial_cs
++serio_raw
++sermouse
++serpent_generic
++serport
++ses
++sfc
++sh_veu
++sha1-powerpc
++shark2
++shpchp
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sir-dev
++sis
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skfp
++skge
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++sl811_cs
++slcan
++slip
++slram
++sm501
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smc91c92_cs
++smipcie
++smm665
++smsc
++smsc-ircc2
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4117
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als300
++snd-als4000
++snd-aoa
++snd-aoa-codec-onyx
++snd-aoa-codec-tas
++snd-aoa-codec-toonie
++snd-aoa-fabric-layout
++snd-aoa-i2sbus
++snd-aoa-soundbus
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt3328
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-cs4281
++snd-cs46xx
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1938
++snd-es1968
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm
++snd-pcm-dmaengine
++snd-pcm-oss
++snd-pcxhr
++snd-pdaudiocf
++snd-portman2x4
++snd-powermac
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-sb-common
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-core
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-es8328
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-ssi
++snd-soc-gtm601
++snd-soc-imx-audmux
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rt5631
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-xtfpga-i2s
++snd-sonicvibes
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-usx2y
++snd-usb-variax
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-vxpocket
++snd-ymfpci
++snic
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++softdog
++softing
++softing_cs
++solo6x10
++solos-pci
++sony-btf-mpx
++soundcore
++sp2
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_dectlk
++speakup_dummy
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++spectrum_cs
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi-lm70llp
++spi-nor
++spi-oc-tiny
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tle62x0
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spmi
++sr9700
++sr9800
++ssb
++ssb-hcd
++ssd1307fb
++ssfdc
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++ssu100
++st
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++svgalib
++swim3
++sx8
++sx8654
++sx9500
++sym53c500_cs
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink
++synclink_cs
++synclink_gt
++synclinkmp
++syscopyarea
++sysfillrect
++sysimgblt
++sysv
++t1pci
++t5403
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc3589x-keypad
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tehuti
++tekram-sir
++teles_cs
++teranetics
++test-hexdump
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tg3
++tgr192
++therm_windtunnel
++thmc50
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timeriomem-rng
++tipc
++tlan
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++torture
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_atmel
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps65218-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tsi568
++tsi57x
++tsi721_mport
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl-regulator
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++uPD98402
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udc-xilinx
++udf
++udl
++udlfb
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_fsl_elbc_gpcm
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++uninorth-agp
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmisc_imx
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vcan
++vcnl4000
++ves1820
++ves1x93
++veth
++vf610_adc
++vga16fb
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-ircc
++via-rhine
++via-sdmmc
++via-velocity
++via686a
++videobuf-core
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videocodec
++videodev
++vim2m
++viperboard
++viperboard_adc
++virt-dma
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_scsi
++virtual
++visor
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_ca91cx42
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vpx3220
++vrf
++vringh
++vsock
++vsxxxaa
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83977af_ir
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++walkera0701
++wanxl
++warrior
++wbsd
++wcn36xx
++wd719x
++wdrtas
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++windfarm_core
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wl3501_cs
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x_tables
++xc4000
++xc5000
++xcbc
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xhci-plat-hcd
++xilinx-tpg
++xilinx-video
++xilinx-vtc
++xilinx_emaclite
++xilinx_ps2
++xilinx_uartps
++xillybus_core
++xillybus_of
++xillybus_pcie
++xirc2ps_cs
++xircom_cb
++xor
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yenta_socket
++yurex
++zatm
++zaurus
++zd1201
++zd1211rw
++zforce_ts
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++zr36016
++zr36050
++zr36060
++zr36067
++zr364xx
++zram
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb
+new file mode 100644
+index 0000000..9c87de2
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb
+@@ -0,0 +1,17241 @@
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0x6310e901	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/atm/suni 0x68f4622a	suni_init
++EXPORT_SYMBOL drivers/bcma/bcma 0x3a3d4a98	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/bcma/bcma 0x79d1b084	bcma_core_irq
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x01c94bce	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x0d74f83d	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0x1a5c6a83	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0x4267110a	pi_register_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0x841c36e7	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0x8df2d11a	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x94566518	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x9be8f1f4	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xaa182144	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xac5ab8d9	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0xb21ba07d	pi_unregister_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0xb867eded	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0xc0f36df1	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xd5c61a73	pi_write_block
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0xccba0ab6	btbcm_patchram
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x639d9b6e	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x6b4a490a	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x6c7dbdbf	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x6e718b16	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xac8be85b	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x2b36e38d	st33zp24_probe
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x72985374	st33zp24_remove
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x0f0874a0	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x7bd62aa6	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xafb3541b	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/crypto/caam/caam 0x1c758e97	caam_get_era
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0x0de93aaf	caam_jr_free
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0x1407a511	caam_jr_enqueue
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0x31a4987a	caam_jr_alloc
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0x3ec1e19a	split_key_done
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0xa683396b	caam_jr_strstatus
++EXPORT_SYMBOL drivers/crypto/caam/caam_jr 0xe842b38d	gen_split_key
++EXPORT_SYMBOL drivers/crypto/talitos 0x1bd0a055	talitos_submit
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x4fc6b61a	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x83b5c443	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x8a24be00	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xc02b175e	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xdc0466c9	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xfa0d03f0	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/edac/edac_core 0xf4898f1b	edac_mc_find
++EXPORT_SYMBOL drivers/edac/mpc85xx_edac 0xee6c3ba8	mpc85xx_pci_err_probe
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04d0f641	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0f7d6af8	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x11491e67	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x11c6b5c3	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x17faf1ae	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x27c48b06	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2b0a126a	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x331bbf02	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x34adedf1	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3936d614	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3af43bc8	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4254a70b	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4ff65e1a	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x555b273b	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x645b715f	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x6787b169	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8ed1e143	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9976d15f	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9aa511d8	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9b453cb7	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa137e0a6	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb479448d	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb4bd0c25	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xdcca22c0	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xe202216d	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xe3c20b7a	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xea0d9aa2	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xebfa4875	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xed45e25c	fw_bus_type
++EXPORT_SYMBOL drivers/fmc/fmc 0x1eb9d8cf	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x2081b92a	fmc_driver_register
++EXPORT_SYMBOL drivers/fmc/fmc 0x22f1e0f1	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0x29beed0f	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0x3fcd20d7	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0x560fe5b5	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x71770d88	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x78a19792	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x88cd079a	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x8c800e1b	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xd04a0a46	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0057e806	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06fa82a5	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0b38f0e0	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0bd4c389	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0bdbf4d3	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0be3c0c4	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ed13945	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f12bc3c	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f3fcbab	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x10d33dae	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x10ef96f4	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1224551c	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12497b94	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1386c700	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1537598a	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x16bf8518	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x170851df	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x188367be	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x19b706ba	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x19d1abfa	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x19e4430f	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1bbf2015	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1bd3cbd6	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c19786d	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c5811eb	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c5d143a	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c89db37	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x21fb924e	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x23405642	drm_agp_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2350e37a	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x238184d6	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x23c8510f	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x23e45c7b	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2448b262	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x24ea6eb4	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x25a7acb8	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2812a044	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ad630d6	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c588ff1	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d109438	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e5d68ad	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2eaf3f00	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2f3dcb95	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x30321b77	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x308fb48a	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x30c38b5f	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3341fff7	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x34b5a57e	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x35fbd1b1	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x362ce0c2	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x36af85f1	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38ef4485	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38fb1f77	drm_agp_bind_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x39a9d436	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b3603e4	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ba0c00c	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3c77cfd0	drm_of_find_possible_crtcs
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3de83ec5	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3e57cf87	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ecf666e	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ef84b16	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x40f65396	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43866777	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43ca42c5	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x44910e47	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x452b0c00	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4671344f	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x47e2011f	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4979fa63	drm_agp_acquire
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x49a95029	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4a168c7c	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4a54112c	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4a74e696	of_drm_find_bridge
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4a868570	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4a8eca22	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c4f113e	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c988a3b	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4cfbd1c9	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4f2ff7f5	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4fcc897b	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51842b60	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51d2e570	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51db353a	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x520a8de9	drm_agp_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5232411d	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x529c4b59	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x53ab6c89	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x548ea62d	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54b481e5	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x55876d8b	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x56d46d4a	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57332c3b	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5b57192d	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5c4f28f2	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5c6f1d07	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d7318dc	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e5d0404	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5ed13d5a	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5f85df84	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5f974d0d	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x60138adf	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6154d9ae	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x61b45e19	drm_compat_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x631c4ec0	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x63eb3feb	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x649f416e	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x675f2ac4	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6795bf6a	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x687fec63	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68ed607c	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6998aff7	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6bcd3835	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6c2d2b4e	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6d11b32b	drm_agp_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6d756df9	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e80fb0b	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6faadec1	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6fb4086b	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x704bf914	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7057c3a9	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70715f40	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x71f208c9	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72d04d8b	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7318315e	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x731dce6c	drm_legacy_addbufs_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x741bb719	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74cf8c60	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7675dc56	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x77861de2	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x77cacfa1	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x78b0e02a	drm_agp_unbind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x78cc5e0e	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a325d44	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7aa48831	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b90accf	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7bfcaf79	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7dc22823	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7e0f6b66	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7eb8b7dd	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7fa19555	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x80594584	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x818a7655	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82b96322	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c96109	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x837c85bb	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x839e9345	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x840e59b3	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x84833819	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8492f7a0	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x84fea47f	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x855b6160	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a61f288	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8aa9a0d9	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ad6fd73	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8b88ae60	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c089c52	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c9484f2	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ce0fe58	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e0085e3	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8edba031	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f3d6d47	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f8bbba9	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x907889e6	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92327143	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x925e3d10	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x93be181c	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x93e504fc	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9443bb1d	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x96ced9b9	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97a173c3	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x981439d7	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x987d2512	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9971da4d	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x99a87ae9	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a79c163	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9aa4e18b	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9adf5fa7	of_drm_find_panel
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9b24edfd	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9b26bfba	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9b5f0ca5	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9b77007d	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ce6fb39	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ec1c526	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f0d7b5d	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0284b62	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0685fcc	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa16e5fe1	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa2647dda	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa29293b2	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa2d4ae75	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa307c7f1	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa438a66a	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa5aedaa6	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa5fd43bc	drm_agp_info
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa840ff60	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa96b989c	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaab79b87	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad614a22	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae1e4112	drm_agp_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaf93181d	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xafe9b358	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb07a33ad	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb1b5db47	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb1c563e4	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb25ed6ed	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb32cf547	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3542082	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5540008	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb639fc3a	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb7c5d74c	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbb351253	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbbc58c92	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbd8fd0f7	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbefbcda9	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbfc45cb4	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbff98c8d	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc0c37e80	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2438847	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2589f99	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc3222800	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc34bb983	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc4a47d5e	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc6704700	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc6cf3156	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc7284307	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc7286de6	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc8d9775b	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcaa5600b	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcafe823d	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcceb9c8f	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcdf4484a	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf7190b5	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd00427ea	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd013d4b4	drm_of_component_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd0941d83	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd127129f	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3a7cd01	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3a8e938	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3c9c94b	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd5462cd0	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd782f2f2	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd7ac3f20	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd86d7673	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd8d47828	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdb10edcc	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd4994c6	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe0271db5	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe1447f62	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe1c825fc	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2807dea	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2fcb4ad	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2ffd7a5	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe3320927	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe368a52b	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe3bcdb2e	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe580f08d	drm_agp_bind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe60a8437	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe676a452	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe750be77	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe841e3bb	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe879d9ee	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe8a9ed3b	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe95fa5d1	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea72d3e7	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb700bf4	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb7d7b66	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xecb335d5	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xedac77ce	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xee766fbc	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1415963	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1b098be	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf4b5676a	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf52cf7dd	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf6de41b3	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf6fdadec	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf745e17f	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf7e51a31	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf8309130	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf86a4aaf	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf8a84ca4	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9a46bc4	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9fc83f7	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb04ef3d	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb50d67a	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc8a0879	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcdbb896	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfdcd7771	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfe1bbce8	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfe90834f	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x00ef21e4	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x00efe2c9	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x014c8394	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x01b423df	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x02719841	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x03002be9	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x03f01949	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0486427f	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x04c9e197	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0617c0e5	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x061f1007	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0957dbef	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0a5036b7	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1430a695	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1598e3f1	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1838fe00	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x199a39d5	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1ab42e55	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1dd8b69f	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1f24899e	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1fb93b19	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x20effc77	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x23f3a85c	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x26480e35	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x270bf379	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x28cc4de5	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2a140625	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2c9be015	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2e1eca26	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2e8226c3	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x371d5973	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x387bdadf	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x388aef3e	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x38e2b799	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3b193b15	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3c96bfb9	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x40908912	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x421e3e07	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4272c82d	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x44c5469d	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x45008b87	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x469c56da	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x49276ea6	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x49e70214	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4e307452	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x512e8573	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x51bbd66a	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x54d3fc92	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x594c8f7d	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5bda7dc0	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5c6ef7d9	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5cc74b7d	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5f2df717	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5f8f9c9a	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x602a8e81	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x60950792	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x609c7c2b	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x617a4e45	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6338324c	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x64666e0d	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x64ce9eb0	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6511c799	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x65219a9e	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6af36319	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6e0b485d	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6ed8ddcf	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6fe8e24a	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x72915dea	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x779e415f	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x793ae80b	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7a16dbdb	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7be8eb09	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7d84ceea	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7e7a424e	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7f46fce3	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x80d40a39	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x82843b38	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x846e3d83	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84d51063	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x86f744cf	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8a0873f5	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x905d08fb	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x909eac3a	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x936bde85	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9563e99e	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x98095624	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x982f334d	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9b171b51	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9cba3ba2	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa30b583e	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa3b94e43	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa3cb0a1c	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa46f5301	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaa95d833	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xabfa1644	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb045e476	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb58d6f31	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb58fc2f7	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb5b6c516	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb5bf7fdd	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb6e779e5	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb7a30220	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb89a345c	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb956a302	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbdde182d	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbf09ffde	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc03d1fc9	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc3348f13	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc344c3ec	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc3bfa095	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc4e0d321	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc5d769e4	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc5ea72e0	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc6b7c9ba	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc707bd9b	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcb48923e	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcd66aa79	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xce9efa3a	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcee51a3c	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcff5d6e7	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd00d5d11	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd077869e	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd0eca685	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd40900f6	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd728418d	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd73bac93	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd84384a1	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd8ccef76	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdecd4ab2	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe3d64cd6	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe6238cdb	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe78f2500	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeca4f5c3	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xecd974e8	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xed3191de	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xed45e7b9	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf92fd369	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfa5837b4	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfb18bfc4	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfdef12b9	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfe3a0109	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xff794a88	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x013fb635	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x015d1cb3	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0f43c7d2	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1356a62c	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x187f7b01	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1a412b3d	ttm_prime_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1b014379	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2ba84f72	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2cedcad9	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2f7d734f	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x341897ba	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x35cb519e	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3c648883	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x429128a9	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x43a3c016	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x47a3745e	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4d43936c	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4e8dd264	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x564e1aee	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5a8fdfea	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6052860c	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x610e641b	ttm_agp_tt_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6128ce4d	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x62cbec6e	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7a9a9331	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7c79c4b2	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7d55da85	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7f58ca58	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x83c096ce	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x84a13931	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x873d0abd	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x876f2779	ttm_agp_tt_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x89a443de	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x89edfbed	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8d14adbf	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8f38efe3	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x92271100	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x92ee72f0	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x966a2b5e	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9809828a	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9bd0939b	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9c90e7dd	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa2a129fd	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa48c1bce	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa73de2a9	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb28d0e07	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb36647e4	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb60f0121	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb83c6470	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb8ec64c5	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbad27271	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbb72cd5b	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc29dd08d	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc2c532a2	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc5f0c2da	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcba1d5f1	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcbb59bd4	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcc57bc04	ttm_agp_tt_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd7f51742	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdb6e1f8b	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdd33fc5d	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdde8e45a	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xddf67926	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe13e5bfa	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe2300aff	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe29cfab3	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe2e07a0b	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfb352c61	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfde3355c	ttm_bo_device_init
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x1f19ec51	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x43389dfb	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xd3525e99	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x8c74404a	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x977b8773	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0x15636d78	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x130442a3	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x131ca5b2	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x1ac0fe75	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x5f9993cf	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x70318b77	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x7da2a27f	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x8d0919e3	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x8f73adb4	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x91448921	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x94517ad9	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xa5624272	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xaf4b1773	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xb4143521	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbf61a12a	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xd3200eb9	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xfa0f0f25	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x2b617f62	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x467f1b19	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x2c759235	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x7cfb17aa	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xb0ac886d	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xc6d70f95	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xc85b4df6	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xe2719640	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x12ca4f66	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x1d4bb411	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x4f4032c7	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x636d659f	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xaa30a081	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xce5900c7	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x1a2ab685	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x6c64967a	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x826d1c78	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xf2f6cc3d	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x07754bce	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x14cb4d76	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x3cf63db0	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x4f9f5d05	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x75c6bcae	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x933a57da	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xd3e3c7a0	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xfb1e3a1f	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xff1bd928	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x46781b7b	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x6b2b7b39	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x7a139591	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x7e95944c	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xbfeab8d9	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x13dc01dc	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x4608a587	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x6420004c	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x01d9427a	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x03b09ca7	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x0881ec5a	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x1922fd29	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x2cccdf74	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x520faaa3	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6808b4fe	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6f5fd075	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x7756f37b	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x97b6c748	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb08150bc	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb18da3fa	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc7fe13d8	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xdc63ea3d	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xdeaa1319	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf07b9f2d	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xfb6b20a3	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x20c4ea75	st_sensors_of_i2c_probe
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x323a7283	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0x24427312	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x1d38f29c	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0xfbb98de2	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0xce1532c6	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x712e39f5	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x9f19b5bd	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/industrialio 0x05a2606b	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x1b8b8fe4	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x2e819ffa	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x3f616071	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x402f49f0	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x5001779d	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x51b3704a	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0x5e020760	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0x67e4a713	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0x7894bc2c	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x99bfedbf	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x9fcb4dc1	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xa1f3262e	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0xa85cd5a5	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0xbfb84e38	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio 0xc79e56cc	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xe3456ad1	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x40092b06	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0xa0a3928e	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x364d0ce6	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x3ebf6569	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0x4d9dcb2e	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x6756b775	st_press_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0xb639a656	st_press_common_probe
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1ea5767b	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x32a8402c	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x44f9cb5a	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xeb4e6683	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xeb8704ca	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xf040e516	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x22dad0b0	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x2a196665	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x31bf6d4e	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x410aad6b	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x4c6fc445	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x5417ac7e	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x5e549246	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x627b5b59	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x63a6b36d	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x6fe9e08a	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x79c0d3fa	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x7a73bf73	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x7bf87ec5	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa850d66e	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd8bc9f3b	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xf46ff7da	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xfa55dd98	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xfc0fd578	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x00c1021f	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x09180b3f	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0a1f2839	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0bed9c4b	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1c0019	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x18c5d14e	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x19c6e06c	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1a1c3506	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1d012a20	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1dffdfad	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x224ee36e	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x22f3cf93	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x235215e1	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x245127af	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x28be6b08	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2aaae9fe	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2b6e2f6e	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x33139c82	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x364e04f8	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x39afad3c	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3e81d1ae	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x44700bbe	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x44988daa	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x47e9ece5	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x497ff6a9	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x49a788bc	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4faea346	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x53e5b4d2	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x573242c6	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5a71ec9d	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5d79a633	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x620e5df7	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x63c0ef59	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x64f523cc	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x651aa897	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6ab3f182	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6e66f55e	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x769abac8	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7a226b91	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x81c40a3f	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x82aba354	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x86a8fa80	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x87b59af1	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8e4bc67e	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9b7b6595	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9fa07e25	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa1e243b1	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa34fd40a	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa395b118	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa432baf6	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa87bc24d	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb3b1c46c	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb567e687	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb58becd9	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb5b36b6c	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb8abe4f0	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc14bf988	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc14e97f3	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc3631f8f	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc38e7b2a	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc61fcd46	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc7dbfb6c	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc9c7e5b5	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcf884b87	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd57f8d18	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd62de720	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd7a0a2ce	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd7e5d124	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd85d11b4	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xda3c3917	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdc6dd195	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdc8ce6b0	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe42c2809	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe4726ed2	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe55255f0	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe63639de	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe8ab9153	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf036f7d5	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf4429669	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf5521ac1	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf64b709b	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf899d577	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf92d7364	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfa529cf8	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfd70c362	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x0be8489f	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x356b1d84	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x630349a1	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7190918b	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x780db9fe	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7a24a9fd	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7c8a1149	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x996daef0	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x9bcccf94	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xa55e6028	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xc70d423d	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd720acd7	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xdf4684d0	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x24bc8710	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x3ae36336	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x425dfba3	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x4f783ab4	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x5318bb08	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x5328d7a6	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x74495657	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x9066574b	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x9a1cd50d	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xd414b8d9	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xdf66b035	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x7b67b22f	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xaf498132	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x094cc68e	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x2262ba62	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x30c77513	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x36cd3b9a	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x3cfa00e9	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x56529cec	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6622c1af	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x87b0c82f	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x90b312fc	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x94527632	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9ab35615	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xa469579a	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xab919ace	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd0911bc4	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd6d422f8	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x07e3cfd5	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x1c88fb10	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x351e5179	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3a13c714	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3e62102a	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x41f4ae99	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x54aa7140	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x6d57b76c	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7475781b	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7aaefeff	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7b507035	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x86aed87b	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x890cf6b7	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x9f7f4976	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xb23ddb8c	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xb5d2901b	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xb7eaf8bb	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xcb952c25	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd4d466a7	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd7fac0ea	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf9dbe634	rdma_accept
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x274cdb16	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x3ba95d40	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x3dfb6c39	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x487fb969	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x99ee1ebb	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xae8b7468	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xb933aa3d	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xe93c7825	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xf6528c07	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/input-polldev 0x1704f6e5	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x7e135ded	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xbe958b92	input_register_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xf52eeef0	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xfd6b1462	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0x972cf250	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x335aff1f	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x7ddad0f3	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xcdf314c9	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xd3f98d15	cma3000_init
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x22895f6f	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x7ca5407c	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x95653a7d	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x98356ce5	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xa6bf7c9c	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xb495fb99	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x0fbab7a0	ad7879_pm_ops
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xd462c818	ad7879_probe
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2591b048	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x58edd27e	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x620136ae	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x631f08d6	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7292ab34	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x72a25a72	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xbac0b846	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc18e9eb8	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc555d2d5	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc818edf7	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe988bdb8	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xf9cd06e0	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xfd552f7a	capi_message2str
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x041cfcea	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x13a490a8	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x1a4081ad	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x240252a1	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x2ef4f634	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x4a270248	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x6c80c2e4	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x724ad6c2	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9de4d6a6	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9e74e32f	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xa0fc2dc0	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xa982bfcf	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xc0ca05df	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xe5adda52	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xec1c7671	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x0a2c624b	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x3b9774a9	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x4cd9dd6a	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x67c4c97e	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x7929c9a7	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x8d15ace4	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xc68f1f6d	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xe444ec54	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xe604689b	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0x29562993	b1pcmcia_delcard
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xaec3240e	b1pcmcia_addcard_m1
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xea620116	b1pcmcia_addcard_m2
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xf14bf8b1	b1pcmcia_addcard_b1
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x1c3a45ef	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x724472e5	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x84213c8c	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xd93321d1	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x64d44f14	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x9670b295	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfa51a0d0	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x41b83775	isac_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x49baefa0	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x4e1145ff	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x93156afb	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xec720583	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x0e850361	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x9aec18e3	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xa08151e6	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x007e5322	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x00ecdc46	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x051cff19	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x22aaa0c5	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x26939885	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2d0d68d5	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3995a579	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4e9d72a7	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x53d0f06f	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x5efd8243	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x603b07a4	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7592d5a9	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7c342be8	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8421e6bf	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x84437dc2	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x846e58ad	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x970c68a0	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb476097e	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb708bd17	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc0e54c29	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc7a2208f	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xda1f0dcf	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xeff0d454	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x1d89bd11	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x1f529ce8	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x26481f26	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x440b4830	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x44a37d62	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x5b59b856	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7daccb73	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x8802be4f	closure_put
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x8833b0e8	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xa3c5c702	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xb5fbc479	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xc88cd795	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca5df778	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xce47a6d9	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd2813054	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xdf892351	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe67c2d16	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe753f37a	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xec6f33d0	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/dm-bufio 0x268682d2	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-log 0x021c4b7f	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-log 0x0bf5af35	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0x339fdd4e	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0xfbed0973	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x46f4a81f	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x47bba335	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x622fbbc1	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xa231c5ed	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xbdbc5486	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xfa38681c	dm_snap_origin
++EXPORT_SYMBOL drivers/md/raid456 0xd47c6c5d	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x20ebfe46	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x3dbda8b4	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x4417324b	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x4df81bde	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x531cb1e4	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x715d873a	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x84301db4	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x86f110ec	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xb06e5faf	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xb5e7b7b0	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xc5ede52a	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xeb225c32	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xf0a78068	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x180c6980	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x83b6b906	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x84d93f5a	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xb80edb31	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0xa9e0fe93	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x1633404f	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x8541036e	tveeprom_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x057f032d	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x23c6604c	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2bdc06ef	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2bf0d64b	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x32706276	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x329de070	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3376af73	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x366af8ab	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3f1e40bc	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4430e431	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x47e537c1	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4f0e9449	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x50245c5a	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5c0ea535	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x62e57643	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6a7fb6de	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7079da60	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x70af1058	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7764eb22	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x78db694b	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x79f2d6f7	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7f4f9b54	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x84a7116b	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x85a5e7d3	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8bdf81c6	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9f7ad746	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa0ccc8e7	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa1f16a61	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xbdca3dcb	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc152e321	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc2ff5f1c	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xcf589e8c	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd14e1d20	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd8f7184c	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xee838add	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf28e7431	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfb4011a7	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfbaa7e01	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0x6ed24007	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0x228b3150	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0x617cf37d	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x1521f843	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x16b7ed05	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x2e63445e	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x5db82535	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x639c1952	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x6ce56e67	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xbe47406d	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xcd168636	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xf07a00de	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0x4e471895	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0xa0b46a41	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0xe8d764cd	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0x13ecb6ca	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0x274ea811	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0xe343bb95	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0xed889ce5	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0x07f33c75	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0x8a090ee9	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x0462df1c	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0xcdb14cef	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0x55c69f6d	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x4668d456	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x543ae74e	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xac2bbee2	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x1baef0d5	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x1cbe7d54	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x40403396	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xc77b5121	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xd3e31ec2	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x3d174669	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x50b23e2d	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5b4e00b1	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x60f6f713	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x614bf8c3	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x76ece59f	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7f2e657a	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x8023c4af	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x8eb71b48	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x98d12e94	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xa354056d	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xbe9b3114	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xd8254e67	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xecbab157	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xecf1eade	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0xbc591d0b	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x0d7af51e	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x29b6e7cd	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x625af13d	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x726b34e8	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xb8676a6d	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xfaa9842a	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x22209242	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xa2b8bc45	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xe0a889ae	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xe8a57826	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x6f3f2445	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x68ad11a8	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x101f2f40	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x933790e9	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x96dc3022	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xd50f593b	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xdd1df1ba	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0x6ed1f3df	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0x7cde435a	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0x3ec4edf1	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0xc4f70249	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0xc961c351	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0xaad5afb3	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0x1a191829	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x4161ab20	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0xe4fc6766	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0x664dfc09	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0xf0a9ac4a	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0xc3ce594f	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0xdb9f2277	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0x273f165e	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0xa66b2959	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0x027b984c	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x3f114ed2	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0xd88e5bfe	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0x9eb1b314	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x124e4b68	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x45c179bd	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0x27898699	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0xcf685ae9	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0xd57defdb	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0x2f6aa8bf	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0xb4aae376	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x1cdfc8d7	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0xe0e71faf	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0xcd2963af	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0xaa05c1f4	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0xa39c80aa	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0x11db31c1	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0x80008099	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0xd6be0e15	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0xe603df58	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x199f9861	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x1f212fb0	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x9168990c	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0x1353d788	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0xacbbd415	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0x5ad6aa40	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0x09636881	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0x9414acb7	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0xb1ed87e5	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0xb2e97bf0	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0x97482d52	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0xb48b8123	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x583031b8	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0xd41903ce	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0xd7403bd4	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0xe25bdaf4	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x59b3d779	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0xd640f877	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0x58f37436	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0xec38d129	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0x050a8f38	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0xe8e57bec	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x5a651885	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x6e70b0ed	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0x4d2e33dc	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0xe46df4fa	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x856d6491	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0xa5d70e0c	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0xb70b65d0	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0x3d3fb9b2	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0x7a271a24	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0x54af5280	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x1d260820	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0x72f93c2b	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0xcdff4596	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0x669873e8	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x02228748	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x0551d696	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x30c57501	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x6c60ab9e	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xc182c5b0	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xed868843	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xef54fd29	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x1aa416a7	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x4664f901	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd9f0949a	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xdcb51822	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x1b7db364	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x601cc8db	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xcf79a30d	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x0b545489	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x0cba284f	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x13a8f0c5	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x1ba72336	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x1da46d99	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x24f5af5c	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x76d3c4b1	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xdfafca36	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xf38344d0	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0x0dd96db7	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x4004153b	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x430c316b	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x43f97b74	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x8157b05c	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xa453940c	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x53eb39c4	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x0b619194	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x3b9d8673	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xa91edc85	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xb62e119a	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xe126c817	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xeda381a4	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xfd36f883	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xae555126	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xefdb31d3	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x26fedfb0	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x2782e22c	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x6892b03d	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xea560a71	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x2d4b082c	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x2ed478d3	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x57e55120	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x68e6a418	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xaea60091	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xd7d4b09b	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xf5854c7f	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x08b812ef	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x1716f465	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x19d2366e	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4c91990d	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x57d7cb9f	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x58b3e581	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x63e73a59	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6984b79a	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6aee2d2c	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x86140e62	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xa5bfee99	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xa7f224cc	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb44fbefc	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xbc26f364	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xd1131238	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe10c155b	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe78c5e60	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xef0d1d7c	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf0871554	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf4b71ceb	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x061e12a9	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x0c5df183	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x194772a9	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x1eda1595	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x211d9fdb	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x529bd140	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x5bd26544	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x6d422ed2	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x72dcbd89	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x73ee4e01	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x81b8d254	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x879acc87	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x8b813807	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x9c3da44f	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xccb8357e	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xe706c91c	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xe8d1d2cc	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x01cad0d1	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x19ecd5d9	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x26358ee8	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x32f07a57	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x37c9c736	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x4531e5a1	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x6be7bb69	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x95e35dc2	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x96bc71a1	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xd905bb65	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xea7a7181	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xedd0efe4	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x538d227a	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x11cbd7f1	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x64225470	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x69aaee6c	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x8346d4ab	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xca95748a	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xe4012581	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xe4209ee9	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x3b286b91	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x400d5dd4	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x75b3dabe	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x7e7012c2	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xbb684c7e	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xc9be36a7	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xfebe3d82	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x23842079	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x4485fefa	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x6fd49a92	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x7fcab1de	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x90f1de8d	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xaad88793	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xcf04f11c	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xeffe414f	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xda454b50	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xee8d06eb	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0xcae5cd2e	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0xb41779f2	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x196bd548	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x4557fe33	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x6e31b2e3	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/max2165 0xcaee3409	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0x56b1d7d2	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0xa026d052	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0x986e6777	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0xeaadb5bc	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0x0d395459	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x9302b696	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0x4765e0ee	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x9ea11a03	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0xdab98176	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0xb17942b8	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x988347c5	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xf4a42209	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x142f9673	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x2184be3c	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x456baf97	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x5a2d569a	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xa9d895a2	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xd2ccf859	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xd5f02f05	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xdf354209	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xeec85b5a	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x2fa6728a	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x78619d8a	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x93e9cb40	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x9e2c19a1	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x9fdd8279	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xaa56bcc9	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xba38de80	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x2f2f25b3	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x005f43d6	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x239cef58	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x34d6cedb	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x3d3dc773	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x7a18a34a	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x7d39ee6d	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x9ae2a941	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xaf3cb687	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb1e9a96e	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xc8c4f911	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xe99bc0a1	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x43e33759	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xc41947ad	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x1b0a725b	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x59c5b4ee	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x612aedf2	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x6697cd4c	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xd673158f	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xe3238572	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xefff75e9	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xf618fcd7	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xfb29b924	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x2089072f	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x245cf9a3	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x2f8986e2	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x47a48398	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x8abcac5c	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xa1626e2f	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xd0b425ef	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xf4f5a992	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x7abfd2af	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x8221fef5	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x85ca64ef	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x934fbd55	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0xb888bc9f	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x20d653c8	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x3c185d0b	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xc3620b55	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x468896e3	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x5fbac464	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x6428a4c0	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xb137980e	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xb94d5d4d	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xee7459cc	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x060ec303	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x56a75585	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x0015c8d5	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x264e1d0f	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x46dd9b8b	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x8b4db49e	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xe20935fb	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xfd3418fb	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0x2b441ddf	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0218deea	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x06b97f24	v4l2_of_parse_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x122c68a3	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1321a819	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x13802eff	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1aeab84c	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1bb6ac28	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1fc87634	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x200ab12a	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x219b7187	v4l2_of_alloc_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x24dfba20	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x250f4311	v4l2_of_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2b3c8638	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2edafc08	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x321c3a55	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x34fb5ec1	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bf33b73	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3f134b79	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x403cce6e	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x46750c44	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x535556a5	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x54a40220	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x55ffe021	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5625ef60	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x58a3e4b6	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5d826a1a	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5ea574b9	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x676494d7	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x75579951	v4l2_of_put_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7573d1a2	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x76ed1e7d	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7756671a	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7e04f4de	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7e6d61ab	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x81900f96	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8366fe25	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x83f67d42	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x84e99d36	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x86fd5349	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8dd6391e	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x914f9393	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x92579884	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9fe4aecc	v4l2_of_free_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa126f7ea	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa2d661a0	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa938bc9d	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xac0e8bb8	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xac4cdfc4	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xafbba90f	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb12f54dd	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb180b3da	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb3ac1a69	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb7b1c566	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbcfba303	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbecde832	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbf022c35	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc714b1e1	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xca27e09f	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcb61800b	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcb8236a5	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcdc2744c	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xce23bb7f	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcf0e4e6d	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcfbd33f7	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdf6ced8d	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe20247d1	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe509982a	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe88f2966	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf2f95882	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf775e52a	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf7ac52a4	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf8df0ba4	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf97ce340	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x05163514	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6ab01564	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x7cc8541e	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x95cb6ad0	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xadf087dd	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xb229b02b	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xba7a8861	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xc1bf1c15	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xd1a8651d	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xd5d48f03	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xdc07e67e	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xe198ef40	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xf57aeb0c	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x014ecff8	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x16dc7923	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1de3a1c3	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x24ab7c38	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4b919cc5	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4c868e93	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4d0b7f21	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4e1d6aed	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x54c7d29c	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x5bf06ebf	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x5cb081fa	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6305ed83	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x7f2363c9	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8420a6b5	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x85b6c8f7	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x979c364e	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x9b94cda5	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa1272740	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa79ad0f8	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa83d22d2	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xaf7d5eb1	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb2abd9a0	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb3b3304f	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd0971e43	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd84754e0	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe980a15f	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf3395c5d	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf754c43a	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xfc2762d7	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0601b136	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x087dd3ea	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0ddfbee3	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x145becb5	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1892c69e	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1b8287e2	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1f851a89	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2684f129	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x30047540	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x434b72fd	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4f62b906	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x50be64a9	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x5e98a566	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x67897a66	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7282924e	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x77af8ed5	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7a6c278d	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x947239ac	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9950a60d	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9ca6951c	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9f5d8a68	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xaa7c7763	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xac6be66b	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc81775f0	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xda2fdc98	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe4c7e598	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe60d7ab7	mptscsih_event_process
++EXPORT_SYMBOL drivers/mfd/dln2 0xce10ac41	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/dln2 0xdb180ab0	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0xe26cd68d	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x2511bde2	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x3c659704	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x08babe72	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x1d80ccc7	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x24515e73	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x3f135c4e	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x4186920d	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x5c591964	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x6948b7dd	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x70986991	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xc0d07513	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xc279c433	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf8529e32	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0xbce42266	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0xf3a1ea7c	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x0c607554	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x6bcfcf61	wm1811_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xc69776d5	wm8994_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xf4adcd4c	wm8958_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x3efd3b72	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x7111221f	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x30b3ae49	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0x2ac68920	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0xeea35f31	c2port_device_register
++EXPORT_SYMBOL drivers/misc/ioc4 0x1fd202b9	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0x8bdbc8bf	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/tifm_core 0x04ccdced	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x140de6c8	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x14c5122a	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x282b18b9	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x36a1ba84	tifm_add_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x6f679a14	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x892eb413	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x8deae88d	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0xa8c2ec46	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0xb79a6835	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xc6681458	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xeb930250	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xed6c94b1	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/mmc/card/mmc_block 0x1012bed8	mmc_cleanup_queue
++EXPORT_SYMBOL drivers/mmc/host/of_mmc_spi 0x29571775	mmc_spi_put_pdata
++EXPORT_SYMBOL drivers/mmc/host/of_mmc_spi 0xe9563269	mmc_spi_get_pdata
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x33e66a84	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x37fecc7b	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x860d6f8d	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x94e4064a	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xb4761fb8	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xcbc0cf3e	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xf727d3b0	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x4dd2fe67	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xa0008111	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xad62a480	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xd7f8d481	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0x174e0931	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0xde9aa44d	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0x356d0452	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x073b26b1	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/mtd 0x6ced2e21	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x780789cb	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x7fae501f	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x0d226759	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x5c31352b	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x79bd4d27	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x82a92e43	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xaf2f0511	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xe15c4e1b	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x12a77e80	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xe8ae0146	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xfb1c94f9	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xc322457f	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xc5101445	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x15af8260	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x2d2bee8f	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x42641303	onenand_default_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x815aa830	onenand_addr
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x07a246f5	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x1fc8e96f	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x2453d2f4	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x25ce3fee	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x4b43113f	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x7b83b2ce	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x942282c7	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xa7bba92c	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xd53c7311	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xe0c1d27e	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xacd3160f	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xc668f2e1	com20020_found
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xe0ee637b	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x0dd96955	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x13cf2fee	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x1c528794	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x4d5ccd15	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x54f1b4aa	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x56a0a2d1	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x77d73570	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x90221f1d	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xb079e978	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xb677b921	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0x9cb789eb	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0xb87310d7	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x0d8be5fd	bgx_lmac_rx_tx_enable
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x285bde59	bgx_get_rx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x42264715	bgx_get_lmac_count
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x6dc1648d	bgx_get_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc397f585	bgx_lmac_internal_loopback
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc82be691	bgx_get_map
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xe48ca42a	bgx_get_tx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf101d1b2	bgx_get_lmac_link_state
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf9508980	bgx_set_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x2fdfa8ac	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x3d0d67c8	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x3f9cab6a	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x67ca099e	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x6d84d670	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x6fe0fbf2	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x743053b3	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x90b7a960	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x9403469b	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x95df9996	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x98f5fec1	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x9d418c4a	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xa50c5402	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xbbeb1abe	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xc8daa11c	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd838facf	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0056bb40	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x00d5b13f	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0c43a498	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1e990cf1	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x2141ce33	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x29f12a7f	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3b880136	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x464bc352	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4d8992cc	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x538c309a	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x58840efc	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x5a7df15c	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x60580ef4	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x668ef337	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7279d8c4	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x752748af	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7e6cb2c2	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x807f9a2e	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8dbfd4b7	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8e5a80a7	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9c995aba	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa46621db	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa8ff9666	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xae79fe81	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xcb7c39d9	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xccd04631	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd408b0ff	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe51385c1	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe7854c56	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xea11345e	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xedc2d742	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf076c1b4	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf1f4caef	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xffbd69ca	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x24202527	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x56c4a81f	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x59d88a98	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x69e3bfe5	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x8f5e517f	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xe142a5b5	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x74bbbef2	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xe45f39e1	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/freescale/gianfar_driver 0x79f28897	gfar_phc_index
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0406be56	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0d0432c4	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0d8df60c	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x13508add	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x269db7b3	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x26c799fc	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2a6b9e46	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x36057621	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x37ee2aea	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3b52c201	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4036702d	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4d6892de	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4f5daafd	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x515b6822	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x518ec3a3	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x59a9c4a3	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5ed014fe	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6b28ec29	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6b62ee65	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7ab26967	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8854eba2	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8e237394	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x920f6728	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9260b574	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x92f290ca	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa2a95023	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaab132b7	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xac02c1fc	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb39b9781	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbe5fa8be	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbf768596	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc8168cd5	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd8f31f11	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd99db1df	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdafd9b39	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdc1ff0d3	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdce6158b	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf39964a3	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0c5ab386	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0df89940	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x14c141e5	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x16e34c1a	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x176237b1	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1b3b38eb	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x23b09c1d	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x23e618ac	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x28da0af4	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2e89069f	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3b2eeb99	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3b60295a	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3d1d4754	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x45b3083e	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x66c60b2f	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x673676d4	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7a9e970d	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7f914d39	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8196e746	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x86fb61f7	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa0a73b3e	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa3a1f28e	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xaf94a5ec	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb844fcf6	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbcb9389e	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbd952589	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc325bcb4	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc55f0587	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc5864804	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcbbc75f2	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd08e7f84	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd305381b	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd38d71e3	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe2c4ab02	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xeef00dec	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf5fb469a	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf6e8353c	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfb8c75e2	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x15a2a399	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x18531d2a	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x2bf27d7c	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x2d07a992	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x6d265007	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x8d533f16	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xbd56fca8	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xf96a542e	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x0705e304	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x26577581	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x27ddf03f	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x31782b73	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x5025fbba	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x6e9a4d4c	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x216c5aa2	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x34ecd086	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x578397b2	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x71a2ea81	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x7bcdcfc4	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x7d3cc319	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x97c7bdfb	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xa0279424	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xa2d7d089	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xf50b6b80	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x02cdd8a5	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0x3840dfda	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0x5e00a6e1	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0x757c9fd1	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0xa2f4454c	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0xdf0a8bab	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0xf41e41ba	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0xf670af04	mii_link_ok
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x2b65bb61	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xa17c435d	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0x9c18b558	cavium_mdiobus_read
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0xed45c77a	cavium_mdiobus_write
++EXPORT_SYMBOL drivers/net/phy/mdio-octeon 0x8a1d5c26	octeon_mdiobus_force_mod_depencency
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xc3becd05	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xea6f076c	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xf536ac11	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/vitesse 0xb81c65c6	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x0c359344	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x3321e874	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xfc558e8b	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/sungem_phy 0xcd3df180	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x18419536	team_options_register
++EXPORT_SYMBOL drivers/net/team/team 0x56995366	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0x6f227599	team_mode_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x71b8d6e4	team_options_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x757759b0	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/team/team 0x7a276eab	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0xcd62ed34	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0xf8f2988a	team_mode_register
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x5d686acb	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x6f6b0d6d	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x7bdb93f2	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xa2579790	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x4a1d5796	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x5c7f93cf	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x8a7fcfff	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x8bb57c99	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x93c481c0	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xa6326771	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb80ee3e3	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xcc85621e	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xebbabde5	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xf3662dd1	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xf617da8c	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0xc5d180c9	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/airo 0x21d82371	reset_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xb4ee08c8	init_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xbe75aed0	stop_airo_card
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x0ffff1ba	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x3659c2e5	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x3ee76d55	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x461631b6	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x7a86dd0c	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x93ead4bf	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x9d7d16d4	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xc1c1a93f	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xc77fad15	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xdc1b0cd4	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xf52f42e4	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfd7f6184	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x017ef177	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x036de2ff	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x08947038	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x194b6a4e	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x30e19d94	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x34f92124	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x560433ce	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x7cfb0d8d	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x8c806ff8	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xa53f0b22	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xaaee346b	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xb2d99835	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc498de10	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xda80b318	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xf3c42288	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x27121318	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x5af5e1d1	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x6dd57bbe	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x81f906b7	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x9edae4dd	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc2dfb594	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xca60a8e3	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xdb17c612	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xe5636919	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xf37dae29	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xfff8308a	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x063b1b31	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x3d3faa7b	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x425c0370	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x49586ef1	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x51e49dca	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x54d5b2f8	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x61b92e5e	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x6456c913	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x64b8a8bf	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x659f690b	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x69a5628f	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x6e1ecd80	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x73a11d8e	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x79731e61	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x99dcff9e	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xa565d2a4	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xbfa46a98	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xcf084536	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd6552b35	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe44982b9	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe7740fa9	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe7b81170	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf9c307aa	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x00d864b8	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x032e6217	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0383e4e2	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x04bb8f0e	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x05e9e1b9	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0721f5bb	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x07369de6	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x090fc8e6	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0b630171	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0f83005c	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x125fa342	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x13f475f7	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1530aee2	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x15981646	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x184b7822	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1931ed1b	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x19d01983	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1a393824	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1ab87281	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x263586b2	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x26b7c1ec	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x29963d4c	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2b16932e	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3059ad81	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3400dabe	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x342d2408	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x344a62de	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3826af79	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3997005a	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3b72791e	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3b8ae28f	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3e9c086d	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3f4a10c7	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x415e8a7f	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4237f1ac	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4561f567	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x496b4c49	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x57fb35d8	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5c9c0c1e	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x605f4d1b	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x67301ff0	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x68b5e49b	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6d905b20	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6ee92eb5	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7100f6ab	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x734d3517	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x74d454f1	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x76b05d26	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x77403f7b	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x78ace91e	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7abbefd9	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7afe83b3	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7c60e6a0	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7d1c1d24	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7f463a2e	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7f67e4eb	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x81fb6372	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x835835da	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x855c6eec	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x858e56f0	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8706e929	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x873d89ab	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8937523d	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8981de22	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8bff939e	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8c46c8a4	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x90590cbc	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x91f899b0	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9436441f	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9b4cd775	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9c31caac	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9d0d3bab	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa0278d33	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa17e07fb	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa46e7834	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa6027387	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa66ebb83	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xac2ee6f7	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xad2f8652	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaef223cd	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb233b8e1	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb373b4ee	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbae77b78	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbdc96e15	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc3cdbdbf	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc74de99d	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xccc71183	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd10610b9	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd21ed33d	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd2380c79	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd23dbc0a	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd8ff447f	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd9552708	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xda77850f	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe41c6340	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe70c35f4	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xec4c28e0	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xee609325	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xef253e5c	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xef55dad7	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf48f7316	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfbbd2c42	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfc549aaf	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfd5dd69d	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfd5f01f2	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x165c5525	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x17132bdc	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x3c1ceeaa	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x1324d949	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x13352746	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x1d11e486	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x61b9b6ff	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x6dc9f541	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x73ecc1c0	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x8e5e3501	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9efafa25	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xa56dc88c	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xa8a1afd0	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xb33e7c56	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xb3971d2e	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xbbd79a15	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x00c92c26	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0f12d7ff	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1723ac32	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1f94e307	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x27550dae	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x525f1bf2	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x6c5da984	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x6dcad50b	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x776a4bfd	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7fde5888	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8cf37c13	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x91cc6008	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9cbc3753	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9efa7154	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb241bd34	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xbd6b0e1c	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xbebf7f0f	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd0784c99	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd33360ad	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd6628d6d	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe3c01d79	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe665a5fd	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xedff3ae7	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xef1821cf	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf76bce65	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf9c77ae7	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x18775940	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x248e8f2e	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x2d8afcf2	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4b16a1b4	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x52b001f8	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x538aa6e0	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x57db67e2	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x58aafee8	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5c86838c	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x70fb42d3	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x73652036	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x7e288456	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x951eecef	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x9b041744	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa4f74bfb	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa520fee7	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xaf42ddf1	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb223cab5	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xbdc8cef6	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xe3ac7036	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf155a2d8	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x04e1416e	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x05b0f9b0	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x083ccfac	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x11a72811	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x135d8e1f	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x18681f5e	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1872afa3	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1dfc2ef9	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1e493af9	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2425b267	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x26b8c414	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x27e2262a	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2a716f36	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2e8b32cc	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2ed680b9	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2f3b7ee5	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x32642925	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x32df7f1a	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x36343f57	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3c72ed9c	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3f0eea25	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3f3477cd	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3f5e8397	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3fc8ed75	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x41c6f96f	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4579136c	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x48526583	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x486e79f8	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4e1895a3	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x50671db3	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x516cb87b	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5197a353	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x531aea58	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x559c41f3	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5ad46f94	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5f1fe571	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x629eb3e0	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x64ecd06c	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x67b8bbde	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6a27d6a2	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6cf64848	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6e5a9b82	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x703201a8	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x71f43927	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x72c40c0e	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x73c9dd1e	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x77f32ffa	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x79b58027	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7d5aa58b	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7ecf1b97	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x80602a79	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8170e3b6	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x847525e3	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x865fc05f	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x870a0e96	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8a528e8e	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8d92c5df	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8e990683	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x92ba5777	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x93994df8	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x98dca956	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9c1bd887	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9c70ae38	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9dac2d59	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9f6e38d5	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9fa84bfc	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa15be958	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa2b87629	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa8bc0695	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa9d884b4	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xad75a37c	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb3c8effe	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb434f7bd	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb6765323	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb70ce99f	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb793b080	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7da34c7	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbabd44b7	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc1a3d61c	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc210af72	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc73a50e7	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc746e6a9	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xca39fb15	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcc8c6ca6	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd3eb19e5	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd7685209	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd812d324	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdcdd4568	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe1d8b994	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe3bdcd96	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe6d3304f	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xecc5380c	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf61d4108	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf934174b	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfc6c37a9	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfd4969ea	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xff474579	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x1b06ce78	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x2447a6ab	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x314a20a8	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x5e9c24ff	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x8c8ab242	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x9a1b1df9	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xdced6db1	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x1f900acf	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x262cf476	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x2a5603f9	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x2f15a189	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x35585023	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5dea5bf1	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x70de6c8b	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x99d8e769	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa1ab8ba5	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa53642d8	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa8504bd7	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xc6abc36e	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xcd88c59a	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xdd1dcab9	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xef91d285	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf2738232	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xfd9b5cab	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0xda2529f5	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0324e9af	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x045d7612	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x04eaa21a	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x08aab7e8	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0abfd5fe	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0d6918a9	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x218424a0	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x351552d3	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x432f701a	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4c7310ea	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4cafc064	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4fa72716	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x58c1e956	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x61cdd5db	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x660fc9b3	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x748b99ae	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x74b91f1c	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7789a329	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x78ea15eb	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7f4f5c3b	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x825f142c	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8c3f898f	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8fd1bc34	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x9f06fe94	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa75b6221	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb794377f	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xbbb4ac15	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xbeac0dc7	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc0af680c	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd31a9020	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdac1ea1e	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xddba7d95	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe0ec2df5	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe407cc6a	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe8566495	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xebbe56cb	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf101cf81	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf18f28de	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf199d88e	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf5147288	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf5d38203	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x4a97fc6a	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xcacd1b24	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x598e4f38	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xb089871d	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xe28e3de5	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xee9a9c16	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x00ab2b42	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0116e31a	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0434c549	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x333c051a	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x34531aaa	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x404ed3b5	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x43be6b2e	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4a500bbf	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5884534c	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x59648d05	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5fecf410	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x62d6f6f5	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x74c82dd0	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x7769475b	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x94886e26	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x997fdd42	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9f39a8be	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa47da5a8	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa6fdccc4	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xab7a791b	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xafc43c0b	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb0895eb2	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbd336d9d	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc81ce502	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xca7b62fb	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe708f7d4	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf4c9973e	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xfd79de8e	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x48e71ffa	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xb1000a5c	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xc68ccfc1	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xdfb22060	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x2cc2575b	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x689f30ac	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xd503d4b6	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x70fd7536	microread_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0xca7fa68e	microread_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x3c43a54c	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x70db6ef4	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xdc7d8bf9	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x68c667ed	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0xa37d54d9	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x12b23df6	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xa214f605	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xab9e890f	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x260c3c97	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x2753b610	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x2a48c55a	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x331a0034	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x3d23bebd	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x585055a3	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x6d3c8262	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x9866b57e	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x9ce94cb0	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xce4754b7	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xdd6cd5d3	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x01b7d430	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x13be5d8d	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x29d506f6	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3066114e	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x5d1a66a4	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x75878e1c	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xa6c45e06	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xb7a1baae	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xbb2fe3c0	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xc07e43ef	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xc47e6d5b	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xc60ccac5	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xe0b7665e	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xe5a33c2b	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xea94a137	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xec2d3ef8	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xee5b2606	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xf4429bae	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/ntb/ntb 0x1d5186d4	ntb_set_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x2ad338e5	ntb_link_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x3872d34a	ntb_unregister_device
++EXPORT_SYMBOL drivers/ntb/ntb 0x538242b9	__ntb_register_client
++EXPORT_SYMBOL drivers/ntb/ntb 0x6c4716e1	ntb_db_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x898da980	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0xe506627d	ntb_register_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xe85f0ed8	ntb_clear_ctx
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x333cb14f	nvdimm_namespace_attach_btt
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x5947c61e	nvdimm_namespace_detach_btt
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0xf5ad5d5d	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x10ad86e8	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0x1c356d9b	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0x1d8e384a	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x25deb2d3	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0x2bdaf87d	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x2e7c85d7	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0x3638d967	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0x3a13ef0a	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0x3c0eac9c	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0x455e7dc5	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0x46b190a0	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x67022f7c	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x6c33e606	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x70a18ca2	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x737341b7	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x7a25e11c	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0x7b3810c2	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x8c3bea51	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0x9a6c2ed2	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0xb527e6e6	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0xb8ddfc44	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0xba4a21d2	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0xc43b3dd6	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0xcdf7f3cf	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0xd0e5ffe4	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0xd1abd931	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0xd9e66471	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0xe3435ae3	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport 0xe77851ed	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xe9f2e71f	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0xece1cd8d	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xfedb101d	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport_pc 0x223b47f1	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0xa5e96dad	parport_pc_probe_port
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x046aeca8	pcmcia_register_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x0be80bac	pcmcia_release_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x123e7c06	pcmcia_get_mac_from_cis
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x17004a5e	pcmcia_loop_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x1c2c96ab	pcmcia_request_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x2f5a1075	pcmcia_unregister_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x4a744b88	pcmcia_request_io
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x602905d0	pcmcia_fixup_vpp
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x67e07f26	pcmcia_dev_present
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x742f5665	pcmcia_parse_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x8ca37875	pcmcia_disable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xa9ad78d0	pcmcia_request_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xbdb62b8d	pcmcia_enable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xc105aa92	pcmcia_fixup_iowidth
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xcd101782	pcmcia_read_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xcf0142f7	pcmcia_loop_config
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xde0cc223	pcmcia_map_mem_page
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xecb68e0b	__pcmcia_request_exclusive_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xf9a7f1ec	pcmcia_get_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xfbd0e52b	pcmcia_write_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x00db41d7	pcmcia_put_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x06e9b999	pcmcia_socket_class
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x0b161188	pccard_register_pcmcia
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x1ff0b649	pcmcia_reset_card
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x212db8d2	pcmcia_socket_list
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x21fb9220	pcmcia_parse_events
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x5331f34a	pcmcia_get_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x569c699e	pcmcia_register_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xb15ca60a	pcmcia_get_socket_by_nr
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xbe3a22fc	pcmcia_parse_uevents
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xc751a672	pcmcia_socket_list_rwsem
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcf97f3bd	dead_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xe163c5c9	pcmcia_unregister_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0x9f1441aa	pccard_nonstatic_ops
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0xa9e51ddc	pccard_static_ops
++EXPORT_SYMBOL drivers/pps/pps_core 0x02a2a4df	pps_register_source
++EXPORT_SYMBOL drivers/pps/pps_core 0x057049e4	pps_lookup_dev
++EXPORT_SYMBOL drivers/pps/pps_core 0x186c6b53	pps_unregister_source
++EXPORT_SYMBOL drivers/pps/pps_core 0xd1e4f107	pps_event
++EXPORT_SYMBOL drivers/ptp/ptp 0x3c3a8962	ptp_clock_register
++EXPORT_SYMBOL drivers/ptp/ptp 0x9e2b4bb9	ptp_clock_unregister
++EXPORT_SYMBOL drivers/ptp/ptp 0xb1864160	ptp_find_pin
++EXPORT_SYMBOL drivers/ptp/ptp 0xba342482	ptp_clock_event
++EXPORT_SYMBOL drivers/ptp/ptp 0xf42dfa0d	ptp_clock_index
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x3e743e29	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x46319633	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x468424ac	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x47fa88b8	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x51985a5d	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xca5f0fff	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xd981031e	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xda09b86e	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xe68b5cae	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xe8d7d397	rproc_add
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0x0a218bf9	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x0cf6561e	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x6f1685ea	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x8f3ae3a0	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xd2533bc8	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x07582ea6	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x10df0b57	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x157601ea	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x4316cb16	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x70307bdc	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x70764949	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x996645b2	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x9afc0f2d	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xa98c5b71	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xcf6e129c	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xf111ae1f	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xfebb4d52	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x026b6eed	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0bf0e712	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x11654a67	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x128e0ecd	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x12e5b65b	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x13c074f4	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1430414c	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x17053bce	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x215cca62	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22477734	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2c6c03fb	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2d3254d1	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x322526c7	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x41ac9b14	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x42cc6cd6	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x466d3e45	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x468e536e	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x49dcf3bc	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4acbddca	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5303afb0	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5ccc441b	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5dc68312	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x71454e49	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x738fb5e4	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x78585644	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7b1a0946	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8403b789	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8cba5a21	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x93dcd1f2	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9a93b565	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9ccf0495	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9cec5cbe	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa62bec20	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa75605eb	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa93dc2e1	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb19c33e0	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb22c4d43	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb632bdd9	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbf4c89d5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc234acdc	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc34b8fdc	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc49baa6a	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc6b45c40	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd1d4c561	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xea7b43d5	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xed13694a	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xefc4b957	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf0e6f13c	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf42a14f3	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf5ab8197	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x5b86b4cd	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x72c41949	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xc48673f2	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xc75512cf	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0xcfef8f69	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0e40a22d	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0eb5ecd7	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x127b4226	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x20b8758d	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3118599e	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x322879b4	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x37c1c635	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3976719f	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x47a6bbf9	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4dc1a891	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x527ac548	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5a241f15	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x64a7173e	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6dcf2b2d	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7602584c	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x76e513bc	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x76e5b697	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7887c6ff	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7a20070f	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7c059409	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x81d7e436	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x87d50f82	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9c66dd99	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9caade78	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa2b00a4b	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbace06fb	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbc14c1a2	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbd577b41	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbe75973d	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbf9c59c6	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc584ae44	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcec60c7d	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xda46e410	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe3d41c3f	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xeaba1fbf	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf4e07ab5	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x0cebd746	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x1790ebda	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x241ab5d8	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x37fe5fc3	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x436af312	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xd55aabc6	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x02e1ce5a	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x10079f5f	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x12335e66	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x578972a9	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x5f09d4b7	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x8778e52a	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x9283231d	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xcebb29f3	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xd75dbc95	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xd8935dad	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xef06835c	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xfdd71914	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x1f55cd70	qlogicfas408_ihandl
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3fd8cd71	qlogicfas408_detect
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x55d7c219	qlogicfas408_queuecommand
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x5c1aa0b3	qlogicfas408_bus_reset
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x9b95257e	qlogicfas408_biosparam
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x9ed1138a	qlogicfas408_info
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xdcfc95ff	qlogicfas408_disable_ints
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xdf8eea72	qlogicfas408_abort
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xe76b3b20	qlogicfas408_get_chip_type
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf2b95199	qlogicfas408_setup
++EXPORT_SYMBOL drivers/scsi/raid_class 0x1eec8a34	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0x3d2fbe89	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0xc8b13c03	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x25d833e9	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x27223584	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x4daae358	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x80dbf992	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x86a29998	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x87a7e6b9	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x8dc431f7	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x90a1cee9	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x941ae5e0	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xb9f952ad	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xc48f71bc	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xe6593253	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xf7aa35e4	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x00c965f7	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x032de964	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x13be756b	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1c76dd06	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x201db958	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2d5afc9d	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2e203563	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x3a5790b6	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x492c2b28	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4aa9cb95	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x53d12b94	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x56315e8d	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6d497178	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7f8d6670	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x85702255	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x89a01432	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9da8c2ae	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa09d1be4	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa7db6ee7	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa7f5244e	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa9024f10	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xaaa22f45	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xaae7e649	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb2872eb9	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb7371b92	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb7bbe70f	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc6fb8618	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe5e64264	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe66b4d33	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3dd7b2a8	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x6f4e88c4	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xa4e082dc	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xa747adfd	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xa82193a5	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x2e676b47	srp_reconnect_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x43f4516f	srp_rport_get
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xa14c5e2f	srp_start_tl_fail_timers
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xf4b00ef7	srp_rport_put
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x25f14f43	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x3903d4d3	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x406271d2	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x674be8b6	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x67b65cc6	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x97a7961c	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x9c2df20a	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x07f714f5	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0x113731f0	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0x2fe46d9e	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x3818aeee	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x39bd0fa2	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0x3e8c4384	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x45db6220	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x5a1215fc	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0x68ed6911	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x6af023b9	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0x80ebfe2c	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x80ecb239	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0x8f1f9d34	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0x98d64d30	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0xaee85699	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0xb349d803	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0xb82d7d67	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xc5081b2f	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xf59c0cac	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xfd7200c0	ssb_bus_powerup
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x02c460a2	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0af51b8e	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0e602147	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1c33dc0f	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1e50408f	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1ea6ecde	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x27d00351	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x4ac48f9d	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x68ed0322	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x706343b2	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x83f93fda	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x8db458e5	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x8fd2e440	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x9ea27365	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa168b1d6	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xb23acf00	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xb38b2acb	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xc035a8f5	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xcfe6102a	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xdd0e7d21	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe1559ecd	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xf27c8829	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xf7e0ce9c	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xfaa06d91	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xc25defe6	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xf280a6cc	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x21b90f58	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x0dede8b8	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x2707bb16	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x3e8b8725	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x57ce5752	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x4cd92b3e	ade7854_remove
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x9d6f9eff	ade7854_probe
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0xdeb4197e	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0xfcc3adf5	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x024d369a	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x08bc76fc	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0e06985f	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0ec1f49d	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x11a974ce	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x12dd5910	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x135147ea	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x19008a51	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2419fe5e	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x257424b7	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2f95c469	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x39dc9835	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3df05047	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3e77f740	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4a99c42c	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4ddc74b3	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x50ff0579	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x59bbf872	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x60c8b3d3	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6602326d	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6e7c8fa2	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x77ef07d3	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x78080d5a	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7dc67077	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7e832a76	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7fe80da0	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x83293b5c	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x85371a0c	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8dab857c	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x972e0761	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x97bf1653	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa25c189e	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa2932475	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb846c597	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc23b78d9	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc2b6c1bc	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcbd7dfa9	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xccf375c4	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcdf376b4	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xce474ea3	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd3ad15a4	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd5831dae	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd84370d8	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdae0526b	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf5d83143	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf5fc0f09	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf7135c2a	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf8d15158	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfb483378	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfc96ac51	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x028caefc	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x062ca22f	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x097b0502	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0998fb2f	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0cdc7fbd	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0f099f61	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0f1356d0	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x10a8fb2c	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x18c9b850	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1e95a913	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x263da46d	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2650d560	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x289cf4fe	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2b3f99a1	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2db1dcf1	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2e1186b6	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3d1dc11f	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x40e27eb1	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4cf2b1e3	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5b7f8995	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5ed28d84	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x61ea895d	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6b894b76	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6c67311c	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6e82e78a	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x78eb5224	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7dfefceb	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9382ccb8	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9dbf9e87	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa145e74a	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa27890a8	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa3f5304e	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa6b50da3	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaac99fd6	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xada23c38	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb1ae818e	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb697eb8d	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xba9c74de	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc4af9208	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc4da1103	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc8c4967d	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd1a52568	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd333d9c0	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd33e06a5	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd6fa8a24	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd9f0fbdc	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdfe28677	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe3575bf1	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe7701784	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xef9dd125	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf02aa838	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf6a105c7	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf75156b5	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf77dccc4	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfe56a76d	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x08b2a8d5	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x17120088	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x209b610f	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x2de16f9e	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5ae60f74	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5b46caee	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5c0da850	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x610e961c	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x639dc53e	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x64663531	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x65b3fcc0	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6f1a2138	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x75b25db2	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x7c1c7146	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x90306ef6	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x91deff85	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x9ad2add8	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa2a28174	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa7f2a031	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xad54dd51	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xaf795de8	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb3eeaa80	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc0740b64	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd1b660ff	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xdc45932d	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xdd6ffe77	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xde0b77b0	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf2cf01f5	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02bd4594	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x102b5ffb	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0x11ab2549	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x11dca53f	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x14160219	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1b14fddf	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1e64805b	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1e852fed	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2040f48b	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0x20f5710a	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0x234b5179	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0x23ea0cac	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2a4a3761	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3124d29d	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0x313900b5	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x40562fcb	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4bc6f831	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0x52f21125	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x52f769f6	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5ab2326c	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5f4a99da	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x60d26d5f	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x60d446cd	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x61f24f5a	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6cb66679	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7506c162	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0x78c6d446	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x79678671	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7cf3b6ae	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x81af95e8	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8f7e1773	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9327a53e	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x95c8e495	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9a29a888	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa1e8523d	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa6693c12	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa7661a96	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa8f47e50	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0xae1e3ca3	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb1d84214	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb4d54cd2	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbba05816	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbd021b1c	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbff3ccd7	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc056c0bc	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc28db68c	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc3133008	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc7a5539b	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc841fb33	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd19b3109	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd23e3f4d	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdedca53d	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdf3f7d2c	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdf8155e0	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe0980ba2	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe1b2d802	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe3150297	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe4ddf2d1	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe55b9569	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe5f443d9	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe78d3767	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xebff5607	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xed8bf3fe	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf04e1b6f	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf11b5d09	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfb1b0b66	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfc08d18c	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfc4f4a14	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfeedf81c	transport_init_session_tags
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0xd875fa5c	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0xc4567394	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0x8e3337eb	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x0ed412ef	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x1a1465dc	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x33cbf1e4	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x4df86843	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x55343846	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x62d3a38c	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x6386df10	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x709a6fc8	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x70b95fe7	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x87c948bb	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xbed87240	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xf05ea62a	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x1b8a34ac	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0xc4a8d7fc	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3b304ebb	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3c71c418	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x4311cd91	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x5fedea44	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x97fa07e9	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xde804bb9	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x194934c6	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x1f3f17ae	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x40e95be4	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xaaef395c	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x175f4ccf	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x3b33934a	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x424f50d9	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x7179c0bf	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xa8c4cc9c	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xc6bad6d8	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xeacc3925	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xe6d4d485	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x36ac568d	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x9fb0f7d8	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0xb072f5b8	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x10b9b726	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x1a5f050b	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xb1a0dc57	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0xbeb3ba34	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0xc042195a	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0x7affb554	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x5fe4730b	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x96c36cbd	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xa7e2d4b1	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xcd77ef2f	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0x273b7fad	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xeae7a67a	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x01e7c7d4	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x3afbd782	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x49343d7f	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xaee27bec	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xdf88fab3	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0x3b4fe115	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/virt/fsl_hypervisor 0x45fd1882	fsl_hv_failover_unregister
++EXPORT_SYMBOL drivers/virt/fsl_hypervisor 0x77c9b191	fsl_hv_failover_register
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x0099b0cb	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x2cb72716	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x9ac7af2b	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xc450df9e	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0xbd7e603c	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0xc9b5dbb2	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x58e3ca52	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0xba0f965c	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/wire 0x221beb9e	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x4548774f	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x9c82afd4	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0xd807225e	w1_register_family
++EXPORT_SYMBOL fs/configfs/configfs 0x11a37984	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0x1cb11e5d	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x209b88dc	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0x2aec9049	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0x3952da36	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0x439673e9	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x56e01bad	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x6c9fa1f9	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0x7d174b75	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x8972787d	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0x985d441d	configfs_unregister_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0xb27568b1	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0xc3fbb031	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xd7dd2d31	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xfca0fc23	config_group_find_item
++EXPORT_SYMBOL fs/exofs/libore 0x0fb6305b	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0x15356d05	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x719555e9	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x8c8da945	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x960114e5	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xa79dd99f	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0xa7e1b9a8	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0xc40ca498	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0xd2cab31b	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0xf98b185a	ore_read
++EXPORT_SYMBOL fs/fscache/fscache 0x07b86a8b	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0x08e749fe	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x0971b6d5	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x0af7172a	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x0dde309d	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x0de5e689	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x0fa0ef2c	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x167f88df	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x1f7431ef	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0x20db2d78	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x3950ec3d	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x3b65eb14	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x41c4b6d7	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x4eac0ade	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0x5cb95c21	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x72453d95	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x763dcdf7	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x777c4179	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x80a88076	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x83a225bd	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x8414230e	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0x8fd52d8d	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x96fba267	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0xa51bb9f4	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xa7bff5a1	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0xb9b74c5b	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xba21e33b	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0xbcf6369c	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0xbe9d5f2a	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0xc27027e4	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xc4c12841	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0xc7e631f8	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xd40d7d90	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xe46645ed	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0xe5141f10	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0xe741a5cc	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0xe850b98e	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0xea9e761c	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0xef40b1e4	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0xf34aa2e0	__fscache_alloc_page
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x1fd8d247	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x46fa4143	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0x69c23a6b	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xbbc3a9d8	qtree_write_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xf241a9ca	qtree_read_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x1a703ba1	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0x6d356209	crc_itu_t
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc7 0x56329ecc	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd09b2cba	crc8
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x0641307b	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0x098d2ed9	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x18462b06	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x2d47ac83	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0x2f3dcecb	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0x4522d82a	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0x4a35ecfc	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x4cf5f5a8	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0x5752f31b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0x7257beee	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0x9134feb7	lc_get
++EXPORT_SYMBOL lib/lru_cache 0xb672aa97	lc_create
++EXPORT_SYMBOL lib/lru_cache 0xbfbe53d5	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0xc3a98c1d	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcc979a91	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xefec290a	lc_find
++EXPORT_SYMBOL lib/lru_cache 0xfd525ec7	lc_put
++EXPORT_SYMBOL lib/lz4/lz4_compress 0x0c222eb5	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x682a23e0	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x7456cc61	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x3452f117	lowpan_netdev_setup
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x84305613	lowpan_nhc_del
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xd4ab3507	lowpan_nhc_add
++EXPORT_SYMBOL net/802/p8022 0x770cbf0d	unregister_8022_client
++EXPORT_SYMBOL net/802/p8022 0xb2f60647	register_8022_client
++EXPORT_SYMBOL net/802/p8023 0x7e0ee1cb	destroy_8023_client
++EXPORT_SYMBOL net/802/p8023 0x876fc2b5	make_8023_client
++EXPORT_SYMBOL net/802/psnap 0x2b3a0257	register_snap_client
++EXPORT_SYMBOL net/802/psnap 0xa35553af	unregister_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x00ee2cff	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x046c2437	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0x0e7d78fd	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x228cc9e7	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x26e8c692	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0x2d4623d1	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x315c4cfd	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0x35c346bc	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x35d3755f	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x3aeaa2d6	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x3cb29971	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x3fb1249e	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x4e3e958d	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0x53d58a07	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x557cd124	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x59235461	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0x5e871382	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x64b13847	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x7725131c	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0x86fa9f7f	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0x87f73ff5	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x946a1d80	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0x9694aca2	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0x9ba9dfe8	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xa8171deb	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xae843c02	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0xb6231c68	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0xb864eda0	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0xbc7efacb	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0xc2f791ce	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0xc5b3a15e	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xca6febb0	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0xd0fa07cd	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0xd29df58e	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0xd4a99537	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0xd76cb99a	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0xdfb1e6ed	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xef9aef68	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0xf4308c05	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0xf47eb06b	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf827565f	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfbb6cc3e	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x5c4ad199	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0xd8341af4	atrtr_get_dev
++EXPORT_SYMBOL net/appletalk/appletalk 0xf4bb15fb	aarp_send_ddp
++EXPORT_SYMBOL net/appletalk/appletalk 0xff88cc3f	alloc_ltalkdev
++EXPORT_SYMBOL net/atm/atm 0x0461ec48	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0x21b9b822	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0x235df3d4	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0x2afb25bf	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x314fef89	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0x36b0c96d	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x38c7b291	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x47316016	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0x70609767	atm_charge
++EXPORT_SYMBOL net/atm/atm 0x71e5ea7a	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xc8e6be77	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0xca87b453	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0xe8e5a6cf	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/atm/atm 0xfe274b03	vcc_release_async
++EXPORT_SYMBOL net/ax25/ax25 0x18362a0c	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x37ec699e	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x66011a8c	ax25_ip_xmit
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0x94b3ec00	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0x9819754f	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xcca3ac15	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xdb5337f6	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0xfb467d75	ax25_send_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0aa2d343	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1103c972	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x122db8af	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1be9ff0f	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1dd6800a	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x23ea80a0	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2557f6b0	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x387ad044	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3cc5f3ec	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3ea8528c	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x45c48aba	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x467d3f32	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x504b3071	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x5505d4d3	bt_sock_wait_ready
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x5627a5e6	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x5646391f	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6048a35c	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6361a463	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x68941d65	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x746e94ca	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8069edd8	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x80e02318	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8c968d7e	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8e1aed2d	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8e1d4624	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8e8e134c	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x90080a6c	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9296f562	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x931900dd	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x94e3f079	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x96420c6e	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa967e543	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xaf3c3691	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb24566ad	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb8293515	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc038b251	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xce2ba558	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xdc159d2c	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe0b8e4a7	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf9685e91	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xfc8f7b44	hci_register_cb
++EXPORT_SYMBOL net/bridge/bridge 0x11a50dec	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x0199c195	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x76dbf7c7	ebt_register_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xb61ae187	ebt_do_table
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x22c015d1	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x93cc6e43	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xb2ab47fc	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xc3d8c55e	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0xc535d56f	caif_disconnect_client
++EXPORT_SYMBOL net/can/can 0x367bb17f	can_rx_register
++EXPORT_SYMBOL net/can/can 0x47081b09	can_proto_register
++EXPORT_SYMBOL net/can/can 0x812cd977	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0xaf8bbd93	can_send
++EXPORT_SYMBOL net/can/can 0xb2b2aba4	can_ioctl
++EXPORT_SYMBOL net/can/can 0xcbe7f056	can_proto_unregister
++EXPORT_SYMBOL net/ceph/libceph 0x078b4704	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0e83c6b6	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x1476c467	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x1662ff42	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x198d803d	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0x1b45b94a	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0x1c7003b6	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x206425d7	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x21c60751	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x24d897df	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x27e8109d	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x350ae1d2	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x3864c4b1	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3ac8a486	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0x3d250a3b	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x3de7f060	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0x3e29ce06	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x3fe633c0	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x410012e9	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x419cb09b	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0x42f50763	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x45fc2d53	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x4b77daec	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0x4b8dc8fe	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x56e38552	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x5996afcc	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x5d8ae87b	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0x6086fbda	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x62367714	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6c70cf15	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x6fcdafef	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0x70143de8	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0x73ade3d3	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0x7429000c	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0x7633e121	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0x77d4f306	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0x7d66cff5	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x7e1f5ee3	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x807ea240	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0x82151f53	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0x84631624	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0x85a4d229	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0x85b995b9	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x861751ed	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x8c74a0f1	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x91df5e15	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x950ad8a4	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0x9590eab7	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x95ca5525	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0x98546246	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x98cf3ffc	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9cea08e5	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0x9ed9c3d4	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa71b2d88	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xa83c08d6	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xa8a70554	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xad81af74	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0xae1a2fa6	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xaf2840fa	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb64a6549	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0xb6aa0fef	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0xb6fa6b43	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0xbbe2e850	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0xbe533a71	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0xbed46bc4	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0xbf3a918e	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xc336df17	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc85c91eb	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xca50db0e	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xcdf13469	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0xcffff883	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd35d157c	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0xd37d9e3d	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0xd4be214d	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0xd7acd83f	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xdaedee77	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0xdb2b5259	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xdd25f3b1	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0xe3357064	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xe3b042ca	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xe9bd72ed	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0xe9d1b906	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0xf1437868	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0xf17ab4da	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0xf35cb4d9	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xf5fcd7b2	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xfa57adfa	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0xfb39adc9	osd_req_op_init
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x7d9dc4b8	dccp_req_err
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0xe7673cac	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x06dd10a6	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x11178c8f	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x38cfbfb2	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x8b043b7e	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xb0587b07	wpan_phy_find
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xc9862dff	wpan_phy_new
++EXPORT_SYMBOL net/ipv4/fou 0x0b58b38b	gue_build_header
++EXPORT_SYMBOL net/ipv4/fou 0x3106aeb4	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0xd0750778	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0xe36f2863	fou_build_header
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x00a87c13	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x077f9b12	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x242f6dea	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x37ec4061	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xdd968908	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xe44b7f61	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x07b143a5	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xc648711a	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xca4ff2e3	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x09bb79aa	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x689e0a5c	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xe7e0b29d	ipt_do_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x0ddb4c3c	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/tunnel4 0x108d9512	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0x0d5940bf	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x589e5658	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x8da3e73e	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xf6ab52b6	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xfa1cb189	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x5c28e450	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x64a4d805	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x775cf6e7	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x1d51e67d	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0x3ffee5e4	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x75c30dd3	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0xe64ca5ac	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x0969a14d	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x0c543055	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x3b27fb1d	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x6ce1ff62	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x80c38b80	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x8e54719b	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xc613a262	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xddefbdbe	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x0064e0ea	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0x03b56b3d	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x098798aa	irlap_open
++EXPORT_SYMBOL net/irda/irda 0x10c9bc3a	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0x14bf7e68	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0x1e6cade0	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x2267c950	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x39949549	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0x3e56064f	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x49d031ba	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0x4c24d9ba	iriap_open
++EXPORT_SYMBOL net/irda/irda 0x601bda46	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0x667e6872	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x6a6726e5	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6b5fbcef	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x6de43b19	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x6e0ab3c7	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x85d88217	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x87fd22dc	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x8b0c7a27	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0x8bac151f	irlap_close
++EXPORT_SYMBOL net/irda/irda 0x8f5193ad	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x964cd57a	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0xa1d41e58	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0xa1fd3344	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0xaa557515	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0xb3ee280d	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xbe8b1015	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0xc34d0d15	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0xc68e43be	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0xcead7dbb	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xd2108314	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0xd6deeaae	irda_setup_dma
++EXPORT_SYMBOL net/irda/irda 0xdd16410e	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe3463529	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0xe3bde43e	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0xe785992e	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xf078366e	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0xf0a694a1	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0xf1b8baae	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xf5876b95	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0xfbdcda99	iriap_close
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x7de6e949	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0x4ed6ee23	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x0c831f60	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0x1425f943	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0x249c6efa	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0x35d2af24	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0x3fd8f0dc	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0x5a454782	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0x66b6be0b	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0xcae3c3b8	lapb_unregister
++EXPORT_SYMBOL net/llc/llc 0x122bbdfe	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0x363764ae	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x53ce08e6	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0x6bc83853	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0xadb31979	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0xdfd7fda2	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0xeb2be817	llc_set_station_handler
++EXPORT_SYMBOL net/mac80211/mac80211 0x023f3322	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x06ca1fde	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x0bd609f2	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x0c0b0949	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x0cd86ec1	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0x0d810d9e	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x0d85c575	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x0e9f290e	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x122dfc3d	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x153d4222	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0x1ac72312	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x20882935	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0x21839162	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0x242a8167	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x24e2693a	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x2cd4a0b6	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x36f03f5a	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x3741176e	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x38134fdc	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x388f78c6	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0x3ae9bdd5	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x419c0202	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x431876cd	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x433a68cb	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x4a7159d3	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0x4c2b011a	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0x51028096	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x515c75ba	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x55f97e4f	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x5639acf0	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x574fac43	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0x5d43be41	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0x5f3ba67c	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x5f99d98a	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x65797f8d	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x66964854	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac80211/mac80211 0x66ed1e89	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x6b970567	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x6c161fb7	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x6c47ec01	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0x6df91682	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0x7095083b	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x758664a3	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x773fe3e4	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x77edad16	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0x79c85c13	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x7a18fe8c	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x8d216f4b	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x8d774c34	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x8df225d3	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x92840f05	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x96a9ec62	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x976985e5	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x9791a5ba	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0x9c4929b4	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x9f20a8e9	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0xa5cf0386	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0xb00d33b6	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0xb2ad2edb	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0xb2df0dea	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xb8f96bcf	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xb9ed53e3	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0xba6539b4	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0xbb885fcd	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xbb8f4116	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0xbfae87d7	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xc0023c6e	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xc061e695	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0xce547094	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xd59258b7	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xd703612b	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xd93d155d	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xdfd3ead7	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xe180bdef	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0xe6a4cb7b	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0xe959d0b8	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xe9dc114f	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xf0774739	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xf36ce8a3	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0xfaa093e8	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0xfb0bf819	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0xff2e937d	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac802154/mac802154 0x05633593	ieee802154_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x415e5405	ieee802154_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x78c516f5	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0xc26f5af7	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0xc8f0fd60	ieee802154_alloc_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xce0f1e37	ieee802154_unregister_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xe2d256e5	ieee802154_xmit_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0xfd178440	ieee802154_register_hw
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x0292219e	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x165b8421	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x2c4177a0	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x4a09104f	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x5b930e57	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x5d3279f6	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x7920e0d3	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xac690fb8	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xc8f14d96	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd5f29b93	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd9cbe859	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xe640e879	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xf63a90be	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xfa821e50	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x09f19f46	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xbadae743	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xbd6bf8e9	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x111b365d	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/nf_nat 0x195c9060	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x8797f583	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xd28a88b8	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0xdcd71f09	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xe6f49e59	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/x_tables 0x130ca0c0	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x1d30d047	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x253e8b44	xt_compat_init_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0x28bff088	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x37e06eb7	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x59dcffc9	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x78586b3d	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xa25fc115	xt_compat_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xaca97937	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xefa58d6a	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xf13c4076	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xf86a0d45	xt_register_target
++EXPORT_SYMBOL net/nfc/hci/hci 0x0b5c0fe3	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0x2ba7ff0a	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x2d684f61	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x31e2d05f	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0x38be46a2	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x4338990e	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/hci/hci 0x448a0048	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x603900fb	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0x654f8369	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x6a90a288	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x783ae54c	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x80a2ca7e	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0x9937b9ff	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0xa4f974c8	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0xaedd8faa	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0xba6e27df	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xbecfa87f	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0xbf6ecf61	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0xd7b9acfb	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xe71742ba	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0xf6616f17	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/nci/nci 0x0105cbbe	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0x0beba47f	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x0fc83ad5	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x1c093feb	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x2f1b7f8a	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0x3c6a42fe	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0x3d075a80	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0x3e0d5f7a	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x4cf0df9d	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0x4f9ad2b6	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0x5b635e94	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x5d7dd228	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nci/nci 0x636faabc	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x825c31bc	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x82cac518	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x91d5fc99	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0xaa547f00	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xbd09e145	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xbeb3bfc4	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nci/nci 0xc09340eb	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0xc39e8925	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0xd286404e	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0xd2def9a1	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xd613ae85	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xdf7ddb62	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0xe3f30803	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xf47036c9	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xf92f346a	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nfc 0x05bb0af8	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc 0x08fa9fda	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0x0bfe1952	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0x0cac1c5d	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0x1a64f7f3	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0x2901a1c9	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x2946ebbf	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0x2bf09452	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0x3a19cf64	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x3f40de50	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0x4cfffdc6	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0x54364aa5	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0x86f2941e	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0x9b93dc55	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0xa52a927a	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0xa832d68a	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0xb22bc33e	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xd4a3eae9	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0xd517f912	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0xe5f2332c	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0xe92e852f	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0xf38b843d	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0xf4b5c465	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0xf58f5105	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc_digital 0x16e8cded	nfc_digital_unregister_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x2b4ccee7	nfc_digital_register_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x4d956bf6	nfc_digital_allocate_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x76bff7d6	nfc_digital_free_device
++EXPORT_SYMBOL net/phonet/phonet 0x1e8a1fdf	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0x305aaaef	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0x48484f0a	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0x640316c5	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0x674222d4	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0x7e604ec1	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0xb60be822	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0xc793148a	phonet_proto_unregister
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1332eec5	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x16a91a09	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1c1c1f1e	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1c76ae4f	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x34b39210	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x3631d643	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8f9fe3eb	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb6206689	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xbd06ffbc	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xcbd1cf3c	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xd80a3de1	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xd8f38e36	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xda9cbe17	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf52dc370	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf5886c4f	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/sctp/sctp 0x3ab9c871	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xb2fe2860	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xcfbf21b8	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xe4d785b5	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x5c038847	xdr_restrict_buflen
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x5fe381b1	svc_pool_stats_open
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xbe69bf8f	xdr_truncate_encode
++EXPORT_SYMBOL net/wimax/wimax 0x004d41c0	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0xac9d72b4	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x02f9d21f	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0b3ff06c	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x0db4070c	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x0dfa6edc	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x0ebd20fd	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x0ffa7eb4	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0x16b6a1be	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x17f5ed73	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x1b3ace94	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x1ce42a1e	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0x212860a3	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0x25f6a39a	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x2611d616	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x320941f6	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x33a5a24e	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0x36b92344	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x3a5b1923	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x3a94a288	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0x3bc9d5be	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x443877be	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0x45de969d	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x48e8c630	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x492ab305	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x49577c33	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0x4e7d1991	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x52a372da	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0x553baf5a	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x558f8e9a	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0x56815999	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x58f43970	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0x59656341	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0x5a4f066b	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x5f278404	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x62a7bbd8	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x63c89ba4	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0x6476e1cf	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0x686d7b7b	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6a92b09c	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x6e8cd32e	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0x6f2f3ed5	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0x70f6c08c	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x71f56aa7	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0x72fe3fd2	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0x79743c05	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x7a43c79c	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x7a4f6549	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0x7d7bad22	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x7e85f13e	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x831f4ddc	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0x8467bbc3	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x8ba18898	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x905c93db	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x91d7a142	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x93c927e3	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x94cb834e	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x952bc994	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xab8da8e2	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xad6e88c8	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0xae7a9613	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0xaea4a436	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xb5338cab	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0xb8ce0b65	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xbb3be76f	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/cfg80211 0xc392d23d	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xc40c8dd2	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0xc463e8c0	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xcc792dd9	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0xd50b0a22	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xd536c44f	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xd74a210b	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xdce23621	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0xdeb96b94	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xdf26aed2	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0xe44e20b6	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0xe9a7b292	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xed74b05f	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xed765750	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xeeef71b3	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0xef16898d	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xf237f181	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xf6b12db9	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xf8b2a4eb	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0xf9929e33	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0xfc7e1794	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/lib80211 0x1fbdd62f	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x337c5132	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x558f1594	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0xa1a7f414	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0xda451b26	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xff695748	lib80211_crypt_info_free
++EXPORT_SYMBOL sound/ac97_bus 0x79736366	ac97_bus_type
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0x7b911e55	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x089fa15c	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1d4e1fcc	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x55786758	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xebd2b3c8	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x244725ce	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x072d978b	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x13a17752	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x2eed26bf	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x4d5ca523	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x592f6e9b	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xd7c7afcc	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xe60fb228	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xecbde43c	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0x71447f08	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x08e7d011	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0x0d7aef35	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0x0ec6bfc1	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0x15255643	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0x18e1683f	snd_dma_program
++EXPORT_SYMBOL sound/core/snd 0x191e88cf	snd_dma_pointer
++EXPORT_SYMBOL sound/core/snd 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL sound/core/snd 0x1e9ff47d	snd_register_oss_device
++EXPORT_SYMBOL sound/core/snd 0x1ff5b97f	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x26a8dacc	snd_jack_add_new_kctl
++EXPORT_SYMBOL sound/core/snd 0x28164c31	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0x342a2354	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x358396e8	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0x38f9b41c	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x3de97696	snd_jack_new
++EXPORT_SYMBOL sound/core/snd 0x406de084	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0x47f88f27	snd_ctl_unregister_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0x481d2a2b	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0x48f80dc9	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x506d6491	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0x55d11abd	snd_cards
++EXPORT_SYMBOL sound/core/snd 0x56631c76	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0x58780db4	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0x634846d3	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0x64b003e7	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0x69363482	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0x6e9d236b	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0x6edccaa2	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0x70c15ac1	snd_dma_disable
++EXPORT_SYMBOL sound/core/snd 0x7581b22f	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0x78c9f0cb	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0x7cd78c9c	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x8b5f189b	snd_unregister_oss_device
++EXPORT_SYMBOL sound/core/snd 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL sound/core/snd 0x8e64c48b	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0x8efbf82c	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x9106c5ef	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0x93d4ae51	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0x96e0c774	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0x97e07f14	snd_register_device
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xb562303f	snd_device_new
++EXPORT_SYMBOL sound/core/snd 0xb7b03893	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0xb8b63696	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0xb94bf420	snd_card_new
++EXPORT_SYMBOL sound/core/snd 0xbb60e715	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0xbc66ea5d	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0xbe0051e9	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0xcde4285d	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0xe3b748af	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd 0xea89700c	snd_ctl_register_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0xf26e8f20	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0xf9d64e7b	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0xfc704081	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0xfe6a1fc0	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0xfffd89db	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd-hwdep 0xfdfabf70	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x000e2f5b	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x02f2ad48	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x06b310c9	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x119c0b48	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x1e2e341f	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0x21a8181a	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0x239b8330	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0x2ae3e655	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x2cf94a45	snd_pcm_lib_mmap_iomem
++EXPORT_SYMBOL sound/core/snd-pcm 0x33615975	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x3c85e79f	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x3fab2900	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0x4db39619	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x4df28661	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x582c0588	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x5898dcba	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x5923fd8e	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0x5a1657ee	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e81bd2a	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e9af3e3	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-pcm 0x64d3ff12	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x68459126	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x6a22855c	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x723fb8e1	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0x7881cf9f	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0x7fa67398	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x81902296	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x8227e5cc	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x834dc955	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x8701dba9	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x87686d68	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL sound/core/snd-pcm 0x89e72cad	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0x8a9819d2	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x8c9eaa98	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0x8ec62715	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x9ebd4707	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xb0cacdd3	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0xb702e557	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xbfa78b7d	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0xc118d458	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0xc506d468	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0xd887c552	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0xdd9bbe62	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xe1333e83	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xea20521c	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0xee60a106	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0xeea14b58	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0xf3823fd9	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0xfc02f128	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0xfc5b4eef	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x0a550256	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x0fb64db4	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x13904792	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x23de0bd5	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x49986c44	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x582e1862	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x60f7b5aa	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x69d83e69	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x728f3f35	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x766d86b7	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x88e9547e	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd24102db	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd82029ee	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xe072a3ce	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xe647f0cf	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xe9f2b48c	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xef8de35c	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xf1d4274e	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xf479f4bf	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-timer 0x1182f566	snd_timer_start
++EXPORT_SYMBOL sound/core/snd-timer 0x153888e9	snd_timer_pause
++EXPORT_SYMBOL sound/core/snd-timer 0x1d1b2075	snd_timer_new
++EXPORT_SYMBOL sound/core/snd-timer 0x38fe2bee	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0x4174caf7	snd_timer_close
++EXPORT_SYMBOL sound/core/snd-timer 0x56546c9c	snd_timer_global_register
++EXPORT_SYMBOL sound/core/snd-timer 0x5f08f68c	snd_timer_open
++EXPORT_SYMBOL sound/core/snd-timer 0x68f82281	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0x6d3603ad	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0x73610504	snd_timer_stop
++EXPORT_SYMBOL sound/core/snd-timer 0x7774660b	snd_timer_interrupt
++EXPORT_SYMBOL sound/core/snd-timer 0xb10cec09	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0xf8b2515d	snd_timer_resolution
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x10706a05	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x124f5768	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x1eb60059	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x3fc0fe51	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x40d1467b	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x5ecec42a	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x6b84f406	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x7457434a	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x9b63fb37	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xcb641a83	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x1b7d81c8	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x1fed4ec8	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x294c1b1a	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x4213f306	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x479d383e	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x9ee6a8b5	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xac9a7e3a	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xc454f85b	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xe9af5008	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x069b3f5a	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x07b2991c	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x0cd6078d	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x24bbcf7c	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x259a3391	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x294db86d	amdtp_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x29f6bd42	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3c6df5d5	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4c864c9d	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x51f05fb7	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5e8e2908	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x64f4f1ef	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x67214eea	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x6a39b702	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7c5a787b	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7c8125ee	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8d35f61e	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9774c0c4	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9b668314	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa40dd190	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xacb1e0db	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xb0f9420f	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xb6a3c99b	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xb75745e1	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc0784eea	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc4c5beae	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc635ef4a	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xcf0aa2b1	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd960bbe6	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd9832db5	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe9743a4f	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xeb9f70d4	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x29286f11	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0xe6175b0c	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x1ec81bcb	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x329143a1	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x570b23c7	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x5d9b386b	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x7696bb6b	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xb63c4745	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xe66a7304	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xf5411ea7	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x5d85c278	snd_ak4117_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x65910bfd	snd_ak4117_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xa7d9d07b	snd_ak4117_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xaa7f0be1	snd_ak4117_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xd7ab98c3	snd_ak4117_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xe821d9fc	snd_ak4117_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x241104a8	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x3de71a1a	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x98348d4e	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x99a7b6ba	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x2e804238	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x8f8f8845	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x2afaaf9f	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x37a50cca	snd_cs8427_init
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x7d8c1ae8	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x8093ee5a	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xb7a1bb65	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xfcd79a09	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x5e287a8e	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x628e5a05	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x9f328d6f	snd_i2c_device_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xd45a55b0	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xdbcfeaa6	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xe948301a	snd_i2c_device_free
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x0c15a6c9	snd_sbmixer_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x1536e46a	snd_sbdsp_reset
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x375dfaf8	snd_sbmixer_write
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x5913178f	snd_sbdsp_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x8f69e720	snd_sbdsp_get_byte
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x9fa67df5	snd_sbmixer_add_ctl
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xa4d96c42	snd_sbmixer_resume
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xc628f2a0	snd_sbmixer_read
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xd27371e4	snd_sbmixer_suspend
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xf5481cdd	snd_sbdsp_command
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x07320507	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x13b3c535	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x25c45aca	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x45363090	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x54c73bf4	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x59214e9b	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x69a7e858	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x71a6eaed	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xa63a0129	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xa6e9b4b0	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb76c96a3	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xc01a740d	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xc35b8284	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xce6d17a7	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xdd42f9e3	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xde638168	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xe48539d0	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x01a5c548	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x3b5031cf	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x820f3fca	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x8387d107	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x96df4303	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xc076c2b0	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xceec3ccd	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xe67ee9c1	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xef4d087c	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x44244a0c	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x985aa851	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xfda9ecf1	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x07b20552	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0d66d14f	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x23d9c9c3	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x27ef7f6b	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x289cf56f	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x4e29128c	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x620d945d	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x63d6d2da	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x791b942c	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x807b01db	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x941c7669	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x9cb39898	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa001c885	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb4a4d153	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xbe3095be	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc1326a4f	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xe490a0da	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xee7710a3	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf35693db	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xff67f480	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x1de18973	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x25493beb	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x81a084ab	snd_trident_free_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x8f360797	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xd6bc22d2	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x4e5f158b	tlv320aic23_probe
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0xd0ae2833	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/snd-soc-core 0x35fa630e	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL sound/soundcore 0x0d57e8cb	register_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0x5068c3fa	register_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x7533b2f9	register_sound_special_device
++EXPORT_SYMBOL sound/soundcore 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x903bfe9c	sound_class
++EXPORT_SYMBOL sound/soundcore 0x99415188	register_sound_midi
++EXPORT_SYMBOL sound/soundcore 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL sound/soundcore 0xacd48726	register_sound_special
++EXPORT_SYMBOL sound/soundcore 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x18ac08f1	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x3c89bf02	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x6b19d0f4	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x7ac66250	snd_emux_register
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xb2cdcf8c	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xcc1a53d0	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x0ae73cd4	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x0aeb473f	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x15875799	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x189d8022	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x63c58f03	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xab5df7b1	__snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xd129ca40	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xec98a46b	snd_util_memhdr_free
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xe7462e38	snd_usbmidi_create
++EXPORT_SYMBOL vmlinux 0x001223b2	genphy_config_init
++EXPORT_SYMBOL vmlinux 0x001f9bdf	compat_ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x00327082	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0x0036bcde	bdi_init
++EXPORT_SYMBOL vmlinux 0x0070cd1f	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x007e07fd	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x0080fcb3	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0x00855cf3	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x0085e1f1	__do_once_done
++EXPORT_SYMBOL vmlinux 0x00b4ab0a	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0x00b7d7d1	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0x00b88545	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x00c7996b	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x00cf16a6	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x010144d5	__skb_checksum
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x010e9996	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0x01139ffc	max_mapnr
++EXPORT_SYMBOL vmlinux 0x012a97fc	xor_altivec_4
++EXPORT_SYMBOL vmlinux 0x0135732e	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0x01513ea1	__d_drop
++EXPORT_SYMBOL vmlinux 0x015b6ba4	path_noexec
++EXPORT_SYMBOL vmlinux 0x015c6f72	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x01872d70	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x019bc3d8	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x01d33c26	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0x01d60cc9	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0x01ed06a4	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x01f07882	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0x01fd7346	kern_path_create
++EXPORT_SYMBOL vmlinux 0x021fe3b7	d_drop
++EXPORT_SYMBOL vmlinux 0x0226e52d	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x02270fe4	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0x023e4443	submit_bh
++EXPORT_SYMBOL vmlinux 0x023f4388	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0x024bf827	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x02572b5b	icmpv6_send
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x02700dd6	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x028ab84c	input_unregister_device
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02a9937a	set_groups
++EXPORT_SYMBOL vmlinux 0x02ab9bc2	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0x02d29a34	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x02d5d56d	__brelse
++EXPORT_SYMBOL vmlinux 0x02de5870	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x02ea5a5f	generic_setlease
++EXPORT_SYMBOL vmlinux 0x02edca12	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0x033407f2	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x035c4369	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0x0364a3d6	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x03696418	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0x036d2284	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x03ca490a	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x03e38e74	compat_sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x04069978	dma_iommu_ops
++EXPORT_SYMBOL vmlinux 0x04074f48	ioremap
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x04630c31	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0x047e372e	blk_init_queue
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x048fae8c	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x04916654	security_path_chown
++EXPORT_SYMBOL vmlinux 0x0492240c	led_set_brightness
++EXPORT_SYMBOL vmlinux 0x04b0c712	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0x04b1c212	agp_generic_destroy_pages
++EXPORT_SYMBOL vmlinux 0x04c340d6	netdev_features_change
++EXPORT_SYMBOL vmlinux 0x04c4baf9	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x04d97262	md_write_start
++EXPORT_SYMBOL vmlinux 0x04df0d69	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04ea5d10	ksize
++EXPORT_SYMBOL vmlinux 0x04fc5893	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x050828ba	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0x05186ca4	flush_icache_range
++EXPORT_SYMBOL vmlinux 0x05204a35	__bforget
++EXPORT_SYMBOL vmlinux 0x05229586	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x05241073	bdi_register
++EXPORT_SYMBOL vmlinux 0x0530dede	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x053474ca	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x05379a7c	tty_hangup
++EXPORT_SYMBOL vmlinux 0x053ce746	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x055c8559	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x05674e90	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x05a514a1	_insl_ns
++EXPORT_SYMBOL vmlinux 0x05bf0681	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x05c0e574	agp_backend_acquire
++EXPORT_SYMBOL vmlinux 0x05ed59bb	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x05f6ff13	param_set_invbool
++EXPORT_SYMBOL vmlinux 0x05f864bc	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0x060d2407	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x061759e6	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x063cf696	posix_test_lock
++EXPORT_SYMBOL vmlinux 0x064d5d1f	pci_find_hose_for_OF_device
++EXPORT_SYMBOL vmlinux 0x064ec6d8	cdrom_release
++EXPORT_SYMBOL vmlinux 0x06532283	__vfs_write
++EXPORT_SYMBOL vmlinux 0x065bc0f0	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0x06697e52	scsi_register
++EXPORT_SYMBOL vmlinux 0x066ed902	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0x067ac8a6	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x067e7584	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x067f544f	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x0727c4f3	iowrite8
++EXPORT_SYMBOL vmlinux 0x072a9f1f	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x074b032a	skb_unlink
++EXPORT_SYMBOL vmlinux 0x074b2ad9	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0x074ba728	fd_install
++EXPORT_SYMBOL vmlinux 0x074e9213	down_killable
++EXPORT_SYMBOL vmlinux 0x0774ca95	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x07844435	sock_efree
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07a9ef84	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07dfd09b	security_mmap_file
++EXPORT_SYMBOL vmlinux 0x07e290c9	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x07ef4875	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0x07f31869	md_register_thread
++EXPORT_SYMBOL vmlinux 0x080608a4	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x082e6f58	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x083e6511	ilookup
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x084cfdc8	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x08505d62	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0x0854f83a	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x086d8cdd	irq_stat
++EXPORT_SYMBOL vmlinux 0x08767cfc	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x087796c4	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x08b0d328	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x08e1f90b	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x08eaaf24	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0x08efb1c7	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0x08f003f9	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0x08fe31ed	ns_capable
++EXPORT_SYMBOL vmlinux 0x0919cbeb	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0x091c34ad	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0x092c500c	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x098983e7	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x0994fee5	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x09b2900a	audit_log_start
++EXPORT_SYMBOL vmlinux 0x09b40fbb	tty_port_close
++EXPORT_SYMBOL vmlinux 0x09c35837	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c67afb	flex_array_get
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09cd2bc3	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x09d237ac	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09d93c57	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0x09df0e4d	d_invalidate
++EXPORT_SYMBOL vmlinux 0x0a059996	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0x0a06413f	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a35d216	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0x0a569a91	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0x0a57863e	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x0a67fe0d	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0x0a84ebf9	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x0a9a10fd	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0aa8f99a	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0x0accc08c	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0ae623db	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0x0af69784	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x0b013b78	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b30b6eb	simple_unlink
++EXPORT_SYMBOL vmlinux 0x0b42ce71	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x0b5823dc	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b614e35	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x0b62c349	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b80271f	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x0b8d5d42	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0x0b9b1e27	dqget
++EXPORT_SYMBOL vmlinux 0x0ba95f40	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bd5d517	compat_nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x0be981e7	skb_checksum
++EXPORT_SYMBOL vmlinux 0x0c134470	generic_update_time
++EXPORT_SYMBOL vmlinux 0x0c21d019	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c4e59ac	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c595227	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x0c6bdc3f	vme_master_read
++EXPORT_SYMBOL vmlinux 0x0c91640c	set_wb_congested
++EXPORT_SYMBOL vmlinux 0x0c93373b	nf_log_register
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cb506ec	sock_create_lite
++EXPORT_SYMBOL vmlinux 0x0ce510e0	agp_generic_alloc_by_type
++EXPORT_SYMBOL vmlinux 0x0ce5cc4d	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0x0cea1224	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0x0cfea460	register_cdrom
++EXPORT_SYMBOL vmlinux 0x0d1a1f19	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x0d300311	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x0d415862	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d61d0b9	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d6c963c	copy_from_user
++EXPORT_SYMBOL vmlinux 0x0d7a7823	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x0d851fe0	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0x0d95d5da	kill_pid
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0da53381	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0x0da94452	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x0dbc56b2	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x0dc0ace0	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x0dcc4361	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x0dd15c2c	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0x0ddc1710	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0x0decf20b	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x0e02dab5	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0x0e056a93	scsi_device_get
++EXPORT_SYMBOL vmlinux 0x0e0c6a2c	inet_bind
++EXPORT_SYMBOL vmlinux 0x0e17aa55	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x0e1d02fc	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x0e5260b8	brioctl_set
++EXPORT_SYMBOL vmlinux 0x0e5fabb6	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e8a3174	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0x0e8f30f6	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x0eaaf398	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0x0eb8c7a9	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0x0ec3a38b	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0eee53a8	iov_iter_init
++EXPORT_SYMBOL vmlinux 0x0ef2ea4d	set_disk_ro
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f018c25	agp_generic_mask_memory
++EXPORT_SYMBOL vmlinux 0x0f11c8d4	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0x0f142fd4	kill_fasync
++EXPORT_SYMBOL vmlinux 0x0f213d5f	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x0f25a763	inet_offloads
++EXPORT_SYMBOL vmlinux 0x0f3cf4c6	mntput
++EXPORT_SYMBOL vmlinux 0x0f4bb4c6	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f5faa7e	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x0f685732	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f85d5a5	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0x0f889f46	agp_generic_type_to_mask_type
++EXPORT_SYMBOL vmlinux 0x0f95ea12	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fc65ddb	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0x0fea413c	kobject_del
++EXPORT_SYMBOL vmlinux 0x0ff0b9c7	scsi_print_result
++EXPORT_SYMBOL vmlinux 0x0ff54d8c	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x1001eaa7	del_gendisk
++EXPORT_SYMBOL vmlinux 0x1013248e	nvdimm_namespace_capacity
++EXPORT_SYMBOL vmlinux 0x1021bd3c	sk_alloc
++EXPORT_SYMBOL vmlinux 0x103a13bc	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0x103fba42	scsi_host_get
++EXPORT_SYMBOL vmlinux 0x1041782e	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0x105eecf8	kernel_accept
++EXPORT_SYMBOL vmlinux 0x106972ab	flush_tlb_mm
++EXPORT_SYMBOL vmlinux 0x1071bab8	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x107e2946	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x107ee89b	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x1086bbd2	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0x10950ee1	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x10a3e180	param_get_ushort
++EXPORT_SYMBOL vmlinux 0x10c372b0	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0x10df0fcb	blk_start_queue
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x1101f4ee	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x11293cc6	of_find_all_nodes
++EXPORT_SYMBOL vmlinux 0x112a5f15	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0x112fca77	md_integrity_register
++EXPORT_SYMBOL vmlinux 0x11308931	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0x11586b4b	of_platform_device_create
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x1177f5cf	tcp_req_err
++EXPORT_SYMBOL vmlinux 0x1182d83a	cpuidle_disable
++EXPORT_SYMBOL vmlinux 0x1183b6ee	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x118cdd20	blk_end_request
++EXPORT_SYMBOL vmlinux 0x119366cc	dup_iter
++EXPORT_SYMBOL vmlinux 0x1193f713	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11b37acb	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x11d15dd2	lookup_one_len
++EXPORT_SYMBOL vmlinux 0x11d226aa	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120a1ee0	igrab
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x123ced43	import_iovec
++EXPORT_SYMBOL vmlinux 0x123f82f3	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x1251fce5	blk_get_request
++EXPORT_SYMBOL vmlinux 0x12572715	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x1274432f	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x12813cde	unload_nls
++EXPORT_SYMBOL vmlinux 0x1289dbcb	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0x128d1c48	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12b6b3b5	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0x12db5d1d	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0x12dfd164	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0x12dfeb12	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x12e8d495	bio_flush_dcache_pages
++EXPORT_SYMBOL vmlinux 0x12ed5d80	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x12eeeb95	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0x12f4b184	neigh_for_each
++EXPORT_SYMBOL vmlinux 0x12fafad8	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0x12fc3589	rt6_lookup
++EXPORT_SYMBOL vmlinux 0x130298c9	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0x130cbdf4	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x13215eac	mem_section
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x13360821	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x13554dff	single_open_size
++EXPORT_SYMBOL vmlinux 0x13713635	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x13901311	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x1392bb51	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0x139c5ff2	__blk_end_request
++EXPORT_SYMBOL vmlinux 0x13ca2c3b	cad_pid
++EXPORT_SYMBOL vmlinux 0x13cfd714	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x14186dac	seq_lseek
++EXPORT_SYMBOL vmlinux 0x1440ea10	input_register_handler
++EXPORT_SYMBOL vmlinux 0x145e53b8	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0x1471cf23	__free_pages
++EXPORT_SYMBOL vmlinux 0x147f806a	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0x149d0825	seq_open_private
++EXPORT_SYMBOL vmlinux 0x14acbde8	of_create_pci_dev
++EXPORT_SYMBOL vmlinux 0x14b5942b	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0x14b5ec09	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x14cb154d	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x1503daef	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0x1508bc46	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0x151a40ae	__nd_driver_register
++EXPORT_SYMBOL vmlinux 0x1535b1b7	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0x1536a5e4	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0x153bbcbc	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x15493368	nvm_end_io
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x155c312d	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x156a608b	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0x156e0019	input_register_handle
++EXPORT_SYMBOL vmlinux 0x15745242	machine_id
++EXPORT_SYMBOL vmlinux 0x158243f1	phy_device_free
++EXPORT_SYMBOL vmlinux 0x15b3b4a9	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0x15b6c8db	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15c302e1	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0x15c3f85c	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0x15d3fd60	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x15efe329	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0x15f69b43	inet_accept
++EXPORT_SYMBOL vmlinux 0x16132833	neigh_table_init
++EXPORT_SYMBOL vmlinux 0x16354a10	pci_dev_get
++EXPORT_SYMBOL vmlinux 0x164d39b2	mmc_erase
++EXPORT_SYMBOL vmlinux 0x166355f5	dquot_get_state
++EXPORT_SYMBOL vmlinux 0x1664b7a8	__module_get
++EXPORT_SYMBOL vmlinux 0x167c5967	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x16809ff9	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x1684b089	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0x16a806ac	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0x16a878cb	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0x16c44728	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0x16cdad57	napi_complete_done
++EXPORT_SYMBOL vmlinux 0x16e002f0	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0x16e04634	cdev_alloc
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x16f6328c	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x170c5b5e	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0x171108de	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0x1715c870	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0x1743414f	__debugger_fault_handler
++EXPORT_SYMBOL vmlinux 0x1751f778	param_get_short
++EXPORT_SYMBOL vmlinux 0x175435f4	pipe_lock
++EXPORT_SYMBOL vmlinux 0x17648396	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x1765295f	key_put
++EXPORT_SYMBOL vmlinux 0x17843987	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0x17860618	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x1793f685	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0x17a9a0b7	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17ccda01	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x17e28473	fsl_upm_run_pattern
++EXPORT_SYMBOL vmlinux 0x17f341a0	i8042_lock_chip
++EXPORT_SYMBOL vmlinux 0x18017e3b	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x18318839	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x184942f5	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x1857aa39	proc_dointvec
++EXPORT_SYMBOL vmlinux 0x18605a01	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0x1868d700	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0x1878a9ac	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0x18798304	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x18841143	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x18c1214a	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0x18d8ca3e	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x18ee12ca	pci_domain_nr
++EXPORT_SYMBOL vmlinux 0x18f2bc71	tcf_register_action
++EXPORT_SYMBOL vmlinux 0x19065ad4	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x190e017a	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x19489487	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0x1961ef76	udp_poll
++EXPORT_SYMBOL vmlinux 0x19638248	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x196c3cc6	seq_write
++EXPORT_SYMBOL vmlinux 0x198fb7eb	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0x199ec4fb	arch_spin_unlock_wait
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19a7f066	dev_open
++EXPORT_SYMBOL vmlinux 0x19ac61b9	cont_write_begin
++EXPORT_SYMBOL vmlinux 0x19b004fc	dquot_disable
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19b758f5	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x19ba1dc7	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19c03543	local_flush_tlb_page
++EXPORT_SYMBOL vmlinux 0x19c1082a	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0x19fd6848	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0x1a11cfa2	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0x1a2a9396	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0x1a30a57f	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0x1a382a8b	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0x1a4026b2	netdev_notice
++EXPORT_SYMBOL vmlinux 0x1a41412e	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x1a57f19a	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0x1a621667	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0x1a9fc1e4	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x1aa7e914	genphy_read_status
++EXPORT_SYMBOL vmlinux 0x1ac5d3cb	strcspn
++EXPORT_SYMBOL vmlinux 0x1af62a99	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b06feb0	udp_set_csum
++EXPORT_SYMBOL vmlinux 0x1b132009	rename_lock
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b2d3495	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x1b527c84	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b8b95ad	i8042_unlock_chip
++EXPORT_SYMBOL vmlinux 0x1ba23235	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x1bae1638	input_release_device
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bc4ff03	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0x1bca2b59	load_fp_state
++EXPORT_SYMBOL vmlinux 0x1be17b37	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0x1bf7906a	poll_freewait
++EXPORT_SYMBOL vmlinux 0x1bfd056d	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0x1bfec830	__iounmap_at
++EXPORT_SYMBOL vmlinux 0x1c1bd596	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0x1c270a19	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0x1c3e02e4	memcmp
++EXPORT_SYMBOL vmlinux 0x1c44ddf6	locks_init_lock
++EXPORT_SYMBOL vmlinux 0x1c62eba8	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0x1c6bca2f	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0x1c80de9c	ip_send_check
++EXPORT_SYMBOL vmlinux 0x1c969823	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x1cb20129	scmd_printk
++EXPORT_SYMBOL vmlinux 0x1cbba115	of_root
++EXPORT_SYMBOL vmlinux 0x1ce96a07	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x1d0efa8a	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x1d1056e5	crc32_be
++EXPORT_SYMBOL vmlinux 0x1d18163f	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x1d3c41d3	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0x1d49c0fd	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0x1d779bd6	__sock_create
++EXPORT_SYMBOL vmlinux 0x1d7b4f05	tty_devnum
++EXPORT_SYMBOL vmlinux 0x1d9c0959	get_disk
++EXPORT_SYMBOL vmlinux 0x1da6ef22	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x1db38268	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x1dbc4d0c	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1dd76000	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0x1de313ec	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0x1e0dadb6	dns_query
++EXPORT_SYMBOL vmlinux 0x1e10e14c	of_dev_put
++EXPORT_SYMBOL vmlinux 0x1e178be3	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e371fce	dev_warn
++EXPORT_SYMBOL vmlinux 0x1e3d8812	kobject_get
++EXPORT_SYMBOL vmlinux 0x1e49bcf9	iterate_fd
++EXPORT_SYMBOL vmlinux 0x1e65e109	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0x1e6b9ffd	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e75c950	sget
++EXPORT_SYMBOL vmlinux 0x1e866bf0	register_md_personality
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ea46d25	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x1ec71d47	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x1ec7deaa	dev_close
++EXPORT_SYMBOL vmlinux 0x1ed6016f	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0x1f10be06	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0x1f4907ee	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x1f4ee2ac	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x1f6b0ebc	phy_init_hw
++EXPORT_SYMBOL vmlinux 0x1f6ce67a	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x1f6dedf7	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0x1f9e6ad7	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x1fbb88e9	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fc42375	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x20036935	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0x20041fe4	update_devfreq
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x2037153e	page_put_link
++EXPORT_SYMBOL vmlinux 0x20393890	framebuffer_release
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x2053b3ae	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0x205410fa	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x206170aa	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x208377f6	simple_getattr
++EXPORT_SYMBOL vmlinux 0x20a5b2b2	dcb_setapp
++EXPORT_SYMBOL vmlinux 0x20a77cd1	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20af8e7a	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20dc9fe9	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20fee98c	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x210694cd	security_path_chmod
++EXPORT_SYMBOL vmlinux 0x210f3d4b	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0x211f0500	freeze_super
++EXPORT_SYMBOL vmlinux 0x211f68f1	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x21855bbd	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0x218e2336	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0x2195d5f1	tty_free_termios
++EXPORT_SYMBOL vmlinux 0x21ad7da9	compat_mc_setsockopt
++EXPORT_SYMBOL vmlinux 0x21ad86a9	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x21bebffd	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0x21bfedf0	__kernel_write
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21f19335	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0x21f3e274	seq_read
++EXPORT_SYMBOL vmlinux 0x220002e9	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0x220f352a	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0x221df26c	of_device_get_match_data
++EXPORT_SYMBOL vmlinux 0x222473f4	param_set_uint
++EXPORT_SYMBOL vmlinux 0x222dc069	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x223a4821	security_path_rename
++EXPORT_SYMBOL vmlinux 0x223b7fac	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0x224c0e16	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0x224fc486	poll_initwait
++EXPORT_SYMBOL vmlinux 0x22550c2f	address_space_init_once
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x2278e66c	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x2278e94b	slhc_remember
++EXPORT_SYMBOL vmlinux 0x2281abf9	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0x228de527	mmc_of_parse_voltage
++EXPORT_SYMBOL vmlinux 0x22afdd6b	of_find_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22d72255	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x22d725f1	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0x22e8cde5	nvdimm_bus_lock
++EXPORT_SYMBOL vmlinux 0x22f16b3e	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0x23143b1b	of_mdiobus_register
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x23212634	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL vmlinux 0x2339a04b	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0x234245e0	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x235580e3	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0x235e90f3	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x239c6999	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23bb4df3	of_graph_get_remote_port_parent
++EXPORT_SYMBOL vmlinux 0x23c3e51c	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0x23c9891c	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x23cdfbfe	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x23cfb565	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x23d95e59	param_set_ushort
++EXPORT_SYMBOL vmlinux 0x23f2243d	mempool_free
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x2407b396	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x24254a1d	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0x243c0e8d	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x245b827b	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x245e7670	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0x2462a3e4	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x2484adc3	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0x24b2edd9	page_waitqueue
++EXPORT_SYMBOL vmlinux 0x24bb73f3	sys_imageblit
++EXPORT_SYMBOL vmlinux 0x24d6b4a6	cur_cpu_spec
++EXPORT_SYMBOL vmlinux 0x24ddc531	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x24e232ff	inc_nlink
++EXPORT_SYMBOL vmlinux 0x24f00380	ida_init
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x2500c815	request_key_async
++EXPORT_SYMBOL vmlinux 0x2519c572	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x25247476	file_remove_privs
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x253374e1	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x25382dc9	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x253e5784	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x25924ba9	md_write_end
++EXPORT_SYMBOL vmlinux 0x25b2c32e	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0x25d13a6c	flush_tlb_page
++EXPORT_SYMBOL vmlinux 0x25e8ed29	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x25fa2b0d	key_invalidate
++EXPORT_SYMBOL vmlinux 0x25fabd1c	of_node_put
++EXPORT_SYMBOL vmlinux 0x260ece1c	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0x2627bf3f	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x26477c07	__vmalloc
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x2665d53a	key_create_or_update
++EXPORT_SYMBOL vmlinux 0x267023a9	dev_printk
++EXPORT_SYMBOL vmlinux 0x267591ca	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0x267adb27	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x26b760c4	slhc_init
++EXPORT_SYMBOL vmlinux 0x26be483e	free_task
++EXPORT_SYMBOL vmlinux 0x26c88631	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0x26cfb7cd	input_grab_device
++EXPORT_SYMBOL vmlinux 0x26cfe106	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x26e048ad	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x270795a0	bio_endio
++EXPORT_SYMBOL vmlinux 0x27435961	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x27646df3	start_thread
++EXPORT_SYMBOL vmlinux 0x276f5fd6	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x2771d7ff	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x277a5a94	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x279ab001	fget_raw
++EXPORT_SYMBOL vmlinux 0x27aff427	ether_setup
++EXPORT_SYMBOL vmlinux 0x27b73e05	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27c69ea8	param_set_int
++EXPORT_SYMBOL vmlinux 0x27d47661	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x27e224bb	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x28106174	check_disk_change
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x28318305	snprintf
++EXPORT_SYMBOL vmlinux 0x28348a43	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x284205f1	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x2847ca50	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0x28787d3a	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0x288edfad	account_page_redirty
++EXPORT_SYMBOL vmlinux 0x289a3b0b	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0x289db3ee	idr_remove
++EXPORT_SYMBOL vmlinux 0x28a2b29f	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28abfe6e	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x28bed658	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0x28c618d9	tty_mutex
++EXPORT_SYMBOL vmlinux 0x28e6ce45	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x28e73bc2	pci_find_bus
++EXPORT_SYMBOL vmlinux 0x28e8ad99	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x28f66664	release_firmware
++EXPORT_SYMBOL vmlinux 0x29015e04	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0x29127847	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x291549bf	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0x291a4e7d	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x29394393	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x296584cb	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x298de42e	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x29b2279e	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x29dc4713	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0x29f27d80	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0x2a0d3d3c	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0x2a15af68	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x2a2b1e7d	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0x2a2df1ec	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a383c61	filemap_flush
++EXPORT_SYMBOL vmlinux 0x2a418256	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x2a418a60	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0x2a4852e5	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0x2a646d7b	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x2a93688d	skb_store_bits
++EXPORT_SYMBOL vmlinux 0x2a9a5d80	kill_bdev
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2af11c85	netdev_warn
++EXPORT_SYMBOL vmlinux 0x2b00b528	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0x2b05250c	vga_con
++EXPORT_SYMBOL vmlinux 0x2b08a40f	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b20349a	netlink_capable
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b3b4432	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0x2b3ba157	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0x2b45d2b4	param_ops_string
++EXPORT_SYMBOL vmlinux 0x2b4991ec	xmon
++EXPORT_SYMBOL vmlinux 0x2b664b07	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0x2b6e024d	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0x2b797e56	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x2b92220d	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2ba8bb70	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x2bad16d8	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0x2bdd6e28	node_states
++EXPORT_SYMBOL vmlinux 0x2bddb698	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x2bdddf5a	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x2be0f12d	dql_completed
++EXPORT_SYMBOL vmlinux 0x2c0970dc	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0x2c0da8c5	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c3edd62	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0x2c5141f0	of_parse_phandle_with_args
++EXPORT_SYMBOL vmlinux 0x2c52f210	generic_readlink
++EXPORT_SYMBOL vmlinux 0x2c7589e5	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0x2c7b1fca	down_timeout
++EXPORT_SYMBOL vmlinux 0x2c8221d4	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0x2c9abb76	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0x2c9c86ba	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x2cb0db75	sk_net_capable
++EXPORT_SYMBOL vmlinux 0x2cc26bd4	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x2cc5c67e	of_phy_is_fixed_link
++EXPORT_SYMBOL vmlinux 0x2cd19893	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0x2cd82d37	vme_bus_num
++EXPORT_SYMBOL vmlinux 0x2ce1bd8b	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x2cf73cb7	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x2cfc6834	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d28061d	thaw_bdev
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d339572	vfs_llseek
++EXPORT_SYMBOL vmlinux 0x2d37342e	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0x2d3adb3c	read_code
++EXPORT_SYMBOL vmlinux 0x2d5bb589	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x2d8b8dc1	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0x2daee7ff	msi_bitmap_free_hwirqs
++EXPORT_SYMBOL vmlinux 0x2dfa8c29	ppp_input_error
++EXPORT_SYMBOL vmlinux 0x2e0acb35	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x2e0d2f7f	queue_work_on
++EXPORT_SYMBOL vmlinux 0x2e106ee6	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e2b40d2	strncat
++EXPORT_SYMBOL vmlinux 0x2e2ccc5a	param_set_bint
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e476d71	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0x2e593a27	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0x2e60fe0d	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0x2e781c4f	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x2e8e6591	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x2ea2d79d	skb_trim
++EXPORT_SYMBOL vmlinux 0x2ea672e7	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0x2eb91375	simple_readpage
++EXPORT_SYMBOL vmlinux 0x2ee4853e	md_check_recovery
++EXPORT_SYMBOL vmlinux 0x2ee7121e	ihold
++EXPORT_SYMBOL vmlinux 0x2eedca5c	put_tty_driver
++EXPORT_SYMBOL vmlinux 0x2ef243ad	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f258dd2	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x2f287f0d	copy_to_user
++EXPORT_SYMBOL vmlinux 0x2f2a357d	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x2f3331d9	i8042_install_filter
++EXPORT_SYMBOL vmlinux 0x2f3bc76e	sys_fillrect
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2f54b2a7	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x2f5f2a57	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0x2f75b180	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x2f930a3a	flush_tlb_range
++EXPORT_SYMBOL vmlinux 0x2f9fd0bb	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x2fb18efe	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fbae91f	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0x2fd96141	path_is_under
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x300a2c14	seq_dentry
++EXPORT_SYMBOL vmlinux 0x30226ddf	agp_device_command
++EXPORT_SYMBOL vmlinux 0x302e1ed3	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x30423fc0	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0x3067831c	mmc_release_host
++EXPORT_SYMBOL vmlinux 0x306bba2d	devm_free_irq
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x307d6747	simple_dname
++EXPORT_SYMBOL vmlinux 0x3083f680	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0x30966465	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x309932ae	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x30a221ed	fsl_ifc_ctrl_dev
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30b8b35c	cpu_to_chip_id
++EXPORT_SYMBOL vmlinux 0x30d2e093	of_device_is_compatible
++EXPORT_SYMBOL vmlinux 0x30d325e3	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0x3101bdf4	dentry_open
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x3106046c	unregister_nls
++EXPORT_SYMBOL vmlinux 0x310ac60b	bdget_disk
++EXPORT_SYMBOL vmlinux 0x310f02ec	memremap
++EXPORT_SYMBOL vmlinux 0x312a5c62	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0x312c6366	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0x313fe4ee	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0x3144d51c	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x315d57ec	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x317cbe44	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0x317d22fa	down_write
++EXPORT_SYMBOL vmlinux 0x317ff4e2	of_graph_get_next_endpoint
++EXPORT_SYMBOL vmlinux 0x3199f171	vmap
++EXPORT_SYMBOL vmlinux 0x31c656dd	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x31da4e90	bdget
++EXPORT_SYMBOL vmlinux 0x32007612	override_creds
++EXPORT_SYMBOL vmlinux 0x320293c2	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0x3215ecd2	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0x3222d725	nd_device_unregister
++EXPORT_SYMBOL vmlinux 0x323111af	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0x32351c19	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x324923c4	pci_get_device
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x3251f3cf	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0x3271ec80	inet6_getname
++EXPORT_SYMBOL vmlinux 0x3275b39d	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x3280c66d	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0x32831249	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0x329c9d07	udp_ioctl
++EXPORT_SYMBOL vmlinux 0x32c36b6a	sg_miter_next
++EXPORT_SYMBOL vmlinux 0x32db696f	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x32ddc69b	nd_sb_checksum
++EXPORT_SYMBOL vmlinux 0x32ef841b	flow_cache_init
++EXPORT_SYMBOL vmlinux 0x32f72d36	thaw_super
++EXPORT_SYMBOL vmlinux 0x3306a9f2	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0x33071ad2	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x3309ecf3	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0x330d9d6b	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0x3323b2bc	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0x333cb37c	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x33422250	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x3357b3a7	d_make_root
++EXPORT_SYMBOL vmlinux 0x337c99e8	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x33940af8	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x33a01d38	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0x33b84f74	copy_page
++EXPORT_SYMBOL vmlinux 0x33bb29ef	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0x33c14538	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33cbd279	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0x33d002c0	netdev_change_features
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x33f3de7f	phy_disconnect
++EXPORT_SYMBOL vmlinux 0x33fcf44a	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0x340784ac	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x34145eba	inet_ioctl
++EXPORT_SYMBOL vmlinux 0x34241716	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0x34247122	mdiobus_write
++EXPORT_SYMBOL vmlinux 0x34411786	find_get_entry
++EXPORT_SYMBOL vmlinux 0x3446fc21	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0x344adbd5	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x346b84be	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x34712ae8	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34b25214	dst_alloc
++EXPORT_SYMBOL vmlinux 0x34b342fe	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x34b5f551	tty_port_open
++EXPORT_SYMBOL vmlinux 0x34cb8c55	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0x34df37a5	block_write_full_page
++EXPORT_SYMBOL vmlinux 0x34e2c3e7	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x3539f11b	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x356d5bf2	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0x35873cc1	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x358b9246	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0x35a75dd5	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35c128e4	kfree_skb
++EXPORT_SYMBOL vmlinux 0x35c27f1f	of_mm_gpiochip_add
++EXPORT_SYMBOL vmlinux 0x35c32767	xor_altivec_2
++EXPORT_SYMBOL vmlinux 0x35c8c952	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x35c9bc69	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x35d9d726	dma_set_mask
++EXPORT_SYMBOL vmlinux 0x35de5266	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x35e2235c	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0x35f4569c	agp_unbind_memory
++EXPORT_SYMBOL vmlinux 0x360271a8	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x3618cb2d	ida_destroy
++EXPORT_SYMBOL vmlinux 0x361a6860	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0x362d3779	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x362e7a21	d_path
++EXPORT_SYMBOL vmlinux 0x363144c6	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0x36388c4a	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x3665b5cb	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0x366f6d27	idr_destroy
++EXPORT_SYMBOL vmlinux 0x366faa79	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x369e1115	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x369ecd36	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0x36ab9c54	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x36b0e732	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36d83a86	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0x36e2bcc8	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0x371d2130	check_legacy_ioport
++EXPORT_SYMBOL vmlinux 0x37344510	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x374bb144	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x3758dfd7	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0x3761365d	down_read_trylock
++EXPORT_SYMBOL vmlinux 0x37692126	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0x37746966	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0x3789f566	kthread_bind
++EXPORT_SYMBOL vmlinux 0x37ab6846	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37b8b39e	screen_info
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37e0153d	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x37e93c97	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x38469458	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x384bcf06	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x384d2026	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x3851e301	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x3868657b	mach_qemu_e500
++EXPORT_SYMBOL vmlinux 0x3874bcdd	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x388bccf8	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x388cab50	clk_add_alias
++EXPORT_SYMBOL vmlinux 0x388ffc42	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38b825d1	idr_replace
++EXPORT_SYMBOL vmlinux 0x38d4a7a2	generic_write_checks
++EXPORT_SYMBOL vmlinux 0x38d7b2db	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x38fb9933	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x391f9aa8	bio_chain
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x393d4de9	crc32_le
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x3955fcf6	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x395643c9	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0x39732482	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0x3995de9c	ps2_command
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x399ad043	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0x399ca11b	i2c_use_client
++EXPORT_SYMBOL vmlinux 0x39b27af3	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39c19330	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0x39c6145a	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x39c8f849	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x39cdf63c	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x39d02333	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x39d64838	pci_bus_get
++EXPORT_SYMBOL vmlinux 0x39d793c5	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x39dd4d44	inet_listen
++EXPORT_SYMBOL vmlinux 0x3a074536	fasync_helper
++EXPORT_SYMBOL vmlinux 0x3a1e1da5	dget_parent
++EXPORT_SYMBOL vmlinux 0x3a265365	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0x3a2a9d98	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x3a63bd98	of_find_node_by_name
++EXPORT_SYMBOL vmlinux 0x3a759053	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0x3a7b11e3	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x3a8453a0	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x3a89ee50	iget_locked
++EXPORT_SYMBOL vmlinux 0x3a99db92	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3aa4b75b	clear_nlink
++EXPORT_SYMBOL vmlinux 0x3ad218bd	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0x3af3b430	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0x3afea074	i2c_transfer
++EXPORT_SYMBOL vmlinux 0x3b092b4e	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x3b20be64	pci_pme_active
++EXPORT_SYMBOL vmlinux 0x3b3fd9f5	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0x3b40945b	cdev_init
++EXPORT_SYMBOL vmlinux 0x3b5e81c1	__frontswap_test
++EXPORT_SYMBOL vmlinux 0x3b615a21	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b6c6634	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0x3b6dc875	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0x3b6e2556	console_stop
++EXPORT_SYMBOL vmlinux 0x3b7aa2f4	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0x3b7cc908	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0x3b871ce5	update_region
++EXPORT_SYMBOL vmlinux 0x3bb02502	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0x3bc47702	netif_device_detach
++EXPORT_SYMBOL vmlinux 0x3bf0da7e	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0x3c1a9940	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x3c254541	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x3c2d1831	skb_find_text
++EXPORT_SYMBOL vmlinux 0x3c338459	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c481e0a	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x3c483012	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x3c49a944	bioset_free
++EXPORT_SYMBOL vmlinux 0x3c4c90d1	may_umount
++EXPORT_SYMBOL vmlinux 0x3c4ef4c8	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c8d8375	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0x3c92c4e6	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0x3ca88c79	proto_unregister
++EXPORT_SYMBOL vmlinux 0x3cb44551	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0x3cc4b0dc	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x3cca958d	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0x3cded3c3	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3cebbe7c	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0x3ced3cf1	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0x3cf81b1a	of_match_node
++EXPORT_SYMBOL vmlinux 0x3d16b053	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0x3d6c5df2	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0x3d7efd2c	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x3d88d3d6	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0x3da474e4	add_disk
++EXPORT_SYMBOL vmlinux 0x3db42b4a	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0x3db7503f	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x3dbf36c9	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0x3dc02a4e	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e25f9a6	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x3e3c2fe9	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0x3e3db0c0	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0x3e7c6e60	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0x3e882943	pcibios_align_resource
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x3e9cbb1a	of_platform_bus_probe
++EXPORT_SYMBOL vmlinux 0x3ebc4ff7	dquot_initialize
++EXPORT_SYMBOL vmlinux 0x3ebed355	simple_link
++EXPORT_SYMBOL vmlinux 0x3ed7df46	elevator_exit
++EXPORT_SYMBOL vmlinux 0x3eda8fc0	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x3ee1a77e	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0x3ef38d98	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x3ef4a04b	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0x3f0546a8	ioread32_rep
++EXPORT_SYMBOL vmlinux 0x3f406a3b	enable_kernel_altivec
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f600653	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0x3f701c48	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x3f8b0ba5	flush_old_exec
++EXPORT_SYMBOL vmlinux 0x3fb48a4d	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0x3fc06884	init_buffer
++EXPORT_SYMBOL vmlinux 0x3fdf6647	dev_load
++EXPORT_SYMBOL vmlinux 0x3fe0d1c0	slhc_free
++EXPORT_SYMBOL vmlinux 0x3fe2ccbe	memweight
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x3ff277bb	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0x3ff67bfb	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0x3ff8e495	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0x400edbf7	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4039918a	clk_register_clkdev
++EXPORT_SYMBOL vmlinux 0x404df45e	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0x405962b8	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x406671c9	agp_generic_free_by_type
++EXPORT_SYMBOL vmlinux 0x407456af	tty_check_change
++EXPORT_SYMBOL vmlinux 0x407813ba	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0x407faa9c	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x40858e97	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x4097c1d5	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40b40a2c	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x40bb6c3b	icmp_send
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d218e7	serio_bus
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40d8b9a8	serio_close
++EXPORT_SYMBOL vmlinux 0x40e6df69	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x41193058	vc_resize
++EXPORT_SYMBOL vmlinux 0x4144374c	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x4159c38f	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x416d60e7	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x418ba53c	simple_empty
++EXPORT_SYMBOL vmlinux 0x418f3618	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x41a3fbf1	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x41baf194	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0x41bfb513	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0x41c0e4e1	fget
++EXPORT_SYMBOL vmlinux 0x41e2ba17	vme_slave_request
++EXPORT_SYMBOL vmlinux 0x41e3b4e1	md_error
++EXPORT_SYMBOL vmlinux 0x41f61d13	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0x41fd8d04	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x420a8e3c	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0x420efac2	would_dump
++EXPORT_SYMBOL vmlinux 0x42157e12	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x42401521	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x424ceaa9	dev_mc_add
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x424e55e7	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x42595e58	vgacon_text_force
++EXPORT_SYMBOL vmlinux 0x426a8378	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x427868eb	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0x428c9b36	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42a2b762	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0x42cd8607	i2c_master_send
++EXPORT_SYMBOL vmlinux 0x42e62115	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0x42f533b5	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0x42fd7dd3	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x43023475	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x4303bdf3	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x430668f3	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x430d4bd5	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x43563a43	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0x4359af43	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0x436c2179	iowrite32
++EXPORT_SYMBOL vmlinux 0x436eff37	of_find_node_by_phandle
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x43a01f90	complete_all
++EXPORT_SYMBOL vmlinux 0x43a0cb29	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0x43a78649	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0x43a9648a	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0x43c093c5	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x43e2cb8b	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x43f218fd	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x43f31e74	flush_dcache_page
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x441a93d8	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0x4422e7be	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x4435c51d	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x443bff0c	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0x4453d366	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0x4488c166	compat_tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x448a0f1e	dquot_operations
++EXPORT_SYMBOL vmlinux 0x448eac3e	kmemdup
++EXPORT_SYMBOL vmlinux 0x44a6d352	kobject_put
++EXPORT_SYMBOL vmlinux 0x44a98986	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44c663f7	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x44e945a6	console_start
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44eb192e	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x44f71c44	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0x44f7595a	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0x451dc2ce	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0x4529bab8	dump_page
++EXPORT_SYMBOL vmlinux 0x4530705a	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x453ebae7	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0x454501d9	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0x45494b93	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x454973d2	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x455df9a2	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x4566700d	start_tty
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x45870e49	seq_puts
++EXPORT_SYMBOL vmlinux 0x4595fe3a	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0x45a55ec8	__iounmap
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45af0aa8	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x45b3e155	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x45de9bec	up_write
++EXPORT_SYMBOL vmlinux 0x45f7e50e	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0x46111ec4	giveup_altivec
++EXPORT_SYMBOL vmlinux 0x4612c59d	down_trylock
++EXPORT_SYMBOL vmlinux 0x4619a0f9	devm_memunmap
++EXPORT_SYMBOL vmlinux 0x461ac773	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x461ebfa0	__copy_tofrom_user
++EXPORT_SYMBOL vmlinux 0x461f1737	bio_split
++EXPORT_SYMBOL vmlinux 0x4624bc00	local_flush_tlb_mm
++EXPORT_SYMBOL vmlinux 0x4631b9e2	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0x46547119	param_ops_long
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x467df16d	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0x46814986	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0x468668f1	security_path_truncate
++EXPORT_SYMBOL vmlinux 0x46983a2c	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0x469d1f23	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0x46a53481	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x46bfc6bf	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0x46d12956	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x46da35dc	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0x46f82b44	pmem_should_map_pages
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x472c2f69	rwsem_wake
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x47487da5	clk_get
++EXPORT_SYMBOL vmlinux 0x47608718	fence_init
++EXPORT_SYMBOL vmlinux 0x47633b8f	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0x4774d841	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0x478ab77e	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x4793e33a	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x47cf9b99	bdi_destroy
++EXPORT_SYMBOL vmlinux 0x47dc8907	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x47e6a12e	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x48065e7f	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x481af38f	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x4829a47e	memcpy
++EXPORT_SYMBOL vmlinux 0x482abc56	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0x482bc3d4	tty_register_device
++EXPORT_SYMBOL vmlinux 0x4832102f	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x4836780a	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0x48404b9a	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x4841279b	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x4841bdee	strnchr
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x4866e098	follow_down_one
++EXPORT_SYMBOL vmlinux 0x48885910	agp_generic_destroy_page
++EXPORT_SYMBOL vmlinux 0x488e1630	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x48a771c5	cpu_core_map
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48d6a018	genphy_resume
++EXPORT_SYMBOL vmlinux 0x48fd03e3	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x49476853	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x49622253	file_ns_capable
++EXPORT_SYMBOL vmlinux 0x4986a02b	__lock_page
++EXPORT_SYMBOL vmlinux 0x49a97d85	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x49aec026	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b6175a	nvdimm_revalidate_disk
++EXPORT_SYMBOL vmlinux 0x49b6d876	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x49cba366	mdiobus_free
++EXPORT_SYMBOL vmlinux 0x49cea0bf	bdgrab
++EXPORT_SYMBOL vmlinux 0x49dff7f9	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x4a091c6b	register_netdevice
++EXPORT_SYMBOL vmlinux 0x4a0997c1	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0x4a351ae7	param_set_ullong
++EXPORT_SYMBOL vmlinux 0x4a3626fd	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x4a499bab	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x4a7c38e7	end_page_writeback
++EXPORT_SYMBOL vmlinux 0x4a84ecd5	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0x4a8961f5	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4ae33e06	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x4ae526cc	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x4ae5840c	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x4af69122	get_user_pages
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b085dbf	agp3_generic_configure
++EXPORT_SYMBOL vmlinux 0x4b2261c7	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x4b233aa8	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x4b3b1cf6	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x4b4f8f5a	file_update_time
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b693535	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0x4b6ab23c	ip6_xmit
++EXPORT_SYMBOL vmlinux 0x4b729222	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0x4b8326ff	ida_remove
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4bd10435	pci_iomap
++EXPORT_SYMBOL vmlinux 0x4bd38499	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x4bf102f9	param_array_ops
++EXPORT_SYMBOL vmlinux 0x4c11435a	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0x4c2c2479	from_kprojid
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c5a7a7f	sk_capable
++EXPORT_SYMBOL vmlinux 0x4c63d967	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0x4c7429d9	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x4c786752	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x4ca9669f	scnprintf
++EXPORT_SYMBOL vmlinux 0x4caa98c4	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0x4cbadc10	__register_nls
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4ce0fe33	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x4ce14b39	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x4ce868ea	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0x4ceaf095	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0x4cecfada	__bread_gfp
++EXPORT_SYMBOL vmlinux 0x4cfb0cf0	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0x4d0429c6	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0x4d131297	agp_put_bridge
++EXPORT_SYMBOL vmlinux 0x4d21e06d	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0x4d2f30a5	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0x4d322183	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x4d40bf38	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x4d41fa61	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0x4d5a0599	mntget
++EXPORT_SYMBOL vmlinux 0x4d646463	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0x4d70601e	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0x4d791953	mempool_resize
++EXPORT_SYMBOL vmlinux 0x4d8309f2	find_lock_entry
++EXPORT_SYMBOL vmlinux 0x4d8bba34	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x4d91287f	nf_reinject
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4da26271	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0x4da69280	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x4da93a12	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0x4db6148e	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0x4ddac184	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0x4ddfd1fb	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4de6501a	devm_memremap
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4dfa8314	of_device_alloc
++EXPORT_SYMBOL vmlinux 0x4e0b3018	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x4e1a5440	register_gifconf
++EXPORT_SYMBOL vmlinux 0x4e20d3bc	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0x4e2edcd8	sync_blockdev
++EXPORT_SYMBOL vmlinux 0x4e33cba3	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e3e729f	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0x4e479db1	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0x4e4a63ee	component_match_add
++EXPORT_SYMBOL vmlinux 0x4e572388	get_super_thawed
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e9243c6	dev_crit
++EXPORT_SYMBOL vmlinux 0x4e9dffb5	ip_fast_csum
++EXPORT_SYMBOL vmlinux 0x4ec3db3e	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x4f1ba679	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0x4f1c89ed	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f38ab18	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f605d25	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f6bf835	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x4f7c351c	bd_set_size
++EXPORT_SYMBOL vmlinux 0x4f7f60a6	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x4fa1e3c2	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0x4fdee897	i8042_command
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x500b6e1b	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0x5032b3bb	__nd_iostat_start
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x5083856b	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0x5086b0bc	try_module_get
++EXPORT_SYMBOL vmlinux 0x50a90e8d	bsearch
++EXPORT_SYMBOL vmlinux 0x50ba769a	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x50bc9b43	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x50c5f66b	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x50d267db	do_splice_to
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x50f7cf0a	d_walk
++EXPORT_SYMBOL vmlinux 0x510548fd	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0x51164ad9	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x5123ce81	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0x513c8e0f	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x513feeb6	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0x5144e342	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x5170dce3	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0x518acb8c	of_parse_phandle_with_fixed_args
++EXPORT_SYMBOL vmlinux 0x5195c34c	seq_vprintf
++EXPORT_SYMBOL vmlinux 0x519b0da3	finish_wait
++EXPORT_SYMBOL vmlinux 0x519d51ad	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0x51b4a840	ip_defrag
++EXPORT_SYMBOL vmlinux 0x51f7922d	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x520f3bb5	register_console
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x5237b0bd	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x5257cee1	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0x526ef2c8	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x528273a1	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0x5287c3ca	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x52983a4f	vme_master_write
++EXPORT_SYMBOL vmlinux 0x52acf255	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0x52b962c8	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0x52bd684a	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x52c0c46f	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x52c32187	__napi_complete
++EXPORT_SYMBOL vmlinux 0x52d23db7	flush_dcache_icache_page
++EXPORT_SYMBOL vmlinux 0x52d352fc	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x52db2b5e	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0x52e06ffa	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x52f1d465	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x52f25e9b	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x5332b03f	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x5364575f	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x536cc847	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x53713edf	udp_add_offload
++EXPORT_SYMBOL vmlinux 0x5377e556	hex2bin
++EXPORT_SYMBOL vmlinux 0x53973d02	tcp_filter
++EXPORT_SYMBOL vmlinux 0x539af73c	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x53d704be	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0x53d84772	make_kprojid
++EXPORT_SYMBOL vmlinux 0x53ebab1b	_outsl_ns
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x5412c7c7	up
++EXPORT_SYMBOL vmlinux 0x541bbf33	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0x54245b39	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0x5427de94	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x544683d7	pci_disable_device
++EXPORT_SYMBOL vmlinux 0x545256fb	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x545d864c	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0x545e36cd	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x5461c7f2	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x54772792	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x548ac440	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0x549445e4	alloc_file
++EXPORT_SYMBOL vmlinux 0x54a46e85	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54af4fec	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54c48082	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x54cc07fb	agp_allocate_memory
++EXPORT_SYMBOL vmlinux 0x54d294b5	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x552e97ce	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x5538e9c6	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x5542d054	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0x55656c47	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x5568c553	complete
++EXPORT_SYMBOL vmlinux 0x556e0a7c	to_nd_btt
++EXPORT_SYMBOL vmlinux 0x5577ef9e	udp_table
++EXPORT_SYMBOL vmlinux 0x557b06d5	km_query
++EXPORT_SYMBOL vmlinux 0x558fd736	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x55a55219	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x55b0198b	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0x55b45335	input_set_keycode
++EXPORT_SYMBOL vmlinux 0x55c2035e	__dst_free
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x560151a2	inode_init_owner
++EXPORT_SYMBOL vmlinux 0x5612e666	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0x561658ce	km_state_notify
++EXPORT_SYMBOL vmlinux 0x562259f6	sock_i_ino
++EXPORT_SYMBOL vmlinux 0x5622db10	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x5671d672	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0x568a0a93	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x56c2d0b6	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0x56c32310	phy_device_create
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56ebfb67	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0x56f6c7de	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0x570b5d8b	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x573a95f7	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0x573c4a5e	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0x573de83a	__inet_hash
++EXPORT_SYMBOL vmlinux 0x57419025	kobject_init
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x575af70c	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x577d35f3	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x5792f848	strlcpy
++EXPORT_SYMBOL vmlinux 0x579fbcd2	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0x57ae095f	decrementer_clockevent
++EXPORT_SYMBOL vmlinux 0x57bab86d	agp_copy_info
++EXPORT_SYMBOL vmlinux 0x57bd4586	sock_i_uid
++EXPORT_SYMBOL vmlinux 0x57bf780f	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0x57dff7ff	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x57fb12a3	generic_read_dir
++EXPORT_SYMBOL vmlinux 0x58036755	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x5833c1e3	dev_notice
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x58426992	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0x5857b225	ioread16_rep
++EXPORT_SYMBOL vmlinux 0x5858e346	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0x58690e22	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x587a53b6	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x58833ad0	dev_alert
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58ccfe2b	compat_ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x58e64edd	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0x58e76f21	fsl_lbc_ctrl_dev
++EXPORT_SYMBOL vmlinux 0x5900d6c8	tty_lock
++EXPORT_SYMBOL vmlinux 0x59296db1	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0x592e9a35	dev_emerg
++EXPORT_SYMBOL vmlinux 0x5931eb2c	simple_setattr
++EXPORT_SYMBOL vmlinux 0x5932b12d	clkdev_drop
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x595d0946	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x5984ef0a	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0x598b504a	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x5999ec6b	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59b3378a	completion_done
++EXPORT_SYMBOL vmlinux 0x59b8aef6	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0x59d1aad3	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x59e713ef	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x59e81201	ps2_drain
++EXPORT_SYMBOL vmlinux 0x59fcadf5	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0x5a025f7b	arch_local_irq_restore
++EXPORT_SYMBOL vmlinux 0x5a0aaa12	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a0dcece	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0x5a1b57a8	generic_show_options
++EXPORT_SYMBOL vmlinux 0x5a2cda3e	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0x5a2e1f5c	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0x5a591003	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x5a609a17	compat_sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x5a6613d9	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0x5a7b46cf	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x5a80f310	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0x5a921311	strncmp
++EXPORT_SYMBOL vmlinux 0x5a9f1d63	memmove
++EXPORT_SYMBOL vmlinux 0x5ab15bdc	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x5ab90e8e	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x5adf659a	tty_throttle
++EXPORT_SYMBOL vmlinux 0x5af4b03a	__breadahead
++EXPORT_SYMBOL vmlinux 0x5af5b237	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5b043674	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0x5b2eb6fd	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0x5b2f49dc	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x5b30bd50	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0x5b3dcc6b	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0x5b56860c	vm_munmap
++EXPORT_SYMBOL vmlinux 0x5b5806b7	vme_dma_request
++EXPORT_SYMBOL vmlinux 0x5b6ef7e3	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0x5b79c8b5	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x5b9828c5	dma_spin_lock
++EXPORT_SYMBOL vmlinux 0x5ba35b60	follow_pfn
++EXPORT_SYMBOL vmlinux 0x5ba6c90c	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0x5bc10524	printk_emit
++EXPORT_SYMBOL vmlinux 0x5bd1f21f	of_get_ibm_chip_id
++EXPORT_SYMBOL vmlinux 0x5c109c32	mount_nodev
++EXPORT_SYMBOL vmlinux 0x5c1716af	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0x5c2ca444	param_ops_int
++EXPORT_SYMBOL vmlinux 0x5c37f319	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x5c38a5fe	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x5c430a29	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0x5c5848bf	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x5c65eb7d	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0x5c76c514	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0x5cb42fcf	netif_skb_features
++EXPORT_SYMBOL vmlinux 0x5cc32bdc	bitmap_copy_le
++EXPORT_SYMBOL vmlinux 0x5ccfcd55	copy_to_iter
++EXPORT_SYMBOL vmlinux 0x5cd2659a	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0x5cdd4c7b	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x5cf30e10	__debugger_ipi
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5d1cce6d	path_nosuid
++EXPORT_SYMBOL vmlinux 0x5d29b207	irq_to_desc
++EXPORT_SYMBOL vmlinux 0x5d518c60	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d58efa0	convert_ifc_address
++EXPORT_SYMBOL vmlinux 0x5d93eea1	nd_region_to_nstype
++EXPORT_SYMBOL vmlinux 0x5da107e8	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x5dab1147	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0x5ddf3477	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x5de795fd	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x5e15425b	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0x5e203e2e	nvdimm_bus_unlock
++EXPORT_SYMBOL vmlinux 0x5e3a8a9c	__wake_up
++EXPORT_SYMBOL vmlinux 0x5e4018da	dev_set_group
++EXPORT_SYMBOL vmlinux 0x5e66e4c9	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0x5e7b777f	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0x5e7e0842	fb_class
++EXPORT_SYMBOL vmlinux 0x5e8f3bc2	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ec61be1	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5eddb914	lockref_put_return
++EXPORT_SYMBOL vmlinux 0x5ee2056b	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x5ef23a32	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f052b51	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f21e1ba	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0x5f2bb946	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0x5f497435	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x5f6e40a7	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x5f8a2728	isa_io_base
++EXPORT_SYMBOL vmlinux 0x5f9f2a7a	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x5fd94a53	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x5fec20a0	dump_emit
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x6014b313	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x603a3253	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0x60603109	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0x60682f0f	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x6077c8cc	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x607e3b7a	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0x60912167	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60a2330b	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0x60a782f9	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x60ddb938	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x61081370	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x612a6f10	skb_split
++EXPORT_SYMBOL vmlinux 0x612eb533	input_close_device
++EXPORT_SYMBOL vmlinux 0x614bb773	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x6181bcd1	dump_truncate
++EXPORT_SYMBOL vmlinux 0x619b6fa5	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0x619cb7dd	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x61a87594	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x61a915b2	kernel_listen
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61bf73ca	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0x61d8b28d	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0x61dcf24a	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x61eef2c9	_insb
++EXPORT_SYMBOL vmlinux 0x61ef6170	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x6216a6be	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x62363afa	agp_bridge
++EXPORT_SYMBOL vmlinux 0x62398891	mount_ns
++EXPORT_SYMBOL vmlinux 0x6242f4f0	dquot_enable
++EXPORT_SYMBOL vmlinux 0x624633bf	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x624ca287	kset_register
++EXPORT_SYMBOL vmlinux 0x62538167	slhc_toss
++EXPORT_SYMBOL vmlinux 0x626c7a36	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x6299cf8c	request_key
++EXPORT_SYMBOL vmlinux 0x62e6802f	nonseekable_open
++EXPORT_SYMBOL vmlinux 0x62e9540f	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x630546d6	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0x6308c3b2	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0x630be268	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x6315a042	skb_pull
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x6318d6b3	notify_change
++EXPORT_SYMBOL vmlinux 0x6321f020	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x6328a9a1	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x63396aec	__debugger_break_match
++EXPORT_SYMBOL vmlinux 0x63510f94	keyring_search
++EXPORT_SYMBOL vmlinux 0x635d37fc	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0x637227e5	of_get_next_available_child
++EXPORT_SYMBOL vmlinux 0x6394073d	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63b5ac28	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63d3b643	key_link
++EXPORT_SYMBOL vmlinux 0x63d61ed7	from_kuid
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63f69a7c	pci_request_region
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x63fe4f8f	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x6404c4c7	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x643f0723	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0x645abde7	irq_set_chip
++EXPORT_SYMBOL vmlinux 0x6483622e	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x6486df1e	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0x648c5a7e	of_get_next_child
++EXPORT_SYMBOL vmlinux 0x648fe03f	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x649c43db	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x64a4b84d	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x64bbc288	string_unescape
++EXPORT_SYMBOL vmlinux 0x64bc33af	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x64d975c1	ping_prot
++EXPORT_SYMBOL vmlinux 0x6501f184	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0x6501fa50	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0x65041640	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x652ce9aa	nla_memcmp
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x65432cb4	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0x656c1a0e	string_escape_mem
++EXPORT_SYMBOL vmlinux 0x658658b3	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x65a87d68	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0x65b3cb26	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0x65bb58a2	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65e0d6d7	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x65ec8246	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x65fdf0cf	unlock_rename
++EXPORT_SYMBOL vmlinux 0x66149f25	pci_clear_master
++EXPORT_SYMBOL vmlinux 0x66176ab1	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0x665dc413	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x666195e2	iterate_dir
++EXPORT_SYMBOL vmlinux 0x666c1c02	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x66754be3	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x66a06d25	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0x66b38c1a	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0x66c41e12	mmc_free_host
++EXPORT_SYMBOL vmlinux 0x66cce55e	elv_rb_find
++EXPORT_SYMBOL vmlinux 0x66db40ea	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0x66e33325	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0x66f7ecc5	save_mount_options
++EXPORT_SYMBOL vmlinux 0x67074c43	compat_tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x6709d0ea	phy_suspend
++EXPORT_SYMBOL vmlinux 0x671426c7	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x671962f6	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0x671af999	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0x6736f04f	get_fs_type
++EXPORT_SYMBOL vmlinux 0x673f815e	agp_bridges
++EXPORT_SYMBOL vmlinux 0x6742eeb7	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0x6755069b	fb_find_mode
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x6788ae93	deactivate_super
++EXPORT_SYMBOL vmlinux 0x678df9de	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x67918354	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0x67985259	unregister_key_type
++EXPORT_SYMBOL vmlinux 0x679e154d	of_graph_parse_endpoint
++EXPORT_SYMBOL vmlinux 0x67a3fb92	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x67ade263	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x67b685ff	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67b926b5	serio_reconnect
++EXPORT_SYMBOL vmlinux 0x67bebb0e	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x67da9c41	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x68242415	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x6825584e	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0x684f331b	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0x6857b48b	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x68609857	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x687bd0fc	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68aa07df	md_update_sb
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68e1f9e8	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x69174af0	page_symlink
++EXPORT_SYMBOL vmlinux 0x6963d39d	mapping_tagged
++EXPORT_SYMBOL vmlinux 0x696d3e18	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x6973f033	serio_interrupt
++EXPORT_SYMBOL vmlinux 0x6996bf2d	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x69971230	ip_options_compile
++EXPORT_SYMBOL vmlinux 0x69a0ca7d	iowrite16be
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69ad1381	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69adbf10	agp_generic_alloc_pages
++EXPORT_SYMBOL vmlinux 0x69bb9b3e	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x69c8f7bd	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0x69e3315f	__register_chrdev
++EXPORT_SYMBOL vmlinux 0x69edfefa	phy_device_remove
++EXPORT_SYMBOL vmlinux 0x69ee9e8f	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a0c1846	d_genocide
++EXPORT_SYMBOL vmlinux 0x6a10ac7b	agp_generic_free_gatt_table
++EXPORT_SYMBOL vmlinux 0x6a1227d3	flush_signals
++EXPORT_SYMBOL vmlinux 0x6a1e416b	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0x6a3e19ac	page_readlink
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a5fa363	sigprocmask
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6aaeeefa	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6acb973d	iowrite32be
++EXPORT_SYMBOL vmlinux 0x6ae66d4e	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b54b763	tcp_prot
++EXPORT_SYMBOL vmlinux 0x6b5aff50	generic_perform_write
++EXPORT_SYMBOL vmlinux 0x6b5dfe73	__debugger_bpt
++EXPORT_SYMBOL vmlinux 0x6b640864	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6b66c889	fence_free
++EXPORT_SYMBOL vmlinux 0x6b837263	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0x6b932b13	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0x6b9dc211	init_special_inode
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bd37c47	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c25ba18	lease_modify
++EXPORT_SYMBOL vmlinux 0x6c3048d3	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0x6c340753	alloc_disk
++EXPORT_SYMBOL vmlinux 0x6c4af84a	sk_free
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c551368	km_report
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6cb37127	flex_array_clear
++EXPORT_SYMBOL vmlinux 0x6cb7c787	nd_dev_to_uuid
++EXPORT_SYMBOL vmlinux 0x6cbd74e0	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x6ccce710	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0x6cea6cfe	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d105cbf	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x6d18f862	mmc_start_req
++EXPORT_SYMBOL vmlinux 0x6d1ac178	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x6d1eb01f	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d340849	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0x6d35ca41	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0x6d65b5a3	inet_getname
++EXPORT_SYMBOL vmlinux 0x6d72eb2c	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0x6d740223	flex_array_put
++EXPORT_SYMBOL vmlinux 0x6da928f4	_insw_ns
++EXPORT_SYMBOL vmlinux 0x6dc327a3	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0x6dcd8958	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0x6de873ba	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6dfdf25f	misc_register
++EXPORT_SYMBOL vmlinux 0x6dffe7d9	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0x6e183561	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0x6e54ef04	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e7f0fd2	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6eda2584	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x6ee963fb	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0x6f16a79d	skb_pad
++EXPORT_SYMBOL vmlinux 0x6f1cf3a2	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f209aa4	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x6f4335dd	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x6f477498	of_get_named_gpio_flags
++EXPORT_SYMBOL vmlinux 0x6f4a6c8c	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0x6f791f54	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6f8a48e4	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0x6f9c94ab	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fca1f1f	dump_align
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x703d318d	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0x7052284d	genphy_suspend
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7054a3e4	request_dma
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x7088c035	registered_fb
++EXPORT_SYMBOL vmlinux 0x709e8627	filp_close
++EXPORT_SYMBOL vmlinux 0x70b44abe	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x70b8067e	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x7120d8ef	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x7140c26f	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x714239f3	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x715349b0	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71d8632d	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0x71dcc0ab	nvm_register
++EXPORT_SYMBOL vmlinux 0x71ee73de	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0x71f5f5ac	of_get_parent
++EXPORT_SYMBOL vmlinux 0x72011652	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0x7215e14d	noop_fsync
++EXPORT_SYMBOL vmlinux 0x7232e454	elevator_init
++EXPORT_SYMBOL vmlinux 0x7269fcbd	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x7277a3ae	set_page_dirty
++EXPORT_SYMBOL vmlinux 0x7280fd0a	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0x72851760	bioset_create
++EXPORT_SYMBOL vmlinux 0x728fd2c1	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x729c93fd	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0x72ab580e	set_nlink
++EXPORT_SYMBOL vmlinux 0x72b243d4	free_dma
++EXPORT_SYMBOL vmlinux 0x72b2d03b	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0x72b42ef3	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x72b6fa56	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0x72c98139	__arch_hweight64
++EXPORT_SYMBOL vmlinux 0x72d4c23c	fsl_get_sys_freq
++EXPORT_SYMBOL vmlinux 0x72e441ca	agp_generic_remove_memory
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x731a747a	pci_io_base
++EXPORT_SYMBOL vmlinux 0x731f3723	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0x733b2383	next_tlbcam_idx
++EXPORT_SYMBOL vmlinux 0x733b50de	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x735be4f0	pci_map_rom
++EXPORT_SYMBOL vmlinux 0x735d8503	add_wait_queue
++EXPORT_SYMBOL vmlinux 0x736905b0	msi_bitmap_alloc_hwirqs
++EXPORT_SYMBOL vmlinux 0x73902baf	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0x73b9b583	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x740feaa5	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x74181c98	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x7454f48b	inet_select_addr
++EXPORT_SYMBOL vmlinux 0x74614919	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x74934697	phy_device_register
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74e91c48	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0x751562bd	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0x7532588a	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0x753674ea	get_cached_acl
++EXPORT_SYMBOL vmlinux 0x7538b132	agp_off
++EXPORT_SYMBOL vmlinux 0x7553c368	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x7558f540	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0x75637c04	d_add_ci
++EXPORT_SYMBOL vmlinux 0x758ada7f	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0x75994700	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0x75b26e2d	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75be6702	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0x75c7d77b	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x75cba03b	prepare_creds
++EXPORT_SYMBOL vmlinux 0x75ea3c0e	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0x760793a5	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x762f79b4	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0x7645af6f	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x7659c22f	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0x765ff474	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x7669fba0	__sb_end_write
++EXPORT_SYMBOL vmlinux 0x766c71ee	sock_rfree
++EXPORT_SYMBOL vmlinux 0x769a55c7	tso_start
++EXPORT_SYMBOL vmlinux 0x769e06d7	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x76ad8329	get_task_io_context
++EXPORT_SYMBOL vmlinux 0x76b79ae3	skb_copy
++EXPORT_SYMBOL vmlinux 0x76b7d7ab	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x76cbe29e	read_cache_page
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76d53c8e	setattr_copy
++EXPORT_SYMBOL vmlinux 0x76ebb1da	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x76ef1f78	d_alloc
++EXPORT_SYMBOL vmlinux 0x76f0c178	vm_mmap
++EXPORT_SYMBOL vmlinux 0x76f6aab0	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0x76ff325e	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0x771be7ab	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x772608b3	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0x7730e881	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0x77359ff5	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0x773fa409	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x77517618	follow_up
++EXPORT_SYMBOL vmlinux 0x7760904d	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0x77788659	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x7789bf99	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x7798a247	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x779c54b8	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x779ccab7	phy_print_status
++EXPORT_SYMBOL vmlinux 0x779f9bf1	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0x77b77c90	mpage_readpages
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77bd5a0f	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0x77eab5aa	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x77f0be36	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0x77f62c5c	kthread_stop
++EXPORT_SYMBOL vmlinux 0x782c5012	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x783b5dd6	put_cmsg
++EXPORT_SYMBOL vmlinux 0x7846af3e	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x784cea1c	put_disk
++EXPORT_SYMBOL vmlinux 0x785d451d	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0x786e82f9	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0x787a08a2	simple_follow_link
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x7889674b	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x789473ad	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78b01661	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0x78b49052	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0x78dd79cb	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78ec6326	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0x78ffc139	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0x7901b69b	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0x7905ccc2	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0x79083ef7	blkdev_put
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x7984eefc	key_update
++EXPORT_SYMBOL vmlinux 0x7985d043	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x7992841f	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x79951a67	block_write_end
++EXPORT_SYMBOL vmlinux 0x79a33f85	vme_get_size
++EXPORT_SYMBOL vmlinux 0x79a4e9c0	vfs_readf
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79adabc5	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0x79b07bb5	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0x79e1f897	read_cache_pages
++EXPORT_SYMBOL vmlinux 0x7a120773	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0x7a226619	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0x7a2c9053	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x7a35048f	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0x7a399250	tcp_close
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a69265c	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x7a6cdedc	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7ada6590	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0x7addd733	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x7b1046db	devm_release_resource
++EXPORT_SYMBOL vmlinux 0x7b14be6d	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0x7b16235f	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b174046	key_type_keyring
++EXPORT_SYMBOL vmlinux 0x7b2aef6c	__krealloc
++EXPORT_SYMBOL vmlinux 0x7b3d8aab	down_write_trylock
++EXPORT_SYMBOL vmlinux 0x7b40760f	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0x7b658fcc	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0x7b677e70	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x7b6e1380	phy_find_first
++EXPORT_SYMBOL vmlinux 0x7b6ea88c	tso_build_data
++EXPORT_SYMBOL vmlinux 0x7b74d056	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0x7b7518cd	skb_clone
++EXPORT_SYMBOL vmlinux 0x7b78ec65	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x7bae4679	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0x7bb01589	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0x7bb756cc	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x7bea34d3	filp_open
++EXPORT_SYMBOL vmlinux 0x7c003aef	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c163ef7	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c1a6336	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x7c1ccd01	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0x7c270746	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0x7c2d098f	krealloc
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c6d7fed	register_sysctl
++EXPORT_SYMBOL vmlinux 0x7c901d6b	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0x7c90360a	put_filp
++EXPORT_SYMBOL vmlinux 0x7c9291d1	csum_partial_copy_generic
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7c9ac32e	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0x7ca86a54	sock_create
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d1b3dbf	pci_bus_put
++EXPORT_SYMBOL vmlinux 0x7d1ea6e3	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0x7d3e18b2	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x7d5ea83a	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x7d5f2e01	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x7d641874	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d821fe0	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x7d8a0e33	simple_lookup
++EXPORT_SYMBOL vmlinux 0x7db013be	__break_lease
++EXPORT_SYMBOL vmlinux 0x7db1e6ff	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0x7dbdd443	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x7de5bf49	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0x7debbce4	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7df0f12e	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x7e1888f6	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0x7e40796e	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x7e487d7c	nd_integrity_init
++EXPORT_SYMBOL vmlinux 0x7e501c6d	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x7e50bfef	d_delete
++EXPORT_SYMBOL vmlinux 0x7e558f7e	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0x7e5af67a	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0x7e6b2bad	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x7e726b8b	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0x7e87227e	slhc_compress
++EXPORT_SYMBOL vmlinux 0x7ea1f9df	seq_path
++EXPORT_SYMBOL vmlinux 0x7ea7353a	ps2_end_command
++EXPORT_SYMBOL vmlinux 0x7eae38d3	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x7eb529fa	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0x7ecb001b	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f15cf88	input_set_capability
++EXPORT_SYMBOL vmlinux 0x7f1d41a2	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f263ed9	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x7f2a2c7a	seq_file_path
++EXPORT_SYMBOL vmlinux 0x7f33d037	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7fbd10d2	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x7fdb55d3	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fe38f48	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x7fe5fdbc	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x7ff0fe63	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0x80284555	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0x802ac160	vme_bus_type
++EXPORT_SYMBOL vmlinux 0x804009de	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0x8059b7dd	devm_request_resource
++EXPORT_SYMBOL vmlinux 0x8068c15c	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x806e6ef3	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0x806e780a	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0x80791a8c	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0x809328c8	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x8095d8a5	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x809d99b2	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0x80a8f1d5	vga_client_register
++EXPORT_SYMBOL vmlinux 0x80bb5248	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80e80dd5	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x81061f94	seq_putc
++EXPORT_SYMBOL vmlinux 0x8106d3af	sys_copyarea
++EXPORT_SYMBOL vmlinux 0x810d1c04	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x8110ba7d	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0x8113907c	mpage_readpage
++EXPORT_SYMBOL vmlinux 0x812c6b37	finish_open
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x81533963	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x815c56d0	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x81a07f4e	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x81aefc37	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0x81be1b53	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81df7397	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x81e89515	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0x81f03340	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x81f692ae	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x81fca6ce	genl_notify
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x8208930a	input_free_device
++EXPORT_SYMBOL vmlinux 0x8216f791	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0x822c5a8c	fence_add_callback
++EXPORT_SYMBOL vmlinux 0x8237cc05	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x824507f6	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0x82454d08	make_kuid
++EXPORT_SYMBOL vmlinux 0x82458f7f	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x824e8807	dma_direct_ops
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x82752f38	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x827baf83	default_llseek
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x8293d5f4	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0x829b8a2e	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82b6fa1d	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0x82e5a238	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x8306035a	skb_append
++EXPORT_SYMBOL vmlinux 0x830676fa	of_get_next_parent
++EXPORT_SYMBOL vmlinux 0x830c76e1	blk_queue_split
++EXPORT_SYMBOL vmlinux 0x832217de	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x832aa4d8	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0x83374fdb	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0x8341a620	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0x83642c1a	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0x8383552b	uart_resume_port
++EXPORT_SYMBOL vmlinux 0x838f4add	write_inode_now
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x839c5579	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83beaaf5	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83cb125e	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x83d6df60	dev_err
++EXPORT_SYMBOL vmlinux 0x83e7aadd	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0x83f3abe3	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x83fcc673	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0x842a393d	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0x844e3767	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0x84511ece	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0x8466e294	blk_complete_request
++EXPORT_SYMBOL vmlinux 0x847b73a5	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x849fe807	csum_and_copy_from_user
++EXPORT_SYMBOL vmlinux 0x84a3aba5	mount_subtree
++EXPORT_SYMBOL vmlinux 0x84bd69bf	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x84d19e03	of_match_device
++EXPORT_SYMBOL vmlinux 0x84d496b9	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x84d81476	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0x84f17ea9	vfs_writef
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x85016036	inet_frags_init
++EXPORT_SYMBOL vmlinux 0x85057c58	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x850e1d51	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x85417488	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x854c1510	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0x85633675	register_shrinker
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x858afc51	netif_rx
++EXPORT_SYMBOL vmlinux 0x858f6c73	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x85aa3a6d	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x85ae6052	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85ba68d5	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85e25466	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x860199c9	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0x860def36	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0x86132263	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0x8638d97f	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x8645abb0	padata_alloc
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x865172c4	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0x865356f2	iunique
++EXPORT_SYMBOL vmlinux 0x8655b148	up_read
++EXPORT_SYMBOL vmlinux 0x8660fa6a	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x868bdb0e	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x8697073f	seq_open
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86c6c267	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x86dd3700	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0x86e4abb1	i2c_release_client
++EXPORT_SYMBOL vmlinux 0x86e75148	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x87040f4b	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x871fdcac	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0x872b4c23	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0x873a53ea	__arch_hweight8
++EXPORT_SYMBOL vmlinux 0x873b0eda	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0x874aaa62	request_firmware
++EXPORT_SYMBOL vmlinux 0x877aea4f	backlight_device_register
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x87928da1	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x8792db79	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x87c40819	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x87d68e62	dquot_release
++EXPORT_SYMBOL vmlinux 0x87dc1a84	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0x87f62018	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x8803b411	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x8822e368	__alloc_skb
++EXPORT_SYMBOL vmlinux 0x882db37f	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0x88386b7d	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0x885f5039	blkdev_get
++EXPORT_SYMBOL vmlinux 0x88618f27	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x88687f7a	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x8878ece3	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0x887fa47e	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x88914cad	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0x88ad05b1	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x88c8a8f2	kern_path
++EXPORT_SYMBOL vmlinux 0x88e44bd4	file_open_root
++EXPORT_SYMBOL vmlinux 0x88fa791a	elv_add_request
++EXPORT_SYMBOL vmlinux 0x89030f16	generic_file_open
++EXPORT_SYMBOL vmlinux 0x890a7adf	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0x891fbb10	mempool_destroy
++EXPORT_SYMBOL vmlinux 0x892de3fb	__nla_put
++EXPORT_SYMBOL vmlinux 0x895108f3	proc_dostring
++EXPORT_SYMBOL vmlinux 0x89522f80	dqput
++EXPORT_SYMBOL vmlinux 0x89540317	set_device_ro
++EXPORT_SYMBOL vmlinux 0x89563bee	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0x895c593b	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0x89614647	input_event
++EXPORT_SYMBOL vmlinux 0x89797060	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x8983f6ba	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x898cc2a3	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0x89934b03	netdev_err
++EXPORT_SYMBOL vmlinux 0x8996b6e2	set_anon_super
++EXPORT_SYMBOL vmlinux 0x89994d0f	generic_write_end
++EXPORT_SYMBOL vmlinux 0x89a4a1c7	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89c6f94a	vfs_readv
++EXPORT_SYMBOL vmlinux 0x89d2c521	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89de22e3	d_find_alias
++EXPORT_SYMBOL vmlinux 0x89f5b338	mach_corenet_generic
++EXPORT_SYMBOL vmlinux 0x8a090cde	nd_device_register
++EXPORT_SYMBOL vmlinux 0x8a0c5b9b	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0x8a18887d	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a226734	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0x8a36d5b9	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a6336d5	netdev_state_change
++EXPORT_SYMBOL vmlinux 0x8a66f2eb	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0x8a6796d5	block_commit_write
++EXPORT_SYMBOL vmlinux 0x8a6af65c	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a81cba6	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0x8a87725d	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0x8a8eaa54	bh_submit_read
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8b0186ab	vfs_writev
++EXPORT_SYMBOL vmlinux 0x8b0e4f12	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0x8b31d3bc	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b442d1c	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0x8b557648	consume_skb
++EXPORT_SYMBOL vmlinux 0x8b609807	__scm_send
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b67d8a7	of_node_get
++EXPORT_SYMBOL vmlinux 0x8b7bfeec	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b849575	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x8b9ac3bf	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x8ba73aab	param_set_long
++EXPORT_SYMBOL vmlinux 0x8baf3116	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x8bf2ae1f	fsl_lbc_addr
++EXPORT_SYMBOL vmlinux 0x8c04f3b9	of_device_is_big_endian
++EXPORT_SYMBOL vmlinux 0x8c109e7c	passthru_features_check
++EXPORT_SYMBOL vmlinux 0x8c153a36	__netif_schedule
++EXPORT_SYMBOL vmlinux 0x8c183cbe	iowrite16
++EXPORT_SYMBOL vmlinux 0x8c49c856	nf_log_trace
++EXPORT_SYMBOL vmlinux 0x8c6322f8	do_SAK
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c7f42af	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0x8cb3532c	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0x8cb43817	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x8cc17f89	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x8cc79cab	iowrite16_rep
++EXPORT_SYMBOL vmlinux 0x8ccc00a8	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0x8ccc6f62	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x8cd0d095	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x8d015dd4	__bswapdi2
++EXPORT_SYMBOL vmlinux 0x8d060250	user_revoke
++EXPORT_SYMBOL vmlinux 0x8d06cbec	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0x8d2000fc	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0x8d476b2e	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d628a55	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0x8d6406b7	set_binfmt
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d756c8b	agp_alloc_page_array
++EXPORT_SYMBOL vmlinux 0x8d8e5615	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x8d8f6950	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x8d944cbb	copy_in_user
++EXPORT_SYMBOL vmlinux 0x8d9da34a	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0x8d9f4942	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0x8dadcc6a	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0x8dbd20dc	of_parse_phandle
++EXPORT_SYMBOL vmlinux 0x8dd3666f	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x8de0b5ac	mempool_create
++EXPORT_SYMBOL vmlinux 0x8def1854	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0x8df92f66	memchr_inv
++EXPORT_SYMBOL vmlinux 0x8e065a5b	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x8e0efe0a	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x8e184f51	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0x8e4543c1	of_find_device_by_node
++EXPORT_SYMBOL vmlinux 0x8e49ac22	simple_open
++EXPORT_SYMBOL vmlinux 0x8e4fc39d	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e789236	of_get_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0x8e888ec3	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x8e8d58da	diu_ops
++EXPORT_SYMBOL vmlinux 0x8e94d99e	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x8ebd51be	proc_symlink
++EXPORT_SYMBOL vmlinux 0x8ec04552	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0x8ec89707	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x8f033198	vfs_rename
++EXPORT_SYMBOL vmlinux 0x8f0cf5e9	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0x8f16824e	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0x8f539d09	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0x8f85f835	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x8fa20cd0	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0x8fb65b00	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0x8fc15bf6	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0x8fdc101d	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0x8fe863b0	generic_permission
++EXPORT_SYMBOL vmlinux 0x8fff0b69	__lock_buffer
++EXPORT_SYMBOL vmlinux 0x9023a30a	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x90276beb	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0x902958f1	__scm_destroy
++EXPORT_SYMBOL vmlinux 0x9044cabe	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0x90476e9e	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0x90874dc1	empty_aops
++EXPORT_SYMBOL vmlinux 0x908b82bc	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x90a551be	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0x90c7222c	vfs_link
++EXPORT_SYMBOL vmlinux 0x90d5e5e7	agp_collect_device_status
++EXPORT_SYMBOL vmlinux 0x90e3ac70	nf_register_hook
++EXPORT_SYMBOL vmlinux 0x90f6a041	sock_from_file
++EXPORT_SYMBOL vmlinux 0x910783d1	to_ndd
++EXPORT_SYMBOL vmlinux 0x91106ba7	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x915a6549	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0x915e1208	tb_ticks_per_usec
++EXPORT_SYMBOL vmlinux 0x91652baf	arp_tbl
++EXPORT_SYMBOL vmlinux 0x9166fada	strncpy
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x91721641	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0x917b739d	param_get_charp
++EXPORT_SYMBOL vmlinux 0x918b3069	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0x919d1163	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x919e94b8	simple_rmdir
++EXPORT_SYMBOL vmlinux 0x91ac822f	vscnprintf
++EXPORT_SYMBOL vmlinux 0x91b33092	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x91bc8e36	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x91e83f4f	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x92474bff	nd_region_acquire_lane
++EXPORT_SYMBOL vmlinux 0x92887220	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0x9291cd3b	memdup_user
++EXPORT_SYMBOL vmlinux 0x92930092	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92bfcb2f	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0x92caacab	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x92e20bb0	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x92ea7d49	clear_user_page
++EXPORT_SYMBOL vmlinux 0x92f7912e	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x92fd2a58	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0x93022ba6	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x931c1f09	__seq_open_private
++EXPORT_SYMBOL vmlinux 0x932138b2	phy_stop
++EXPORT_SYMBOL vmlinux 0x933ee549	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0x936e67c5	vga_get
++EXPORT_SYMBOL vmlinux 0x9371c94e	uart_match_port
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x93778120	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0x938b58ff	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x9395113d	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0x93a06257	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0x93ac6c32	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93cac9dc	netdev_printk
++EXPORT_SYMBOL vmlinux 0x93da8fb6	d_rehash
++EXPORT_SYMBOL vmlinux 0x93f90032	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x93fe26db	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0x940041f4	of_device_unregister
++EXPORT_SYMBOL vmlinux 0x94015b2c	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x940b1435	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x940b572e	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x941ed00d	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0x94238ea9	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x942f0c71	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0x943dc80f	csum_and_copy_to_user
++EXPORT_SYMBOL vmlinux 0x943e3dcb	down_read
++EXPORT_SYMBOL vmlinux 0x94439708	input_open_device
++EXPORT_SYMBOL vmlinux 0x94832c2b	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x948dbb23	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0x9492fc78	vme_master_request
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94a124a9	I_BDEV
++EXPORT_SYMBOL vmlinux 0x94a2b99b	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x94a2dc1f	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x94b541b5	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x94c68f28	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x94ef2826	__get_page_tail
++EXPORT_SYMBOL vmlinux 0x94f29364	downgrade_write
++EXPORT_SYMBOL vmlinux 0x94ff80ab	dst_destroy
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x9512f1eb	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x9514151a	_mcount
++EXPORT_SYMBOL vmlinux 0x9522b70d	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x9524b0ae	_outsb
++EXPORT_SYMBOL vmlinux 0x9537fde7	soft_cursor
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x954bc038	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x95652fa3	ata_port_printk
++EXPORT_SYMBOL vmlinux 0x95921be3	agp_free_memory
++EXPORT_SYMBOL vmlinux 0x95cd4dd5	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0x95d5d604	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0x95d82c98	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x95e525b4	bio_add_page
++EXPORT_SYMBOL vmlinux 0x95f313ce	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x96034596	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x961248a5	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0x965b798c	sync_filesystem
++EXPORT_SYMBOL vmlinux 0x9674b457	eth_header
++EXPORT_SYMBOL vmlinux 0x9684bcbb	netif_napi_add
++EXPORT_SYMBOL vmlinux 0x969987fc	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0x96b29254	strncasecmp
++EXPORT_SYMBOL vmlinux 0x96bc8aef	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x96be4202	nd_btt_arena_is_valid
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x97022e9d	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0x970da6d6	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0x97298a02	cdev_add
++EXPORT_SYMBOL vmlinux 0x972e9ffd	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x9748927f	_outsw_ns
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x97868aef	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0x97980349	wireless_send_event
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x979a5ad7	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x97a57333	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0x97afba7b	proc_douintvec
++EXPORT_SYMBOL vmlinux 0x97bbe08e	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0x97fa654c	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x97ff9dd4	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0x9807229f	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x9829fc11	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0x9852c1e1	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0x98594330	truncate_setsize
++EXPORT_SYMBOL vmlinux 0x9867eb27	ata_link_printk
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x987388aa	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x987fc124	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x9890ece4	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0x98b2f93e	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0x98c68c41	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x98cd2539	loop_backing_file
++EXPORT_SYMBOL vmlinux 0x98cf60b3	strlen
++EXPORT_SYMBOL vmlinux 0x98d2e1eb	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0x98fcd540	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x99195078	vsnprintf
++EXPORT_SYMBOL vmlinux 0x991c27f1	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x992ae44d	sk_common_release
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x99449f17	vme_irq_free
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x996d8d88	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x99766955	mmc_request_done
++EXPORT_SYMBOL vmlinux 0x998ad00d	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x998e5932	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99afe916	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d3a43c	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x99dc357b	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x99dc6fcc	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x9a0180da	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x9a0ad805	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x9a1dc1ed	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a502016	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0x9a57b959	pci_get_class
++EXPORT_SYMBOL vmlinux 0x9a5c9ec2	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x9a750791	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x9a812df5	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0x9a891e54	param_get_uint
++EXPORT_SYMBOL vmlinux 0x9a956bae	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0x9ab1502c	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0x9ad1d342	mem_map
++EXPORT_SYMBOL vmlinux 0x9ada2e57	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x9ae42930	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9b053509	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0x9b1174f5	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0x9b135503	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0x9b32d0ba	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b3589d6	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b428973	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0x9b593ba0	skb_push
++EXPORT_SYMBOL vmlinux 0x9b61a4d1	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0x9b63329f	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0x9b71654b	of_mdio_find_bus
++EXPORT_SYMBOL vmlinux 0x9b7e85a6	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0x9b8a34d8	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9babca29	touch_atime
++EXPORT_SYMBOL vmlinux 0x9bacf351	dput
++EXPORT_SYMBOL vmlinux 0x9bae5ac2	ppp_input
++EXPORT_SYMBOL vmlinux 0x9bc151d6	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0x9bd343d2	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0x9be000d1	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x9be28f30	get_agp_version
++EXPORT_SYMBOL vmlinux 0x9be369c4	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9bfe1671	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0x9c00fb7e	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x9c2a9424	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0x9c38b490	__neigh_create
++EXPORT_SYMBOL vmlinux 0x9c3999d0	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c5bf489	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0x9c864340	__page_symlink
++EXPORT_SYMBOL vmlinux 0x9c8fa5b4	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0x9c97f8ee	genphy_update_link
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cabf034	security_path_link
++EXPORT_SYMBOL vmlinux 0x9cad1d2b	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0x9cc3c176	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x9cd70826	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0x9cd987d3	of_device_register
++EXPORT_SYMBOL vmlinux 0x9cdb1e05	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0x9ce04cb7	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x9cfeab62	proc_create_data
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d14983a	ppc_enable_pmcs
++EXPORT_SYMBOL vmlinux 0x9d1bf844	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d4810c1	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0x9d4cc9d2	dma_set_coherent_mask
++EXPORT_SYMBOL vmlinux 0x9d518a01	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x9d537a8d	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x9d6a54c2	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0x9d72229b	fsl_ifc_find
++EXPORT_SYMBOL vmlinux 0x9d737cf9	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0x9d7abb05	f_setown
++EXPORT_SYMBOL vmlinux 0x9d7ce8dd	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x9d83c87f	fs_bio_set
++EXPORT_SYMBOL vmlinux 0x9da05e10	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0x9dac457d	tty_port_init
++EXPORT_SYMBOL vmlinux 0x9db65be0	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x9dca1811	agp_generic_create_gatt_table
++EXPORT_SYMBOL vmlinux 0x9ddb0784	udplite_prot
++EXPORT_SYMBOL vmlinux 0x9ddb2363	kobject_add
++EXPORT_SYMBOL vmlinux 0x9df217d0	__vfs_read
++EXPORT_SYMBOL vmlinux 0x9dfbef19	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x9dfca983	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0x9e001e69	dquot_acquire
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e2f8c90	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9e353184	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0x9e44527b	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e613fdb	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e89b5a9	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0x9e95f326	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9ea884ba	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0x9eb9be21	md_done_sync
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9ee13fbb	fb_get_mode
++EXPORT_SYMBOL vmlinux 0x9ef8e07b	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x9f122a43	netdev_alert
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f63a88d	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x9f7a99a1	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x9f7c1be8	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0x9f830412	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x9f911629	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9fbda277	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0x9fc0cb5d	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0x9fc65530	finish_no_open
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa00a6577	bio_advance
++EXPORT_SYMBOL vmlinux 0xa012b96c	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0xa021a7b4	nd_iostat_end
++EXPORT_SYMBOL vmlinux 0xa034744e	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0xa0363f30	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0xa03b1aab	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa055362b	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa05d7161	simple_write_end
++EXPORT_SYMBOL vmlinux 0xa07a37f0	memchr
++EXPORT_SYMBOL vmlinux 0xa07c9ed7	ata_print_version
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0b2fee2	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0xa0d973d7	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0ff74d6	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xa0ff9c54	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa12cdc15	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa154e2ed	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0xa15865c2	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0xa15b9215	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0xa172c6ef	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0xa1b568a1	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1ba0797	__mutex_init
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1c99385	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0xa1de3f53	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0xa1de8512	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa1ead8fd	freeze_bdev
++EXPORT_SYMBOL vmlinux 0xa1f8fe75	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0xa202a8e5	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0xa2071ae6	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa219e625	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0xa221a1fc	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0xa24563f7	elv_register_queue
++EXPORT_SYMBOL vmlinux 0xa25a6e8d	vfs_setpos
++EXPORT_SYMBOL vmlinux 0xa268dfa5	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa29a3e4e	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xa2a335bd	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0xa2a721a4	register_framebuffer
++EXPORT_SYMBOL vmlinux 0xa2bbed37	crash_shutdown_register
++EXPORT_SYMBOL vmlinux 0xa2db7cd5	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0xa2fa8dc6	of_find_backlight_by_node
++EXPORT_SYMBOL vmlinux 0xa2fdbcbe	fence_default_wait
++EXPORT_SYMBOL vmlinux 0xa303d1ff	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0xa311e39b	twl6040_power
++EXPORT_SYMBOL vmlinux 0xa31591f4	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0xa319687d	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xa31a32c4	phy_detach
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa33588a6	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0xa381944f	dql_reset
++EXPORT_SYMBOL vmlinux 0xa386d5df	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0xa39b4cf2	udelay
++EXPORT_SYMBOL vmlinux 0xa3abc422	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xa3db4743	agp_enable
++EXPORT_SYMBOL vmlinux 0xa3e0274b	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0xa3e75545	flush_tlb_kernel_range
++EXPORT_SYMBOL vmlinux 0xa3ec28c6	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0xa403a572	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0xa41e0b51	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xa4299a89	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0xa4511467	crc16
++EXPORT_SYMBOL vmlinux 0xa4531570	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0xa45e1bbd	giveup_fpu
++EXPORT_SYMBOL vmlinux 0xa4637b29	path_get
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa4832d0b	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0xa4904486	phy_resume
++EXPORT_SYMBOL vmlinux 0xa494155c	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0xa4a72495	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0xa4a94d26	find_next_bit_le
++EXPORT_SYMBOL vmlinux 0xa4b94fea	iowrite8_rep
++EXPORT_SYMBOL vmlinux 0xa4bf0b5c	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0xa4d3cd30	dev_add_offload
++EXPORT_SYMBOL vmlinux 0xa4d4f0e6	global_cache_flush
++EXPORT_SYMBOL vmlinux 0xa4f85d0e	no_llseek
++EXPORT_SYMBOL vmlinux 0xa507ebea	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0xa53cad05	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa55a0eb1	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0xa55c6830	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0xa5673c6d	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0xa56b8ab2	flex_array_free
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa5a51eee	__crc32c_le
++EXPORT_SYMBOL vmlinux 0xa5a53ac6	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0xa5a6c27d	mount_single
++EXPORT_SYMBOL vmlinux 0xa5b2fdac	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0xa5b41628	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0xa5d5f601	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0xa5e8b919	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0xa5e944f9	inet6_release
++EXPORT_SYMBOL vmlinux 0xa6061bcf	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0xa615d8ed	d_obtain_root
++EXPORT_SYMBOL vmlinux 0xa6199788	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xa63322c6	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xa6496133	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0xa64bf88f	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0xa65972b8	_memcpy_toio
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa6a1debd	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0xa6b02a86	module_put
++EXPORT_SYMBOL vmlinux 0xa6b656ae	of_phy_attach
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa707ae7e	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0xa708cc80	is_bad_inode
++EXPORT_SYMBOL vmlinux 0xa70fae79	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xa712766c	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0xa720678c	lg_global_lock
++EXPORT_SYMBOL vmlinux 0xa7266957	led_blink_set
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa74f4e9b	ida_simple_get
++EXPORT_SYMBOL vmlinux 0xa75276b2	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0xa752dc0d	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0xa7859966	of_find_node_with_property
++EXPORT_SYMBOL vmlinux 0xa78d9eb7	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0xa792fb89	mac_find_mode
++EXPORT_SYMBOL vmlinux 0xa7d62a4d	dev_activate
++EXPORT_SYMBOL vmlinux 0xa7d84f02	softnet_data
++EXPORT_SYMBOL vmlinux 0xa80771ed	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0xa811295f	agp_generic_alloc_page
++EXPORT_SYMBOL vmlinux 0xa814cfcb	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0xa82d8e06	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa843ed40	netdev_info
++EXPORT_SYMBOL vmlinux 0xa84fa5c5	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xa8556258	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0xa85e522f	tcp_poll
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa88c38f7	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0xa8b73c86	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0xa8c172ba	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0xa8cdf84a	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa916b694	strnlen
++EXPORT_SYMBOL vmlinux 0xa91d90d3	nla_put
++EXPORT_SYMBOL vmlinux 0xa9220a25	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0xa9273e1a	epapr_hypercall_start
++EXPORT_SYMBOL vmlinux 0xa9390c72	vm_map_ram
++EXPORT_SYMBOL vmlinux 0xa93ba88e	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0xa952382f	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0xa9588e96	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0xa95f09f7	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0xa9623248	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0xa96276f6	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa991b59a	iget_failed
++EXPORT_SYMBOL vmlinux 0xa99871e7	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0xa99b39c2	prandom_bytes
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9d7c54a	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0xa9e87a17	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0xaa03faf0	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0xaa04c144	d_move
++EXPORT_SYMBOL vmlinux 0xaa0672c3	mpage_writepages
++EXPORT_SYMBOL vmlinux 0xaa11ab08	generic_setxattr
++EXPORT_SYMBOL vmlinux 0xaa26acf5	bio_reset
++EXPORT_SYMBOL vmlinux 0xaa46e87e	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0xaa48dde0	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0xaa6e4df5	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa711ca9	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xaa768d6c	skb_make_writable
++EXPORT_SYMBOL vmlinux 0xaa8da89b	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0xaaab8067	cpu_sibling_map
++EXPORT_SYMBOL vmlinux 0xaaabc61e	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0xaabdf3ef	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0xaabe0aad	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0xaad009f6	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaaf36c14	input_inject_event
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab01bf1d	init_task
++EXPORT_SYMBOL vmlinux 0xab0b9f6d	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0xab228e31	csum_tcpudp_magic
++EXPORT_SYMBOL vmlinux 0xab22e819	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0xab3c8d0c	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0xab4c7579	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0xab690e92	nf_afinfo
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab7f6eff	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0xab8aaeb9	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0xab93ea3b	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0xab96e4f7	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0xaba89208	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0xabc8e3dd	scsi_host_put
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabd61a40	pipe_unlock
++EXPORT_SYMBOL vmlinux 0xabecf7c4	sock_init_data
++EXPORT_SYMBOL vmlinux 0xabf4c3e4	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1732c8	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac1b539c	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0xac26b820	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0xac3faf8c	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0xac4f2e9e	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0xac5ce099	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0xac6391c0	inet6_offloads
++EXPORT_SYMBOL vmlinux 0xac77d465	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0xac9eca7a	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacbdc86a	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0xacc457dc	of_get_min_tck
++EXPORT_SYMBOL vmlinux 0xacc5b5d2	csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacd5549d	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xace081fa	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0xace10b82	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0xace50076	dev_addr_del
++EXPORT_SYMBOL vmlinux 0xacf0b9d6	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xad01744f	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad11416b	touch_buffer
++EXPORT_SYMBOL vmlinux 0xad164875	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xad236625	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0xad2af0c8	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xad35f3b7	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0xad485026	dev_deactivate
++EXPORT_SYMBOL vmlinux 0xad541ea2	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0xad5664a4	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0xad72c8b5	inet_frag_find
++EXPORT_SYMBOL vmlinux 0xad7fae9f	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad961743	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0xadbc3e58	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0xadcc7e12	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0xadd0a849	get_super
++EXPORT_SYMBOL vmlinux 0xadd3397f	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0xadef1854	paca
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xadffa360	put_page
++EXPORT_SYMBOL vmlinux 0xae0f5d22	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0xae28d54c	register_filesystem
++EXPORT_SYMBOL vmlinux 0xae349561	of_graph_get_remote_port
++EXPORT_SYMBOL vmlinux 0xae358236	fence_signal
++EXPORT_SYMBOL vmlinux 0xae363be7	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0xae43f2f0	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0xae545f06	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xae907f2b	register_netdev
++EXPORT_SYMBOL vmlinux 0xaea1aa99	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0xaf063510	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xaf21064a	bdevname
++EXPORT_SYMBOL vmlinux 0xaf2d872c	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0xaf2d90d8	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xaf2dca3b	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf6ae696	kstrndup
++EXPORT_SYMBOL vmlinux 0xaf6be6d7	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xaf7c1ada	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0xaf91831f	param_ops_byte
++EXPORT_SYMBOL vmlinux 0xaf9340a7	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xaf980d91	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0xafb0b6a8	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0xafb0fd09	gen_pool_create
++EXPORT_SYMBOL vmlinux 0xafbc9eb1	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xafe4c4e4	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0xafff3d1d	mempool_alloc
++EXPORT_SYMBOL vmlinux 0xb00343c2	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xb03abbdb	vfs_getattr
++EXPORT_SYMBOL vmlinux 0xb04241b4	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0xb04b1ec9	proc_set_size
++EXPORT_SYMBOL vmlinux 0xb04d361e	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0xb053165f	register_key_type
++EXPORT_SYMBOL vmlinux 0xb059392e	security_path_symlink
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb065fe01	kernel_read
++EXPORT_SYMBOL vmlinux 0xb06ccbc8	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0xb08664e9	iget5_locked
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0aff92e	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0xb0b1063c	generic_make_request
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0b66c87	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0xb0c31358	of_find_node_opts_by_path
++EXPORT_SYMBOL vmlinux 0xb0c8a66e	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0xb0cb3353	mmc_get_card
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0ea5cbb	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb144d790	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0xb14b1744	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0xb15bd8fa	tb_ticks_per_sec
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb165ef45	__irq_regs
++EXPORT_SYMBOL vmlinux 0xb167c104	param_ops_short
++EXPORT_SYMBOL vmlinux 0xb1832371	con_is_bound
++EXPORT_SYMBOL vmlinux 0xb18f3079	netdev_emerg
++EXPORT_SYMBOL vmlinux 0xb1b51b99	pcibios_fixup_bus
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1c6e787	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1d44c50	module_layout
++EXPORT_SYMBOL vmlinux 0xb1fb0fef	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0xb244f9fb	keyring_alloc
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb287a824	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0xb292e5f3	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0xb29349b5	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2e72403	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0xb2efe01a	agp3_generic_tlbflush
++EXPORT_SYMBOL vmlinux 0xb2f1f806	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0xb311a71c	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0xb3382494	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0xb34c98ed	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0xb351aa44	vga_put
++EXPORT_SYMBOL vmlinux 0xb35f181d	try_to_release_page
++EXPORT_SYMBOL vmlinux 0xb36fe42c	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0xb370f84f	of_graph_get_endpoint_by_regs
++EXPORT_SYMBOL vmlinux 0xb3b9d727	kill_block_super
++EXPORT_SYMBOL vmlinux 0xb3c07604	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0xb3d0da17	arp_create
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3d8cbb0	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb3ff8df1	__devm_request_region
++EXPORT_SYMBOL vmlinux 0xb41bf1c9	pci_save_state
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb43930a6	param_get_ullong
++EXPORT_SYMBOL vmlinux 0xb43fcd27	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0xb44d4d9c	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0xb453f0f0	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0xb46cde80	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb47189b5	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xb473e2c2	lockref_get
++EXPORT_SYMBOL vmlinux 0xb48a0c91	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0xb4960e2a	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0xb4970bba	misc_deregister
++EXPORT_SYMBOL vmlinux 0xb4c279c3	xattr_full_name
++EXPORT_SYMBOL vmlinux 0xb4c3950d	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0xb4c9a932	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0xb4cef8c9	bio_init
++EXPORT_SYMBOL vmlinux 0xb4e24b6f	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0xb4f72aed	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0xb50c662f	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb57d31b8	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0xb57d9513	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0xb581f5d6	vme_register_driver
++EXPORT_SYMBOL vmlinux 0xb5820784	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0xb585486e	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0xb58d7c6b	free_page_put_link
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5cceccf	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0xb5d2255c	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb6269dd1	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0xb6412373	neigh_xmit
++EXPORT_SYMBOL vmlinux 0xb64eba5b	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0xb65f44e4	blk_start_request
++EXPORT_SYMBOL vmlinux 0xb663bfd6	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0xb676775a	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb68f3993	i8042_remove_filter
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6978be5	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6a7ee6a	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0xb6ac1cc2	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0xb6aceb05	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0xb6b57e8e	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0xb6c2e0bc	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0xb6c58c2a	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0xb6d810e4	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0xb6f0cbcc	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0xb6f76881	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0xb6f82742	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0xb6fafe96	tty_port_put
++EXPORT_SYMBOL vmlinux 0xb722cf13	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0xb7284873	vfs_symlink
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb74987a8	fput
++EXPORT_SYMBOL vmlinux 0xb75ae31c	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0xb75b9c2f	kill_anon_super
++EXPORT_SYMBOL vmlinux 0xb7643d64	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0xb770be3e	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb7941606	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0xb79a4e1a	store_fp_state
++EXPORT_SYMBOL vmlinux 0xb7a27fe1	proto_register
++EXPORT_SYMBOL vmlinux 0xb7bc3d88	md_reload_sb
++EXPORT_SYMBOL vmlinux 0xb7bcd9c0	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7d29492	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0xb7d2f841	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0xb7f2222a	padata_start
++EXPORT_SYMBOL vmlinux 0xb80acc12	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0xb816cd4d	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0xb8197f7e	set_posix_acl
++EXPORT_SYMBOL vmlinux 0xb825ccad	of_find_net_device_by_node
++EXPORT_SYMBOL vmlinux 0xb8269c8e	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb847999d	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0xb850141d	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0xb85c112f	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0xb86564d8	of_graph_get_port_by_id
++EXPORT_SYMBOL vmlinux 0xb871911c	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0xb87284f3	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb8de6278	new_inode
++EXPORT_SYMBOL vmlinux 0xb8ef2bf7	dm_put_device
++EXPORT_SYMBOL vmlinux 0xb8f35de5	current_in_userns
++EXPORT_SYMBOL vmlinux 0xb8f5f715	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0xb906515e	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0xb90cbc61	of_find_node_by_type
++EXPORT_SYMBOL vmlinux 0xb917d5b7	vc_cons
++EXPORT_SYMBOL vmlinux 0xb918db11	udp_del_offload
++EXPORT_SYMBOL vmlinux 0xb91fb345	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0xb98813ca	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0xb9b1d1d3	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0xb9be599b	compat_sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0xb9c2369b	module_refcount
++EXPORT_SYMBOL vmlinux 0xb9c7a8f2	do_splice_from
++EXPORT_SYMBOL vmlinux 0xb9ccd0c9	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xb9f22dce	datagram_poll
++EXPORT_SYMBOL vmlinux 0xba31ab5a	block_write_begin
++EXPORT_SYMBOL vmlinux 0xba483afc	dev_change_flags
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba4e5a2f	tty_unlock
++EXPORT_SYMBOL vmlinux 0xba545aec	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0xba5d2fb9	xfrm_input
++EXPORT_SYMBOL vmlinux 0xba8769fb	set_security_override
++EXPORT_SYMBOL vmlinux 0xba9efd19	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0xbabb243d	compat_mc_getsockopt
++EXPORT_SYMBOL vmlinux 0xbac6668a	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0xbadc1915	__find_get_block
++EXPORT_SYMBOL vmlinux 0xbb02ec71	phys_mem_access_prot
++EXPORT_SYMBOL vmlinux 0xbb04e5a8	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0xbb050e18	__block_write_begin
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb055f77	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0xbb22a9d7	d_alloc_name
++EXPORT_SYMBOL vmlinux 0xbb254656	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0xbb2a441c	sock_wfree
++EXPORT_SYMBOL vmlinux 0xbb34134a	iov_shorten
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb369d91	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0xbb464fb8	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xbb4b25c2	lock_fb_info
++EXPORT_SYMBOL vmlinux 0xbb4f4766	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0xbb5929ee	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb8ef819	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0xbb901965	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbbaeb559	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0xbbb6b412	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xbbb840e2	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0xbc21be61	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0xbc239914	do_truncate
++EXPORT_SYMBOL vmlinux 0xbc2481bb	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0xbc2cac10	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0xbc2f666b	open_exec
++EXPORT_SYMBOL vmlinux 0xbc316de4	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0xbc58da66	kernel_bind
++EXPORT_SYMBOL vmlinux 0xbc7a18f8	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0xbcabaa3a	init_net
++EXPORT_SYMBOL vmlinux 0xbcb6527b	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0xbcbdb7ac	param_get_byte
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcdd8521	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0xbcf150f9	xor_altivec_5
++EXPORT_SYMBOL vmlinux 0xbcf657de	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0xbd1011e5	generic_getxattr
++EXPORT_SYMBOL vmlinux 0xbd1ce247	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0xbd462b55	__kfifo_init
++EXPORT_SYMBOL vmlinux 0xbd47ee5f	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0xbd4c5764	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0xbd6d79f1	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0xbd6f0020	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xbd803510	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbd986fc7	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0xbda79c52	dma_find_channel
++EXPORT_SYMBOL vmlinux 0xbdb706c4	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0xbdc1d38d	write_one_page
++EXPORT_SYMBOL vmlinux 0xbde0d136	param_ops_bint
++EXPORT_SYMBOL vmlinux 0xbde18d6a	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0xbdf76374	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0xbe016acf	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe38527d	dst_release
++EXPORT_SYMBOL vmlinux 0xbe38e196	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0xbe60612b	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0xbe71521b	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0xbebd89ef	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0xbec51f14	vm_stat
++EXPORT_SYMBOL vmlinux 0xbeed321b	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbeff696b	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0xbf0fae6f	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0xbf146162	vm_event_states
++EXPORT_SYMBOL vmlinux 0xbf508e90	nvdimm_namespace_common_probe
++EXPORT_SYMBOL vmlinux 0xbf523184	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0xbf6a618a	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8a5141	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf925c42	idr_init
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbf9c6938	key_alloc
++EXPORT_SYMBOL vmlinux 0xbfa9bb07	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0xbfabfe59	__debugger_iabr_match
++EXPORT_SYMBOL vmlinux 0xbfb37caf	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0xbfb8b0b7	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xbfc1255b	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0xbfc177bc	iowrite32_rep
++EXPORT_SYMBOL vmlinux 0xbfea96bd	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0xbfedca6c	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xc008c84f	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0xc0276b2a	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0xc02a846d	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0xc0356a2c	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0xc0365e52	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0xc03fcf83	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0xc05c8dc2	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0xc05dd98d	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0xc0632f7d	ppc_md
++EXPORT_SYMBOL vmlinux 0xc06d8efd	have_submounts
++EXPORT_SYMBOL vmlinux 0xc0705a2d	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc07b1cd3	generic_removexattr
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc08c8a80	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0xc0961603	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0xc0a19d11	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0b7a758	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0xc0e61f0a	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0xc0ef2ecd	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0xc0f45da2	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0xc100178c	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0xc10d4130	serio_rescan
++EXPORT_SYMBOL vmlinux 0xc1196230	pci_match_id
++EXPORT_SYMBOL vmlinux 0xc13a10dc	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0xc1507b81	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0xc15a44c6	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xc15d68b7	d_lookup
++EXPORT_SYMBOL vmlinux 0xc16456b0	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0xc1b42de9	__check_sticky
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1dd2ccc	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0xc1e393b0	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc1ed5b9c	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0xc217199c	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0xc21726d4	tty_vhangup
++EXPORT_SYMBOL vmlinux 0xc21e3f8e	build_skb
++EXPORT_SYMBOL vmlinux 0xc22a9014	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0xc2394a03	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0xc23b3e8c	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0xc2424641	agp3_generic_cleanup
++EXPORT_SYMBOL vmlinux 0xc268b496	drop_nlink
++EXPORT_SYMBOL vmlinux 0xc2694b3a	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0xc2750527	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0xc27cea96	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0xc2900ff9	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0xc2921a30	tty_set_operations
++EXPORT_SYMBOL vmlinux 0xc29bf967	strspn
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2af3120	nla_append
++EXPORT_SYMBOL vmlinux 0xc2be766e	bmap
++EXPORT_SYMBOL vmlinux 0xc2cefa69	iterate_mounts
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc30a049f	of_device_is_available
++EXPORT_SYMBOL vmlinux 0xc30b8142	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0xc310b981	strnstr
++EXPORT_SYMBOL vmlinux 0xc31ad3b3	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0xc370d4ff	__quota_error
++EXPORT_SYMBOL vmlinux 0xc376695e	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0xc3837fcf	invalidate_partition
++EXPORT_SYMBOL vmlinux 0xc3a86e18	complete_request_key
++EXPORT_SYMBOL vmlinux 0xc3b4632d	param_set_charp
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3d1ac4f	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0xc3d2dd54	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0xc3d97013	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0xc407dd04	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0xc423128c	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0xc4384508	input_reset_device
++EXPORT_SYMBOL vmlinux 0xc4387ce3	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0xc438c96e	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0xc444137f	agp_bind_memory
++EXPORT_SYMBOL vmlinux 0xc4477c09	arp_send
++EXPORT_SYMBOL vmlinux 0xc4513ceb	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0xc45755de	find_next_zero_bit_le
++EXPORT_SYMBOL vmlinux 0xc458719c	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0xc464997b	of_mdio_parse_addr
++EXPORT_SYMBOL vmlinux 0xc46863d2	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0xc46fba94	secpath_dup
++EXPORT_SYMBOL vmlinux 0xc47cdf9c	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0xc48307db	lz4_decompress
++EXPORT_SYMBOL vmlinux 0xc48fd1b9	copy_from_iter
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4a53810	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0xc4ae8ee2	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0xc4af9fe1	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0xc4b8ea68	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0xc4d3eb00	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0xc4dfe93b	free_user_ns
++EXPORT_SYMBOL vmlinux 0xc51398c7	pci_release_region
++EXPORT_SYMBOL vmlinux 0xc5239d8b	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0xc53210d1	netlink_set_err
++EXPORT_SYMBOL vmlinux 0xc53d373d	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0xc5426b1e	tcp_check_req
++EXPORT_SYMBOL vmlinux 0xc5534d64	ioread16
++EXPORT_SYMBOL vmlinux 0xc55da9e8	sync_inode
++EXPORT_SYMBOL vmlinux 0xc5952229	__devm_release_region
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc59e2cb5	bio_put
++EXPORT_SYMBOL vmlinux 0xc5ac6bd5	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0xc5d9c46c	agp_try_unsupported_boot
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc62343d1	pci_select_bars
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc64c96b0	sock_create_kern
++EXPORT_SYMBOL vmlinux 0xc65abeb7	agp3_generic_sizes
++EXPORT_SYMBOL vmlinux 0xc663b075	__ioremap
++EXPORT_SYMBOL vmlinux 0xc666a132	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xc6772da2	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xc683b1d2	ps2_init
++EXPORT_SYMBOL vmlinux 0xc6b9f13e	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0xc6cb465a	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6dcb74d	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0xc6ec0fa1	nvm_register_target
++EXPORT_SYMBOL vmlinux 0xc6f0a196	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0xc6fb0f75	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0xc70114ac	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0xc707fbb1	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0xc70c9385	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0xc713bddc	__register_binfmt
++EXPORT_SYMBOL vmlinux 0xc71c4918	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc721427e	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0xc729d11a	inet_del_offload
++EXPORT_SYMBOL vmlinux 0xc7353243	of_phy_connect
++EXPORT_SYMBOL vmlinux 0xc7496aa6	skb_put
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc758cbc9	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0xc7591cf0	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0xc75eb431	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0xc761b5dd	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0xc7680d30	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0xc768de19	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0xc7746303	of_phy_register_fixed_link
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc7898275	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0xc7909760	compat_sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc79ea4ec	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7e01d56	vga_tryget
++EXPORT_SYMBOL vmlinux 0xc804f71b	nf_log_unset
++EXPORT_SYMBOL vmlinux 0xc80b9860	padata_stop
++EXPORT_SYMBOL vmlinux 0xc83b34d3	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc83f5cfc	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xc845b9ab	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc84d2101	cdev_del
++EXPORT_SYMBOL vmlinux 0xc850061b	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0xc8571bcb	idr_for_each
++EXPORT_SYMBOL vmlinux 0xc8678349	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc87ab7b2	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0xc88e1b24	of_get_address
++EXPORT_SYMBOL vmlinux 0xc88f4e5a	iput
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc893828c	dquot_file_open
++EXPORT_SYMBOL vmlinux 0xc897c04e	n_tty_compat_ioctl_helper
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8b040a8	sk_dst_check
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8fdd233	inode_permission
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc919192a	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0xc93b50dc	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0xc93fbc54	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xc94b2e77	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc978479a	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xc9794407	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0xc97d4395	__put_cred
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc9e0bdbd	param_get_string
++EXPORT_SYMBOL vmlinux 0xca05d4e3	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca2b1cd6	ida_pre_get
++EXPORT_SYMBOL vmlinux 0xca2be3fc	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0xca386b14	sock_wake_async
++EXPORT_SYMBOL vmlinux 0xca3b28c6	store_vr_state
++EXPORT_SYMBOL vmlinux 0xca3b418d	blk_make_request
++EXPORT_SYMBOL vmlinux 0xca5ee09a	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0xca832efe	kmalloc_order
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xca965abc	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0xcaa1f445	of_get_ddr_timings
++EXPORT_SYMBOL vmlinux 0xcab60fe7	inet6_bind
++EXPORT_SYMBOL vmlinux 0xcac70a29	agp_find_bridge
++EXPORT_SYMBOL vmlinux 0xcace6297	idr_is_empty
++EXPORT_SYMBOL vmlinux 0xcad62f73	vfs_create
++EXPORT_SYMBOL vmlinux 0xcadc03ab	agp_alloc_bridge
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb083ea9	__f_setown
++EXPORT_SYMBOL vmlinux 0xcb1a8f36	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0xcb329f33	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0xcb3dfdcc	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0xcb424a46	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xcb47303d	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0xcb662031	follow_down
++EXPORT_SYMBOL vmlinux 0xcb741acf	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0xcb7d4563	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0xcb936989	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcb9faaf9	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc129f0	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbf0b430	set_bh_page
++EXPORT_SYMBOL vmlinux 0xcc04b1df	revalidate_disk
++EXPORT_SYMBOL vmlinux 0xcc17504d	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xcc178e5b	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc36cafa	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc87395a	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0xcc92a6a8	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0xcc9b5306	flush_icache_user_range
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccca3d4a	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0xccd718d5	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0xcce4bc95	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0xcce648e8	dquot_commit
++EXPORT_SYMBOL vmlinux 0xccf375e0	blk_put_request
++EXPORT_SYMBOL vmlinux 0xcd0529c7	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0xcd20667a	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0xcd23072d	done_path_create
++EXPORT_SYMBOL vmlinux 0xcd233561	param_get_long
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd363575	user_path_create
++EXPORT_SYMBOL vmlinux 0xcd3f0d51	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0xcd46ffa7	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0xcd4af006	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0xcd5423b8	vfs_unlink
++EXPORT_SYMBOL vmlinux 0xcd57f7b0	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0xcd6029b3	of_find_i2c_device_by_node
++EXPORT_SYMBOL vmlinux 0xcd7ede2a	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xcd7f5ce0	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0xcd86c87f	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0xcd932c9d	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0xcd94dd79	inet_put_port
++EXPORT_SYMBOL vmlinux 0xcd98169b	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xcd9d4a8b	scsi_unregister
++EXPORT_SYMBOL vmlinux 0xcda2ee18	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0xcdaa191a	sget_userns
++EXPORT_SYMBOL vmlinux 0xcdc392e2	agp_generic_alloc_user
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdc7d6f3	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0xcde0f4b7	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0xcdef0c07	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0xce0b341d	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0xce0e2d66	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xce10ed33	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0xce120df8	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0xce1273ab	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0xce13e802	get_acl
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce3b3f09	profile_pc
++EXPORT_SYMBOL vmlinux 0xce4e47b6	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0xce5475ff	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0xce5a5144	cdrom_open
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce7850e1	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0xce8a7a88	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0xce8f4753	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0xcea1e24e	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xceae504f	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0xcebf04c1	get_io_context
++EXPORT_SYMBOL vmlinux 0xcec0c31b	of_scan_pci_bridge
++EXPORT_SYMBOL vmlinux 0xced777cb	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf256091	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0xcf2c865e	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0xcf517e89	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0xcf563555	make_kgid
++EXPORT_SYMBOL vmlinux 0xcf5db729	of_find_matching_node_and_match
++EXPORT_SYMBOL vmlinux 0xcf85a4e4	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0xcf976c87	kset_unregister
++EXPORT_SYMBOL vmlinux 0xcf9a886d	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0xcfb33deb	scsi_execute
++EXPORT_SYMBOL vmlinux 0xcfc33965	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0xcfcbde62	__ps2_command
++EXPORT_SYMBOL vmlinux 0xcfcc1da4	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0xcfdba6f1	seq_printf
++EXPORT_SYMBOL vmlinux 0xcfdc9cd2	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0xd00b844e	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0xd01a91e8	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0xd04de212	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0xd059ba3f	dquot_alloc
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd08350fa	of_get_property
++EXPORT_SYMBOL vmlinux 0xd08f6239	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xd0905c9a	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0xd094748d	pci_restore_state
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0c05004	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0xd0d90f3f	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fef3b2	agp_free_key
++EXPORT_SYMBOL vmlinux 0xd107d190	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0xd117d51c	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0xd1201fad	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0xd1327a98	agp_generic_enable
++EXPORT_SYMBOL vmlinux 0xd141846b	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0xd1594cbf	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd1664f20	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xd1758b80	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0xd17b10e4	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd183bb18	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0xd187e337	udp_prot
++EXPORT_SYMBOL vmlinux 0xd1a5d8df	__genl_register_family
++EXPORT_SYMBOL vmlinux 0xd1a80cfc	of_get_mac_address
++EXPORT_SYMBOL vmlinux 0xd1b16f65	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0xd1d22a52	get_pci_dma_ops
++EXPORT_SYMBOL vmlinux 0xd1d62117	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd2197533	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd2599bbc	bdput
++EXPORT_SYMBOL vmlinux 0xd25b24cf	nd_btt_probe
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd26c692b	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0xd26d7d2f	vme_slot_num
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd28a6dac	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0xd2937aab	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0xd294537d	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0xd29b3de0	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0xd2b09ce5	__kmalloc
++EXPORT_SYMBOL vmlinux 0xd2c089a6	force_sig
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2df3aa5	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0xd2e40455	blk_rq_init
++EXPORT_SYMBOL vmlinux 0xd3084447	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0xd31ccb06	of_machine_is_compatible
++EXPORT_SYMBOL vmlinux 0xd3225a85	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0xd324b698	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0xd324f021	seq_escape
++EXPORT_SYMBOL vmlinux 0xd3434165	neigh_update
++EXPORT_SYMBOL vmlinux 0xd34b2376	cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0xd34c6ea6	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0xd360cb04	unregister_console
++EXPORT_SYMBOL vmlinux 0xd36e3d59	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0xd38d0cab	ilookup5
++EXPORT_SYMBOL vmlinux 0xd38f4281	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0xd3a08e7b	revert_creds
++EXPORT_SYMBOL vmlinux 0xd3aa8ab6	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0xd3bc3804	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3d86d9b	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0xd3e3b7cf	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0xd3e73968	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0xd4097cd8	security_file_permission
++EXPORT_SYMBOL vmlinux 0xd41a78f8	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0xd447cfb7	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0xd44832eb	powerpc_debugfs_root
++EXPORT_SYMBOL vmlinux 0xd44b7e21	to_tm
++EXPORT_SYMBOL vmlinux 0xd45cc6ca	bin2hex
++EXPORT_SYMBOL vmlinux 0xd46d4c8d	dm_register_target
++EXPORT_SYMBOL vmlinux 0xd470e65a	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0xd47f9f43	register_qdisc
++EXPORT_SYMBOL vmlinux 0xd4a22d3a	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xd4c36935	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0xd4d84a22	vme_irq_request
++EXPORT_SYMBOL vmlinux 0xd4e0d63e	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0xd50f1f9d	tty_name
++EXPORT_SYMBOL vmlinux 0xd529eb18	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0xd532f692	tc_classify
++EXPORT_SYMBOL vmlinux 0xd549c9b7	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0xd54b6b01	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0xd54c3550	phy_start
++EXPORT_SYMBOL vmlinux 0xd54c3db5	inet6_protos
++EXPORT_SYMBOL vmlinux 0xd54cfc42	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd562fff0	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0xd568be21	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd59ee454	d_tmpfile
++EXPORT_SYMBOL vmlinux 0xd5b9e1f8	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0xd5d09389	free_netdev
++EXPORT_SYMBOL vmlinux 0xd5d581a2	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0xd5f806ec	blk_finish_request
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd61e4aee	sock_no_listen
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd62c9648	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0xd63ba6f7	send_sig_info
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd6493d16	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0xd64cdf19	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0xd67be138	compat_ip_setsockopt
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd6a64e97	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0xd6cb3028	__invalidate_device
++EXPORT_SYMBOL vmlinux 0xd6cecffa	release_pages
++EXPORT_SYMBOL vmlinux 0xd6d63e9d	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0xd6e4d4ea	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd6fd4053	__arch_hweight32
++EXPORT_SYMBOL vmlinux 0xd6ffed5e	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0xd7021840	proc_set_user
++EXPORT_SYMBOL vmlinux 0xd717f8c4	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0xd7357b63	kfree_put_link
++EXPORT_SYMBOL vmlinux 0xd73e15ec	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0xd745194e	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0xd74cb6d7	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd761a383	ioremap_prot
++EXPORT_SYMBOL vmlinux 0xd7722f8e	kernel_connect
++EXPORT_SYMBOL vmlinux 0xd796dad8	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0xd7977270	kernel_write
++EXPORT_SYMBOL vmlinux 0xd7b118a9	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0xd7b6142a	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0xd7cdb482	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0xd7d2214b	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd7ee178a	clear_inode
++EXPORT_SYMBOL vmlinux 0xd7f0d1f8	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0xd7fef176	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xd80a59ee	proc_remove
++EXPORT_SYMBOL vmlinux 0xd80e0581	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0xd818ec5d	nd_region_release_lane
++EXPORT_SYMBOL vmlinux 0xd8259209	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0xd8269da3	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0xd83fd084	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0xd844caea	get_gendisk
++EXPORT_SYMBOL vmlinux 0xd84bbb90	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0xd8592d06	vfs_write
++EXPORT_SYMBOL vmlinux 0xd85a3909	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0xd86838a4	commit_creds
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a2933d	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0xd8a7777d	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8be67fe	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0xd8cbf342	pci_bus_type
++EXPORT_SYMBOL vmlinux 0xd8cc5cf4	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd8f0bd7e	backlight_force_update
++EXPORT_SYMBOL vmlinux 0xd9720b56	set_user_nice
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd99267c3	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0xd9990f61	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0xd9baa693	netlink_ack
++EXPORT_SYMBOL vmlinux 0xd9bac924	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0xd9c86478	fb_blank
++EXPORT_SYMBOL vmlinux 0xd9ce1a34	mmc_add_host
++EXPORT_SYMBOL vmlinux 0xd9cf1a39	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9ec5a3f	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0xd9f5443e	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0xda112a19	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0xda12e540	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0xda1ebe4d	netlink_unicast
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda64a08b	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xda72f442	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda7e4da8	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda9041f2	tso_count_descs
++EXPORT_SYMBOL vmlinux 0xda926c69	elevator_change
++EXPORT_SYMBOL vmlinux 0xda98db9f	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0xda9fc7ae	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0xdabc1ea8	fsl_lbc_find
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdac545b9	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0xdacd7ce3	vfs_read
++EXPORT_SYMBOL vmlinux 0xdad7adff	dqstats
++EXPORT_SYMBOL vmlinux 0xdad86aff	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0xdaea6e0d	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0xdaf3eef1	_dev_info
++EXPORT_SYMBOL vmlinux 0xdaf59af3	tcp_child_process
++EXPORT_SYMBOL vmlinux 0xdb01198e	fsl_upm_find
++EXPORT_SYMBOL vmlinux 0xdb2b3f67	mutex_trylock
++EXPORT_SYMBOL vmlinux 0xdb3bcca6	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0xdb4701f0	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb770190	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0xdb965bd8	dst_discard_out
++EXPORT_SYMBOL vmlinux 0xdba77a90	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0xdbbd3d2a	PDE_DATA
++EXPORT_SYMBOL vmlinux 0xdbbf8a6b	inet_sendpage
++EXPORT_SYMBOL vmlinux 0xdbcb9ee4	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0xdbf1320c	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc0b4e33	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0xdc0bde9e	keyring_clear
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc184545	fb_show_logo
++EXPORT_SYMBOL vmlinux 0xdc214961	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0xdc24b7b5	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0xdc29d412	mutex_lock
++EXPORT_SYMBOL vmlinux 0xdc315fc4	block_read_full_page
++EXPORT_SYMBOL vmlinux 0xdc34e454	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0xdc3c41a8	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdc789d60	blk_register_region
++EXPORT_SYMBOL vmlinux 0xdc8b33f4	key_unlink
++EXPORT_SYMBOL vmlinux 0xdc9498dd	down
++EXPORT_SYMBOL vmlinux 0xdc96805c	mount_bdev
++EXPORT_SYMBOL vmlinux 0xdc9ca7e8	eth_header_parse
++EXPORT_SYMBOL vmlinux 0xdca1b0d2	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0xdca63c21	agp_create_memory
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdcb764ad	memset
++EXPORT_SYMBOL vmlinux 0xdccbca69	inode_init_once
++EXPORT_SYMBOL vmlinux 0xdcf7873f	blk_run_queue
++EXPORT_SYMBOL vmlinux 0xdd0471ea	set_blocksize
++EXPORT_SYMBOL vmlinux 0xdd1c7343	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0xdd3a0013	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0xdd51147c	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0xdd553f89	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0xdd64e639	strscpy
++EXPORT_SYMBOL vmlinux 0xdd8c8510	load_nls
++EXPORT_SYMBOL vmlinux 0xdd9030af	current_stack_pointer
++EXPORT_SYMBOL vmlinux 0xdd955144	__debugger
++EXPORT_SYMBOL vmlinux 0xdda52594	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0xddb3769b	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0xddc7466c	set_cached_acl
++EXPORT_SYMBOL vmlinux 0xddcb284e	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0xdde6cec2	skb_insert
++EXPORT_SYMBOL vmlinux 0xddf555a8	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0xde25842e	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0xde48e9ca	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0xde5db213	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0xde6151db	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xde67182c	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xde91448c	load_vr_state
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde9b17ed	agp3_generic_fetch_size
++EXPORT_SYMBOL vmlinux 0xdebf6815	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0xdeccd72b	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0xdedcf090	phy_driver_register
++EXPORT_SYMBOL vmlinux 0xdedec247	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0xdf13e82f	unlock_buffer
++EXPORT_SYMBOL vmlinux 0xdf22a0a0	param_get_bool
++EXPORT_SYMBOL vmlinux 0xdf23ce40	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf3d15c4	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0xdf51d3a8	fb_set_var
++EXPORT_SYMBOL vmlinux 0xdf52461d	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf57c261	pid_task
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf8d2faf	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdf992740	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0xdf9f7188	sk_wait_data
++EXPORT_SYMBOL vmlinux 0xdfa74f4f	__dax_fault
++EXPORT_SYMBOL vmlinux 0xdfb34455	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0xdfcafa70	single_release
++EXPORT_SYMBOL vmlinux 0xdfd7f032	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0xdfddb43f	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0xdff09ae8	from_kgid
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xe004c16a	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0xe02c0aa9	__getblk_slow
++EXPORT_SYMBOL vmlinux 0xe0387266	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0xe04b6598	d_instantiate
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe053bed7	compat_ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0xe05cede1	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0xe05e4ed2	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe07442ea	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe07c872a	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0xe07cff32	pci_find_capability
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe09a636a	unlock_page
++EXPORT_SYMBOL vmlinux 0xe09c986b	bio_map_kern
++EXPORT_SYMBOL vmlinux 0xe09e4681	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0b2d599	drop_super
++EXPORT_SYMBOL vmlinux 0xe0bafa15	__inode_permission
++EXPORT_SYMBOL vmlinux 0xe0c97d27	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0xe0cd17b9	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0xe0e447c6	dcb_getapp
++EXPORT_SYMBOL vmlinux 0xe0e818c0	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0xe0e823b2	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe1195bed	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe13e29d3	md_flush_request
++EXPORT_SYMBOL vmlinux 0xe1414dd0	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0xe14f7ca7	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0xe15c9545	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0xe16146b2	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe18ecd61	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0xe1d1e92e	kdb_current_task
++EXPORT_SYMBOL vmlinux 0xe1e18cfd	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0xe1ffcf17	stop_tty
++EXPORT_SYMBOL vmlinux 0xe1ffdb99	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe20372ae	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0xe21f83c9	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0xe220ceb8	__debugger_sstep
++EXPORT_SYMBOL vmlinux 0xe2289f2b	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0xe22c9a78	of_clk_get
++EXPORT_SYMBOL vmlinux 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe2480ca9	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0xe24bbbb6	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe279713a	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2a88d92	seq_release_private
++EXPORT_SYMBOL vmlinux 0xe2ba3f91	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0xe2be5498	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0xe2cabdec	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2e3e5ea	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe30cb425	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0xe30d890a	__frontswap_store
++EXPORT_SYMBOL vmlinux 0xe317764d	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0xe32f83a9	is_nvdimm_bus_locked
++EXPORT_SYMBOL vmlinux 0xe3321b28	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0xe335672d	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0xe340b0f0	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0xe35c1893	da903x_query_status
++EXPORT_SYMBOL vmlinux 0xe37b99c4	elv_rb_del
++EXPORT_SYMBOL vmlinux 0xe386e80e	scsi_init_io
++EXPORT_SYMBOL vmlinux 0xe392fcc3	load_nls_default
++EXPORT_SYMBOL vmlinux 0xe399fb4b	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0xe3a53f4c	sort
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe423b682	of_gpio_simple_xlate
++EXPORT_SYMBOL vmlinux 0xe4318919	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0xe45cad60	tty_kref_put
++EXPORT_SYMBOL vmlinux 0xe473b916	get_phy_device
++EXPORT_SYMBOL vmlinux 0xe47b7e21	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0xe484e35f	ioread32
++EXPORT_SYMBOL vmlinux 0xe493492c	blk_peek_request
++EXPORT_SYMBOL vmlinux 0xe4b38bd5	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xe4bd9592	agp_backend_release
++EXPORT_SYMBOL vmlinux 0xe4bf360c	send_sig
++EXPORT_SYMBOL vmlinux 0xe4e25032	nf_log_set
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe4eaab2e	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0xe4eb146f	pci_iounmap
++EXPORT_SYMBOL vmlinux 0xe4fe8ca1	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xe51baae8	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe55b40c3	param_set_byte
++EXPORT_SYMBOL vmlinux 0xe56862ef	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0xe5693149	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0xe57849c8	abort_creds
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe58aadcc	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xe58b6d3e	compat_nf_setsockopt
++EXPORT_SYMBOL vmlinux 0xe58f8354	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0xe59ba173	sock_release
++EXPORT_SYMBOL vmlinux 0xe5a7d24c	serio_open
++EXPORT_SYMBOL vmlinux 0xe5a80db8	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0xe5a926e7	validate_sp
++EXPORT_SYMBOL vmlinux 0xe5c4f722	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5d81f13	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe61909c6	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0xe657bb8b	seq_pad
++EXPORT_SYMBOL vmlinux 0xe65a73d7	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xe66452ab	dql_init
++EXPORT_SYMBOL vmlinux 0xe666ed76	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0xe66d9f5f	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0xe6871115	of_mm_gpiochip_remove
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe698c4c3	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0xe69a9df4	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xe69db463	input_register_device
++EXPORT_SYMBOL vmlinux 0xe6a30b57	dquot_drop
++EXPORT_SYMBOL vmlinux 0xe6e46106	tcp_connect
++EXPORT_SYMBOL vmlinux 0xe6e670a3	inode_init_always
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe7056112	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0xe711b221	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0xe74ba8d3	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xe74c67bc	of_phy_find_device
++EXPORT_SYMBOL vmlinux 0xe7520877	audit_log
++EXPORT_SYMBOL vmlinux 0xe754f0f0	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0xe767a452	dm_io
++EXPORT_SYMBOL vmlinux 0xe787c24f	simple_statfs
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7bb76ef	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0xe7ce7439	_memcpy_fromio
++EXPORT_SYMBOL vmlinux 0xe7d14fe2	sock_register
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7fdafcb	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0xe8008f46	install_exec_creds
++EXPORT_SYMBOL vmlinux 0xe803f914	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0xe8130870	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xe81ef1dd	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe82b0d52	find_vma
++EXPORT_SYMBOL vmlinux 0xe848a39e	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0xe864588a	devm_clk_put
++EXPORT_SYMBOL vmlinux 0xe8911faa	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8c438f3	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0xe8ef0ff0	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0xe8f517b4	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0xe911089b	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe91f328d	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0xe9323ff2	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0xe932a536	generic_writepages
++EXPORT_SYMBOL vmlinux 0xe9378d58	idr_get_next
++EXPORT_SYMBOL vmlinux 0xe9525caf	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe96f5146	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0xe9751e99	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0xe97fc599	param_set_ulong
++EXPORT_SYMBOL vmlinux 0xe999c667	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0xe9a55391	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0xe9b748ee	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0xe9bea94d	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0xe9eaaeb8	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea05aaf0	is_nd_btt
++EXPORT_SYMBOL vmlinux 0xea2504ad	give_up_console
++EXPORT_SYMBOL vmlinux 0xea36aa94	file_path
++EXPORT_SYMBOL vmlinux 0xea52dba4	release_sock
++EXPORT_SYMBOL vmlinux 0xea64b513	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0xea76f3c5	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0xea7a42f9	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xea968c96	___ratelimit
++EXPORT_SYMBOL vmlinux 0xeaabab8f	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0xeaad3cdb	input_flush_device
++EXPORT_SYMBOL vmlinux 0xeac1228b	of_dev_get
++EXPORT_SYMBOL vmlinux 0xeac20a7d	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0xeacefca9	padata_free
++EXPORT_SYMBOL vmlinux 0xead5f5a5	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0xeae12787	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0xeae4ac7f	dst_init
++EXPORT_SYMBOL vmlinux 0xeaefc0c3	neigh_destroy
++EXPORT_SYMBOL vmlinux 0xeaf18c09	netdev_update_features
++EXPORT_SYMBOL vmlinux 0xeaf1b715	dquot_destroy
++EXPORT_SYMBOL vmlinux 0xeaf57396	uart_register_driver
++EXPORT_SYMBOL vmlinux 0xeaf84f86	nd_namespace_blk_validate
++EXPORT_SYMBOL vmlinux 0xeafb7919	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb44339a	free_pages_exact
++EXPORT_SYMBOL vmlinux 0xeb6cd726	param_set_short
++EXPORT_SYMBOL vmlinux 0xeb876c66	simple_write_begin
++EXPORT_SYMBOL vmlinux 0xeb884083	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0xeba9a656	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0xebdeade4	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xebfa7315	submit_bio
++EXPORT_SYMBOL vmlinux 0xebfb0294	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0xec0da47c	scsi_add_device
++EXPORT_SYMBOL vmlinux 0xec12e374	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0xec205c12	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec50ba79	path_put
++EXPORT_SYMBOL vmlinux 0xec6d2ea8	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0xec7c19c4	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0xec7d0c1b	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xec8c16b0	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0xecaa02f8	tty_do_resize
++EXPORT_SYMBOL vmlinux 0xecb3b60d	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0xecbb926f	xor_altivec_3
++EXPORT_SYMBOL vmlinux 0xecc869d3	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0xecd47d69	of_translate_address
++EXPORT_SYMBOL vmlinux 0xecd982a2	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xecf8bd86	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0xecf98d2f	contig_page_data
++EXPORT_SYMBOL vmlinux 0xecfcad3e	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xed0233fc	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0xed09902a	nvdimm_namespace_disk_name
++EXPORT_SYMBOL vmlinux 0xed102a6a	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0xed159ba2	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0xed1d9a81	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0xed3845cc	of_count_phandle_with_args
++EXPORT_SYMBOL vmlinux 0xed47a373	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0xed57be9f	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed70e2d2	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0xed776fa7	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xed8e3a25	of_iomap
++EXPORT_SYMBOL vmlinux 0xed9be880	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedc410d0	udplite_table
++EXPORT_SYMBOL vmlinux 0xedf26869	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xedfd5bb9	simple_rename
++EXPORT_SYMBOL vmlinux 0xee1ebeec	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0xee1f58bb	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee2fc9d1	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0xee3e5e4e	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xee4ad063	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0xee5b2e59	pci_set_master
++EXPORT_SYMBOL vmlinux 0xee684b7f	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0xee6b27a2	of_translate_dma_address
++EXPORT_SYMBOL vmlinux 0xee6b80b7	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0xee7c6721	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xeea3cd7a	nla_reserve
++EXPORT_SYMBOL vmlinux 0xeea99080	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeec8cbb8	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0xeed5775a	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0xeed80043	lro_flush_all
++EXPORT_SYMBOL vmlinux 0xeee5c14d	inet_addr_type
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xef0c5d92	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0xef0cb8e3	of_get_pci_address
++EXPORT_SYMBOL vmlinux 0xef108c90	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0xef2a8eb0	key_task_permission
++EXPORT_SYMBOL vmlinux 0xef358565	key_validate
++EXPORT_SYMBOL vmlinux 0xef5476de	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0xef761412	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0xef9abd08	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefde1bbe	flush_dcache_range
++EXPORT_SYMBOL vmlinux 0xefeb4fa1	param_set_bool
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf00d3964	dev_uc_init
++EXPORT_SYMBOL vmlinux 0xf017e6d3	kern_unmount
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf032b0a4	seq_release
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf063097d	__serio_register_port
++EXPORT_SYMBOL vmlinux 0xf065f629	ioread16be
++EXPORT_SYMBOL vmlinux 0xf07fe9a0	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0xf087d8f7	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0a8237a	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xf0b22f50	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0xf0d77351	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf0f46ddd	prepare_binprm
++EXPORT_SYMBOL vmlinux 0xf0f47d25	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0xf0fc857e	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf10de535	ioread8
++EXPORT_SYMBOL vmlinux 0xf1122bf0	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0xf11cd6ce	down_interruptible
++EXPORT_SYMBOL vmlinux 0xf144b152	textsearch_register
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf153df1d	dump_skip
++EXPORT_SYMBOL vmlinux 0xf15afdaf	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0xf178299a	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0xf183189b	__ioremap_at
++EXPORT_SYMBOL vmlinux 0xf183a03f	kill_pgrp
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf1b8c805	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xf1b923ef	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0xf1bac0cb	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1e91df9	of_n_size_cells
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1f25419	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf217726d	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0xf21a19a8	of_find_property
++EXPORT_SYMBOL vmlinux 0xf221f13d	arp_xmit
++EXPORT_SYMBOL vmlinux 0xf22881e8	lg_local_lock
++EXPORT_SYMBOL vmlinux 0xf22b2208	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf249fa5b	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0xf24d535f	mdiobus_read
++EXPORT_SYMBOL vmlinux 0xf257f362	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0xf25b74ca	make_bad_inode
++EXPORT_SYMBOL vmlinux 0xf25ccdad	param_get_invbool
++EXPORT_SYMBOL vmlinux 0xf269e1a4	generic_fillattr
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2a2b163	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2d08a2a	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0xf2e9f34f	inet_release
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf317b72b	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0xf31b5ff0	filemap_fault
++EXPORT_SYMBOL vmlinux 0xf31d1b1d	pci_release_regions
++EXPORT_SYMBOL vmlinux 0xf322a206	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf3660ec7	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0xf36ef088	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0xf389407d	phy_connect
++EXPORT_SYMBOL vmlinux 0xf389cf75	of_find_compatible_node
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf38d98c2	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0xf390e18e	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf3cc296f	of_n_addr_cells
++EXPORT_SYMBOL vmlinux 0xf3dd0f9f	get_empty_filp
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf3f2122a	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0xf3f97824	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0xf3fa689e	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0xf4047acd	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0xf40cb302	fsync_bdev
++EXPORT_SYMBOL vmlinux 0xf40dcbb4	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0xf40f19e7	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0xf418700a	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0xf441ac43	ioread8_rep
++EXPORT_SYMBOL vmlinux 0xf447dad6	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0xf44e4e68	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf47969fc	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0xf47a7b3d	netdev_crit
++EXPORT_SYMBOL vmlinux 0xf47b068e	sock_edemux
++EXPORT_SYMBOL vmlinux 0xf481dde2	__init_rwsem
++EXPORT_SYMBOL vmlinux 0xf494d308	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0xf4a4365d	bio_copy_data
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4c59bdd	register_quota_format
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf51ae235	touch_nmi_watchdog
++EXPORT_SYMBOL vmlinux 0xf51bf88b	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xf5222143	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xf525cb54	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0xf5289d38	of_io_request_and_map
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf54194d5	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xf542aac1	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0xf54e0e72	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0xf55b3b3d	__arch_hweight16
++EXPORT_SYMBOL vmlinux 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL vmlinux 0xf5a62ecc	_memset_io
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5e1558d	crash_shutdown_unregister
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf6110ea5	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0xf61209a6	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0xf62426b6	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0xf6309fcc	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf67247de	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf68720b4	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6c86ce1	redraw_screen
++EXPORT_SYMBOL vmlinux 0xf6dac2a9	acl_by_type
++EXPORT_SYMBOL vmlinux 0xf6e00d7f	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6ee5117	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0xf6ee87cb	write_cache_pages
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf70ca2ae	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0xf71656bf	nobh_writepage
++EXPORT_SYMBOL vmlinux 0xf735549a	single_open
++EXPORT_SYMBOL vmlinux 0xf74d3b61	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0xf7526475	pci_request_regions
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf7722c38	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0xf78cbf12	param_get_int
++EXPORT_SYMBOL vmlinux 0xf7935f14	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xf79638fd	agp_generic_insert_memory
++EXPORT_SYMBOL vmlinux 0xf798753d	d_splice_alias
++EXPORT_SYMBOL vmlinux 0xf798a54f	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0xf7b68700	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xf7c318bb	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0xf7cdc736	clkdev_add
++EXPORT_SYMBOL vmlinux 0xf7d7e42c	km_state_expired
++EXPORT_SYMBOL vmlinux 0xf7eec077	lock_rename
++EXPORT_SYMBOL vmlinux 0xf7f1dc6d	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0xf806bf86	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0xf806f0f7	eth_header_cache
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf812cff6	memscan
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf839f98e	dm_get_device
++EXPORT_SYMBOL vmlinux 0xf8538ff4	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0xf8588e32	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0xf8671c4b	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0xf869f9f3	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0xf879769a	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0xf8a2997e	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0xf8c53f38	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0xf8d04f09	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0xf8e2dacb	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf9228003	get_immrbase
++EXPORT_SYMBOL vmlinux 0xf924250c	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0xf93601b1	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0xf9557da9	wake_up_process
++EXPORT_SYMBOL vmlinux 0xf95690e7	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0xf97d2b20	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0xf9862e58	security_path_mknod
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9c0b663	strlcat
++EXPORT_SYMBOL vmlinux 0xf9cbf3a0	unregister_netdev
++EXPORT_SYMBOL vmlinux 0xf9d1b31d	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0xf9efbc98	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0xf9f9f729	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0xfa1bc202	dquot_resume
++EXPORT_SYMBOL vmlinux 0xfa32f2f7	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0xfa38c876	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa9a7b15	of_cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0xfaafaa9f	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0xfab5f66d	do_splice_direct
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfb0414c3	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0xfb0bfaee	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xfb1b0847	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0xfb51cc1d	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0xfb5aa6c5	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0xfb5c80f0	key_revoke
++EXPORT_SYMBOL vmlinux 0xfb5cf1cb	migrate_page
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb76e28f	elv_rb_add
++EXPORT_SYMBOL vmlinux 0xfb7cf297	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0xfb905cdf	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0xfb929950	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfba1ba31	tty_write_room
++EXPORT_SYMBOL vmlinux 0xfba1ebe6	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0xfba713bb	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbb118c1	vfs_statfs
++EXPORT_SYMBOL vmlinux 0xfbbbb237	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0xfbc1cd0e	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbea40d1	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0xfc003de3	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc07a77a	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xfc2ecd10	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc3b160f	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xfc6c9e80	fb_pan_display
++EXPORT_SYMBOL vmlinux 0xfc73b294	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xfcaf6cdf	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0xfcb926cd	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfccc2e4f	__elv_add_request
++EXPORT_SYMBOL vmlinux 0xfccf50d3	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0xfcd682ed	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcf0e799	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0xfcf2771c	phy_attach
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfd0e9457	security_path_unlink
++EXPORT_SYMBOL vmlinux 0xfd11dbe0	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0xfd205443	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0xfd28e5c3	devm_clk_get
++EXPORT_SYMBOL vmlinux 0xfd3e1b38	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xfd4cf796	tcf_em_register
++EXPORT_SYMBOL vmlinux 0xfd4e99d4	eth_type_trans
++EXPORT_SYMBOL vmlinux 0xfd63019d	of_get_child_by_name
++EXPORT_SYMBOL vmlinux 0xfd77f043	nobh_write_end
++EXPORT_SYMBOL vmlinux 0xfd81863c	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfdb6cedc	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0xfdb9b629	ioread32be
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfdbeefbf	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0xfded48ed	enable_kernel_fp
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfdfc7956	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0xfe01427f	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0xfe014bad	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe10e1aa	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0xfe17047b	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xfe1db814	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xfe35aa4a	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0xfe4555cd	sock_no_poll
++EXPORT_SYMBOL vmlinux 0xfe510e03	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe61de0d	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe890b30	put_io_context
++EXPORT_SYMBOL vmlinux 0xfe8ffc59	netif_device_attach
++EXPORT_SYMBOL vmlinux 0xfe916dc6	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xfea27345	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0xfedcd0d6	current_fs_time
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfee1453b	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0xfee4c81f	led_update_brightness
++EXPORT_SYMBOL vmlinux 0xfee8b9ea	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0xfeebc7c4	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0xfef84ce0	km_is_alive
++EXPORT_SYMBOL vmlinux 0xff0bd1a7	km_new_mapping
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff26a018	vme_lm_request
++EXPORT_SYMBOL vmlinux 0xff2b488e	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0xff30e54e	of_clk_get_by_name
++EXPORT_SYMBOL vmlinux 0xff3a6d0d	noop_llseek
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff9858a3	km_policy_expired
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffa8df0b	setup_new_exec
++EXPORT_SYMBOL vmlinux 0xffb407fb	___pskb_trim
++EXPORT_SYMBOL vmlinux 0xffcc4055	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffdc51f1	of_get_cpu_node
++EXPORT_SYMBOL vmlinux 0xffe720ef	napi_disable
++EXPORT_SYMBOL vmlinux 0xffff6444	ip_cmsg_recv_offset
++EXPORT_SYMBOL_GPL crypto/af_alg 0x0e268559	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x186bb72e	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x24423869	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0x387899eb	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0x58716898	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0x7328c4f4	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0x8899c71c	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xa633f216	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xafc891df	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0xc2157767	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xd696085a	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x8046a3da	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x1482f04e	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x707d5d5c	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x806321ce	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0xd5271ccd	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x02f85a63	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x8b14997c	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xaf1a20e4	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xf4bb15fb	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x29875e02	async_xor_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0xf04bf025	async_xor
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x23cfac9b	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x43335050	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x54ac6ce3	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x53fa9466	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x75dde7d3	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/cryptd 0x775eaeaa	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x7a0442c5	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x92cb7248	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x95872257	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x9cae44c2	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xb292da68	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xb94cbf5c	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0xe1be096c	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xece707ea	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xfe9a1bc5	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0x8c3ed2ae	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x1a69c1b7	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x61b92915	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x8347667c	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xb58393b7	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xd81222d3	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xd8ca8f7e	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xe6c5eae3	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xfb8df02c	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xfd602a0c	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x1e40baa3	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x54aea64c	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x94700a77	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x9f665534	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0xb4b5eced	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x49146bdc	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0xc63ca27a	xts_crypt
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x2a0ac225	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x6231d7a1	ahci_qc_issue
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x684ed721	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x7c3c93d6	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8cc3444e	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8f7b62a6	ahci_host_activate
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x9ae446eb	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x9f68d3f2	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa2e3c977	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa368a2ab	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa883fcbd	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xb0cf582c	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xb193a1cd	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xb7e2c417	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc4fc0576	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xd3bf2a56	ahci_error_handler
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xd5e02a27	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe204e3ef	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe366504b	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf5b6d8b7	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf8111fad	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xfadde3e1	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xfd9625c9	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x0ffcba36	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x1a7057c0	ahci_platform_init_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x5cef1681	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x6803b3eb	ahci_platform_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x6ecf926e	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x80ddfcc9	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x8b46e54b	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x9a4e7c4b	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xf0316f8f	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0x35794d37	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/ata/pata_sis 0x14e49799	sis_info133_for_sata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x4dc55b9e	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x62a170ae	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xb878e784	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xf4eaa1f5	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x05bb9fd9	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x0ab4baca	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x13364a76	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1df2a0ba	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x24c3a259	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x36247d5a	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x455864bd	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x4b76a79a	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x4dfb50f1	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6dfc1048	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x865292e9	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xa8fbc36d	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb8775107	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc8434828	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xcfff5f7f	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd6bc0dd6	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd9c8496c	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdf0b79d2	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdf3bfd7d	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe9a2e70c	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xee342043	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xef41bea0	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf5ca0244	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xfd9efc7b	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x038d563b	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x2d10bb59	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x60fbf55e	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xaef21545	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xb94449c3	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xff421d6e	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x17824eca	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x18c14b3c	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x1f2c4156	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x5d97f3fb	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x67661a8d	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x7afd7051	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x7c3a3426	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x86fed0a8	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xc0b03ce3	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xcddf4da2	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xee4069d0	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xff7c8215	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x1c5ab4b4	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x6a28c20c	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x94e6e3a7	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xa1c02602	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xb76743da	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xb9fbc868	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xcc8cf523	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xd67fc42f	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xdac3bf21	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xe02ec87e	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xf3a47a3b	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x7df9aa38	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0xadbd27e4	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0x636c0dff	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0x801cba1f	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x15aabff3	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x57c6b089	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x594bea9e	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xdcd0fff0	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xdf3bf653	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/fsldma 0xcd3b0bce	fsl_dma_external_start
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x0395dad1	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x2d01ca3f	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x9be19602	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x52303458	vchan_init
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x7463b37a	vchan_tx_submit
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x77a30e9c	vchan_find_desc
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x94f3143b	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x18363360	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2b5e924b	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8e8f53	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x346a381e	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3abfbbe1	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4584f2b1	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4a9c53a1	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4ef5d4db	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6dcb05b5	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x70d5495a	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x71eab98e	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7fae3d70	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7fce5221	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x85f2037f	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x897e78ec	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x8a0eddb8	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa786c970	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd4ef1111	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xdd583ab9	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe60a8117	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf1b04f2a	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf52222ad	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf7d10d38	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x282b16c0	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x4b510288	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xa954b2dd	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xd3e8a40a	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xf1727389	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xfa5c017d	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x07a1b6ca	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0xe1164ff5	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x74e1ed50	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0xadadee07	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x0acc61ef	drm_display_mode_from_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x173edb15	drm_display_mode_to_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x2b81fba3	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x2c25e203	of_get_drm_display_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x9b282086	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xd881ba7f	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6abfac69	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xc993dc32	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xd2d0d545	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0bb6ad83	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x1e2c971e	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x25bc426b	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2946f02e	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2a4907f3	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2b6d21aa	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x31cb599b	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x341a3fe5	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3c28087e	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3d125940	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4abecea9	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4bc354d4	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4c23f70f	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5080ae25	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5364a621	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5c33e28d	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6d3665d7	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7fb89a03	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x88b3219a	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x92c14700	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9a1795ad	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9a76a18f	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa7bf951c	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa9afaed1	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xae32472c	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc02fd9ba	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc2a20bb7	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc4075473	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xce942f94	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd127fcaf	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd50d1992	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd6370045	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xdbb6f2b4	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe58b42b2	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe76d6351	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfb5a00bc	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x624c86f1	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x1a0d2f52	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x22d44574	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x3d7ac226	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x3faa94e6	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x7a84c748	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xcc9b6a25	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x2aa8748f	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x49659b1b	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x5f56401f	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xc1e5d40b	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xd0239846	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xe38ec15e	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xe4eed22d	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xea8387d9	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xeae17cf4	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x1ae42b9d	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x09f5ba1e	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x12155581	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x27f3569b	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x325a06c3	hsi_add_clients_from_dt
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x331c4282	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x38d359ba	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x3c9e0306	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x40344f7d	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x41a0706f	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x6b701c3d	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x6c71f3ce	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x794aa7a4	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc6aa20f2	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc7f351e1	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xddf0c5b6	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xdf0437f1	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe1636282	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf4ebf63e	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x309eb2ab	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xdf9dd44f	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x1f782fc6	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x2a21dc79	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x385506c2	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x572f7877	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x5e85e49a	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x6a67d65e	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x81d6fc28	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x933c8890	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xa5f5bde0	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xc46aeb0b	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xc5a43fd8	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xcd7a97b9	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xdb5e5444	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xef0a52a1	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf15fc763	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x43e2cbad	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x49598c8f	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x94576d72	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x9fc43752	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xbf45f0b3	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xde114da7	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xf0bb9919	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x430a1113	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x66c5b4fb	stm_source_write
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xd6a2f44d	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xeee4c1f2	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xf78b300e	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x03c23eb5	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x41a45b4d	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xd388e164	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xdcda8073	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xfbaf82e9	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x429783c3	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xeca8684b	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x33a992f1	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xbea67fe5	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x148f90b5	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xe5f5d301	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xfe66402a	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x11ded283	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x22c328e9	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x26576abb	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x3353dcca	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x7ef647e5	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x92e25cc0	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x9a3622ec	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xa10c04e6	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xd412ecd9	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xe6d49b64	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x3932e3cf	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x49db116a	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0x5f864b18	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xf20f2e43	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xbcc19761	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xd7fc219d	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xf09935e7	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x015aa2a6	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x0cb253a8	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x4ac6c89a	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x7e631a05	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x8eb4c593	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x959865e0	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xa9325a7b	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xb64e3d68	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xbe1fb39f	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xc9b30782	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xcdc073ec	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xddb1a98f	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x05496066	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0dd71c6f	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2468a3b5	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2e507a26	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3071814b	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3979f725	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3e12248c	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x41d7705f	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x430289bc	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x43a9c38c	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x461a88bb	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4bd3dfd4	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4d95c7aa	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5d7efc71	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5e7cf9a8	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x61e9df7f	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x65c95309	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x69b60766	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7ab936e6	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x869e8f1d	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x8eb7e3b1	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9557c979	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa249946b	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb34b758d	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb371c95e	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb7c9e491	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xba0c58ef	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xbbcab51c	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xcc4927bb	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd172e2b9	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe7dacbc6	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0x2602b6ec	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/matrix-keymap 0x2a829e93	matrix_keypad_parse_of_params
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x0d499d7f	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x5b7f2829	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xb4ee4438	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xf84c8421	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xb19da883	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xcf837881	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xdccd1512	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x63bb1ab2	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x8187cef9	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x0a84f420	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x220c9479	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x406e88b8	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xae12be97	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x22357bcd	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x2a8d8c23	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x3bd3c347	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x49247107	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x5e1e3dfb	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x626158be	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xa6848fee	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xaecb5820	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xb137bc8a	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xb375457a	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xb95cfcac	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xdc8568c9	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x0be7bc26	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x1da0032a	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x45b12d36	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x471a45aa	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x542a358f	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x5f9007ec	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x70a10d82	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xac3bb46d	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xd41ce68c	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x029b10c3	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x23fa66db	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x26ddd825	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x2cb32107	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x3dad45fd	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x472a2264	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x4870f623	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x5a17c3cb	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x83effd11	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x96148479	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa3151853	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa626abc5	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc2375e64	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xdc746d0f	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xe102e3b0	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xf62cd3d5	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xfc28e016	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xff1f7a10	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x273efbfa	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x3ee16e59	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x497c34c3	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x90ef5d6b	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xde936bee	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xec1f9adf	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x18538ff8	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x1cc12e84	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x2a852641	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x4208d6dd	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x74f6eaa2	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x7632571f	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x78161c64	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x781eec51	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xcdd781d3	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xcfc1bad0	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xf689990b	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x0a0527be	wf_register_client
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x3c4529e0	wf_put_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x3e7bea1f	wf_register_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x5b2d2a83	wf_register_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x5fd12608	wf_unregister_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x75147afa	wf_set_overtemp
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x7b6798ac	wf_put_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xa54e7114	wf_get_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xa83d3bd8	wf_unregister_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xb4009da7	wf_get_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xbcace2a5	wf_unregister_client
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xed82a14f	wf_clear_overtemp
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x009c53ed	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x0e1b6928	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x16e8cda6	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x47b549a3	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x5a854272	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x5e16ba04	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8bf52ac0	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x91c9a956	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x961adf20	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x9d5e4964	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc190b228	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc8640d7d	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xe0dded7b	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xe486a57a	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x021811cf	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x0f0677b8	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x10e6a889	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1154f7a1	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x15aa8e40	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x174c2a29	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2205bcf9	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3fc7cb7f	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x469f38de	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4ba51ecf	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5b2a89c7	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5d950f2a	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5e21030c	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5ed04550	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6eef9654	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x74ab7b0f	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x84efb763	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8fe32879	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x91f02667	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x93f7fc02	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa1de5277	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa81bf581	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb7d964de	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbbace2cd	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc6673631	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc8a2f711	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe3de2ba2	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe902838d	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xec919105	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xeea27f46	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfad1ec73	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x0e9ee07a	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x1c0f6b6b	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x830ba6ea	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x8e9384d0	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xa279041d	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xc2f1d9f9	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xcab04bef	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xe0e509d0	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xfefaccc7	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x36021fa0	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6aba7f5e	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9310ba06	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9c256008	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa1d2413a	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa448e19f	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xafbda3f3	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xcbb1bae2	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x38aeb423	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x785c08e3	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xad07e161	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xaef87e99	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xaf1247c0	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xb342a9aa	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xedf16f0b	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x21bf81b1	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x758b5e8d	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4430764e	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x45ab972a	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4edd6e1c	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x50c09dff	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x5651a14b	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x5fb7dd15	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x64cbf6a4	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa68e1f06	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf5de93d6	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfad9d53a	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfc62ef4e	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x17c36f29	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x346f8903	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42dbdfc3	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x49b35849	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x55b4bd4d	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x827a42f4	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9f624559	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xafeda29f	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd29923fb	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf375d009	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf5455120	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x3981e906	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x419beec8	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x53b59811	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x6ea46f07	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x71cc4e9b	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xaf0ecefa	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xbdde5e1c	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xbe995f90	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xc468e619	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xd6743a27	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x0615f76a	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x0cceb3dc	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x3fc65296	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x5d816742	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x8d0da743	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xb6027d23	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xe9f1632f	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x088d4bba	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x09054a20	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x0914dd4d	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x15beeb87	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21359ad7	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x293a1a13	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x2d81af2a	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x3f015dec	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x4a261bc7	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x5b624d5e	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x5c841804	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7f750ee7	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x8ac240d3	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x99a81ab3	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9d9252d9	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xa01b3c9c	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xad9966e1	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xf96827d2	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0x3ce9bcd3	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0xe305882f	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0xb74138ac	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x03759d48	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0x090bb403	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x0b8149c9	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x2ec03422	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/media 0x3016fbe6	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/media 0x3ca8c11a	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0x4026038c	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/media 0x4a98e800	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x50ab2a38	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0x57b43716	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/media 0x634233fd	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x7efab900	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0x806f4e09	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x8503e80b	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x91627061	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0xd5fd0549	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0xe14619be	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0xf9def49a	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0x3155aac1	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x05dcb8b0	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x208898b0	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x2bd6f8ed	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x2e380bba	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x38d34144	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x4a5ca1bd	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x4db5e157	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x55758e24	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x6456e1e0	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x7180c158	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x86972681	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x8853a3a5	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x900d27e1	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x900d653e	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x9b4c6ea6	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb5462efb	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xbcaefb6c	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd0168b76	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd28d6313	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0293c47d	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x04ce41a5	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x06c0c648	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x1b0dd53d	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x1ca44dc9	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x26eaae4c	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x2879c2fa	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x3cafba7a	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x4a6dd705	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x58cb261a	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x5ccc1d44	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x7e505b19	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa4889028	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xabdc408e	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xba802a03	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc7beb48a	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc8b498f7	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xddb9029e	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xe2d2e99b	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x748eed9a	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x89a198e0	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x8ea6ff02	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xb205ebb0	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xcd037760	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xe3b45e66	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xef9cb2f6	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x0b2585ce	xvip_get_format_by_fourcc
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x220bb2b8	xvip_enum_mbus_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x31e41111	xvip_cleanup_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x3c7eb685	xvip_set_format_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x417c37ce	xvip_clr_and_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x490bd11c	xvip_get_format_by_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x4b277b88	xvip_clr_or_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x57c1e9ea	xvip_init_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x90bb10b4	xvip_enum_frame_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xa23f3a30	xvip_of_get_format
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x3c16a6b1	xvtc_generator_stop
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x47d7900b	xvtc_generator_start
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x8dc87ff2	xvtc_of_get
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0xa8a0f912	xvtc_put
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x9b73b6be	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0xc3403957	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x03dc6149	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x0c1c970b	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x1547aa5a	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x2fe008b4	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x31789aad	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x3530448b	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x56eabcd1	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x6159adcf	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x888f9776	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9ed51e5c	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa53fde13	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa8c3d59a	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa934df42	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb75ce1db	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb875c9ee	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc2fc8427	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc60e2e9e	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xe7e88e0d	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xfd680863	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0xecc338fa	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0xe2cf25fc	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0x8c05aec8	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0xf8617bd4	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0x4b6ba360	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0xe78c03ad	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x661f8fec	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x6d7bfffc	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0xc2d92aa9	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x62244bd0	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x6571d168	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x259a3a60	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x8baae18e	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0xaee7b303	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x20f5e304	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x3a3da25a	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x54f6b115	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x56d1a5e4	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x57607545	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x62c1b95e	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6d11d6d8	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x7a690ab6	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8df120ff	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x9fe078eb	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa4723283	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xbffce30f	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd6afd8a4	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xdfaeb7a0	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe013747e	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe1f4b187	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe5adda3a	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf41cf03b	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf92844e7	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xfb6378c1	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0x20a0e4f0	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x26815f77	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x06eef88e	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x070fb0f6	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x0e2a7cfe	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2bd69974	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3789846c	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x48b9eeb0	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x54dadd8f	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x85eae5a7	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x8f1b32b5	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x97eb69d9	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcaee96e0	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcc2d99f2	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd256e4d	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xd7995f11	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xdc4239b8	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xdf748bbd	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xef7040ce	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xf5421c64	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x466195fb	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x5b1f653f	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xa7ac3d88	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xc48c3b04	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x2a196071	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x96e05807	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xae5a69ed	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xceccf908	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xced02ca6	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xd848a9e1	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x6fed6d7c	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0xdf4ab7ee	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1635069e	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x18772c33	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1a38f77a	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1f5f8702	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x330be69c	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x42f1cc5c	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x438e0cf8	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x43f5f239	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x48ad3035	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x5fa4e177	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x634fc28f	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6c569816	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x727e649d	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7bea0d8d	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7e1b5ddc	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7e67042e	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x801229dd	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x8a486ebc	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x8b34bbf4	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9a61d54f	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xaa1e5cd3	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xaec23b00	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xbbe4808b	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd5d5ed0c	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd90a1811	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xec4d7fc5	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf33dfb88	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x19bc35bd	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x1f8687a5	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x22d14bbd	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x29903cb3	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x2b584bee	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3003bbc8	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x301a700c	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x32375bf9	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x33d31e08	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x36410f86	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x366696d8	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4eb152a3	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x66744405	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x68ce5259	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x70eb7d59	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x7529bb47	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8f8b0270	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x913e1e44	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa2ae63ae	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xab310580	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xc568a398	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xc8c415e2	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xcac7f6a9	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xee8269f7	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x553a86d0	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x6a5896ff	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x7faafc22	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x8c17b0fe	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xc083a363	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x1d0ec2bb	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x9537a01f	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xe826e1d6	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x08c11da4	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0cd80bc4	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x176ae7a0	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2aefb2d7	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2f6acefc	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x3d2d6de9	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x46df5627	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x6a827e08	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x6b03721f	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x78c7b7b5	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x88f325d3	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xb340f3b9	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xb6a462c7	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xb894f928	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xca58568f	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xcc3b7d01	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd8bfffb4	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf1014b01	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x82bba0b5	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x97b2091a	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x4b1c9475	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xf32fa811	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x8d31d987	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x08e62b47	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x11f83694	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1cecfc15	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1d142dc1	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1fe09b63	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x28c9927a	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x375bc931	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x4b972729	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x540cc6c4	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5dbba1bd	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x682ebc72	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8c39451f	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x9098f091	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x939e39db	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa1b37c08	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa2f83959	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb208db3b	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xbc657c59	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xbf388953	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xbfb7dd29	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc0d9454b	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xcde983eb	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xceb92bc8	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xd162a843	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xdb866d1b	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xde8ead27	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xe64e4d97	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xeb845dbc	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf1512197	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf327e6b5	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xfa1b512c	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xfb1b96a1	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x59f9e31a	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0bbcc7a4	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0ea37204	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0f34e968	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x133adfc4	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x170884bb	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x18770cb1	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1de59c61	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1ef3a428	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x205dabf3	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x22cb44d6	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x22e6cc24	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x28f9f67a	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2ab9d732	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x39ddad8e	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x404f8418	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4e73fa8d	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x57519190	v4l2_compat_ioctl32
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5e34438d	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x646ee8b2	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x688306c5	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x74a017c5	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x760e6e35	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7bfda7d4	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7d50337b	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7ed41cc8	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8b0f3cdb	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x956070e4	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9715440c	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9d3ae16f	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xaca2544a	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xaf9bd875	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xbf3febf1	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc6429d8b	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xdc1cf320	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf3ef3936	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf44bb709	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xfcb947ae	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x220341a8	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x457ea84d	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x9acc7d28	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x1dd0204a	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x31f992a3	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x8ebf33d3	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x8f47a24b	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xb9fc2cd3	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xc9a375f0	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xe90fc10f	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x2d27769e	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x3377ceac	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x3d441a27	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x3ddc0f5c	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x564a8b03	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x6f5d93af	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xa0533a70	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xd3797932	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x279faa04	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x4a29a693	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x77b8bca0	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x1bb45f33	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x1c87f439	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x24e8e2e2	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x316c8f15	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x9a7b4f86	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xd2378d18	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xd8a8ee12	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x7b458a8d	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x7b468fc9	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xff9e7729	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x83f42246	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x8c0cbb83	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x91fbd72e	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xc34e6966	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xc7d8834e	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xce7690fa	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x008281e7	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x118e7d3c	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x2d5b10fd	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x858bc3ac	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x913a13b7	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xaab2f0fa	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xb333811b	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xc9c7cb64	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xd699f7b8	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xd86cb838	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xfeb522b6	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xdf6e623c	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xe6358e0e	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x2c4c9d5a	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x37b01892	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x3a241c3a	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x9b18ae8e	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xe5ea6fc8	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0457db71	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x1a445ea4	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x29140546	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x2afdcdbd	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x383ef790	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3a1f59f3	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x55f6984a	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x567bb044	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x5f3e1498	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x6665d3e6	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x7f9dbfb0	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x91e32cf4	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x95fc31cb	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9bc11bef	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa99870b5	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb3285778	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb4675057	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb4d43ab5	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb7274740	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb79daaaf	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xc845d1c2	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd0d24f88	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd1abb23c	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xdc784502	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x1b11a490	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x23c77071	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x4defa71a	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x68e5d88f	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x7d754e76	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x8cb98e65	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x9c1f319d	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xa1648394	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xa2863783	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xad6602d4	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xcaa4c757	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xea2d0762	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xffd18c01	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x15323928	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1b4da9a0	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x25a4aa24	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x35fe1661	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3ba21dd8	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3eebe93f	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x55a17df6	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5bd0c19e	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5ce86750	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6147c9d3	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6b9223ad	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6fc17aab	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x72e8b102	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x72ed7e70	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x77036b53	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7f5a6cb6	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x859bbb12	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x88387888	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8b797db2	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9e06627c	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa2ff91a4	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa3eb3fd0	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa771fed1	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xae041bb8	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xba8ef127	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc8426d42	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xcf1aea45	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd1d2f6bc	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xdbf5b7b8	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe338e82e	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf1bb441a	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfa799215	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfb999387	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xff7c2a70	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x10953dc5	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x3054025e	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x8c5b2d1f	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x8d69a2f3	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xc55004b5	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x287953f0	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x3fc5d72d	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x5a47b671	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x5f6b195d	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x691663c2	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x8a8462bb	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x94fb98f9	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xe87bcd64	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0xe5608b13	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x035ffe01	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x408388d7	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x7fbc1812	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xe980f04f	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x3c20b33e	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xba0fbe33	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xd6912828	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xf2abc71a	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x0dbd5fdb	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x17cdf005	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x5862c326	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x6d2fae89	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x8b8d0691	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xae78e74b	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xc437977e	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xc8c3509c	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x798d984a	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x9ab9b3f1	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x9fb79dd3	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xe33ee6f9	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xe4338706	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xe708fc20	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xee8e3f91	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xf51f3162	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x95ea0797	st_register
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xbe92fb75	st_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x00b24afa	sdhci_reset
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x52e0666b	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x560da93d	sdhci_send_command
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x65c96f48	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x660c74d2	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x69a88225	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x6ccef986	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x7c9cc60e	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x9aa816ad	sdhci_set_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xab8bf1ab	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xd55be7ee	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe11afa80	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe5e7009d	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe97c364d	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x0754838d	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x08ece0ae	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x4b3ca8c4	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x7c693fe0	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x8795d1a9	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xb3b2cfe9	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xbe46030f	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xc3c05768	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xf68b751b	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x2f331918	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xd22d3c8e	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xed041966	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x3e4061fc	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xb3ebe5aa	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xcdb9ae7a	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0x5c7ec8fd	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x17584e54	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x1aa17fcd	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x74fb096b	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x099afa85	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x17b5a517	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1ec5f6bb	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1f463061	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2648a25c	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x307419a0	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3d4ecb5b	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3f31debd	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4c3be366	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x50d48428	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5579afdb	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5f02640f	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x76483024	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8434520f	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8aa4e7ac	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9e811a5d	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9fac6d31	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa1d2075a	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa5591ad8	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa6cda7cd	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa9455874	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xab3e69a1	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xaf60f73c	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb12859cc	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb260a2fb	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb7c1ed1e	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc0be4e84	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc3ff68c0	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc8cdbf98	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcb171d90	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xceae5ec3	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd0889a02	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd3fca307	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xecfd5371	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf1ad3efd	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf8280431	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfad23ebb	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfb1f0269	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfdc652a8	mtd_block_isreserved
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfe17ba96	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfe597eb9	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xff2c0ba2	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x31968209	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x94c9f68d	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xa06116f1	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xa6e3d927	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xd91d32a0	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x10921b0c	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x672a728e	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0x66159740	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x12bd3b9f	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0xf68dd0fa	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0xd0be4291	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x009dedbc	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x142968b4	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x193079ba	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x3ffd058d	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cdbef7d	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x709abef0	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x7a4b5acf	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x86f8ecf8	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x95315a25	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xb506e0ae	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xd2293801	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe78ee385	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe8d7f991	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf40ae644	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x5fb4e157	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xc153538b	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x110f5e75	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x1c6328ea	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x2340128a	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x9abf4ad4	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xb497e8c2	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xfe0c1ed2	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x003f20eb	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x00ab590a	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x07236d09	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x10ec608e	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x19f5f952	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x28c1e244	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x5ec5e876	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x7e93dab1	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x824ccdf0	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x9779292e	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x9e9da08b	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb0c3a27b	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc74b6e7e	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc78b7a25	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xd35f5fc2	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xdcacb288	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xdd431267	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xee890b46	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x1b104176	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x21b672ba	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x9a4d1262	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xa907f330	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x0f88bec3	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49b044ac	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x500860b1	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x545bf505	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0x1975b133	arc_emac_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0xeb11d3e1	arc_emac_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x00e2d093	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x018857d0	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x043381a2	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x04476327	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0d0aedda	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0d86042d	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x141c7292	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1472edbe	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x14dfe2f8	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x16eb778e	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1708a8ec	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1a14e601	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1a1928dc	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1c89ad4b	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1e79d42b	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1fe3c328	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x25fc1d58	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2624506b	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x272d76cd	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x288be4bd	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2a463d39	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2a893508	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2d1b3b12	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2db5c7f2	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x309b7ac3	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x37d239da	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3861d266	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3a906625	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3a9a40ac	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3ea727df	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3f81eadc	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4022ba57	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x418a05b2	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x456f7b6d	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x45835332	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4625d16c	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x46d8969f	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x47e5f3ed	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x48f4b45f	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x48fa8491	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4bd47d5c	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4da4f8c5	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4edb2d99	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4fa18a0b	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x52275b35	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x52a81102	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x571faa8a	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x57571f28	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5e815208	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5ea74499	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x615e9ba4	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6334f949	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x668a1228	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x66b27d0d	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6e6281e2	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x717deecc	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x773c12be	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x77cd9c36	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x79166322	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x804cdf30	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x80ee0344	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x814d02a9	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8169cd52	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x817ae331	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x81a59e98	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x81c77830	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x83f077c5	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x84eed07a	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8740dfbf	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x884a4d84	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8f083487	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x943b26d2	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x951619ba	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x966109d9	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9739979c	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x97d0d59c	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9bc5cbf1	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9c1d8a1f	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9c984560	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa0e838a7	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa20df466	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa723000e	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa7b74eca	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa907b8ba	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa9a65f85	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaa4ed082	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xabf1a9ff	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb49089ec	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb6afda9a	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb73bedf4	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb93f6c2e	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xba81731e	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xba8523f9	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbda94563	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbf44bee8	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc00aed45	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc05cb59e	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc0e2ec7b	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc4bc1a5d	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc5038f9e	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc65aea11	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcb487cd3	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcec7f8fc	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcf5a6a78	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcf8a292a	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd4a5207d	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd549b571	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd61de741	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd6308253	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd807b0e9	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdc0613da	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdd19b3e3	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xde5b80e8	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe02e3c6a	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe33537ab	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe554fe56	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe63f36ef	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe8431d5e	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xeba3035a	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xed0c1349	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xee88e0a3	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf8665a65	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf895c851	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfe92efb8	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x04cf2029	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x04f6e833	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09543b3d	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0b924c17	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1f085d77	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x222c006f	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2b0ddb86	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x33aad64c	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x348fb328	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3755930c	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3d484a11	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3e8091a6	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4910aca4	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4c184da0	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x516ab7b3	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x59af0986	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5c818bb3	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5c9f2070	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5de063c1	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x60e29885	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x64338adb	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x684adb6f	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x72cbaace	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7d1bab8a	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7e799689	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x801e6198	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x84f9d69d	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8c37d434	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9492e245	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9a2d1740	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9dc9a809	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa8679247	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa96cb11a	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb125fb57	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb1a6f0cb	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb284c38e	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb3c7a74f	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb7eba342	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xca597b33	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xce162f4a	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd91204c8	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xda86c110	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdda29bba	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdf76b1c0	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe213d969	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe93740a3	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x5e28947e	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x9674111a	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xac144314	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x21fe6369	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x5aafc5bd	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x8d84ae2f	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xbd1f5dc5	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x9c3b48ed	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xbd753140	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xd41c28c9	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xef4a4633	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x0211cf5e	cpsw_ale_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x1ad32216	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x2187261b	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x29adbb4e	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x2bae1acb	cpsw_ale_stop
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x3bfe8fd5	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x47c7eb68	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x4dc94564	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x4f66a96f	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x57e7fbaf	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x5b01d0ee	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x6ec26774	cpsw_ale_dump
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xa04dcf72	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xad261baf	cpsw_ale_start
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xcebf7528	cpsw_ale_add_vlan
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x82b63584	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/geneve 0xab438f03	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x638b1630	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x73670df0	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xa6581720	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xbd6a7614	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0x8529b1df	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x22e24aa3	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x30490685	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x6cc4d94c	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x816e2b99	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x84999826	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x84eeaaaa	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x903a4714	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xaa6f61c6	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xb3b29605	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xb96151c0	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x6318757f	mdio_mux_uninit
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x9a4b92af	mdio_mux_init
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x04056567	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x5bc911ba	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xa62c04f9	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xcbee9415	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x45d19d66	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x463af3da	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x82e75b0b	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x9400691e	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xaf4977bf	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xc47ad688	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xd04d34e3	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xdd71728e	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xea74b7ab	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x84ba0286	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xae52623d	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xdb4e75b1	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xdf765943	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xe578fb90	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xfc8473f8	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0190cfeb	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x07822423	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x081a8fee	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x176083ce	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1a372238	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x34ff1b16	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x351fba4f	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x35cfea86	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4242f68c	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x43614d9e	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x46163c04	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x519cb210	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x5b7b85a2	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6261e972	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x681bbed3	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6d6102ce	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x79b2d08b	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7a0abf83	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7f379b86	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8c819a24	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9b996aa9	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa77bd173	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb01275e2	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbab52d77	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbc7facbf	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd157c858	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd61214ea	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe7a38d0b	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xeab859ce	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf38da2bb	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf7147a0e	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xffd76076	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0xbbd15260	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0xe2e6c207	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x03f612b5	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x291fc7bc	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x590fc7cf	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x5a36e009	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x5e1e4187	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x60f02c9f	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x65569711	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x6805cee4	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x72cb15d6	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x770e12ae	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x7d59f1c4	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x931bdbc1	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x9c01d095	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb8973456	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xd2dd6f75	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xdee4c0cf	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x127591aa	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x17c9f397	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xd1d2b4b7	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xf50a0819	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0xf7f94481	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x09ba37bb	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x3775a9be	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x52a6b718	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x9e7cf822	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xdd96ebf7	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x002b2e74	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0d556623	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0f48dcb7	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x11df2b1a	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x12207cf9	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x398355b3	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x3e5c7bba	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x468c510c	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x4dec4790	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x539184c1	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5ba53608	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x68b753a8	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x71391630	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7810a97f	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8649f7be	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x89344a86	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8e5a12b8	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x92a41468	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x96598709	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9bd11e7f	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xaf97cbed	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xba0b0eaa	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc67c31ed	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc90228ee	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc98b5cf7	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xcc2aa384	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe0d3442b	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xea9f75b8	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf4cecf72	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf5aea4a7	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf65c0c2a	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x10c03173	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x1d58776f	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x27d07f90	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x41c778f7	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x4e359abc	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x56a20528	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5abe4836	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x6b97ba0d	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x6f173a5d	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x770db47c	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x905b24ed	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa315cea3	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa68f39d1	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xabe6cd15	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd0787fe8	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd7dbe077	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x13b9ab1c	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x316b36ba	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x59be9e6e	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x67eac08f	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x6a4b4493	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xa722ddee	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xda8d0c2c	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xdc62e9f8	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x00dfd782	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x0384b9c7	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x0a28e884	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x13c6a1d3	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x161ed56d	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2528329f	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x253b312d	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2ca065b8	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x30a73df0	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x3d9f1350	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x464ac54a	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x494793f3	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x4d6e4ec2	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x515e954f	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x660d6cd2	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x6c3f925a	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x8a6b14ba	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x958a1bce	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc8a58bc0	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x0155f793	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x09e13398	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x0fedd0d4	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x4cfae3f0	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x82688b94	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x870d3576	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x9718d154	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xc205ea40	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xcdaf8b3b	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x0f919311	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1b2b54e1	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x36fea445	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x93bf2248	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x0261a4b0	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x049e2b8f	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x0c026fe6	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1bbb0423	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1e916001	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x485d0665	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x5203575d	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x5c76c7ee	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6ce19bd4	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6f4bcd42	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7ba8bfaa	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7deaabf9	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa7d21984	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xac32ad18	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xac51c94d	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xb446ef6a	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xb6ef8a56	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd0480604	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd2819787	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd2e3622c	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd62ac2b2	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd8b5141f	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xe18206d3	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xeb5011a0	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xef3befd9	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf5b2effe	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xf929a364	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x08eb3d55	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0d0b6636	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1385e59c	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2e2ade9d	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x31287a7f	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3b62608d	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4776ae5f	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x49dbf701	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x49fa7933	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4bb596cc	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4c5219fc	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4db407ba	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5caac1bf	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6103ab2c	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6b4de810	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x726a90d4	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x735d85b6	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x780638cd	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8016114a	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8874c27a	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa6e54002	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x28a43055	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x416f0178	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x67a8c5bb	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x711ac3cc	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1ae80bf9	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x2b079c44	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3096db35	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x393d716e	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3ae0b7b0	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x41078b43	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4fbcba04	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x54ca3e76	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x644e1a86	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x664fff03	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6f122e05	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6f8a5678	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x70081d9b	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7046150c	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x714f0247	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x750d65c0	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x760da2c6	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x765a5bdc	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7bc70415	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x88f20486	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8cb5a9ee	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x91b76cc1	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa2040513	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa6dd1fce	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb2fecf8d	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xbd50fe99	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc3da197c	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc9e4591c	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcf7f6a98	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd1c085a6	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd590568a	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xdaa4853a	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xdb1d0da0	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe1f2f392	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe2b98698	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe5ad00b7	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe80ced74	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xfe76eefd	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x114e91a9	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x3a271e9a	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x482c5b67	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x60c95831	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x6b18f383	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x767a7e12	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xa1e7df06	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xb7c3ee4d	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xbbb11648	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xd864a4b3	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xebc43568	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xf8f08bf1	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xfed7a7d6	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x065829a3	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x078f3bfa	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0ed306bb	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1390a74b	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1424ac33	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x14e91e7c	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1a644413	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x32b78e1d	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3e725fcf	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x411c5c63	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x45e37271	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4d051b96	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x579d84eb	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x59beb059	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5d2a7e65	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5fec05ce	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6474309b	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x67acbc5b	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x71ac1d0c	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x73689248	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7c22a918	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x82dea998	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x87ed0a2a	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x91af6734	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9634ecf7	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x989ae20f	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9ab5f987	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa86908e2	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa92028b4	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xafe4ab3d	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb7e00542	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xba896e1a	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbd9de88b	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc5ff440f	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc78cd0c3	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc8eab285	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xca187c4b	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd1ad4239	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd4c72b54	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xda3d2dfe	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdd0961e9	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe057c7d9	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe31e0cec	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xefa00f48	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf008887c	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfc9d8e11	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x35860960	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x56ede7ec	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x80c64c29	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x82f42a1d	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xc60945dd	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x21e9c2b1	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x3cc006e0	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x63a010c7	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xee4dfc8f	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1f8f32b1	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x282826f9	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x2ce9c58c	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x40975891	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x4f6c23a6	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x5dbb84eb	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x641fd697	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x68ca38f3	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6bdf510b	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x78b27786	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x837d3b4e	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xb7b85806	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe25f758b	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe41bc54b	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xfa74d1dc	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xfcd8ab7b	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x3c34760f	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x919f6424	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xb02b6d58	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x00c83845	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0b337e9e	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x15236bf2	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x184756a2	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x18bc45e9	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1a1a4850	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x21a5ec3c	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x29890233	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x29963b17	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x30de67e8	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3368c2e1	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3396680b	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x377ac944	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x397889bb	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3a78449b	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3f4febe4	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x42904731	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4925682b	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4ad62ef4	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4f270b55	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4fbd8226	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x58a56fd2	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x58ea91f0	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x60fbf77b	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x70df75e7	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x880d5d09	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8d4a293c	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x91543d5d	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x99beba0a	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9c99327e	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xac0180df	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xae65fa0c	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xaedfb35e	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb0547fac	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb805a0fa	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xba297fb0	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbcfcc142	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc3ac9501	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xcbef4936	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xcc7a3c96	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd67cb7b0	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe915f2b7	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf51df07f	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf96ed9c3	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfc5ec9b8	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xa2316e60	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xb91fbdc9	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xc141a305	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xd5322f19	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x1d02afa8	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x47737020	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x79b1c81c	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x832fb787	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xc11e791e	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xe9b2cf9c	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xf60b6312	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xfc78b4b6	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x4ecea1c5	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x7918bea1	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd5a6aaca	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x052d33cc	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x202d4ed6	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x224f51bf	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x2ae598be	of_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x3866e217	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x3c27749f	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x99f018c4	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xab8632b6	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xbc2e750d	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc4200e52	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc64ddf0f	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc697b0f7	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xfd5db878	of_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x138cc1f3	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x3f7eafcc	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x44d3fa88	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x45c1a59d	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x469c68ae	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x4e182691	mc13xxx_get_num_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x5671abda	mc13xxx_parse_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xb7e1c97b	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x0c405992	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x17cf1b8d	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x3ac8c703	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xa68bead0	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xa8d1bf39	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xc5fe5b64	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0x6ef7febf	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x025f2196	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0a0c39cc	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0e5ba929	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0ed21eec	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0f3ecbae	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x10687d21	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1e8378f0	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1f664eae	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2f9070e0	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x308b2ab5	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a02a07b	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4b165c6b	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4fff5872	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x516aea2a	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x54019cb7	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5ce2e197	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5f35efbf	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x652a45b0	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x65823be9	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6772a07c	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6e11a8a5	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x72a399e3	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x856fd79a	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8fb62b4e	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x97dce4ce	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa2a5dd46	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa33abee7	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb22be664	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb4d1180b	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbac73d99	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbfdeee64	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xcb6918ab	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd1bb4dfe	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd1bdde25	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd2eccbfa	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd5319b91	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd7653062	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xda06c11d	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdae7234c	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdfc37f80	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe79fee65	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xebfba9b9	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xed5dcc2a	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf2ff935a	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf92baaa9	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf9881139	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x013a2926	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x119b6212	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x15b5a541	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x1e9412f3	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x214a8a3a	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x32fe5821	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5925593e	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x59de611e	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x88ee143d	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x8a76060f	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x90e10086	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x94e3bcd4	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa226dbb5	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xc87bedd8	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf38a6552	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf57b31cd	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x03e1ebd4	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x0b8ed3fa	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x21fe993d	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x30c479c5	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x47947f85	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x5aad1552	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0c103e2d	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1d007170	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1e008e2a	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x20fb9048	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x26ebc96c	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2b829d40	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2d7a83a0	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2f6ac7be	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2fb48d59	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x32a3e0b3	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bdc273f	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3e8306c2	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3f85bb89	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x43e5c537	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5c586853	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x62c5a89b	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x63c327a5	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x69b6df4a	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x69c18e31	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6d04d1d7	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6f72453e	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7a561b03	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7f71872d	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7f9e1a6d	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7fa416d8	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x84f49c0e	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x861546bf	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8c7140fd	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d23dbdd	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9dbeecfa	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa2fe8992	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb71253e1	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc3ea3d8b	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc57d896b	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd9475af5	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xda5dcba5	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xdcfecb9c	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe9aee1f2	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xeffe7a24	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf865efdf	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfaa66728	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfd9259ff	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x0863d0df	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x1d8bda64	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x1ecdffa2	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x20e57dc3	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x30d934ff	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x341a3152	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x3b012de9	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4b31d0cc	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4ed0e2c5	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x62e6996d	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x65c06c36	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x9051d016	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x90a8a09e	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x97979aa3	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xb01065d8	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe0299ecf	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xf52d52cb	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x083d2efb	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x19651f11	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1c4056c7	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1d697ab1	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x240bcac9	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x27fda1c7	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2fe1e87a	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3d7b1cd1	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x484b1ec6	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x58f1c561	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x597f0a45	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5dc217af	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6c9b363b	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7a8d1f6b	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9a90aef9	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa1cede7c	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa84da6a7	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb1394ee5	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb644c0ed	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb73ffc32	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xd2c7e04d	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe13230ad	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe4a15564	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf79117b1	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x096a5432	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x102fc16a	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1098167d	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x137001d8	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x14106214	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x197c4290	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x21dd6a2f	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2205780d	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2bb4d7b2	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x39a643eb	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3c3e3c03	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3db59509	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3e90579b	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x48f20bef	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x491192f1	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5bbb25e7	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6316948a	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6ad7b52b	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6c7282cf	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6f450064	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6fb3970a	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x731bcf58	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x80c09ed6	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x86674966	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x890ae84e	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8dc2adeb	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x952ddf29	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x970ec0d9	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xae771d49	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb47b2e70	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb8cfe06e	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd850abd5	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xdf8f9324	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe3101b36	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe9517d3b	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xed18d2fb	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xef6489dd	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xefab6644	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf6153420	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf95f4589	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x2ebecbb3	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x68910073	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x8a2bff4e	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xd921090b	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x78da95ba	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x1bdc5f30	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x6d7ba716	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x70ad1e8d	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x7ec6c81a	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xe7fe0434	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xf5b89383	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x0f206fee	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x21a34ddb	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x2a77af55	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x6dcd7366	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x8d0d6c80	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xa5ac4a8c	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xe045a409	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x15ec959b	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x547793ef	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x7f1b5807	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x94794802	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xbcd4fc96	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xe2a66f72	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xed1f5236	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x06131284	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x299a06f7	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x3bfaea8c	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x99307a16	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xb9ac7a24	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x38acb076	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x73e0fb6f	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x9d4c0eeb	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xb2fd8178	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x14529dc0	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1ced0cdd	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x2328bf18	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x2c34be5c	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x3af2f00b	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x41ff0eeb	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x43b98f65	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x61bb594e	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x70daacaf	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x7dcd0bab	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8aeced3e	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xa5fa522c	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xbb37f77c	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xc4743341	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xc9bbfb17	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xd9e9d38c	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xdc4ad777	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xeec3c5ae	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0xe5662eb2	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0bd8d456	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x163ff506	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1a113d3c	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2175269f	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x26d82243	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x33d553b5	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x34f9923d	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4bc3ff27	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x542259aa	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5b96ab66	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5df6595b	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x62a7ee1d	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6b64686d	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x778c932a	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x90396c51	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x967947b0	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa169ec74	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xaab1f013	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb08a3422	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb5156fc9	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc06957b4	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc0cf406b	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc5c1361d	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc5d4cd76	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcb198116	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcd548de5	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd50d5db1	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdee84170	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe0887ba4	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe4e3e4bf	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe573334e	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xeab45866	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf002b70f	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf457d897	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xfc1ad239	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x0c22a8d5	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x143a4a0b	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x63280bc5	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x7e3c3ab2	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x89ef91cf	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x9bf33be3	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x9e73e9c1	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xf3eaf0ed	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x4040bf09	comedi_pcmcia_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x6b317c23	comedi_pcmcia_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x6b3def7a	comedi_pcmcia_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x7e3ad881	comedi_pcmcia_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xc6899f50	comedi_pcmcia_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xe0f2e588	comedi_to_pcmcia_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xef2e93b7	comedi_pcmcia_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x08eb0418	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x39d87d98	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x8318786f	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xba37e92e	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xf19607fc	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xfc8bcd72	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0xd420e6a8	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x2b93a526	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0xe016d3ad	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0x9bbe80c7	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x0842a2ae	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x39164cfb	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x451ca320	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x4a6d045c	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x4ad368d4	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x5e91a058	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x5f6a4b47	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x6a2b574e	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x71102411	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x85ec716b	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xbe933542	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xc392cf5e	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xf89762fc	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x1ba81781	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xb087be64	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xefb8d949	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x0d68fcd9	comedi_isadma_poll
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x12fba874	comedi_isadma_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x4a17474e	comedi_isadma_disable_on_sample
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x6815a033	comedi_isadma_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa3d01a85	comedi_isadma_program
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa7ebb8a3	comedi_isadma_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xfb5d45e5	comedi_isadma_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x1d00616e	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x042aaca8	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x19e6c674	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x1f396341	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x20c1e780	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x27d8cc62	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x2e982201	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x2ebf3c04	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x51df2c6f	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6093b785	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6b6f2fc8	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x83471f87	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x91990d42	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x9239615b	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xb59d4a01	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xbbd785b1	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc2f3a867	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xcce0a96e	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xcd983b74	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe65227c7	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xed11c739	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf33d5d49	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x306f35cd	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x387c1f12	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x3db59a08	labpc_handle_dma_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x6534a6fa	labpc_free_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x7db1f933	labpc_init_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x93a0ea3a	labpc_setup_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xbfdbc481	labpc_drain_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x21510648	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x5d58498e	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x6015ce5a	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x82113a20	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x9f436766	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xac5dbe9a	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xc9b24756	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xee20ac76	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x0b7ec172	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x3c653022	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x68bc1db8	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x77038f8b	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x95dca91a	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xc9ff8566	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x21981886	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x31e8035b	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x498e0b61	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x81318edd	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x9a12196a	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xcd80359b	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xe04a17bf	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x2b840e7e	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x2cea6b62	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x3d63111f	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x479d5508	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x492654d6	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x610d1411	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xaa2c5240	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xca6a4693	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xd4bc9bd2	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xf7032ba5	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xfa938b27	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xff610137	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0ef1d765	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x10772273	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x168fdcce	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x180910f0	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x2c873cb6	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x535df281	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x782ebb69	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8b4a01fc	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb35aaab9	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd856e159	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xdbadf743	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xdbd2ad0e	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x597bf437	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x8ea31ff3	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xa6f3f389	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x82122271	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xdce4a84c	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x45b9e738	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0xe9de0cc8	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0x68a4bfcb	imx_usbmisc_set_wakeup
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xa2241237	imx_usbmisc_init
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xd089a7af	imx_usbmisc_init_post
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x4bf39046	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x66cf0b7a	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xa85809ae	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xbb28b754	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xdd969127	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xe54fcd4a	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x007b3278	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x035c2eea	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x1103db5b	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x2a6f7264	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x2fd2458a	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x2ff27172	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x41de6f56	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x48094682	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x48d50d1c	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x6e17825a	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x792e8ce8	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xba2bc9b3	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd799aa68	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd930761a	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xee50d015	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x89263c4e	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x89ca818c	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xc2bfa7a1	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xd371dd12	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x283763fc	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xe53a9759	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xf9bdc1e7	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1a3dec1e	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x23f1a6f3	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x27d5e54e	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2ad0aeb3	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2b8cad3f	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d96ee9e	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x46e34ca6	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6ce75bb9	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x75466f8c	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xaade0dbe	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xafccdc83	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xc0ab5cdf	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xc74c538c	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xe7dbea58	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xe98571a1	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x0abc3038	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x0b93aaf1	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x111d5c6b	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x213ae5db	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x374cd28c	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x380cbbd8	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x429a9129	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x5c501bf7	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x6f9e55c6	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x707eae82	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x76481478	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xa74078fc	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xd232dd14	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xe6bc077e	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xfc49db17	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x03cc3925	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x14cd96ca	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x16ca28e5	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x18d52f77	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x1d8688af	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x27a417b2	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2ea0a36c	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x3e61d2b8	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x459ba287	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5d310bc0	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x649c68d0	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x68494784	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6cdc98c5	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6ed31789	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x741245ea	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7dfd2837	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x89ec6e87	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9416f5d2	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa103cb11	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa3d7c243	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb37f0eea	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb42426b6	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb4bc7115	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xca096464	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xcc3c61a1	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd0599bf0	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xda9a97fd	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xdca51965	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xeffe66a9	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf468452b	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfc9b7a7c	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfdc0815c	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x0c63ede3	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x1453fef2	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x480df37e	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x4edb7a7e	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x53010148	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x61ec812d	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x81c36fb8	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x8e404e87	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa3153ef3	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa4744dba	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xaa4d2581	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xb17c7592	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xb8f3557a	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xd2b7d7ab	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x119be410	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x4eb39b92	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x1bdacbbe	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x2a3d2987	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x5811b9e1	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x5b222ecd	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x849c9841	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x88214d5e	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x9eb21f70	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xd4df1224	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xddbf32d8	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x880993d0	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0xd858a7bb	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x5a0aa345	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x0998ecb1	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x0d2493ed	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x12d5bf63	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x18559b71	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1cc8ff68	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x37590e86	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x462eb252	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x5c487837	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x76c5667a	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x76cdefd0	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x81eb7b91	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x84c013c2	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x8e0597e8	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x9a034307	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xa1ac3e97	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xa5c61f9d	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc0e29b75	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc4bfe740	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe670a214	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf392f639	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf59c8b3e	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x136aeb8a	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x17f09b65	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1e5ab4b3	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3478b9ea	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x357e77fd	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4f4c7964	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x540853e0	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x5724d934	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x5b94f250	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6b857d15	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x7049479d	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x82476a88	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x9722f353	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbe70bc1d	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbf557c48	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc0458623	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc6454052	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd2486964	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd824282c	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xdeee9e06	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe5024a73	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe74a3ebc	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xef9b0960	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf067ca8b	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x0bcd70ab	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x19cc0fd1	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x2f05ee5b	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x549bbe5c	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x88b9dae4	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x8c74211f	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x92f69332	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xa6113e39	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xab66a8fa	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xcc98c3ac	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xde99e711	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xef209401	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x0bd816f0	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x122f15ac	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x20527ed2	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x504a9930	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x5b78b66f	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x692a70c0	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x8bc8de16	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xd7d6be4d	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xf9414410	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x227c5c76	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x267eb67e	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x3c2a14ba	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x490067a0	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x69930044	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xa37b1a66	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xa4b6163b	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb3564041	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb645da6a	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xc30ef785	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xc42a74d8	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xc56039f7	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xcd572efc	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xcdd51d15	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x8fd564b9	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xd9591094	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xf50e49f2	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x11f32baa	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x255aeab9	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x311f5848	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x3808a69a	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x3ec9449b	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x450d55bb	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xf1e77f74	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xfe7da439	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0c269aed	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0d78016e	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0fc02440	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1347b4f4	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2fc33cfd	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x32d55959	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x355aa9ee	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x45369c0a	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x46121165	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x49686f41	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4a7b455a	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4cc3c4d2	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5084fb43	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x51d7b6ee	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5d83c207	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x65cf8ed8	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x66748928	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x69cb3d12	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6e3ed1b4	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7f0563a0	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x804f2b69	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x816b9e92	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8633474c	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8c17c28e	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8d74da04	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8f0ee8f3	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x90cc9ffb	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9683f63c	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98df3148	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9d68f79b	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa9083d6f	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xac97316b	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb5f16cef	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd61f288e	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe06c6478	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe789cc7d	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf09e2039	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf3ec6cff	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf7558315	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf977f184	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xfc7a14c4	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0xc425b088	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0de1646b	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x113772d4	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x12252435	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x20cb01fd	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x218cdb90	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x224b669f	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x363fde47	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3b466e9d	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x419352ba	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4a6c5d4c	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x57968ec0	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5c770ecc	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x669f70c7	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x734dadb5	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x7a9e5675	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8ce105bc	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x96823ea3	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xab391bfb	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb0f81e37	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc2deb4c0	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc2f60e9f	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc67817f8	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd4ef0fa3	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe0447ea7	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe0c8201b	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe70a22c3	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe7a3581c	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xee599f03	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xf53de307	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xf7f50e45	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x2383403e	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x3da6e151	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x41c79b77	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xdbc5b977	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xe85bbc10	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x041c5954	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x354cc5be	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x66b79d5f	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x7bbcbe59	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x921fd326	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xb0223f23	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xb9b21193	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xba0ea404	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xc409c253	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xd11fa224	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0xf2d7c34d	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x353737b2	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x98951e27	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x139a47eb	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x22581c8f	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x554a281a	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x718abaed	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x86091bdd	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x9c3c9c95	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xb4c25328	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xbbeb6e62	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xeea251cb	w1_touch_block
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x2b5c8fb9	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x7e5efafe	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xabe77229	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x325aca73	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x63199f67	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x9898100e	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xa79b08c1	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xb147d3b8	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xb3acc169	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xf01373e4	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x00305d6b	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x042e9199	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x06a3d1aa	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0d71fa23	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x12150ee7	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x122a5618	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x16af37fe	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x16c7efff	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x171238f3	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1a1b13b8	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1db90001	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1e3f76b3	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x20356900	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x22e470aa	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x23c9758a	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x25252aa9	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x25333090	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x28ae2237	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x28ec1f67	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2989b55b	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2b0957ad	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2cd6d7f3	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2dd59978	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x367c507e	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x378f64b6	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x38d913e3	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3a578704	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3d2028e8	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3e6dd0af	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3fb38fe5	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f7cff2	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4a1f7c69	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4b9c1010	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4c1fe6d4	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4d634728	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4dc460a6	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x502e6702	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x520f7440	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x52d06bc1	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x53eaecb6	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5481562a	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x553d184c	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x566c324b	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5973ffa7	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5d81b79d	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x603de696	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x60584cbd	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x612e1e9b	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x61e13b3c	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6205f64f	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6498adc6	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x67d1800c	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6bae2618	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6f2a341b	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x72ee99a8	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7493e221	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7603dd57	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x765cef14	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x773f0c3f	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7875deda	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x78fd7900	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x799d9eba	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7c9722ba	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7f05762a	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x803725dc	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x822e4971	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8339b254	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x83e0cd22	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x86722831	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x88f75fd4	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8a6c119a	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8ab063e2	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8dbfb1d4	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8e8421d9	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91a18b1f	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9349afa7	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9b6c6b48	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9e88eef3	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa15dd42d	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa2492d09	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa7114db9	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa7a4fe2b	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa91942bf	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xab1b37f4	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xabc4d87e	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xad7b0f6f	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb12a8647	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb2c68de0	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb57bbb71	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb7eec7b2	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb97d0177	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbaab8fbc	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbd2ae1ee	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc0838905	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc2335fc5	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc235dbea	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc2699097	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc32a4513	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc6ecf0e6	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc7182a88	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcae391ac	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcb8e4dd7	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xce9f7904	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd0333047	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd48c996e	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdd1b7c2e	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xde6ac8eb	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe300cc64	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe7f6bffb	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe8412a53	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe8ce1ab6	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeb140fed	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xec739aa4	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xed208468	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xee29ccce	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xee45c80c	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeeb2f742	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf1f0eb44	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf325cf9d	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf41e7efc	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf858a3af	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf8b93aae	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfa691805	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfe68b6d8	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfff06523	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0x58843ff6	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x07245e2c	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x07626656	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x098c22d9	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0af11020	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0dcd0079	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0ffa0822	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1093b108	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x15bda362	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1b8adc5b	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1fb6293f	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x27bd46de	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x29c1d361	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2c712164	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x31c52bec	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x34f24fd5	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x480b71b7	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x544acb89	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x56835924	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5a631a92	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5b8f394c	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6085edbd	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x63f117df	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x698a50fe	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x73e926ae	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7eb7e0ee	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8213f2f3	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8dc86431	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8ee8d851	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8f673a37	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x94836292	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x953e3c3f	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9615309e	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x973b478e	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9cf5879a	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9e03d032	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa011e98f	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa452e715	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa63ee431	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa87690d6	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa9291606	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa93de121	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa9cd36df	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb0480ef3	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb5da98c2	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb9662c84	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xba7fac72	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbe1bb910	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc80d90ac	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc9245b82	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcbe020c8	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd0b5b7dc	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd1cc3070	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd50101b6	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd6db59e9	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdccdff61	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe612904e	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xeaafb4dc	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed1f262b	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf3346e1b	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf3852d43	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf64925e0	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xffecd3c0	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x16a1959a	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x42bc72ec	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xfcd06cd9	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x27e066cf	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x62c33935	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x2c5e3316	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36a28a9e	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x3f79ffa0	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x41006ff5	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x637f0c74	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x81a17396	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x98c3427e	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xcf7e2f65	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd1f018d7	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf56c2017	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x2efabea7	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x3cbf5103	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x524ab95d	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xb60841d9	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd86ee196	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xef295dad	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x2f8964f2	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x982c5f5c	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xdfbc375b	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0x9c5013ea	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0xbe522585	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf2e33298	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x44015191	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x83aa87e7	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x1803a6ed	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x2b30f429	raid6_call
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xe4b051cf	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x0adcb055	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x221df614	base_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x4da25bec	base_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x63f42b6a	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x76203267	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xca3140ce	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfa5eee0a	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfc02472a	base_inv_true_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0xd3c8b277	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0xed284d56	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/802/garp 0x1113a2a2	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0x3d0e1fce	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x5161147e	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0xa64590f9	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0xaf2b5674	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0xce04a21c	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x16b96622	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x1de02b4c	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xa3ca8b50	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xc191f210	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xc644ce76	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xec8d9a64	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/stp 0xa0907415	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/802/stp 0xd4103d71	stp_proto_register
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x6a4ef1a1	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/9p/9pnet 0xbd8d795b	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xa4a5957c	ax25_register_pid
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x0c24b18b	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x17437079	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x2488c4e7	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x5c21b8fd	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xb5e9ff5e	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xc3601f22	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xcae2d9a6	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xeadf4bfe	bt_debugfs
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x03f68290	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x1df831df	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x2d4f3dba	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x76304ede	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xba4902c2	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xc1c77ab8	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xea165f88	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xf7c2123b	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x90f6b14f	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0xff65dfe6	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0944db70	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x19e1b626	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d4c83ba	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x21321fea	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2da693d6	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4295d57d	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x44722778	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x46743dbd	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4755b6c5	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4bf2447b	compat_dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x517f07a3	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5f0b5ea1	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x61809cf5	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6441ed2f	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7e180dac	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7fabc66c	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x945e77b6	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9c37a59c	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xab98fba0	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb0ff05db	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb1b848d8	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb2415b68	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb449c519	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb5bc9f3c	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xbd4aaa76	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc40104ba	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc72c0300	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xcf993b40	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xcfc55680	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xde5b1ce3	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe1ae2838	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe4909c48	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe65558e8	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe7d5dc57	compat_dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf08e7e43	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xfe9638c1	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x1e034e2e	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x9818d3e8	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xa53a1924	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xcf0a13bc	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xe0094ac2	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xeb95a9ac	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x4a0abd6b	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x5ab40533	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x762fd75b	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x77be9ed0	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xd58dfa29	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x708d1b7a	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xa1615f2b	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x652dcf4e	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x6948f995	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x7ce2d16b	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x8e1056e1	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xc504b2c8	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xf343d649	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0xb94d1002	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x2fcb0401	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x4358d3f7	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x43967350	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x49049726	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x55fd4516	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x62cb1f9e	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x6ab178d6	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x6b21b3b6	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8522cefd	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x85abbd10	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xa396baaa	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xacf971a7	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xe3c88648	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xed9d17bd	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xfc570b6c	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0x539ce4f5	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0xb26fedfa	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0x6ecc9cab	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x04546d55	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x1a106ac3	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x3d5441db	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x89b4aa22	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xf421f8ff	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x2d6e3bf7	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x6c776e0c	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x71ddc634	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x8aa68394	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x92974421	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xd97b9ef4	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0x52657a34	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x70d7c374	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x739e9ef5	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xda5da9b1	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xdeba90fb	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xeae024fe	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x073a7206	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x2671010e	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xd7f91c74	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xf2da7c69	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x50418cac	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x5801a96c	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x627cee98	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x791baae5	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xdef12815	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xee721a76	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xf0b42147	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x57b68d67	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0xa7377a6e	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0xb9b050e4	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x5fe61fb8	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x8a481499	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0xe2d62582	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x18a158fe	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x317e9ecd	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x364eb6ad	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x52526a21	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xc410b98c	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0xac9bc18c	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x5603f403	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x73882a18	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x872feb98	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x9ecfc0bd	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xfc77d291	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0xa33225e8	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x083bb954	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x085290cf	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x2b27e472	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x3be6b9e5	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x5804a4f9	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x80ac2b18	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x88e86819	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x89dba929	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8a28de80	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8a6980e6	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8c545886	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xb452ebe4	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xbd6226c0	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc7a30417	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd4f051f8	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xf3ee62f1	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0xa1739d01	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x11e1f72f	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x1f216d2c	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x232cba80	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x289f9b92	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x3df4f1b9	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x4231c4b1	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x4cebf2e2	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x58a151ae	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x6512a1c8	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x7e39681c	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x8b2742a0	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xbd1b6648	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xd3f7f314	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xdf3220e9	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf09b2b26	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf0c98e37	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf3f80180	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xfbf5e0e2	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x0ae15c92	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x13fb4eb9	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x7f56cfdc	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x9eb31077	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x01379e7e	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x0f1b5ba3	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x12baeed5	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x2172a650	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3e9e5703	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4146e7e3	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4341236e	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x562ed160	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x77ffd070	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xabb09f9a	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc52b15af	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc7639a3d	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcddb0105	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd0916894	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf1001cf9	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf3b4d4ae	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf4fafcdd	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x600581ce	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x9bca4d6e	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xad286c54	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xea061d4f	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x02792537	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x090df7e8	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0b3a2b37	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0da5a3ad	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1354194f	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x15e709d2	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x16be0d7b	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x170303d0	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x18dda914	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1d67d31a	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1e0ce124	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1e9241e9	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x22b4a010	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x23a3057b	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x23e0d891	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x282ad2a9	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x29a376d6	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2a66fc2b	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2b35a3df	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2b3f7640	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2b8e9f32	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2c3a83a6	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x361aae71	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x39c5cfab	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3d6af087	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f93c12f	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4579002f	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4c28b2cc	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4cdbe937	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4ed18807	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x547c199f	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5acc57ba	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5ba6eff8	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x66c7cf61	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x68f398ad	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x75240a37	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x79d4103b	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7aa76574	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7b12651b	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7b55a52c	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7c31f4a9	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7deda4df	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7ff00de2	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8a66c4fc	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90c1cda2	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x91affa89	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x920d0d47	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9a2e192b	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9a6bd46a	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9c3d8a3c	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9c4d9d98	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa0459315	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa064e1e8	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa26f37f7	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa996a5ff	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1622ef	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaf68c87a	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb1452c03	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb77e6523	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xba253806	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbc1c3e42	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbf4e32d6	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc2d6b7f6	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc4b56f80	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc8d73049	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xca8522cd	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcabccde4	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcad82da1	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd3b89c84	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd59dbb19	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd87bb2eb	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdbd9e539	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe3488bda	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xeb099c51	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xeee79deb	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf0bf0df1	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf7d06082	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfd425660	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xff40b965	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xff642d4d	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0xe1191e9e	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0x917c9a8a	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0xef8a4ebb	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x0b0f48d6	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x4122bd26	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x4e4a8b24	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x8152dadc	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x89a51a5b	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x95b1ab2f	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc420e651	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xf4cbdd81	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xf4eec4eb	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xfda231bf	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0x66f4f5fa	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x727bd68d	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xd8cae292	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xe17ca936	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xe30cca64	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x712d2cbf	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x82114685	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x77b7eb8b	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x8e0c918c	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x907031dc	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x9a8041e0	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xcae60a35	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xde0a730e	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xe151d523	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0x88bdc649	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0x089a80b6	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x13b94421	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x3064b2c8	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x94a3c67a	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xb2ad5c5f	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x00992d83	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x19ba03d5	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x2ad46dec	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x2efdd27b	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x70f0242b	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xa61c7167	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xdd080e70	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xe0cae208	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xf2a96643	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x01129fca	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xc0fa6692	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x0e10858e	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x2d063b80	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x5f339439	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x09b8b6ff	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x62bcc3ed	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x63da1ab3	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x6a098d42	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x9345c3b7	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x9652335a	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xa7f557b1	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xb1e52cbb	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xc5bf9d58	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xda1a51bd	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xdb449dde	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xdd3ecb38	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xefb095c9	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xf450b9a3	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xf4db8a33	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xf6bc753b	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xf95982dd	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x1217d817	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x122b5997	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x907f3766	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x9ead5f14	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xa65a67ce	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xaf352c42	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xf8e052f7	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x4abb93e8	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x5fd6ff07	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xe89a5b7c	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0xb5569cb1	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x45b17fd2	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xc1e2e67b	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xc80f506d	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x28f796f5	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x46c839eb	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x6afa498f	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x7b57a738	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x8bb59230	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xcc0fc450	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x510b6416	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x88bcee64	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x8d2ef9ce	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x5883c801	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x5a3c9ebc	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x161d1417	xt_compat_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x1e24c6b8	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x1fe58e9b	xt_compat_match_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3907929d	xt_compat_target_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3e88f43a	xt_compat_match_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x4d3e80f0	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5a3740f7	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5cd15514	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5f82f1f7	xt_compat_flush_offsets
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x691a6d69	xt_compat_calc_jump
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x6fc771d4	xt_compat_match_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x73cee41e	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9b6440d3	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9da49343	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xa45a3199	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc4311b9f	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc5fbf40c	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc7791bad	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc854b3ef	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd116c278	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe0b4971b	xt_compat_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe5b95510	xt_compat_target_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xec24fd82	xt_compat_add_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xf28bb1f6	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xf3576814	xt_compat_target_from_user
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x00204983	xt_rateest_put
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x482b6a12	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x70b43f52	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x9910bfb4	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0xfd6b7ae7	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x09596eba	nci_uart_register
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x10c2cc39	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0xaac573d0	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x3154e4cc	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x75a19bd5	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x8d167b2d	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x95785e9c	ovs_vport_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xa8bcffa7	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xad5b5360	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xae8e1a0c	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xd50c3fdf	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xf38a210d	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x04124c9c	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x12028990	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0x1baadef8	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x218d4b66	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x37303ab1	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x3c4c5a37	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x441e25b3	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0x453127a7	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x4c84b948	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x61cc614e	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0x64730e46	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x68abfa4d	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0x68db5b90	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0x6ac3863a	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0x6c19c9ac	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0x70537c3a	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x7bc62829	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x86e8b2f8	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x94cbf5a2	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0xa9fd6272	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc867b648	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0xdc4e5d2b	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0xe1b9d24a	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0xe5c1f742	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0xef678a93	rds_inc_put
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x5e816a1d	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xe1fed802	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x6bc99f85	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xaf5bd846	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xcf91dc25	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x01789af5	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x019c2c69	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x01fd413e	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0343ce03	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x035a986b	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0362542b	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x037af647	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x043fc979	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x04c77143	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x062fd8ca	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x093e58cc	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x095426d9	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b7a98ea	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0bea3be2	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c2d4f05	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c87eac7	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0da06165	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x12da1f6f	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x142a00c5	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x146819ac	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x14cd1d48	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x177c01ec	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x19142b9e	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x19fb9f71	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1acba809	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1cdb2cec	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1e0d53a3	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1eae1c6b	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1f2a9970	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x202e9d94	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2115a4df	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x21642579	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x223a5bd4	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x23a70b20	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x245a6dac	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24f53d8e	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x284e88c5	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x285fc7da	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x28a693bd	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x29a028ea	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2aadce8b	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2b493947	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2bdd23ae	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2e45fcc4	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x325ce9de	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3416912b	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x34889006	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x35af7493	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x36d9caf8	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x38465d10	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x39bbfd4a	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c2ce109	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3cdb2520	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x40ce0c14	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4119ceb1	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x449ff84c	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4621456d	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x464fc54a	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x466ae4d1	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x47d3c3d1	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x47eb3222	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x493d5ec2	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x499fdcc2	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4a33e014	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4ced1dcf	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4ecfa015	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x505566ed	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5265161e	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5299b128	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5342becb	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x552120a7	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x59b6a149	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b16a873	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5ce5151f	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5e95de12	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6139b0a9	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x624b6b65	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x62a6d72f	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x63320d0e	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x63fa80d4	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x64624f86	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x64b2a739	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x64e09e08	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x65168f4b	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x66929f1b	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x68f2c49f	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x69bf7505	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6a8d256f	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6ae8b13b	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6cd1996e	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6cf79122	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6f499e2a	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7377eb1c	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7425d44f	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x768456a5	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x77a74368	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7c18b04f	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7ca5d6fb	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7d4230d3	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7da5c681	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de50ef5	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7e8aa3c8	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8068b0de	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8206d5f5	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x82ab0658	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x84d05d67	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x85c94330	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x864e1bde	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x87145e0e	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x898c8ab1	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8ac5dd56	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8ae71c45	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8b454c84	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8e748ad1	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8e95b856	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8ea24b08	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8ef956a8	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x90571c41	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x914eae3e	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x91d123d3	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9334b985	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x93c32141	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x96558a39	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9882b140	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9897ab09	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98ac82cb	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98c81c41	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98e002b2	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b201f4b	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b6bcda1	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ca97a72	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9cae5fe7	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ef449af	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa3820b35	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa3b73deb	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa45079c3	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa5c2fce7	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa450f32	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xac8d3eeb	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xad60ca75	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb1e2cfa7	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb3be222e	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb6c802c0	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb857eac0	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb9301947	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xba332a12	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbaa25321	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbb6513a3	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf5a7f90	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc5664841	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc815a0cc	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8c2af8f	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc91fb2aa	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc97d8e00	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xca2baef7	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcaf2e05c	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcddeaccb	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce0bf35a	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee1d4a6	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd19bc721	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd36a379d	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd59db261	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7f3c3a8	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd9614d68	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xda29a14d	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdbe8371a	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdbff53b9	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdc059bce	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdd6b720e	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdd8db1cd	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xddb1771f	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xde636d17	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe0b6b39a	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe0d65a1b	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1d80cc4	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe2681f09	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe6867d3e	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe74ff364	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe84ffe4d	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe8700a63	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xea398969	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedea4c00	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xee01a442	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeea4d123	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef0c21e4	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef167f23	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf083b09a	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf289d698	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf2d5c83b	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf322e32e	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf4833c5b	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf6c8db41	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf8a0e768	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf916c2f0	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa77d6b2	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfd1a8c88	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfd36dde4	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfe71f80c	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xff44ae4b	cache_check
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x104d14c3	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2a4054f2	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x47daf2e9	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x59d943c8	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x81db4e95	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x8ea8325e	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x970b77bc	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x9a5e202c	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa26c6238	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbe4d3807	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xc66511c5	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xe3f8c049	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xed82561b	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xfe0daa41	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xff5b79ac	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x0287a183	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x10240007	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x25ee1b7b	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x37abb8a9	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x51c1b1bf	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x8187b887	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xa8dd4228	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xb5e70e16	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xc8b6c914	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xe23a452b	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xf7e339ac	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xfb7a050b	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xfc03ecda	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x19797a3b	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x383bb012	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x3ce2afaf	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x50420512	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x564c0b91	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x7f1fdc0a	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xb3e8ce84	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xbce9ef9b	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xbf430d6b	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xc260d15f	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xcaf96c40	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd3fb9963	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xdd7d6e20	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x0420ed13	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x30ee1659	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xab1bb09a	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xce7b4866	ipcomp_destroy
++EXPORT_SYMBOL_GPL sound/ac97_bus 0xb7dd185d	snd_ac97_reset
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x2111a648	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0xcc08dd7c	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/core/snd 0x0293218a	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL sound/core/snd 0x372a629b	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL sound/core/snd 0x38a917d2	snd_device_disconnect
++EXPORT_SYMBOL_GPL sound/core/snd 0x3b1eeb13	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd 0x8151bfbe	snd_device_initialize
++EXPORT_SYMBOL_GPL sound/core/snd 0xb6496102	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd 0xd9303340	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x061d1c08	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x18e20cac	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x5d8dba08	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x81e04252	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x8d8b9abf	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xac447d8d	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xcdf1907b	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xd74dafb3	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xdbd3c974	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x002124d0	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x0294d26a	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x2117e57d	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x533f4f2b	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x55679fd7	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x63b0f8e2	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x709be624	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x807084ca	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xc173d342	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xd4ee6744	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xdf097601	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x1e859c2c	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x2258555a	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x9508f441	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x97bf58aa	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xb0ce2b8c	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xdacc46ea	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xe452cbbd	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x128a3a57	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1986a321	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1a743f8f	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1b46a365	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1ce4dadd	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x205d9291	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x219e8268	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x21e3b1a1	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x22f6ebc1	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2a963f6d	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2be11094	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2c40b7c4	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2e626480	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2f9b68b0	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2fd7a386	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x35804433	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x387bdc1e	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3d7e4499	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3f7f2267	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3fef8be0	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4113f842	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x440a9b1d	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x45f0ae24	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x49c6a107	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x50c2e5e5	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5227533e	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x56338cad	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5951479c	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5c6e4876	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5ca96d22	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5d1b1eef	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5eca40f3	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5febeb43	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x62766bb6	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x67633d24	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6d3818e2	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6effedbe	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7776b386	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7a20862d	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7bc086ee	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8103b869	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8198183a	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x83337a4f	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x87591de8	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8d5601db	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8d962640	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x901b97dd	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9432f199	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x99547d05	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9aeaaa3a	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9c5081a4	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9d9506ea	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa1dbe672	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa6d44402	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xac2fa17a	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xaf91fc86	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb1c3bf13	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb1c9afc6	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbc08a59e	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbcd8e821	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc09ef66b	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc1b4ec89	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc5436de7	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc5ccdc54	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc7d67670	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcb5d82dd	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd32eca1c	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdded4738	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xee6f0c64	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf9a2d733	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfab6e13e	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x0a3a0720	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x1a0f125d	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x315bb3ef	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x56d62ca4	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x81bc05f7	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xc8ce8bb0	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0152ff03	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x01cceae4	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x029e712f	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x045e7bd3	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x054cc842	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x07bca6c4	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x07ed442a	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x088327d0	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0ea67aa9	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x115f55f9	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x141da8f0	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x17765e9d	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x18fa4929	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x19d47db8	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1a5b0eca	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1acada42	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1ad24e8f	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1e16fefe	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1ece8103	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x204ed292	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x21117c2f	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x26aa0562	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2793449f	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x290de193	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2c5cf2b1	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2f58c1eb	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2fa3dbc8	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3126bfc7	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x35f496dd	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3afaa84d	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3ca59ac6	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3e4b1e3f	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3f69fcd9	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3fb04cda	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3ffd8a81	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x40b0b9d2	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x40fed993	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x41343a89	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x457506b9	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x46d3ee4e	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x482d857b	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x496297a8	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x498b288c	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4ab9531d	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4abe1ff7	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4b26cce3	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x519ffa41	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x534c8ef0	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x543ce7d7	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x54755211	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5507c536	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x56111d96	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x581869e8	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5960b65d	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x597f95ea	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5a616c2e	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5b175748	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5d7f8e90	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6429fa34	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x68b4dbd5	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6d47fdb2	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6d8a2268	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6dac8732	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6decf506	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7776bc4d	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x77992950	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x77fb4065	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7b0bf220	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7ccd56e5	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7cce9b1a	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7dc4dc71	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x80c030a0	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x841d9f20	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8a7b6736	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8ab7760a	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8c9c1388	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8de660b9	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x90f5c51c	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9181f77b	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x95ea9aa8	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x96db469a	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a768447	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9b436604	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9df73559	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9f184e9a	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9faa2ab8	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa3bfb7cb	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa756689a	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa7ee451c	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaa679e7c	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xab2ecd20	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb2132289	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb52587d3	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb9af2152	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xba66cb6e	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbad3bda9	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbe126112	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbe141985	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc328586b	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc3e24313	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc5dafa5e	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc7e09fae	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc8b42942	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcc91e95c	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcdc9d48c	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcf69bf4f	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd0dae75c	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd3713e9a	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd480d640	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdcc570da	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe65c8179	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe70122ee	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe814d8e3	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe9563372	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeac1991c	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeb3f49a0	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xef0546d7	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf0807ebe	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf3d68d54	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf49f10d6	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf74770c7	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf8cd8d52	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf9efd96a	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfc641aa5	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x07d888be	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x0e62f0c1	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x20534ff6	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x3674ee79	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x3b7884e7	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x4cde58d9	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x58781c11	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x59f7978b	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x5aa91331	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x69956986	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x6fc6cebd	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x71ee1a2f	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x7719e27e	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x84b03177	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x8d90bd6f	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xa32750cb	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xbe0b1236	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xd8b658bb	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xd8c93bd8	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe02b30df	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xee2eb986	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x576ede98	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x7d05786f	cs4271_dt_ids
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xf8237f1d	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x02da7df2	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0xdff79440	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x5fe222fb	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x629294fc	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcdaab68d	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x247509b2	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x28503e0f	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x23f4f2ca	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x33ea64d8	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xb74ad26d	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xe8375eb8	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x335f9b56	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x34304eeb	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x3c6efbae	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x9d3390a5	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xd7172a1e	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0xcdb8c78d	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x37d27cd2	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0xaaa64543	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xb7815bbe	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xd3e9fa3b	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0x350a8e9b	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x37fa3acc	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x8dc62c1c	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xe5920335	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xf087fdbd	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0xa8f59679	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0x6a90753e	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x11d5c158	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x8965671b	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x012a7cb3	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x05ef054e	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x06339b1d	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x081530ff	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x097bd3c0	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x097ee941	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0ada353f	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0c78606d	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0cdc887c	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0f02fe3d	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x12e9d023	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x15c6857f	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x15fdc4bc	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x165493e2	snd_soc_component_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1844a812	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x18abe415	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1a7b9141	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1a8b024b	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1ba64bdc	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1e67b665	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x23ee7872	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2425211f	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x25ee2dc9	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x27711e4b	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2888410f	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x295371cd	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2bb7eee5	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2fabc6ac	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3134024b	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x329bdbcf	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x341a84ed	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3572b761	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x36d6f085	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x37e4edc4	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x39265fa1	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3b1850a6	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3e9480f0	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3f729f3e	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x410853c4	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4657524b	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4785c5cf	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x484cfaf3	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4b1d261d	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4b386036	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4d607717	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4eb6fd44	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x511583db	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x51c60dc8	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x52104de1	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x54000992	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5458f5ed	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x54bbfb5c	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x568f83f8	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x57490aa4	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5adab392	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5c33a479	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5e0c2b26	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x600b13c5	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x65069708	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x659df216	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6618e34d	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x66cb3f04	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x67e17c71	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6a7a072c	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6b09e614	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6d3f9315	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6d48c8e0	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6fdb7757	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x711dc311	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x720520f5	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x726273e7	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x72fb90f3	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7314ef26	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x73a52a64	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7661cb39	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7854d5b4	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x787bf780	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x794ccfc7	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7bb52ddb	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7ef805aa	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8243fc19	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x82f9f8a5	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x85926ee6	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x85b23330	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x89929bc0	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8a987d38	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8cadc685	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x903c2086	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x904709cf	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9240a9da	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x99075822	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x99cfb1f9	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9c072ae8	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9c9842a1	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9cf437a9	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9d5b3e38	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9d93e058	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9f6e6e80	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9ff7eec4	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa04c76fb	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa0751e29	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa0ee4667	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa12b934e	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa2781cc2	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xab8dcda0	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xad5a22d8	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xaea0e2dc	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb17b59f8	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb19b2070	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb2402505	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb31ff003	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb33afa84	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb3f784dc	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb7b31999	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb86168bc	snd_soc_component_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbb6aeed6	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbea8125d	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc23f7411	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc3833c92	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8ca9192	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcbe741c6	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd06fac4d	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd6c7f1a6	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdfa2dc0e	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe0404b6f	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe1f543b3	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe26d63ef	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe58e59a9	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe6be9c73	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe920e6c4	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xed1e0dc3	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xee2e820a	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeed79ae3	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xef760bd5	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf530296e	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf6dcbc3c	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf7203240	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf7a0352a	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf7be0eb1	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf7e1aa5f	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf925f127	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfa542633	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfa6e2ec9	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xff61dce4	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xff9df886	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xffa68437	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x07aae4aa	line6_suspend
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x431bbf99	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x4715181b	line6_pcm_release
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x478800fb	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x4bababa8	line6_read_serial_number
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x56de152f	line6_write_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x70b44f55	line6_init_midi
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8bc027dd	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8cdb65d7	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x95852dd1	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xb0a14fc1	line6_send_sysex_message
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xc45dd9e8	line6_read_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xea2ce22e	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xf1ca1eb1	line6_pcm_acquire
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xf3edac63	line6_version_request_async
++EXPORT_SYMBOL_GPL vmlinux 0x003c344a	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x0068a393	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x008ac83f	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00d488f6	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x01003c5b	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x014db228	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x015feab1	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0x016aea92	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0x016fa0ab	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x0176c15e	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x017add3c	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x017d59aa	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x0190c80a	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x01a02327	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x01bca0d4	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x01c068be	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x01c1401c	of_css
++EXPORT_SYMBOL_GPL vmlinux 0x01d0fd90	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x021ebfda	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0x022b61ee	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x02416cb2	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x0248d975	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x025615ed	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x0265170a	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x0268d2ac	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x029482d8	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x02971706	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x02ad4f7a	of_get_display_timings
++EXPORT_SYMBOL_GPL vmlinux 0x02cdc863	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x02e8e359	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x0321cdbf	of_alias_get_highest_id
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x036b105f	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x0376f34f	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0x038f7619	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03b5ac6a	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x03cc44e2	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x03e18b75	nd_blk_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x03ea9704	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0x03fab673	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x0402cbbf	preempt_notifier_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0441cb40	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x0467a308	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x0469cc7a	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0x047a1b7d	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x048bae62	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0x04968d81	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0x0496d972	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x04988d23	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0x04a50020	of_resolve_phandles
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04b5549c	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04df8fbc	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0x04efdec2	clk_hw_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x0504ca08	rio_unregister_scan
++EXPORT_SYMBOL_GPL vmlinux 0x0521adde	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x052dc69c	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0x053494cb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0x0538f1d9	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0x053b3237	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x05464fbb	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x054a63f7	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0x054a7640	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x057572b7	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0x0580d2dd	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x058b1c97	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x0599afda	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x05bf8bb3	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x05d88436	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x05fef37b	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x061dee59	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x061ec7aa	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x069ef349	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0x06a55ec4	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x06b57715	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x06d9d74b	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x06f13ae3	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x070d7244	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x071808c9	of_clk_src_onecell_get
++EXPORT_SYMBOL_GPL vmlinux 0x07216849	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x072b0bb8	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x076b390e	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0x077d5faf	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x077eedf8	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x079abb8f	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0x07aa7e25	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07cc0d7d	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x07e0edc4	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0x07e27b29	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0x07f300c3	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x080e3470	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x0819e806	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0x08207f29	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0x08245ba7	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0x08408462	__clk_get_hw
++EXPORT_SYMBOL_GPL vmlinux 0x0842aa74	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x0870026b	of_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x088841bd	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x088bfa7e	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x08960ef5	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0x08bc0870	compat_put_timespec
++EXPORT_SYMBOL_GPL vmlinux 0x08e4e2d8	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0x0900fe21	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x091906bf	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x091c824a	machine_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x093f9984	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x0940151f	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0951287e	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x0952af60	fb_videomode_from_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x095b461f	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x09766569	of_get_nand_ecc_mode
++EXPORT_SYMBOL_GPL vmlinux 0x0983b379	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0x09ace51b	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0x09af42bd	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x09eddb3c	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x09f940d6	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0x0a483214	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x0a51ae5b	virq_to_hw
++EXPORT_SYMBOL_GPL vmlinux 0x0a62e295	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0a83adc9	rio_mport_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x0a866371	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x0a886cec	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x0aa37be6	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x0ab49705	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x0ac37156	of_clk_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0x0ae16cc8	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0x0aeeea4b	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0x0b056aaa	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b10f705	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0x0b1e7317	of_usb_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x0b36d260	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0x0b44f3ca	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x0b50e41e	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x0b67b1b9	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x0bb8c354	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x0bdf7057	of_clk_get_parent_count
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c197384	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x0c1cc53a	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x0c214ec2	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x0c24f672	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c2d7b65	kvm_clear_guest
++EXPORT_SYMBOL_GPL vmlinux 0x0c4a6e21	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x0c5841c8	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x0c6093d4	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x0c83f68c	of_clk_src_simple_get
++EXPORT_SYMBOL_GPL vmlinux 0x0caa549f	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x0cb104db	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0cdb5047	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0x0cf0000b	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0x0cfb1cb9	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x0d0b470c	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0x0d2adbf5	to_nd_blk_region
++EXPORT_SYMBOL_GPL vmlinux 0x0d46138d	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d706d2e	rh_set_owner
++EXPORT_SYMBOL_GPL vmlinux 0x0d73a952	GregorianDay
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb4bcb	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x0ddf3f00	of_usb_update_otg_caps
++EXPORT_SYMBOL_GPL vmlinux 0x0de06988	cpu_first_thread_of_core
++EXPORT_SYMBOL_GPL vmlinux 0x0dfa8b63	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0e02baf2	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x0e087cd7	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0x0e16cd9d	clk_register_fractional_divider
++EXPORT_SYMBOL_GPL vmlinux 0x0e2319ca	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x0e4fb03a	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x0e614a9b	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x0e654fd6	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0x0e78f41f	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0x0e89f2b1	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0x0ea41f64	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x0ea7466c	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0x0ecf823a	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x0ef683ee	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x0ef95e31	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0x0f131382	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0x0f2b8b08	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0x0f312e86	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f7c206d	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0x0f7cfc6f	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x0f7f9c89	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x0f892981	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x0f93f40f	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x0f9d5cdc	__clk_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x0fa68a23	of_get_fb_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x0fbd2b0d	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0x0fca1722	of_fdt_unflatten_tree
++EXPORT_SYMBOL_GPL vmlinux 0x0fd633ed	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x0fed0c41	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x0fffae0a	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x100c4123	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0x100ff22c	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x10110e78	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x10358d4a	of_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x103c913b	of_property_read_string_helper
++EXPORT_SYMBOL_GPL vmlinux 0x105820be	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0x1059ae92	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0x108bca9e	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0x108ee324	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x10a9c759	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x10a9e895	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0x10ada377	find_module
++EXPORT_SYMBOL_GPL vmlinux 0x10bcb140	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x10edcb5d	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x11102d1e	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0x1114011d	threads_shift
++EXPORT_SYMBOL_GPL vmlinux 0x11166b3b	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x11174084	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0x11259986	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x113e644b	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x11439e82	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0x1146335f	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0x1167bc9f	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x11aca37e	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x11c73857	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x11c8110c	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x11caa6e9	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x11cb2619	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0x11e57f4e	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x11e5bc16	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0x11f07cac	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x11fa139a	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0x1211b3fd	rio_enable_rx_tx_port
++EXPORT_SYMBOL_GPL vmlinux 0x12157778	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x12166e86	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x1219b292	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1227cd2c	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x12625a26	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x126f889c	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x12ad5d7b	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0x12ad78b0	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x12b0f7bf	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0x12f3fcfe	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x12f9296d	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0x130514ac	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0x130dec77	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x132856f6	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0x13472f2d	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x135965b1	dev_pm_opp_disable
++EXPORT_SYMBOL_GPL vmlinux 0x135ccbdc	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x136a4ee6	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x136d3613	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x137ba52d	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x13908d67	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x13a5ddec	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0x13ad647f	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x13ce87e8	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0x13e5ea13	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0x13ec781a	nd_blk_region_to_dimm
++EXPORT_SYMBOL_GPL vmlinux 0x13ee656d	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0x13fd055f	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x140dd2fe	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0x1479111b	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x147b87db	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0x14878783	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x148aa8a3	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0x14a6aac0	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0x14c171a4	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0x14d85129	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0x14e65dc8	dev_pm_opp_remove
++EXPORT_SYMBOL_GPL vmlinux 0x14e6d76f	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x14e89ed7	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0x14eaffc1	fsl_spi_cpm_reinit_txrx
++EXPORT_SYMBOL_GPL vmlinux 0x14ef7020	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0x150a43e3	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1514bf8a	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x15157116	dev_pm_opp_get_opp_count
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x158bfe8d	dax_fault
++EXPORT_SYMBOL_GPL vmlinux 0x159181b1	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x15980f78	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0x15a5d817	component_del
++EXPORT_SYMBOL_GPL vmlinux 0x15bccafc	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0x15c21e5e	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x15c7c3e2	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x15d4b567	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x15e6a40d	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x16101cb1	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0x16312f7f	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x165a69de	kvm_vcpu_read_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x165f5b6a	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0x1662f7d5	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x16867314	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x16be6195	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0x16fcc9ea	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x1705cd1e	dax_truncate_page
++EXPORT_SYMBOL_GPL vmlinux 0x1752c9ca	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0x175f52a6	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x1776eb42	of_platform_default_populate
++EXPORT_SYMBOL_GPL vmlinux 0x17784383	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x177a9e0b	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x17a4b896	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x17ba9268	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x17d9c98a	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x17fa4996	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0x18026a12	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0x1842431b	nd_cmd_out_size
++EXPORT_SYMBOL_GPL vmlinux 0x18434d44	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x184b8abd	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x18a39323	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x18b0392e	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x18b34f1b	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0x18bc5d5d	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0x18caef42	rio_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x18edc969	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x19119803	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x191a8e83	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x19284e19	rio_route_get_entry
++EXPORT_SYMBOL_GPL vmlinux 0x19318483	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x193cfffa	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x1949b5cd	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x1954bc3c	rio_mport_get_physefb
++EXPORT_SYMBOL_GPL vmlinux 0x19606986	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0x19696348	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x197a4a64	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19ca3ab9	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0x19d292e0	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x19d9017a	rio_mport_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x19dafe45	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x19e5d552	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0x19edb5a8	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x19f028e5	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1a02c99f	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x1a2c92c9	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1a2cb725	clk_register_gpio_gate
++EXPORT_SYMBOL_GPL vmlinux 0x1a689aa3	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x1a8c5907	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0x1a931919	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1a99ffeb	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x1aca3bd5	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1ad2f86a	of_irq_parse_and_map_pci
++EXPORT_SYMBOL_GPL vmlinux 0x1add4f8c	component_add
++EXPORT_SYMBOL_GPL vmlinux 0x1b26d0fd	clk_register_mux
++EXPORT_SYMBOL_GPL vmlinux 0x1b29750e	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x1b4da391	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x1b6024a3	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x1b73d387	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1bb30e69	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x1bd6e7bb	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x1c02e16c	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0x1c18b7bd	of_get_nand_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0x1c2620f4	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x1c2ad10a	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x1c38c41d	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0x1c48eea4	dev_pm_opp_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c5ff742	clk_get_phase
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1caf6d51	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0x1cbd45c3	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x1ccb3cc3	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0x1cdb2147	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x1cee5920	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0x1d00e986	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x1d102c74	__clk_mux_determine_rate
++EXPORT_SYMBOL_GPL vmlinux 0x1d1c615c	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d408774	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d660585	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x1d74ad5c	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1d94d294	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1de03005	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0x1df71f25	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0x1dfbcf4c	mpic_msgr_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1e13730d	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e208942	of_pci_get_host_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1e995083	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1ea80919	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebac2bd	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0x1ebc569c	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0x1ebd94b6	__rio_local_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ecc368a	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x1efad16f	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x1f162950	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x1f379896	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0x1f3cfb3d	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x1f40e654	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x1f4c4e2d	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x1f55c462	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0x1f5680ee	input_class
++EXPORT_SYMBOL_GPL vmlinux 0x1f614aec	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1f761f1f	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1f95971d	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0x1f95b795	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x1fc2ae24	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x1fcd0a40	fsl8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1fd71a04	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x1fe9cafa	thermal_zone_of_sensor_register
++EXPORT_SYMBOL_GPL vmlinux 0x1febdce7	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0x2001fbec	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x200f96e1	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x20174a72	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x2033ce8d	gfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0x20aa6f51	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x20d31554	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL vmlinux 0x20eb3442	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x20fb87c0	pcibios_scan_phb
++EXPORT_SYMBOL_GPL vmlinux 0x219b2cef	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0x21a563da	clk_get_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21f0fdab	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x2222cb99	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x223af821	nvdimm_volatile_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x226646b6	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x22860245	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0x228628c2	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x22ae7bac	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x22ce4b8a	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0x22e21794	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x22f304ac	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x22f96a53	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x22f9cd96	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0x2300dbf2	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x23085037	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x230b5695	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x230ff8d9	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x2315a82c	clk_mux_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2321aca4	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0x232dc3cb	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x2340f1fe	kvm_vcpu_write_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x23654f69	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x236a5e0e	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0x236f0a83	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0x2373a21a	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0x237c2042	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x238d3ef0	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0x2396c7f0	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0x2398277b	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x2398ceab	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x23c26778	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x23cf3407	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0x23dfeb53	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0x23ec075e	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x23f54e0e	rio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x23f6f72d	of_get_nand_ecc_step_size
++EXPORT_SYMBOL_GPL vmlinux 0x23fb0fe7	of_reconfig_get_state_change
++EXPORT_SYMBOL_GPL vmlinux 0x24011e14	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x2435d955	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0x2438b324	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x24396edf	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x24438a73	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x24794fb3	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x247f5ad6	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x248e71cf	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x24905915	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x24929dc3	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0x249baa91	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x251f2a27	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x25379e73	clk_set_min_rate
++EXPORT_SYMBOL_GPL vmlinux 0x25622204	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x2573e51e	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x25829f47	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x259ff31d	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x25a39249	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x25bdd950	clk_hw_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x25cf157e	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0x25da9487	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x25e4806a	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0x25eddd15	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x25ef3ca1	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x26114d83	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x261956cc	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x261cf59e	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x26484e31	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x2657f5c5	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x26629043	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0x266aca62	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x267d73f7	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0x268bf092	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x268cc6bc	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0x2691a093	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x26ac7331	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26ba36cc	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26d38793	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x26d846a5	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL vmlinux 0x271f8ea3	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0x272a602c	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0x273ba723	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0x274cf5e1	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x27525454	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x27600fcf	of_get_nand_on_flash_bbt
++EXPORT_SYMBOL_GPL vmlinux 0x277034a6	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0x277e6439	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x27c0c4be	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27de69d9	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f049	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x282b4e94	rio_mport_send_doorbell
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x283f3aa9	kvm_read_guest
++EXPORT_SYMBOL_GPL vmlinux 0x285a5f9d	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0x2867f855	of_mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x28882f8a	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0x28b22075	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x28c4bfa7	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0x28c95ebd	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2901fbfa	of_overlay_create
++EXPORT_SYMBOL_GPL vmlinux 0x290620d8	of_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x2921402e	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0x294266cd	of_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x2943dc14	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x29bae5e7	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0x29e79618	__rio_local_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x29ea83cd	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x29f1bdbb	mpic_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x29f92752	kvm_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x29fbfecc	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x2a20848c	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2a24e696	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x2a823a92	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x2a9b5556	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0x2ac1e22c	of_thermal_get_trip_points
++EXPORT_SYMBOL_GPL vmlinux 0x2ac37cf8	kvm_flush_remote_tlbs
++EXPORT_SYMBOL_GPL vmlinux 0x2acaa52b	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0x2add3389	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0x2adedb2a	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0x2aec3a38	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0x2afdd5d7	max_gen_clk_probe
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b5c303b	smp_send_reschedule
++EXPORT_SYMBOL_GPL vmlinux 0x2b952517	clk_has_parent
++EXPORT_SYMBOL_GPL vmlinux 0x2baed152	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x2bb4f579	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0x2bc9cc86	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0x2be7e872	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0x2bed0259	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa985e	nd_cmd_dimm_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2c1009ef	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c5e46a9	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c97f8a2	of_reconfig_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2c9a9e38	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2cad1a65	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x2cb7629d	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x2cbd418c	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0x2cd0b218	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d247a7b	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x2d36c57b	rh_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d4ccc75	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0x2d599b20	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d9aee5c	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0x2dc5a6d1	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0x2e06bcdd	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x2e110450	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0x2e1bd8a6	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x2e1c50c6	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x2e1c6224	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0x2e1da9fb	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e25f9f7	pcibios_map_io_space
++EXPORT_SYMBOL_GPL vmlinux 0x2e2b2927	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e38539a	kvm_write_guest
++EXPORT_SYMBOL_GPL vmlinux 0x2e8d9d88	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x2e8f741c	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x2e9688a2	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ec53d99	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2ecbbeba	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x2ee47b2b	user_update
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f34e3ea	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x2f39f049	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x2f3b57ae	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2f3ebd25	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f4ca20b	flush_altivec_to_thread
++EXPORT_SYMBOL_GPL vmlinux 0x2f640408	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f714b9f	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0x2f87853b	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x2f8c8196	dev_pm_opp_get_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2f964a0f	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x2fba2599	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x2fd918d6	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x2ffa6682	rio_release_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x2ffb5ff7	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0x300000eb	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0x3020c464	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x3020df90	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x30573437	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x30729556	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x3072a545	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x307c157c	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x30825d76	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x308432cf	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0x309406e9	of_thermal_get_ntrips
++EXPORT_SYMBOL_GPL vmlinux 0x309433d3	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0x30af7f08	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x30c71862	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x30c8e93b	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0x30c9b675	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30f24b9c	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0x3100ee5f	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x31183505	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0x312492b6	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x312e9ce0	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x31584100	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0x317051a3	rio_mport_get_feature
++EXPORT_SYMBOL_GPL vmlinux 0x318e316c	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31e3b4f1	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x31f316c1	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x320c8745	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x321bdbb1	compat_get_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x32207a2b	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x32550523	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x32642b44	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x32673f9c	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x3270d592	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x3284ac0d	rio_dma_prep_slave_sg
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x328d3924	of_dma_xlate_by_chan_id
++EXPORT_SYMBOL_GPL vmlinux 0x32b141bc	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x32bc0fcf	preempt_notifier_dec
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32d93645	kvm_get_dirty_log
++EXPORT_SYMBOL_GPL vmlinux 0x3319bb6b	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x33450d8a	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x334a8aea	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x334ba2c4	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x334bf0f4	of_pci_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x336318c1	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0x336b2771	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0x337786fa	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x33885d7a	kvm_vcpu_block
++EXPORT_SYMBOL_GPL vmlinux 0x33c1d27b	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0x33d02a5c	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x33d5c069	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x33eb0e44	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x34083af8	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x340ce1ca	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x3425e2bc	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0x344c5e63	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0x345dac7d	pcibios_finish_adding_to_bus
++EXPORT_SYMBOL_GPL vmlinux 0x346a4f85	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x347fa1b4	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x3488e7f4	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x349c7382	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0x34a1dfa8	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34a8da5f	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0x34ac7d79	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0x34c59bd1	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x34dce120	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0x34e2370d	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x34e2be0e	rio_release_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0x3506be29	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3540d80f	device_move
++EXPORT_SYMBOL_GPL vmlinux 0x356276b4	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x35677296	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x3576596f	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x3579b5d1	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0x3582be1d	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x35a73457	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0x35ab45b2	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0x35bf2acd	nd_fletcher64
++EXPORT_SYMBOL_GPL vmlinux 0x35d3cda3	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x364460af	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x364de272	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x3651377c	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0x36584580	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0x365cb98a	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x368f1fea	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36a64e5c	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0x36b097d5	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0x36b71784	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x36bda7b0	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x36d996bd	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x36f78471	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x371dbd7c	gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x373040b9	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0x3735e050	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0x373f4eec	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x375c5340	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0x378ab84e	devfreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x37ac50da	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0x37d2a40f	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x37d2c2c5	rh_dump_blk
++EXPORT_SYMBOL_GPL vmlinux 0x37ef4a9d	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x37f114ab	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0x37f91464	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x37fc941b	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x3806178c	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x381ee018	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x381f090d	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0x3834e85f	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x3840a54e	clk_register_fixed_rate_with_accuracy
++EXPORT_SYMBOL_GPL vmlinux 0x38438169	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x384a6981	__gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x384fa707	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x385926c9	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x38639300	of_overlay_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x38782879	cpu_remove_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0x389dda32	of_reserved_mem_device_release
++EXPORT_SYMBOL_GPL vmlinux 0x38cbb0bc	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0x38e5bc5a	clk_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0x38e8e2db	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x38f39f19	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x39073b30	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x392add00	dev_pm_opp_of_get_sharing_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x392fe739	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x393cb077	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x394511cc	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x394689a3	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x39597d25	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x395ed48e	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x39617b07	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x3962325d	irq_of_parse_and_map
++EXPORT_SYMBOL_GPL vmlinux 0x3973c2e2	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x397b55a7	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x398f3807	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0x3999ce1b	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x39ad351d	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0x39c62f63	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39d19384	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0x39db1b2f	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x3a1232ca	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a2b1e9e	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x3a316e76	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x3a3db234	divider_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x3a459553	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a69db1a	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0x3a74632d	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x3a7bc905	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3aa6c582	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0x3abd2db6	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x3ac14a92	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0x3ac294b4	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3ad0e201	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x3af7bee4	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x3b00840d	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0x3b0a8687	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x3b0c643f	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x3b3edcec	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0x3b480c76	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x3b56f694	pcibios_unmap_io_space
++EXPORT_SYMBOL_GPL vmlinux 0x3b7b0c22	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x3b92b1eb	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0x3b993167	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0x3b9e7697	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x3ba02065	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x3bafd75a	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0x3bbab52e	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0x3bcf600a	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x3bd574e9	kvm_release_page_clean
++EXPORT_SYMBOL_GPL vmlinux 0x3bd8ecc8	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0x3c2188be	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0x3c50602f	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x3c7a8d48	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x3c85e510	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3c978fa1	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3c98d912	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3ca008df	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x3cc651f0	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cf2dd96	realmode_pfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0x3cf441f6	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x3cf75363	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3cfc3a81	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x3d0c6565	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x3d1cb1ac	of_reserved_mem_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x3d223d99	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0x3d3351fc	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0x3d3cdf44	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x3d612305	iommu_direction_to_tce_perm
++EXPORT_SYMBOL_GPL vmlinux 0x3d68e31e	of_irq_find_parent
++EXPORT_SYMBOL_GPL vmlinux 0x3d8736a8	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x3d8c29d7	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0x3d9431f1	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x3da67a23	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x3dae419d	kvm_put_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x3dc2ae94	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0x3dc526a9	arizona_of_match
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd10ff7	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1a112	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3ddcfa97	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3de006a4	of_pci_range_parser_init
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3df1505e	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x3df4de92	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x3dfa3277	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x3dfc436e	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x3e1f72e0	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL vmlinux 0x3e218887	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0x3e2c4dfe	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0x3e2d6df3	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3e4fa778	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0x3e54a57f	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x3e5a0239	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e77fdca	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x3e8e3deb	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x3ed5fc90	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3ee4359c	nvdimm_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x3eff6e43	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x3f081e66	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x3f1cb321	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0x3f35117d	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x3f518e9a	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x3f6248d8	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x3f7a40e5	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x3f7c32e7	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3f7ed1e0	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x3f9fcfc2	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x3fa5af9c	nd_cmd_bus_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3fafc794	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0x3fb14423	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x3fb89a6b	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x3fd733aa	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x3fe7e4a7	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x3fef7431	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x3ffe8e32	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0x4009a4b4	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x402034b3	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x40318da2	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x4031f893	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x4034afe9	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x40592985	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0x405f35ad	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x4076d785	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x408083ec	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x40a2872e	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0x40a31112	clk_register_divider_table
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40af27be	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0x40d2c17f	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40dd8f65	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x40de65b3	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x40f43209	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0x411ba165	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x41271c65	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x412975a2	rio_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x4149d69d	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x41bc17ba	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x41e988c9	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0x41ed673e	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0x41f0a9ca	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0x420e9786	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0x422a7139	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x422bdf24	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0x4237cffc	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x426b2c92	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x427122b7	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x427de547	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42a6e512	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x42dae139	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0x4325b305	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x433eb9ee	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0x43455d5a	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0x43561459	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x43597a28	of_dma_configure
++EXPORT_SYMBOL_GPL vmlinux 0x43619e1a	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x4375d680	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0x4388e539	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0x438f55a2	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x43969dbe	rh_alloc_fixed
++EXPORT_SYMBOL_GPL vmlinux 0x439d8a14	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0x439db97e	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43a5b6d9	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0x43b466b0	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x43bb8d05	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x43c8b64e	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43d46fb3	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x43db5d33	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x43e180c1	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x43f81957	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x4401ecb8	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0x442742b2	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x4438d98f	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0x445b282d	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0x446e3c47	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x449ad9d1	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x449add42	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x449bbcaf	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44c37a35	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0x44c77df7	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x44f2833a	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x450fb522	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x45206a8c	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0x453b9a1f	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0x454407a1	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x4582bd63	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x458b892f	of_pci_msi_chip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x458eaa2f	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x4592a912	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0x459f8687	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x45aa269d	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x45b665b6	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45e35ce5	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x461a6031	rio_register_scan
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x463f4e6c	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x463fffb2	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x4688c96a	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x46afa9c4	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x46c655cd	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x46cc2e32	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x46d27d5c	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x46de6582	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0x46ea3098	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0x46f46e65	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0x4700e1ef	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x471150fe	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x474f0479	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x478d83fa	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0x4798d27d	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x4799ba1a	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0x47a38a19	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47b14072	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x47bd002d	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x47c4f7fc	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x47de0dc7	clk_unregister_mux
++EXPORT_SYMBOL_GPL vmlinux 0x47fe1363	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0x4817990f	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x481ddcef	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4829e8b9	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x48445842	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x484c7ee9	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x4854dc94	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL vmlinux 0x4860b57d	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x4876571c	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0x48784c0f	to_nvdimm_bus
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x4894ecfb	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x48a1e234	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL vmlinux 0x48a461ad	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0x48a77202	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x48abd62f	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0x48b94052	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x48cebb65	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0x48d3ade8	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x48f85760	to_nd_region
++EXPORT_SYMBOL_GPL vmlinux 0x4909aff9	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0x49157f27	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x4918425d	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x491e6123	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0x494e95f2	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x49542343	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x49565350	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x495f1527	rio_set_port_lockout
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x49e05d76	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x49f58034	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0x4a13ab9e	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4a1b7dc5	dev_pm_opp_get_max_clock_latency
++EXPORT_SYMBOL_GPL vmlinux 0x4a36e45b	generic_access_phys
++EXPORT_SYMBOL_GPL vmlinux 0x4a41c0b2	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a52589f	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x4a7f498e	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0x4a82e8a2	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x4a8d2c9c	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x4a90160e	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4ae50fb7	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x4afefea3	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x4b0bbd1c	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4b0da9ce	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x4b0e7f03	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x4b284144	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4b590e77	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0x4b802a86	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x4b89bb5c	clk_gpio_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0x4b98827c	rh_init
++EXPORT_SYMBOL_GPL vmlinux 0x4bb1190f	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x4bb1da78	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x4c082165	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x4c0ab4ff	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4c13920b	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0x4c2aa17c	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x4c38b6ef	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x4c3a1476	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x4c483cf9	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c645f9e	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4c813b84	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x4c8bd3e3	kvm_get_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x4cd838b4	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0x4d03c2d3	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x4d07c9ad	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4d0f34e0	of_pci_find_msi_chip_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x4d7ae534	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x4d887286	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4dad674b	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x4db08b9a	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0x4dcb6457	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4dcc94a9	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x4dce70d1	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4df5ce21	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x4e0a7933	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0x4e0d8ed5	kvm_vcpu_mark_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e17fca2	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e3e8996	of_clk_get_parent_name
++EXPORT_SYMBOL_GPL vmlinux 0x4e5f3efa	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4e61b9d9	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0x4e667ddf	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0x4e847c42	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0x4ec2ffb1	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x4ed4adcc	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4efed558	of_pci_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0x4f05925c	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4f07e946	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0x4f0a432d	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x4f0c8241	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x4f0e5783	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x4f1c7f9a	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4fbd193b	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0x4fc77666	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4fec03ee	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x4fed1193	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0x500343e9	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0x50082262	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x50084462	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x5008d2f6	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0x500c2003	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x50259f7e	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0x504b7f40	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0x50692a2a	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0x507596d8	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x5080f5ff	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x5083f097	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x508638b3	rio_release_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x50895a5e	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x508d9328	of_pci_get_devfn
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x50ca28be	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50f17a8d	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x50fae510	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x50ffbcca	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x5114c2e4	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0x51467922	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x514e9875	divider_get_val
++EXPORT_SYMBOL_GPL vmlinux 0x5150c1b7	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0x5156cbd9	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x5192d282	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x51aa9890	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x51b65a26	rtc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x51b8262e	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x51ce9bc0	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x51dcb9ce	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5205e64d	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x52200b49	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0x52260c73	kvm_vcpu_gfn_to_hva
++EXPORT_SYMBOL_GPL vmlinux 0x522f538b	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x52512bfe	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x525d8c42	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x527d8cea	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x52924f20	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x52a58447	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x52adca81	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x52b33807	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x52dfbb43	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x5302e271	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5316d06f	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x5335dd11	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x5354f8cb	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x538e66fe	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x53be0748	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0x53c4aaab	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x53e4fad8	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x53f46d16	agp_remove_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x54215db5	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0x542a53e7	nvdimm_pmem_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x542a5fc8	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL vmlinux 0x5435f124	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0x5443edd7	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0x5458fa2f	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x546b4a00	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0x546c5565	ppc_tb_freq
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54af2b26	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0x54cf799f	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x54dfa2f8	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0x54f9964b	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x55028ba2	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x5534ab14	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x55369241	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x556e4390	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x557149af	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x55783335	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x55b2ae8d	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0x55d5316b	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x55f3652d	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x55f51ef3	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0x55fad6b0	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x560c1d13	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0x561ac767	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x5622c803	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x56a7ebec	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x56d48b89	dev_pm_opp_of_add_table
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56d81ad8	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56f4afa2	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x570e7e45	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0x57190b2d	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x57322b36	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x575c5f94	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0x5778d6b5	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0x57842409	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x578be614	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x57976cc3	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x579cae5a	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57aa2c41	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x57c4778c	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x57de9560	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x57f65611	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x58110346	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x581172ae	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x582482a0	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x58336d6a	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x588aecdc	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0x588d1dd8	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0x5892f832	release_pmc_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x5894ba6b	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x589fdfd1	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0x58e24708	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0x58fe9409	rio_inb_pwrite_handler
++EXPORT_SYMBOL_GPL vmlinux 0x58ff87b4	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x5901e098	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0x595fd6c4	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0x5962b087	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x5967017b	rio_request_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0x597ec69b	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x59914496	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x59a3970b	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x59ad2a74	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x59b2adbf	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x59b50967	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x59c2ee25	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x59f6659a	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x59fbf9cb	nvdimm_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x5a1cba30	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x5a33e053	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0x5a38013c	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0x5a48a7db	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x5a6f05c4	of_irq_to_resource_table
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a79402b	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a987e09	kvmppc_emulate_instruction
++EXPORT_SYMBOL_GPL vmlinux 0x5aad1aa9	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x5ad4f0b9	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0x5afd05f6	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x5aff5ef8	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0x5b0a4aa9	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x5b3d978b	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0x5b4a811f	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0x5b4e90b9	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0x5b53b3ea	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x5b58b8e5	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x5b6ffde4	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x5b7de514	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0x5b8cb480	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x5bc1c084	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0x5bcd473a	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5be85861	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0x5c04e511	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x5c1a3bf6	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x5c1dcdd1	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x5c28e329	of_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0x5c384314	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x5c3edae5	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x5c54c60b	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c654dff	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x5c6952da	of_dma_router_register
++EXPORT_SYMBOL_GPL vmlinux 0x5caaa640	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5cc8b49a	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0x5cc978d3	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x5cdc90ab	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0x5ce9906a	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0x5cec5449	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d404329	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x5d4f3c8e	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0x5d5316d9	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x5d5f5dfd	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0x5d60c6d4	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5db6211c	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL vmlinux 0x5dbd24b7	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0x5dc58fe3	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5deb3573	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x5dff2269	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x5e030e2d	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x5e120543	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e5de698	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x5e620715	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x5e653be4	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x5e774d63	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x5ea1283f	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x5ea80666	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x5ee7542e	reserve_pmc_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x5eecdf34	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x5ef1c230	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0x5f067caf	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x5f226035	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x5f2407c7	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0x5f30af19	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0x5f352c4b	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5f416079	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x5f49ed71	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x5f6c15a9	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x5f8edc7c	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5fbc6479	__rio_local_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x5fd4235e	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5fe78362	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x5ff4530c	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x60032715	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0x600518aa	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0x60071ede	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0x60091316	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x600dd572	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0x60467b06	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x6052ed40	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x60543236	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0x60634ea5	nd_blk_region_set_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x608d4b96	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x60bacab5	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0x60cca309	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6122e4bd	of_modalias_node
++EXPORT_SYMBOL_GPL vmlinux 0x612d518d	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0x613a0842	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x6154c1bb	of_gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0x616251cd	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x6163e53d	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x6165dd8d	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x616b07ac	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x61743c27	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x619bb1cd	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0x61a90c54	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x61d5cc0d	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x61f52221	rio_request_mport_dma
++EXPORT_SYMBOL_GPL vmlinux 0x6214b16c	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x622299f6	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x622cc794	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x623765b0	of_property_read_u64
++EXPORT_SYMBOL_GPL vmlinux 0x624a8807	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x624cef6f	nd_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x62796ef4	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0x627cf5c9	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0x62bd5a6d	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x62cf6ac7	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0x62e8954c	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x62f00ba1	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x63038bf1	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x63122612	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0x63150e06	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x6327c131	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x63309f49	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0x6334a8b7	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x634102de	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x634caa23	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x637ce7b7	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0x638900e7	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0x6397929a	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x63a1817a	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x63c38aee	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0x63d178ed	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x63da2e03	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x63e17b86	divider_recalc_rate
++EXPORT_SYMBOL_GPL vmlinux 0x63f14ebe	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x6406da0e	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x6416dc1a	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x6428da4f	rh_attach_region
++EXPORT_SYMBOL_GPL vmlinux 0x64399f9c	nvdimm_bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x6456329e	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x6463a92e	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x64679362	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x646a3b84	pcibios_add_pci_devices
++EXPORT_SYMBOL_GPL vmlinux 0x646dfa91	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x64ac2b20	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x64b7c26d	dev_pm_opp_init_cpufreq_table
++EXPORT_SYMBOL_GPL vmlinux 0x64b819fb	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x64babd14	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x64d4b04a	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0x64e80dfb	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x64eae574	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x65308f57	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0x655c23f1	user_read
++EXPORT_SYMBOL_GPL vmlinux 0x65781593	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x65992d1e	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x65a13d7f	dev_pm_opp_find_freq_floor
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65e84528	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0x65f39154	rio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6601a4ac	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0x660ea006	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x66100d89	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x662c783b	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0x662d02fc	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x6638755b	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x6640b4c4	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0x664b460f	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0x664ef420	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x66611729	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x66844103	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6691d372	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0x6698ab1d	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x66afb53b	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66d3a89f	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x66d4f42f	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66d8a483	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x66e3137a	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0x66e4e6a9	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0x66e8c351	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x66e8ec6f	rio_unlock_device
++EXPORT_SYMBOL_GPL vmlinux 0x66ed62a2	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x66ef275e	kvmppc_pr_ops
++EXPORT_SYMBOL_GPL vmlinux 0x66f1b8db	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x66f6527b	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x670ebc0a	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x67131f87	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x67189829	mpc8xxx_spi_tx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x671e70c4	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0x673c10ad	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6763c1cb	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x676ce872	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x677991df	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0x6779c18a	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0x678a4105	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x6798bf68	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x67c3159c	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x67ddbf31	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x6868ae68	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0x687d5311	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x688d0f03	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x68a9c0a3	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x68b5f3da	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0x68b6a825	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0x68d157f5	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0x68e1322b	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0x6921aa34	compat_put_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x6969a208	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x697cbbb4	threads_per_core
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x69a92753	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x69b2279b	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x69b3c328	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x69b69380	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x69eb80ce	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x69f2446e	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0x69f372cd	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0x69f7a43f	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x69f95f25	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0x69fa3a4b	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x6a137242	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x6a34e194	clk_hw_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x6a35060b	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x6a36125d	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a545736	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a6b5bce	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x6a6cafd2	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a936feb	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x6a9bd094	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x6ab4234e	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0x6abdae05	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0x6acb8d84	ppc64_caches
++EXPORT_SYMBOL_GPL vmlinux 0x6acea0c5	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x6ad22552	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b375b2d	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6b3d24ad	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x6b48a910	switch_booke_debug_regs
++EXPORT_SYMBOL_GPL vmlinux 0x6b4b837e	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6bdbe4ab	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x6bedb63a	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0x6bffb76b	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c4bed6d	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x6c516f21	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x6c638d67	rio_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6c891eb1	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0x6c8bcd8a	of_property_count_elems_of_size
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6cd7c412	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x6ceb9839	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6cf01167	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6d043d52	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0x6d1bc7eb	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d3559d3	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0x6d43f9cb	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0x6d675ae8	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x6d7127e9	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6d74237c	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x6d95c178	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x6d9a1d2f	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x6db4005c	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e051f66	cpufreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6e17e7ca	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6e2361e6	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0x6e2a1281	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x6e379526	kernstart_addr
++EXPORT_SYMBOL_GPL vmlinux 0x6e3a1f3b	clk_hw_get_parent_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x6e3a99d3	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0x6e5829b7	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x6e65913e	nd_mapping_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x6e7c9485	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6e91c278	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x6ea4287d	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6ee21846	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0x6ee392dc	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x6ee901af	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x6ef69f0e	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0x6f03f5c9	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x6f049ead	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f6d5022	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0x6f74a7f1	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x6f76d4be	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x6f7dc8b8	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6fe0a9f6	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6ff0459e	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x70056f5c	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x700eac77	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0x701dde11	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0x702bbf75	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x7039e557	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x703ac45e	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x704afbf2	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x7096c1ef	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x70a789a2	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x70bc786c	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x70be17fb	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70ceaa5f	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70e4725a	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0x710a5a63	of_prop_next_string
++EXPORT_SYMBOL_GPL vmlinux 0x710aedc7	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x714f626b	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x71558004	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0x71621fe0	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x716eee96	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x718334fc	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x7192f992	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0x71990938	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x719e17ff	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x71a2205a	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x71a421eb	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x71a770d8	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x71b7fb57	kvm_vcpu_read_guest_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x71d2fc51	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71fe3ec1	dev_pm_opp_find_freq_ceil
++EXPORT_SYMBOL_GPL vmlinux 0x720a3613	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x720b1aa3	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0x72580986	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x726a6e3c	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x727a2b75	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0x729887c4	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x72a0b915	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x72bb52a6	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x7300eb4e	rio_mport_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x730929e2	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x733624d4	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0x733e343f	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x735efa42	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0x73760ec9	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x73784f73	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73af362a	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x73c1cfbd	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0x73c2554f	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73d19602	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x7422dc45	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x74a542a8	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x74ad600d	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74b6a4e0	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74c49ec9	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x74dc78dd	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x74e94a4e	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x750a44ef	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x75133f6e	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0x75177c8c	kvm_read_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x75329035	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0x753cbc96	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x757b49d2	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0x757c950b	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x757d0e68	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0x75896ded	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x758eb565	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x759139cb	of_pci_check_probe_only
++EXPORT_SYMBOL_GPL vmlinux 0x7595e4b0	agp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x7596b820	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x75c9d8c3	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75eb484c	rio_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x75f2a044	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x75fb9c91	kvmppc_emulate_mmio
++EXPORT_SYMBOL_GPL vmlinux 0x761ed6ec	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x762c0858	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0x76372145	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0x7648c4fa	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x766267c2	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0x76959563	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x76a2e428	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x76b01148	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0x76cab65f	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x76d945a6	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x76d9b876	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0x76e2c0b1	pcibios_alloc_controller
++EXPORT_SYMBOL_GPL vmlinux 0x76e6cc21	rio_unmap_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0x76fb09fa	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x77121165	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x77208bae	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x7730dec4	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x7732d094	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x77386044	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x773a93c5	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x775719ff	rio_mport_chk_dev_access
++EXPORT_SYMBOL_GPL vmlinux 0x7757b51a	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x775b58ae	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0x7764ae6c	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x77bdd654	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0x77d79e0b	power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x77df9215	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0x77ff7cab	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x7807f09e	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x782a3681	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x782c63ec	dev_pm_opp_enable
++EXPORT_SYMBOL_GPL vmlinux 0x78537587	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x78539f1c	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x78694b87	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0x787c882b	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x78856e6a	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0x789f5aa9	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x78abdb28	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78cc5bec	hugetlb_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x78e08b0e	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0x791eaf2c	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x795b6af0	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x79712de7	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x7985ecfa	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x79b98e82	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0x79bda7a8	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x79c480da	rh_dump
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x79e14aac	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x79eed981	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x7a0db8f5	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0x7a1fb734	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a642402	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7a9c713f	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL vmlinux 0x7b02cdce	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b179352	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b3c8ee4	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x7b4f0220	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x7b51663e	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0x7b70ed5c	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x7b7661da	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7b8b75e7	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0x7b8da136	rio_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x7ba2f210	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x7bf83057	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0x7c004e17	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x7c15a5e9	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0x7c1722f6	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0x7c184122	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0x7c1d244b	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x7c7f1b84	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x7c82a862	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x7c899c9c	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0x7c91a61d	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x7c9a7371	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x7ca1a35d	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x7cbbba8b	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x7cc34857	dax_do_io
++EXPORT_SYMBOL_GPL vmlinux 0x7cd23815	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0x7cd437ad	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7ce3daf1	of_dma_is_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cedf677	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7cf208be	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x7d00c65b	nd_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x7d0c2ee5	kvmppc_handle_store
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d9d220d	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0x7da4c6ce	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7db096af	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x7db66116	of_display_timings_exist
++EXPORT_SYMBOL_GPL vmlinux 0x7dbb6f03	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x7dc1e388	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7dee3994	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0x7e1609e8	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x7e17ba7b	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x7e183549	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0x7e2306a3	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0x7e404bfb	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e6bc4ad	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0x7e6d84e4	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x7e710a08	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7e7add2a	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7ea1a2bc	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x7eaf4d36	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x7ec8064c	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x7ece4132	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x7edebeff	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0x7ee0f93e	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x7f008202	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7f13d491	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f331d59	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x7f3c53f3	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x7f41cbad	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x7f5b9c31	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0x7f6f45f4	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0x7f7141a9	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7f7bc710	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7fb6ab91	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0x7fb913bc	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7fcc3cac	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x7fd01fe7	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0x7fd7c1e8	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0x7fdd9128	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7fdf54e3	mpc8xxx_spi_rx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0x7feda1d9	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0x800003df	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x8013a207	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x80146d7b	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0x804ea02d	__find_linux_pte_or_hugepte
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x80767e09	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x807a72b1	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x808ef264	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x80aeda50	dax_clear_blocks
++EXPORT_SYMBOL_GPL vmlinux 0x80baf9fa	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80ce1fab	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x80d10466	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80e9ec03	mpc8xxx_spi_rx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x8114b8d6	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x81474aa7	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8152e111	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x815588a6	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x816da4e3	rio_request_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x81a40dc1	nd_region_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x81e19178	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x81ea841d	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x82191f33	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x822d84c4	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0x8237d054	clk_hw_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x827a627c	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0x8286a27f	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x828c6c33	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x82a72004	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0x82c22716	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x82cdb077	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82e25d90	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x82f5475c	dev_pm_opp_add
++EXPORT_SYMBOL_GPL vmlinux 0x82f91748	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x830b6d43	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0x831a73fd	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x832f61a9	of_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x8342a657	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0x836d61d0	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x83760086	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0x838397e9	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x83cb9426	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x83dd9503	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0x83ef2b91	phy_pm_runtime_put
++EXPORT_SYMBOL_GPL vmlinux 0x83ff25b9	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x84285847	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x84353b9a	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x84368bed	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x847c2719	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x8487a2b6	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x84913b55	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0x84a9ebee	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x84b2ad42	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x84c9e7ca	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x84d6b8c7	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x84f66b07	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x8506baa8	clk_unregister_gate
++EXPORT_SYMBOL_GPL vmlinux 0x850df8b9	clk_divider_ro_ops
++EXPORT_SYMBOL_GPL vmlinux 0x851fda9c	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x85224c21	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0x85743964	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0x85b64d85	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85d47418	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x85dbfcda	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x85ebfb9c	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8624be13	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x8666a7c5	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x867362d5	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x86ba7b00	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x86c77b4a	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x86cd39ef	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0x86ec2a73	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8702e548	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x8727a861	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x8771c411	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0x879eb23c	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0x87a03773	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0x87aff828	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0x87b02e19	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x87b32f62	nvdimm_name
++EXPORT_SYMBOL_GPL vmlinux 0x87bdec86	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0x87d96071	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x87f46db2	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0x8804af3d	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x881ce99c	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x88362d5c	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x8841bd5c	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x88489161	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x885e8514	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x886b759c	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x887c7988	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x887ecee4	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x888306ad	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0x888348ce	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0x889bf32f	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0x88a1a615	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88bf5c34	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x88da1741	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x8908709f	rio_route_clr_table
++EXPORT_SYMBOL_GPL vmlinux 0x891df469	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x8929b8c8	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0x896fe513	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x8972ae3c	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x89a91269	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89bec510	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x89fd1d21	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0x8a011427	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x8a495196	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0x8a554a36	mpc8xxx_spi_strmode
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a7d1b3d	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x8aa1a91f	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8adbcc03	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x8add8b6a	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0x8afc6b44	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x8b03c71a	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x8b149c36	clk_is_match
++EXPORT_SYMBOL_GPL vmlinux 0x8b4f254c	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x8b69e125	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0x8b70a7d9	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0x8b70e8ea	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x8b7cd80b	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8b861038	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8b9058d6	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8ba02978	clk_hw_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x8bac9c5f	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x8beaeaaa	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x8beafaec	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c0560e9	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x8c0bf7f0	rio_mport_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x8c21f208	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x8c2c43c7	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x8c352c5a	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x8c5d45e1	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c651ec2	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c8ead2f	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0x8c9d5040	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0x8caa4c40	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8cae54b5	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x8cb4334b	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0x8cc41d58	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0x8cc57d1f	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0x8cca38d9	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0x8cd43111	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8ce94961	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x8cea765f	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x8ceedcc8	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0x8d0bbc51	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x8d249ba6	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x8d3bb53d	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x8d3dae02	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x8d97beb4	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x8d9b590c	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x8dab05df	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x8dab4462	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0x8db9aa01	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0x8dc0fc96	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0x8dc8bcee	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0x8dcc4d32	gfn_to_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x8de93b6f	nvdimm_blk_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x8dfc48ee	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8dfd5821	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x8e052b20	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x8e189ea2	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x8e1c7d74	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL vmlinux 0x8e2b25c2	videomode_from_timings
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e3befeb	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0x8e51ad1d	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8e51ce70	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL vmlinux 0x8e547e03	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x8e6f89ba	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0x8e7f2922	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x8e8092e0	kvmppc_sanity_check
++EXPORT_SYMBOL_GPL vmlinux 0x8eb0706f	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0x8ee00217	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x8ef9ee37	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f23e5c5	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0x8f29c8be	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x8f3b3ff6	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0x8f4ed87a	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x8f5e4316	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f70b03e	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0x8f7e4ea3	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x8f95107f	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0x8fa6352f	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8faf39dd	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8fb6a18b	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x8fbe3213	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x8fc1eaf4	cpu_add_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0x8fc3dcd6	pcibios_free_controller_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x8fce990c	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0x8fced602	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0x9028a76a	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x902f07ce	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x9040a150	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0x904c46e5	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9055334a	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x906449ae	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x9077d5ea	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x909f560f	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90a3dfea	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x90c54924	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x90d96751	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x90fd7619	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x91003925	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0x912989f8	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0x913fa1be	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x913fdd0c	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x91424ec1	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x914b3b2c	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0x915a8599	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0x9179f10e	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x918cd2c3	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0x9195aec9	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x919f2909	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x91a9df45	clk_register_gate
++EXPORT_SYMBOL_GPL vmlinux 0x91bc7b88	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x91bc8cbb	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91c7ee5d	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0x91d27347	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x91d3fb6e	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x91e60f70	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x91f0c992	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0x91fd5776	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x92058576	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0x920cc389	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x92595a68	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0x92622931	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0x92740b71	devm_power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x92b862ce	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0x92bf16ac	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92f71d89	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x93331d72	nd_cmd_in_size
++EXPORT_SYMBOL_GPL vmlinux 0x93524dc3	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x935519ce	clk_multiplier_ops
++EXPORT_SYMBOL_GPL vmlinux 0x93570ad6	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x936a65f5	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x9381b227	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0x939878a5	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x93a11170	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0x93a6a4b5	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x93ae6fdd	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x93d20a20	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0x93eada89	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x9406e4f6	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0x940fc1f4	of_devfreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x9425afd2	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x943a14d8	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0x9444c4d5	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x944bf9ce	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0x946f734e	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x949f7342	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x94a79ebe	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x94ac9eb0	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0x94b4b397	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0x94d972b7	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x94e371e6	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x9523afc6	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x9559a0ed	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x958a20a6	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x9599b9cd	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x95bbe282	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95be7d1a	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x95c89eba	rio_release_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x95d740b0	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x95eda5ea	pcibios_claim_one_bus
++EXPORT_SYMBOL_GPL vmlinux 0x95f11264	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x95fbfb4f	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x960483ad	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9663a5bb	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0x96b0e8c8	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x96b68379	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x96b801a9	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0x96b8d919	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0x96bdd174	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x96e0b078	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0x97015c3d	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0x970d19da	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x971ea716	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x9735f061	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x974910c1	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x974fcf1a	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x97713081	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x97728b17	dev_pm_opp_find_freq_exact
++EXPORT_SYMBOL_GPL vmlinux 0x97852356	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0x97951930	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x9799b212	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0x979e5c99	of_regulator_match
++EXPORT_SYMBOL_GPL vmlinux 0x97bafddb	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0x97c41516	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x97ca90a9	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x97d94259	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x97f2146a	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0x9801ed0a	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0x98227b76	fsl_spi_cpm_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9825d5e0	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x982c9e17	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x982cd486	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x983c7494	rh_detach_region
++EXPORT_SYMBOL_GPL vmlinux 0x983f7c0c	__clk_mux_determine_rate_closest
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x98599121	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x98944eb3	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0x98a02a70	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x98b29028	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x98f9f73d	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x9913be52	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x99756a3a	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x998d79d6	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x999aec23	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0x999f5c77	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0x99a9ff9a	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x99ad7ca5	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99c087ab	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x99dbac53	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x99ff97ba	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x9a009e6b	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a2b2c6a	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x9a2f1dbc	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9a3b20f1	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x9a41ca7a	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x9a49d937	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0x9a678576	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9aad6540	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x9ab09b31	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x9abeb259	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9b1148b8	rio_local_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x9b3206ff	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0x9b53616f	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0x9b736b8c	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x9b922f1a	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0x9ba2bb2b	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x9bb873a0	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9bca03ca	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0x9bd61020	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0x9bddb57f	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c68fe18	clk_hw_get_num_parents
++EXPORT_SYMBOL_GPL vmlinux 0x9cad43fd	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0x9cbe47c2	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x9cc0364e	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0x9cd42733	of_pci_range_parser_one
++EXPORT_SYMBOL_GPL vmlinux 0x9ce749b1	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x9d060b0e	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x9d55ad33	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x9d6864ae	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x9d7d628c	fsl_rio_mcheck_exception
++EXPORT_SYMBOL_GPL vmlinux 0x9d843b89	of_usb_host_tpl_support
++EXPORT_SYMBOL_GPL vmlinux 0x9d84ea8d	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x9d8d2542	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x9d9d5489	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9df21a7d	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x9e0c45a2	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x9e152c30	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e482ce3	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x9e55fda2	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0x9e62c079	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x9eccacad	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x9ed1d463	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9f35b604	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x9fa12c63	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x9fa3b307	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0x9fbb1009	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x9fc1b4be	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9fe97c24	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x9ff08f06	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0x9ff36269	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x9ff8f11b	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xa01fa46d	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0xa0208e02	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xa0247320	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xa039bb0b	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xa0546e48	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0xa071e996	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xa0902e51	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0xa092eaba	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0xa09db322	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0xa0a27fff	pci_address_to_pio
++EXPORT_SYMBOL_GPL vmlinux 0xa0a5a5da	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xa0afbb84	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xa0b0422d	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0xa0b8bd27	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xa0d4c87b	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa0e824f6	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0xa0e853b6	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa0fd178d	clk_hw_set_rate_range
++EXPORT_SYMBOL_GPL vmlinux 0xa102bb79	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0xa11a374e	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0xa11feaff	dummy_con
++EXPORT_SYMBOL_GPL vmlinux 0xa12d3ba5	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xa16677c7	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0xa1689a3c	__nvdimm_bus_register
++EXPORT_SYMBOL_GPL vmlinux 0xa16c8063	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xa1722c2d	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa174b0c2	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0xa17ff3ef	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa1976e45	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0xa1a42c63	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0xa1aacef6	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xa1ab318d	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0xa1d226be	mark_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0xa1ec7976	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0xa1ed9c8b	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xa1fb7043	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa2128052	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xa213abca	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0xa219527c	of_irq_parse_one
++EXPORT_SYMBOL_GPL vmlinux 0xa22f7eba	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xa25683ec	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa2718017	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa28aaf29	rh_create
++EXPORT_SYMBOL_GPL vmlinux 0xa2966fdb	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0xa2ac5519	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2cbd550	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xa2cd4684	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0xa2e90034	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0xa2ff2f90	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0xa3068b72	of_clk_del_provider
++EXPORT_SYMBOL_GPL vmlinux 0xa334e126	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0xa3402d45	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa344c474	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa34734cf	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xa34aa66a	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0xa34eacac	pcibios_free_controller
++EXPORT_SYMBOL_GPL vmlinux 0xa35ac5a4	of_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0xa3604874	of_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0xa36d3ba3	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0xa36fd5a4	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xa38223f0	of_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xa384918b	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3a2d9af	walk_system_ram_range
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3c63719	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0xa3cf7f41	__rio_local_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xa3d35a2a	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa3d6b714	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0xa3e16693	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa42a19e2	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xa466f78b	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0xa4796972	cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa48f6b32	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xa4951962	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xa4af09f6	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xa4ce1896	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0xa4f49317	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xa50144ae	kvm_vcpu_gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xa53b1490	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0xa57ba2f6	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xa5833251	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa5b00659	ppc_proc_freq
++EXPORT_SYMBOL_GPL vmlinux 0xa5b5726e	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0xa5d6f9df	kvm_write_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5efe460	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xa6029b47	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0xa60b803b	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0xa6147827	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa64c5196	mpc8xxx_spi_tx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0xa6647139	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa6888097	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xa69d36e0	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa7218b64	kvm_init
++EXPORT_SYMBOL_GPL vmlinux 0xa723bf67	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0xa7318a97	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0xa754beaf	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xa76c4c80	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0xa76cc191	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0xa7bddc8a	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xa7c05aff	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa7c0e96f	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xa7d21dd5	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0xa7d3ca73	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0xa7e65f15	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0xa7e9874c	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0xa7f56d8c	of_property_read_u32_index
++EXPORT_SYMBOL_GPL vmlinux 0xa7ff8617	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0xa842c2ea	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa85db4c8	arizona_of_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xa8847020	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0xa898c32f	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xa8b5218c	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa917645b	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0xa91bdf02	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0xa931b56b	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa9376dc7	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xa948c1a9	flush_fp_to_thread
++EXPORT_SYMBOL_GPL vmlinux 0xa94fb7e1	kvmppc_hv_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa957139d	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0xa96d6704	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0xa9760bdf	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0xa991aa8b	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0xa99b86eb	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0xa9adeae0	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0xa9aef2e1	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL vmlinux 0xa9b3a3b2	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0xa9bd4a7e	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0xa9c51ca0	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0xa9cb58cb	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0xa9ce341e	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0xa9e09afa	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9f04a9a	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0xaa17a2e2	rh_alloc_align
++EXPORT_SYMBOL_GPL vmlinux 0xaa2eb12d	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0xaa5094e2	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0xaa73a733	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xaa8233cb	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaaca3515	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0xaaed93ee	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xaaf4410f	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0xab1fe291	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0xab29ad96	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0xab2e6905	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0xab567d31	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xab59d373	kvmppc_free_lpid
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab882909	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0xab965a84	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0xaba2db15	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0xaba9bb99	rio_dma_prep_xfer
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabcef848	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0xabd3d40c	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0xabdfc3cc	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xabfec465	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0xac0d42bc	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0xac12a25f	__rio_local_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xac1dd013	of_cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0xac250cb1	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0xac6ba9d1	mpc8xxx_spi_tx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0xac85d265	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0xaca02c9f	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0xacb8f848	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xacc00227	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xacd28506	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0xacd58574	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xacde95f1	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0xace196c4	device_create
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xacfe997e	powerpc_firmware_features
++EXPORT_SYMBOL_GPL vmlinux 0xad10a30f	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0xad1dfdf7	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0xad22cacd	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xad4576e6	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0xad6d47ef	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0xad961ff2	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0xad9960e8	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xadaa2916	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0xadabd7a2	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xaded9da1	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xadfc82c7	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0xae1d25bd	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0xae2a07e3	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0xae383af0	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae81922b	of_overlay_destroy_all
++EXPORT_SYMBOL_GPL vmlinux 0xae8cb677	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0xae975eeb	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0xaed7f2b6	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0xaf14f88c	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0xaf7083c1	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xaf745ea5	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xaf7e04f1	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0xafbdeea3	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xafc2682a	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xafc2eb82	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xaff27de4	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0xb00340b0	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0xb00b833e	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb0418eda	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xb06b91a3	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0xb077e70a	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xb08cf53c	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0xb0b4acf3	kvm_vcpu_gfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0bd0ef5	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0xb0c36f60	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0xb0cc2dc4	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0xb0cf98c1	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0xb0d1656c	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0xb1055c48	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0xb1233333	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0xb13eb354	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb162c703	of_get_regulator_init_data
++EXPORT_SYMBOL_GPL vmlinux 0xb1637de1	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xb1763fdb	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0xb1978900	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0xb19a7dba	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xb19c6ba3	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1b370bd	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1cdc275	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1e6085f	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xb1fd80f9	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0xb20364fe	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb22429e6	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0xb23163a2	devfreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb24a8397	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0xb24dd216	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0xb26a1add	elfcorehdr_addr
++EXPORT_SYMBOL_GPL vmlinux 0xb272626d	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0xb2873180	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xb298bd62	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb2a4268d	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0xb2beb5b4	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xb2e5978b	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0xb2ed1ab6	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0xb317f3a8	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb33d944d	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xb347bb2c	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0xb38c4773	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0xb399c0a4	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xb39c350a	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb3a0a913	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0xb3d03889	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xb3d0714e	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb3ed9807	dev_pm_opp_get_suspend_opp
++EXPORT_SYMBOL_GPL vmlinux 0xb403b06a	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0xb40e79b7	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xb41fe359	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0xb45ca420	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0xb4635dc0	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0xb47c0b9d	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xb4839057	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0xb487f60c	rio_mport_class
++EXPORT_SYMBOL_GPL vmlinux 0xb488588e	tb_to_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4cebc8e	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0xb4e17425	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb5052c5d	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb5127d50	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0xb51a5103	kvmppc_ld
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb530c0fc	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb562dece	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0xb57c5973	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0xb5848bae	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5aa10af	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb5c6494b	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb5c8edf4	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0xb5de1c95	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb5f1b1ae	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xb60b5707	of_i8042_aux_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb666376e	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb676c81c	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0xb67a7d1f	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0xb68cab1b	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb6ac9328	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6d24651	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb6d6f290	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0xb6e012ad	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0xb6e6d99d	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb6ed1033	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0xb6fafdb6	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0xb719bc39	of_clk_add_provider
++EXPORT_SYMBOL_GPL vmlinux 0xb72eb550	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0xb7329c06	clk_set_phase
++EXPORT_SYMBOL_GPL vmlinux 0xb770daa7	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xb77223e2	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xb786e77d	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb79ebd6c	rio_request_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xb7e4bbca	nd_device_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xb7ef5e6d	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0xb7f3c6ea	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0xb7f452f2	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb80501bd	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0xb828f761	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0xb8296bd3	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0xb83aefb1	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xb83d0a95	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0xb87dc4ce	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb891ea0e	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xb8988412	clk_register_mux_table
++EXPORT_SYMBOL_GPL vmlinux 0xb8b28d3b	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb902440d	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb911d4a4	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0xb91f1f46	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0xb9230e31	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xb92942af	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0xb9343d85	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0xb9451c7a	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0xb94734af	rio_mport_get_efb
++EXPORT_SYMBOL_GPL vmlinux 0xb97c3c2e	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0xb98cc136	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb9aaf586	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0xb9b1e777	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9c70ad7	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xba08b670	of_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0xba2387b7	dev_pm_opp_is_turbo
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba3aed93	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xba48421a	of_irq_parse_pci
++EXPORT_SYMBOL_GPL vmlinux 0xba5996dd	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xbab03fd0	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbaca035c	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xbaf351a5	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0xbaf6d630	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xbaf930e7	of_irq_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0xbafa42d6	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbafb8c86	clk_fractional_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0xbb015501	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0d71bf	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0xbb1f6ee3	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0xbb336e8f	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0xbb33e095	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0xbb405bb8	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbb596cd6	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbb6f025a	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0xbb8e0eaf	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0xbb9bf3f6	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0xbb9ebe0e	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xbb9f0340	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0xbbc8cd05	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xbbe67011	kvm_vcpu_write_guest
++EXPORT_SYMBOL_GPL vmlinux 0xbbeb8f12	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0xbc49bde3	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xbc644749	rio_request_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc6d25ab	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0xbc8e595d	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcca7c76	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbce23c08	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xbd1b8c2e	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xbd2ef279	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xbd392776	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0xbd3c0312	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd4a8c0e	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd671048	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xbd7fd5bf	pcibios_remove_pci_devices
++EXPORT_SYMBOL_GPL vmlinux 0xbd84b425	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbd88d881	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xbd8db6ab	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbdd74efb	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xbde8dc00	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe1c4175	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xbe1c97bb	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xbe234770	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0xbe2a3888	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xbe417e31	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0xbe467f11	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe886197	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xbe96dfd8	of_reconfig_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbebcd541	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xbec8d1c8	analyse_instr
++EXPORT_SYMBOL_GPL vmlinux 0xbecfaf75	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0xbed61f64	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0xbee197d9	to_nd_desc
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbeefef50	clk_gpio_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xbef91a6b	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf1a9c50	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xbf1cc04b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xbf255682	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0xbf3e01c7	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0xbf3f0f35	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbf626287	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0xbf66f359	rio_dev_get
++EXPORT_SYMBOL_GPL vmlinux 0xbf9147d1	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xbfa79e6a	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xbfb91674	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xbffde8ec	compat_alloc_user_space
++EXPORT_SYMBOL_GPL vmlinux 0xc02678d3	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xc026c06f	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xc02bb77e	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xc02bec3c	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xc030e535	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xc061367e	mpic_msgr_get
++EXPORT_SYMBOL_GPL vmlinux 0xc063fb28	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0xc065a455	cpu_core_index_of_thread
++EXPORT_SYMBOL_GPL vmlinux 0xc08092d7	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc088b56a	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0xc0a35a86	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0b0af17	kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc10ef2f7	nvdimm_create
++EXPORT_SYMBOL_GPL vmlinux 0xc12b554d	rio_mport_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xc131c79c	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc1380db3	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc13cbce6	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xc155d843	gfn_to_pfn
++EXPORT_SYMBOL_GPL vmlinux 0xc15dbeb3	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc1ae44c6	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0xc1c79019	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc1cabe7d	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0xc1d81e26	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xc1e5ac4e	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0xc2083203	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc23069b2	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0xc24dfc8d	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc297acd1	of_devfreq_cooling_register_power
++EXPORT_SYMBOL_GPL vmlinux 0xc2c25342	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xc2d6108f	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0xc2e8a5fb	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0xc3054b92	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0xc316ba58	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0xc31b9fff	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0xc33e2543	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc357923c	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xc3679a90	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc3764a3e	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xc38f36d9	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc39f13cc	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0xc3a04506	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc3ae3a51	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0xc3bda1c0	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xc3c136b0	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0xc3e40f9e	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0xc3e4e8d2	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc3eb3feb	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0xc426ac57	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc42a871e	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0xc44e8bb7	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0xc45005a0	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc495154a	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xc4a16a61	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xc4bc8913	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0xc4bdc3ce	of_fixed_factor_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4fd7997	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0xc5055285	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc51d4371	put_device
++EXPORT_SYMBOL_GPL vmlinux 0xc5232114	of_clk_parent_fill
++EXPORT_SYMBOL_GPL vmlinux 0xc52594ab	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0xc529ea76	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc569d8ce	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0xc57024ea	of_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc586edac	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xc58a1687	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xc5a0debc	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xc5a2c19f	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc5cd5fe5	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc5d681f2	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc5d9bb65	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0xc5e4e6fd	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc5ebca4d	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0xc606cd3c	boot_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc627431a	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc63e7d93	static_key_deferred_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc6407778	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc6693678	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0xc679741d	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xc68aa252	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xc6915bed	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6a4a872	__clk_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc6c71856	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0xc6fb0df0	kvm_io_bus_write
++EXPORT_SYMBOL_GPL vmlinux 0xc70e4b59	kvmppc_claim_lpid
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc75f8fc4	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0xc768e1bc	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0xc78ca7b3	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7bbdb02	md_run
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7d1b02f	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0xc7e0fec2	of_dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xc7e2dc7d	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0xc7e38e2d	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7eaf474	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0xc7edae64	dev_pm_opp_of_remove_table
++EXPORT_SYMBOL_GPL vmlinux 0xc7ee798b	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xc7f73d17	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc820d82e	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0xc860809e	cpu_add_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0xc874b05c	rio_release_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc8889ee7	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc8a27df9	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc8e7e656	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc914a8b9	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0xc9163e8a	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0xc9195da0	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc93bd0db	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0xc9543f2c	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc95d41e4	of_alias_get_id
++EXPORT_SYMBOL_GPL vmlinux 0xc9641b48	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0xc9714625	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xc974d676	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc97d1140	cpufreq_cooling_get_level
++EXPORT_SYMBOL_GPL vmlinux 0xc992e896	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xc9989e5b	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc9aae69b	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xc9ace1be	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0xc9b7dbfd	dev_pm_opp_free_cpufreq_table
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xca16bf16	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0xca299134	dev_pm_opp_get_freq
++EXPORT_SYMBOL_GPL vmlinux 0xca3f72b6	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0xca599360	early_find_capability
++EXPORT_SYMBOL_GPL vmlinux 0xca6ee167	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0xca70e027	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xca7a9f54	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xcaa08f33	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0xcaa17893	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcadcbe36	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0xcae474aa	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb5491d3	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0xcb5ee621	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0xcb6694bd	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0xcb6ea9ad	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xcb75d491	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0xcb85d2ab	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcb8ae92c	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xcb946c1b	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0xcbb1f64e	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0xcbd17c6b	kvmppc_handle_load
++EXPORT_SYMBOL_GPL vmlinux 0xcbdfda3c	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcbf793af	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcc0d746d	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0xcc0e20d7	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0xcc0f1009	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xcc1920cb	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xcc3b42b2	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0xcc44961f	kvmppc_alloc_lpid
++EXPORT_SYMBOL_GPL vmlinux 0xcc46f37f	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xcc4f3bca	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc98cb6e	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0xccae9ebe	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0xccbbeaa9	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccec82ce	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0xcd04a4db	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0xcd1447cc	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0xcd2c05a9	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0xcd5c4502	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0xcd87479b	get_device
++EXPORT_SYMBOL_GPL vmlinux 0xcd881d3d	kvmppc_prepare_to_enter
++EXPORT_SYMBOL_GPL vmlinux 0xcd8fd097	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcda06d70	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcde80876	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xcdeaa1d0	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0xcdfddbdc	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0xce151a36	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0xce351d08	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce76d746	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xce8072f9	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0xceb1f126	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0xceb22755	mmput
++EXPORT_SYMBOL_GPL vmlinux 0xcecc5470	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0xced95a98	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcf1d1700	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0xcf244a19	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf5b8976	of_platform_populate
++EXPORT_SYMBOL_GPL vmlinux 0xcf6ad24e	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xcf757f7b	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0xcf762486	of_pci_msi_chip_add
++EXPORT_SYMBOL_GPL vmlinux 0xcf9636e6	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0xcf9cb953	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0xcfaafe52	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc4ddd9	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfd3221a	clkdev_create
++EXPORT_SYMBOL_GPL vmlinux 0xcfe4b01d	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xcff3fcdf	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd0072aee	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd032d33b	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd03dc9ef	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd0685ef9	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0xd07f50ac	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd0a281d6	fb_sys_write
++EXPORT_SYMBOL_GPL vmlinux 0xd0be93c2	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd1451a19	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xd1468d8c	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0xd15016d6	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0xd15da468	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd1926669	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xd19e4a54	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0xd1d12ecb	device_del
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd2022821	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd238f9c0	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0xd2398a48	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xd23fea62	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0xd245d181	rio_get_comptag
++EXPORT_SYMBOL_GPL vmlinux 0xd25205ed	hugetlb_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd261839c	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xd26c82d1	gfn_to_hva
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd27e102f	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xd2817892	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xd28b8ed2	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0xd292cfad	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd296c09f	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xd2aec508	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0xd2b455bf	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0xd2cab963	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd3360c16	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd348d17d	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xd39087aa	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3d83c39	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xd3e5a06f	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd404a937	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd4078689	nvdimm_bus_check_dimm_count
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd426378f	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xd43fed6c	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0xd4487fd5	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd44cce3e	kvmppc_st
++EXPORT_SYMBOL_GPL vmlinux 0xd45b6147	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0xd476c299	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0xd47ea4ca	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0xd4a93f23	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0xd4b1e3e3	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xd4bd66a0	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4cb297f	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0xd4db062c	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xd4f39ed8	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xd56b5f64	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0xd586a836	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0xd5a87c92	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5cc6675	rio_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xd5f9d1fa	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0xd5fdb2a5	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd61c6f65	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0xd61caf7f	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xd627e6ea	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0xd6447718	of_console_check
++EXPORT_SYMBOL_GPL vmlinux 0xd6464d21	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd68f1306	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xd6d9c42e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0xd6e0075d	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xd6ebb667	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0xd6f603ae	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xd6feefa5	agp_num_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd72bcef4	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd773e6f1	kvm_vcpu_read_guest
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd7b86951	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xd7c32dc0	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0xd7db9c83	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xd7e4449e	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0xd7f16d75	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0xd7fc3e98	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd8101df1	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xd8143a8b	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xd8177229	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd828a786	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0xd82e7379	rq_flush_dcache_pages
++EXPORT_SYMBOL_GPL vmlinux 0xd830e6a1	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xd844ea60	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0xd862ba2b	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xd8719b02	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd88354ec	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0xd8a2260c	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd8a8bca8	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0xd8ad103b	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xd8b11949	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0xd8c2b0bc	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd8cbb689	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd8ccefe3	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xd8ddd455	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0xd8f9b4d2	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0xd93430b7	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xd93e8e0e	of_get_videomode
++EXPORT_SYMBOL_GPL vmlinux 0xd93f1ad2	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94aa457	display_timings_release
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd976af07	mpc8xxx_spi_rx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0xd9a1075d	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0xd9c45886	dax_zero_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xd9c97a38	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0xd9d8502f	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0xd9d99c03	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xd9dd44ac	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0xd9eb352f	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xd9f4d09d	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xda028ed1	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0xda070ff6	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xda0a4d22	mpic_msgr_enable
++EXPORT_SYMBOL_GPL vmlinux 0xda1c9a5c	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0xda2aacd9	fsl_spi_cpm_bufs_complete
++EXPORT_SYMBOL_GPL vmlinux 0xda3fac3d	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0xda50ac66	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0xda8cb2e5	threads_core_mask
++EXPORT_SYMBOL_GPL vmlinux 0xda9beed2	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0xdae715e0	videomode_from_timing
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdaf8844d	rio_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xdaf9af8e	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0xdb0b8b55	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0xdb30cd3c	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb7647be	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0xdb87f075	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb91e05c	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xdbd499e9	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0xdbdc6f5d	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0xdbe8f0e6	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0xdbf2cd58	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xdbf4f2a5	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0xdbf68bf2	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc33f0b9	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0xdc3bad6e	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0xdc6b5673	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc85d938	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xdc8b2acc	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xdc9dc712	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdcf057be	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0xdcf9cf3b	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xdcff804f	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd249ef2	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd39d087	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0xdd57e2b5	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0xdd729424	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xdda623d2	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xddac6ca6	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xddacdeea	fsl_spi_cpm_init
++EXPORT_SYMBOL_GPL vmlinux 0xddb71e50	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xddf5a82e	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xde031c14	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xde3668ae	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0xde3769e2	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xde42b669	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xde46e353	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xde52413f	isa_bridge_pcidev
++EXPORT_SYMBOL_GPL vmlinux 0xde59c16a	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0xde5e927c	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0xde5fbde9	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xde60315b	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xde673f89	fb_sys_read
++EXPORT_SYMBOL_GPL vmlinux 0xde72e38c	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0xde74bb04	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0xde9e2403	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xdead73d2	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0xdecc2cb1	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xdf0c3252	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf14edb2	nd_numa_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xdf1a4ce6	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0xdf30d884	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xdf480cb1	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0xdf4bc23c	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0xdf52fe32	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xdf582c53	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0xdf80476d	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0xdfa47cbd	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0xdfb7512f	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0xdfbb3a5f	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe00c3539	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0xe00cdf8f	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0xe011bfba	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0xe0220000	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe034e9cc	kvmppc_kvm_pv
++EXPORT_SYMBOL_GPL vmlinux 0xe036b3e9	mpic_msgr_put
++EXPORT_SYMBOL_GPL vmlinux 0xe037cf8a	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0xe03a9a60	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0xe0544b9b	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0xe0573559	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0xe06d9f09	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe0860ba0	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0xe089cfcc	agp_memory_reserved
++EXPORT_SYMBOL_GPL vmlinux 0xe0b1c103	clk_set_max_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe0b8e5ea	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0xe0c21bc8	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0xe0e3dffd	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0xe0f67c5a	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0xe0f9e2e9	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xe14a5218	rio_lock_device
++EXPORT_SYMBOL_GPL vmlinux 0xe1746349	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xe1753997	of_thermal_is_trip_valid
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe17c5f9f	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0xe18f5bc8	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe19eb1c4	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe1ad80e3	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0xe1ade37c	dax_pfn_mkwrite
++EXPORT_SYMBOL_GPL vmlinux 0xe1b23ae4	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0xe1bd6c99	rio_init_mports
++EXPORT_SYMBOL_GPL vmlinux 0xe1cb6dbf	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xe227ae5c	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0xe239e499	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xe23b6342	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xe24180ad	rio_map_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe2bece83	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0xe2dccbb3	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0xe2f134d8	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe32fda54	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0xe3515360	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0xe38692d9	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xe38d2247	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xe38dc5ea	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0xe39afec3	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0xe3a92f74	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0xe3c9205d	rio_request_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xe3d11587	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0xe3d38f0a	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe3d7750e	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xe3e82123	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xe3eb5945	max_gen_clk_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe3f0fa98	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0xe40198be	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0xe407b8f4	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0xe40b09a3	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xe41f3975	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xe428d154	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0xe43d2217	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe4862ebb	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe490b0fd	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe49d19db	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe4c031f8	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4d07674	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0xe51c040f	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe52b4b1f	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0xe5370852	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe5540302	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe56446f8	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xe5866cf9	of_scan_bus
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5a3929d	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe5aa626e	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0xe5b7383e	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe5bc2851	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xe5ea8be5	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0xe6185656	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0xe628dd6b	fsl_spi_cpm_free
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe665d18e	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe689b214	clk_register_divider
++EXPORT_SYMBOL_GPL vmlinux 0xe689f6be	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xe6a6e143	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe6ff0010	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0xe6ff40d4	rio_route_add_entry
++EXPORT_SYMBOL_GPL vmlinux 0xe716f66b	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0xe7274426	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0xe72d99cd	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0xe7320a7d	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0xe736982f	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xe73818a7	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe73d21fa	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe768d444	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe77490db	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe78eef90	of_prop_next_u32
++EXPORT_SYMBOL_GPL vmlinux 0xe7a66728	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0xe7abfa04	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe7b804f9	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0xe7bb0602	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0xe7c28e8a	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe7c5e2ff	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0xe7d5e9f9	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xe7f18b3c	threads_per_subcore
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe80af294	thermal_zone_of_sensor_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe85b2004	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xe85c55e7	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe85d5716	arizona_of_get_named_gpio
++EXPORT_SYMBOL_GPL vmlinux 0xe85f71c1	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xe866d820	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0xe87e055c	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe89bd243	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xe8a15ec5	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0xe8dceec0	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0xe8f46963	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0xe8f71ef0	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe9549d3a	of_platform_depopulate
++EXPORT_SYMBOL_GPL vmlinux 0xe96395d3	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xe96cdd66	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe9711d6e	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0xe98006eb	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0xe982a242	clk_register_fixed_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe98df787	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0xe9a3391f	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xe9afefc0	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0xe9b9349e	clk_register_gpio_mux
++EXPORT_SYMBOL_GPL vmlinux 0xe9b9c147	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xe9dcb02e	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0xe9eeaec5	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea235958	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0xea38ff49	dev_pm_opp_of_cpumask_add_table
++EXPORT_SYMBOL_GPL vmlinux 0xea3ba223	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xea3defeb	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea5d1dac	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0xea5d499e	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0xea5d7eee	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0xea628c20	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0xea74a4cf	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0xea7ee1bb	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xeab7ab31	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xeabcfe65	of_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0xeac16868	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0xead7f34e	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0xeaff6623	of_get_display_timing
++EXPORT_SYMBOL_GPL vmlinux 0xeb091b6e	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0xeb2de401	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0xeb3b47ef	kvm_vcpu_init
++EXPORT_SYMBOL_GPL vmlinux 0xeb3f9000	device_register
++EXPORT_SYMBOL_GPL vmlinux 0xeb59f151	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0xeb7d183e	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0xeb8ae736	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0xeb8c8be8	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0xeb958b86	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0xebccadfe	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xebee8be1	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec3e6402	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0xec6e064f	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xec91e687	vcpu_put
++EXPORT_SYMBOL_GPL vmlinux 0xeca7e7cf	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0xecaff5ac	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0xecd1cc65	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0xecdcc52a	clk_register_fixed_factor
++EXPORT_SYMBOL_GPL vmlinux 0xece30a27	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xecf0f6fb	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0xecfd0373	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0xed05fd2f	kvm_vcpu_gfn_to_pfn
++EXPORT_SYMBOL_GPL vmlinux 0xed25b8f7	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xed2a550e	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0xed5edafb	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0xed981a16	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xedaa2955	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0xedb188e7	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xee0110e6	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xee140673	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0xee408266	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0xee430ef0	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee7b66e0	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0xee971caa	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xee993670	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0xeec695ed	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xeee22cb8	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xeef56c47	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0xef11cb35	__tracepoint_kvm_ppc_instr
++EXPORT_SYMBOL_GPL vmlinux 0xef146cca	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xef1df306	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xef35a911	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xef3f7a0b	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0xef57d8e1	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6d007a	sigset_from_compat
++EXPORT_SYMBOL_GPL vmlinux 0xef764889	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xef984377	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefa646c8	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xefc4d523	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0xefdbfb44	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf0063ada	of_irq_parse_raw
++EXPORT_SYMBOL_GPL vmlinux 0xf00be3a4	of_fixed_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0xf0227768	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0xf026bda1	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xf02720eb	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf04250ce	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xf04492d1	inet_csk_compat_setsockopt
++EXPORT_SYMBOL_GPL vmlinux 0xf060fe9e	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0xf06b9e66	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xf06e5012	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xf071c160	inet_csk_compat_getsockopt
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf0777df1	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xf07ef047	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xf08232b0	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0xf0be63b7	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0c9e6fd	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0xf0cd4733	of_get_nand_ecc_strength
++EXPORT_SYMBOL_GPL vmlinux 0xf0d7c87b	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0xf0df1b67	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xf0e97916	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf10563d0	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xf1412ec0	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0xf149b869	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0xf14e4d24	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xf1508829	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0xf15404b1	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0xf158f170	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0xf16c7a4a	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf17b3b43	to_nvdimm
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf1a62b6f	of_i8042_kbd_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf1af95e2	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1d83fbe	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf1e8bbde	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0xf1fde4dd	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf2090fe6	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf2308b90	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0xf272c2e4	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf2a35099	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2c4542a	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0xf2da994f	fsl_spi_cpm_bufs
++EXPORT_SYMBOL_GPL vmlinux 0xf2de24df	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf3012f6c	rh_free
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf33dc43c	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xf345fbb8	dev_pm_opp_of_cpumask_remove_table
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf3801ca6	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf39704ab	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3c6e2df	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf462f8c6	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0xf46ee59a	rio_get_asm
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4a0853c	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0xf4b0a64f	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf4c91baf	max_gen_clk_remove
++EXPORT_SYMBOL_GPL vmlinux 0xf4da3546	kvmppc_init_lpid
++EXPORT_SYMBOL_GPL vmlinux 0xf4da7748	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0xf4daafc5	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf5082589	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf521778e	to_of_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0xf53518b3	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xf535ddbc	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0xf5379771	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf5504ad7	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0xf550edb3	rio_mport_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf553f88a	of_dma_get_range
++EXPORT_SYMBOL_GPL vmlinux 0xf562c3c3	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0xf569bf0c	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xf5720a8e	rio_register_mport
++EXPORT_SYMBOL_GPL vmlinux 0xf5848388	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xf58a5fb1	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xf59939ea	clk_debugfs_add_file
++EXPORT_SYMBOL_GPL vmlinux 0xf5a19db6	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5aac999	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0xf5ac6b25	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0xf5bcf1b2	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0xf5dff756	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0xf5e7f053	rh_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xf639a5b4	of_irq_get_byname
++EXPORT_SYMBOL_GPL vmlinux 0xf63a42d8	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0xf66b2e23	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xf6709be5	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0xf6792dc1	of_pci_parse_bus_range
++EXPORT_SYMBOL_GPL vmlinux 0xf68657d9	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xf692b574	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xf6c4d202	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf6cf2ae9	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xf6d38039	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf6ff75d7	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0xf7116522	of_device_get_modalias
++EXPORT_SYMBOL_GPL vmlinux 0xf7298e7b	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0xf731e3f0	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0xf737fef5	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xf7a2de26	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xf7a7f8f8	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0xf7b4a834	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0xf7c793a7	cpu_remove_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf832a0f4	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0xf8349bea	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xf837e0eb	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf8419420	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xf8462b23	kvm_read_guest_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xf856cdad	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xf85c2aa0	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0xf8647328	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf89af948	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xf8b72c23	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0xf8c10cb7	nvdimm_bus_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xf8cdb2a4	mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0xf8db2263	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0xf8e398fc	memstart_addr
++EXPORT_SYMBOL_GPL vmlinux 0xf8e9d9ba	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xf8f2e2fa	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8f8a87a	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf9104b74	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf931a117	of_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf951c0a5	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf961f6df	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf9672bdb	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0xf9796ce5	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0xf9896498	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9ad2e5d	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0xf9b43672	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0xf9b5e900	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0xf9c38385	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9f04dac	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xf9f5d2f3	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa3659b0	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0xfa40603b	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xfa4a33b4	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0xfa570036	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0xfa59c071	of_get_pci_domain_nr
++EXPORT_SYMBOL_GPL vmlinux 0xfa901b31	compat_get_timespec
++EXPORT_SYMBOL_GPL vmlinux 0xfaa7c9e9	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0xfab189c4	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xfab60503	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0xfaeddc0e	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0xfaf0d009	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xfaf14f6b	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0xfaf5dc7f	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0xfaf686cb	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0xfb0047f6	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0xfb0083ca	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0xfb03997c	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0xfb1b1e24	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0xfb22bc6c	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0xfb2cfbce	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb40d9d9	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xfb469bcf	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0xfb52b77d	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0xfb593129	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xfb69d53b	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb7771ef	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xfb87f290	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0xfb8b20d0	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0xfb907e3b	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xfba75aa5	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfbc18f30	dev_pm_opp_set_sharing_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xfbd5489f	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xfbdf5aa3	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0xfbe8cded	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0xfbef460b	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0xfbf306c2	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfbfcbd71	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc072469	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xfc201b66	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0xfc3980e6	vcpu_load
++EXPORT_SYMBOL_GPL vmlinux 0xfc447186	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0xfc5f5ec1	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xfc873fc1	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0xfcb306cb	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xfcbd9752	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0xfcfc8961	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0xfd46ae55	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0xfd4ca169	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xfd6326d5	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd880e4c	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0xfdb10b96	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xfdb9a29a	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xfdd87bf8	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xfe76f7cf	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xfe786462	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0xfe904d9e	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfee48c7b	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xfeed89a7	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xfef169bc	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xfefded79	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff12355c	__rio_local_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xff291ecf	clk_unregister_divider
++EXPORT_SYMBOL_GPL vmlinux 0xff32b888	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xff3601da	of_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff823ae7	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0xff8862d7	rh_get_stats
++EXPORT_SYMBOL_GPL vmlinux 0xff97a844	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0xffa22ac1	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffba4dfb	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xffd1ce72	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0xffdd16ec	tty_init_termios
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb.compiler b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb.compiler
+new file mode 100644
+index 0000000..d1936f3
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb.modules b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb.modules
+new file mode 100644
+index 0000000..62fb656
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-emb.modules
+@@ -0,0 +1,4309 @@
++3c574_cs
++3c589_cs
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_dw
++8250_mid
++8255
++8255_pci
++8390
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++DAC960
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++ac97_bus
++acard-ahci
++acecad
++acenic
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++ah4
++ah6
++aha152x_cs
++ahci
++ahci_ceva
++ahci_platform
++ahci_qoriq
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airo
++airo_cs
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++ali-ircc
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am53c974
++amc6821
++amd
++amd5536udc
++amd8111e
++amdgpu
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apbps2
++apds9300
++apds9802als
++apds990x
++apds9960
++appledisplay
++appletalk
++appletouch
++applicom
++aquantia
++ar1021_i2c
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_emac
++arc_ps2
++arc_uart
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3722-regulator
++as3935
++as5011
++asc7621
++ascot2e
++asix
++ast
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++ata_generic
++ata_piix
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atm
++atmel
++atmel-flexcom
++atmel-hlcdc
++atmel_cs
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp870u
++atusb
++atxp1
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avm_cs
++avma1_cs
++avmfritz
++ax25
++ax88179_178a
++axnet_cs
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1pci
++b1pcmcia
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm-keypad
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcma
++bcma-hcd
++bcmsysport
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluecard_cs
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpck
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmsmac
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bt3c_cs
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btuart_cs
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++caam
++caam_jr
++caamalg
++caamhash
++caamrng
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++cap11xx
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_das16_cs
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc10001_adc
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipone_icn8318
++chipreg
++chnl_net
++ci_hdrc
++ci_hdrc_imx
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++clip
++clk-cdce706
++clk-cdce925
++clk-max77686
++clk-max77802
++clk-palmas
++clk-pwm
++clk-rk808
++clk-s2mps11
++clk-si514
++clk-si5351
++clk-si570
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cm4000_cs
++cm4040_cs
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmtp
++cnic
++cobalt
++cobra
++coda
++colibri-vf50-ts
++com20020
++com20020-pci
++com20020_cs
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_isadma
++comedi_parport
++comedi_pci
++comedi_pcmcia
++comedi_test
++comedi_usb
++comm
++configfs
++contec_pci_dio
++cordic
++core
++cp210x
++cpc925_edac
++cpia2
++cpsw_ale
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc7
++crc8
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++csiostor
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_cs
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++db9
++dc395x
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++ddbridge
++de2104x
++de4x5
++decnet
++deflate
++defxx
++denali
++denali_dt
++denali_pci
++des_generic
++designware_i2s
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++digicolor-usart
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9601
++dmfe
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++dp83848
++dp83867
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dtl1_cs
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_wdt
++dwc3
++dwc3-pci
++dwc_eth_qos
++dwmac-generic
++dwmac-ipq806x
++dwmac-lpc18xx
++dwmac-meson
++dwmac-rk
++dwmac-socfpga
++dwmac-sti
++dwmac-sunxi
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++earth-pt1
++earth-pt3
++eata
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++echainiv
++echo
++edac_core
++edt-ft5x06
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efs
++egalax_ts
++ehset
++elan_i2c
++elo
++elsa_cs
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emac_arc
++emac_rockchip
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++empeg
++ems_pci
++ems_pcmcia
++ems_usb
++emu10k1-gp
++enc28j60
++enclosure
++encx24j600
++encx24j600-regmap
++eni
++enic
++epat
++epia
++epic100
++eql
++esas2r
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++ezusb
++f2fs
++f75375s
++f81232
++fakelb
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdomain_cs
++fdp
++fdp_i2c
++fealnx
++ff-memless
++firedtv
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fixed
++fl512
++flexcan
++flexfb
++floppy
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fmvj18x_cs
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fsl-corenet-cf
++fsl-diu-fb
++fsl-edma
++fsl_elbc_nand
++fsl_hypervisor
++fsl_ifc_nand
++fsl_lpuart
++fsl_pq_mdio
++fsl_usb2_udc
++fsldma
++ft6236
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu_ts
++g450_pll
++g760a
++g762
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcm
++gdmtty
++gdmulte
++gdmwm
++gdth
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++genwqe_card
++gf128mul
++gf2k
++gfs2
++ghash-generic
++gianfar_driver
++gianfar_ptp
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-74x164
++gpio-74xx-mmio
++gpio-addr-flash
++gpio-adnp
++gpio-adp5520
++gpio-adp5588
++gpio-altera
++gpio-amd8111
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-fan
++gpio-generic
++gpio-grgpio
++gpio-ir-recv
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-rdc321x
++gpio-regulator
++gpio-syscon
++gpio-tps65912
++gpio-twl4030
++gpio-twl6040
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mouse
++gpio_tilt_polled
++gpio_wdt
++gr_udc
++grace
++grcan
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++gxt4500
++hackrf
++hamachi
++hampshire
++hangcheck-timer
++hanwang
++hci
++hci_uart
++hci_vhci
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfs
++hfsplus
++hi6421-pmic-core
++hi6421-regulator
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++hih6130
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi504_nand
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hopper
++horus3a
++hostap
++hostap_cs
++hostap_pci
++hostap_plx
++hp100
++hpfs
++hpilo
++hpsa
++hptiop
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++htc-pasic3
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hwa-hc
++hwa-rc
++hwmon-vid
++hx8357
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd8111
++i2c-arb-gpio-challenge
++i2c-cbus-gpio
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-emev2
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-kempld
++i2c-matroxfb
++i2c-mpc
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-reg
++i2c-nforce2
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-piix4
++i2c-rk3x
++i2c-robotfuzz-osif
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i40e
++i40evf
++i5k_amb
++i6300esb
++i740fb
++i82092
++ib_addr
++ib_cm
++ib_core
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_qib
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibmaem
++ibmpex
++icp_multi
++icplus
++ics932s401
++ideapad_slidebar
++idma64
++idmouse
++idt77252
++idt_gen2
++idtcps
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imm
++imon
++ims-pcu
++imx074
++imx6ul_tsc
++imx_thermal
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int51x1
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipwireless
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++irlan
++irnet
++irtty-sir
++iscsi_boot_sysfs
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it913x
++itd1000
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++kafs
++kalmia
++kaweth
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks0108
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l4f00242t03
++l64781
++lan78xx
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-adp5520
++leds-bcm6328
++leds-bcm6358
++leds-bd2802
++leds-blinkm
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-ktd2692
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max77693
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-pwm
++leds-regulator
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libahci_platform
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_cs
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++liquidio
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++lis3lv02d_spi
++litelink-sir
++lkkbd
++ll_temac
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac80211
++mac80211_hwsim
++mac802154
++mac_hid
++macb
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mailbox-test
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++marvell
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max5821
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max77693-haptic
++max77693_charger
++max77802
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++md5-ppc
++mdc800
++mdio
++mdio-bcm-unimac
++mdio-bitbang
++mdio-cavium
++mdio-gpio
++mdio-mux
++mdio-mux-gpio
++mdio-mux-mmioreg
++mdio-octeon
++mdio-thunder
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++metro-usb
++metronomefb
++mf6x4
++mga
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microtek
++mii
++minix
++mip6
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmc_block
++mmc_spi
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpc85xx_edac
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi001
++msi2500
++msp3400
++mspro_block
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtd_dataflash
++mtdblock
++mtdblock_ro
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-sd
++mtouch
++multipath
++multiq3
++musb_hdrc
++mv_u3d_core
++mv_udc
++mvmdio
++mvsas
++mvumi
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxc4005
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxser
++mxuport
++myri10ge
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nci
++nci_spi
++nci_uart
++ncpfs
++nct7802
++nct7904
++nd_blk
++nd_btt
++nd_pmem
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_daq_700
++ni_daq_dio24
++ni_labpc
++ni_labpc_common
++ni_labpc_cs
++ni_labpc_isadma
++ni_labpc_pci
++ni_mio_cs
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicpf
++nicstar
++nicvf
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nmclan_cs
++nosy
++notifier-error-inject
++nouveau
++nozomi
++nps_enet
++ns558
++ns83820
++nsc-ircc
++ntb
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nvidiafb
++nvme
++nvmem_core
++nxp-nci
++nxp-nci_i2c
++nxp-ptn3460
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_mmc_spi
++of_xilinx_wdt
++ofpart
++old_belkin-sir
++omap4-keypad
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_cs
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++palmas-pwrbutton
++palmas-regulator
++pandora_bl
++panel
++panel-lg-lg4573
++panel-samsung-ld9040
++panel-samsung-s6e8aa0
++panel-sharp-lq101r1sx01
++panel-simple
++parade-ps8622
++paride
++parkbd
++parport
++parport_ax88796
++parport_cs
++parport_pc
++parport_serial
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_of_platform
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pcmcia
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sis
++pata_sl82c105
++pata_triflex
++pata_via
++pc300too
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_udc
++pci
++pci-stub
++pci200syn
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmcia
++pcmcia_core
++pcmcia_rsrc
++pcmciamtd
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcnet_cs
++pcrypt
++pcwd_pci
++pcwd_usb
++pd
++pd6729
++pda_power
++pdc_adma
++peak_pci
++peak_pcmcia
++peak_usb
++pegasus
++penmount
++percpu_test
++pf
++pfuze100-regulator
++pg
++phantom
++phonet
++phram
++phy-bcm-kona-usb2
++phy-exynos-usb2
++phy-gpio-vbus-usb
++phy-isp1301
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-tahvo
++phy-tusb1210
++physmap
++physmap_of
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl2303
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8941-wled
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pn533
++pn544
++pn544_i2c
++pn_pep
++poly1305_generic
++port100
++powermate
++powr1220
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_core
++pps_parport
++pptp
++prism2_usb
++ps2mult
++psmouse
++psnap
++pt
++ptp
++pulsedlight-lidar-lite-v2
++pvrusb2
++pwc
++pwm-atmel-hlcdc
++pwm-beeper
++pwm-fan
++pwm-fsl-ftm
++pwm-lp3943
++pwm-pca9685
++pwm-regulator
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa27x_udc
++qcaspi
++qcaux
++qcom-spmi-iadc
++qcom-spmi-temp-alarm
++qcom-spmi-vadc
++qcom_spmi-regulator
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qlogic_cs
++qlogicfas408
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qoriq-cpufreq
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quatech_daqp_cs
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-bcm2048
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-shark
++radio-si476x
++radio-tea5764
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++ray_cs
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++reed_solomon
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio-scan
++rio500
++rionet
++rivafb
++rj54n1cb0c
++rk808
++rk808-regulator
++rmd128
++rmd160
++rmd256
++rmd320
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-as3722
++rtc-bq32k
++rtc-bq4802
++rtc-cmos
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-generic
++rtc-hid-sensor-time
++rtc-hym8563
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max77802
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-msm6242
++rtc-mt6397
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-r9701
++rtc-rc5t583
++rtc-rk808
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-snvs
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-twl
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtc-zynqmp
++rtc_cmos_setup
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7706h
++safe_serial
++salsa20_generic
++samsung-keypad
++samsung-sxgbe
++sata_fsl
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_sil
++sata_sil24
++sata_sis
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sbp_target
++sbs-battery
++sc16is7xx
++sc92031
++sca3000
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++sdhci
++sdhci-of-arasan
++sdhci-of-at91
++sdhci-of-esdhc
++sdhci-of-hlwd
++sdhci-pci
++sdhci-pltfm
++sdhci_f_sdh30
++sdio_uart
++sdricoh_cs
++sedlbauer_cs
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial2002
++serial_cs
++serio_raw
++sermouse
++serpent_generic
++serport
++ses
++sfc
++sh_veu
++sha1-powerpc
++shark2
++shpchp
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sir-dev
++sis
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skd
++skfp
++skge
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++sl811_cs
++slcan
++slip
++slram
++sm501
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smc91c92_cs
++smipcie
++smm665
++smsc
++smsc-ircc2
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4117
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als300
++snd-als4000
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt3328
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-cs4281
++snd-cs46xx
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1938
++snd-es1968
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm
++snd-pcm-dmaengine
++snd-pcm-oss
++snd-pcxhr
++snd-pdaudiocf
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-sb-common
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-core
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-es8328
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-ssi
++snd-soc-gtm601
++snd-soc-imx-audmux
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rt5631
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-xtfpga-i2s
++snd-sonicvibes
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-usx2y
++snd-usb-variax
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-vxpocket
++snd-ymfpci
++snic
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++softdog
++softing
++softing_cs
++solo6x10
++solos-pci
++sony-btf-mpx
++soundcore
++sp2
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_dectlk
++speakup_dummy
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++spectrum_cs
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi-lm70llp
++spi-nor
++spi-oc-tiny
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tle62x0
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spmi
++sr9700
++sr9800
++ssb
++ssb-hcd
++ssd1307fb
++ssfdc
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++ssu100
++st
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++svgalib
++sx8
++sx8654
++sx9500
++sym53c500_cs
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink
++synclink_cs
++synclink_gt
++synclinkmp
++sysv
++t1pci
++t5403
++talitos
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc3589x-keypad
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tehuti
++tekram-sir
++teles_cs
++teranetics
++test-hexdump
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tg3
++tgr192
++thmc50
++thunder_bgx
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timeriomem-rng
++tipc
++tlan
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++torture
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_atmel
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps65218-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tsi568
++tsi57x
++tsi721_mport
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl-regulator
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udc-xilinx
++udf
++udl
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_fsl_elbc_gpcm
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmisc_imx
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vcan
++vcnl4000
++ves1820
++ves1x93
++veth
++vf610_adc
++vga16fb
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-ircc
++via-rhine
++via-sdmmc
++via-velocity
++via686a
++videobuf-core
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videodev
++vim2m
++viperboard
++viperboard_adc
++virt-dma
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_scsi
++virtual
++visor
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vrf
++vringh
++vsock
++vsxxxaa
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83977af_ir
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++walkera0701
++wanxl
++warrior
++wbsd
++wcn36xx
++wd719x
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++windfarm_core
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wl3501_cs
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x_tables
++xc4000
++xc5000
++xcbc
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xhci-plat-hcd
++xilinx-tpg
++xilinx-video
++xilinx-vtc
++xilinx_ps2
++xilinx_uartps
++xillybus_core
++xillybus_of
++xillybus_pcie
++xirc2ps_cs
++xircom_cb
++xor
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yenta_socket
++yurex
++zaurus
++zd1201
++zd1211rw
++zforce_ts
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++zr364xx
++zram
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp
+new file mode 100644
+index 0000000..6ecccb1
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp
+@@ -0,0 +1,17815 @@
++EXPORT_SYMBOL arch/powerpc/platforms/pseries/hvcserver 0x048d27cc	hvcs_register_connection
++EXPORT_SYMBOL arch/powerpc/platforms/pseries/hvcserver 0x536d329b	hvcs_get_partner_info
++EXPORT_SYMBOL arch/powerpc/platforms/pseries/hvcserver 0xc39c3704	hvcs_free_partner_info
++EXPORT_SYMBOL arch/powerpc/platforms/pseries/hvcserver 0xd0a02396	hvcs_free_connection
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0x6310e901	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/atm/suni 0x338ed3ec	suni_init
++EXPORT_SYMBOL drivers/bcma/bcma 0xe845d95c	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/bcma/bcma 0xf2eeea61	bcma_core_irq
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x0cbc7387	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0x23ee2fe9	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x35335e8a	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x4267110a	pi_register_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0x44c6b49f	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x886cf634	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x95b88bf5	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0x99af9df9	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0x9c0c79e9	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xab6048aa	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xb21ba07d	pi_unregister_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0xbc427c0b	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0xed4bb8c9	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xf7c8ca03	paride_unregister
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0xbd910092	btbcm_patchram
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4e599ca3	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x62cda9e4	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x9521b6d1	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa17ece64	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xb4b30e4a	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x168cfb90	st33zp24_probe
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x36d0eac9	st33zp24_pm_resume
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x505d5a86	st33zp24_remove
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x72adad96	st33zp24_pm_suspend
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x3c8ba78d	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xa61cc487	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xa8434c5f	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x28de278a	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x578bd589	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x5ae7d63d	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x92d88c21	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xe5854200	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xebc52c4a	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/edac/edac_core 0x6eb6167a	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x03d1af77	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04d0f641	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x06a4e095	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0a266950	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0f3c638e	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0f7d6af8	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x263b8fa2	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x272d3f43	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x30d6fffc	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3f06692c	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4c6986e7	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x54af0c35	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x645b715f	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x69813a26	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x74a2d987	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x83d80881	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9089b707	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9832f3a7	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa5d71b95	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xae62b610	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb6b0443a	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb8a04b06	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb98f1f60	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xc37c7cf1	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xcf0b5741	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xcf76f6cb	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xe1ac1c2e	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xe5d5c757	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xf7385c4b	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/fmc/fmc 0x0bc7fe8f	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x10957169	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x4d9ae182	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0x54588bfd	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x64cfb1a4	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x8669f79f	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0xa1ea03b7	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xab6daeba	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xb6fd7c4d	fmc_driver_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xc5258a9b	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0xff44fa5a	fmc_device_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x00eaef99	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x01311088	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0257dd20	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x03c39a79	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x076617f4	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x078ba00f	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x08549e12	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0976d8ae	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x09bc7258	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a54b180	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0b6d91a2	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0b7f1cd5	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0baa4be8	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0bae31c0	of_drm_find_panel
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0cbd149a	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0df3515d	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0df8a949	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0e891949	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f73ff71	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f7bd603	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x10447f4e	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x115429ce	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1156b609	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x137bf9f9	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13a6e348	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14b21841	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1539e7fc	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1654948b	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1665d5ef	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1689820c	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x16c4f5ec	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x19490f45	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x196a0838	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x19e4430f	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a6a9cb3	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a8e8500	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1b586eae	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1bd3cbd6	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1d33f983	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1de1da05	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1e7b2177	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1e8ee7b3	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acb8e4	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22bff8af	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x23b6e142	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2415abf8	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2997db8a	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29b18be1	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29ba467f	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ca0cae5	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d2fd0ba	drm_agp_bind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d6ede1c	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e804540	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x309dd6cd	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3136c3a1	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x315a279f	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3351c564	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x33665707	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x33a957c7	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x33aa8e9c	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x33d157fa	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x33ea0327	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x34ca4a20	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3519f9d8	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x35771162	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x369943ed	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x39867333	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x39d19aad	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3adaa5f6	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3af51ff4	drm_agp_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3badbfb0	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3bd5662a	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3c23ce35	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d2663e2	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3e2d141d	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x40659ce4	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x414eb2c4	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4267ed09	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43bde352	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x440ac13e	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x458c6c91	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x46124238	drm_agp_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4671344f	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x47f3710f	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x49b7ccf5	drm_agp_acquire
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c227655	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4cf60423	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d30a43f	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d524119	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4e7bd5a6	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4f4031e7	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4f52e10f	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4fbfec88	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50891e14	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51bc5f83	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51db353a	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5367bf9d	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54cb978f	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57453205	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x58d91978	drm_agp_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5b68c8bc	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5bc25c54	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d12497e	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d5f3a33	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d7318dc	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d88c062	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d971557	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d9bb3dd	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e1f3121	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5f9fa90c	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6005df97	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6056c412	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x60c3c709	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x649f14dc	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6560ef19	drm_of_component_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x676ff013	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67b28c1e	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68ed607c	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6b33d183	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6c0404ea	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6c298f6d	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6d33ae6f	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6d408d29	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6df8eedc	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e2fa869	drm_of_find_possible_crtcs
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6eb5a2fd	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x704bf914	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x716522bb	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x717f9cb9	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x71bd6be8	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x71d5eae3	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72a21cbf	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7318315e	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x73c58c0c	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x749bd063	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x77b6dfb7	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7862116d	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7876d679	drm_legacy_addbufs_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7baa01d2	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c166b5e	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7dd88fd6	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7e835fbb	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7f49a5ff	drm_agp_bind_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x80247b65	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x81053b13	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x81aa8907	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x81c461e8	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x81e1f978	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x837c85bb	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x83b44933	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x84df169a	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8affb48e	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e788396	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8edf9174	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x904fd0d9	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x90c4df0f	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x93bf8db7	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9516374d	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x96a53a8e	of_drm_find_bridge
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x96b9eb42	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x97e57457	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x98275747	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9838abcf	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9883d7e8	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a45668d	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ace226a	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9af6a713	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9b6af8a9	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9bc4729d	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9c2797d3	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9e72e4cd	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ed1482d	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9efb6ddf	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa208ce78	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa46af023	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4c3a0f2	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4c4c07a	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa53ea4c9	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa5f9245f	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa6387a30	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa8045cf9	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa886fa44	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaa80dda2	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaacd01ce	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xac5bf31c	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xacc6150d	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae579b99	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xae71f786	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb14c38a8	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb2fb27e4	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb37aa861	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb4c534e8	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb53116fd	drm_agp_unbind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5540008	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb61e369f	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb9142fa7	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbba5e010	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbbbfba43	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbc9c029d	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbcc6fb42	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbd466b6f	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbd834815	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbda624df	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbdd123d7	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc041ae8e	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc1cc2de5	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc20c83c6	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc29db446	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc3694753	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc492bc62	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc4c446b0	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc55113f5	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc7a63ad7	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc8acaa0c	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc907c488	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc935a81e	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc9772467	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca14100a	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb048200	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb388714	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcbc1d6d9	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcbccdcfa	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcc3ac965	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcc437cc6	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcc506aff	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcc7f99de	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcccb7db1	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd545131	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf14e8d8	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf4ae0f2	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd0563a4f	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd098923d	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd1c6c175	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2cde511	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd308cf9a	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3488b15	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd56a8b93	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd6b2a1af	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd7266b5c	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd903df23	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd9e849bf	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xda027080	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xda28813b	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdb60ebaa	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbc11d88	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc61a22c	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd0b0ade	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf7ec363	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdfae502d	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2d246e2	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2ffd7a5	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe39f7bd3	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe3d355e3	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe3ecc7d3	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe48a970c	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe510b8c5	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe58fb21d	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe5f7e836	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe60d03a2	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe9f7282c	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea787f44	drm_compat_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed588bab	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xede47a97	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xedf9b3d4	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef2dd623	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef49288a	drm_agp_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef51a431	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xefc6b002	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0ecea59	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf12c5ca1	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf143bb44	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1b098be	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf24d371f	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf2b52d04	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf3b95b7c	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf45c624d	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf45cabaa	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf478182f	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf71caa43	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf867fbe4	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf95d7c73	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9daf175	drm_agp_info
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9f8d56a	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfa18568a	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbcc5352	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfbe97070	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc471a64	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc5f3bf3	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfef4cb99	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x03082535	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0483e6c5	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x05778a15	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x07c117f1	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x085cd84a	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0974d039	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f16851a	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x12c49107	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x131105a8	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x152789af	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x15808138	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x15a99201	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16735524	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1b72a834	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1f212cb2	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x22f85c4d	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x231ba995	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x25a74597	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x25dc0326	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x27fa9ba3	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x29221bba	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x29a29a4f	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2b2b78b1	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2b2e2004	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2cbf10ea	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2d9d7621	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2e37feed	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2feb5210	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x305058b4	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x31158bde	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x337d0187	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x363fa549	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x36479b4e	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x38abb13f	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x38bd6948	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3a4e57ae	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3a87471c	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3b18e320	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3b46012a	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3eb84903	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x40ac904d	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x41ef8e1f	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x427d014d	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x433a69db	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x43401acf	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x445caa72	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x448ede72	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x46a3d9bf	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4784bab0	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4905c18b	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x49252ee4	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4ac8b5cf	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4c54b0f2	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4dc0c8d8	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4f205a6e	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x51863f37	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5273994b	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x53bb1421	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x54fcbcf3	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x59993e10	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5a1ac4ad	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5a5e4b33	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5abe2c8c	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5c2d6a1a	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5d869553	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5f07f25a	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5f68223a	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x650c1bf5	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x670373f3	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x682f3b43	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x68a94ee9	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x68ae909e	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6d0b024c	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6de8c037	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6ec1d565	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x73fd1b52	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x75d6d902	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7ae4efec	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7ae8c9ec	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7b20a60c	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7b9f2138	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7e2c70b7	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7f4b96e0	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7fa36f5f	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x82bee680	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x83e52908	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8b64eb22	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x90686769	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9092b9f1	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x90e60b4e	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x928cb99c	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x93fceaee	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x942a5be5	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x94b11599	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x95e83dcc	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x980a46be	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa0c4cd90	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa16a038c	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa1ae4c26	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa6b1ef8f	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa7715681	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa930d86a	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaa23f7d0	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaa4b601b	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xacf241c0	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xad3c0418	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xad841d34	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xae328766	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaead3688	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb113496d	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb268290e	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb2bbb7ce	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb2d3d757	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb59c8eb8	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xba54b268	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xba863c24	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbabdfdd1	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbf39ba31	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbfe3edb4	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc65aab93	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xca4d0f82	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcc272aa2	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcc382682	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xceabd03c	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd14348f1	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd165e9d0	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd44512fd	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd7f6f060	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdb6fe3cb	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe045435a	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe1b58af9	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe3a83e98	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe725c5a9	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xebad8a9b	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xee1f7ac6	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xefaa5519	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf04d6b31	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf3fac4b0	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf6c07434	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfb529057	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfb6e31c5	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfe6cb2c6	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0f39160a	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x13ba2316	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1989f162	ttm_prime_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1a3da01b	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x24badfbc	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x307b37d1	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3f400ede	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x40c0a25b	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4c942eb0	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4c9db944	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4e361a4b	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4e45c13c	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4e8dd264	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x564e1aee	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5a8fdfea	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5cde8da9	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6052860c	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x64c887a5	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x664f9fde	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6d73c1fa	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6f7ac2d8	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x71670458	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x785ef6dd	ttm_agp_tt_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7d55da85	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7de15d07	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x810c3f7b	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x82194d5f	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x84a13931	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x84e23068	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x89a443de	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8be73902	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8c50aab3	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8d14adbf	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8eecec5a	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94a5d79f	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x975677a0	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa2a129fd	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa4898cfb	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa5e83913	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa6aa91a3	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa73de2a9	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa959c314	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb01c89df	ttm_agp_tt_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb279c07f	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb40dae12	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb83c6470	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbc1f147e	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbccdd51e	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbf3c8340	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc31b90f5	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc3835e6c	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc5c50426	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc5f0c2da	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc62ebe68	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc849eec2	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcfd7a68b	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd64f9b5b	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd724857a	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd7f51742	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdc989368	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe835e3b8	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe9b67ee6	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xea1c7b17	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xea322e20	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xeaec7648	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf0c1a05e	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf1db1215	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf9001408	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfa530216	ttm_agp_tt_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x2a6b9653	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x7a8a224b	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xea3f41d0	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0xde89a7ce	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0xf1d23e5a	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0x42d51ad2	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x045d6867	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x0c0a0a3a	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x133b0924	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x47fd30d1	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x7502da56	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x7d467d25	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x8b78c01e	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x9a3c4bd5	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xa5e637cf	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xabca979f	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xc8544d82	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xd2962087	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xe3ec76ce	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xe44a9bc4	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xe5c9ebd6	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xfa7ddca8	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x04dfd124	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x4739425a	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x890b9497	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0xc3f514e0	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x3e000a97	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x7a8ae8e7	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xa6959b51	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xf53bfc56	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x4b1766db	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x5206ef7a	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x7b7e8e77	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc67a8aeb	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xcf0dc0c6	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xfff53137	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x636d202e	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x71159570	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xb5f9a1d3	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xfb5ee526	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x3d7f55d4	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x4900df95	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x491e0192	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x4b2c93cb	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x5da15ca2	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x85366818	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xd35b38f9	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xd7e99538	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xe9cc4e94	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x0dc0e59c	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x10eb630c	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xa8ed474a	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xc73b75c7	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xf60459e2	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x05d6ab8c	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x5a139f25	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x668a216f	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x05f07acc	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x07414264	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x3945a997	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x47c5f6e8	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x5c57625a	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x76cd6e35	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x885d1684	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x93195ce2	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x9e9f52bb	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xaecf07fe	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb17abc0a	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb992c01d	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xbf3c2e4c	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc47890f3	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc5b96b26	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc81bbad9	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf8622460	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x4add8ba5	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x7ed366e4	st_sensors_of_i2c_probe
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0xbf7e9a98	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x72651787	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x8fec3fea	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0x99a6d5af	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x28cbd88d	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xae49924e	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/industrialio 0x01d2e88c	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0x0b443ba1	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x302c1866	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0x66bed67e	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0x69a10af8	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0x85670532	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x866ba520	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x901963f5	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0x9577b941	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x97d70960	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x99991a33	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x9b38b7d1	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x9e428819	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xab7bfe56	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xbf398dc1	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xc0bab5fc	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xf860648e	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0xbdffdcb7	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0xc4174766	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x2105471d	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x4a77aa6f	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0x9f11252a	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x473807ff	st_press_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0xa2638706	st_press_common_remove
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1ea5767b	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x32a8402c	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x7467be37	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x88939fed	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xd7b3073f	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xe87022ef	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x13af8ec3	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1455078a	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1b1c7922	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1dc839ed	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1fe709c8	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x2507dcf0	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x33132ed7	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x389367fc	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x52b94874	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x6b032635	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x79dfeb2e	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x7b769d84	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x82232f0c	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x8f9389cd	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa91ee8bf	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd3a9174a	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd65a6729	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd6b0a0be	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x00aedd6d	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0115baad	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c536585	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x13a8b401	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1b3d557a	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1cf9c7e5	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1d752469	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1de63f37	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x221837d1	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x22f3cf93	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x243c71c6	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x261aec20	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x283fb157	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x29efe2df	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2be9f109	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x31a7ed11	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x31c39aa9	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x330e416b	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3b22ab62	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x41a32b50	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x41c25ff3	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x42e4a2b1	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4a5a0303	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4afb7ac6	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x513c1e85	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x53adc477	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5741aec4	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5dd94da1	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5fb17a90	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x621660d3	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x62919fba	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x63637803	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x63910d3b	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x68b22133	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6cdd98c4	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x72c6df80	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x77fbe418	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7a8430ee	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7e2f8d58	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ffee6e9	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x83ea9cbb	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8b551c85	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8ddab7e3	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x93146d87	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x93b68d3e	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x965951a5	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x98b06175	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9c734cc4	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa06dead4	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa11f5ba2	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa432baf6	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa9fedeff	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb105ef96	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb2a2d523	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb408768a	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb5833f16	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xba17c29a	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbbbd1dad	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbbe33fec	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbdb0e24e	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbe648ff3	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc3a72b8a	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc6d8d5d3	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc7c94d4e	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcbab8d3f	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcd9c2ef7	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xce7b4af7	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd128b08e	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd7c674b2	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd85eb7bf	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd947c7b6	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdb10ef66	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdf263910	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdf97fc8e	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe0031f19	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xea35100d	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xee7b9d9a	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf0e3de94	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf3dde084	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf7f3dcdf	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf915fde2	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfa21fbb2	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfa4f4992	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfbeed002	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfd1afbd1	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x05d80811	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x20881d8e	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2218b3c1	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x26b82ac1	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f71c337	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x4d4eb3df	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x5204555e	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xb3e02455	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xb4377fd1	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xb6544c1f	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xbe1e6be1	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xbf893b72	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xfd862d8a	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x21a089c8	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x33dc60e2	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x3baa1793	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x4eb743c3	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x5328d7a6	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x5755c6ee	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x7af6b6e3	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x9a1cd50d	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xb952296d	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xc2baa499	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xcb95e95b	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x54f29ab1	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x6a68353c	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x05f9d0d8	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x220664e1	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x2dc8e979	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x48e58be9	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x4cbd7c94	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x4d6d529b	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5c265c52	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x71f8e641	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x7390eb53	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x86c7e64d	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x900bdebf	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9d499c84	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xdf6434a5	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xeb86799a	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf6e4a50b	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x08f49f70	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x237be670	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x2730c343	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x31568ec5	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3a064255	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x3bdb958b	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x474c0d14	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x76e3d02f	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x78da68af	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x85572fdc	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x89bbb341	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x9a4c3713	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xb789ea7a	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xc7f310e6	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xcc4c7c22	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xce4bba35	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd6b2e6b4	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xdc8125c1	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf147ccfb	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf968d23b	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xffa20a5d	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x1f89b967	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x36fd009f	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x4ff61989	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x749a6d25	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x97575b79	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x9aaaff75	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xbee724c4	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xe7e94a54	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xfc0d4209	gameport_set_phys
++EXPORT_SYMBOL drivers/input/input-polldev 0x16f801a5	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x2f31ad79	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x387c4089	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x4b22b67f	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x8a95f752	input_register_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0x683c9cbb	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x06b5e885	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x2172a12c	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x61b34644	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x91f26e45	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x05ba710b	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x2d362151	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x707001a5	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xae56e685	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xc0484596	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xf7c6e868	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x4fc80a4b	ad7879_probe
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xe9de7c41	ad7879_pm_ops
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x043eaf4e	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2474741c	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x596b7037	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6000d2c3	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6484562a	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7292ab34	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x72a25a72	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x850cb4ea	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8a3ca899	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xace2862f	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xbc21d2fd	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xca7e6d37	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xfd552f7a	capi_message2str
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x0f03207f	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x231df0a9	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x2a8f3e05	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x2d51092c	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x333a65db	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x37bb568a	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x3d517a26	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x5e9a0f7a	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x68512882	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x73d3f163	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x78660a86	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xac237330	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xb996abc0	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdf93d35f	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xe2d0332d	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x0cd62d8d	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x23ceb389	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x370a2612	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x3854d3ba	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x619ee32c	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x972cde45	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xab79d622	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xbff931df	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xe93b0700	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0x29562993	b1pcmcia_delcard
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xaec3240e	b1pcmcia_addcard_m1
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xea620116	b1pcmcia_addcard_m2
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xf14bf8b1	b1pcmcia_addcard_b1
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x198aed3e	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x3a790322	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xe0561af7	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xefdd89c1	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x193ed27f	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0xd1db9f8b	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x79789296	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x0452e89c	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x690b17c4	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x7a20c2da	isac_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x8c6b66ef	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xdfd209c9	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x0f6c029b	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x1b2c59e7	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x78cc003a	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2480ff72	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2a6cf6f4	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x33bb3c2c	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x34509a89	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3601a41b	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x40b82621	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x429c9e27	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x493b47bc	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4ac58868	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x5beffb57	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x67160edc	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x71dfeb1e	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x752d34b4	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x99ca6d1e	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa671e10d	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa881b8fd	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb3d976f2	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc631cc73	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd3879b12	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe247df5a	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xed889715	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xfb9a70e5	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xfbf54f0b	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x125ec385	closure_put
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x1d89bd11	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x1f529ce8	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x26481f26	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x440b4830	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x44a37d62	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x4ecd91c8	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x520a50b2	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x5b59b856	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7daccb73	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x8833b0e8	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xa3c5c702	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca5df778	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xce47a6d9	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd2813054	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd4226dbb	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xdf892351	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe67c2d16	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xec6f33d0	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/dm-bufio 0x268682d2	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-log 0x31afd609	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0x708134ff	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0x7dd26d17	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0xd12122a2	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x0e9652fe	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x3b5ee86d	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x5b97de5c	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x619c2abc	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xac8d3c5f	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xbcbc5e32	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/raid456 0x131f3e0b	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x1b3c2491	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x44d64bbd	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x6058db49	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x688ee154	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x6ae7a5d8	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x72929f25	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x8adec70c	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xa24257d5	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xa5cb1507	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xaadcd6ab	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xd65ed8d6	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xdf84cd23	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xf71368bf	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xd1d0a76d	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xd4f05708	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xe3592188	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xf84e0fb8	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0x6dc6a5cd	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x497d131f	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/common/tveeprom 0xe3ebfc9f	tveeprom_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x037eb423	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x17d4b5ad	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1922a026	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1e5fa7cc	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3078be06	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x32706276	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x32f132d0	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x33bd98e7	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x37d10c24	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x37d680b6	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x43f3921f	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4f7288b5	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5c0ea535	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x62d3000c	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6c09ad2b	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6cc6a3c9	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x70af1058	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x787768c7	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x78db694b	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7f4f9b54	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x85a5e7d3	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x88c84eb3	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9ae2d7b0	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa100aaba	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa1a0ccbc	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa3aece55	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa8cf285a	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xca9321fd	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xcbd80a01	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xcf589e8c	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd28ca000	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd2f2096b	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd8f7184c	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe04f6e7c	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe81d855a	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe8729f81	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf28e7431	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfbaa7e01	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0x249d30c5	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0x39032e5d	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0x82f8e5d0	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x1147492e	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x2a12f9ee	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x409b38b8	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x5facd7f1	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x7a1de5c2	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xa37a9c73	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xabc98f01	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xbeca59bc	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xc13a6518	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0xd9a76346	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0x61f29ad6	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0x636d7b09	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0xc6879ece	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0xacf4b7d5	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x4876d167	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0xae8599c6	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0xb0ad2f6e	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0x9549f55e	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x321c17b5	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0xdc3c29f1	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0x36f65dc8	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x46e1cc03	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x54b3ff1b	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xaca2a6b7	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x2539341a	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x72de69e1	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x73956010	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xcb6de429	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xd4153245	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x0d536b0a	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x10ea0635	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x1338d4a3	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x178ac7e3	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x41563011	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x55c1278e	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5c41188b	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7b2026d8	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x8adcf18f	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xa6d44437	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xb0fe2047	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xb1a31621	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xd4529b27	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xee93d9bc	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf4375567	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0x9faf261d	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x2e298906	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x5e966f48	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x5f1c5558	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x7d18b762	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x99f327d2	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xeaf21726	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x5d2c5256	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xaa9fbf07	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xc59959d6	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xd6109509	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x85f9fba1	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x1275ac5e	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x2eba0be7	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x96da05a3	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xc3b5d489	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xc47536da	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xe318d412	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0xfea3c073	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0xbdb828ab	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0xdf5ef11c	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0x0b665b6c	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0x8c94f0c8	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0xb1d483d0	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0x01910724	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x2b3ff882	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x6d6ab9b5	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0x052503c3	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0xfbc04c68	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0xa23ec932	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0xa7976df1	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0xbd47cf8d	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0xb749840a	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0x0fafb334	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0xa9cf21f5	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0xf01300b5	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0xc7d59798	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x6762d1af	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0xfc3d1b79	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0x2e749bac	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x00c41645	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0xf2ea929e	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0xcbf29c4b	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0x6f8a19a5	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x08965a36	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0xb9833b23	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0x01bee9b9	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0xe2901aa8	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0xf8a2f61b	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0x594eea9d	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0xff9c6b23	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x9cf17ed7	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x7f42db98	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xc77fd95d	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xeeacab08	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x1870cc0c	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0x63f8eb3f	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x79d0fc11	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0xb5ab3e31	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0xe61efcf0	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0xb71dbed5	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x3952c733	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0xbbd52df3	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0x01b3d2de	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0x93669684	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x28f75648	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x0c60c107	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x0f39f91d	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0xaace7285	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x7c269dfe	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x3916f506	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0x289d1d7f	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0xbde169bc	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0xe192bbcc	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0x26f12b27	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0xcd2e2663	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0xf93b8e0b	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0x2cdea3a1	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0xcf630a12	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x0ed77b55	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0x2e961bbd	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0x81a8d65f	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0xe3c85270	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0xf2985af2	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0xe48d2c49	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x096f9ac1	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0xf6120878	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0x7ae5754e	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0xd0627132	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x05c01991	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x2f184d7b	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x37a1355d	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x3824da4f	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x67fe595b	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x74110f06	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xbc91593f	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x18d828b2	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x3337022d	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd692a727	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xda5579ae	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x26fe13ed	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xa182c1ff	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xdbf8a849	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x0e33b81a	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x10708717	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x11f43cb6	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x44b26d8e	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x6e84f830	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x81e8fc83	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xb6dfdfab	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xb76ead8d	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe3da67ee	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0xd2bf17c7	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x19a80b28	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x8c427caf	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x9a22fb35	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xb87fb855	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xd4be2e2a	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x8f1a38de	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x1f48d101	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x610a47bf	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x94733e67	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xa72129fe	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc282e476	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc6cd26ff	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xd7ed05bd	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x2231116e	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x78dc6b25	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x0f2a356b	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x4121991c	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x9f479ec2	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xd18ab627	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x06c6134d	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x83464589	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x974a747a	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x986c4d5f	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xa6b2df03	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xccddbac2	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xe9874d5a	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x35728fea	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x3d1c39c7	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x47f28f14	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4b15cb56	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x548bd47e	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x60b38770	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x65ea4f2d	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x8645a363	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x8a43b045	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x8b96e0d6	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x8cae08c2	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x9d3e7e3d	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xa76dc952	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb6e97503	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc3c51cf7	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xd07f2833	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xdc90496b	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xec8c33d5	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xed3018c0	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf256e23a	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x029df027	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x0fb76365	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x20103dc9	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2c688991	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x4e34d44e	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x58fbda85	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x6e22f667	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x7bccd497	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa237e288	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xb085699e	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xc58bf229	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xcffd9b10	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xd378687b	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xe7a3a811	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xee28a272	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xf3e3914b	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xf3f564ac	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x0cadb9af	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1ba6b287	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x2507f4f9	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x27d89b9f	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x34fec0f9	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x67487522	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7b8deb84	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x837a9901	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa637d197	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xc70d4e63	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xefe91872	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xf87ee614	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x4c9d00e7	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x077c2bf8	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x2ca59986	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x4ceb97e4	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x7aa5d5c1	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x9ec282af	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xa17476b2	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xbbbe7987	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x4d13bd66	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x63580950	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x75cecef1	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xa81ad0f0	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xc2283fff	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xcce209d5	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xe0ae4e72	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x10de0fb3	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x4656085f	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x5357fead	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x758ea23b	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x94870bf7	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xafc5efa3	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xbdddaaf8	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xeac471e1	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x1c66de25	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x84f7c97f	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0x4ad1735d	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0xdabd39e5	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x09aa8d28	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x1e6484d9	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x8da83157	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/max2165 0x82209a15	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0x81a84cae	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0xf33e7608	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0xcb76c12d	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0x68a55205	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0xd3cebf9b	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x110a512f	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0xa833ed9f	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0xa1923500	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0x43f885b6	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0x464a71d1	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x24da3c03	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xf05c55ca	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x07a4220c	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x0cf691c1	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x1553b5d2	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x199d01fe	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x30ae23e7	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x4702a3b6	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x59896ee9	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x895442c6	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xed473ec6	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x7bcd9391	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x7ccf7444	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x966db238	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x97afa601	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xb6885766	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xe48f7698	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xfd74c1a3	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xc33a99bd	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x5f28fb37	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x761d281e	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x85bbeed6	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xbb06098f	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xc5eb46ca	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xcd72a7ff	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xe8a7c434	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xe9450869	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xf05c7172	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xf46366c4	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xf69e5bb5	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x07fe7fee	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xb5660f09	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x1d17f7f8	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x1f716b48	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x20c71d63	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x38796a50	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x76bbc65a	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x8806895f	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xbf1bd065	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xdd276536	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xf3f6c0d3	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x02297ce1	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x0f126283	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x22b12dec	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x2ef1e54f	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x3f5cf53d	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xa43f4e0b	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xa7b9cc85	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xbd3daa11	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x4d4f71f2	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x93aab527	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xafc35010	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x5964f1cf	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x72a3f005	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x33663427	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x78beaa3f	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xcdcb8541	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x3911ef73	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x3be8dd7e	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x55cb1cc8	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x580efa5f	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x6c37c7f4	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xe0fb86e7	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x6e17e5d3	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0xab794768	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x1f06a5c1	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x2892a8c9	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x53eef3d7	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x9ff78ce7	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xecf59134	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xf9c56589	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0x75807c2c	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x01d4a255	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x03469dbd	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x04bf9227	v4l2_of_put_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x06ebdfe3	v4l2_of_parse_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0981972d	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x107f61b5	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x14d59409	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x152c8a67	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x208f05a8	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2608ab8a	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2656b931	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x278e5e0a	v4l2_of_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2c8c22ae	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2ea6527d	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x37525249	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bc92dc2	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x42f45e70	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x433b9216	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x47c3811b	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4de86331	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4e46d556	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5a44456a	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5dd90165	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x68ae0aaa	v4l2_of_free_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6b9992e8	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6cf5fa56	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x70a1bad5	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x71fb9426	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7666e602	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x789abe05	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7906cfa3	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3a6991	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a884fe0	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7dd5002b	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x80489154	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x81be111c	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8b30d4f4	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8bc95871	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9413ce8f	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9e371445	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa2569e98	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa4a88f2c	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa97ed066	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xabac867d	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xadd5fac3	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb1f9fd48	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb2e8bc25	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb485875e	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb532e77d	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb7bb7beb	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb863de1e	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbbc8b415	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc34e59ca	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc78a4a74	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcbbd1416	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcd39ade9	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd162e825	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd18041dc	v4l2_of_alloc_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd1836a34	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xde18bafd	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2bfc808	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe3d365c7	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe7a54309	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe8890c07	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe92b06a2	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeb82cf32	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xee312767	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf62cfa1c	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf7f9611a	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf84b66f8	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf9d4a5f9	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfb4d273d	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfdcd7476	video_device_alloc
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x0ac9683b	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x2535ad69	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6024f7d7	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6ed6f38f	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x7b12ef6d	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x97f35b5c	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa09340a6	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xcdb7edd5	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xd135cb10	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xdc07e67e	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xe8cd2c82	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xf7423930	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xfe5a4f0f	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x0d37d8c9	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x13cb7a48	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2433028e	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2dcc08ba	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x429af857	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x456d0228	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x47e5fe71	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4a81a947	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4ad96f03	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4b72d4a1	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x547b2ff7	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x7d9bc5d4	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8d92700b	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x903df41c	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xafc11bcd	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb113d2f1	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc03b9956	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc14458e1	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc8d0059b	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xcf2ac10e	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd306e8be	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd3bcb45c	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xda62d9e6	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdbb28815	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe212b2eb	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe2c7f5ed	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xead10083	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf3604ce6	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xfd715848	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0a0bcbca	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x13d70271	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x223a21f2	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2883a84a	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2e5b6529	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2fb3cf0a	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x37e7061b	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x461b0b4f	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x54311243	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x553d7f24	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x55730f77	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x69e3b842	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7921eaee	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x83d04c19	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x88140b0c	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9dfadea2	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb06adec0	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb1b4db4f	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb4451df7	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb6cecd48	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xbdc4484e	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd8cf49ef	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe851a93e	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe858f584	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xec9c6356	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xed6e74e6	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf227e477	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/mfd/dln2 0x267049fe	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/dln2 0xb344da22	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0xe7bd6d8c	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x361eaf0c	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xfa680a3f	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x0d0c42ee	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x24985e6c	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x3f4e517d	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x53e76b29	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x6b2dae6f	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x7dbebd01	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x8c8ba3aa	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xad94df91	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xdf296c9d	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xe64594c7	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xe91ad274	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x6a483ffc	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x7760fd67	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x55d1ac97	wm1811_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xb5fa1d43	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xcab3aeba	wm8958_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xf8891523	wm8994_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x5f074f19	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x98e4eff3	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x30b3ae49	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0xde91f5f4	c2port_device_register
++EXPORT_SYMBOL drivers/misc/c2port/core 0xe5120bdc	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/ioc4 0x30371f1e	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xd7dbb3e0	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/tifm_core 0x161cd8fa	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x27b238a0	tifm_add_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x4ff50c4c	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x6adde909	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x6bc63e9a	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x6cdc51b8	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0x6d63df46	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x93e60a0e	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xa8c2ec46	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0xd398f5e5	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xd6d2f00b	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0xdd7c9e9b	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xdefedc80	tifm_unregister_driver
++EXPORT_SYMBOL drivers/mmc/card/mmc_block 0xc63e7fcf	mmc_cleanup_queue
++EXPORT_SYMBOL drivers/mmc/host/of_mmc_spi 0x5b1bce60	mmc_spi_put_pdata
++EXPORT_SYMBOL drivers/mmc/host/of_mmc_spi 0x79b397d0	mmc_spi_get_pdata
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x05991a56	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x7cbd2489	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x89952f99	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xa8795877	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xd8ca0747	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xf5333dc0	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xf6cbc233	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x1de135f1	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x4cfdec98	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x5885c10f	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x5e1c8aa3	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0xebb0d06e	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0x6e4ce070	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0xdc66674c	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x48f87496	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/mtd 0x4e96f41e	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x78e42dfd	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xdca7700b	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x1d066e4d	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x58956810	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x7943aa77	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x7fe3df47	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xc6d76dfc	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xe19eecab	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x11ccbfb1	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xf387a0aa	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xf4d8d15f	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x5596497e	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x5a5a103a	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x74500629	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xae117f1a	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xd903ba0a	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xf181a933	onenand_default_bbt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x07a051e2	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x111e23b7	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x17ec6831	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x32630ac8	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x402f020c	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x51704c16	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x58686332	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xab533aa4	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xcea2f3f2	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xf65670b0	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x2408225c	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x64bea8f5	com20020_found
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xde14a41c	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x0ce329d7	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x1db4e8c7	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x207230db	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x235d8532	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x29e5d8c5	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x49cce852	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x6a870e05	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x8afbac04	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xba831b8f	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xcab50b4d	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0x41a5dbbc	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0xb71d79d9	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x0d8be5fd	bgx_lmac_rx_tx_enable
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x285bde59	bgx_get_rx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x42264715	bgx_get_lmac_count
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x6dc1648d	bgx_get_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc397f585	bgx_lmac_internal_loopback
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc82be691	bgx_get_map
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xe48ca42a	bgx_get_tx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf101d1b2	bgx_get_lmac_link_state
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf9508980	bgx_set_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x123d0948	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x36c3df61	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x3c911bc7	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x49ee1a32	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x53a54a0c	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x6d588080	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x6eed240d	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x81e02826	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x847a0b6b	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x8eb5f4b7	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xc1b0fb3b	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xda08be1e	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xda254db5	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xe9daec92	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xfaa6d706	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xfb614fa1	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x2a1ab71a	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x36d40fd9	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3edaf999	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x420b8f81	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x473d199a	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4d4f1d1b	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4de0d21c	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x5129accd	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x5a67dca4	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x688f874e	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6d248ae2	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6e4c3ca8	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x723ed6ca	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x723effa1	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7bb2b134	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x82edc481	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8734f980	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8ebcba63	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x9180d48c	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa0e4c159	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xad1fef16	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xad4667cf	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xafe5698c	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb0687115	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb8b2c69e	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb8b83f5f	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd6dbe6fb	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd7523057	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd8fb6d82	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd9e443b6	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe241680b	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe3347353	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xef30c82c	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf128f000	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x1c170763	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x31964c93	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x35936dbe	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x80e24382	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x81f91116	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x86318d5c	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x5d0c1e0e	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x6774b254	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b319ae9	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1288d68d	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x14b8f70d	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1951ca80	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1a30e928	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2e1e8d79	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x317eebf7	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3d8dd6e7	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4ba0a463	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5f084411	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x62c97382	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6562c7cc	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x673d071c	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x68d27c89	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7672ae9b	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x795323cb	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7abd1b1f	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x82727081	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8335c88e	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x86de66e5	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9f5f1332	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa4983a51	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa68b880e	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa6b74ba0	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xac362562	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xafff25ec	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb32a4db3	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb4994d46	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xba365d32	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb5b3f1f	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc2dc340d	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc580d4a8	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xccbd69f1	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd2bbe13e	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd91c32cb	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdc923162	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf1d1cec7	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfd161cd7	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x058dcd53	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x13fb4d9c	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x16420b48	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x245fd966	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x25b2db84	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2aca73f1	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x32a9a24a	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3395c16a	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3e02262f	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x43d87518	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4b5d55d2	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5231dd7b	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5662fc94	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6811de42	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x73b298f0	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7591b125	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x77eafcee	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7b01422a	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7f125ad6	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x841c7891	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x87fa0dd9	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x891d1d92	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x93605bd1	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9a50dcc8	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa167e738	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa260c0f5	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa61e535f	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa88beaa7	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xad1fe2c7	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb5fcf211	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb7eeb771	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbd9faf3c	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbded81a5	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd1ba6b3f	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd2ea4eb5	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd5b29268	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdcf34c2b	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf54364eb	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x22809fe8	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x2b347490	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x2d07a992	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x3efc4b7b	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x99906e29	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xb9511a36	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xc751d9f8	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xc79a4238	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xbd08ec46	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x5d5b1cd6	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x7d02e84c	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x7d9175a0	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x8adedc40	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xa8e8d964	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x1f4ad2de	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x47bf234d	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x6beb109f	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x9524bfaf	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xaabbf0c6	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xb5793070	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xbec28d63	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xd31b41f9	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xebdceb31	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xf7a81977	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x1ef150d6	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0x2a30d1f2	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0x3d141438	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0x8bc16e9a	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0xac834fe7	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0xb16d39f1	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0xc31ee8ee	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0xd28b1c8d	mii_link_ok
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x5b4965f6	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xbbc8e1e8	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0x1fca3a71	cavium_mdiobus_read
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0x261fc8d8	cavium_mdiobus_write
++EXPORT_SYMBOL drivers/net/phy/mdio-octeon 0x8a1d5c26	octeon_mdiobus_force_mod_depencency
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x35efc850	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x9577ffca	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xed7d4008	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/vitesse 0x0f054b2c	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xb3f26511	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xcf2ef33c	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe315090d	register_pppox_proto
++EXPORT_SYMBOL drivers/net/sungem_phy 0xe134c847	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x300bb931	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0x40bd0e2f	team_options_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x738e5ffb	team_mode_register
++EXPORT_SYMBOL drivers/net/team/team 0x7b2d49dd	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/team/team 0xad679d82	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0xde186b7b	team_options_register
++EXPORT_SYMBOL drivers/net/team/team 0xe27dd0bf	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0xe28e6bbe	team_mode_unregister
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x0f9b3896	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x61b8e56b	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x9da37a1d	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xd71d049f	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x0db9f3fc	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x0f83e9d1	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x4b0d39b1	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x4cd5a44c	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x7383528d	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x8944883f	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x92a65f1c	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xcab0d54e	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xccbb2b59	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xd0367c25	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe6181d20	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0x823f40e9	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/airo 0x094067a4	reset_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0x58e66dc3	init_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0x707c9d21	stop_airo_card
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x14b1fb64	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x32b00d05	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x5b2c8502	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x6bf90798	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x8ae78ea6	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x916f7af6	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x99cb75f6	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xab6b038b	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xae595f26	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb554126c	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb980396f	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xf96615a3	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x4038b093	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x49968904	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x50e369fc	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x631ec961	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x6483e263	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x678e8866	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x827a7ed3	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x86b032ba	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x911f43a6	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x970a8f1e	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xc279fc75	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xce4d1d70	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xdc475356	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xf2e724ae	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xf5de47de	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4cf4faef	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x64d5a7be	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x6a08e6e0	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x70330560	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x8814c67e	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x90449c16	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x9c5012b2	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa7523b2e	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xbc43694d	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc052f9d5	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xd9fbb21c	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x04ff3035	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x180cac77	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x28f5a2ec	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2a44795e	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x360b8ab3	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x3965ccc3	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x5a3a4b61	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x5b68e36a	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x5f0b4175	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x60cf37a8	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7b63c8b3	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7c5af0b6	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7ef436d2	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x86f41a3e	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9d4ca2a8	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xaa622a9a	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb083752c	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xc63b2e4d	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd391855d	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd8afc00f	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xee6a4d73	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xfd2427a7	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xfe6e7338	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x007ead76	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x035f038b	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0512d93c	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x07da3ede	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0f767f9f	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x120ae889	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x15131ffa	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1765d71c	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x19e036e4	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1b525b8a	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1ea779e9	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1ecb11cf	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1f0c6363	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x22611e7a	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x227dfd3b	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x26b7449e	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x273998e8	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2d47cc07	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2e260916	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x30ac6968	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x32586428	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x330ddd7b	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x37543297	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x37de130d	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3affe505	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3b3b1fb9	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3b92ebbe	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3bdd1530	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3cb86ccf	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3cf534d2	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3e33c074	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3fb8bd90	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4173e2c4	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x435fd39e	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x46a6ee76	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x48d015a3	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x51b6d2c8	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x53bdb964	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x54a6c447	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x55f90878	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5bb9db05	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5c7651b1	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5c916b12	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5ed35b81	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x60a33d0c	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6580aaa2	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x66eb2029	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6860f6cf	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6964b615	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6cfa0c57	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x728203aa	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7296411a	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x73094246	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x76605eee	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x77c6f003	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x790e5969	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7d65c020	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7da57b1f	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7dcb044d	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x83b9696e	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x84e288d9	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x86f44222	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8a6e17a6	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9067c638	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x919b938e	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9402c490	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x986848c4	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9f89da76	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9ff6cf69	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa3604377	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa57d9682	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa65c5bba	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa95cc9ad	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaa3a4697	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaf5f38c5	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb81a9419	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbc9bada1	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbdb751a9	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbded0e93	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbec1a42f	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc0d5aae2	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc0d98f86	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc7131073	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc7f97f7f	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcb78e824	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcd72763b	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd2b5a4db	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd9690af5	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe34a4dba	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe60c9406	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe6281c51	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe691128b	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe963932a	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xeae0256f	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xeb7ead5a	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xebfa5e65	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xed518259	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xede1ec94	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xef603391	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf1d6e256	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf2472b3e	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf9cd1a7d	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfc8ae58d	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfd252b4c	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffda667f	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x3766649d	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x7a9db171	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xc0727e33	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x0105f857	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x037a7dc9	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x07eb80d5	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x20b29ad6	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x2eb8366f	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x39d487ad	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x55a7155a	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x71c97223	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x935c617f	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xa2cc2d86	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xb248365e	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xb6016c43	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xb9c1ba19	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1203e572	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1723ac32	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x19cbdebd	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x5174ef93	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x533daa42	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x56bd1059	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x60b99feb	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x73869c02	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7969e7e4	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7b686218	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7e2cf729	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x842f214c	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x86ce7179	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8a06e849	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8adf66ca	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8f0ff67a	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa0487c20	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xbc2ea706	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc5649168	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xcae5fcb7	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xcf875644	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd7598143	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe25b4872	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xecee3c03	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf477c49b	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xffe53c9b	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x219fce0c	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x29e4060d	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x2b40d2cf	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x2b4dec07	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x31d49e09	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4cfc959c	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5ddcedb3	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5f5df45a	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x6022ebbf	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x62a1348d	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x78d79bcd	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x91ef8ff5	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x9ef8d1df	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa04d33b7	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa37049e9	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa7bf67eb	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xaa34b49a	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xbd7fd50a	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xcea35405	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd9ef2f63	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xef1b1f6d	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x07190295	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0d798291	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0e61af85	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0e680326	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x15b067b3	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x16c8aba8	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1b897cc6	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1be7fab8	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x21b73f35	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x23b0eaee	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2b1fd6a9	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2bae62e4	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2c1a61c5	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2f40d17a	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x322b5540	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x33e3c81a	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3495cda9	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x356a1b04	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x35f0f39d	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x365f1e13	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3b65e428	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3db92244	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3dce2b5e	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x43523e9b	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4374cb53	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x50dd37f8	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5387c101	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x55e68f7a	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5c495167	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6c40ecdc	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x70413bb2	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x735bc8e5	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x758dc812	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x75f30ca1	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7dc4fc27	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7f773896	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x81f635fc	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x83133d1f	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x87e6fd63	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x88ce2bd3	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x910b7ab9	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x91185500	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x91fd64b6	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x93d79e66	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x94171389	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x947395f7	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x95afe075	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x960288dd	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x972713fe	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x99ee101c	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9b060b72	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9b8b55b5	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9c63efd0	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9e1d59a1	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa1343770	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa18f31c9	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa6610b99	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa6ed993c	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xad4b7369	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xae0b4159	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xaf56b0c1	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xaf756bf5	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xafb3727e	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb0266457	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb3b90184	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb4f5e741	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb85f23ad	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbfaa9f9e	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc0a05b78	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc18667b5	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc18fa585	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc1f54632	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc260cd01	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc3ef3419	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc4ad2a65	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc538445f	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc67dc359	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc72b88e2	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc7e73d59	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc803bdb2	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcaf650a9	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcb5307c6	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xced4eae9	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd7e338fb	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdc35b5f8	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdedca967	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe061c6de	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe3682d7e	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe533a951	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe6c35edf	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe9086265	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe975bf71	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xea639319	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf199a8a7	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf25ca0f6	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf75e8023	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf8badfa2	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfe786173	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x1b06ce78	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x2447a6ab	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x314a20a8	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x5e9c24ff	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x8c8ab242	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x9a1b1df9	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xdced6db1	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x238cf0db	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x42a8ac20	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x44daeda1	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5dea5bf1	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x66545bca	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x7071a127	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x74abe2e7	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x9c5ac87e	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa976f665	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xacbf3ae7	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb00f8b0b	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb2053cb1	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb59b79be	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xc96982f0	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xdf8f8aa9	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xe38fc24a	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xe7d6e78b	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0xbe03e406	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x16b3e2e2	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x192a8f39	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1d8ac9b8	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x29636b2f	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x31e7dfad	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x333aa63f	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x33fcb1f3	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x391462d2	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4c018382	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x53b35aaf	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x59344ac1	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x60d999fd	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x62b5f10f	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6663e6dd	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6821798d	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6d68fd9d	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7022757c	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x792cf13e	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7e14adca	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x7f2f4998	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x937f3db4	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x9b24f936	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x9bb16de7	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa2d0fd5e	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa61d4516	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xab5b6029	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xac5a0e81	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xaf48955f	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb8ed0bfc	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xbe9e1284	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xce81dddf	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xcfd516f8	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xd564cd29	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdaca938d	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdbb9719e	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xde2facb5	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xebf5b762	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf27e49ee	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf4f4bf4e	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf926eef5	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf9c86dad	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x1620c94f	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x6ca0551c	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x73f121dc	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0x744fd6fa	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x0afca1ac	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x0cee900f	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x32bea349	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0xe16bc794	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x07be6e7e	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x18327e24	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1ce36921	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2436753f	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2bd3de69	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x30de2e43	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4edcc3e8	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x502184a5	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x52ec32b4	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x58f642f2	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x607ca666	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6b1a5b11	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x74826f7d	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x857f8223	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8dff91e7	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x90bd513b	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9e613442	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9f6b0103	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa0f9c837	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa369b056	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb429c5c0	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc450ad7e	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xca8a2511	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd97ee4f0	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf0f9520e	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf54e6524	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf8f1ecff	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xfcb35e71	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x12df1a9e	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x1b2c9fbc	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x5170bb9c	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x69421e98	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x0b271e9e	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x9de5ba34	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xd78556e4	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/microread/microread 0xca77b978	microread_remove
++EXPORT_SYMBOL drivers/nfc/microread/microread 0xe75f0920	microread_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x9c5656c8	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xb058db11	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xe7dc4455	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x2d943900	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0xdda756cf	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x0cb8c57a	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x4142f8ab	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x7a28c53e	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x63608fb7	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x658a0e8a	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x68d5cd51	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x70f99bf9	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xa83035a2	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xac852495	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xb4a0e911	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xda64d0c2	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xdf440a2a	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xed70664b	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xf38b0617	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x0a7dcb5d	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x25e8402c	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x29d4a38c	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3062011f	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x379c498a	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x4dc80af9	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x616ee131	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x656240e4	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x6620fec0	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x6a291435	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x6dbdd517	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x6eafa5ab	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x7683fc0f	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x8bd39ff5	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xbc217f0a	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xd87a2977	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xdb762327	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xe2ffeebb	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/ntb/ntb 0x24351707	__ntb_register_client
++EXPORT_SYMBOL drivers/ntb/ntb 0x5df9bf6e	ntb_db_event
++EXPORT_SYMBOL drivers/ntb/ntb 0x6692b124	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0x690a309f	ntb_clear_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x9b46b1de	ntb_link_event
++EXPORT_SYMBOL drivers/ntb/ntb 0xb7d15d83	ntb_unregister_device
++EXPORT_SYMBOL drivers/ntb/ntb 0xfdaa6603	ntb_set_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0xfe0c185f	ntb_register_device
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x1304dd58	nvdimm_namespace_attach_btt
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0xa5f2216a	nvdimm_namespace_detach_btt
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0x68624bed	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x045dd146	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x069fff2b	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0x10a938ec	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x122c3018	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x23ba4108	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x3741a4fd	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x3f0d94d8	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x402128c9	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0x415234b0	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0x46fabf58	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x5e20c474	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x5fdb22ce	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x64319a10	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0x7422a9c5	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0x7ad89705	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0x85076654	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x88c79850	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0x9295cda5	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0x96cf3c19	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0xa6766c43	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0xa826c294	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xb23ab4c3	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0xce9711ba	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0xd090cd0a	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0xdad90509	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport 0xddbb24db	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0xf46f2667	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0xf47b910b	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0xf6494378	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0xf8b77b30	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0xf94e09d6	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0xf9d050bb	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport_pc 0xb360e275	parport_pc_probe_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0xd6d20f0a	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x0884d042	pcmcia_read_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x0b64c5b4	pcmcia_get_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x1ad5f777	pcmcia_unregister_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x33ec3a7f	pcmcia_release_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x3a19b46e	pcmcia_fixup_vpp
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x46bbdd19	pcmcia_map_mem_page
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x742f5665	pcmcia_parse_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x763ad16f	pcmcia_loop_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x79e60537	pcmcia_request_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xa6469d8d	pcmcia_fixup_iowidth
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xb2194a0e	pcmcia_dev_present
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xcfb30775	pcmcia_request_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xcff55d17	__pcmcia_request_exclusive_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xdb747c54	pcmcia_loop_config
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xdf9bc2f5	pcmcia_request_io
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xe383a53a	pcmcia_write_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xe4d12f4c	pcmcia_get_mac_from_cis
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xe7b92b9e	pcmcia_register_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xf0e07e12	pcmcia_disable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xf769cdec	pcmcia_enable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x0a16aab2	pcmcia_parse_uevents
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x212db8d2	pcmcia_socket_list
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x49d6e1c5	pcmcia_socket_list_rwsem
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x567d991e	pcmcia_reset_card
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x6507098d	pcmcia_get_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x9b9df22f	pcmcia_socket_class
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xa1bdd9d5	pcmcia_put_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xbf36db09	pcmcia_get_socket_by_nr
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xce50bca2	pcmcia_unregister_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcf97f3bd	dead_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xd33cd99c	pcmcia_parse_events
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xf3e7d99f	pcmcia_register_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xfd94f4b9	pccard_register_pcmcia
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0x28b331f8	pccard_nonstatic_ops
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0xadc05209	pccard_static_ops
++EXPORT_SYMBOL drivers/pps/pps_core 0x4833b620	pps_unregister_source
++EXPORT_SYMBOL drivers/pps/pps_core 0x4ee60586	pps_lookup_dev
++EXPORT_SYMBOL drivers/pps/pps_core 0x77a56298	pps_event
++EXPORT_SYMBOL drivers/pps/pps_core 0xe8a13292	pps_register_source
++EXPORT_SYMBOL drivers/ptp/ptp 0x1404636e	ptp_clock_index
++EXPORT_SYMBOL drivers/ptp/ptp 0x9e9d6846	ptp_clock_event
++EXPORT_SYMBOL drivers/ptp/ptp 0xae1ff64f	ptp_find_pin
++EXPORT_SYMBOL drivers/ptp/ptp 0xb6d58140	ptp_clock_unregister
++EXPORT_SYMBOL drivers/ptp/ptp 0xec538d95	ptp_clock_register
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x0135aed0	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x2356f8d8	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x3f91f4cd	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x40334571	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x6462a3c8	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x6d9b39a8	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x94f0ad60	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xb2e822c2	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xd4580e13	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xf7561c7b	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0x54c7435f	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x5cf00092	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x94720f2b	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xa97b5c3b	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xc384b127	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x3250a049	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x57873cf2	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x5963bbe4	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x9f11d853	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xa85a893c	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xa997fad6	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xae91081e	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xcdbb3a36	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xd7bf4fce	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xeb4fd47f	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xed3db8d1	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xf70c74fa	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x01dca623	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x044aa8c6	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0af05290	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0f244411	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x13c074f4	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x152d8cd5	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1bf36dbe	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1f9d19bb	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2bf484c9	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2d3254d1	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x30704c4c	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x350c6e4c	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3540d6b2	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x35c5b227	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36fd929c	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x40baedda	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x42cc6cd6	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x450ae1f3	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4cea053c	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5303afb0	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x595edece	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x59d4002e	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5baa8520	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5ccc441b	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5f16ddcd	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x67dee661	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6a573c63	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6fe521cc	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x77e00a75	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7aafd92d	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7b601c95	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x81c79375	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x892cd4e6	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x91d2aa4e	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x936aa364	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9a1403d0	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa5fcf5a4	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xabccbdb8	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb1f176af	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb8593248	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbf4c89d5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc6b45c40	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xca885089	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd7cf63fc	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd8722ece	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe1d806b8	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe1ef23d9	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe2965d8b	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf02347b6	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf236cc2c	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x40a98554	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x604caaad	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xb10f09ac	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xd60ecc21	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x859c1177	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x00035000	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x065b5aaa	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0a9da79d	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0df2ef24	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x346cf0f9	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3b3d1805	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4c8142a1	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4dd6192b	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5097461d	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x521ef072	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5706373d	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x585f2875	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5abd84c9	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5bca4069	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5d22499b	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5d8cd9dc	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x65c3ef9e	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7b2c1c0e	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x80162a2c	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8354c6bf	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8666f24f	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8c54a464	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9257a4e9	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x98d0269d	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa8fa6a7a	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa91cab7b	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb6743f30	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb6d07028	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb70b1103	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb86d919c	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc0e9e5fa	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd1abec42	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd5dce8e6	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd88874e2	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf4fdeaf2	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfe95a383	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x2d77e2bd	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x715be1df	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x9929c1d2	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xdb228da8	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xeca0a090	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xff8aa54e	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x032caafb	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x11e9f835	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x14ee1d35	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x2061fc49	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x2eb0e6ad	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x35991a7c	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x3bd227c9	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x3e888d80	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x9a8a028b	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xb8c707c1	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xd7f77984	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xec5f5ab0	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x03e9d448	qlogicfas408_disable_ints
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x1f55cd70	qlogicfas408_ihandl
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3fd8cd71	qlogicfas408_detect
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x443df378	qlogicfas408_bus_reset
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x690109ff	qlogicfas408_abort
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x9612ffc0	qlogicfas408_info
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xd7077cad	qlogicfas408_queuecommand
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xe76b3b20	qlogicfas408_get_chip_type
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf2b95199	qlogicfas408_setup
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xfebf005f	qlogicfas408_biosparam
++EXPORT_SYMBOL drivers/scsi/raid_class 0x7caf6070	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/raid_class 0xb250f3b3	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0xe94473d6	raid_component_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x05ac127e	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x095cb17b	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x19b83537	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x1baa98d0	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x1d724fc7	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x2dbbab3a	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x6f19c3de	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7c0b0217	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xb16429e7	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd2837d41	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd4ef8fa1	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xe387ea2e	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xeb44c696	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x0294cd2c	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1d51d869	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x210b8f6d	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x21269589	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x231c9229	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x3105c100	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x464d7af2	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x49d63f30	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4a62abda	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x52de4d77	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x58bec861	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5b07d921	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5cdb87b6	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5df519db	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x66299c82	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x66600b3e	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x67ae604b	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x67ca5cbf	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x68c53dce	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x75e0f8f9	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7bf09499	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x97a8d3a3	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9c5db1b7	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa3d3f633	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc49bd73f	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd0245bd8	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd1c2c79e	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe0865d65	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xfea81c66	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x437cbc5a	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x49358282	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xa30bb0f0	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xc6380ae9	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xdcea3729	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x316d39b4	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x3d10da43	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x3d2d90a7	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x67cf2252	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x699cd792	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xa58f3e56	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xed2ed6e5	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x0bb10cc9	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0x12dab6ab	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0x49b8c349	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x64518805	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0x67dc220b	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x7b89e9d7	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x7ce9b148	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0x847c192b	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x8b15cd35	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0xa131c7f3	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0xafbf9237	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0xbc404f6d	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xc4c3fefa	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0xc8269d64	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xd66a0b74	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0xd6fb374c	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0xdc775be0	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0xe3a60504	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xe8d65e7b	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0xf41a2d40	ssb_device_disable
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x017103e8	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x05d2d9bd	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x05ef1394	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x0a4682a5	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x24d1e345	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x36f526c8	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x3fa9ef84	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x3fc07423	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x4d0c47ae	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x4fa557a8	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x594366fb	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x6363ad53	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x65abe5ad	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x72f5a2b3	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x92b9b14c	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xabdb5103	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xcbe7c97e	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xcbf0588a	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xce48f23a	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xd86c2c54	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe4d6a8a5	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xeb47ccd0	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xf8a01368	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xfdb0d534	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x01ea756b	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xf57b229a	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x028c8ecb	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x2f0cc193	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x5c239b53	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x65240cce	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x87a3d92c	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x0abd5f1e	ade7854_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x969903c3	ade7854_remove
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0x0b5d9aeb	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0x35a3c3d7	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x00032ab9	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x00cb8bbe	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x021d5774	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x045433fd	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x050c87e6	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x07c3e63c	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0ffd4468	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x15224bd9	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1bdcee2a	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1d6826ff	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x24eb79f4	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x30f3da61	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x31a016dc	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x32ab4a51	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3460732f	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x373d4ade	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x42471417	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x47602779	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4fb33f68	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x51917abe	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x55e1e1ac	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x59d003a1	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5db83cb7	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x60e59eb5	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6a39fb92	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x742c4c44	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x774e3234	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7a880a3a	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7b48c2cc	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7f5ff7a2	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7f9d01e9	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x848c26af	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x97c145c9	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x99928f95	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa290f95a	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xab131f00	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb3f1b1b6	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xba1d78ea	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc177e584	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc30c6c9f	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc3278a68	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcde362ba	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd1a872aa	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd6cab5b2	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe0839be0	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe4db4400	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe514e758	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe74c91c1	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf704745f	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfb5399d7	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x03c199cf	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x08501008	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0dcf4a02	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0f099f61	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0f4dee0a	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x10d466dd	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x12399d53	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x13d5b509	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x13f8834b	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x143800a3	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1dba3d05	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2a57ea13	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3f78db99	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x40d03941	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x45353578	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x469d154b	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4d73c8b3	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4e1958d4	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4ed4867a	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5e78e35d	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x61ea895d	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x63a9021c	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x673ca7fe	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x681c40af	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x691f1347	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x71cf70a1	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x75e2dd8f	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x76ce3819	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7a330c03	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7c06d1c4	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7c365d2f	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x81326472	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x86398f2e	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x86c19fac	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x892f7a52	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x947e5a9f	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9f6286c3	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa37f1183	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa566fda0	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xac357e4b	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb6602dfb	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb8023f25	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbcfc4305	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbdc177d1	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcb7580d3	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdeb671c4	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe091a086	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe15e33a6	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xed9d444f	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf9b821f8	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfa54c977	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfab9021e	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfc3ba03a	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfd1f27ef	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfed50b24	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x096f8044	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x114e3b79	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x158ffc5c	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x1e1a7171	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x22a87b62	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x2e4527e9	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x34eefbf1	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x366f117f	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x390bc01b	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3d155c4b	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4109b9e9	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x411473e0	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5117681f	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6bf2cb0c	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x72249661	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x88c5eec6	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8b7a1766	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa2182c57	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xad5527ce	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb7a8f327	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc0b62a43	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc33b0742	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc90b7a5b	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd1f25559	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd2bdfb01	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe751622f	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xfa5bf6c8	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xfe113b46	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x031c89f6	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x058deacb	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x08d12716	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0x08f33cd7	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0c3a0f89	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0da96c3e	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x11316d13	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x12a12415	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x14c39e3c	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x20edca40	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0x256086bc	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2dc18d4a	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2fd4770d	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3031bf57	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x30ba8e4b	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0x34f13cd0	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3746cd69	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3aaafff7	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3c016416	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x485e8f75	transport_init_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4b49f6e2	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4bbdfa1a	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x561ad622	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x572356f0	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5eeedcca	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0x60c4f7fd	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x62c49e25	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x666d8e85	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6723c8f6	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6729a459	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6780461c	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x68bb4ff2	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x69c15cd5	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6bfe11e8	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6c419f23	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6d2c3edc	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7586108b	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x854d591b	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8621e6de	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9d4eda7d	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa3d07987	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa7b1a9c5	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0xadab89ca	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xadb24143	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0xaf26f2bb	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb116478b	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb7668fdc	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb79fdad9	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc2f867e7	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc472901c	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc4a579b8	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc5db238b	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc7db33ae	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc808b5fc	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcceee2b7	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd0d32746	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd308f223	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd5c53e34	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd638854e	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe08f426f	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe1b372dc	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe489daf8	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe5327571	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0xedc202d2	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf257fddf	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf49c5f04	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfb9b5665	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0xff7ac62d	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0xff9b98d6	target_get_session
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0x5ff085ef	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0x4424cb90	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0x74fd4b7a	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x00ed3f91	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x173d070c	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x377690b1	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x3b05ec2c	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x4aa54985	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x59f3ba45	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x6a2fede0	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x772a0bb8	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x9caa0ad0	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xc22fefeb	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xc47aa40b	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xe14fb24d	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x48e17737	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x9b466197	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3b304ebb	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3c71c418	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x4311cd91	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x5fedea44	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x97fa07e9	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xde804bb9	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x1821bc87	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x42f2db1a	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xda7e07be	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xe5eefad2	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x09fe1718	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x12486f05	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1e908f04	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x5ca68797	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd49e7231	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xdf10cd19	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf5d17406	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x2ce23156	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x40ad90e2	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x6b149320	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x9c4dd5ca	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x0126f5d9	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x0280d9f8	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x8500351b	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x900f4fc6	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0xac59a4f8	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0x6f2ab52b	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x4a174d67	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x7aec4eae	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x8559cf9e	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xb7805ab1	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0x67f5295c	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xbbbce29a	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x17cc1b7d	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x7748a8fd	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x9e1bc772	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xdd7b5bac	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xe3bfc7bb	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0xd876f4f6	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x1d4485a9	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x45e143bd	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x78be6913	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xbd50313e	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x8247c8c9	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0xfdd86424	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x9d99ca6f	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0xa6fae376	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/wire 0x147e61a1	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x1a405bec	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0x7de40117	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xe5371c32	w1_register_family
++EXPORT_SYMBOL fs/configfs/configfs 0x084e2c90	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x3857a804	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x49d9e39d	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0x5ad47457	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0x5e628863	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x61c72c90	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0x769f915e	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0x8c613b3c	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0xa410754c	configfs_unregister_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0xb7b03e33	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xc49aaf97	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0xdffe0574	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0xeab5f24c	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0xf90d5ea7	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xfc53f52e	config_group_init
++EXPORT_SYMBOL fs/exofs/libore 0x067f3ed2	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0x251121f7	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x2e968e4d	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x361dc470	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x38b54002	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x4f8b5894	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0x6f539c71	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0xa23d5fb4	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xd9c652dc	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0xe8ed65a0	extract_attr_from_ios
++EXPORT_SYMBOL fs/fscache/fscache 0x023b25a5	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x087a965a	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x08ca35ce	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x0c7b31c0	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x0fcd4e79	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x29f6017a	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0x2a5b6bdc	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0x2bfd13a8	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0x38335916	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0x3fd60e97	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x40c1e720	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0x4aa5f6ff	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0x4e4f8ac5	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0x4e8ef38d	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x5501338e	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x5b9f1266	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x6563e8a4	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0x67e09c78	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x69e32687	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x6d1b5cbc	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x72453d95	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x79cd3c18	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x838304bc	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0x840d2279	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0x8ecca4fe	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x904a9e8e	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x91838de7	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xa235c352	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xab668336	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0xab7a98e6	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xabe14cc9	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0xb554e10d	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xbaf12fc2	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0xc55b010d	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xc8995516	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0xd74d7284	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0xdf15c268	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xe330257b	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0xe7c360de	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xea9e2897	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x1a2f5a1c	qtree_write_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x99f6bdb5	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xb1bc0c95	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xb2488fb8	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0xdc26def1	qtree_read_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x1a703ba1	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0x6d356209	crc_itu_t
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc7 0x56329ecc	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd09b2cba	crc8
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x0641307b	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0x098d2ed9	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x2d47ac83	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0x2f3dcecb	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0x4522d82a	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0x4cf5f5a8	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0x5752f31b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0x7257beee	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0x9134feb7	lc_get
++EXPORT_SYMBOL lib/lru_cache 0xb672aa97	lc_create
++EXPORT_SYMBOL lib/lru_cache 0xbfbe53d5	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0xc3a98c1d	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcc979a91	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xcf308d34	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0xe7fdefdc	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0xefec290a	lc_find
++EXPORT_SYMBOL lib/lru_cache 0xfd525ec7	lc_put
++EXPORT_SYMBOL lib/lz4/lz4_compress 0x0c222eb5	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x682a23e0	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x7456cc61	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x36da4be8	lowpan_netdev_setup
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xb14b4e0d	lowpan_nhc_add
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xc4a19649	lowpan_nhc_del
++EXPORT_SYMBOL net/802/p8022 0x3de6224c	register_8022_client
++EXPORT_SYMBOL net/802/p8022 0xca57d308	unregister_8022_client
++EXPORT_SYMBOL net/802/p8023 0xee194d0d	make_8023_client
++EXPORT_SYMBOL net/802/p8023 0xfe04e213	destroy_8023_client
++EXPORT_SYMBOL net/802/psnap 0x7dc22656	register_snap_client
++EXPORT_SYMBOL net/802/psnap 0xbcb8db37	unregister_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x046c2437	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0x065bac5e	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0x0f7bbdd0	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x14f30b73	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x23259343	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0x23fe1d2e	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0x2449615c	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0x34f8f033	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x3717664c	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0x394ebe23	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x3aeaa2d6	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x47b2abbe	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x47d9ab39	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x493fc61c	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0x49683197	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0x52cb01b2	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x53d58a07	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x5b191e05	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x66a6462b	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x67593829	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0x742eaad9	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x76bf5610	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x7e218ab0	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x7e5a9a18	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0x87f73ff5	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x8b7f9c90	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x912356e5	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x9452248b	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0xa630822b	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0xaf681c0b	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0xafb06524	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0xb28af5f9	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0xbcb52803	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0xbffce67d	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xd11ce39f	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0xd9948d49	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0xdc7a90bd	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0xde3034e2	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xe798c263	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0xeb923727	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xf8c490aa	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xf8c6e869	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x42238f34	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0x46544e5a	atrtr_get_dev
++EXPORT_SYMBOL net/appletalk/appletalk 0x65ba4860	aarp_send_ddp
++EXPORT_SYMBOL net/appletalk/appletalk 0x7e82e131	atalk_find_dev_addr
++EXPORT_SYMBOL net/atm/atm 0x01ce468c	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0x1c2bd283	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x3578618d	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x6c62b16b	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0x6db31129	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xae4a3e30	atm_charge
++EXPORT_SYMBOL net/atm/atm 0xbd14b4b6	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0xc1cb5a99	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xc8cce6ed	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0xca87b453	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0xe364f2b6	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0xebd81ba4	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0xf1491383	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/atm/atm 0xf59f37d4	deregister_atm_ioctl
++EXPORT_SYMBOL net/ax25/ax25 0x0c190951	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x2b66e92a	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x7486859d	ax25_ip_xmit
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0x96eb8eeb	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0xa3010999	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xc6688d1b	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0xca8db46b	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xecd2e5b3	ax25_send_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x06b21ff9	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x09193907	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0ed246b7	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0f320ce6	bt_sock_wait_ready
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0fdffec8	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1da93db9	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2854ef53	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x291ba43b	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2c62dace	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x332f854a	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3596bab9	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3b6951eb	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x498281c7	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4a65f46d	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x549813e1	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x66779253	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6c192247	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6e87f2c9	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x70478703	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x76fb7d85	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x78505764	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7b916a68	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9b8313f5	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9d2a9291	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa8c15afc	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xafe303bc	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb11c5d3a	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb1ded9c4	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb9bc351a	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbb754ce4	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbc375c97	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbf48867d	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc42eec39	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd5c3416c	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd9e24ee3	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xed00af7a	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf3c6a894	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf5581684	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf7258566	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf84ce8ff	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xfc8437ad	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bridge/bridge 0xd7ea687c	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x3fbf120f	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x469314a8	ebt_register_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x7575ac26	ebt_do_table
++EXPORT_SYMBOL net/caif/caif 0x07fba2b0	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x8ed4866d	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9ade59b2	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xaa374df6	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xfaa1e7aa	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/can/can 0x14d015b4	can_send
++EXPORT_SYMBOL net/can/can 0x1d111f16	can_rx_register
++EXPORT_SYMBOL net/can/can 0x21e774f4	can_ioctl
++EXPORT_SYMBOL net/can/can 0x59ee78ae	can_proto_register
++EXPORT_SYMBOL net/can/can 0xbb308161	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0xdfff4ad4	can_proto_unregister
++EXPORT_SYMBOL net/ceph/libceph 0x0187af13	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0x0359a0cf	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0x05fa830c	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0b9c9f96	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0x0f004c13	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x10b3e82b	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0x16c5f31d	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0x1db0c995	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0x1ffdb4e1	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x205e1b49	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x2169ddb3	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0x21c60751	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x24d897df	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x2bed91f2	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0x3144121f	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x3357c025	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x37302806	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x4062aac9	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x419cb09b	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x4c5f52f4	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0x4e098287	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x4ee939db	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x53ce08bf	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0x560c0fad	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x57d353ee	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x5bcab1cc	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0x61b0fd91	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0x63041744	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x66f15094	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x698a9ae5	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6bdcd721	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x6fcdafef	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0x70dc7a41	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0x70ee45e1	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0x71476444	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0x736871cb	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0x7760c38c	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x8c4a7694	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x8c96e981	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x8e452666	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x8fdc0452	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x908a92e2	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0x9980ec82	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9a449269	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x9aa0d119	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x9d3a2587	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0x9de04ee3	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0x9fd8a791	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0xa13f2b32	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xa49b7111	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0xa4ae1741	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0xa4c30e04	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xaf5707ad	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb3cc16fc	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb87198ee	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0xb879ff07	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0xbb9e74dd	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xbc77c63f	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xbcf5772a	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0xc167a691	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0xc183911d	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc50f6b8a	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc975dd99	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xcdb5eca1	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0xcec9186c	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xd0642733	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0xd0ee7396	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xd1ea5044	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd37c44f9	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xd58865f0	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0xd658817c	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xd7acd83f	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xd7f627d1	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xd8f8987d	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0xe1279f64	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xe3b042ca	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xe9100e05	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0xeb7a140a	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0xef3db572	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xf01cb440	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0xf1af7fc9	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0xf24fb65f	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0xf35cb4d9	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xf388a218	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0xf449d43a	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0xfdf19b15	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0xff508020	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0xff9b51ed	__ceph_open_session
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x00d0e9d8	dccp_req_err
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0xed47ab7c	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x0de85637	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x5c362d57	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x82b2d77a	wpan_phy_new
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x901096be	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xa13ff870	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xb8652bc6	wpan_phy_find
++EXPORT_SYMBOL net/ipv4/fou 0x3106aeb4	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0x44732433	fou_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xa22d3fb6	gue_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xd0750778	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x041c1a67	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x5399605c	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x84ca3543	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xb80c339d	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xbc9f6361	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xce716771	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x2fcc4c27	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x9f48a8a2	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xcd0fbbda	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x3c7f33c4	ipt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x845a7477	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xb72151f1	ipt_register_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x9ce3be92	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/tunnel4 0xac19cd17	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0x423a49c7	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x107ed27c	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xa4bd79d1	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xaad5a2ee	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xd86175a8	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x32f7b9db	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x5ca838be	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x7e5ea9b9	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0xaeda1547	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0xf2cd9542	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x986428f9	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0xa97b5d29	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x17619e4f	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x4b1cf42d	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x7c8ae919	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xa486aee3	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xb3502455	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xd0bd3ca7	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xe64bf2de	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xe68fdb97	ircomm_flow_request
++EXPORT_SYMBOL net/irda/irda 0x0064e0ea	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x10173847	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0x16b22600	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x1e40702d	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x1e6cade0	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x3e56064f	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x4b53e020	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x5d6e498f	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0x601bda46	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0x69d1e491	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6b5fbcef	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x6e0ab3c7	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x7555cda5	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7dc655cf	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x85d88217	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x8caa9d04	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0x90fee316	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x9f6ffd37	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xa1d41e58	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0xa7493ada	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0xa82b4d56	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0xaa557515	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0xac421657	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0xaf58f59a	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0xaf645939	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xc59d5dd4	iriap_close
++EXPORT_SYMBOL net/irda/irda 0xc63ee014	irlap_open
++EXPORT_SYMBOL net/irda/irda 0xc68e43be	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0xcaa7534c	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0xcead7dbb	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xd2108314	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0xd6deeaae	irda_setup_dma
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xdea1b2c2	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xe3463529	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0xe3bde43e	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0xe4cae302	irlap_close
++EXPORT_SYMBOL net/irda/irda 0xe5d4da7f	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xf0a694a1	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0xf1c044ff	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0xf5876b95	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0xfc2b310d	iriap_open
++EXPORT_SYMBOL net/irda/irda 0xfcd3c072	irttp_disconnect_request
++EXPORT_SYMBOL net/l2tp/l2tp_core 0xefaef8b2	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0x46999b10	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x0c3105c0	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0x31e36382	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0x3c11bab2	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0x70e9223f	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0x86d378e0	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0x96ecb3a1	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0xead92c51	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0xebce56fa	lapb_disconnect_request
++EXPORT_SYMBOL net/llc/llc 0x260b104f	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x840f7e6d	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0x88a4eea7	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0xa9f447b2	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0xb5be75e5	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0xfe035e77	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0xfedb0bca	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/mac80211/mac80211 0x018016b6	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac80211/mac80211 0x036b5bd7	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0x07b79c18	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0x0bd609f2	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x0c557aae	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x14f61961	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0x18c416b7	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0x1bcb016c	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x1cb32563	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x1e18a84b	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x1fffef72	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x2423e516	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x259a5c62	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x28a98ca8	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x2b15908a	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0x2b6456d9	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x2b66ea47	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x2bc23891	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x2d8b982d	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x3513d7f7	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0x3a62906a	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0x3d420ae1	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0x3e84b17c	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0x41804e1e	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x419c0202	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x463d5273	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0x4aac2ea5	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x4c2b011a	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0x4cb501bd	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x4e2a2e6c	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x4eb28ce2	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x507981aa	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x5224a91b	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x55f97e4f	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x5fffd2b4	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x61a6db76	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x6431457e	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0x6b68955f	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x7ebf7169	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x84097313	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x84afba1c	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0x8b026360	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x8bbd8f15	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0x90b1820a	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0x94ccb86a	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x9501e8da	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0x998f1186	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x9a5ad0f7	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x9ca64ae7	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x9d08dfca	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0x9dd81b52	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0x9ef96a13	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0xa710efd1	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac80211/mac80211 0xa8f6aff3	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0xa980e1c1	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xb022773e	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xb1fec778	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xb7b433e6	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xbd7cc9d2	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xbe470dab	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xc78f35e4	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0xc8900670	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0xc8e773b1	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0xcab67aa1	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xccacd5e2	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0xcebba4c8	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xd1267f32	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0xd31c30f1	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xd6429bee	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0xd6ed5ee7	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xd750b5be	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0xdb69ac7e	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xdc0ad09c	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xe95f9541	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xeaddd787	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0xf10702ad	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xf38bbf4b	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xf3a61fb3	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0xf55c3da3	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xf9ea79ad	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0xf9f7beb2	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xfefc1e5a	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac802154/mac802154 0x22f6fb30	ieee802154_register_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x4cdeea73	ieee802154_alloc_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x57dd5679	ieee802154_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x887958ea	ieee802154_unregister_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x970ac366	ieee802154_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0xd1bcb629	ieee802154_xmit_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0xdb364a8f	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0xe5bd5846	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x20834854	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x2de7dac1	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x3491d22c	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x3642a91c	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x3e514c17	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x821028fc	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x8a69e086	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb9b6da75	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xbc4ed49c	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xc3524e12	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xcf5be5b7	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xea30d752	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xea7134f1	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xec00fe14	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x3ee43c71	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x77d3bbc1	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xce7b036c	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x0b8699c3	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0x59f49e45	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0x5cab6127	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x8ffaf1bc	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xaf8d5f1e	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/nf_nat 0xc6373894	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/x_tables 0x168cf775	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x253e8b44	xt_compat_init_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0x2df03197	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x40895a3e	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x4b171995	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x4ed5d638	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x81de574a	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0xa2552157	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0xa25fc115	xt_compat_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xabb5b5a0	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xb2af76f0	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xbdea7ecf	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/nfc/hci/hci 0x05a010f4	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x0d8ee26b	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0x142eac09	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0x2c47ee01	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0x328757db	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0x37f2b7d7	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x52c2f78d	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x5bb9264a	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0x6026805d	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x639ca17f	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0x63b96fbf	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x781b862b	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/hci/hci 0x7f93a654	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0x80ebf284	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xb782fa98	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0xbb1847d0	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xbdef4abc	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xbfb96d7b	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xd83b6589	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0xf4d942a7	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xf8617dde	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0x07f8edff	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x121070ee	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0x12455094	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x21d0dd6d	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x237b242d	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x2697e2f5	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x327d8f5a	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x3a927f3a	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0x459911ea	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x471a8d02	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nci/nci 0x5046f3c8	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x51977cbf	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0x611e81c3	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x616f1be9	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0x63f14b45	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0x6c8a1b4c	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x80258d92	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0x829fa049	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0x8b7f6a58	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x90092ef2	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0x98858bd9	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0xa9a64113	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nci/nci 0xb24d6c74	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xc80b6205	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0xd0a54941	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0xe1e5f0ed	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xea9b28f6	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xf01284a3	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nfc 0x0397fa70	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0x0e452cfa	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x144a5452	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0x14f35c39	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0x167263f9	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0x27d2823d	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0x380e7835	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0x49387775	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0x494acbf1	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0x755753c3	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0x759318b8	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x7e9b6259	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0x94b80620	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0x9db76e3f	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0xaa35e5f2	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0xab8fa381	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0xb3c69776	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0xc8025c55	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0xd993aa4e	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0xe2682ac0	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0xe2dcb425	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xf02620d5	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0xff09ccb7	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc 0xffe3eaad	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc_digital 0x006a60ce	nfc_digital_free_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x2a6acfdc	nfc_digital_allocate_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x653b084c	nfc_digital_register_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x67a118a2	nfc_digital_unregister_device
++EXPORT_SYMBOL net/phonet/phonet 0x21de5146	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0x44adae2e	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0x630fc530	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0x66901605	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0x6dc37306	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0x7857a459	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0x912afd95	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0xd902597c	pn_sock_get_port
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x027c7549	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1791420d	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x183088a5	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x18491dac	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x4831fd5c	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x567328c0	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x5f8a0ee7	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x761c262d	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x77005cc1	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x7e40cf01	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x7ea2aafe	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8a7f79bb	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xd795eb1c	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xdbf3ea51	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xec4130c7	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/sctp/sctp 0x1705fec8	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x052f34f1	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x3a12428c	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x7e894175	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x49f244b6	xdr_truncate_encode
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x643914ab	xdr_restrict_buflen
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xd7b7eafd	svc_pool_stats_open
++EXPORT_SYMBOL net/wimax/wimax 0x52b9a573	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0x8f6d3ddf	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x01877772	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x04b0c426	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x09d60be3	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x12c6d036	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x1a4b5631	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x1b2b4d7c	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x1b572400	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x1ca28db1	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x242911d3	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x2ab38400	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0x2cb4748f	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x2df6b83b	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0x2ed6aa19	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0x2fbafa91	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x30040df6	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0x31e56959	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0x32549d10	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x33e178bc	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/cfg80211 0x389461c7	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x42b59a74	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x444f44d4	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x4506a7c9	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0x460eb978	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x477c2105	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0x48a56dff	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x4b522fee	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0x4c770ef8	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0x4f4d71cf	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x4fcbb76f	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x52b71d28	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0x5d84c16b	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x60bdb6ac	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x617f20e7	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x667bd88a	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x66ce8c0f	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0x68bb3ae2	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x6e32cc2e	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x6eebd19b	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0x7a7745e6	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ce3744d	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x899dbf72	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a3b37b7	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x8e944dc0	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x91d7a142	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x9213e3be	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x94052278	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x972f6fc6	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x98e1a669	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0x9c25be58	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0x9d382aa8	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa46d6420	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xa52135bc	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0xa989d209	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xaa717168	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0xaab1f60e	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xacaf23e6	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0xafa7e2ee	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0xb807d6d8	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xbd630cd5	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0xbf21a8aa	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xc1aadfb3	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0xc1b28f20	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xc2a37d1f	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xc4b0797c	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0xc5c43128	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc68da684	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xcd5adf7c	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0xcd72f4d6	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0xd133f256	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0xd4df8999	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0xd50b0a22	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xde5ae093	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xdf1e185e	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xe4c47676	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0xe54cd2a0	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe642314d	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xee3d524b	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xeebb903e	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xefd7feaa	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xefd93830	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xf079175c	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0xf2b8e8fd	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0xf5635ee1	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0xfc12e5f5	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/lib80211 0x06ff5cf1	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0x266da702	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x94b606a4	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0xbcf969ee	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xdc81c6e0	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xf3ebe9fb	lib80211_crypt_info_free
++EXPORT_SYMBOL sound/ac97_bus 0x421c8d96	ac97_bus_type
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0x16d7e462	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1b9e7804	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x2b98dbf4	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x2e38a5cb	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xec45c04b	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x20934555	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x072d978b	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x13a17752	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x2eed26bf	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x4d5ca523	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x592f6e9b	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xd7c7afcc	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xe60fb228	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xecbde43c	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0xe0c4bf79	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x0a4d95f5	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0x17830a81	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0x18e1683f	snd_dma_program
++EXPORT_SYMBOL sound/core/snd 0x191e88cf	snd_dma_pointer
++EXPORT_SYMBOL sound/core/snd 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL sound/core/snd 0x1f6b35e1	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0x20576d4f	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x27f343c0	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0x2bf1284b	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0x2bfebc38	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0x342a2354	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x34648a2e	snd_ctl_register_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x3aa4ab5a	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0x3afb04d3	snd_device_new
++EXPORT_SYMBOL sound/core/snd 0x40905d34	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0x49b884cd	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x507b7fd4	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0x53a41274	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0x5d265a25	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0x62a75a4c	snd_ctl_unregister_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0x642c0672	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0x70c15ac1	snd_dma_disable
++EXPORT_SYMBOL sound/core/snd 0x7141b8f6	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0x74771025	snd_register_device
++EXPORT_SYMBOL sound/core/snd 0x7710c645	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0x78187cdb	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0x79009977	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd 0x7fc7a6b7	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0x813f62ad	snd_cards
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x83957d50	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0x8d0c3433	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x934f7526	snd_card_new
++EXPORT_SYMBOL sound/core/snd 0x98e55c2a	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0x9a041dec	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd 0x9e6401cc	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xa62620ba	snd_jack_new
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xb642b3bf	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0xbb11349c	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0xbbcdf1a0	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL sound/core/snd 0xc59c6bb8	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0xc892cbe4	snd_jack_add_new_kctl
++EXPORT_SYMBOL sound/core/snd 0xc8cf5448	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0xcc81781c	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0xd2244613	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0xd8fd5929	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0xdc33db9b	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0xe017c7f4	snd_unregister_oss_device
++EXPORT_SYMBOL sound/core/snd 0xe86bea4f	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0xea5e922b	snd_register_oss_device
++EXPORT_SYMBOL sound/core/snd 0xed0e2208	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0xf1a68d2f	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0xf68cf137	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0xfe2a70e9	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0xfffd89db	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd-hwdep 0xb0964784	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x06b310c9	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x095e12e5	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0x0fca199d	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x17b07cef	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0x185c15e4	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0x1b81db6e	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x1e05d53d	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x213c9897	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0x23fd26cb	snd_pcm_lib_mmap_iomem
++EXPORT_SYMBOL sound/core/snd-pcm 0x269ea461	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x2c346e51	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0x2e6d5e98	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0x2f573c96	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0x3210ad9e	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x3b5dcda7	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x3e8ad4c8	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL sound/core/snd-pcm 0x464c1a5f	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x4844356b	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0x4dd8830e	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x5898dcba	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x59135863	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x5c7fd313	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x5fec88a6	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0x620b0891	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x6b75a68a	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x7942f8a6	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0x7ae516da	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x834dc955	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x867cdbc1	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x8a5ce154	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x8fc8c49f	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x96383b66	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-pcm 0x97460c5d	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0x98a03635	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xa92e59f9	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xab58f11a	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xb6ae1735	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xba9dbc24	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0xc0eaa6f6	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-pcm 0xcb55132f	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0xcbb7723f	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0xd085a29c	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0xd0b88602	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0xdacc004e	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xe8454fe8	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0xe98fe141	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0xeaa2dc39	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0xf153a26b	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0xf7aec242	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-pcm 0xfec6f2a9	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x07332ea9	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x1989155d	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x1c2163dd	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x2ec59fac	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x5da4ba02	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x5db9dccd	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7025516d	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x72e0082d	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x94f49c23	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x96bf0dea	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xa8cf5e4a	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xbcee4083	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xc27886c0	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xcc6f7751	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xcddb60ef	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xf00c2fd8	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xf4ca5e59	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xf7cd9f26	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xfae05c18	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-timer 0x03a90050	snd_timer_start
++EXPORT_SYMBOL sound/core/snd-timer 0x047cd651	snd_timer_close
++EXPORT_SYMBOL sound/core/snd-timer 0x08766536	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0x3d6a935c	snd_timer_interrupt
++EXPORT_SYMBOL sound/core/snd-timer 0x4601e481	snd_timer_global_register
++EXPORT_SYMBOL sound/core/snd-timer 0x552fdb1d	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0x5b3f8104	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0x77cdf4e9	snd_timer_resolution
++EXPORT_SYMBOL sound/core/snd-timer 0x8920b4d7	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0x8cc66332	snd_timer_stop
++EXPORT_SYMBOL sound/core/snd-timer 0xcc5ceb33	snd_timer_open
++EXPORT_SYMBOL sound/core/snd-timer 0xd65d3a74	snd_timer_pause
++EXPORT_SYMBOL sound/core/snd-timer 0xf0e8b662	snd_timer_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x15096a83	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x00b0056c	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x41dc0268	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x50d3a06e	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x824beaff	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x8de92272	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x94c16441	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xa83528ac	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xd00ae471	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xe2563237	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x36e3b002	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x39875910	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x3e648b59	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x5f8e4a8e	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xa7111911	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xad461146	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xc2b96094	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xe065d5a1	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xec360223	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x0bb46f5f	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x16d5e4ed	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1d7a635e	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x29b57d8c	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x36830815	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3cdb32f4	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3efe8f7a	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x409ee110	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4a2cacff	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x522f5166	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5ad7a689	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5b5a7eb4	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x67f5c6a2	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x6fb4144f	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x774e39fe	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8443466a	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x85123543	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x891a1705	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8eb994b5	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x92c5364e	amdtp_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x990cf149	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9a089423	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xad2a1496	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xb57959fd	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xbbb00808	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xdb1e9696	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe0a81b75	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xebab4af6	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xef2094d9	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xef9b319d	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf0dd6f46	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf80427ed	fcp_avc_transaction
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x7bfccfc8	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x7fa43187	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x082299da	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x83a1c703	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xc1bf3a74	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xc3887ef6	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xd83a4305	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xd9bc034b	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xdad3869e	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xf20f6c53	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x36b46489	snd_ak4117_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x371dc580	snd_ak4117_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x465c7fa3	snd_ak4117_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xc744394c	snd_ak4117_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xd5ad42e0	snd_ak4117_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xda3539e3	snd_ak4117_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x174511fe	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x2650155e	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x74823834	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xedc534d2	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x0a5dc384	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x0e832127	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x0efd80bc	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x6dfc4e28	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x9347b2f4	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x9faf1d35	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xd611967a	snd_cs8427_init
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xfc9a90a0	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x01a0828d	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x2afc4747	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x4ebce651	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x59d98dde	snd_i2c_device_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x94eafa25	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x9783f327	snd_i2c_bus_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x02523ea4	snd_sbmixer_read
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x14541698	snd_sbdsp_command
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x1aeb8503	snd_sbmixer_resume
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x2aa6ac75	snd_sbdsp_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x32fd1b4c	snd_sbdsp_get_byte
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x6f2ecafc	snd_sbmixer_add_ctl
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x7909c70d	snd_sbdsp_reset
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x7af6707e	snd_sbmixer_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x9078893e	snd_sbmixer_suspend
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xa78f8fc1	snd_sbmixer_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x0ad46823	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x0bdb1018	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x145bcd8c	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x15919eb4	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x1978a4aa	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x1d4b05fd	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x1f0e3414	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x380eef58	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3e755120	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3f718705	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x647c7669	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x790d2b03	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xcd156f2e	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xd65849a0	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xe84f9769	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xeaf731d4	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xfb9c768a	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x17b4fbfb	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x2d56df18	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x385de5bf	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x5f5090a3	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x6cd495e9	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x70da3e21	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xa0ee5fe6	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xb0f5822f	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xb51c5d9a	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x7efd0439	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x92f81d83	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xc49278c4	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x2a4eabba	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x31a12014	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x46c7384f	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x53ef83b0	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x64ebf02b	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x72a5e1d0	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x753beec3	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x7d6d2f43	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x808acc1a	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x891399de	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x8d0d1940	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x8d86488c	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x99c5973f	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa3ac3051	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa57079c4	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb0aa60e0	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb316ca58	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb9cf836f	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc2c0d19f	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xe82b8529	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xfa707567	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x5f31fb4f	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x5f993de3	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x66130509	snd_trident_free_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xb64f8183	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xc924b510	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0xb240a806	tlv320aic23_probe
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0xba335405	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/snd-soc-core 0x89af5e68	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL sound/soundcore 0x161de080	register_sound_midi
++EXPORT_SYMBOL sound/soundcore 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x8b0119ac	register_sound_special_device
++EXPORT_SYMBOL sound/soundcore 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL sound/soundcore 0xaf4d04e8	register_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xc485e2ea	register_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xd523f4ab	sound_class
++EXPORT_SYMBOL sound/soundcore 0xe9ba20c2	register_sound_special
++EXPORT_SYMBOL sound/soundcore 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x3cc6a6a1	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x651641dd	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x91a9ad33	snd_emux_register
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x96815485	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xf1cebbef	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xf70ffaa2	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x1e232747	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x1e4b7310	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x40979e1a	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x4cd52ee5	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x6bcdd297	snd_util_memhdr_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xa67679a8	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xac912ce5	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xc9845c80	__snd_util_mem_free
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x766deb26	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL vmlinux 0x00193966	icmpv6_send
++EXPORT_SYMBOL vmlinux 0x0021e93a	macio_dev_put
++EXPORT_SYMBOL vmlinux 0x0028c568	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0x0032e54f	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0x005a4975	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0x005d9f56	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x00681a4a	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0x0070cd1f	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x00741c68	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0x007bbd51	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x0085e1f1	__do_once_done
++EXPORT_SYMBOL vmlinux 0x00862961	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0x009339f0	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0x009fa8fe	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0x00b81566	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x010b633c	free_netdev
++EXPORT_SYMBOL vmlinux 0x011cf88e	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0x0122f95e	_lv1_get_spe_irq_outlet
++EXPORT_SYMBOL vmlinux 0x012a97fc	xor_altivec_4
++EXPORT_SYMBOL vmlinux 0x0146970a	neigh_destroy
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x017b3f5b	ns_capable
++EXPORT_SYMBOL vmlinux 0x01853a59	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x018d9919	_lv1_set_lpm_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x018fa76b	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0x01946e53	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x01b26301	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x01e68f0f	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0x01ee6985	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0x01ee970c	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0x020d18d7	_lv1_set_lpm_debug_bus_control
++EXPORT_SYMBOL vmlinux 0x023a074a	hvc_get_chars
++EXPORT_SYMBOL vmlinux 0x024bf827	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x027d5499	_lv1_did_update_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02af53e1	of_parse_phandle_with_fixed_args
++EXPORT_SYMBOL vmlinux 0x02b5b04e	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x02c17b53	flow_cache_init
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x0317cad6	vfs_read
++EXPORT_SYMBOL vmlinux 0x031dc65e	pasemi_dma_free_chan
++EXPORT_SYMBOL vmlinux 0x032ff383	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x033a8e1f	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x034d0261	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x0356fbd9	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x036d0eb3	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x036f926a	pci_get_class
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x037fccd8	vfs_writev
++EXPORT_SYMBOL vmlinux 0x0383bf43	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0x039ac6d1	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0x03f930a2	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x03f9822f	scsi_unregister
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x040465a3	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0x04074f48	ioremap
++EXPORT_SYMBOL vmlinux 0x0419e83b	inet_del_offload
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x0424aabc	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x0440a533	_lv1_net_remove_multicast_address
++EXPORT_SYMBOL vmlinux 0x04479557	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x04726750	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0x0482d49b	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x049980f6	d_alloc
++EXPORT_SYMBOL vmlinux 0x04c66902	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0x04c70be3	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0x04d5ebb2	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04ea5d10	ksize
++EXPORT_SYMBOL vmlinux 0x050f2450	phy_find_first
++EXPORT_SYMBOL vmlinux 0x05186ca4	flush_icache_range
++EXPORT_SYMBOL vmlinux 0x051b44a7	skb_unlink
++EXPORT_SYMBOL vmlinux 0x051eacb1	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x0530dede	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x053b2379	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0x0540b32a	cpu_core_map
++EXPORT_SYMBOL vmlinux 0x055b57e7	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0x055c8559	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x05856895	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0x058735a9	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x059c4126	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0x059d2cd1	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x05a3a67a	lock_fb_info
++EXPORT_SYMBOL vmlinux 0x05a514a1	_insl_ns
++EXPORT_SYMBOL vmlinux 0x05b1d058	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0x05d8c921	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0x05ec9483	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0x05f6ffa7	netlink_capable
++EXPORT_SYMBOL vmlinux 0x06107663	inc_nlink
++EXPORT_SYMBOL vmlinux 0x0612ba8a	of_get_pci_address
++EXPORT_SYMBOL vmlinux 0x0612e6fc	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x06456aff	_lv1_get_virtual_address_space_id_of_ppe
++EXPORT_SYMBOL vmlinux 0x06634580	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0x0674346a	of_graph_get_endpoint_by_regs
++EXPORT_SYMBOL vmlinux 0x067ac8a6	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x068d031a	input_set_keycode
++EXPORT_SYMBOL vmlinux 0x06b414ce	tty_port_close
++EXPORT_SYMBOL vmlinux 0x06c8bb80	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0x06e97e6b	__scm_destroy
++EXPORT_SYMBOL vmlinux 0x06f51f2a	copy_to_iter
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x0727c4f3	iowrite8
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x0736fde5	update_region
++EXPORT_SYMBOL vmlinux 0x074e9213	down_killable
++EXPORT_SYMBOL vmlinux 0x0765d0ee	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07a9ef84	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07d964c4	seq_puts
++EXPORT_SYMBOL vmlinux 0x07e9d5db	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0x07ef213a	pasemi_dma_free_fun
++EXPORT_SYMBOL vmlinux 0x07f652e3	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x07f8ee15	_lv1_unmap_device_dma_region
++EXPORT_SYMBOL vmlinux 0x0803b6cc	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x084e38e5	bio_init
++EXPORT_SYMBOL vmlinux 0x086dfee8	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0x087abdb2	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x087d949c	netdev_update_features
++EXPORT_SYMBOL vmlinux 0x08a77d76	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0x08b4223a	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x08c9c84a	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x0908c2f2	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x09257b5e	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0x0935e87b	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0x0936a849	of_device_is_big_endian
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x096341c2	_lv1_connect_irq_plug_ext
++EXPORT_SYMBOL vmlinux 0x09676499	vio_register_device_node
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c67afb	flex_array_get
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09d05b6c	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09df082d	of_phy_find_device
++EXPORT_SYMBOL vmlinux 0x0a11b542	blk_rq_init
++EXPORT_SYMBOL vmlinux 0x0a1ab2ac	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a3d0644	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0x0a4b8e94	set_device_ro
++EXPORT_SYMBOL vmlinux 0x0a57863e	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x0a770832	register_memory_notifier
++EXPORT_SYMBOL vmlinux 0x0a82bfb9	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x0a894d21	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0x0a9c1674	backlight_force_update
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0ab09858	sk_net_capable
++EXPORT_SYMBOL vmlinux 0x0ab2b8e3	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0x0ac5f314	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0ad1d7b7	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b1fa87e	of_graph_get_remote_port
++EXPORT_SYMBOL vmlinux 0x0b2b5f90	mpage_readpages
++EXPORT_SYMBOL vmlinux 0x0b2e1ec7	h_get_mpp
++EXPORT_SYMBOL vmlinux 0x0b36c2aa	param_get_long
++EXPORT_SYMBOL vmlinux 0x0b3dda3d	dma_iommu_ops
++EXPORT_SYMBOL vmlinux 0x0b5d8670	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b66eb0d	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b7cb9f2	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0x0b9f9a85	inet_frags_init
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0c1ad162	_lv1_net_start_rx_dma
++EXPORT_SYMBOL vmlinux 0x0c21d019	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c563206	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c6bdc3f	vme_master_read
++EXPORT_SYMBOL vmlinux 0x0c6ef18d	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0x0c6fde6f	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0x0c7ef70d	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0x0c7ff61e	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x0c80b209	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0x0c8ba8c0	tty_check_change
++EXPORT_SYMBOL vmlinux 0x0c926dcd	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x0c984b31	__block_write_begin
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0cab63f1	have_submounts
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cbbda9b	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0x0ce9d9d2	dev_open
++EXPORT_SYMBOL vmlinux 0x0d144d90	revalidate_disk
++EXPORT_SYMBOL vmlinux 0x0d457011	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0x0d4640c3	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x0d49eb79	pci_iounmap
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d57570b	vga_get
++EXPORT_SYMBOL vmlinux 0x0d582453	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d6a88be	d_instantiate
++EXPORT_SYMBOL vmlinux 0x0d6c963c	copy_from_user
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0da42e66	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0x0db34537	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0x0dc0ace0	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x0dcc4361	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x0dd6edea	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0x0de95a4b	scsi_init_io
++EXPORT_SYMBOL vmlinux 0x0e091c83	agp_alloc_bridge
++EXPORT_SYMBOL vmlinux 0x0e58fa48	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e6e61b9	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x0e777f8d	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0x0e8de4c7	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x0e8f30f6	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x0ebaabf5	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0ed02a1b	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x0ed0caab	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0x0edca097	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x0eefba5f	tty_throttle
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0efe49c3	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0x0f220def	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x0f23b2c3	netif_napi_add
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f5e5e81	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x0f5faa7e	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f7ee609	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0x0f88eb24	genphy_config_init
++EXPORT_SYMBOL vmlinux 0x0f9335c6	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0x0fa879c0	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fbfb09b	mmc_free_host
++EXPORT_SYMBOL vmlinux 0x0fca9268	ppp_input
++EXPORT_SYMBOL vmlinux 0x0febd937	dump_page
++EXPORT_SYMBOL vmlinux 0x0ff5b3be	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0x101dbfcb	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x103bd775	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x1043f4a2	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0x106e01df	of_device_unregister
++EXPORT_SYMBOL vmlinux 0x107021ac	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x1073262c	__breadahead
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x109009cd	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0x10950ee1	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x10b011b7	fget_raw
++EXPORT_SYMBOL vmlinux 0x10b1172a	serio_rescan
++EXPORT_SYMBOL vmlinux 0x10c0d9a1	up_write
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x110a12b5	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0x110df7c7	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x11136114	commit_creds
++EXPORT_SYMBOL vmlinux 0x111b0675	agp_generic_mask_memory
++EXPORT_SYMBOL vmlinux 0x1133cdf2	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0x115a28a6	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x116e577a	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x1171b635	_lv1_delete_lpm_event_bookmark
++EXPORT_SYMBOL vmlinux 0x117458d3	srp_rport_put
++EXPORT_SYMBOL vmlinux 0x1182d83a	cpuidle_disable
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11d4df28	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0x11db7c38	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0x11e7ce9a	of_mdio_find_bus
++EXPORT_SYMBOL vmlinux 0x11e8dbd5	scsi_device_get
++EXPORT_SYMBOL vmlinux 0x11f04bad	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x12072cac	get_empty_filp
++EXPORT_SYMBOL vmlinux 0x1208ac78	input_free_device
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120d67d4	unregister_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x12253cc3	down_write_trylock
++EXPORT_SYMBOL vmlinux 0x122be267	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0x1234b966	security_path_mknod
++EXPORT_SYMBOL vmlinux 0x123983ca	kernel_bind
++EXPORT_SYMBOL vmlinux 0x123f82f3	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x12452803	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0x126f1c9b	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x1270ec47	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x127a0133	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0x127c2330	__vfs_read
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12a52f52	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0x12b9fe0e	generic_setxattr
++EXPORT_SYMBOL vmlinux 0x12c50f30	free_user_ns
++EXPORT_SYMBOL vmlinux 0x12cb6622	_lv1_map_device_dma_region
++EXPORT_SYMBOL vmlinux 0x12d3db99	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x12dfeb12	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x12e5ef0c	rtas_set_power_level
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x13215eac	mem_section
++EXPORT_SYMBOL vmlinux 0x1321e9c3	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x13316316	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x13467685	tty_write_room
++EXPORT_SYMBOL vmlinux 0x13590d21	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0x135e1328	nd_device_unregister
++EXPORT_SYMBOL vmlinux 0x1364ab6e	blk_finish_request
++EXPORT_SYMBOL vmlinux 0x138b1db2	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0x139448c0	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0x1397de36	kobject_del
++EXPORT_SYMBOL vmlinux 0x13a6145a	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x13ad07cb	d_obtain_root
++EXPORT_SYMBOL vmlinux 0x13ba6f87	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x13c6cbbc	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13dac636	vfs_readv
++EXPORT_SYMBOL vmlinux 0x13e16a8d	sk_alloc
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x13f53da6	CMO_PageSize
++EXPORT_SYMBOL vmlinux 0x141fe5fd	pasemi_read_iob_reg
++EXPORT_SYMBOL vmlinux 0x142c15c0	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0x14347e3e	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0x1439321c	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0x143d97b2	generic_perform_write
++EXPORT_SYMBOL vmlinux 0x1440834d	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x144c99ad	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x1451af19	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x1455ba7a	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0x146de191	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0x14a14817	pSeries_enable_reloc_on_exc
++EXPORT_SYMBOL vmlinux 0x14bd15b0	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x14d35113	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0x14f72b29	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0x150ca87e	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x150faee4	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x1515634c	scsi_print_result
++EXPORT_SYMBOL vmlinux 0x151592c4	_lv1_invalidate_htab_entries
++EXPORT_SYMBOL vmlinux 0x152c0907	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x1563424c	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0x157e066a	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x15a5f07e	start_tty
++EXPORT_SYMBOL vmlinux 0x15a68d6b	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15c15c35	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x15c302e1	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0x15d06690	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0x15d3fd60	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x15e95c11	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0x15f08201	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0x16064e46	agp_unbind_memory
++EXPORT_SYMBOL vmlinux 0x160bd45c	rtas_token
++EXPORT_SYMBOL vmlinux 0x1616533a	kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x161e57c1	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x1621f2ab	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0x162ecdf1	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0x165e2a6b	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0x167c5967	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x1688a5bb	vme_slave_request
++EXPORT_SYMBOL vmlinux 0x16978f23	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0x169fe180	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x16f9b092	is_nd_btt
++EXPORT_SYMBOL vmlinux 0x16fbda26	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0x16fc1cd1	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0x1700a15f	inet_ioctl
++EXPORT_SYMBOL vmlinux 0x17266eb6	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0x173452dd	macio_release_resources
++EXPORT_SYMBOL vmlinux 0x1735786d	audit_log
++EXPORT_SYMBOL vmlinux 0x1738442b	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0x1743414f	__debugger_fault_handler
++EXPORT_SYMBOL vmlinux 0x174d4209	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0x17648396	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x176fbb03	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0x177f777d	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0x178a4bc1	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0x17910b3a	flush_dcache_icache_page
++EXPORT_SYMBOL vmlinux 0x179196aa	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0x1793f685	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17b195c9	proc_set_user
++EXPORT_SYMBOL vmlinux 0x17b54ade	key_validate
++EXPORT_SYMBOL vmlinux 0x17c6b41b	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0x17cb8c79	_lv1_read_htab_entries
++EXPORT_SYMBOL vmlinux 0x17d19dc1	wireless_send_event
++EXPORT_SYMBOL vmlinux 0x17e28473	fsl_upm_run_pattern
++EXPORT_SYMBOL vmlinux 0x17e3079c	tcp_close
++EXPORT_SYMBOL vmlinux 0x17f341a0	i8042_lock_chip
++EXPORT_SYMBOL vmlinux 0x17f78676	devm_free_irq
++EXPORT_SYMBOL vmlinux 0x17fca7f0	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x1813d7d5	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x1817fd0c	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0x18254cc9	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x182f50af	_lv1_open_device
++EXPORT_SYMBOL vmlinux 0x1839386c	import_iovec
++EXPORT_SYMBOL vmlinux 0x183d62ca	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x184a588b	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x1857aa39	proc_dointvec
++EXPORT_SYMBOL vmlinux 0x18660552	__kernel_write
++EXPORT_SYMBOL vmlinux 0x186d957c	generic_make_request
++EXPORT_SYMBOL vmlinux 0x1879c14f	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x189765bb	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x18a5cc5c	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0x18be67e1	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0x18c41a61	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0x18c98205	_lv1_destruct_virtual_address_space
++EXPORT_SYMBOL vmlinux 0x18d2761c	simple_dname
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x19109872	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x19424c08	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x19569624	pnv_cxl_release_hwirqs
++EXPORT_SYMBOL vmlinux 0x195795d3	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0x19666e09	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0x196f56ae	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0x199ec4fb	arch_spin_unlock_wait
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19a34125	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19ba1dc7	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19c7198f	nvm_register_target
++EXPORT_SYMBOL vmlinux 0x19c968d1	pasemi_dma_start_chan
++EXPORT_SYMBOL vmlinux 0x19d3d08a	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0x19e64a24	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0x19f62505	sock_create
++EXPORT_SYMBOL vmlinux 0x1a01ccf8	vio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x1a185983	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0x1a3d4ca3	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x1a5246de	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0x1a559a7b	up_read
++EXPORT_SYMBOL vmlinux 0x1a5b1dce	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0x1a709d48	km_policy_expired
++EXPORT_SYMBOL vmlinux 0x1a8019f1	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0x1a81835d	phys_mem_access_prot
++EXPORT_SYMBOL vmlinux 0x1a91663d	pasemi_dma_free_buf
++EXPORT_SYMBOL vmlinux 0x1aad9b53	fb_find_mode
++EXPORT_SYMBOL vmlinux 0x1ac5d3cb	strcspn
++EXPORT_SYMBOL vmlinux 0x1ace8e47	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0x1ad65a5d	vc_cons
++EXPORT_SYMBOL vmlinux 0x1ad6e97b	read_cache_pages
++EXPORT_SYMBOL vmlinux 0x1af46cff	agp_generic_free_by_type
++EXPORT_SYMBOL vmlinux 0x1af62a99	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0x1afbcd49	note_scsi_host
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b07a42e	init_special_inode
++EXPORT_SYMBOL vmlinux 0x1b07c781	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0x1b132009	rename_lock
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b485afb	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x1b625d33	enable_kernel_vsx
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b7b6131	del_gendisk
++EXPORT_SYMBOL vmlinux 0x1b80622c	compat_ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b8b95ad	i8042_unlock_chip
++EXPORT_SYMBOL vmlinux 0x1b8e140c	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bb7cff1	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x1bb9d994	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0x1bbc486c	register_console
++EXPORT_SYMBOL vmlinux 0x1bc4ff03	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0x1bf7a2a9	release_pages
++EXPORT_SYMBOL vmlinux 0x1bfec830	__iounmap_at
++EXPORT_SYMBOL vmlinux 0x1c200a7d	pasemi_dma_stop_chan
++EXPORT_SYMBOL vmlinux 0x1c2de9bb	sync_blockdev
++EXPORT_SYMBOL vmlinux 0x1c38c334	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x1c3c3988	of_mm_gpiochip_add
++EXPORT_SYMBOL vmlinux 0x1c3e02e4	memcmp
++EXPORT_SYMBOL vmlinux 0x1c481569	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x1c4dab93	_lv1_connect_irq_plug
++EXPORT_SYMBOL vmlinux 0x1c5191c1	vme_master_request
++EXPORT_SYMBOL vmlinux 0x1c5b2c15	pmu_wait_complete
++EXPORT_SYMBOL vmlinux 0x1c80de9c	ip_send_check
++EXPORT_SYMBOL vmlinux 0x1cad2910	from_kuid
++EXPORT_SYMBOL vmlinux 0x1cbbe3ab	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x1cc9b90d	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0x1cccbadc	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0x1cdff921	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0x1ce5fb57	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0x1cf90471	param_set_uint
++EXPORT_SYMBOL vmlinux 0x1d082b95	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0x1d1056e5	crc32_be
++EXPORT_SYMBOL vmlinux 0x1d251ddb	of_mm_gpiochip_remove
++EXPORT_SYMBOL vmlinux 0x1d2f6e22	thaw_super
++EXPORT_SYMBOL vmlinux 0x1d44b063	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x1d4750bc	_lv1_stop_lpm
++EXPORT_SYMBOL vmlinux 0x1d4cc345	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0x1d5682c1	agp_generic_create_gatt_table
++EXPORT_SYMBOL vmlinux 0x1d665502	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x1d6db79e	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x1d88142d	bio_put
++EXPORT_SYMBOL vmlinux 0x1daee28a	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x1db6bffb	bio_flush_dcache_pages
++EXPORT_SYMBOL vmlinux 0x1dbc4d0c	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1ddd0fbd	put_page
++EXPORT_SYMBOL vmlinux 0x1e0dadb6	dns_query
++EXPORT_SYMBOL vmlinux 0x1e153940	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0x1e1885d0	pci_set_master
++EXPORT_SYMBOL vmlinux 0x1e221c65	blk_queue_split
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e495b80	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0x1e4bf9b5	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0x1e637e5b	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e77ec81	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ec310c3	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0x1ec34a98	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0x1ed9271b	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x1ee78c06	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x1f1bbed7	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x1f38fabc	cad_pid
++EXPORT_SYMBOL vmlinux 0x1f422b83	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0x1f467b54	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0x1f4ad787	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x1f6ce67a	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x1f869035	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fbdfe5f	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fe7b4ab	pasemi_write_dma_reg
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x1fefb4a8	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x201494ee	_lv1_net_set_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x202d481e	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0x2031938a	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x204c09d3	get_pci_dma_ops
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x20606c65	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x206b1ec6	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x2089a18a	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x2089b584	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0x208cc033	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0x20a5e6ff	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20b7b871	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x20e45a27	alloc_file
++EXPORT_SYMBOL vmlinux 0x20eb9164	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20ef81e5	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x210c54b8	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x211f68f1	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x2127faa1	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0x213603bf	pasemi_dma_free_ring
++EXPORT_SYMBOL vmlinux 0x218506d8	register_key_type
++EXPORT_SYMBOL vmlinux 0x21871f4f	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x219bb555	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0x21a8fc69	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x21a94d70	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x21b42985	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0x21c2545a	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x21c88264	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x21d1fd35	d_drop
++EXPORT_SYMBOL vmlinux 0x21da5832	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x21dbafa3	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21f19335	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0x220b774b	vio_find_node
++EXPORT_SYMBOL vmlinux 0x221bddb7	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x221ce802	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0x222aa5ea	netdev_change_features
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x223823a7	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0x225aec89	follow_down_one
++EXPORT_SYMBOL vmlinux 0x225ebee6	_lv1_destruct_lpm
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x2278e94b	slhc_remember
++EXPORT_SYMBOL vmlinux 0x229f35ba	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0x22ab2a2b	tty_mutex
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22b5cb8d	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x22c6bcc8	bmap
++EXPORT_SYMBOL vmlinux 0x22e05caa	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x22e16257	build_skb
++EXPORT_SYMBOL vmlinux 0x22f30224	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x22f4ad3e	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x22fbfd2a	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0x23037777	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0x2304457f	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0x2304faf6	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0x231270f9	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x2327b905	bio_endio
++EXPORT_SYMBOL vmlinux 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL vmlinux 0x233cbb47	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x235160db	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0x235e90f3	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x238ffb70	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23ad3307	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0x23b9140e	iget5_locked
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23c176b0	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0x23c457fc	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0x23c9891c	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x23f2243d	mempool_free
++EXPORT_SYMBOL vmlinux 0x23f5d2cb	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x23f7c667	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x24071f33	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x24222a1f	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x246f2ee8	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x2472dfd4	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x2484adc3	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0x24855cba	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x2493bcf6	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x24b93602	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x24c6bb07	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0x24cb4131	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0x24cfd438	_lv1_copy_lpm_trace_buffer
++EXPORT_SYMBOL vmlinux 0x24d6b4a6	cur_cpu_spec
++EXPORT_SYMBOL vmlinux 0x24e444e0	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0x24e4efa6	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x24f00380	ida_init
++EXPORT_SYMBOL vmlinux 0x24f4c80a	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x24f9da94	pmac_suspend_agp_for_card
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x24ff5637	pnv_cxl_ioda_msi_setup
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x253b3a65	__devm_release_region
++EXPORT_SYMBOL vmlinux 0x25548f6e	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x25590014	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x2579a709	sock_release
++EXPORT_SYMBOL vmlinux 0x257ee8c6	mmc_of_parse_voltage
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x258f24d2	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x258f6a93	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0x258fb3b7	path_nosuid
++EXPORT_SYMBOL vmlinux 0x25964e5c	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0x25b6b8f7	_lv1_set_spe_transition_notifier
++EXPORT_SYMBOL vmlinux 0x25d07112	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0x25e8ed29	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x25e94360	inet_put_port
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x25f1a6da	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0x25f3fcca	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x2616dcbc	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0x2623ad6c	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x26477c07	__vmalloc
++EXPORT_SYMBOL vmlinux 0x2649753b	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x2665a2f8	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x2665d53a	key_create_or_update
++EXPORT_SYMBOL vmlinux 0x268738cb	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0x26a0a8ea	dma_set_mask
++EXPORT_SYMBOL vmlinux 0x26b760c4	slhc_init
++EXPORT_SYMBOL vmlinux 0x26b9f854	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x26e298e0	unregister_memory_notifier
++EXPORT_SYMBOL vmlinux 0x26e55685	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26f30488	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x26ff2330	phy_device_register
++EXPORT_SYMBOL vmlinux 0x271c104f	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0x2724fe26	param_set_ushort
++EXPORT_SYMBOL vmlinux 0x2736b6ab	__nd_iostat_start
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x2761b325	vfs_rename
++EXPORT_SYMBOL vmlinux 0x27646df3	start_thread
++EXPORT_SYMBOL vmlinux 0x2769a446	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0x2771d7ff	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x277a5a94	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x27ec5956	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0x27ed0c08	cont_write_begin
++EXPORT_SYMBOL vmlinux 0x27f9c578	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x2819d695	bio_advance
++EXPORT_SYMBOL vmlinux 0x282051ba	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0x282325ed	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0x28318305	snprintf
++EXPORT_SYMBOL vmlinux 0x283b1f24	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0x283c5397	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x28403b52	seq_read
++EXPORT_SYMBOL vmlinux 0x28573a1e	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0x2877d1c4	end_page_writeback
++EXPORT_SYMBOL vmlinux 0x289db3ee	idr_remove
++EXPORT_SYMBOL vmlinux 0x28a2b29f	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28a5a950	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x28a7beba	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x28a9a45d	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0x28abfe6e	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x28b977ba	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0x28ccbd20	agp_generic_destroy_page
++EXPORT_SYMBOL vmlinux 0x28e6ce45	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x291bd884	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0x2940dc4d	kill_pid
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x295a3edf	__alloc_skb
++EXPORT_SYMBOL vmlinux 0x295cd787	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0x296436ea	bio_reset
++EXPORT_SYMBOL vmlinux 0x2987fe8f	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0x29a3bd48	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x29b2279e	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x29c7451d	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a33df19	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a3ff6d7	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0x2a4403c3	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0x2a4b9ab6	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x2a6c35d7	neigh_xmit
++EXPORT_SYMBOL vmlinux 0x2a8b8d6c	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0x2a8d4a07	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x2a9de080	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x2aa92849	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2aae8b45	vm_map_ram
++EXPORT_SYMBOL vmlinux 0x2ab6083d	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0x2abee966	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x2ac0aa01	seq_release_private
++EXPORT_SYMBOL vmlinux 0x2ac17752	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0x2ac17be1	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2ad892e0	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0x2aff39e7	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b3a1f20	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0x2b3b7d7b	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0x2b3e213f	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0x2b4991ec	xmon
++EXPORT_SYMBOL vmlinux 0x2b4daaa1	igrab
++EXPORT_SYMBOL vmlinux 0x2b6f88a0	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0x2b8a640e	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2b9f5ba2	vme_dma_request
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2bb9cc15	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0x2bbf1e23	kobject_get
++EXPORT_SYMBOL vmlinux 0x2bc42ae1	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0x2be261eb	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x2be87887	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x2c075933	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x2c0cbe64	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x2c12075d	ihold
++EXPORT_SYMBOL vmlinux 0x2c1cd4a4	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c464205	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x2c4b74c3	page_readlink
++EXPORT_SYMBOL vmlinux 0x2c4c7997	_lv1_construct_lpm
++EXPORT_SYMBOL vmlinux 0x2c511745	write_cache_pages
++EXPORT_SYMBOL vmlinux 0x2c59ece7	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x2c7b1fca	down_timeout
++EXPORT_SYMBOL vmlinux 0x2c7b53fe	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0x2c87760f	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x2c8bb116	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x2c994069	filemap_fault
++EXPORT_SYMBOL vmlinux 0x2cb1fc79	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0x2cd06208	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0x2cd290ac	write_inode_now
++EXPORT_SYMBOL vmlinux 0x2ce486a3	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0x2cf73cb7	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x2d008263	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0x2d036285	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0x2d0d836b	register_quota_format
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d1de2b7	tty_hangup
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d3c1d02	dm_register_target
++EXPORT_SYMBOL vmlinux 0x2d3e40df	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0x2d5336aa	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0x2d5ca179	dev_activate
++EXPORT_SYMBOL vmlinux 0x2d763c38	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0x2d7d2767	_lv1_set_lpm_group_control
++EXPORT_SYMBOL vmlinux 0x2dacce67	d_invalidate
++EXPORT_SYMBOL vmlinux 0x2db1e0c6	dql_init
++EXPORT_SYMBOL vmlinux 0x2de3240d	get_io_context
++EXPORT_SYMBOL vmlinux 0x2de95fbd	__f_setown
++EXPORT_SYMBOL vmlinux 0x2e0d2f7f	queue_work_on
++EXPORT_SYMBOL vmlinux 0x2e0eeb46	skb_pull
++EXPORT_SYMBOL vmlinux 0x2e12a93b	ibmebus_request_irq
++EXPORT_SYMBOL vmlinux 0x2e2b40d2	strncat
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e3d894c	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2e593a27	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0x2e73dfd2	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0x2e8b5add	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0x2e93495e	_lv1_write_htab_entry
++EXPORT_SYMBOL vmlinux 0x2e96f12e	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x2ea712ba	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0x2ed446ec	misc_register
++EXPORT_SYMBOL vmlinux 0x2edd1bc8	ps3_sb_event_receive_port_destroy
++EXPORT_SYMBOL vmlinux 0x2ede3843	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0x2ee4337f	smu_queue_cmd
++EXPORT_SYMBOL vmlinux 0x2ef129ff	set_wb_congested
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f1281e2	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0x2f287f0d	copy_to_user
++EXPORT_SYMBOL vmlinux 0x2f3f51ae	__frontswap_test
++EXPORT_SYMBOL vmlinux 0x2f3f6c46	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2faadd36	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0x2fae96de	rtas_data_buf_lock
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fb9eee2	nvdimm_revalidate_disk
++EXPORT_SYMBOL vmlinux 0x2fbe889f	set_posix_acl
++EXPORT_SYMBOL vmlinux 0x2fcef3e4	nonseekable_open
++EXPORT_SYMBOL vmlinux 0x2fd1c8f5	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2feba029	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x30199ca2	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0x3020b7b5	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0x30226ddf	agp_device_command
++EXPORT_SYMBOL vmlinux 0x302aa4da	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x303d09c3	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x307d70fb	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0x308e9b5d	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0x309546e0	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x30977885	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30b8b35c	cpu_to_chip_id
++EXPORT_SYMBOL vmlinux 0x30d973fd	mdiobus_write
++EXPORT_SYMBOL vmlinux 0x30e50c61	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0x30fb2d8e	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310f02ec	memremap
++EXPORT_SYMBOL vmlinux 0x3112600c	complete_request_key
++EXPORT_SYMBOL vmlinux 0x312cfaf2	_lv1_disable_logical_spe
++EXPORT_SYMBOL vmlinux 0x312d7d40	param_set_long
++EXPORT_SYMBOL vmlinux 0x313b5323	generic_file_open
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x3162ad38	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x31763d89	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x317b211c	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0x3192fcf3	sget_userns
++EXPORT_SYMBOL vmlinux 0x31943f19	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x319b1fd7	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0x319f9f6b	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x31b21c5d	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0x31b7f300	_lv1_set_lpm_signal
++EXPORT_SYMBOL vmlinux 0x31cd509a	_lv1_net_control
++EXPORT_SYMBOL vmlinux 0x31cd995b	store_fp_state
++EXPORT_SYMBOL vmlinux 0x31ddf571	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x31e63889	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0x31fa52c7	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0x321ea3f2	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0x32283c5b	d_splice_alias
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x32542e52	of_find_all_nodes
++EXPORT_SYMBOL vmlinux 0x3267e8d4	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x326df472	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0x3277bb6d	blkdev_put
++EXPORT_SYMBOL vmlinux 0x327b9c1b	pmu_poll_adb
++EXPORT_SYMBOL vmlinux 0x3288b003	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0x32a933c7	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0x32af3c3e	cdrom_open
++EXPORT_SYMBOL vmlinux 0x32dbee94	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x32ddc69b	nd_sb_checksum
++EXPORT_SYMBOL vmlinux 0x331440bd	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x33191d6b	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0x331dcc8c	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x33275c2d	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x333cb37c	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x335e19a8	seq_write
++EXPORT_SYMBOL vmlinux 0x3395ecbe	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x33ad71c2	vfs_setpos
++EXPORT_SYMBOL vmlinux 0x33afb276	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x33b84f74	copy_page
++EXPORT_SYMBOL vmlinux 0x33c5de4b	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33e8ddd2	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x33f07c09	md_done_sync
++EXPORT_SYMBOL vmlinux 0x33fcf44a	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0x34062126	param_set_charp
++EXPORT_SYMBOL vmlinux 0x3417f3b8	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x3421d74c	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x342e3d3e	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0x34386191	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0x344adbd5	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x3459266d	poll_initwait
++EXPORT_SYMBOL vmlinux 0x345bb59f	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0x34619150	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x348301f9	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x348b9569	setattr_copy
++EXPORT_SYMBOL vmlinux 0x348c2ebf	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x3492c41c	km_state_expired
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34af716e	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x34b5d2b9	module_layout
++EXPORT_SYMBOL vmlinux 0x34d80ff6	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x34f79fae	kernel_read
++EXPORT_SYMBOL vmlinux 0x34f87534	input_reset_device
++EXPORT_SYMBOL vmlinux 0x3506695f	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x350cbe88	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x35253ce5	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0x3539f11b	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x354d48b9	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0x35512818	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x357cbde5	do_splice_from
++EXPORT_SYMBOL vmlinux 0x3581f343	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0x358cc4e1	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35af0325	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0x35bee5e6	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x35c32767	xor_altivec_2
++EXPORT_SYMBOL vmlinux 0x35e00923	of_graph_parse_endpoint
++EXPORT_SYMBOL vmlinux 0x35f7a439	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0x3609e4d2	iget_locked
++EXPORT_SYMBOL vmlinux 0x36147d54	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0x3618cb2d	ida_destroy
++EXPORT_SYMBOL vmlinux 0x3623989d	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x3626e8e0	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x36476ff6	sock_init_data
++EXPORT_SYMBOL vmlinux 0x3658bbbc	eeh_dev_release
++EXPORT_SYMBOL vmlinux 0x3661e8d5	of_find_property
++EXPORT_SYMBOL vmlinux 0x3662a4d4	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0x366895c1	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0x3669e709	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x366f6d27	idr_destroy
++EXPORT_SYMBOL vmlinux 0x369e1115	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x36ac8f4a	kset_unregister
++EXPORT_SYMBOL vmlinux 0x36b0e732	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36bde2d9	sg_miter_next
++EXPORT_SYMBOL vmlinux 0x36c0e6d4	mapping_tagged
++EXPORT_SYMBOL vmlinux 0x36dfffef	generic_write_end
++EXPORT_SYMBOL vmlinux 0x36e8861c	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x36f7096b	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x36f7d2f9	flush_signals
++EXPORT_SYMBOL vmlinux 0x371902e9	_lv1_get_lpm_interrupt_status
++EXPORT_SYMBOL vmlinux 0x371d2130	check_legacy_ioport
++EXPORT_SYMBOL vmlinux 0x37344510	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x37383edd	rtas_get_power_level
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x37481812	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x3775f75e	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0x378576e3	mdiobus_read
++EXPORT_SYMBOL vmlinux 0x37a47bd3	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x37aa522c	vio_unregister_device
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37b8b39e	screen_info
++EXPORT_SYMBOL vmlinux 0x37bdac69	tso_count_descs
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37e0153d	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x37e6b33c	i2c_transfer
++EXPORT_SYMBOL vmlinux 0x37f75e8f	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x3809ab1c	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x380da1f9	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x382777ab	_lv1_gpu_context_allocate
++EXPORT_SYMBOL vmlinux 0x3842bafc	nd_btt_arena_is_valid
++EXPORT_SYMBOL vmlinux 0x385514a4	of_get_next_available_child
++EXPORT_SYMBOL vmlinux 0x386e13aa	sys_fillrect
++EXPORT_SYMBOL vmlinux 0x387fed67	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x389a49b2	nd_btt_probe
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a7fc74	migrate_page
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38b47360	tcp_filter
++EXPORT_SYMBOL vmlinux 0x38b825d1	idr_replace
++EXPORT_SYMBOL vmlinux 0x38cc3430	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x38d26fd0	get_super
++EXPORT_SYMBOL vmlinux 0x38dd985a	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x38deff9a	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0x38e56877	drop_super
++EXPORT_SYMBOL vmlinux 0x38f18574	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x38fb9933	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x393d4de9	crc32_le
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x3955fcf6	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x3964e7eb	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0x397276dd	dev_add_offload
++EXPORT_SYMBOL vmlinux 0x39732482	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0x397b52da	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0x39939d7b	sync_inode
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x399ad043	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0x39a76c3d	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0x39a939da	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39cdf63c	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x39d1b90a	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0x39e76ab1	of_find_matching_node_and_match
++EXPORT_SYMBOL vmlinux 0x39f7da61	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0x39f9c44c	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x3a07f190	dev_close
++EXPORT_SYMBOL vmlinux 0x3a090566	sk_free
++EXPORT_SYMBOL vmlinux 0x3a188e95	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0x3a1e4710	led_set_brightness
++EXPORT_SYMBOL vmlinux 0x3a3c0c46	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0x3a5d1183	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0x3a6939d4	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x3a99e001	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3aa58074	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0x3ab2d8a9	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0x3ac86565	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x3aec4cdc	generic_show_options
++EXPORT_SYMBOL vmlinux 0x3b0882cc	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0x3b17e715	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x3b3a56d9	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0x3b40af62	page_put_link
++EXPORT_SYMBOL vmlinux 0x3b43b516	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0x3b4aa97b	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0x3b615a21	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b65e4d0	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0x3b7aa2f4	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0x3b89f458	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0x3b9d13c0	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0x3b9ef78a	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0x3ba6a5ad	blk_complete_request
++EXPORT_SYMBOL vmlinux 0x3bbdc707	iterate_fd
++EXPORT_SYMBOL vmlinux 0x3bc2d73e	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x3bc3daf9	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0x3bf252da	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0x3c04a070	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0x3c183feb	get_user_pages
++EXPORT_SYMBOL vmlinux 0x3c29901f	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0x3c3bfb8e	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c483012	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c946c90	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0x3cc4b0dc	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x3ccec63b	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x3cd45879	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3d0ded17	sk_capable
++EXPORT_SYMBOL vmlinux 0x3d22b17b	param_get_int
++EXPORT_SYMBOL vmlinux 0x3d4eba16	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x3d6305bc	pcibios_fixup_bus
++EXPORT_SYMBOL vmlinux 0x3d6a6f91	pci_match_id
++EXPORT_SYMBOL vmlinux 0x3d837791	vga_put
++EXPORT_SYMBOL vmlinux 0x3d9b526d	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x3db0e198	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x3dbf36c9	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0x3dc02a4e	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3ddacb2d	kobject_put
++EXPORT_SYMBOL vmlinux 0x3df5a3b6	__nd_driver_register
++EXPORT_SYMBOL vmlinux 0x3df77fa0	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0x3dfa7c1a	of_find_node_by_name
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e0f1158	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0x3e286dca	_lv1_get_rtc
++EXPORT_SYMBOL vmlinux 0x3e45041c	path_noexec
++EXPORT_SYMBOL vmlinux 0x3e570337	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0x3e585f85	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x3e6ec525	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0x3e7ffa76	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x3e882943	pcibios_align_resource
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x3e962be6	kthread_stop
++EXPORT_SYMBOL vmlinux 0x3ebdfcde	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0x3ec24d5f	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0x3ed5e67b	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x3ed69814	do_splice_to
++EXPORT_SYMBOL vmlinux 0x3ed95120	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x3ed9dc9a	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x3f0546a8	ioread32_rep
++EXPORT_SYMBOL vmlinux 0x3f05de3a	vfs_getattr
++EXPORT_SYMBOL vmlinux 0x3f06a656	_lv1_construct_event_receive_port
++EXPORT_SYMBOL vmlinux 0x3f3554bc	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x3f406a3b	enable_kernel_altivec
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f5df26a	pci_bus_type
++EXPORT_SYMBOL vmlinux 0x3f76f7bf	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0x3f95fe59	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x3faf2481	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0x3fbfd6ed	_lv1_gpu_open
++EXPORT_SYMBOL vmlinux 0x3fd1da65	kill_anon_super
++EXPORT_SYMBOL vmlinux 0x3fdc9399	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0x3fe0d1c0	slhc_free
++EXPORT_SYMBOL vmlinux 0x3fe2ccbe	memweight
++EXPORT_SYMBOL vmlinux 0x3fe931ca	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x3ff0e902	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x3ff32b25	cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0x3ff8e495	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x404568c6	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x404f8d1f	udp_del_offload
++EXPORT_SYMBOL vmlinux 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x406a3a25	tty_do_resize
++EXPORT_SYMBOL vmlinux 0x4077bebe	dma_find_channel
++EXPORT_SYMBOL vmlinux 0x4078c098	xattr_full_name
++EXPORT_SYMBOL vmlinux 0x408e3d7d	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40b1d80d	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0x40ba4f3c	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c64382	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40e6df69	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x412a2929	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0x41361807	_lv1_get_logical_ppe_id
++EXPORT_SYMBOL vmlinux 0x413753f5	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x413befb4	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x4159c38f	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x4160a025	set_disk_ro
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x418e38c7	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x41a3fbf1	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x41b196ca	mach_maple
++EXPORT_SYMBOL vmlinux 0x41b2d848	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x41b394c4	make_kgid
++EXPORT_SYMBOL vmlinux 0x41baf194	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0x41c74f16	key_type_keyring
++EXPORT_SYMBOL vmlinux 0x41dbf4de	_lv1_start_lpm
++EXPORT_SYMBOL vmlinux 0x41e93f1e	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x41f1de38	vme_irq_request
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x423e40a1	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x424613e3	agp_find_bridge
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x424e9b16	iput
++EXPORT_SYMBOL vmlinux 0x42595e58	vgacon_text_force
++EXPORT_SYMBOL vmlinux 0x4265e658	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x427fed7f	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0x42838ebd	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0x429b9d94	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42ca0d71	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0x42e020f6	d_lookup
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x43331c60	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x4333f0d3	macio_register_driver
++EXPORT_SYMBOL vmlinux 0x4342ae64	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0x43447782	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x4363f36e	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x436c2179	iowrite32
++EXPORT_SYMBOL vmlinux 0x43800fa0	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x43880fd5	km_state_notify
++EXPORT_SYMBOL vmlinux 0x43a01f90	complete_all
++EXPORT_SYMBOL vmlinux 0x43a78649	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0x43a84895	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x43d821b9	__getblk_slow
++EXPORT_SYMBOL vmlinux 0x43ef1a81	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x43f07afc	do_truncate
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x43f493d2	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x441feeb1	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x444bb4c7	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x44685cab	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0x44710197	free_task
++EXPORT_SYMBOL vmlinux 0x44786eee	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0x447a71ad	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x447bf102	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0x447eb4f1	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x447f68c3	of_translate_dma_address
++EXPORT_SYMBOL vmlinux 0x448eac3e	kmemdup
++EXPORT_SYMBOL vmlinux 0x448f13d4	sync_filesystem
++EXPORT_SYMBOL vmlinux 0x44995ea3	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0x449bcde2	bio_copy_data
++EXPORT_SYMBOL vmlinux 0x449c56e0	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0x449e5dd6	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44b8a376	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0x44c6885c	of_find_node_opts_by_path
++EXPORT_SYMBOL vmlinux 0x44e05073	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x44e5d0c6	lro_flush_all
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44eb192e	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x4512dbd4	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0x451c5ed7	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x451ca959	dev_set_group
++EXPORT_SYMBOL vmlinux 0x451e335f	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0x4521b0b3	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x453b73b4	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x453ebaec	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0x45537cfc	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0x455e0c89	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0x4564459b	_lv1_set_virtual_uart_param
++EXPORT_SYMBOL vmlinux 0x4566ae08	copy_from_iter
++EXPORT_SYMBOL vmlinux 0x456c6361	tcp_connect
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x4594b99b	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0x4596bf16	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0x459e58d5	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0x45a55ec8	__iounmap
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45b17231	input_grab_device
++EXPORT_SYMBOL vmlinux 0x45cfe80b	pasemi_dma_free_flag
++EXPORT_SYMBOL vmlinux 0x45d78329	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0x4612c59d	down_trylock
++EXPORT_SYMBOL vmlinux 0x461ac773	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x461ebfa0	__copy_tofrom_user
++EXPORT_SYMBOL vmlinux 0x462a1333	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x467df16d	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0x468c94cd	nd_region_to_nstype
++EXPORT_SYMBOL vmlinux 0x46a473ca	vio_h_cop_sync
++EXPORT_SYMBOL vmlinux 0x46afd532	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x46c47fb6	__node_distance
++EXPORT_SYMBOL vmlinux 0x46d12956	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x46f2bb50	netdev_state_change
++EXPORT_SYMBOL vmlinux 0x46fd32bd	skb_put
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x47027750	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x47048cbf	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0x471c7389	fb_get_mode
++EXPORT_SYMBOL vmlinux 0x471d1774	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0x472c4127	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x475fc57f	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0x47608718	fence_init
++EXPORT_SYMBOL vmlinux 0x476c45b6	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x4775d166	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0x478edd28	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x47a10dae	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0x47aa79a4	set_blocksize
++EXPORT_SYMBOL vmlinux 0x47d38bd6	pipe_unlock
++EXPORT_SYMBOL vmlinux 0x47d48691	md_update_sb
++EXPORT_SYMBOL vmlinux 0x47e824ac	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0x48057be6	agp_generic_alloc_user
++EXPORT_SYMBOL vmlinux 0x480ed01e	agp_generic_remove_memory
++EXPORT_SYMBOL vmlinux 0x4815f22b	_lv1_gpu_attribute
++EXPORT_SYMBOL vmlinux 0x4827f6bc	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x4829a47e	memcpy
++EXPORT_SYMBOL vmlinux 0x4830f830	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0x4831ecfc	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0x48345d1e	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x48391059	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0x48404b9a	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x4841bdee	strnchr
++EXPORT_SYMBOL vmlinux 0x4843a1b9	_lv1_delete_repository_node
++EXPORT_SYMBOL vmlinux 0x48448803	pci_release_regions
++EXPORT_SYMBOL vmlinux 0x4847ecd5	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x484c1424	pnv_cxl_get_irq_count
++EXPORT_SYMBOL vmlinux 0x4850cc03	__inet_hash
++EXPORT_SYMBOL vmlinux 0x48587027	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x4881efab	pmac_get_partition
++EXPORT_SYMBOL vmlinux 0x4889a164	__sock_create
++EXPORT_SYMBOL vmlinux 0x4899a473	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x48a2a6dd	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x48a7f84a	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48bd83c5	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x48ea0382	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x493063f1	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0x4934ea98	keyring_clear
++EXPORT_SYMBOL vmlinux 0x4934ee7e	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x4959ed89	follow_down
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x495ec6eb	pasemi_dma_alloc_buf
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x49696cfe	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0x49701fa5	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x497352ad	set_cached_acl
++EXPORT_SYMBOL vmlinux 0x497e7a2b	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b0fd1e	load_nls
++EXPORT_SYMBOL vmlinux 0x49bae9d5	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0x49be8bf4	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0x49e2cab8	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x49eda4fd	param_set_int
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x49fc88e3	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x4a156c95	page_waitqueue
++EXPORT_SYMBOL vmlinux 0x4a425ece	key_put
++EXPORT_SYMBOL vmlinux 0x4a5eff35	uart_match_port
++EXPORT_SYMBOL vmlinux 0x4a8961f5	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x4a984c4a	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x4ab158d2	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4ac64da4	_lv1_select_virtual_address_space
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4ad2a57a	opal_event_request
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b085dbf	agp3_generic_configure
++EXPORT_SYMBOL vmlinux 0x4b1d4800	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x4b1ec89d	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x4b3363a7	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0x4b38837a	blk_get_request
++EXPORT_SYMBOL vmlinux 0x4b3cb349	_lv1_destruct_io_irq_outlet
++EXPORT_SYMBOL vmlinux 0x4b4fcee2	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0x4b5bf6f6	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b604d1a	skb_push
++EXPORT_SYMBOL vmlinux 0x4b6fcddc	_lv1_set_spe_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x4b8326ff	ida_remove
++EXPORT_SYMBOL vmlinux 0x4b9918a3	padata_free
++EXPORT_SYMBOL vmlinux 0x4b99a9b0	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4bb36178	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0x4bed99b3	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0x4bf48d50	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x4c046962	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x4c11435a	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0x4c1b45bf	of_device_is_compatible
++EXPORT_SYMBOL vmlinux 0x4c23b8c9	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x4c2d53ff	machine_id
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c51f7a4	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0x4c628504	open_exec
++EXPORT_SYMBOL vmlinux 0x4c8859e8	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0x4ca9669f	scnprintf
++EXPORT_SYMBOL vmlinux 0x4cb62aa7	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x4cc0624d	set_bh_page
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4d1d7ecf	rt6_lookup
++EXPORT_SYMBOL vmlinux 0x4d26514a	pnv_cxl_release_hwirq_ranges
++EXPORT_SYMBOL vmlinux 0x4d2e7f79	acl_by_type
++EXPORT_SYMBOL vmlinux 0x4d31f19c	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0x4d3373d3	unlock_page
++EXPORT_SYMBOL vmlinux 0x4d36078c	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x4d39e6ab	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0x4d4c044d	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0x4d6d6673	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x4d791953	mempool_resize
++EXPORT_SYMBOL vmlinux 0x4d7cb47d	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4d9f4b9e	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x4da46a88	param_ops_string
++EXPORT_SYMBOL vmlinux 0x4ddbbeb7	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x4ddcdfa9	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x4de0f608	no_llseek
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4df6aab9	of_mdio_parse_addr
++EXPORT_SYMBOL vmlinux 0x4e001906	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x4e13cd8a	__bforget
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e3bcc2c	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e74577a	__dax_fault
++EXPORT_SYMBOL vmlinux 0x4e7a5721	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0x4e7bc529	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0x4e86df5c	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0x4e91b1d7	of_phy_is_fixed_link
++EXPORT_SYMBOL vmlinux 0x4e9d046e	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0x4e9dffb5	ip_fast_csum
++EXPORT_SYMBOL vmlinux 0x4eac1a79	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0x4ebb837c	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x4ec303ab	wake_up_process
++EXPORT_SYMBOL vmlinux 0x4edcb432	give_up_console
++EXPORT_SYMBOL vmlinux 0x4efff5e9	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0x4f1c038a	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f1f1860	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f35a133	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f4b09ff	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x4f60d5f8	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x4f664db6	_lv1_insert_htab_entry
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f743c21	input_register_handler
++EXPORT_SYMBOL vmlinux 0x4f82894e	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x4f89acef	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x4f8d0ad2	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x4fa53b09	simple_write_end
++EXPORT_SYMBOL vmlinux 0x4fcdf4d3	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0x4fcdfc8c	of_match_device
++EXPORT_SYMBOL vmlinux 0x4fdb672c	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x4fdc2fec	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0x4fdee897	i8042_command
++EXPORT_SYMBOL vmlinux 0x4ff38bf3	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x5008ebe3	serio_bus
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x5030626e	udp_prot
++EXPORT_SYMBOL vmlinux 0x5034f98c	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x5071cc28	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x5076bdd0	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x507871d2	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x507bc7ad	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x50a2d375	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0x50a90e8d	bsearch
++EXPORT_SYMBOL vmlinux 0x50ba769a	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x50bbaf0e	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0x50d93d53	km_query
++EXPORT_SYMBOL vmlinux 0x50dd6188	load_nls_default
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x51108437	phy_device_create
++EXPORT_SYMBOL vmlinux 0x51164ad9	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x512482c6	md_write_end
++EXPORT_SYMBOL vmlinux 0x514bf35e	add_disk
++EXPORT_SYMBOL vmlinux 0x515d22a3	vfs_unlink
++EXPORT_SYMBOL vmlinux 0x515ec33d	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0x519b0da3	finish_wait
++EXPORT_SYMBOL vmlinux 0x51a67f4d	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0x51a7e82e	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x51bcc7c8	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x51dee068	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x51e07230	fb_blank
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x520a04c0	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0x520e0a18	dget_parent
++EXPORT_SYMBOL vmlinux 0x5210e88c	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x5214dab0	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x5247d11a	giveup_vsx
++EXPORT_SYMBOL vmlinux 0x524ea2a9	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x52531e56	vfs_readf
++EXPORT_SYMBOL vmlinux 0x525aea0c	node_data
++EXPORT_SYMBOL vmlinux 0x52670384	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x52759e07	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x527830ff	pmac_xpram_read
++EXPORT_SYMBOL vmlinux 0x528a7d7b	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0x529498a7	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0x52983a4f	vme_master_write
++EXPORT_SYMBOL vmlinux 0x52a39bb0	pnv_pci_get_npu_dev
++EXPORT_SYMBOL vmlinux 0x52c700bf	misc_deregister
++EXPORT_SYMBOL vmlinux 0x52e3fa05	_lv1_allocate_memory
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x531bb28c	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0x5322bf66	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x53378cfa	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0x5339f25d	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0x5339f5f8	_lv1_read_virtual_uart
++EXPORT_SYMBOL vmlinux 0x534cfcd2	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0x5359cf98	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x536459f3	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0x536cc847	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x5371d868	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0x5371e96c	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x5377e556	hex2bin
++EXPORT_SYMBOL vmlinux 0x5387765a	generic_read_dir
++EXPORT_SYMBOL vmlinux 0x5392905a	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x5398103e	vga_con
++EXPORT_SYMBOL vmlinux 0x539af73c	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x53b0165e	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0x53c8ac80	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0x53e0a70a	macio_request_resources
++EXPORT_SYMBOL vmlinux 0x53e6da4f	update_devfreq
++EXPORT_SYMBOL vmlinux 0x53ebab1b	_outsl_ns
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x540ddec1	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x5410cedb	check_disk_change
++EXPORT_SYMBOL vmlinux 0x5412c7c7	up
++EXPORT_SYMBOL vmlinux 0x54245b39	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x5446e93d	pci_restore_state
++EXPORT_SYMBOL vmlinux 0x54526587	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x5468704c	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x548384be	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x54883515	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0x548f22ec	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x5492a3ab	single_open_size
++EXPORT_SYMBOL vmlinux 0x549b603c	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0x549f4722	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0x54a6defc	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54b2981e	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0x54b622fe	input_open_device
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54c82879	cdev_add
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54f88828	get_phy_device
++EXPORT_SYMBOL vmlinux 0x54fb47aa	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x550d6d17	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0x5511dc7c	of_phy_attach
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x55341ec1	prepare_creds
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x55531e1b	I_BDEV
++EXPORT_SYMBOL vmlinux 0x5560d833	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x5565d832	ether_setup
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x5568c553	complete
++EXPORT_SYMBOL vmlinux 0x5577ef9e	udp_table
++EXPORT_SYMBOL vmlinux 0x557b3dd8	_lv1_gpu_close
++EXPORT_SYMBOL vmlinux 0x55b30d23	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x55f5019b	__kmalloc_node
++EXPORT_SYMBOL vmlinux 0x5610dbd8	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0x56140c60	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x563927ba	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0x56461c2d	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x56516373	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x568804ee	_lv1_destruct_event_receive_port
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x5694fd04	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x56a9dbe0	of_dev_get
++EXPORT_SYMBOL vmlinux 0x56baab53	dev_crit
++EXPORT_SYMBOL vmlinux 0x56c2b95b	rtas_progress
++EXPORT_SYMBOL vmlinux 0x56c3f7c2	mount_subtree
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56ddd997	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x56e437de	param_ops_short
++EXPORT_SYMBOL vmlinux 0x56edc13e	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0x56f6c7de	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0x56f87bb5	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0x57010289	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0x570a9cc5	pci_bus_get
++EXPORT_SYMBOL vmlinux 0x5712c9ae	tcp_child_process
++EXPORT_SYMBOL vmlinux 0x572647d6	get_mce_fault_addr
++EXPORT_SYMBOL vmlinux 0x57287773	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x574a184f	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x5753283c	md_register_thread
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x57749b5a	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0x577d35f3	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x57875aaf	ibmebus_unregister_driver
++EXPORT_SYMBOL vmlinux 0x578c6a9f	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0x5792f848	strlcpy
++EXPORT_SYMBOL vmlinux 0x5798819b	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x579bab50	_lv1_gpu_memory_free
++EXPORT_SYMBOL vmlinux 0x57a1d0d1	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0x57a5ba2c	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0x57a91fb9	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0x57d33e36	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0x57ecf1e5	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0x57fb92ca	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x5801d167	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0x58170415	flush_old_exec
++EXPORT_SYMBOL vmlinux 0x5819b4ef	of_cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x582eac92	page_symlink
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x58519aa8	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0x5857b225	ioread16_rep
++EXPORT_SYMBOL vmlinux 0x5866855b	path_is_under
++EXPORT_SYMBOL vmlinux 0x58739cd3	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x589f1f1b	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x58b54321	nd_namespace_blk_validate
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58c54576	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0x58dd6f47	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x58fb5191	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x58fb58b3	tc_classify
++EXPORT_SYMBOL vmlinux 0x59272f65	nf_register_hook
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x5959b75f	posix_test_lock
++EXPORT_SYMBOL vmlinux 0x595d0946	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x59680b92	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x59690ae7	stop_tty
++EXPORT_SYMBOL vmlinux 0x596b8539	kmem_cache_alloc_node_trace
++EXPORT_SYMBOL vmlinux 0x59729603	kill_fasync
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x598fcaeb	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x59941008	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0x59a6102f	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0x59a7a5ec	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59b3378a	completion_done
++EXPORT_SYMBOL vmlinux 0x59d2fc0b	agp_bind_memory
++EXPORT_SYMBOL vmlinux 0x59e531cc	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0x59f29fd1	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0x5a025f7b	arch_local_irq_restore
++EXPORT_SYMBOL vmlinux 0x5a098b04	security_file_permission
++EXPORT_SYMBOL vmlinux 0x5a0aaa12	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a0c1584	__lock_buffer
++EXPORT_SYMBOL vmlinux 0x5a0eb6a9	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0x5a1d78b2	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x5a2cda3e	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0x5a6e9a6c	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x5a77136f	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0x5a921311	strncmp
++EXPORT_SYMBOL vmlinux 0x5a93a00c	arp_xmit
++EXPORT_SYMBOL vmlinux 0x5a9f1d63	memmove
++EXPORT_SYMBOL vmlinux 0x5abcf1fa	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x5abe4e1e	netdev_printk
++EXPORT_SYMBOL vmlinux 0x5ad8fc7d	sget
++EXPORT_SYMBOL vmlinux 0x5af45e4c	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5b038dcd	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x5b33cb97	of_get_cpu_node
++EXPORT_SYMBOL vmlinux 0x5b43f1f1	rtas_service_present
++EXPORT_SYMBOL vmlinux 0x5b4cef51	netlink_ack
++EXPORT_SYMBOL vmlinux 0x5b56860c	vm_munmap
++EXPORT_SYMBOL vmlinux 0x5b5b0e32	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x5b94f7c3	netif_device_detach
++EXPORT_SYMBOL vmlinux 0x5b9828c5	dma_spin_lock
++EXPORT_SYMBOL vmlinux 0x5b9d5538	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0x5bad887c	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0x5bbbf04b	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x5bc10524	printk_emit
++EXPORT_SYMBOL vmlinux 0x5bc9cdf8	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0x5bcdce10	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0x5bea79f0	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x5bfaa80f	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0x5bfd4542	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0x5c10d532	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0x5c182fd1	dqget
++EXPORT_SYMBOL vmlinux 0x5c2477d3	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x5c37f319	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x5c626d5c	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0x5c6d5573	ps3_dma_region_create
++EXPORT_SYMBOL vmlinux 0x5c8a6858	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0x5c970cf5	__page_symlink
++EXPORT_SYMBOL vmlinux 0x5cb065ad	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x5cc32bdc	bitmap_copy_le
++EXPORT_SYMBOL vmlinux 0x5cc3767a	noop_fsync
++EXPORT_SYMBOL vmlinux 0x5ccc9045	_lv1_close_device
++EXPORT_SYMBOL vmlinux 0x5cefd239	__genl_register_family
++EXPORT_SYMBOL vmlinux 0x5cf30e10	__debugger_ipi
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5cfb7592	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0x5d165798	fsl_lbc_ctrl_dev
++EXPORT_SYMBOL vmlinux 0x5d1bfd68	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x5d1f9aaf	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0x5d2a56d3	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0x5d2a9474	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0x5d494f46	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0x5d4d949f	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d6acafc	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0x5d87a0fe	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0x5daa6e81	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0x5daae8bd	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x5db73048	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x5de00409	vfs_link
++EXPORT_SYMBOL vmlinux 0x5df43000	macio_dev_get
++EXPORT_SYMBOL vmlinux 0x5e030ac0	nf_afinfo
++EXPORT_SYMBOL vmlinux 0x5e076ab8	softnet_data
++EXPORT_SYMBOL vmlinux 0x5e111c5a	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x5e239db0	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0x5e3a8a9c	__wake_up
++EXPORT_SYMBOL vmlinux 0x5e48b6bc	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x5e4e09dd	init_buffer
++EXPORT_SYMBOL vmlinux 0x5e667aa1	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x5e7c73d9	of_node_put
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5eb04a76	pci_find_hose_for_OF_device
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5eb81642	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x5ec1270b	bh_submit_read
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5eddb914	lockref_put_return
++EXPORT_SYMBOL vmlinux 0x5eec52a7	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f011021	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f108f9a	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0x5f25c467	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x5f434c5d	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x5f656ea1	of_iomap
++EXPORT_SYMBOL vmlinux 0x5f6dd871	override_creds
++EXPORT_SYMBOL vmlinux 0x5f7671ed	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0x5f8a2728	isa_io_base
++EXPORT_SYMBOL vmlinux 0x5fd17294	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x5fdb8e89	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0x5fe8eec0	netlink_set_err
++EXPORT_SYMBOL vmlinux 0x5ff47def	vme_bus_num
++EXPORT_SYMBOL vmlinux 0x5ffd391b	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x6009995b	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0x6019e527	send_sig_info
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x601fa24a	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0x60351b2d	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x604aa600	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x604f9d24	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x6074709a	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x607515d8	of_n_size_cells
++EXPORT_SYMBOL vmlinux 0x6075311b	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0x6088127d	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x6093a67c	dm_put_device
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60a87f2d	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0x60b4eaff	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0x60b902ad	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x60c88b2e	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0x60c8f0c3	sock_i_ino
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x60e0b10e	clear_user_page
++EXPORT_SYMBOL vmlinux 0x60ea5081	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0x6106234c	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x61229b10	node_to_cpumask_map
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x614bb773	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x61674bd2	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0x618911fc	numa_node
++EXPORT_SYMBOL vmlinux 0x619cb7dd	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x61a4487c	_lv1_gpu_device_unmap
++EXPORT_SYMBOL vmlinux 0x61a81964	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0x61aee8b4	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61bd875f	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0x61bdba9b	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0x61c78197	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x61da364b	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0x61dcdcd3	_lv1_pause
++EXPORT_SYMBOL vmlinux 0x61dcf24a	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x61e477dc	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0x61eef2c9	_insb
++EXPORT_SYMBOL vmlinux 0x61ef6170	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0x61f86f30	flush_dcache_page
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x6215a4f2	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x62223b52	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x623d03be	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x6242d0c4	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0x6244d85e	param_get_short
++EXPORT_SYMBOL vmlinux 0x62538167	slhc_toss
++EXPORT_SYMBOL vmlinux 0x6257589f	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0x6272591d	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x627b7f42	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x627f2dc7	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x62914cb4	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0x6297c68d	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x62a6542a	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0x62e14c41	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x6305bf8f	nvdimm_namespace_disk_name
++EXPORT_SYMBOL vmlinux 0x630e2c2e	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x631d09b8	phy_attach
++EXPORT_SYMBOL vmlinux 0x63270a3b	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0x63396aec	__debugger_break_match
++EXPORT_SYMBOL vmlinux 0x63453717	mutex_lock
++EXPORT_SYMBOL vmlinux 0x635d75e1	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0x6360d639	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63b31cbb	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x63bed626	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63c911ab	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x63d1555d	put_filp
++EXPORT_SYMBOL vmlinux 0x63d1b1f3	input_set_capability
++EXPORT_SYMBOL vmlinux 0x63da1828	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63f75920	_lv1_construct_virtual_address_space
++EXPORT_SYMBOL vmlinux 0x63f8a239	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x64081f2d	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x64088efb	netif_rx
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x6419d062	netdev_alert
++EXPORT_SYMBOL vmlinux 0x64291abf	downgrade_write
++EXPORT_SYMBOL vmlinux 0x6431934a	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x643fe4dc	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0x64638b5c	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x646cc6ab	pmu_poll
++EXPORT_SYMBOL vmlinux 0x6477a453	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x6488b8de	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x648ef3e3	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0x64901f72	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64a9d7e7	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0x64b98538	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0x64bbc288	string_unescape
++EXPORT_SYMBOL vmlinux 0x64c0ba07	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0x64cb0a75	block_write_full_page
++EXPORT_SYMBOL vmlinux 0x64f51e41	blk_end_request
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x652ce9aa	nla_memcmp
++EXPORT_SYMBOL vmlinux 0x653179d0	phy_suspend
++EXPORT_SYMBOL vmlinux 0x65318863	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x65457bf4	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0x655d9d4c	sock_i_uid
++EXPORT_SYMBOL vmlinux 0x65607cc4	of_match_node
++EXPORT_SYMBOL vmlinux 0x6566c685	simple_lookup
++EXPORT_SYMBOL vmlinux 0x656984c1	file_remove_privs
++EXPORT_SYMBOL vmlinux 0x656c1a0e	string_escape_mem
++EXPORT_SYMBOL vmlinux 0x65797543	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0x657ef054	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0x659f0bb1	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x65aacbe6	registered_fb
++EXPORT_SYMBOL vmlinux 0x65ab92ae	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x65bb58a2	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0x65d1147c	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65db0fe5	i2c_use_client
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65e0d6d7	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x660d1349	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0x663ba06d	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x66531dea	serio_interrupt
++EXPORT_SYMBOL vmlinux 0x6657e2f7	get_agp_version
++EXPORT_SYMBOL vmlinux 0x666edc22	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x66754be3	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x668babf7	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0x66ad1cb3	_lv1_set_lpm_general_control
++EXPORT_SYMBOL vmlinux 0x66b33879	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x66c1808d	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x66c32742	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x66c4df9d	param_set_short
++EXPORT_SYMBOL vmlinux 0x66c5a620	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x66cbf14b	pmac_xpram_write
++EXPORT_SYMBOL vmlinux 0x66cfcd87	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0x670f832d	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x672a69a8	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x672daf4d	nf_log_trace
++EXPORT_SYMBOL vmlinux 0x6737b685	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0x673f815e	agp_bridges
++EXPORT_SYMBOL vmlinux 0x67732bf9	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x6773e550	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0x67946162	bio_chain
++EXPORT_SYMBOL vmlinux 0x6795808a	register_netdevice
++EXPORT_SYMBOL vmlinux 0x67a55364	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x67a9cd2e	__neigh_create
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67c8be9b	of_n_addr_cells
++EXPORT_SYMBOL vmlinux 0x67ef0da6	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x682160c1	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x682784bb	dump_align
++EXPORT_SYMBOL vmlinux 0x6834b245	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x683ae06d	agp_backend_release
++EXPORT_SYMBOL vmlinux 0x68559af0	dst_discard_out
++EXPORT_SYMBOL vmlinux 0x685f7dd5	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x68609857	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x686841c3	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0x686d47f6	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x68722a04	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x689269b8	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68b2040c	init_net
++EXPORT_SYMBOL vmlinux 0x68b7e35d	inet_offloads
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68cb9723	msi_bitmap_free_hwirqs
++EXPORT_SYMBOL vmlinux 0x68d65fc1	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0x68dd885a	find_vma
++EXPORT_SYMBOL vmlinux 0x68e1ef51	smu_present
++EXPORT_SYMBOL vmlinux 0x6921f066	vga_client_register
++EXPORT_SYMBOL vmlinux 0x6968116e	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x696bb808	md_integrity_register
++EXPORT_SYMBOL vmlinux 0x696d3e18	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x6984d8d5	of_find_node_by_phandle
++EXPORT_SYMBOL vmlinux 0x699ccbf8	_lv1_deconfigure_virtual_uart_irq
++EXPORT_SYMBOL vmlinux 0x69a0ca7d	iowrite16be
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69aa4a2e	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0x69abb748	elv_rb_del
++EXPORT_SYMBOL vmlinux 0x69ac5f70	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69c67dde	fd_install
++EXPORT_SYMBOL vmlinux 0x69dfe448	init_task
++EXPORT_SYMBOL vmlinux 0x69e6f134	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a0aa25f	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x6a0d7528	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0x6a0e64f6	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x6a17955c	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0x6a23bdb4	inode_permission
++EXPORT_SYMBOL vmlinux 0x6a47dfef	freeze_super
++EXPORT_SYMBOL vmlinux 0x6a4bc20e	user_revoke
++EXPORT_SYMBOL vmlinux 0x6a50d1a3	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a5fa363	sigprocmask
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6ab055c5	pci_pme_active
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6acb973d	iowrite32be
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b106617	d_genocide
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b358cab	_lv1_read_repository_node
++EXPORT_SYMBOL vmlinux 0x6b387694	_lv1_end_of_interrupt_ext
++EXPORT_SYMBOL vmlinux 0x6b5094f7	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0x6b589a6e	_lv1_net_add_multicast_address
++EXPORT_SYMBOL vmlinux 0x6b58c2f7	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x6b5a778d	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0x6b5dfe73	__debugger_bpt
++EXPORT_SYMBOL vmlinux 0x6b640864	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6b66c889	fence_free
++EXPORT_SYMBOL vmlinux 0x6b6f0c4b	_lv1_create_repository_node
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bc431bf	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x6bc76d1c	__put_cred
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6bf15d53	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x6bf436a8	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0x6c0743d0	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c1a2a2d	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x6c1d6141	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0x6c39bc61	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0x6c3a1b26	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c628bfb	msi_bitmap_alloc_hwirqs
++EXPORT_SYMBOL vmlinux 0x6c6de77a	icmp_send
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c9814b0	sk_common_release
++EXPORT_SYMBOL vmlinux 0x6c9a7344	get_acl
++EXPORT_SYMBOL vmlinux 0x6cadf19e	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0x6cb37127	flex_array_clear
++EXPORT_SYMBOL vmlinux 0x6cb98898	udplite_prot
++EXPORT_SYMBOL vmlinux 0x6cd24fb8	i8042_remove_filter
++EXPORT_SYMBOL vmlinux 0x6cd5b8a5	down_read_trylock
++EXPORT_SYMBOL vmlinux 0x6cf31e97	user_path_create
++EXPORT_SYMBOL vmlinux 0x6cfcc963	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d1743eb	_lv1_get_total_execution_time
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d3aabb9	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x6d4af2fc	seq_file_path
++EXPORT_SYMBOL vmlinux 0x6d53aa07	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0x6d58c417	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0x6d5b7132	dev_err
++EXPORT_SYMBOL vmlinux 0x6d651e2f	inet6_offloads
++EXPORT_SYMBOL vmlinux 0x6d740223	flex_array_put
++EXPORT_SYMBOL vmlinux 0x6d79e3ce	neigh_for_each
++EXPORT_SYMBOL vmlinux 0x6d8adc8c	simple_readpage
++EXPORT_SYMBOL vmlinux 0x6d9cd32f	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0x6da928f4	_insw_ns
++EXPORT_SYMBOL vmlinux 0x6dbfd8fd	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x6dd36ee7	macio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x6dd43db8	dentry_open
++EXPORT_SYMBOL vmlinux 0x6dd97e4b	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6df98c7e	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x6e08f71b	unregister_console
++EXPORT_SYMBOL vmlinux 0x6e0b43ff	ilookup
++EXPORT_SYMBOL vmlinux 0x6e0bfb31	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0x6e0e7ad8	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0x6e20a52f	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x6e5887eb	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x6e6374cf	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0x6e71f640	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e7f0fd2	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x6e905db3	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6ee5ff09	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0x6eebeb23	kernel_accept
++EXPORT_SYMBOL vmlinux 0x6efc1086	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0x6f10f476	udp_add_offload
++EXPORT_SYMBOL vmlinux 0x6f15d576	phy_resume
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f2ab32a	backlight_device_register
++EXPORT_SYMBOL vmlinux 0x6f438bd5	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0x6f7ba161	passthru_features_check
++EXPORT_SYMBOL vmlinux 0x6f7f4499	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6f9ffbd7	macio_release_resource
++EXPORT_SYMBOL vmlinux 0x6fa331ed	_lv1_construct_io_irq_outlet
++EXPORT_SYMBOL vmlinux 0x6fb83fd6	compat_mc_getsockopt
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6fe834f7	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0x6fee7a5a	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x7007ae95	kthread_bind
++EXPORT_SYMBOL vmlinux 0x70130bcf	seq_path
++EXPORT_SYMBOL vmlinux 0x701699b2	_lv1_set_spe_privilege_state_area_1_register
++EXPORT_SYMBOL vmlinux 0x702d0101	d_path
++EXPORT_SYMBOL vmlinux 0x703cd214	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0x7044860d	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7054a3e4	request_dma
++EXPORT_SYMBOL vmlinux 0x706637a1	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0x706cfcd9	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x70d4bcbc	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0x70f86c70	pmu_queue_request
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x7113ae63	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x713cd238	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0x71593319	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0x71601fd2	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x7168d07e	key_link
++EXPORT_SYMBOL vmlinux 0x716b7a16	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0x716db2f9	i2c_release_client
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x718d4810	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x719fa2ef	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x71a3d925	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71b60100	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0x71b9ab03	__free_pages
++EXPORT_SYMBOL vmlinux 0x71be607e	dquot_resume
++EXPORT_SYMBOL vmlinux 0x71e86b09	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0x722d26c5	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0x723f0617	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x725eb461	may_umount
++EXPORT_SYMBOL vmlinux 0x7299bbfe	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0x729b4a83	_lv1_get_spe_all_interrupt_statuses
++EXPORT_SYMBOL vmlinux 0x72a17622	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x72b243d4	free_dma
++EXPORT_SYMBOL vmlinux 0x72b36400	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0x72b6fa56	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0x72c98139	__arch_hweight64
++EXPORT_SYMBOL vmlinux 0x72e36850	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x72ecbb8e	tty_lock
++EXPORT_SYMBOL vmlinux 0x72fcf2bb	__vio_register_driver
++EXPORT_SYMBOL vmlinux 0x73096c02	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0x73110fea	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x7312ddbb	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x731341be	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x7319baa9	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x731a747a	pci_io_base
++EXPORT_SYMBOL vmlinux 0x7331f225	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x734c3dc1	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0x7357142b	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x735d8503	add_wait_queue
++EXPORT_SYMBOL vmlinux 0x73710a3e	dqstats
++EXPORT_SYMBOL vmlinux 0x73bafd93	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0x73be114e	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0x73f34303	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x741b8c23	__scm_send
++EXPORT_SYMBOL vmlinux 0x74475cb5	of_get_next_parent
++EXPORT_SYMBOL vmlinux 0x744795cf	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0x7459f9da	led_update_brightness
++EXPORT_SYMBOL vmlinux 0x745a21b2	bdget_disk
++EXPORT_SYMBOL vmlinux 0x745c0699	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x7475aed8	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0x747c09d2	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0x74849dbe	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x748bbf36	of_gpio_simple_xlate
++EXPORT_SYMBOL vmlinux 0x7494c769	filemap_flush
++EXPORT_SYMBOL vmlinux 0x749b636c	n_tty_compat_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x74b35006	tcf_register_action
++EXPORT_SYMBOL vmlinux 0x74bf0aa8	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74c7680e	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x74d2b69b	dquot_get_state
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74f08313	seq_putc
++EXPORT_SYMBOL vmlinux 0x74fa4987	of_device_get_match_data
++EXPORT_SYMBOL vmlinux 0x74fe8730	sys_ctrler
++EXPORT_SYMBOL vmlinux 0x7503b092	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x75179435	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0x75208f60	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0x7532588a	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0x7538b132	agp_off
++EXPORT_SYMBOL vmlinux 0x756c786e	_lv1_connect_interrupt_event_receive_port
++EXPORT_SYMBOL vmlinux 0x75754995	_lv1_storage_check_async_status
++EXPORT_SYMBOL vmlinux 0x7583476f	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x75909951	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0x75994700	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75be6702	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0x75c9defe	block_commit_write
++EXPORT_SYMBOL vmlinux 0x75cb8fca	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0x75e4f5aa	pasemi_read_mac_reg
++EXPORT_SYMBOL vmlinux 0x75e72d3b	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0x75ee3078	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0x75f92042	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x760c063a	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0x761f19b7	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0x761f2d17	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x7645af6f	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764845ce	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x764e2224	_lv1_disconnect_irq_plug_ext
++EXPORT_SYMBOL vmlinux 0x765ff474	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x76676739	pcibus_to_node
++EXPORT_SYMBOL vmlinux 0x76763daa	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x768988e4	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x76b7a92f	phy_detach
++EXPORT_SYMBOL vmlinux 0x76cb301e	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76e754b6	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0x76f7cf53	serio_close
++EXPORT_SYMBOL vmlinux 0x76ff3864	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0x7709a9a3	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x77144936	_lv1_disconnect_irq_plug
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x771d14a0	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0x772a7235	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x773506e8	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0x773fa409	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x77423eb3	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x774716d3	dev_deactivate
++EXPORT_SYMBOL vmlinux 0x7767ad48	kfree_skb
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x779fc135	neigh_table_init
++EXPORT_SYMBOL vmlinux 0x77a9fbff	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77cdd9a3	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0x77db10dc	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x77e12275	param_get_uint
++EXPORT_SYMBOL vmlinux 0x7830b04f	hvc_put_chars
++EXPORT_SYMBOL vmlinux 0x7834a6e2	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x78403921	blk_run_queue
++EXPORT_SYMBOL vmlinux 0x7846af3e	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x789a17f7	_lv1_destruct_logical_spe
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78a7cc20	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x78a8788f	vme_slot_num
++EXPORT_SYMBOL vmlinux 0x78a9e905	_numa_mem_
++EXPORT_SYMBOL vmlinux 0x78aec7d1	dquot_release
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78ede9b0	of_root
++EXPORT_SYMBOL vmlinux 0x78f09a04	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0x78fdebf3	generic_update_time
++EXPORT_SYMBOL vmlinux 0x79504718	of_get_mac_address
++EXPORT_SYMBOL vmlinux 0x79570b11	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0x795bb0fd	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0x79667368	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x7968eb10	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x797b391d	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0x798075ba	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x7984eefc	key_update
++EXPORT_SYMBOL vmlinux 0x7985d043	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x79896403	netdev_info
++EXPORT_SYMBOL vmlinux 0x799e2e43	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x79a33f85	vme_get_size
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79d11bd7	nvdimm_namespace_common_probe
++EXPORT_SYMBOL vmlinux 0x79d9b944	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0x79def19b	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0x79e3c944	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0x79e3ead7	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x7a2074a5	module_refcount
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a4a7541	generic_readlink
++EXPORT_SYMBOL vmlinux 0x7a60a876	bdput
++EXPORT_SYMBOL vmlinux 0x7a652a68	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0x7a6cdedc	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7a74b9e4	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7aa9e259	_lv1_map_htab
++EXPORT_SYMBOL vmlinux 0x7aac0a75	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0x7ab6cf76	scsi_register
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7abaf2f1	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7adfa632	dev_load
++EXPORT_SYMBOL vmlinux 0x7ae5a980	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x7b16235f	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b21166e	srp_reconnect_rport
++EXPORT_SYMBOL vmlinux 0x7b2267df	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x7b23bc3d	sys_copyarea
++EXPORT_SYMBOL vmlinux 0x7b27abe5	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x7b2aef6c	__krealloc
++EXPORT_SYMBOL vmlinux 0x7b3f9dee	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0x7b4042c4	bioset_create
++EXPORT_SYMBOL vmlinux 0x7b4a2b0f	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0x7b5b551e	filp_open
++EXPORT_SYMBOL vmlinux 0x7b625baf	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x7b6c364f	redraw_screen
++EXPORT_SYMBOL vmlinux 0x7b92504d	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0x7bb756cc	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x7bccd113	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x7bd17155	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x7bf5cd96	netdev_notice
++EXPORT_SYMBOL vmlinux 0x7c003aef	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x7c0850c5	led_blink_set
++EXPORT_SYMBOL vmlinux 0x7c0cdf44	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c18f90f	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0x7c27156c	rtas_online_cpus_mask
++EXPORT_SYMBOL vmlinux 0x7c2d098f	krealloc
++EXPORT_SYMBOL vmlinux 0x7c3c3782	dev_notice
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c5b9428	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c6d7fed	register_sysctl
++EXPORT_SYMBOL vmlinux 0x7c71ed4f	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x7c801a84	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x7c9291d1	csum_partial_copy_generic
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7ca291e3	file_update_time
++EXPORT_SYMBOL vmlinux 0x7cad3b6a	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cb3ea85	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0x7cd08966	__serio_register_port
++EXPORT_SYMBOL vmlinux 0x7cd148a5	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0x7cdc5577	nd_region_release_lane
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7cec9060	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7cfbca4d	kernel_listen
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d63462a	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0x7d6935c6	agp3_generic_tlbflush
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d70dd83	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x7d82fa90	pnv_pci_get_gpu_dev
++EXPORT_SYMBOL vmlinux 0x7d8fac17	param_ops_long
++EXPORT_SYMBOL vmlinux 0x7db5d4a4	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x7dc97879	rtas_get_error_log_max
++EXPORT_SYMBOL vmlinux 0x7dcdd1d4	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0x7dddcb08	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7e0f1ab5	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x7e1a0c26	locks_init_lock
++EXPORT_SYMBOL vmlinux 0x7e27f201	touch_buffer
++EXPORT_SYMBOL vmlinux 0x7e36c6fe	bio_split
++EXPORT_SYMBOL vmlinux 0x7e4a57b6	unregister_netdev
++EXPORT_SYMBOL vmlinux 0x7e5a8d76	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x7e67932e	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x7e80addf	of_parse_phandle
++EXPORT_SYMBOL vmlinux 0x7e87227e	slhc_compress
++EXPORT_SYMBOL vmlinux 0x7e9b9c83	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7eea227e	i8042_install_filter
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f0ff0c3	bdi_register
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f263ed9	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x7f2cda5b	free_page_put_link
++EXPORT_SYMBOL vmlinux 0x7f31d172	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x7f4308c8	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x7f5a3350	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x7f5c8ba1	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f820feb	do_SAK
++EXPORT_SYMBOL vmlinux 0x7f8a13a0	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0x7f9d3482	udp_poll
++EXPORT_SYMBOL vmlinux 0x7fa5078d	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0x7fae581a	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0x7fbd10d2	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fe38f48	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x7fe9a060	_lv1_net_stop_tx_dma
++EXPORT_SYMBOL vmlinux 0x7feaace7	finish_no_open
++EXPORT_SYMBOL vmlinux 0x800bf42e	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0x8014da99	mount_nodev
++EXPORT_SYMBOL vmlinux 0x8028b1fe	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0x80318626	netdev_features_change
++EXPORT_SYMBOL vmlinux 0x8060e132	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0x8068c15c	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x80791a8c	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0x808461cb	generic_write_checks
++EXPORT_SYMBOL vmlinux 0x8085f204	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x809590e9	clear_inode
++EXPORT_SYMBOL vmlinux 0x8096e3ae	dev_warn
++EXPORT_SYMBOL vmlinux 0x80a97436	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x80b38a3a	audit_log_start
++EXPORT_SYMBOL vmlinux 0x80c2a396	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80cf5c66	consume_skb
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x8104ca52	padata_stop
++EXPORT_SYMBOL vmlinux 0x8109deb7	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x81533963	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x8188f65d	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0x81a07f4e	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x81afbe92	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x81c0a84f	rtas_set_indicator
++EXPORT_SYMBOL vmlinux 0x81c8ab09	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0x81d9f7f2	_lv1_put_iopte
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81f64cfb	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x8225bebd	nobh_writepage
++EXPORT_SYMBOL vmlinux 0x822c5a8c	fence_add_callback
++EXPORT_SYMBOL vmlinux 0x82458f7f	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x82472906	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0x825b3f96	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0x8265e6ec	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x8271c16d	tty_port_open
++EXPORT_SYMBOL vmlinux 0x82753253	param_set_ullong
++EXPORT_SYMBOL vmlinux 0x827790ba	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x828b2fb6	of_dev_put
++EXPORT_SYMBOL vmlinux 0x829b0311	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0x829e5b2f	agp_generic_alloc_pages
++EXPORT_SYMBOL vmlinux 0x82a3c474	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82d3face	empty_aops
++EXPORT_SYMBOL vmlinux 0x82dec7c4	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0x82e5a238	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x8321d68c	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x8327bfe0	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0x832c02ac	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x83433de8	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0x8352c826	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x838c9a76	vme_lm_request
++EXPORT_SYMBOL vmlinux 0x838d2080	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x839abdbd	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83b5fec4	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83cd7a26	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0x83dd30d2	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x83e34488	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0x83e59652	revert_creds
++EXPORT_SYMBOL vmlinux 0x83e82802	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0x83ea8d6f	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0x84201bbf	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x844e3767	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0x845055ba	ps3_dma_region_free
++EXPORT_SYMBOL vmlinux 0x845124e0	ps3_mm_phys_to_lpar
++EXPORT_SYMBOL vmlinux 0x845d918a	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0x848f4033	vfs_llseek
++EXPORT_SYMBOL vmlinux 0x849fe807	csum_and_copy_from_user
++EXPORT_SYMBOL vmlinux 0x84a723d8	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x84bd69bf	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x84bee69b	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x84c67545	d_delete
++EXPORT_SYMBOL vmlinux 0x84e388e6	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x84f7065b	dma_direct_ops
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x853a37da	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x853a6f9b	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0x8546b4f3	mach_ps3
++EXPORT_SYMBOL vmlinux 0x854e93bc	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0x85511044	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0x8553b204	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0x855bcc91	of_node_get
++EXPORT_SYMBOL vmlinux 0x855fd054	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0x856355ff	ppp_input_error
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x85748feb	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0x8574f5e6	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x85838547	pid_task
++EXPORT_SYMBOL vmlinux 0x85885ff8	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x8597eb47	plpar_hcall
++EXPORT_SYMBOL vmlinux 0x85990709	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0x859ab2c7	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0x85a6fc27	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x85ae6052	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85c26dfe	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0x85c99191	compat_nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x85cb1dcb	of_get_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0x85dddaf7	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85e73892	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x860ce829	tty_kref_put
++EXPORT_SYMBOL vmlinux 0x860f769e	keyring_search
++EXPORT_SYMBOL vmlinux 0x8614955d	arp_create
++EXPORT_SYMBOL vmlinux 0x8615cdd8	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0x863b0c38	param_ops_bint
++EXPORT_SYMBOL vmlinux 0x863e66e2	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x865504e9	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0x865a722c	of_platform_device_create
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x86944892	agp_collect_device_status
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86c10670	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0x86c5e1b5	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0x86c7ac40	tty_register_device
++EXPORT_SYMBOL vmlinux 0x86db1cbb	rtas_flash_term_hook
++EXPORT_SYMBOL vmlinux 0x86e8b3f2	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x87022389	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0x8703e88a	of_get_ddr_timings
++EXPORT_SYMBOL vmlinux 0x87082d3d	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x871e1370	poll_freewait
++EXPORT_SYMBOL vmlinux 0x8727a853	from_kgid
++EXPORT_SYMBOL vmlinux 0x872f2708	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0x87331e67	make_kuid
++EXPORT_SYMBOL vmlinux 0x873a53ea	__arch_hweight8
++EXPORT_SYMBOL vmlinux 0x875fa1f4	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0x87742aeb	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0x8775477b	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0x87831719	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x87ad88c6	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0x87c22979	napi_complete_done
++EXPORT_SYMBOL vmlinux 0x87cf39e2	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x87eec2df	mdiobus_free
++EXPORT_SYMBOL vmlinux 0x87f3af98	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0x8808d506	request_key_async
++EXPORT_SYMBOL vmlinux 0x880996ef	__sb_end_write
++EXPORT_SYMBOL vmlinux 0x880da1b1	_lv1_get_logical_partition_id
++EXPORT_SYMBOL vmlinux 0x882a5e01	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0x882c34d9	inet_addr_type
++EXPORT_SYMBOL vmlinux 0x882db37f	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0x884ab856	set_binfmt
++EXPORT_SYMBOL vmlinux 0x8852091f	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x885c47b2	is_bad_inode
++EXPORT_SYMBOL vmlinux 0x887fa47e	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x888aabeb	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x88ac0de4	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0x890fa97d	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0x8916d59b	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x891fbb10	mempool_destroy
++EXPORT_SYMBOL vmlinux 0x892de3fb	__nla_put
++EXPORT_SYMBOL vmlinux 0x893eda4d	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x895108f3	proc_dostring
++EXPORT_SYMBOL vmlinux 0x895577b0	numa_cpu_lookup_table
++EXPORT_SYMBOL vmlinux 0x8961575f	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x8963d697	from_kprojid
++EXPORT_SYMBOL vmlinux 0x896bd385	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0x897097aa	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0x89797060	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x897af480	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x899e0b16	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89ba14d8	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0x89c5a8be	smu_get_sdb_partition
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89e31dd4	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0x89eeb633	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0x89f37999	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a24362c	twl6040_power
++EXPORT_SYMBOL vmlinux 0x8a2462f2	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a5c83f8	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x8a6ae547	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0x8a6af65c	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x8a749f16	param_set_invbool
++EXPORT_SYMBOL vmlinux 0x8a772e2c	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a7d98ef	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0x8a97f094	__quota_error
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8a9cef2a	_lv1_allocate_device_dma_region
++EXPORT_SYMBOL vmlinux 0x8aa5b2f0	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0x8ac0385e	of_phy_connect
++EXPORT_SYMBOL vmlinux 0x8adfc954	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0x8af12274	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x8af24c74	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x8af39578	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x8b037a76	nd_iostat_end
++EXPORT_SYMBOL vmlinux 0x8b23dc26	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0x8b2dd5f8	submit_bio
++EXPORT_SYMBOL vmlinux 0x8b3528bd	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b505f80	sock_wake_async
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b8f7c37	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0x8ba732e5	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x8bbd30ef	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0x8bd7efa0	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0x8bf2ae1f	fsl_lbc_addr
++EXPORT_SYMBOL vmlinux 0x8c098234	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x8c15653f	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x8c183cbe	iowrite16
++EXPORT_SYMBOL vmlinux 0x8c2008f9	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x8c5a6ec1	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c72dfae	vfs_write
++EXPORT_SYMBOL vmlinux 0x8c82f6c7	seq_release
++EXPORT_SYMBOL vmlinux 0x8c8d79c0	_lv1_gpu_context_iomap
++EXPORT_SYMBOL vmlinux 0x8cad3dfb	lease_modify
++EXPORT_SYMBOL vmlinux 0x8cb18152	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0x8cbd122d	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x8cbdef66	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x8cc79cab	iowrite16_rep
++EXPORT_SYMBOL vmlinux 0x8ccb58dd	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x8d015dd4	__bswapdi2
++EXPORT_SYMBOL vmlinux 0x8d0db923	i2c_master_send
++EXPORT_SYMBOL vmlinux 0x8d4eb8f9	blk_register_region
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d5e9ad2	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d777777	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0x8d82e0c0	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x8d944cbb	copy_in_user
++EXPORT_SYMBOL vmlinux 0x8da1141d	tty_unlock
++EXPORT_SYMBOL vmlinux 0x8dadcc6a	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0x8de0b5ac	mempool_create
++EXPORT_SYMBOL vmlinux 0x8de2fbc5	_lv1_get_virtual_uart_param
++EXPORT_SYMBOL vmlinux 0x8deff77e	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x8df92f66	memchr_inv
++EXPORT_SYMBOL vmlinux 0x8e006599	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0x8e1a58ac	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0x8e21b92c	__register_chrdev
++EXPORT_SYMBOL vmlinux 0x8e5105ee	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0x8e5f7cca	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x8e67f119	path_put
++EXPORT_SYMBOL vmlinux 0x8e6f97fc	dev_emerg
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e9496f2	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0x8ea98ae9	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x8eb5de7f	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x8ec04552	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0x8ecc1db4	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x8eea1bc9	smu_poll
++EXPORT_SYMBOL vmlinux 0x8ef1e665	dquot_file_open
++EXPORT_SYMBOL vmlinux 0x8ef6c177	agp_bridge
++EXPORT_SYMBOL vmlinux 0x8f0f2460	follow_pfn
++EXPORT_SYMBOL vmlinux 0x8f1360fa	finish_open
++EXPORT_SYMBOL vmlinux 0x8f337e99	input_flush_device
++EXPORT_SYMBOL vmlinux 0x8f34ed76	skb_trim
++EXPORT_SYMBOL vmlinux 0x8f55792c	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x8f80eb8c	ps3_dma_region_init
++EXPORT_SYMBOL vmlinux 0x8f80fe0a	agp_enable
++EXPORT_SYMBOL vmlinux 0x8f8587ff	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0x8f85f835	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x8f8a3831	request_key
++EXPORT_SYMBOL vmlinux 0x8f912773	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0x8f960065	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x8fa54745	__lock_page
++EXPORT_SYMBOL vmlinux 0x8fc15bf6	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0x8fcdf83a	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0x8fdbc882	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0x9010ce1d	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0x9017f093	simple_unlink
++EXPORT_SYMBOL vmlinux 0x9023a30a	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x903928f6	d_tmpfile
++EXPORT_SYMBOL vmlinux 0x9049a0a1	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0x905cb899	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0x90630bf2	nvdimm_bus_lock
++EXPORT_SYMBOL vmlinux 0x907cb552	prepare_binprm
++EXPORT_SYMBOL vmlinux 0x90b7bac8	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0x90e20413	set_security_override
++EXPORT_SYMBOL vmlinux 0x90fb59b0	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x910a7ab8	compat_sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x9114f61d	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x911df0ce	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x91201cef	_lv1_enable_logical_spe
++EXPORT_SYMBOL vmlinux 0x912557ce	rtas_busy_delay
++EXPORT_SYMBOL vmlinux 0x9125f6fc	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x9126a027	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x915e1208	tb_ticks_per_usec
++EXPORT_SYMBOL vmlinux 0x9166fada	strncpy
++EXPORT_SYMBOL vmlinux 0x9168c033	rtas_get_sensor
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x9172eaa3	eth_header
++EXPORT_SYMBOL vmlinux 0x9186ce96	giveup_altivec
++EXPORT_SYMBOL vmlinux 0x919d1163	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x91ac6ac9	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x91ac822f	vscnprintf
++EXPORT_SYMBOL vmlinux 0x91c4feca	_lv1_unmap_htab
++EXPORT_SYMBOL vmlinux 0x91cd0a0e	vm_mmap
++EXPORT_SYMBOL vmlinux 0x91e7acf5	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0x91ef96d2	cdev_init
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x91fd6d28	set_user_nice
++EXPORT_SYMBOL vmlinux 0x92037823	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x92166a3b	notify_change
++EXPORT_SYMBOL vmlinux 0x921c90a1	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0x9236da4b	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x9264d948	nd_device_register
++EXPORT_SYMBOL vmlinux 0x9291cd3b	memdup_user
++EXPORT_SYMBOL vmlinux 0x929535ea	srp_rport_get
++EXPORT_SYMBOL vmlinux 0x929feedb	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92ad008a	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x92b6d238	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0x92c39a51	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0x92e0a8ce	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0x92e96f98	pci_iomap
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x93022ba6	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x9315a638	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0x931d3717	unregister_nls
++EXPORT_SYMBOL vmlinux 0x9334acaf	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x93507f1c	_lv1_gpu_memory_allocate
++EXPORT_SYMBOL vmlinux 0x9354fcde	ibmebus_free_irq
++EXPORT_SYMBOL vmlinux 0x935df2f3	nd_region_acquire_lane
++EXPORT_SYMBOL vmlinux 0x9375e806	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x9378dbe4	d_add_ci
++EXPORT_SYMBOL vmlinux 0x937e0bd3	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x938b615f	brioctl_set
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93c5b84b	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0x93d047e3	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x93da2538	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x9421b35a	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0x943dc80f	csum_and_copy_to_user
++EXPORT_SYMBOL vmlinux 0x943f556d	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x943f8243	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0x944a5e11	param_ops_byte
++EXPORT_SYMBOL vmlinux 0x94541aa3	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0x9458a81a	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x946f78b5	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0x94766d83	seq_open_private
++EXPORT_SYMBOL vmlinux 0x948a3233	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x949bb98d	of_mdiobus_register
++EXPORT_SYMBOL vmlinux 0x94a99802	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x94b362c5	generic_writepages
++EXPORT_SYMBOL vmlinux 0x94c0b461	keyring_alloc
++EXPORT_SYMBOL vmlinux 0x94e643d5	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0x94fc9bf3	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x9514151a	_mcount
++EXPORT_SYMBOL vmlinux 0x9524b0ae	_outsb
++EXPORT_SYMBOL vmlinux 0x952d4e32	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x95347c8d	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x955ad71a	macio_enable_devres
++EXPORT_SYMBOL vmlinux 0x955dbb6b	srp_start_tl_fail_timers
++EXPORT_SYMBOL vmlinux 0x95798a71	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0x958eb634	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0x95a9bb83	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0x95b17acb	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0x95c17ded	param_get_ushort
++EXPORT_SYMBOL vmlinux 0x95c7dded	agp_backend_acquire
++EXPORT_SYMBOL vmlinux 0x95dcc1bd	paca
++EXPORT_SYMBOL vmlinux 0x95e4afff	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0x95fe2c87	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0x95ff4280	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x96034e73	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x96069281	security_path_chown
++EXPORT_SYMBOL vmlinux 0x960a93e6	__break_lease
++EXPORT_SYMBOL vmlinux 0x962ff622	pmem_should_map_pages
++EXPORT_SYMBOL vmlinux 0x963c100b	inet_frag_find
++EXPORT_SYMBOL vmlinux 0x963dba7f	phy_print_status
++EXPORT_SYMBOL vmlinux 0x9651f8f2	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x96749db5	security_path_truncate
++EXPORT_SYMBOL vmlinux 0x96927e2b	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0x969987fc	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0x96b01af3	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0x96b29254	strncasecmp
++EXPORT_SYMBOL vmlinux 0x96b9e720	security_path_unlink
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96d117cc	mmc_start_req
++EXPORT_SYMBOL vmlinux 0x96ebeee1	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x96f225c4	inode_init_always
++EXPORT_SYMBOL vmlinux 0x970e5678	set_groups
++EXPORT_SYMBOL vmlinux 0x9748927f	_outsw_ns
++EXPORT_SYMBOL vmlinux 0x974e2026	dump_truncate
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x975dd319	nf_reinject
++EXPORT_SYMBOL vmlinux 0x9761e887	of_get_parent
++EXPORT_SYMBOL vmlinux 0x9764ad20	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x976e014f	_lv1_map_device_mmio_region
++EXPORT_SYMBOL vmlinux 0x97868aef	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0x978f79fc	md_write_start
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x979e597e	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0x97a189d4	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x97a57333	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0x97afba7b	proc_douintvec
++EXPORT_SYMBOL vmlinux 0x97ba1af0	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0x97c57de5	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0x97da910a	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x97f03d6f	vio_cmo_entitlement_update
++EXPORT_SYMBOL vmlinux 0x97f2861a	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0x97f7a8f2	invalidate_partition
++EXPORT_SYMBOL vmlinux 0x980a71ff	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0x98177648	_lv1_set_lpm_interval
++EXPORT_SYMBOL vmlinux 0x981b1cf7	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x981b2148	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0x9821221f	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x98268bde	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0x9829fc11	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0x9858d33c	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0x9864d4b3	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x9875323e	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0x987fc124	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x98994f9f	simple_follow_link
++EXPORT_SYMBOL vmlinux 0x98ac01da	km_report
++EXPORT_SYMBOL vmlinux 0x98c68c41	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x98cadac3	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0x98cf60b3	strlen
++EXPORT_SYMBOL vmlinux 0x98d49011	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x98d71777	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x98ddd441	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0x98efef5b	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0x99022246	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x99195078	vsnprintf
++EXPORT_SYMBOL vmlinux 0x9924c3ae	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x9944bb01	pci_clear_master
++EXPORT_SYMBOL vmlinux 0x994cd0a4	skb_find_text
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x995e0cb1	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0x996de261	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0x99777049	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0x99833a29	iterate_mounts
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99a4fb37	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0x99afe916	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0x99b25e60	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x99b3adaa	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x99c24cfe	_lv1_free_device_dma_region
++EXPORT_SYMBOL vmlinux 0x99ca6f4e	__mutex_init
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d3a43c	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x99daa9bf	try_offline_node
++EXPORT_SYMBOL vmlinux 0x99ed10ff	of_graph_get_port_by_id
++EXPORT_SYMBOL vmlinux 0x9a0570e8	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a1ffb92	_lv1_clear_spe_interrupt_status
++EXPORT_SYMBOL vmlinux 0x9a4af8b4	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0x9a564b47	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0x9a591b75	fasync_helper
++EXPORT_SYMBOL vmlinux 0x9a5ce77e	datagram_poll
++EXPORT_SYMBOL vmlinux 0x9a6c2531	pasemi_dma_init
++EXPORT_SYMBOL vmlinux 0x9a78fb28	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0x9aa557ab	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x9ae12329	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9aedcbb6	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x9b247fac	of_io_request_and_map
++EXPORT_SYMBOL vmlinux 0x9b30d095	inode_init_owner
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b600d7a	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0x9b636660	pci_select_bars
++EXPORT_SYMBOL vmlinux 0x9b66c471	security_path_symlink
++EXPORT_SYMBOL vmlinux 0x9b753ad8	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0x9b7e85a6	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0x9b976e45	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bad267d	pci_request_regions
++EXPORT_SYMBOL vmlinux 0x9bbfe3f2	fs_bio_set
++EXPORT_SYMBOL vmlinux 0x9bca9a61	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0x9bd343d2	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0x9bdfdc7a	mach_pseries
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9bef9e45	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0x9c046bd6	alloc_disk
++EXPORT_SYMBOL vmlinux 0x9c191089	input_unregister_device
++EXPORT_SYMBOL vmlinux 0x9c36670f	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c702f96	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0x9c8a1990	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0x9c938359	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0x9c93d2c6	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cb704cf	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x9cb7909b	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0x9cc49df8	pnv_cxl_alloc_hwirqs
++EXPORT_SYMBOL vmlinux 0x9cd25b49	skb_checksum
++EXPORT_SYMBOL vmlinux 0x9cf05bd8	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0x9cf5bd23	key_revoke
++EXPORT_SYMBOL vmlinux 0x9d062c05	validate_sp
++EXPORT_SYMBOL vmlinux 0x9d07c881	single_release
++EXPORT_SYMBOL vmlinux 0x9d09f248	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d14983a	ppc_enable_pmcs
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d45958b	default_llseek
++EXPORT_SYMBOL vmlinux 0x9d4a880e	block_read_full_page
++EXPORT_SYMBOL vmlinux 0x9d4ef46d	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0x9d61d209	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0x9d6a54c2	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0x9d7ce8dd	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x9d83a783	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0x9d9dfc18	load_fp_state
++EXPORT_SYMBOL vmlinux 0x9da05e10	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0x9da5ef4c	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0x9daa0680	mach_pasemi
++EXPORT_SYMBOL vmlinux 0x9db704c0	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0x9dc7c632	register_gifconf
++EXPORT_SYMBOL vmlinux 0x9dfe6b69	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e18f49e	simple_statfs
++EXPORT_SYMBOL vmlinux 0x9e2f8c90	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9e3c76ca	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0x9e4d5f7c	d_rehash
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e5cc5e5	compat_sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x9e5f58c0	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e672d5a	dst_alloc
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e784785	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0x9e8ebcdd	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0x9e97375d	rtas_busy_delay_time
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9ea8a419	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0x9eb17ac0	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0x9eb739bc	genphy_update_link
++EXPORT_SYMBOL vmlinux 0x9ebb0a4b	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9eda3327	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x9ee78669	_lv1_write_virtual_uart
++EXPORT_SYMBOL vmlinux 0x9eeb0175	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0x9eecf56f	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x9ef3f5b9	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0x9f0c04dc	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0x9f2e2fd1	tty_set_operations
++EXPORT_SYMBOL vmlinux 0x9f301d46	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x9f353f79	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x9f3c36ed	security_path_link
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f4a5652	vme_irq_free
++EXPORT_SYMBOL vmlinux 0x9f7c1be8	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0x9f8e3632	soft_cursor
++EXPORT_SYMBOL vmlinux 0x9f911629	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0x9f928fb2	kset_register
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9fe1ebcf	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0x9febbbc2	dev_alert
++EXPORT_SYMBOL vmlinux 0x9ff900e8	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa000a98c	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0xa03858a4	kern_path_create
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa060adfd	inet_sendpage
++EXPORT_SYMBOL vmlinux 0xa07a37f0	memchr
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa0ac23ce	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0e9d4b0	seq_open
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0ff74d6	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa1101b87	pci_bus_put
++EXPORT_SYMBOL vmlinux 0xa118ab70	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0xa11a6a1d	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0xa120bc22	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa127d7f2	mach_powermac
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa145cd30	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0xa1472288	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0xa156895d	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0xa16d303e	ilookup5
++EXPORT_SYMBOL vmlinux 0xa175801a	dm_io
++EXPORT_SYMBOL vmlinux 0xa17c00ee	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xa18f1c64	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0xa19661a6	dcb_getapp
++EXPORT_SYMBOL vmlinux 0xa19d74f8	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1bfe947	dump_skip
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1c99385	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0xa1ce47e3	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0xa1d279a5	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa1f35827	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0xa1f8fe75	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0xa202a8e5	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa20cd38f	__frontswap_load
++EXPORT_SYMBOL vmlinux 0xa2127cdc	pasemi_dma_alloc_flag
++EXPORT_SYMBOL vmlinux 0xa23125ab	seq_escape
++EXPORT_SYMBOL vmlinux 0xa232b795	sock_no_poll
++EXPORT_SYMBOL vmlinux 0xa2465322	_lv1_get_version_info
++EXPORT_SYMBOL vmlinux 0xa271a084	dst_init
++EXPORT_SYMBOL vmlinux 0xa2722a96	vc_resize
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa296c828	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0xa2a335bd	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0xa2bbed37	crash_shutdown_register
++EXPORT_SYMBOL vmlinux 0xa2cc1fbf	dquot_acquire
++EXPORT_SYMBOL vmlinux 0xa2e691f6	param_get_bool
++EXPORT_SYMBOL vmlinux 0xa2ee5243	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0xa2f9f4fe	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0xa2fdbcbe	fence_default_wait
++EXPORT_SYMBOL vmlinux 0xa303d1ff	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa353046c	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0xa3740273	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0xa3979ce8	ppc_md
++EXPORT_SYMBOL vmlinux 0xa39b4cf2	udelay
++EXPORT_SYMBOL vmlinux 0xa3abc422	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xa3ccc54f	get_fs_type
++EXPORT_SYMBOL vmlinux 0xa3d6e5b8	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xa3da08e0	of_get_min_tck
++EXPORT_SYMBOL vmlinux 0xa3dfe787	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xa3fb5856	nf_log_unset
++EXPORT_SYMBOL vmlinux 0xa4186fde	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0xa41b66ab	serio_open
++EXPORT_SYMBOL vmlinux 0xa429b1eb	mount_ns
++EXPORT_SYMBOL vmlinux 0xa4511467	crc16
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa47b0048	dev_uc_init
++EXPORT_SYMBOL vmlinux 0xa480c04b	_lv1_gpu_context_attribute
++EXPORT_SYMBOL vmlinux 0xa4a94d26	find_next_bit_le
++EXPORT_SYMBOL vmlinux 0xa4b7cf43	set_nlink
++EXPORT_SYMBOL vmlinux 0xa4b94fea	iowrite8_rep
++EXPORT_SYMBOL vmlinux 0xa4bddf6b	scsi_print_command
++EXPORT_SYMBOL vmlinux 0xa4d4f0e6	global_cache_flush
++EXPORT_SYMBOL vmlinux 0xa523767d	register_netdev
++EXPORT_SYMBOL vmlinux 0xa54f47be	key_task_permission
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa55c6830	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0xa566be2e	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0xa56b8ab2	flex_array_free
++EXPORT_SYMBOL vmlinux 0xa57701a3	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0xa57f56ae	iget_failed
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa5a51eee	__crc32c_le
++EXPORT_SYMBOL vmlinux 0xa5b1bb69	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0xa6152ee4	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0xa6268968	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0xa63322c6	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xa648fed2	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0xa65972b8	_memcpy_toio
++EXPORT_SYMBOL vmlinux 0xa65b3723	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0xa672446e	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa67d3d6a	agp_free_memory
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa692cb5e	of_get_property
++EXPORT_SYMBOL vmlinux 0xa69e1af1	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0xa6b44640	of_translate_address
++EXPORT_SYMBOL vmlinux 0xa6b9e1ca	cdrom_release
++EXPORT_SYMBOL vmlinux 0xa6c16c1b	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xa6ca8ac6	arp_send
++EXPORT_SYMBOL vmlinux 0xa6ce472f	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0xa6e23e98	agp_generic_insert_memory
++EXPORT_SYMBOL vmlinux 0xa6f07f1c	decrementer_clockevent
++EXPORT_SYMBOL vmlinux 0xa6f6d7d1	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa7013b33	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0xa71ba503	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0xa720678c	lg_global_lock
++EXPORT_SYMBOL vmlinux 0xa72a0f5b	nr_online_nodes
++EXPORT_SYMBOL vmlinux 0xa72e52cb	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa73eddb6	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0xa74281a8	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0xa74d435e	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0xa74f4e9b	ida_simple_get
++EXPORT_SYMBOL vmlinux 0xa75e30b0	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0xa763167c	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0xa7713dbe	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0xa7733e18	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0xa777bbb9	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0xa7780c69	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0xa7849df9	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0xa78d9eb7	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0xa79d015a	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xa79fa724	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0xa7c050a3	bdgrab
++EXPORT_SYMBOL vmlinux 0xa7d3c67c	__frontswap_store
++EXPORT_SYMBOL vmlinux 0xa7e3062e	bd_set_size
++EXPORT_SYMBOL vmlinux 0xa7e37463	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0xa80cd111	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0xa80eb69f	km_is_alive
++EXPORT_SYMBOL vmlinux 0xa8135161	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0xa82c1018	lookup_one_len
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa8443cec	d_walk
++EXPORT_SYMBOL vmlinux 0xa84c19c8	dquot_initialize
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa8a9e652	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0xa8b46e4b	blkdev_get
++EXPORT_SYMBOL vmlinux 0xa8ced546	_lv1_net_set_interrupt_status_indicator
++EXPORT_SYMBOL vmlinux 0xa8d13d65	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0xa8dd4ee7	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa904562c	security_mmap_file
++EXPORT_SYMBOL vmlinux 0xa9158546	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa916b694	strnlen
++EXPORT_SYMBOL vmlinux 0xa91c77b6	_lv1_end_of_interrupt
++EXPORT_SYMBOL vmlinux 0xa91d90d3	nla_put
++EXPORT_SYMBOL vmlinux 0xa9220a25	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0xa9273e1a	epapr_hypercall_start
++EXPORT_SYMBOL vmlinux 0xa93ba88e	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0xa94dcf19	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0xa9602693	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0xa9739327	of_count_phandle_with_args
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa99b39c2	prandom_bytes
++EXPORT_SYMBOL vmlinux 0xa9a40a06	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0xa9b079c7	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9e0d3d6	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0xaa0edca8	pasemi_dma_alloc_fun
++EXPORT_SYMBOL vmlinux 0xaa46e87e	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0xaa4f0d2b	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0xaa66d4d6	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0xaa67d40a	sock_create_kern
++EXPORT_SYMBOL vmlinux 0xaa6e4df5	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa909b14	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0xaac2bca1	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xaac413e8	input_close_device
++EXPORT_SYMBOL vmlinux 0xaac6e3c6	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0xaacd8981	generic_permission
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab01426a	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0xab192652	inet_add_offload
++EXPORT_SYMBOL vmlinux 0xab1c7c38	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0xab1f74d3	freeze_bdev
++EXPORT_SYMBOL vmlinux 0xab228e31	csum_tcpudp_magic
++EXPORT_SYMBOL vmlinux 0xab2e47c0	rwsem_wake
++EXPORT_SYMBOL vmlinux 0xab2e869b	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0xab38d22a	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0xab66f611	_lv1_set_lpm_trigger_control
++EXPORT_SYMBOL vmlinux 0xab69c75b	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab84a841	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0xab86fa11	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xab8cb6a6	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0xabb3c18b	vme_bus_type
++EXPORT_SYMBOL vmlinux 0xabc06917	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabcc2e39	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0xabe14eae	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0xabf0a117	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac22531c	elevator_init
++EXPORT_SYMBOL vmlinux 0xac26b820	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0xac2b0571	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0xac34596b	path_get
++EXPORT_SYMBOL vmlinux 0xac3849e5	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0xac53e894	rtnl_notify
++EXPORT_SYMBOL vmlinux 0xac5b774f	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0xac688919	blk_make_request
++EXPORT_SYMBOL vmlinux 0xac72f423	param_array_ops
++EXPORT_SYMBOL vmlinux 0xac7cb480	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0xac84e9e1	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0xac972186	to_nd_btt
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacc5b5d2	csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacd14ab8	_lv1_construct_logical_spe
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xacf26bcc	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xad01744f	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad0a3c73	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0xad164875	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xad1b1524	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0xad2af0c8	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xad4690fe	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0xad4f7da8	__brelse
++EXPORT_SYMBOL vmlinux 0xad50cebb	i8253_lock
++EXPORT_SYMBOL vmlinux 0xad542bf5	param_get_string
++EXPORT_SYMBOL vmlinux 0xad6d9844	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0xad6ec8d5	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0xad716095	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad9500d5	fput
++EXPORT_SYMBOL vmlinux 0xad961743	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0xadb42a2d	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0xadbab878	thaw_bdev
++EXPORT_SYMBOL vmlinux 0xadcefeb6	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0xadecd1f8	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0xadeffe25	_lv1_gpu_context_intr
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xae005648	kill_block_super
++EXPORT_SYMBOL vmlinux 0xae132ee1	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0xae1472ff	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0xae22b84b	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0xae358236	fence_signal
++EXPORT_SYMBOL vmlinux 0xae38b66f	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0xae545f06	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xae65e6b3	compat_ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xae740dec	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0xae7ffe29	inet6_getname
++EXPORT_SYMBOL vmlinux 0xae9c6b7f	ata_print_version
++EXPORT_SYMBOL vmlinux 0xaee597d5	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0xaef379f6	framebuffer_release
++EXPORT_SYMBOL vmlinux 0xaf063510	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xaf2d872c	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf410bfe	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0xaf49a92f	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0xaf4d1d73	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0xaf69c2af	would_dump
++EXPORT_SYMBOL vmlinux 0xaf6ae696	kstrndup
++EXPORT_SYMBOL vmlinux 0xaf712c55	register_framebuffer
++EXPORT_SYMBOL vmlinux 0xaf7c84e5	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0xaf9340a7	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xafa61702	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0xafb0fd09	gen_pool_create
++EXPORT_SYMBOL vmlinux 0xafc35283	netif_device_attach
++EXPORT_SYMBOL vmlinux 0xafc72913	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0xafdb3988	phy_stop
++EXPORT_SYMBOL vmlinux 0xafff3d1d	mempool_alloc
++EXPORT_SYMBOL vmlinux 0xb0385b79	compat_sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0xb04241b4	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0xb053e9b0	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb07797df	scsi_execute
++EXPORT_SYMBOL vmlinux 0xb0838802	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0xb08e06a8	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0xb08f4ec3	of_get_next_child
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0b44f30	of_find_backlight_by_node
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0b89f5a	dst_release
++EXPORT_SYMBOL vmlinux 0xb0c4e061	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0xb0cc1cdc	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0xb0df2e77	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0e624f1	input_event
++EXPORT_SYMBOL vmlinux 0xb0ed1ea8	pci_request_region
++EXPORT_SYMBOL vmlinux 0xb0fd431c	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0xb1008529	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0xb10be83e	dcb_setapp
++EXPORT_SYMBOL vmlinux 0xb10ee51b	vmap
++EXPORT_SYMBOL vmlinux 0xb112ddf7	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb147a855	dql_reset
++EXPORT_SYMBOL vmlinux 0xb152dae5	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0xb15bd8fa	tb_ticks_per_sec
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb165ef45	__irq_regs
++EXPORT_SYMBOL vmlinux 0xb169ee38	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0xb16f3b03	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0xb17aacf4	bdi_destroy
++EXPORT_SYMBOL vmlinux 0xb17b2ae9	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0xb17bd5ba	param_get_charp
++EXPORT_SYMBOL vmlinux 0xb186b9f8	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1c6e787	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0xb1ce13ad	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1f0d89b	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0xb1f60dbb	input_inject_event
++EXPORT_SYMBOL vmlinux 0xb20460a6	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0xb20f85aa	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0xb2132aaa	mntget
++EXPORT_SYMBOL vmlinux 0xb22250fe	seq_pad
++EXPORT_SYMBOL vmlinux 0xb222c499	dev_printk
++EXPORT_SYMBOL vmlinux 0xb22fb24c	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0xb24c4cee	pcim_iomap
++EXPORT_SYMBOL vmlinux 0xb25d10bf	kvmppc_hv_find_lock_hpte
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb28795c0	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2c8b7c4	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xb2c967ff	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0xb2cfc7db	put_tty_driver
++EXPORT_SYMBOL vmlinux 0xb2d2d0f2	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0xb2ef2284	submit_bh
++EXPORT_SYMBOL vmlinux 0xb2fa458a	proc_set_size
++EXPORT_SYMBOL vmlinux 0xb3146eda	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0xb318aab9	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0xb3382494	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0xb350b475	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0xb352d6bd	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0xb37d5c38	genl_notify
++EXPORT_SYMBOL vmlinux 0xb37e9170	vio_cmo_set_dev_desired
++EXPORT_SYMBOL vmlinux 0xb3a0191d	bdi_init
++EXPORT_SYMBOL vmlinux 0xb3ab8d51	kernel_connect
++EXPORT_SYMBOL vmlinux 0xb3bf73df	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0xb3c7145e	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3d4c1c9	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb3fe4b63	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0xb4175c92	fb_class
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb4607bcb	fsync_bdev
++EXPORT_SYMBOL vmlinux 0xb4615d82	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb47189b5	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xb473e2c2	lockref_get
++EXPORT_SYMBOL vmlinux 0xb480deaa	kern_path
++EXPORT_SYMBOL vmlinux 0xb4858723	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0xb4c00cc8	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0xb4c9d5d1	sock_efree
++EXPORT_SYMBOL vmlinux 0xb4cb3064	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0xb4ebdb8f	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0xb51a2f32	current_fs_time
++EXPORT_SYMBOL vmlinux 0xb51eaa49	try_module_get
++EXPORT_SYMBOL vmlinux 0xb523bd7b	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0xb54cae0f	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0xb567f6e7	dquot_operations
++EXPORT_SYMBOL vmlinux 0xb56adc6e	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0xb56bfd9e	smu_spinwait_cmd
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb595c1b0	__find_get_block
++EXPORT_SYMBOL vmlinux 0xb599be15	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5b08265	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0xb5c14001	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0xb5d757e4	is_nvdimm_bus_locked
++EXPORT_SYMBOL vmlinux 0xb5e18449	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0xb5e76ae9	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0xb5ff0571	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0xb60ec777	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb639fdf8	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0xb63e5083	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0xb652fdb0	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0xb6577cf9	key_invalidate
++EXPORT_SYMBOL vmlinux 0xb6579f5d	seq_lseek
++EXPORT_SYMBOL vmlinux 0xb66d720e	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb68642b9	simple_setattr
++EXPORT_SYMBOL vmlinux 0xb68bfa9d	node_states
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb695ae89	sk_wait_data
++EXPORT_SYMBOL vmlinux 0xb69efed9	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6aa6bad	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0xb6d80753	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0xb6e12e7e	proto_unregister
++EXPORT_SYMBOL vmlinux 0xb6e8aa44	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0xb6eadf52	irq_to_desc
++EXPORT_SYMBOL vmlinux 0xb6f16c75	vio_disable_interrupts
++EXPORT_SYMBOL vmlinux 0xb6fb42da	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0xb6fcf6f2	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xb721a54f	__dst_free
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb74c1bdd	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb775f0ff	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0xb788217d	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0xb79e9368	of_find_net_device_by_node
++EXPORT_SYMBOL vmlinux 0xb7b4c69f	save_mount_options
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7de2bbe	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0xb7df9912	pci_get_device
++EXPORT_SYMBOL vmlinux 0xb7ecc9e3	netdev_emerg
++EXPORT_SYMBOL vmlinux 0xb7efcfd1	mmc_erase
++EXPORT_SYMBOL vmlinux 0xb7f094ca	udp_set_csum
++EXPORT_SYMBOL vmlinux 0xb8269c8e	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb8284f4a	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0xb8569d36	param_set_copystring
++EXPORT_SYMBOL vmlinux 0xb85c3973	nf_log_set
++EXPORT_SYMBOL vmlinux 0xb86123be	_lv1_write_repository_node
++EXPORT_SYMBOL vmlinux 0xb86206a1	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0xb862c94c	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0xb86fb45b	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb88182ee	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0xb883fd7b	vfs_statfs
++EXPORT_SYMBOL vmlinux 0xb8a30c7e	_lv1_add_lpm_event_bookmark
++EXPORT_SYMBOL vmlinux 0xb8a57a47	of_device_is_available
++EXPORT_SYMBOL vmlinux 0xb8ac3046	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0xb8e484fe	dev_change_flags
++EXPORT_SYMBOL vmlinux 0xb8fbedd0	__module_get
++EXPORT_SYMBOL vmlinux 0xb8fdb1a7	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xb9025612	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0xb907513f	unpoison_memory
++EXPORT_SYMBOL vmlinux 0xb91c6a07	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0xb930ee2b	elevator_change
++EXPORT_SYMBOL vmlinux 0xb94058ea	simple_open
++EXPORT_SYMBOL vmlinux 0xb9437b67	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0xb95c97a2	ps2_drain
++EXPORT_SYMBOL vmlinux 0xb96f68f5	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0xb99c04ec	__page_cache_alloc
++EXPORT_SYMBOL vmlinux 0xb9abcb98	get_tz_trend
++EXPORT_SYMBOL vmlinux 0xb9d0a32b	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0xb9e16921	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xb9f17b41	inode_change_ok
++EXPORT_SYMBOL vmlinux 0xb9fdcfc4	agp_generic_type_to_mask_type
++EXPORT_SYMBOL vmlinux 0xba06bb17	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0xba122a2c	smu_done_complete
++EXPORT_SYMBOL vmlinux 0xba2ffec2	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba4f2a79	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0xba698284	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0xba8a57e0	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0xba9c6990	dev_mc_add
++EXPORT_SYMBOL vmlinux 0xbabcfe0c	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0xbac37c1a	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0xbaf9811c	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb34134a	iov_shorten
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb38247d	scsi_add_device
++EXPORT_SYMBOL vmlinux 0xbb4f4766	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0xbb5c5f71	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb6ba119	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0xbb7aa27f	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0xbb825a0e	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xbb87bb37	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0xbb903710	skb_insert
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbba5ab99	force_sig
++EXPORT_SYMBOL vmlinux 0xbba5db59	fb_show_logo
++EXPORT_SYMBOL vmlinux 0xbbaeb559	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0xbbb09aad	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0xbbb1fd6b	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xbbb6b412	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xbbe4f554	bio_add_page
++EXPORT_SYMBOL vmlinux 0xbbe7fa06	tso_start
++EXPORT_SYMBOL vmlinux 0xbc1dd8e6	current_in_userns
++EXPORT_SYMBOL vmlinux 0xbc1e97c9	sk_dst_check
++EXPORT_SYMBOL vmlinux 0xbc316de4	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0xbc34578c	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0xbc49e6a0	tcp_prot
++EXPORT_SYMBOL vmlinux 0xbc4d4d76	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0xbc502792	dup_iter
++EXPORT_SYMBOL vmlinux 0xbc5cbc7b	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0xbc7c05d1	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0xbc8d24b7	con_is_bound
++EXPORT_SYMBOL vmlinux 0xbc94c9d8	filp_close
++EXPORT_SYMBOL vmlinux 0xbc982b06	eeh_subsystem_flags
++EXPORT_SYMBOL vmlinux 0xbca0a9b8	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0xbca3de02	unlock_buffer
++EXPORT_SYMBOL vmlinux 0xbca73c9d	tty_port_init
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcea2958	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0xbcf150f9	xor_altivec_5
++EXPORT_SYMBOL vmlinux 0xbd015b6b	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0xbd023e42	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0xbd22e8b5	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0xbd242dbc	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0xbd32dd6d	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0xbd462b55	__kfifo_init
++EXPORT_SYMBOL vmlinux 0xbd6d79f1	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0xbd782d2e	register_cdrom
++EXPORT_SYMBOL vmlinux 0xbd7e8d96	tso_build_data
++EXPORT_SYMBOL vmlinux 0xbd803510	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xbd893bf0	netlink_unicast
++EXPORT_SYMBOL vmlinux 0xbd8cfa15	pasemi_write_mac_reg
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbdc46592	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0xbdcda7ef	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0xbdcf2cde	__blk_end_request
++EXPORT_SYMBOL vmlinux 0xbde5ace8	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0xbde9fca4	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0xbdf951fd	nobh_write_end
++EXPORT_SYMBOL vmlinux 0xbe173221	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe295d5d	genphy_resume
++EXPORT_SYMBOL vmlinux 0xbe3d1cf5	file_open_root
++EXPORT_SYMBOL vmlinux 0xbe41af5e	of_phy_register_fixed_link
++EXPORT_SYMBOL vmlinux 0xbe43874e	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xbe4bccd2	pnv_phb_to_cxl_mode
++EXPORT_SYMBOL vmlinux 0xbe544d83	f_setown
++EXPORT_SYMBOL vmlinux 0xbe5e14b2	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0xbe619f38	phy_disconnect
++EXPORT_SYMBOL vmlinux 0xbe6f610a	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0xbe87be68	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0xbe94800a	macio_request_resource
++EXPORT_SYMBOL vmlinux 0xbe957de3	of_find_node_by_type
++EXPORT_SYMBOL vmlinux 0xbe9ce56e	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0xbecf9289	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0xbed74e28	d_move
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbef674da	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0xbf020f02	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0xbf0399f2	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0xbf078e41	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0xbf1e2d33	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0xbf243dcd	of_scan_pci_bridge
++EXPORT_SYMBOL vmlinux 0xbf4fbd1b	dev_get_stats
++EXPORT_SYMBOL vmlinux 0xbf64e9af	neigh_update
++EXPORT_SYMBOL vmlinux 0xbf69cd8e	of_get_child_by_name
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf925c42	idr_init
++EXPORT_SYMBOL vmlinux 0xbf954224	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbf9eb0f2	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0xbfabfe59	__debugger_iabr_match
++EXPORT_SYMBOL vmlinux 0xbfaf38ae	file_ns_capable
++EXPORT_SYMBOL vmlinux 0xbfb8b0b7	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xbfbb7629	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0xbfc177bc	iowrite32_rep
++EXPORT_SYMBOL vmlinux 0xbfd98256	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xbff45f75	__skb_checksum
++EXPORT_SYMBOL vmlinux 0xbff8182c	plpar_hcall_norets
++EXPORT_SYMBOL vmlinux 0xc0036eb4	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0xc019f804	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0xc01b4865	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0xc043280e	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0xc055d10e	__d_drop
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc0930ff7	padata_alloc
++EXPORT_SYMBOL vmlinux 0xc09680da	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0a7869d	module_put
++EXPORT_SYMBOL vmlinux 0xc0aadfb3	iterate_dir
++EXPORT_SYMBOL vmlinux 0xc0ada701	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0xc0c819e6	drop_nlink
++EXPORT_SYMBOL vmlinux 0xc0e3dd40	netif_skb_features
++EXPORT_SYMBOL vmlinux 0xc0f6f5f0	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xc0fe223c	tty_port_put
++EXPORT_SYMBOL vmlinux 0xc1039619	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0xc106a11f	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0xc13511d7	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0xc13a10dc	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0xc1433573	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0xc15a44c6	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xc1825575	mac_find_mode
++EXPORT_SYMBOL vmlinux 0xc1888d00	simple_empty
++EXPORT_SYMBOL vmlinux 0xc18929f4	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0xc18d9acb	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0xc1a892ee	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0xc1b71b40	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0xc1bbfb23	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0xc1cab284	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc20e05cb	serio_reconnect
++EXPORT_SYMBOL vmlinux 0xc210b882	udp_disconnect
++EXPORT_SYMBOL vmlinux 0xc2336ab4	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0xc2424641	agp3_generic_cleanup
++EXPORT_SYMBOL vmlinux 0xc2555521	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0xc2767bdf	dput
++EXPORT_SYMBOL vmlinux 0xc2780a31	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xc28db402	new_inode
++EXPORT_SYMBOL vmlinux 0xc29bf967	strspn
++EXPORT_SYMBOL vmlinux 0xc29c9ad3	inet6_release
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2a9d429	elevator_exit
++EXPORT_SYMBOL vmlinux 0xc2ae2c07	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0xc2af3120	nla_append
++EXPORT_SYMBOL vmlinux 0xc2b8e412	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0xc2c19448	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0xc2c62190	inet_bind
++EXPORT_SYMBOL vmlinux 0xc2d94827	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc2e5d613	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0xc2fb9ee1	_lv1_shutdown_logical_partition
++EXPORT_SYMBOL vmlinux 0xc30a365d	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0xc310b981	strnstr
++EXPORT_SYMBOL vmlinux 0xc31b485b	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0xc3238c27	phy_init_hw
++EXPORT_SYMBOL vmlinux 0xc36b18fb	bdget
++EXPORT_SYMBOL vmlinux 0xc3bb01af	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3c47924	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0xc3d2550e	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0xc3d556a0	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0xc41f1696	_lv1_configure_virtual_uart_irq
++EXPORT_SYMBOL vmlinux 0xc44d5972	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0xc44f83f3	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xc45755de	find_next_zero_bit_le
++EXPORT_SYMBOL vmlinux 0xc46e803e	generic_fillattr
++EXPORT_SYMBOL vmlinux 0xc4736351	get_gendisk
++EXPORT_SYMBOL vmlinux 0xc47cdf9c	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0xc48307db	lz4_decompress
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4a0be24	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0xc4a4cd81	put_disk
++EXPORT_SYMBOL vmlinux 0xc4ca9d7f	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0xc4faf586	of_find_compatible_node
++EXPORT_SYMBOL vmlinux 0xc5021253	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0xc5089620	_lv1_stop_ppe_periodic_tracer
++EXPORT_SYMBOL vmlinux 0xc52fdfa1	param_set_bool
++EXPORT_SYMBOL vmlinux 0xc5382998	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0xc545cb7d	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xc5534d64	ioread16
++EXPORT_SYMBOL vmlinux 0xc555f4de	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0xc55de23c	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0xc567acd7	vme_register_driver
++EXPORT_SYMBOL vmlinux 0xc568a19e	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0xc5969e5e	__napi_complete
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc5c20d14	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0xc5c6f5c3	request_firmware
++EXPORT_SYMBOL vmlinux 0xc5cfbd7e	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0xc5d9c46c	agp_try_unsupported_boot
++EXPORT_SYMBOL vmlinux 0xc5e0bac8	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0xc5e10741	bio_map_kern
++EXPORT_SYMBOL vmlinux 0xc5f984c5	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc60880bc	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0xc6193876	vga_tryget
++EXPORT_SYMBOL vmlinux 0xc6232348	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc6341b6b	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0xc63784dc	sock_from_file
++EXPORT_SYMBOL vmlinux 0xc65abeb7	agp3_generic_sizes
++EXPORT_SYMBOL vmlinux 0xc663b075	__ioremap
++EXPORT_SYMBOL vmlinux 0xc666a132	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xc66d4285	of_graph_get_remote_port_parent
++EXPORT_SYMBOL vmlinux 0xc6772da2	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xc69223fe	mount_bdev
++EXPORT_SYMBOL vmlinux 0xc69d6961	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0xc6acd390	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0xc6b22c71	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0xc6cb465a	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6d3020e	get_cached_acl
++EXPORT_SYMBOL vmlinux 0xc6d54d4e	of_get_ibm_chip_id
++EXPORT_SYMBOL vmlinux 0xc6ecf70a	dma_set_coherent_mask
++EXPORT_SYMBOL vmlinux 0xc6f24f0f	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc7591cf0	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0xc7664fdd	__netif_schedule
++EXPORT_SYMBOL vmlinux 0xc768f712	skb_store_bits
++EXPORT_SYMBOL vmlinux 0xc7697a03	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc7898275	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0xc795f609	qdisc_reset
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7cbd0c2	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0xc7cde595	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0xc7e2afbe	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0xc7f39b15	irq_stat
++EXPORT_SYMBOL vmlinux 0xc81c2411	cdev_alloc
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc83f5cfc	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xc84298d4	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc84a274f	_dev_info
++EXPORT_SYMBOL vmlinux 0xc8571bcb	idr_for_each
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc8863e47	blk_put_request
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8b47c9d	get_super_thawed
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8bf7748	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0xc8d5aa60	nd_integrity_init
++EXPORT_SYMBOL vmlinux 0xc8e2a85d	of_graph_get_next_endpoint
++EXPORT_SYMBOL vmlinux 0xc8e31d75	_lv1_configure_irq_state_bitmap
++EXPORT_SYMBOL vmlinux 0xc8e3e28c	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0xc8fa8ab8	secpath_dup
++EXPORT_SYMBOL vmlinux 0xc900720b	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc9346ed2	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0xc93fbc54	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xc95cbc18	genphy_suspend
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc978479a	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc9a1a959	pnv_cxl_alloc_hwirq_ranges
++EXPORT_SYMBOL vmlinux 0xc9be1505	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0xc9edf615	iunique
++EXPORT_SYMBOL vmlinux 0xc9fc598d	pasemi_read_dma_reg
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca158dea	inet_select_addr
++EXPORT_SYMBOL vmlinux 0xca2226e9	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0xca2b1cd6	ida_pre_get
++EXPORT_SYMBOL vmlinux 0xca2e89d3	pmac_resume_agp_for_card
++EXPORT_SYMBOL vmlinux 0xca38a632	dm_get_device
++EXPORT_SYMBOL vmlinux 0xca39f38a	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0xca3b28c6	store_vr_state
++EXPORT_SYMBOL vmlinux 0xca48ade7	nvdimm_bus_unlock
++EXPORT_SYMBOL vmlinux 0xca524043	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0xca5ee09a	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0xca825895	pmu_suspend
++EXPORT_SYMBOL vmlinux 0xca832efe	kmalloc_order
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xcaabf3f9	pasemi_write_iob_reg
++EXPORT_SYMBOL vmlinux 0xcab24a8e	done_path_create
++EXPORT_SYMBOL vmlinux 0xcabb634c	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0xcac0d40b	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0xcac1be2c	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0xcac5e93e	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0xcac98b4f	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0xcace6297	idr_is_empty
++EXPORT_SYMBOL vmlinux 0xcad5d45b	input_allocate_device
++EXPORT_SYMBOL vmlinux 0xcadfb521	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcaf2cd91	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb0fcfd1	send_sig
++EXPORT_SYMBOL vmlinux 0xcb178121	truncate_setsize
++EXPORT_SYMBOL vmlinux 0xcb2124cb	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0xcb4ac4d9	mpage_readpage
++EXPORT_SYMBOL vmlinux 0xcb936989	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcbb25e9f	cdev_del
++EXPORT_SYMBOL vmlinux 0xcbbb509f	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbbf13ca	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xcbc3b94e	eeh_check_failure
++EXPORT_SYMBOL vmlinux 0xcbc3eb70	agp_alloc_page_array
++EXPORT_SYMBOL vmlinux 0xcbc59375	of_create_pci_dev
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbcb437e	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0xcbd3d7ef	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xcbdbbd27	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0xcbe8b038	_lv1_configure_execution_time_variable
++EXPORT_SYMBOL vmlinux 0xcbf40bac	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0xcbf52d66	console_stop
++EXPORT_SYMBOL vmlinux 0xcbff03a0	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0xcc05fb4a	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0xcc17504d	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc24e60e	blk_start_queue
++EXPORT_SYMBOL vmlinux 0xcc279864	param_set_bint
++EXPORT_SYMBOL vmlinux 0xcc2ee6bf	md_error
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc5cd24e	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0xcc7b849a	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0xcc874861	kern_unmount
++EXPORT_SYMBOL vmlinux 0xcc89c246	pasemi_dma_alloc_chan
++EXPORT_SYMBOL vmlinux 0xcca889ec	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0xccb1a0b4	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0xccb8ec22	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0xccbd41fc	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0xccbe17f0	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccd57781	param_get_byte
++EXPORT_SYMBOL vmlinux 0xccea6b0e	ping_prot
++EXPORT_SYMBOL vmlinux 0xccfdf867	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0xcd0529c7	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0xcd0ebd99	release_sock
++EXPORT_SYMBOL vmlinux 0xcd1e5c84	ps2_init
++EXPORT_SYMBOL vmlinux 0xcd20667a	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0xcd2521a6	elv_rb_find
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd2bee75	vfs_create
++EXPORT_SYMBOL vmlinux 0xcd2eba40	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0xcd469d97	of_get_named_gpio_flags
++EXPORT_SYMBOL vmlinux 0xcd57f7b0	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0xcd769f62	_lv1_gpu_device_map
++EXPORT_SYMBOL vmlinux 0xcd7e9feb	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0xcd7ede2a	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xcd86c87f	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0xcda9a830	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdc8dfc9	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0xcddae707	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0xcdea331e	pci_release_region
++EXPORT_SYMBOL vmlinux 0xce0e2d66	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce2c5463	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xce3319ca	read_cache_page
++EXPORT_SYMBOL vmlinux 0xce3977f1	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0xce3b3f09	profile_pc
++EXPORT_SYMBOL vmlinux 0xce409cda	pmac_set_early_video_resume
++EXPORT_SYMBOL vmlinux 0xce4e47b6	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce72bc88	irq_set_chip
++EXPORT_SYMBOL vmlinux 0xce7850e1	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xceae504f	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0xced777cb	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0xced94771	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0xceeb338e	of_device_alloc
++EXPORT_SYMBOL vmlinux 0xcef4351f	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf39990e	skb_pad
++EXPORT_SYMBOL vmlinux 0xcf47133a	address_space_init_once
++EXPORT_SYMBOL vmlinux 0xcf524a4e	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0xcf5661e9	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0xcf93f38c	inet_accept
++EXPORT_SYMBOL vmlinux 0xcf9fc680	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0xcfaa7aff	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0xcfb7d5a0	cpu_sibling_map
++EXPORT_SYMBOL vmlinux 0xd0182b7f	tcp_poll
++EXPORT_SYMBOL vmlinux 0xd03ef676	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0xd057e49c	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0xd05931ec	_lv1_set_lpm_counter_control
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd08f6239	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0befa47	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0xd0c8ba6d	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0xd0cf99b6	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0xd0da7b95	nf_log_packet
++EXPORT_SYMBOL vmlinux 0xd0e54aeb	clear_nlink
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fef3b2	agp_free_key
++EXPORT_SYMBOL vmlinux 0xd1262886	rtas_data_buf
++EXPORT_SYMBOL vmlinux 0xd14691f2	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xd152ab2b	powerpc_debugfs_root
++EXPORT_SYMBOL vmlinux 0xd15c5431	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd178ff70	vm_stat
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd1818772	param_ops_charp
++EXPORT_SYMBOL vmlinux 0xd18dedc0	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0xd1c25455	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1fce011	phy_driver_register
++EXPORT_SYMBOL vmlinux 0xd1fd075e	blk_init_queue
++EXPORT_SYMBOL vmlinux 0xd1fe8ebb	_lv1_get_spe_interrupt_status
++EXPORT_SYMBOL vmlinux 0xd2156682	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0xd21a25bc	arp_tbl
++EXPORT_SYMBOL vmlinux 0xd2352aee	compat_tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0xd24101e7	km_policy_notify
++EXPORT_SYMBOL vmlinux 0xd2440b43	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0xd2483b5a	touch_atime
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd2566fc0	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd2736e45	tty_devnum
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd28d3603	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0xd2ac911f	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0xd2aff6e2	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xd2b09ce5	__kmalloc
++EXPORT_SYMBOL vmlinux 0xd2b6a6dc	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xd2cbb000	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0xd2d0af4e	ip6_xmit
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2ef2638	smu_cmdbuf_abs
++EXPORT_SYMBOL vmlinux 0xd2efc074	ibmebus_register_driver
++EXPORT_SYMBOL vmlinux 0xd2fcc613	agp_generic_destroy_pages
++EXPORT_SYMBOL vmlinux 0xd313de85	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xd31ccb06	of_machine_is_compatible
++EXPORT_SYMBOL vmlinux 0xd345a7db	pci_find_bus
++EXPORT_SYMBOL vmlinux 0xd34748c0	inet6_bind
++EXPORT_SYMBOL vmlinux 0xd3552100	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0xd36e3d59	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0xd373a967	sock_rfree
++EXPORT_SYMBOL vmlinux 0xd37e6bda	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0xd38ef809	security_path_rename
++EXPORT_SYMBOL vmlinux 0xd39d79fc	simple_link
++EXPORT_SYMBOL vmlinux 0xd3a9636d	to_ndd
++EXPORT_SYMBOL vmlinux 0xd3b01dc9	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3c0430d	phy_device_free
++EXPORT_SYMBOL vmlinux 0xd3da32b5	pci_find_capability
++EXPORT_SYMBOL vmlinux 0xd409383c	pmu_request
++EXPORT_SYMBOL vmlinux 0xd40a7c5c	proc_create_data
++EXPORT_SYMBOL vmlinux 0xd4126864	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0xd41b9c8f	mmc_add_host
++EXPORT_SYMBOL vmlinux 0xd43464fe	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0xd43f15d0	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0xd44b61c2	param_set_byte
++EXPORT_SYMBOL vmlinux 0xd44b7e21	to_tm
++EXPORT_SYMBOL vmlinux 0xd44cb026	seq_dentry
++EXPORT_SYMBOL vmlinux 0xd45cc6ca	bin2hex
++EXPORT_SYMBOL vmlinux 0xd48dc22a	input_register_device
++EXPORT_SYMBOL vmlinux 0xd48fdeef	dql_completed
++EXPORT_SYMBOL vmlinux 0xd4a22978	inet_listen
++EXPORT_SYMBOL vmlinux 0xd4a2c466	generic_setlease
++EXPORT_SYMBOL vmlinux 0xd4d405cb	vio_enable_interrupts
++EXPORT_SYMBOL vmlinux 0xd4f8ead7	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0xd5084a4e	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0xd520d6c9	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0xd5302c0c	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0xd532e3e3	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0xd548f918	udp_ioctl
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd55509db	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0xd55aace9	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0xd5649976	seq_printf
++EXPORT_SYMBOL vmlinux 0xd576a6eb	param_set_ulong
++EXPORT_SYMBOL vmlinux 0xd588b8be	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd59b1db2	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0xd5b9795e	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0xd5bed37d	__bread_gfp
++EXPORT_SYMBOL vmlinux 0xd5c27292	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xd5e1d719	_lv1_set_ppe_periodic_tracer_frequency
++EXPORT_SYMBOL vmlinux 0xd5e8a566	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0xd5f2098d	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0xd60aa968	tcp_req_err
++EXPORT_SYMBOL vmlinux 0xd60f331b	dquot_enable
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd619dbec	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0xd626a30f	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0xd626a78a	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd65d3015	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0xd6605c87	__get_page_tail
++EXPORT_SYMBOL vmlinux 0xd668b827	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0xd683e40d	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0xd684e97f	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd68c2bc7	genphy_read_status
++EXPORT_SYMBOL vmlinux 0xd69c163d	unlock_rename
++EXPORT_SYMBOL vmlinux 0xd6a11cd5	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0xd6a663b4	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0xd6ad631d	agp_generic_free_gatt_table
++EXPORT_SYMBOL vmlinux 0xd6d63e9d	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0xd6e2472c	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0xd6edf811	_lv1_release_memory
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd6fd4053	__arch_hweight32
++EXPORT_SYMBOL vmlinux 0xd72e1cfc	_lv1_set_lpm_spr_trigger
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd761a383	ioremap_prot
++EXPORT_SYMBOL vmlinux 0xd786c0ea	plpar_hcall9
++EXPORT_SYMBOL vmlinux 0xd790db72	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0xd7b059fb	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0xd7c66ada	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7e6ed71	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd834f992	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0xd84b7b7e	nf_log_register
++EXPORT_SYMBOL vmlinux 0xd87ba302	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0xd884898d	dquot_commit
++EXPORT_SYMBOL vmlinux 0xd88e0840	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8b3dcd6	get_task_io_context
++EXPORT_SYMBOL vmlinux 0xd8cf0e8b	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e14185	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd8e83d9f	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0xd9083ba1	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0xd94879f2	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0xd94fdcd5	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd9a75219	set_page_dirty
++EXPORT_SYMBOL vmlinux 0xd9b294e5	netdev_err
++EXPORT_SYMBOL vmlinux 0xd9bac924	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0xd9ce1e1c	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0xd9d4d09d	_lv1_release_io_segment
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xda0f5234	rtas_offline_cpus_mask
++EXPORT_SYMBOL vmlinux 0xda3572c8	__check_sticky
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda4eae81	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0xda4ebdbc	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0xda6b8966	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda9fc7ae	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0xdaa258f0	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0xdab6c3f1	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0xdabc1ea8	fsl_lbc_find
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdac545b9	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0xdac668eb	bioset_free
++EXPORT_SYMBOL vmlinux 0xdac8af79	do_splice_direct
++EXPORT_SYMBOL vmlinux 0xdaea6e0d	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0xdb01198e	fsl_upm_find
++EXPORT_SYMBOL vmlinux 0xdb0e706f	__vfs_write
++EXPORT_SYMBOL vmlinux 0xdb0fd7d1	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0xdb25b01d	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0xdb3ada06	skb_clone
++EXPORT_SYMBOL vmlinux 0xdb3bcca6	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0xdb4ef657	eth_header_cache
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdbb6e50d	skb_split
++EXPORT_SYMBOL vmlinux 0xdbbc3bfd	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0xdbd12831	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0xdbe5afaf	console_start
++EXPORT_SYMBOL vmlinux 0xdbeba658	blk_start_request
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc0cf9e9	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc214961	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0xdc33b54d	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0xdc3c41a8	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdc555c7e	dev_add_pack
++EXPORT_SYMBOL vmlinux 0xdc801844	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0xdc8b0ee9	__seq_open_private
++EXPORT_SYMBOL vmlinux 0xdc9498dd	down
++EXPORT_SYMBOL vmlinux 0xdc9c732f	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdcb764ad	memset
++EXPORT_SYMBOL vmlinux 0xdcd0f56a	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0xdcdd2fa5	find_get_entry
++EXPORT_SYMBOL vmlinux 0xdcefb9a5	pmu_resume
++EXPORT_SYMBOL vmlinux 0xdcf83de1	file_path
++EXPORT_SYMBOL vmlinux 0xdcfab228	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0xdd179c3a	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0xdd254e76	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0xdd31e908	phy_connect
++EXPORT_SYMBOL vmlinux 0xdd3a3f8f	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0xdd3cce04	ibmebus_bus_type
++EXPORT_SYMBOL vmlinux 0xdd476c72	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0xdd64e639	strscpy
++EXPORT_SYMBOL vmlinux 0xdd68a817	mmc_request_done
++EXPORT_SYMBOL vmlinux 0xdd6d5adc	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0xdd748fc8	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0xdd9030af	current_stack_pointer
++EXPORT_SYMBOL vmlinux 0xdd955144	__debugger
++EXPORT_SYMBOL vmlinux 0xdd9a5fa2	put_cmsg
++EXPORT_SYMBOL vmlinux 0xddab064f	install_exec_creds
++EXPORT_SYMBOL vmlinux 0xddb3769b	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0xddc852b2	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0xddc9a228	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0xddd2829a	pci_map_rom
++EXPORT_SYMBOL vmlinux 0xddd6f59d	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0xddf2b029	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0xde0ba05a	setup_new_exec
++EXPORT_SYMBOL vmlinux 0xde14c615	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0xde413837	devm_request_resource
++EXPORT_SYMBOL vmlinux 0xde48e9ca	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0xde6151db	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xde783883	pSeries_disable_reloc_on_exc
++EXPORT_SYMBOL vmlinux 0xde91448c	load_vr_state
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde9b17ed	agp3_generic_fetch_size
++EXPORT_SYMBOL vmlinux 0xdea1be1c	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xdeaff2b1	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0xdec86c38	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0xdee40cc8	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0xdef707b4	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0xdf11216a	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf3bc01c	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0xdf3c81d7	blk_peek_request
++EXPORT_SYMBOL vmlinux 0xdf4f01ad	__register_nls
++EXPORT_SYMBOL vmlinux 0xdf53b72f	single_open
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf58203b	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf60fc83	_lv1_net_start_tx_dma
++EXPORT_SYMBOL vmlinux 0xdf6a676e	alloc_pages_current
++EXPORT_SYMBOL vmlinux 0xdf837c93	__invalidate_device
++EXPORT_SYMBOL vmlinux 0xdf8868d9	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdfa4ad43	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0xdfb220d4	md_check_recovery
++EXPORT_SYMBOL vmlinux 0xdfb93ab3	inet6_protos
++EXPORT_SYMBOL vmlinux 0xdfbd82f4	eth_header_parse
++EXPORT_SYMBOL vmlinux 0xdfc41c2a	phy_device_remove
++EXPORT_SYMBOL vmlinux 0xdfc49cb3	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xdfe8602a	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xe00dc563	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0xe00ecffe	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0xe0391863	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0xe04f76c4	sys_imageblit
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe0511485	flush_icache_user_range
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe084713c	of_find_i2c_device_by_node
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe0a1f01c	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0b3182c	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0xe0c2c35b	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0xe0ca3fe2	put_io_context
++EXPORT_SYMBOL vmlinux 0xe0ddd2ae	agp_generic_alloc_page
++EXPORT_SYMBOL vmlinux 0xe104df4a	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe1432f4b	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0xe14cc604	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe1918dea	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0xe198d049	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0xe1a8e045	of_find_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0xe1b4dcdf	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0xe1b79853	__inode_permission
++EXPORT_SYMBOL vmlinux 0xe1ca0891	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0xe1ce355e	d_find_alias
++EXPORT_SYMBOL vmlinux 0xe1cfdf8c	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0xe1e68ab8	pipe_lock
++EXPORT_SYMBOL vmlinux 0xe1e72e10	register_filesystem
++EXPORT_SYMBOL vmlinux 0xe1f713b0	skb_copy
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe20372ae	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0xe20c63e7	_lv1_unmap_device_mmio_region
++EXPORT_SYMBOL vmlinux 0xe220ceb8	__debugger_sstep
++EXPORT_SYMBOL vmlinux 0xe2300de8	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL vmlinux 0xe233dc57	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0xe2350ea5	unload_nls
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe23d0219	loop_backing_file
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe255cea4	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0xe25ce334	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0xe27093e9	kfree_put_link
++EXPORT_SYMBOL vmlinux 0xe2793590	agp_allocate_memory
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe29e4870	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0xe2a7eb0a	fb_set_var
++EXPORT_SYMBOL vmlinux 0xe2a9d092	proc_mkdir
++EXPORT_SYMBOL vmlinux 0xe2be5498	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0xe2cc637f	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2dc5916	follow_up
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe3039b3d	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0xe317764d	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0xe31b0933	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0xe3258e78	sock_wfree
++EXPORT_SYMBOL vmlinux 0xe3263657	netdev_crit
++EXPORT_SYMBOL vmlinux 0xe338be47	dump_emit
++EXPORT_SYMBOL vmlinux 0xe351ef92	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0xe3703abb	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0xe371bdb6	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0xe3a53f4c	sort
++EXPORT_SYMBOL vmlinux 0xe3ac81c2	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3ce4d7f	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3e5d453	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0xe4001b2d	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0xe40cb24e	sock_no_listen
++EXPORT_SYMBOL vmlinux 0xe41a9a02	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xe41d94e9	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0xe436c402	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0xe455b305	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0xe457b897	kernel_write
++EXPORT_SYMBOL vmlinux 0xe461e499	proto_register
++EXPORT_SYMBOL vmlinux 0xe47ebc5b	mount_single
++EXPORT_SYMBOL vmlinux 0xe484e35f	ioread32
++EXPORT_SYMBOL vmlinux 0xe486ec35	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0xe48e1a60	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0xe4a247ee	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0xe4ae6571	devm_memunmap
++EXPORT_SYMBOL vmlinux 0xe4b5bbf3	inet_release
++EXPORT_SYMBOL vmlinux 0xe4c28251	ata_link_printk
++EXPORT_SYMBOL vmlinux 0xe4d0f803	generic_listxattr
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe4eaab2e	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0xe4ee068a	block_write_end
++EXPORT_SYMBOL vmlinux 0xe4f10870	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0xe4fe8ca1	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xe50e63e0	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0xe50f674e	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xe5158449	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0xe51b707e	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0xe5204ae5	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe5293d97	input_release_device
++EXPORT_SYMBOL vmlinux 0xe52b7833	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0xe54e8cc9	pci_domain_nr
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe58f5575	of_find_node_with_property
++EXPORT_SYMBOL vmlinux 0xe594043e	register_md_personality
++EXPORT_SYMBOL vmlinux 0xe5b6bbf5	compat_nf_getsockopt
++EXPORT_SYMBOL vmlinux 0xe5c2dcc0	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5d1083a	proc_symlink
++EXPORT_SYMBOL vmlinux 0xe5d6f9d5	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0xe5da3cf1	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0xe5db5569	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe60988ac	_lv1_query_logical_partition_address_region_info
++EXPORT_SYMBOL vmlinux 0xe64452dc	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0xe6516ead	noop_llseek
++EXPORT_SYMBOL vmlinux 0xe65a73d7	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xe65d4af8	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0xe66cc73f	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xe66f2803	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0xe671312d	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe69a9df4	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xe6b0343d	xfrm_input
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe6fd76a5	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0xe719a51d	pnv_pci_get_phb_node
++EXPORT_SYMBOL vmlinux 0xe74aa406	_lv1_set_dabr
++EXPORT_SYMBOL vmlinux 0xe74ba8d3	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xe74edd29	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0xe75bc19d	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0xe7632f9f	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0xe76f0c39	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0xe770c755	lock_rename
++EXPORT_SYMBOL vmlinux 0xe7869b6a	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0xe78b38f5	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0xe7a23c40	mntput
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7a8fc99	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0xe7ab1c21	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0xe7c4d083	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0xe7ca664c	of_get_address
++EXPORT_SYMBOL vmlinux 0xe7cd99b7	smu_queue_simple
++EXPORT_SYMBOL vmlinux 0xe7ce7439	_memcpy_fromio
++EXPORT_SYMBOL vmlinux 0xe7d1101c	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7ea60cd	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0xe7ec8ddf	deactivate_super
++EXPORT_SYMBOL vmlinux 0xe7f03745	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0xe7f1bdb5	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0xe7f58bb1	kill_bdev
++EXPORT_SYMBOL vmlinux 0xe812d48b	block_write_begin
++EXPORT_SYMBOL vmlinux 0xe81ef1dd	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe82cc752	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0xe8351c0f	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0xe8456d9b	PDE_DATA
++EXPORT_SYMBOL vmlinux 0xe876285d	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8c438f3	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0xe8c4894a	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0xe8c82453	nvm_end_io
++EXPORT_SYMBOL vmlinux 0xe8cf8b37	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0xe8ec39ce	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0xe8ef0ff0	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0xe8f73b7e	devm_release_resource
++EXPORT_SYMBOL vmlinux 0xe8fb450e	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe91ff02e	agp_generic_enable
++EXPORT_SYMBOL vmlinux 0xe92bcdf3	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0xe9320988	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0xe9378d58	idr_get_next
++EXPORT_SYMBOL vmlinux 0xe944848a	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xe947531a	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0xe94bed35	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe95b4d22	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0xe98987b3	tty_name
++EXPORT_SYMBOL vmlinux 0xe98c5c03	set_anon_super
++EXPORT_SYMBOL vmlinux 0xe99e5387	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0xe9aecdbc	skb_append
++EXPORT_SYMBOL vmlinux 0xe9b3062b	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0xe9bc0e7e	scsi_host_get
++EXPORT_SYMBOL vmlinux 0xe9c50ac8	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0xe9d16264	param_ops_int
++EXPORT_SYMBOL vmlinux 0xe9d4f9a4	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0xe9e55a4d	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xe9f90588	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0xea0376f7	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea1557d3	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0xea39439c	giveup_fpu
++EXPORT_SYMBOL vmlinux 0xea3b2024	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0xea44bce1	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0xea73f2fd	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0xea7a42f9	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xea7a688f	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0xea878837	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0xea968c96	___ratelimit
++EXPORT_SYMBOL vmlinux 0xeaade534	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0xeaaf8d41	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0xeacd4761	of_platform_bus_probe
++EXPORT_SYMBOL vmlinux 0xead51c58	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0xeaf8253b	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb3b39a9	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0xeb3e2d0e	kobject_set_name
++EXPORT_SYMBOL vmlinux 0xeb44339a	free_pages_exact
++EXPORT_SYMBOL vmlinux 0xeb4757c8	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0xeb5e1923	pci_dev_get
++EXPORT_SYMBOL vmlinux 0xeb66e2ee	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0xeb68dc73	nvdimm_namespace_capacity
++EXPORT_SYMBOL vmlinux 0xeb7ad2e9	ps2_command
++EXPORT_SYMBOL vmlinux 0xeb8c7b7b	cxl_use_count
++EXPORT_SYMBOL vmlinux 0xeb924c13	ata_port_printk
++EXPORT_SYMBOL vmlinux 0xeb993aa0	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0xeb9b3581	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0xeba2a1f7	rtas_indicator_present
++EXPORT_SYMBOL vmlinux 0xeba47d25	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xebcab3a6	ppc_pci_io
++EXPORT_SYMBOL vmlinux 0xebe727ab	inode_init_once
++EXPORT_SYMBOL vmlinux 0xebf1de4e	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0xec2aafc2	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0xec30765a	_lv1_allocate_io_segment
++EXPORT_SYMBOL vmlinux 0xec3677c1	dquot_drop
++EXPORT_SYMBOL vmlinux 0xec8e1c98	skb_make_writable
++EXPORT_SYMBOL vmlinux 0xecab279c	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0xecbb2818	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0xecbb926f	xor_altivec_3
++EXPORT_SYMBOL vmlinux 0xecc42c3e	param_get_ulong
++EXPORT_SYMBOL vmlinux 0xeccecdce	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0xecd982a2	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xed0539b7	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0xed09a48e	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0xed0b7040	dcache_readdir
++EXPORT_SYMBOL vmlinux 0xed3dc278	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0xed44ca82	down_write
++EXPORT_SYMBOL vmlinux 0xed471735	pci_disable_device
++EXPORT_SYMBOL vmlinux 0xed4aa346	vio_get_attribute
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed646b57	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0xed652427	_lv1_set_interrupt_mask
++EXPORT_SYMBOL vmlinux 0xed758dd5	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0xed880c03	mmc_release_host
++EXPORT_SYMBOL vmlinux 0xed8be92f	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0xed8fd1a8	ip_options_compile
++EXPORT_SYMBOL vmlinux 0xed9f0ce8	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xeda22212	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0xedac555d	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedc410d0	udplite_table
++EXPORT_SYMBOL vmlinux 0xedcf1aa4	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0xedea8969	write_one_page
++EXPORT_SYMBOL vmlinux 0xedef44c5	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0xedf0b48c	_lv1_storage_get_async_status
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xee0bab12	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0xee19db40	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0xee22876c	inet_getname
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee31a89d	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0xee3e5e4e	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xee5bb20b	_lv1_panic
++EXPORT_SYMBOL vmlinux 0xee75633d	kobject_add
++EXPORT_SYMBOL vmlinux 0xee86ea9b	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0xee9174c5	_lv1_storage_read
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xee93656a	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0xee9a26d1	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0xeea3cd7a	nla_reserve
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeeb83040	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0xeedda7d7	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0xeeec26e5	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xef04f336	dev_driver_string
++EXPORT_SYMBOL vmlinux 0xef0ce4b8	find_lock_entry
++EXPORT_SYMBOL vmlinux 0xef143e1b	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0xef35987c	sock_create_lite
++EXPORT_SYMBOL vmlinux 0xef39bd8f	dquot_disable
++EXPORT_SYMBOL vmlinux 0xef41dfa1	unregister_key_type
++EXPORT_SYMBOL vmlinux 0xef9ded23	genlmsg_put
++EXPORT_SYMBOL vmlinux 0xefaaff0a	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xefac6b7e	make_kprojid
++EXPORT_SYMBOL vmlinux 0xefaeffa9	__ps2_command
++EXPORT_SYMBOL vmlinux 0xefafa412	pmac_register_agp_pm
++EXPORT_SYMBOL vmlinux 0xefbb7733	compat_ip_setsockopt
++EXPORT_SYMBOL vmlinux 0xefbfc45b	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0xefc2e54d	_lv1_storage_send_device_command
++EXPORT_SYMBOL vmlinux 0xefcc8160	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefd51993	agp_create_memory
++EXPORT_SYMBOL vmlinux 0xefd963bf	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefde1bbe	flush_dcache_range
++EXPORT_SYMBOL vmlinux 0xefece33d	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf00b98e9	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0xf010c09d	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf047bed5	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf065f629	ioread16be
++EXPORT_SYMBOL vmlinux 0xf067257c	register_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0xf0690ef3	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0xf076f1a9	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0xf07fe9a0	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf0992ad5	of_device_register
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0a8237a	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xf0aa18ea	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0xf0babb3c	da903x_query_status
++EXPORT_SYMBOL vmlinux 0xf0c724ff	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0xf0c76fa4	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0xf0caa5fe	get_disk
++EXPORT_SYMBOL vmlinux 0xf0cfcc6e	dquot_destroy
++EXPORT_SYMBOL vmlinux 0xf0d2f84a	_lv1_gpu_context_free
++EXPORT_SYMBOL vmlinux 0xf0d31435	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0xf0e4062a	block_truncate_page
++EXPORT_SYMBOL vmlinux 0xf0e6c464	dev_uc_del
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf0f8958d	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0xf0ff896f	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf1053f2e	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0xf10de535	ioread8
++EXPORT_SYMBOL vmlinux 0xf11cd6ce	down_interruptible
++EXPORT_SYMBOL vmlinux 0xf127226e	sock_edemux
++EXPORT_SYMBOL vmlinux 0xf14286e1	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf183189b	__ioremap_at
++EXPORT_SYMBOL vmlinux 0xf18620d9	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf1cfadbf	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1db345c	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1eadbba	bdevname
++EXPORT_SYMBOL vmlinux 0xf1f827c9	md_flush_request
++EXPORT_SYMBOL vmlinux 0xf20d2bc1	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf20ecc59	devm_memremap
++EXPORT_SYMBOL vmlinux 0xf217726d	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0xf217d73b	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0xf22029c9	release_firmware
++EXPORT_SYMBOL vmlinux 0xf22881e8	lg_local_lock
++EXPORT_SYMBOL vmlinux 0xf22b8423	component_match_add
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf24194cf	sock_register
++EXPORT_SYMBOL vmlinux 0xf24dcaa8	_lv1_net_stop_rx_dma
++EXPORT_SYMBOL vmlinux 0xf254e014	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0xf25b890e	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0xf27b1f68	kobject_init
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2a2b163	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0xf2ace693	d_alloc_name
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2d93610	agp_copy_info
++EXPORT_SYMBOL vmlinux 0xf2e676c5	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0xf303e5ea	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0xf30d1036	_lv1_start_ppe_periodic_tracer
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf322a206	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf33a4a58	ps3_sb_event_receive_port_setup
++EXPORT_SYMBOL vmlinux 0xf33a6943	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0xf33fc010	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0xf3406d83	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf34dcb1c	proc_remove
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf357db8d	pasemi_dma_set_flag
++EXPORT_SYMBOL vmlinux 0xf359386c	compat_mc_setsockopt
++EXPORT_SYMBOL vmlinux 0xf35e2106	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0xf35fdb6c	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf3b68483	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf3f8f90b	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0xf3fc8449	kdb_current_task
++EXPORT_SYMBOL vmlinux 0xf4064a04	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0xf41c1d77	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0xf441ac43	ioread8_rep
++EXPORT_SYMBOL vmlinux 0xf44e145a	register_qdisc
++EXPORT_SYMBOL vmlinux 0xf45536ed	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0xf4639b2c	compat_tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0xf46e1736	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4d56eb0	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0xf4e02bad	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0xf4e82ff0	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0xf4e8884f	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf51ae235	touch_nmi_watchdog
++EXPORT_SYMBOL vmlinux 0xf51bf88b	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xf5222143	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xf5255602	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0xf533be67	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf55b3b3d	__arch_hweight16
++EXPORT_SYMBOL vmlinux 0xf55d841c	key_unlink
++EXPORT_SYMBOL vmlinux 0xf55f6699	input_register_handle
++EXPORT_SYMBOL vmlinux 0xf588aa9c	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0xf58c4ba2	abort_creds
++EXPORT_SYMBOL vmlinux 0xf599890e	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0xf59b6d10	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL vmlinux 0xf5a62ecc	_memset_io
++EXPORT_SYMBOL vmlinux 0xf5a7772a	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0xf5b816fa	__register_binfmt
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5c758bf	nd_dev_to_uuid
++EXPORT_SYMBOL vmlinux 0xf5e1558d	crash_shutdown_unregister
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf6213e12	pasemi_dma_clear_flag
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf65778fb	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0xf6579799	agp_generic_alloc_by_type
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf696ebeb	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6ecb763	_lv1_send_event_locally
++EXPORT_SYMBOL vmlinux 0xf6f5964d	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0xf6f98920	tty_free_termios
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf70dc5ca	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0xf716cb6d	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0xf71e4996	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0xf75188ef	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf76fb117	mach_powernv
++EXPORT_SYMBOL vmlinux 0xf77e3192	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0xf7838ac2	simple_getattr
++EXPORT_SYMBOL vmlinux 0xf79594f7	textsearch_register
++EXPORT_SYMBOL vmlinux 0xf7ac360e	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0xf7b92fef	nvm_register
++EXPORT_SYMBOL vmlinux 0xf7bac0ec	_lv1_set_lpm_counter
++EXPORT_SYMBOL vmlinux 0xf7f82ed0	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0xf8004bfd	_lv1_disconnect_interrupt_event_receive_port
++EXPORT_SYMBOL vmlinux 0xf805a262	read_code
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf812cff6	memscan
++EXPORT_SYMBOL vmlinux 0xf8188d74	pci_save_state
++EXPORT_SYMBOL vmlinux 0xf823807b	iov_iter_init
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82988ed	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82d499b	compat_sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0xf82def7a	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf83633e1	vfs_writef
++EXPORT_SYMBOL vmlinux 0xf838a0e5	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0xf847ed61	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0xf857d44a	of_find_device_by_node
++EXPORT_SYMBOL vmlinux 0xf88bd870	ip_defrag
++EXPORT_SYMBOL vmlinux 0xf8a3c648	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0xf8a6092c	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0xf8ac51a2	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0xf8d04f09	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0xf8d7568d	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0xf8ef9a2c	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf90db4b6	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0xf9169867	param_get_ullong
++EXPORT_SYMBOL vmlinux 0xf95b8571	netdev_warn
++EXPORT_SYMBOL vmlinux 0xf9632ac6	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xf99b6f14	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0xf99d4b05	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9b467d5	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0xf9c0b663	strlcat
++EXPORT_SYMBOL vmlinux 0xf9c67412	simple_rename
++EXPORT_SYMBOL vmlinux 0xf9c6e829	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0xf9c7903a	rtas
++EXPORT_SYMBOL vmlinux 0xf9c8f7f2	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0xf9cad956	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0xf9ea76d2	phy_start
++EXPORT_SYMBOL vmlinux 0xf9f1d456	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0xf9f9f729	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0xfa1f18a8	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa539d10	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa83f334	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0xfac01d43	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xfad3ed07	seq_vprintf
++EXPORT_SYMBOL vmlinux 0xfadb5750	pmu_unlock
++EXPORT_SYMBOL vmlinux 0xfae140fe	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfaf02a34	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0xfaf986a8	uart_resume_port
++EXPORT_SYMBOL vmlinux 0xfafe2489	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0xfb0cecfd	vm_event_states
++EXPORT_SYMBOL vmlinux 0xfb3d90a6	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb813420	dqput
++EXPORT_SYMBOL vmlinux 0xfb840f47	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbaf14ef	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0xfbbf8398	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc26570f	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0xfc2a23e3	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc3b160f	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xfc4240f9	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0xfc54c7a9	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0xfc5e2aa0	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0xfc88ac67	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0xfc912443	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0xfc925e33	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0xfc92b052	dst_destroy
++EXPORT_SYMBOL vmlinux 0xfc968ecd	simple_rmdir
++EXPORT_SYMBOL vmlinux 0xfca597b2	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0xfcb433e2	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0xfcb926cd	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xfcbfc361	down_read
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfceda212	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfd0ae011	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0xfd198d97	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0xfd244202	register_shrinker
++EXPORT_SYMBOL vmlinux 0xfd2690f6	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0xfd3ac6c7	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0xfd3b6477	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0xfd3fcd84	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0xfd4148ef	agp_put_bridge
++EXPORT_SYMBOL vmlinux 0xfd5df590	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0xfd68e89d	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfda6e4a0	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0xfda7d83c	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0xfdac5645	dquot_transfer
++EXPORT_SYMBOL vmlinux 0xfdae7982	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0xfdb6cedc	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0xfdb9b629	ioread32be
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfdcf5cc2	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0xfde07cdf	account_page_redirty
++EXPORT_SYMBOL vmlinux 0xfde4839e	ps2_end_command
++EXPORT_SYMBOL vmlinux 0xfded48ed	enable_kernel_fp
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfdfd2f21	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe0cc95d	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0xfe133cb6	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0xfe17047b	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xfe2539a0	pci_enable_device
++EXPORT_SYMBOL vmlinux 0xfe2582a1	napi_disable
++EXPORT_SYMBOL vmlinux 0xfe26fc7c	nr_node_ids
++EXPORT_SYMBOL vmlinux 0xfe4cb4b5	_lv1_storage_write
++EXPORT_SYMBOL vmlinux 0xfe599f12	fget
++EXPORT_SYMBOL vmlinux 0xfe5c7a9c	of_parse_phandle_with_args
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe685dc5	key_alloc
++EXPORT_SYMBOL vmlinux 0xfe6e5fd0	md_reload_sb
++EXPORT_SYMBOL vmlinux 0xfe762ee8	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0xfe7c070e	scmd_printk
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe8b7919	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0xfe916dc6	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xfeadb9f9	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0xfeb0e2a9	fb_pan_display
++EXPORT_SYMBOL vmlinux 0xfeb8e403	security_inode_permission
++EXPORT_SYMBOL vmlinux 0xfececff9	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0xfed221d9	pasemi_dma_alloc_ring
++EXPORT_SYMBOL vmlinux 0xfed350c1	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfeebc7c4	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0xfef3f675	d_make_root
++EXPORT_SYMBOL vmlinux 0xfef40532	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0xfefd3aa9	compat_ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xff1765c7	rtas_call
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff3ee62b	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0xff4334eb	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0xff57cb29	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0xff63d0cc	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff97d264	padata_start
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xff9dea47	elv_add_request
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x01d6725a	kvm_write_guest_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x09828bb4	kvm_flush_remote_tlbs
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x0df8a214	kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x0e0f7c09	kvmppc_handle_store
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x0e3f1116	kvm_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x172a5ab4	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x19292a60	kvm_debugfs_dir
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x1a402fe7	gfn_to_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x1a90a123	kvmppc_h_logical_ci_store
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x1fdab0a9	kvmppc_core_queue_program
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x206bb9bc	kvmppc_hv_ops
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x214a4e12	kvmppc_core_prepare_to_enter
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x27a9834a	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x280f59bb	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x2a599114	kvmppc_st
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x2ced6209	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x312fa9d9	kvm_clear_guest
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x3ab45fba	kvmppc_handle_load
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x3e1f72e0	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x42e20820	kvm_read_guest_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x4513506a	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x46e63710	kvm_vcpu_gfn_to_hva
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x4f3f3c13	kvmppc_kvm_pv
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x5125b051	kvm_put_kvm
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x521c2693	kvm_io_bus_write
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x52e60e5e	kvmppc_sanity_check
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x55dc48b9	kvm_vcpu_gfn_to_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x569037f3	kvm_vcpu_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x5acd2f54	kvm_read_guest
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x5bff6ff5	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x5e254d0c	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x629d1664	kvmppc_h_logical_ci_load
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x633b67c8	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x667db834	kvm_vcpu_init
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x68d25447	kvm_vcpu_write_guest
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x6ad77638	kvmppc_emulate_mmio
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x72d107ff	kvm_vcpu_gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x736fe587	kvm_vcpu_read_guest_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x839026a8	kvm_unmap_hva
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x85a5a4b2	__gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x86119dec	kvmppc_xics_hcall
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x8a2fad9e	vcpu_put
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x8b4035f6	kvmppc_core_dequeue_dec
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x92ddfa31	kvm_vcpu_write_guest_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x944dbe75	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xa3b25545	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xa4f64721	kvm_vcpu_gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xa8287e31	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xa8e5566b	gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xab59d373	kvmppc_free_lpid
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xad698912	kvm_vcpu_read_guest
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xb3e87ef9	mark_page_dirty
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xb53f27f7	gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xb75400e4	kvmppc_prepare_to_enter
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xba0aa50b	kvmppc_gpa_to_pfn
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xbfe739cd	kvmppc_set_msr
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xc019122a	kvm_get_kvm
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xc5c8e321	kvmppc_book3s_queue_irqprio
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xc70e4b59	kvmppc_claim_lpid
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xc7c24c7a	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xc8060fc1	gfn_to_memslot
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xcc44961f	kvmppc_alloc_lpid
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xd3a01f1e	kvmppc_core_pending_dec
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xd439ac68	kvmppc_rtas_hcall
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xd46cecfd	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xd794d9c9	kvm_release_page_clean
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xd7d40abe	kvmppc_ld
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xdb94e925	kvm_init
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xddffe954	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xdfd36390	kvm_vcpu_mark_page_dirty
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xe3786c92	kvm_get_dirty_log
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xe50e0628	vcpu_load
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xe5b571cd	kvmppc_unfixup_split_real
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xea9c1b60	kvmppc_core_queue_dec
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xee1602ef	gfn_to_hva
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xeecee5e2	kvmppc_load_last_inst
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xef11cb35	__tracepoint_kvm_ppc_instr
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xefcb2903	kvmppc_pr_ops
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf4da3546	kvmppc_init_lpid
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf5561d18	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf72a8011	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf7e39f88	kvm_write_guest
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xfa258208	kvm_vcpu_block
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xff4b2ee2	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm-pr 0x1e3e5225	kvmppc_emulate_instruction
++EXPORT_SYMBOL_GPL arch/powerpc/platforms/cell/spufs/spufs 0x54e9b501	spu_save
++EXPORT_SYMBOL_GPL arch/powerpc/platforms/cell/spufs/spufs 0xdc291ec9	spu_restore
++EXPORT_SYMBOL_GPL arch/powerpc/platforms/cell/spufs/spufs 0xf377b6aa	spufs_context_fops
++EXPORT_SYMBOL_GPL crypto/af_alg 0x14f505c8	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0x16476f45	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0x39e82ccf	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x58716898	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0x67746fa2	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0x6c1530db	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x850d9ea2	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xa809190f	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0xc734bb76	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xd0571083	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xe5345d94	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x171fc378	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x85f5cc4f	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0xad113c85	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x149e9bf5	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x6ffb2540	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x40869d26	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x592792b1	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xeaa27410	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xf6204f11	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x9a86fd9c	async_xor_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x9e119dac	async_xor
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x77b48e6f	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0xdc355007	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x75cab6d5	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x0eff491d	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x84388d9d	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/cryptd 0x307b9202	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x64c38b14	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x7db4134d	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x8e48d726	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x9fec2085	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xacdb7fde	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0xdce833cf	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xe4ed3875	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xfbc837e6	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0xfd7a9fec	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0x5c8ca1c2	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x1ac078ff	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x3c7b24d8	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x442357e4	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x6fc8ed2a	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x8347667c	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x8b8e3d5e	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xad1cfd57	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xd541b2dd	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xde116540	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x15fb1548	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x4ffcf7e2	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x70d611e1	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xefbef772	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x1c988b98	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0xa0eb8920	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0xd1b8e250	xts_crypt
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x0cda5b0c	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x16c0a243	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x3d32876c	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x4588fe69	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x4d440f7a	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x55cd7711	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x57fec0aa	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x5d700fef	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x63ad8532	ahci_error_handler
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x6570b86d	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x66278bbf	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x66af6360	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x76742648	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x7cc282aa	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x9954529b	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x996b9cce	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x9ef2ffd0	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xb49fa648	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc4a47a1d	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xd4c52ba0	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xd9288627	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf05c7a03	ahci_qc_issue
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xfc822544	ahci_host_activate
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x1c7b2397	ahci_platform_init_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x282a576a	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x4b9146b2	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x599b2e2c	ahci_platform_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x7b854b25	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x84e00e9f	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x88e2bd88	ahci_platform_resume_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x9977d327	ahci_platform_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x9c3e0595	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xc71fb181	ahci_platform_suspend
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xd3de3453	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xec880395	ahci_platform_suspend_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xf25fc9c4	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0x450652d8	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/ata/pata_sis 0xe6b0ae6c	sis_info133_for_sata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x3ee4c0d3	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xbd56781f	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xca863cd0	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xe99099d2	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x0902a9b6	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1189d799	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x19512b14	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1dc5011f	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x2e5a0835	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x2ff7f6ed	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3e813e54	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x4e407dd7	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x568ef53e	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x57dc30b3	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x633bcc4f	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x64a9fbb7	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6d380263	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x7d86e2e1	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x94bc8a42	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xa7eda8b3	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xae64c603	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc6251e6e	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd4bca1c4	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdcd519ac	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xde671347	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdf976ab0	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf5af2d67	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf8eacd85	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x1b6b715f	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x4766c6e0	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x5f070f1a	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x6f48f32b	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xb31fbdb4	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xedd9ffaf	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x17bd494a	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x185862c9	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x25dda0dc	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x3cc7889a	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x45830563	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x8f58a658	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xa85e94c3	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xb08ac3bf	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xb6af3b90	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xbe34e409	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xc5671f25	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xda946de0	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x00a92bc4	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x2c6f355c	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x34a212e0	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x40abe459	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x43176b4b	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x6d187eb9	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x8052b638	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x8b4cf75d	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x9c7fc5e8	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xf21f8a98	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xffc1ff3b	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x9bf2a70a	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0xfc2f1512	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0x9d4bf18f	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0x682b7543	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/crypto/nx/nx-compress 0x2c2d5977	nx842_crypto_exit
++EXPORT_SYMBOL_GPL drivers/crypto/nx/nx-compress 0x78f8bdc9	nx842_crypto_compress
++EXPORT_SYMBOL_GPL drivers/crypto/nx/nx-compress 0xaa564910	nx842_crypto_init
++EXPORT_SYMBOL_GPL drivers/crypto/nx/nx-compress 0xaa78c6df	nx842_crypto_decompress
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x2f1cc226	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x407c627d	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x4832aa81	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xc26d8fc3	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xfedda1a6	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x4ab9bf18	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0xae33f223	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0xed0993b8	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x076c3e27	vchan_find_desc
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x097da9e0	vchan_init
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x3b24aa3d	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xac8efff3	vchan_tx_submit
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c9f4f93	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0da819a7	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0ed35ec4	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x1402daff	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x1faf6b41	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x41134e82	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x47068028	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x53e0b190	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x55213a67	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x67cffda9	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x719b006d	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x724ad30b	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7e3ac44d	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x8d332379	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x95c9798f	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x96e2e21d	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x9a23c3b3	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa7d68c68	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xaaed8226	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe391c20f	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf16d10d6	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf72c695e	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xfd3ae96c	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x0f79704a	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x119bcbec	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x1fb0e151	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x2f9efe4c	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x81f70cd5	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x823029b0	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0xc59e86ea	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0xc7e2ddf3	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x5f68fdcc	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0xc8548dde	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x06235a14	drm_display_mode_from_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x51f723b4	drm_display_mode_to_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x57e15d00	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x96892ffb	of_get_drm_display_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xa0f2a8cf	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xde1e5ec9	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x1fdd70e6	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6090bb54	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xe658429e	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x019da9e7	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x03edbe5c	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0f457916	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x10086c94	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x18419417	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x207b4f63	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x23797d69	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x24f371cb	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x28482dc0	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2f7e9593	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3961f00d	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4155308c	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x42bb39eb	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x453f4931	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x46f87483	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4a952932	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x51b512a6	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x75788819	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7a5abda4	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x914cdffb	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9237ca17	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x95167086	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa9d22893	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xab2d97a1	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xafa10478	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xafa3b876	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbd10ca55	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc8dac007	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd28703ef	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd76ceb09	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xde9167d8	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe1fd7f26	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe3be339c	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xea9000d7	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf5e35ce7	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf6a9c144	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x38aabda1	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x03fc45b7	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x161890b1	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x2d2945a5	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x40b1c61a	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x6cddc212	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xf593eb84	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x015dfbd1	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x170cbc88	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x195a2344	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x68c6447e	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xc4477a3d	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xd113267a	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xef1f5c26	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xf1d4fe7e	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xf2d4bda3	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x75126ff9	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x03a52dd3	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x069960a7	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x06dd2c59	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x0726f841	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x0dbe2b64	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x1b0085be	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x1e082d06	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x2fa6be40	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x3cf3ac16	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x4b4df15f	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x7ce2a2fc	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x7d0730a0	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x7e64a409	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x930f064c	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xd39558fc	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xd42486ca	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe58664ed	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xfb916a6e	hsi_add_clients_from_dt
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x01fa26c4	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x0249a437	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xb6353f87	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x094ee155	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x190e9b76	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x367873ce	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x48a3e305	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x85273522	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xa8f58d44	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xb2c0c31c	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xb37be1f8	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xb5a8688f	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xc092483b	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xca8d5538	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xccca84ab	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xcce437a6	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xd67cf244	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf520a415	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x0ff602a3	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x1715dd08	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x28cffaab	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x6262bfd4	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x669d9b3c	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xb15894c1	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xdf4feea9	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x63bbcd84	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x68f1dacc	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x8f3aa19f	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xb07303a7	stm_source_write
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xf3a39466	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x271c2248	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x2d99b656	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x54818cdb	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xbe2e9a23	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xef9f7bc9	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x26cde695	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xb1f7b30f	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xd864e03e	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xfdf99738	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x2822e972	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x2ad2934b	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x904e2275	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x188dc973	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x1d13ec1c	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x40abbfb9	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x82775a6b	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x9115327a	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x9357595b	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x9c2476bd	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x9cfd442f	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xad050cd0	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xdb22862a	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x5c764bbb	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0xf12b3809	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0x9323f683	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xd19038bb	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x3d694938	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xc3a4ac47	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xdf8df506	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x2df4d94c	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x35ccac8a	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x3ed9e11d	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x5d05e07e	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x6ec90ee4	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x886f7b85	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x8dfbca7f	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x9bb8fb1c	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xc1b709d4	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xc59a4052	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xf7c7fc88	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xfd38fa12	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x016dc9c8	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x016e1ac3	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x07311590	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0a28979b	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x1f5fe2e0	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x333382ed	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x45cfdbf5	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4a735ded	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4dca3f44	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5af5fa6e	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5dd893b6	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6a53ef80	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6ec89871	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x73ed5331	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7a973bd0	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x83406057	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x8b7ac580	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x8df4fa15	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x98d447ed	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9cf4c7c7	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa6dfa960	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc09236d4	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xcbdaedc7	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xcd5811b6	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe527e371	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe660a9bc	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf27fc903	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf74a6f0b	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf940d9b1	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xfa40a32e	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xfe02add5	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0xb63b7664	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/matrix-keymap 0xef7c5841	matrix_keypad_parse_of_params
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe493aee5	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x13a599a5	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x90a1afe0	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x9698ccc5	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x28a8c344	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x5465b9ce	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xc6923b44	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x2f376030	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x87465e3d	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x612c6d04	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xe16de9a4	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xe544fa37	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0xeaf2d124	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x1ec3f736	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x28bbb88a	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x5c901a5a	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x6589ad61	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x6e86c1d3	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x84ccbb11	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xafbe9d33	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xb26a28b7	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xcfd7eaf2	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xd269f7a8	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xecab4900	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xf5c76437	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x02668b88	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x163307c1	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x42a367d7	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x8151e0cb	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xabb181c9	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xb3f3de2d	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xdc4152ba	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xdd577e2c	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xe6a536b0	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x13436f5e	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x150e326a	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x1ca7b1c3	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x2138a922	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x3c93bc68	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x5b47c15d	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x719594ea	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7ab0069e	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7f00ddee	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x914ad1d8	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa3151853	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xac853484	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xd0b5259c	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xd679ce23	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xef242fce	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xef589351	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xef7ee2a3	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xf9e7aa0e	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x1e245efb	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x4698eba8	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x4f912b0e	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x87803d32	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x905130e8	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xeb68e12b	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x0c04db20	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x34e32907	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x4df26705	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x573a5377	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x57641aff	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x9050c13a	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x90f41383	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x98fbd190	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x9e03a0e2	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xb9fb1c8a	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xcf3515a6	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x0a0527be	wf_register_client
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x2f4cb74b	wf_register_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x5279b5cb	wf_get_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x5cc150e0	wf_unregister_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x75147afa	wf_set_overtemp
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x77f539a9	wf_get_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x808f70dd	wf_put_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x897797df	wf_unregister_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xbac34038	wf_put_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xbcace2a5	wf_unregister_client
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xd2826f56	wf_register_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xed82a14f	wf_clear_overtemp
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_pid 0x9808f147	wf_pid_run
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_pid 0xb8ed5b2c	wf_cpu_pid_init
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_pid 0xcd9a18ef	wf_pid_init
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_pid 0xceda69f1	wf_cpu_pid_run
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_smu_sat 0xe05851d5	smu_sat_get_sdb_partition
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x07d05a30	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x2d8a29b4	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x33d12de7	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x5cd6f777	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x5eb75fd4	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x830cc338	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8bf52ac0	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xa0320d5a	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xb095bad4	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xccdeadc2	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xd45b39d0	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xd528eb81	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xe9fa8639	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xf9602acb	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x021811cf	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x0f0677b8	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x10e6a889	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1154f7a1	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x15aa8e40	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x174c2a29	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2205bcf9	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3fc7cb7f	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x469f38de	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4ba51ecf	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5b2a89c7	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5d950f2a	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5e21030c	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5ed04550	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6eef9654	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x74ab7b0f	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x84efb763	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8fe32879	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x91f02667	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x93f7fc02	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa1de5277	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa81bf581	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb7d964de	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbbace2cd	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc6673631	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc8a2f711	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe3de2ba2	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe902838d	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xec919105	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xeea27f46	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfad1ec73	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x33834097	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x40ac24e8	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x81660d1f	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x8b318230	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x923726dc	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xa53047e6	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xe0517e96	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xe2ff0776	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xfe3db482	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6aba7f5e	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7b7ac13d	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9310ba06	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9c256008	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa1d2413a	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa448e19f	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xafbda3f3	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xcbb1bae2	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x2e0f0bc1	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x3c710f0d	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x531ae83a	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x9692a6c2	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xc8f44863	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xd3c2f825	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xf74d400b	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x176c2ea2	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x5e1590f2	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x2a04d298	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4430764e	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x45ab972a	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x52bde202	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x5a4ba679	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x6a85bc8f	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa68e1f06	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xe2c80560	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfad9d53a	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfc62ef4e	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfcad73a1	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x17c36f29	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42dbdfc3	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x49b35849	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x55b4bd4d	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x6cc8d989	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x827a42f4	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9f624559	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xafeda29f	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd29923fb	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf375d009	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf5455120	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x12cb054b	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x1ed77334	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x24b92845	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x444c0296	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x519eb430	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x5a544651	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x85eeccb0	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x9fd0668b	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xfbb4680e	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xfeb19f78	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x0a3d05c4	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x0f8238ca	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x77694665	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x960a2466	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xa3912778	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xbd7b99d2	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xe5243ec5	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x1b90ee8f	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x364edd27	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37228311	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x42283dc1	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x4fde226e	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x778f1d92	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7977ca22	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x90556aa2	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x99a81ab3	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9a5e1473	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9ccd1533	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xb7b5d5cd	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xd20fdcd5	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xd6b11c75	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xdde32b0e	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xef0bf879	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xf9cef16e	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xfc632364	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0xa6670c1f	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0x68bf97eb	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0x44daea4c	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x0bf7ef9d	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x298427cc	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0x2ce2db29	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x41477842	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0x4f4cc3ff	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0x7def42ac	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x820191df	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x896e8e53	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x8a8d25ad	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x95167802	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x99cf5c6a	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0xa437e7d4	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/media 0xac5da3f8	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/media 0xc916b98a	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/media 0xdc0ba6bf	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0xe77760f0	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0xe9df5b96	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/media 0xf0e61467	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0x9fc31218	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x126e1279	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x1498343e	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x188a3866	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x1987fdb4	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x28449539	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x458a5c13	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x51c18825	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x7f7d7629	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x8609744d	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x9471b1cc	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xa3601f23	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xc06ff807	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xc5a6ee11	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xcf42c40e	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd318b94f	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xeb2233e9	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf11f8aa6	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf9079bd8	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xfcb82b65	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x05f9906f	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x1b086abc	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x326f2380	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x33ebc2bf	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x3f9bff2d	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x483ac368	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x53443052	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x54731571	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x63e26e58	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x67674793	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa0c7d2e4	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa4d5d42f	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc7808f44	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xcb8cb069	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xd03147c5	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xd2afc871	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xd9f9c2f2	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xf304592c	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xf7de6e9c	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x02855788	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x174a9297	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x3c9013ce	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x4160f313	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x47e8e723	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x48df5d32	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x96b3b675	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x0b2585ce	xvip_get_format_by_fourcc
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x30d8b5eb	xvip_clr_and_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x3c7eb685	xvip_set_format_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x490bd11c	xvip_get_format_by_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x7c2a0b29	xvip_enum_frame_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x83da58ff	xvip_init_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x83f83b07	xvip_of_get_format
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xb8ef776d	xvip_enum_mbus_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xf0a6dc19	xvip_clr_or_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xf0e16e6b	xvip_cleanup_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x244199e7	xvtc_of_get
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x3c16a6b1	xvtc_generator_stop
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x47d7900b	xvtc_generator_start
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0xa8a0f912	xvtc_put
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x727cf7a7	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0xcac73290	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x00896d13	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x03dc6149	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x0a341b75	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x1328ba17	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x15af27e1	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x41561db2	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x4542ce6f	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x4a93f480	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x525ee654	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x6ad57f74	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x86911d2b	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x886b77e6	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x95734400	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa46d3240	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa8c3d59a	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xbe7a6271	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc388affc	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc60e2e9e	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xf158c366	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0x3bdaa386	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0x8df7ed5d	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0x271f39c9	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0x8af992f5	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0x48c78460	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x67fd993e	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xeb8fb3c2	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xed3df683	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0xdb3884c6	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0xb929eab5	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0xd53e7b08	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x3cb0d156	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x6b5dee2f	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0x05810e7d	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x04f0eabb	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x07699530	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x1c802d66	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x2dbf391f	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x2efc9674	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x384843d5	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x76ac0276	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x79d2e8bc	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x82fc78a4	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8fabbbd8	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x9dff57e5	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xaf0f948a	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xb6d1c88c	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xb972f62c	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xcc5175f7	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd5bb9e0c	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xee1ac25f	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xefcf947a	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf7970d3a	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xfd4764bd	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0xcaa06949	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x07886a36	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x16c7c5bb	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1b4fe680	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1db50168	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1dc13882	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3108f573	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3c30e435	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x5f1d8e30	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x68d501f5	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7012d6b4	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x70bff589	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x8ca1ed21	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9700769b	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xa0a6be14	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xacba4cbc	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xb2fe798c	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xbabcafae	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xc3c34d86	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xe7143316	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x14d508ec	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x30a24067	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x78d5ef66	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xc79f0308	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x4e8dfb72	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x7934e5cb	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x7e41208e	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x8cdd8945	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x9dad98ce	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xc0b467f6	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x30988482	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x457b0731	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x00b1b191	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x088db871	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x2c063db6	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x42cc5743	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x43dbea5f	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x44c1a8da	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x4864a12d	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x4e517dbc	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x580c9c5d	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x62ace0b4	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x64e1a048	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x68aab64a	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6b2674bd	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x94a3cd67	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xa80332f7	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xabfbeb97	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb17c677a	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xbc4e1148	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd66e2680	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xdd574fa8	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xdfb7c507	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe0f1d7ce	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe3d9b131	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe4b44ff5	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xea068f3f	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf0f1c678	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf350324e	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x0969f5a7	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x1dd84758	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3d0b4a11	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4e3e4b74	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x584552bb	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x64ccdb86	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x67686fe7	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6dfe6e78	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x7230b2e4	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x86376b14	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x924c8e73	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa5dbdf15	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa6de1b61	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb69caa89	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb8f7d9d7	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb9b725ca	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xc13b4485	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xc4f6c883	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xca15b6ef	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xd577b3e6	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe6e8fcd7	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf2218308	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfa271be4	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfbe775c8	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x03123d01	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x50505afc	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x553a86d0	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x7268f5b9	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xd83f7c9a	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x2de3284c	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x6dd8c01a	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xc4d8deeb	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x05fee72c	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x10b53a42	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x14084f5c	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x39a91867	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x3e8a2834	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x4a816e6a	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x692880c4	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7f1d4d0c	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x805c72d3	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x88c3a4e0	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8b4458f5	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x94865161	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x97b2ed54	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x9e4aac3a	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xb125c901	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd12938f0	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xeabb31b4	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xeccb7e1b	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x8423dc28	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xda6d1af4	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x02acae7a	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xb3092c48	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x68c2652f	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0398a052	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0496c71f	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x07b643ed	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x07e5149e	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x08c295da	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1278b5d4	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x2194b90b	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x22ac7d4b	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x37c9ecac	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3995e901	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x3fcabbf5	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x411efc8b	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5e67f45e	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x6934cb49	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x81595132	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x83d5fad1	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x88003376	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8c90751c	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa35447ea	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa7de8d9d	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa879e74e	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa917d7b7	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa9752a08	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc474f070	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xca84c813	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xcd8690f0	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xd662ebe2	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xdc30261e	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xdf1637a6	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xe4cbc8cc	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xeecafc8f	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xef48594c	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x0169bab3	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x092eda75	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0bab8ec0	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x133adfc4	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x19378a46	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1ef3a428	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x28bd9048	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2ab9d732	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3bcace3d	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4101e7a1	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x42533040	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4e73fa8d	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x524d5e39	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x573d4d0b	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x59f36f51	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x6c06e00c	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x6efd9a15	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x74a017c5	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x799bf54f	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7bfda7d4	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7c147b30	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7e173c6f	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7f5c524c	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x802accdb	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x99b8e196	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9cc16819	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa2c1f982	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa38bdf68	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa5d32fc9	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa72016d6	v4l2_compat_ioctl32
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xaca2544a	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb026cf6a	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb782e600	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc6429d8b	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd48fc083	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd63bf8ef	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd85ddae4	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xea32d834	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x617093ae	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x8a371782	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x90d4159d	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x17655e74	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x33ce44f4	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xb4972fb9	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xca8c43e1	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xe1cea715	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xec393d2d	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xf698c960	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x0c3a166c	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x1678a890	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x28702af9	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x513da4ca	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xa4df0144	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xbcfae5da	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xc864f8a3	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xffb60738	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x0ac34668	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x9d6bee26	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xbe81abe3	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x0e353ce7	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x17aa7ac6	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x25434fb1	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x2636a253	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x27128735	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x57b193fd	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x75bef83f	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x0d91d1bf	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x58831203	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0xc5c1e65f	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x1b3f5969	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x498ae721	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x5b851249	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x73f7487c	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x7f5ffcd9	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x835c4ef2	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x00f5853d	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x17ecced4	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x217b3959	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x43fef801	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x93458e37	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xaa7f1149	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xb257c618	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xb4cf078b	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xbca9b079	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xdd53b730	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xf2235b8e	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x3dc11916	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x5fe89479	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x15d5022b	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x5dd73c8a	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xa4e7fc6d	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xad0e8e5c	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xf2827ab6	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x13ca7699	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x14397320	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x2ca41520	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3b1f98b4	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x41972694	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x42b7785c	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x452d991b	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x5351ae01	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x582496c8	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x58927c6a	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x657d9a07	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x6ebfadff	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x738b5ee4	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x883b70ce	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb32abd93	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xbf6fa342	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xcc689844	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xda11ccc3	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe50c9f36	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe7f17327	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe95014f7	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe9d7f35e	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf69c7ad9	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xfed09000	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x03cfa878	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x124144a7	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x1604c2d7	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x20d91d57	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x42a92dc3	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x57bcac57	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x62d7e68c	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x7ef74669	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xa7242405	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xe99cdfb3	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xf2087185	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xf4e64594	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xfeb4aebd	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x00d68c9f	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x067f5600	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x08af6ef5	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2e3ecb4e	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2f56c8ba	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3107eaef	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3bc28096	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3c24383a	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3d70f64e	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x43db1570	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4c42087e	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5b8d6d5a	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x66ab082e	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6a9ef28d	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x73912091	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7e923587	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8184c7cd	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x829c0787	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8825e24d	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9b05c786	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9da2a2b8	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9fa42525	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa6e7bf0f	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb9546eaf	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc6153d21	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc815b221	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc87b379b	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd3f6cc2b	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd5c1df31	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd6a2b41f	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe1798048	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf6b88cf4	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf792babc	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xff0164e3	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x1d247a13	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x88628c80	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x9d80da54	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xdc3b2a83	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xdf84c3d3	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x15cea353	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x3c953dcc	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x47c57edc	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xd798e634	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x8f0aa756	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x9985e0e7	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xc8b2174f	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xf013913c	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0xb8aeba98	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x33076164	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x53de7bad	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x8d917d8c	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xf40a14ee	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x3382c093	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x3d9b9bf2	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xee90ffcc	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xfc0d72e8	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x02062952	cxl_allocate_afu_irqs
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x059b29cc	cxl_dev_context_init
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x08ee42fb	cxl_fd_ioctl
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x0e033436	cxl_unmap_afu_irq
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x10c97224	cxl_fops_get_context
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x158f486c	cxl_pci_to_afu
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x2fc6113d	cxl_process_element
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x455fb98c	cxl_set_master
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x467bf5a0	cxl_afu_reset
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x4f9ab3d3	cxl_get_context
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x60367f84	cxl_read_adapter_vpd
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x612ceacc	cxl_free_afu_irqs
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x8740bc47	cxl_psa_unmap
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x9023bca3	cxl_map_afu_irq
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x9116195f	cxl_fd_poll
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x91292083	cxl_release_context
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xa4308c20	cxl_fd_mmap
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xb1a6cc90	cxl_fd_release
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xb4faefda	cxl_fd_read
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xbe6b4565	cxl_start_context
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xc71a3732	cxl_psa_map
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xca78957f	cxl_pci_to_cfg_record
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xd2b97ec4	cxl_start_work
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xd9e2e77c	cxl_stop_context
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xdc1d9edb	cxl_fd_open
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xe20414f4	cxl_get_fd
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xeacb4de8	cxl_perst_reloads_same_image
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x092f565e	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x169d1eb0	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x4b6501c1	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x61eee471	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x8d5876c3	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x9df68e56	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xcdcf600f	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xfe419fc0	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x41ebd5d2	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x4d80bfdd	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x77fce23f	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x8277b4c5	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x8845da25	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xb6b319b3	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xbb6b83cc	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xc064f569	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x95ea0797	st_register
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xbe92fb75	st_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x0185a21e	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x3ec270d8	sdhci_reset
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x433f251d	sdhci_send_command
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x5afb5c20	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x725d478e	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x7e03e0eb	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xa6a93412	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xb95d321d	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xd0f4b0a3	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xd4768a83	sdhci_set_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xea42935c	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xf3d002de	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xf6c92dd2	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xfbfba77a	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x0700237e	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x0d3788c8	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x3ce5e3c2	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x550eb7b7	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x6b85c121	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x8c26889c	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xabbcc7ac	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xc58c6632	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xd5ff46af	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x43653882	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x7c4c1d6a	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xbe7b1d14	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x22a3e1a6	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x5cf1aa76	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xaf0865f0	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0xcd36ccf1	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x5219e1d6	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xe328730d	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xe587b034	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0b970466	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0e0297e7	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1654ba10	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x27e6dee7	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x29e8cc6a	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x464a8f3c	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4f72ea23	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x52f76fd0	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x54587a93	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5d1fa208	mtd_block_isreserved
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x60bdb720	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6231b48a	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x62f83991	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x64289d74	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6704b4e2	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6a3f62ff	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6e797ba7	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6e95115a	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x79183a81	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7c72832e	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7d8cb23e	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x84228cc6	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x850cf699	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x88bdb724	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8d974eca	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8ec78ceb	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x924a2be2	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa377ca4b	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa7d4c8f4	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xae7ff2c2	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb57a8fb6	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xb63eb8d2	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc6833423	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc9a2fbde	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd1f7ebb9	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe0a70140	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe2942852	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe5a06092	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe73097dc	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe996598c	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xed2ed76a	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xef7dd0a2	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x149a426d	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x32dff460	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x37d10b61	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x566b2c65	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xee788517	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x491618a1	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0xd8fc4d9d	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0x4e2db7b6	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x9fde06e0	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0xae865cba	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0xb0ba0f6a	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x027a7c6c	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x2281008d	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x3b1fc9d3	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x3fe2f458	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x4c7261f2	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x73f350b9	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8077f77e	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x820ebbcf	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8f780243	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x9a8f38e7	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x9d838e58	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xdc6e5123	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe609eed9	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe8a6a9d6	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0x78536ef6	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xd4b53548	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x2f4a7692	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x534c74e4	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xb8b69c88	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xc958123a	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xd77ea8ac	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xffb7de49	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x0caaedb6	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x13888a15	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x146bcfe3	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x1e8c15d9	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x2706c543	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x270b61f8	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x49bea295	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x660d93be	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x706bd39a	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x8816073d	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x90ae373d	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xa4bad773	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xa7c2f098	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xace7c292	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xad21292a	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb10856eb	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc91304f0	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xeb2f54d2	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x578eb58e	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xa4fb94d3	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xc0ac0bf2	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xcdbcf14f	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x29909e35	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x6aec5e07	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x86c3a166	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x8c55ac36	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0x0451be4a	arc_emac_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0xdc6d22ba	arc_emac_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0320fab6	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x05d6057f	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0650002c	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0c40aa63	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0f56a50e	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x14589013	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x14aea68e	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x17785224	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1ed0d14d	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x223a90b4	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x252f2434	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x25c6d53a	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x28515247	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2c82f124	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2d11e8d0	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2d1e38f8	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2f6be5a6	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x34404d26	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x356125d6	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x36915876	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x39fa86dc	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3b98dfd5	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3b9a4df2	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3bad0167	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3c7f2a68	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x465be34e	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x47663c9b	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x476a09c7	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x47ae7146	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4cd36355	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4e741b9a	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5010c272	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x52579018	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x52f983a5	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x540cca1c	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5627c21f	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5631c66c	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x57a2dffa	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5a8d71a9	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5e41dd55	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x60250ba0	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x61a218c2	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x61ffe360	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x63361183	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x67a97261	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x699dc769	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6f1c512e	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x70a0a535	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7283a863	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7655d2c3	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x774b3247	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7a74bf96	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7da48e87	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7dfde169	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8057bfcc	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x845ec1b4	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x88d5d9bb	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x897a9f05	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x898caf8d	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x90cc86df	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9244860a	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x92e669e5	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x93442e8b	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x977afce2	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x979590c3	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x99188a51	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9b9a0bc5	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9d49da00	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9e768302	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9ea0b383	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa0d2fe63	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa31011ec	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa43b0660	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa85bbb2a	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xab38f0fe	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaba70e37	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaea74cce	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb4ef6c02	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xba2c3044	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb537eb0	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbe89016f	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbf9bd1ce	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbfe6b619	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc00e5279	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc2f37555	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc4cad604	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc71add8c	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc7ad456e	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc9dbbacc	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcc08095c	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcc3f45b3	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcc7a9686	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcd60bc5b	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xce7a3fd7	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcf063457	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd0376d44	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd4bfdf08	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd6321b2a	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdb019cf6	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdb12982a	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdcb95442	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xde622ab1	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdf1145f7	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdfc32879	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe09fe00c	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe14860c4	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe18bdac8	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe26e4320	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe2c83490	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe3b283f5	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe3dcd7cb	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe4bb2dfa	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe5d1ecd2	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe804c712	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe94ea505	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xeb4aa61e	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xebacaf6f	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xec0373e8	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xecf22a41	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xee82a10f	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf3e6968e	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf5207374	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf6e0254d	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf7054bfa	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09543b3d	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0dd68b94	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x195cf58c	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x197c9f68	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1d073a3a	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1f9b2c7e	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x25d337ad	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x26071771	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x34a226ad	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3712dd2c	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x44231a62	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4c7b0660	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x58a6134f	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5917bda4	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x59f3e3db	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6231515f	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x63b6e737	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6605152f	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x66507b35	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6fc8217a	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x849f36c3	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x87e09931	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8836a80b	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8b498a5f	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x939ef9de	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x94298256	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x975e8cec	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x986b9a9e	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9db905c5	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xab908945	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xad014992	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb2394064	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbaa642e8	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc35c3f16	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc3f3064d	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc638a371	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd76c0c86	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd80963fa	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdbfeae70	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdcf55a97	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdebe5f33	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe9745521	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xeadaad8f	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xefa7bf11	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf5de677a	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfb0a6aae	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x4c472395	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x5e28947e	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xac144314	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x544b4f24	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x58fbe654	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xcd0d5894	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xfa67dd1e	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x4607e97a	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x866972cd	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x9515b29e	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xcce76959	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x18f5c3da	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x1f600356	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x2d7a4b57	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x2f58bbc8	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x55abaf30	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x84da689c	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x932ed7d7	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x98b2de48	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x9e757bb1	cpsw_ale_dump
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xa9d2034d	cpsw_ale_add_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xd6bf5952	cpsw_ale_stop
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xd83df009	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xda32453b	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xed883e33	cpsw_ale_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xf4b9002b	cpsw_ale_start
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x0612cec2	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/geneve 0xbb4c976b	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x27928954	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xad2a65d5	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xb48fca19	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xd5b410c2	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0x18745c66	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x0e8390b0	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x16dc21f3	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x5a0ae1d8	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x6af5a569	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x8db032df	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xa7d11e13	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xb0c96348	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xbfd0c7f3	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xdfa6087a	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xf2941848	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x6318757f	mdio_mux_uninit
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0xb6f5091a	mdio_mux_init
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x25b89003	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x2dadfc7a	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xd6c88556	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xdd9b37be	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x042bcb87	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x3f96c430	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x71d06391	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xa0dd196d	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xb0a8313e	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xb1a61bd0	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xc8ee5f2e	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xd673fefb	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xe0b09cb5	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x03211a80	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x245b5585	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x9eb0ae81	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xb45d2394	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xbebb877b	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xfb198f6c	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x00bc68a4	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x033f494b	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x03576e5e	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x08c3e8df	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1235ec89	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x209ec3ac	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x260c5d4b	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3bebdcb0	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3f7c2835	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4f90f483	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x50bc8c3d	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x57529adf	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x5b5c7738	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6000c534	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6033ff8e	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x69bb84c8	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6bd9c24f	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x709840bf	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x871b850d	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x951c4562	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9c2cdb3b	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa75d32f9	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xae466570	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb7bfed69	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbccd5972	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbe894237	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc371dde4	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe08d09ed	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xeaff61b4	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xecfbc6cb	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf0690268	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf0b52e20	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x3e27048e	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x4fd60142	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x0279223e	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1378068c	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x16074eb2	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1a879b95	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x35d280f1	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x39746bdd	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x4fb5208c	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x6327af2d	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x916e6c78	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xab927d2f	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb3c711b4	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xbfc34b3d	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xd654a75e	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xe8200c86	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf1592581	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf4905e53	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x26f5fb0b	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x418be23c	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xac339b8c	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xd69dbdfb	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0x25118038	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x12485151	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x25f9bc62	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x4bff4b7a	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xcb4734a8	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xead99134	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x002b2e74	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0205c305	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0d556623	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0df0eccf	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0e67f2fc	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0f48dcb7	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x181ee60f	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1eb132b0	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x2f51ad33	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x3f5fb419	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x547ece6f	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5d52f29f	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x6a8b8a4b	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x6bfa1e64	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x6e2cc419	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7a179cf8	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x861b9b22	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x874e12b6	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9392d632	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x95e019c1	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb0383f4b	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xbd8ff68b	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc67c31ed	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc973d377	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd19cf853	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd8b746a2	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xde5a743c	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe0d3442b	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf0529abe	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf5aea4a7	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xfe17902a	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x01c71557	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x0686270b	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x2b5e6a91	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x2f530fb1	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x4cd3c0a4	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x52c01c87	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5e2ffcda	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5f4dc822	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x826d185a	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x8b3c6d25	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x9422b781	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa0d4c04f	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa6be96d2	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd47a6658	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf0ab7660	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xfae684ec	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x03ce2905	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x15f97275	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x865a1551	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x96bba9d9	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x9f535bfc	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xa193a211	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xe9a3a211	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xf6c59082	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x07c57d5d	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x07fd6e03	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x098961cd	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x098eec03	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x0d135748	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x10a93caf	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x20337549	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x25388c4e	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x38e1fd63	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x4d604f69	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x60f09bbc	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x666ce82b	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x6a587cd7	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x92d84ed9	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x97ab02c5	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x9c2d238a	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc8ef113b	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xdddcc02a	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xe87452db	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x3cbd7f2e	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x8990367c	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x920860e3	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x9397a98b	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x956e6b6b	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x98d740ae	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xa9cceabf	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xb5f2ded4	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xd4d656f8	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x822a8d3b	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8ae902ac	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x970b64a8	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xa668a62d	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x157d5a1b	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x178212a5	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x36e7414f	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3cb1433b	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x40ea3f91	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x44dd759f	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x4d5bf71a	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x65c0651b	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x666f9cc6	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x682a3965	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x68bd45f2	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7379b83a	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x73b285f5	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7693ba11	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x7be341aa	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x8ff8566b	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x959f7ac9	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x9d46dcf9	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x9e877172	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa1d09804	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xa901695a	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xae33d805	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xbf72caf6	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xc2491625	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xc90c224f	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xde3742b4	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xe517e2ae	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0d0b6636	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0d45c9fa	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x12f4d0e8	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x22b7c6cd	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x47d6c9f0	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4f417946	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x524151b1	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6b4de810	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x8ddb298a	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9345e165	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9c02f205	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9f2061df	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa2112a73	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb6f77f85	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbd0410c1	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc9bd8cb6	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe4c57663	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe5fd6f0c	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe8509c15	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf6da006e	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf72f846c	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x24e32750	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x50181671	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x93406bfc	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xd3393b2e	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0d7c2811	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x11386114	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1e5f4b4f	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x23f5a36b	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x30e937b8	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x311e97c2	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3c71bc28	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x434d25fd	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5157aecc	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5759979e	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5ebe82f5	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x66267768	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x67b00b1b	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6ff4764a	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7a34baa0	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7f18036b	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8592741c	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8b2924a1	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8ebde78d	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8f02e5f8	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8f0fdd5a	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x97f72137	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x99629486	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x9d1cb4f7	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa1b18f9b	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa6e43655	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xaa212405	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xad6d2f9c	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xaf32ac26	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb149768a	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xbbe21fd3	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc025ddeb	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc0e92050	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcf17bd1a	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xdae9097c	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe5820c93	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xeae3b4c2	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xfeaf1b24	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0044062e	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x1544056b	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x192b4d7f	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x6d57ff43	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x7969eb6f	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x7eabe872	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x7fb21f0a	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x9c94061e	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xa2b853fd	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xd56876ed	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xdc462b4d	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xee46d68c	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xf7b0c4ea	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x04cc0ca0	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x06ba25b0	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x071896d9	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x07cb9855	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x112d4c6d	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x12f37421	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1dd6162d	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x20981182	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2bdb0857	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2ec55b3e	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3f1e554b	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4341d5f0	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x49ac6544	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4b17f62a	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x53b759e3	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x59156edf	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5e8ed063	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x64393632	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x654cf831	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6a467844	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6ef894ba	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x72ef2f9b	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7433bfdd	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x745be4a0	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7e46f30f	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x83a75181	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8583fea5	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x87435f27	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x923efb87	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa437fd2a	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xaeb7c084	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb1518ef1	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb83843c4	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc85646a1	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd5078b64	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd511f6e2	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe13ff81d	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe3e0b793	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe5fe4e1c	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xee76c0a6	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xefc8e4dd	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf045f404	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf213e174	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfbde2053	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfcabccfa	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfd4a2ea6	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x204d7735	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x20f561db	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x47cc0711	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xb8703260	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xdfced66e	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x3a88ec59	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x46e80379	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xebbf0d57	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xf4427ff1	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x056fd110	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x0c038552	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x21607bd2	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x45dcc206	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x80f5215a	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x8b498fbe	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x9066ccf3	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x91c85409	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xad9503c1	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xc788f459	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xc91a67e6	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xcc9b61a2	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe2d2ad57	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe51c8ee3	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe6e0f5c6	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xee9f5c53	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x0b8b896e	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x6563a839	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xd541ca1b	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x08a3e0ce	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x090ee106	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x09f22eb0	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x136cefcc	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x239f49e3	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x256dc046	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x26471b8b	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x274b405c	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2773e70b	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2e294a5b	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x31e8c0c6	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x442570f1	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4ec0c2d5	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5424707d	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5588725b	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6a631942	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6ee4430e	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x72cb0f35	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x827acf80	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x82a2903b	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x87cd281d	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8cc0935f	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8e72c2c5	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9060b5e6	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x916a9d70	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x94827dff	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9bb03533	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa6e992a3	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xaaad3f97	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb4401a89	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb69aea5e	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb805a0fa	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc283bba1	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xded3ce51	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe29c4dd1	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe84c9bb1	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe8a71275	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xeda9696d	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xee9ba556	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf07ef497	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf139d1cd	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf6cadca1	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf9805302	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf9dd286c	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfc5d888c	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x97f6dd4f	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x9fdcf4cc	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xcfff30e8	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xdbdb7038	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x0d73d252	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x1b50b4b7	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x5b05bc83	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x92feeaa9	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xa8923a37	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xba813260	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xde0c6364	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xf762e170	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x60400f5f	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x681c4718	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xefb9071e	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x202d4ed6	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x224f51bf	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x2e9f9995	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x3866e217	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x58168940	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x7828edad	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x7d0e6184	of_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x99f018c4	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xaf91f68e	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xb40b42e5	of_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc697b0f7	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xd9561df4	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xe9ace103	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/pci/hotplug/rpaphp 0x01cc7086	rpaphp_slot_head
++EXPORT_SYMBOL_GPL drivers/pci/hotplug/rpaphp 0xa214f8ee	rpaphp_get_drc_props
++EXPORT_SYMBOL_GPL drivers/pci/hotplug/rpaphp 0xbb929ffc	rpaphp_add_slot
++EXPORT_SYMBOL_GPL drivers/pci/hotplug/rpaphp 0xeaf1d61d	rpaphp_deregister_slot
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x1e3436a1	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x5689fb94	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xebb98ca8	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x003998ab	ps3_write_ctr
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x0bdf50c4	ps3_disable_pm_interrupts
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x0e622920	ps3_write_pm07_control
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x181e55ab	ps3_read_phys_ctr
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x1bcb88c1	ps3_write_pm
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x2abf1471	ps3_get_hw_thread_id
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x2b339635	ps3_disable_pm
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x3c71a6b2	ps3_set_ctr_size
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x4a24996f	ps3_lpm_copy_tb_to_user
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x50488f64	ps3_lpm_close
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x58e642c1	ps3_lpm_copy_tb
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x59c54782	ps3_set_bookmark
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x5eca6711	ps3_get_ctr_size
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x60e3f0d7	ps3_read_ctr
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x6702a28c	ps3_get_and_clear_pm_interrupts
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x69010c19	ps3_set_signal
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0x70177200	ps3_write_phys_ctr
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0xa76ee01d	ps3_read_pm07_control
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0xaa190bc1	ps3_read_pm
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0xbb72a01c	ps3_enable_pm_interrupts
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0xce72c9c0	ps3_lpm_open
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0xdddfc980	ps3_set_pm_bookmark
++EXPORT_SYMBOL_GPL drivers/ps3/ps3-lpm 0xfae0ab68	ps3_enable_pm
++EXPORT_SYMBOL_GPL drivers/ps3/ps3stor_lib 0x47f966f1	ps3stor_read_write_sectors
++EXPORT_SYMBOL_GPL drivers/ps3/ps3stor_lib 0x5d3c1707	ps3stor_teardown
++EXPORT_SYMBOL_GPL drivers/ps3/ps3stor_lib 0xa74e4cde	ps3stor_send_command
++EXPORT_SYMBOL_GPL drivers/ps3/ps3stor_lib 0xae8af72f	ps3stor_setup
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x5cb83d5b	mc13xxx_parse_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x8346f819	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x9469f870	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xe107f118	mc13xxx_get_num_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xfe1adcbc	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x4cd49a31	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x619c6784	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x78457620	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x851be974	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xaf78164d	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xd55b95c0	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0x0f252135	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x071d7f10	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x083086c5	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x095eec65	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x389cddc7	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a66c193	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3d05e680	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x41bbd272	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x42b90d24	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x438f5b24	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x442a3ec5	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x469ea549	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x49be78cc	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4d5c2fd7	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4ded20e7	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5160e4bb	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x598deaae	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x59a22760	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5e57b688	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x618f556e	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x64546887	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x64aa1e25	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x66011339	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6b508666	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x71a4d4de	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x76aa5568	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7756b950	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x79b27b10	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7eeeca60	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x819d980e	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x87ef3d06	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9524d350	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9c7443e0	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa0d92c4f	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa2f5505a	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xaa2b83f7	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xcbe0a2b3	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xcc3833cb	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xce24fb57	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd35a5a89	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd753ea09	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdea166e0	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdefbd2f9	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe3c34029	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe65886e8	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf4b36a58	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfde833f8	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x1cbe5abd	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x205cedd5	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x21517370	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x4678473f	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5cf290d7	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x752efd66	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x761057ca	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x7b4d2997	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x881cffe6	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa0e3b505	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa6398a98	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xc763abf4	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xcb88f544	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xcc91b40c	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xd761477c	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xecba022e	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xb87f3102	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xc06e8d26	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xda7e8d35	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xe3925ea6	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xe5dadf38	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xe64536e9	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x09b02322	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0b32cf3d	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0ce510ee	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x15b75eca	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x22aba5c9	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x259dbe1e	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x25d74c3a	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x296c389f	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2e2595bb	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x38ccd8f0	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x42721d59	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x49aa5c9c	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4bc5d58c	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4dbd90c6	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x56d0e3b8	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5ce14d5a	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x61361633	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x63497a04	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x75bbdefc	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x75fc851c	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7b691925	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x85869f4b	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x94c2ee1d	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa5f1f3ac	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xab61a0c5	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb14025f7	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb7acb387	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbdb75393	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc59038a3	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xcbdc33d6	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xcd440774	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xcdf59b42	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd088763b	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xda207789	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xdb23de01	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xdce999a0	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe1c85433	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe58c4bb2	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf12a00cf	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf29c68c2	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf32e6b6d	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xffbce605	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x1bc78fcb	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x1d0b61f0	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x220072c7	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2755823f	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x360631bd	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x3956cd69	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x58a826c1	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x6738a0b6	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x6a990e51	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x76cba940	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x7d8a6fd1	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x86983d79	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x89898b1a	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xa0c9ace7	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xd15131c9	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xd42bf4ea	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xeb2cfe69	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x0ad9426b	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x124cd921	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x15a2ddf6	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1b6d224b	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x34919a42	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x36e524fe	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3a0088a1	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x52552a8a	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x54998e8c	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5fe18ab3	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x61422a54	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x61a165b1	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7162832a	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8092d328	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x84a68575	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x85e67a34	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8d5b2002	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x988319fc	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9f1ec868	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb556dc3b	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xcb878705	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xcd1c2685	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xef8e211f	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfeb7cdb2	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0a8a9b99	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0cdda20a	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x18d95484	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1fa7283c	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x24c512e6	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x28abe31a	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x295e84d3	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2e10149c	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2fcc9618	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x39c0b3ec	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x42e5378d	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4e86bfa3	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x54e1d631	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x57644eb2	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5f7d7231	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6ce92430	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6d84d6d2	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8075b3c4	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x831289ac	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x95284280	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9a1c4fc9	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9cf75bef	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa428d7a3	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xaa97ad3d	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xae794e93	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb6263ecc	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb7c65f25	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb99f17ab	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xba22e9c1	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbf3fc253	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc6891a84	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc7fb85a4	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xcd1cd740	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd77cbffc	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd9312f6b	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe03a3f43	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe8b0e47b	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf883f498	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf886647b	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfe2b4568	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x2e522473	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x605ec980	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xd617957b	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xe0ebdf86	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xae363270	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x08ad3837	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x3a9f8342	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x40a4714d	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x70b696ee	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x881a7d84	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xb08dd595	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xefa4e7cc	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x1a75bf79	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x2c924f3f	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x43d4f93e	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x46ca0742	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x6d0aacf7	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x6da6b3a0	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x923781ba	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x3c1b73e0	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x7b17dcb9	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x85e8f064	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xa0f9967d	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xcc9db2ab	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x1bdb172e	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x56d8f739	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x5ec7f4ee	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xd0aa3146	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x2d2fc24b	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x32d9999f	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x3899dfbb	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x45b33f69	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x61b5406f	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x66f6eaaa	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x6ade2f05	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x6ea0c81a	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x742aa01d	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x75d7c4e4	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x83ab82e9	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8b49a6ca	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xa3e652f5	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xab083af3	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xb43bf864	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xeac60bd7	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xf3c1974e	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xfe69b5e9	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0x13e89180	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0023b7a9	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x02ae8f1c	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x088e864d	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x14acc83b	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x17b7b0b7	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x20d446a0	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x27a6dcfd	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2ed710e7	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x350b69a2	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3604154e	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4155536d	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4bbe0da3	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4d6a014e	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5b6a34fd	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5b88e210	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5ea18d84	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x707b34e8	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x739cac7d	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x80d47233	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x84a8fe5e	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8a59073a	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x932e8d78	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa53ee29f	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xaf707256	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb37e7706	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb7ab2852	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc4e0fa57	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcb070c80	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcc8e0523	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xced668a0	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcf074b61	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcf9f5edd	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd5b30460	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe1460de4	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf4f8685a	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x12f1349d	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x1b601037	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x3db405a8	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x409f9125	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x7a3714c1	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x8d1638aa	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xa007b62c	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xef53ec9d	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x3310763d	comedi_pcmcia_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x7362f825	comedi_pcmcia_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0x8a2d00db	comedi_pcmcia_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xad57f9d0	comedi_to_pcmcia_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xde0cdb7e	comedi_pcmcia_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xf64b54e3	comedi_pcmcia_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pcmcia 0xfa1ef615	comedi_pcmcia_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x001a50a1	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x2379cd06	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x5985ef3a	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xe39846fd	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xe54fa0c1	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xed4972db	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0xa8091c18	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x40319c02	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0xbd93163e	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0xa3e528de	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x103ca854	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x1de0c56e	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x359e4a8d	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x45e6780b	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x4cdd5585	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x6abb9cf5	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x71323371	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x7c19cbc1	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x7f2a609d	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x91b1a70d	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x9cc82b65	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb31cb7af	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xcbc8ddc5	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xb28bcf62	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xf2085da8	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xf4f55374	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x0d68fcd9	comedi_isadma_poll
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x12fba874	comedi_isadma_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x4a17474e	comedi_isadma_disable_on_sample
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x6815a033	comedi_isadma_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa3d01a85	comedi_isadma_program
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa7ebb8a3	comedi_isadma_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xafa9f21f	comedi_isadma_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x152e281c	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x13005f7d	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x2d06d51b	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x3b41f90e	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x3e6c740e	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x419690b0	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x446649d3	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5589ead8	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5b1d9330	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6a536d62	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x7dc30464	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x81299e3d	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x92849294	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x9a2959f9	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa0ee00ed	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa967f2c9	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa9ba3901	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xdad89f55	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xdb71cc09	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xdceab65b	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe5142d3b	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xfc4c8142	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x18f6b67d	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0xf1f3d71e	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x0b951f00	labpc_drain_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x378ec067	labpc_free_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x928b697a	labpc_setup_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xc4b1ae5d	labpc_handle_dma_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0xdeda05ea	labpc_init_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x15ccf5d4	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x4022d7d0	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x648eea4f	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x8261138f	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x9441ab1e	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xb93d8b3d	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xbbe0a6a4	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xfc26eb81	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x35efa84f	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x62026071	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x622161e5	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x9299b956	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xa18b74d6	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xf966f188	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x041648f3	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x0d8bda07	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x334849e3	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x9908ffa4	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xa978a929	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xe1b279ee	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xf530e340	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0x5ef1ce85	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x094014f2	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x0c0dcfaa	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x0e647359	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x236a7eef	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x2d011db3	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x3cbefa02	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x488270ba	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x6271e1cf	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x73aff57c	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xa5cabd5f	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xad4566ad	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xd7149cdc	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0ef1d765	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x2c1cc975	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x328c5ceb	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x32e11a24	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x37d50f09	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x5d7fe909	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8630a342	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8fe30596	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb35aaab9	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc4f94450	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xea9276db	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xecbb5328	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x04f62162	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x3885b1e0	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xbb3083ca	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x4a77af33	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xd5adc12e	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x701e2a8c	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0xfc8364f3	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0x54590dc1	imx_usbmisc_init
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xa527d8d3	imx_usbmisc_set_wakeup
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xac3b1053	imx_usbmisc_init_post
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x2152401f	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x66971498	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x7de091f1	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x9f0deefd	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xcec0f72d	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xd04441af	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x21cf9efc	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x2b2c3235	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x41273b5e	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x4eb92ca8	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x5f4c65d5	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x65b60376	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x667646cb	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x6ce46e29	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x75e1f994	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xab8e74ce	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xc31e20c6	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd87018be	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xdb4b775b	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xfaf334f2	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xfcceb23c	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x2c710942	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x496a154f	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x89ca818c	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xd371dd12	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x72174fd1	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x85775153	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xbd45738f	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x086cefa9	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x204f04f8	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x322309d1	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x39c6cc97	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x41197b3a	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5bbe013a	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x854c2608	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x888d7d38	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x892dcce0	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a2fb2bf	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xad048104	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xcbfff8c1	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xde031ea0	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xe0257d13	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xe5712d6b	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x0ae4bb89	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x10f0f0d8	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x1515e62c	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x219fabca	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x288c7fdc	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x5151019f	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x57c20800	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x7ae731f7	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x9dba1f97	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xa7623d4f	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xa81e889f	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xc8e6138d	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xd2420d0e	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xd88db3bf	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xfd570cb0	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x056bcef8	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0e671859	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x1497dfeb	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x23f76c73	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x3e637b16	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x459ba287	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x481e216c	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x57468714	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5df7250b	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x68494784	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x69bf8e11	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6cec324d	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6d7e8f26	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7dc39d5b	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8140780f	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x834ab595	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8a6997b6	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8c5994d5	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8cf50296	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8f7db9d4	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa690eadf	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa9a4b99f	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xadb8a7fc	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb30c10e1	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb5740993	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc04a1642	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd799767a	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe687300f	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xeea486e5	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf3f5cb39	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfc68b1bb	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfca56178	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x055cf9a4	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x2797940b	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x6146ab2a	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x66dc50cc	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x6782dcbb	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x947468da	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x969cb89d	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa4744dba	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xb6947c75	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xb881d504	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xc214e5b7	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xc5258ba8	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xd60eadd9	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xea784a4b	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x009b90eb	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x5d032f18	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x185cb878	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x68a3d74e	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x68c8fe97	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x70c4c6cc	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xbe8119dd	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xdbe1d17c	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xdce2527d	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xe4be2d36	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xf94cfa27	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x28f626d9	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0x76c1e057	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0xdede609e	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x047e9a67	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x18af34fb	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1bf1a2b6	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1fd3e788	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x28af7844	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x3c85c857	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x3cb45a2e	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x487860c1	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4ac07c59	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x52c6fcfd	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x52d91a2b	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7a714f1b	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x804746e3	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x8c34aa28	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xb2c74f64	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xba910249	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc15c78a1	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xcaf67912	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xce37a9dc	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xed01985a	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf774f1af	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x093115a7	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x184cfd0e	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1ead8da2	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x37bccc40	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3d072140	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x42e764de	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x43bcd0ac	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6aa0fda8	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6c6a7050	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6db4dc91	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x7b4bbe37	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8548ae57	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8bf6d293	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x91b1d599	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x91ddd6c8	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xa5b68545	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xa6face7a	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xaa3f1fad	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbfd69221	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd471309c	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd4de02aa	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xda541682	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe1e11d09	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf47354a0	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x08d7f2f5	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x32fa5e7a	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x4460eda3	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x56069254	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x6abffe4c	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x7f43f216	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x860e311a	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x96f19687	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xbd38b54d	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xcb543eaf	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xdca99d17	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe44732ab	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x0bd816f0	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x122f15ac	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x1f06897b	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x2d4f6421	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x452d4ec4	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x7c268d04	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xb6b8cd05	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xc1a3c629	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xd9cc0b73	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x155cf021	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x2d80c98f	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x3e12dd9a	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x646eb150	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x719511e4	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7617321f	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x914134c3	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb76794f8	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xbe37b733	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xc6784380	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xd014aa04	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xe094a3ab	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf36ee835	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf9284b24	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x297425af	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x47755f9e	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x6c293fc6	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x0131042a	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x1f9cd4f5	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x23f94698	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x2b2da01a	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x4229e122	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x49dbdb36	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x4e2fb7d8	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xb7e181e4	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x033855e8	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0ca333c1	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0d72b226	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0d78016e	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0fc02440	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x11881e89	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x12a4bdf0	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1eee982e	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x20b26e7e	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3003e3bf	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x37ecb358	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x417c9083	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x47793333	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4cbaa3d9	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d2f5e55	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4de5bb37	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x571cfcc2	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x57695d9c	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5c13116e	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6998adc9	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x703cc0ab	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x816b9e92	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8728b593	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9360ee93	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x96dad555	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa18dcc24	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xac97316b	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb0da7b1a	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb12083ef	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb5cdf45c	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc129bee3	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd0e36a67	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xdc8dec80	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xed7dca46	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf222026a	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf29bb918	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf52c07d8	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf5753b4a	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf841109c	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xfbeb89ad	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xffd07b50	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0xb6ea00a3	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3567743b	vfio_external_user_iommu_id
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x36ee14dc	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x5e710e18	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x7cbdd467	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc1d989c5	vfio_external_check_extension
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc4913442	vfio_group_put_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xcc6ba1d9	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xd6f52eda	vfio_external_group_match_file
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xecfaf05f	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xf235e029	vfio_group_get_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_spapr_eeh 0x22442a0a	vfio_spapr_pci_eeh_release
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_spapr_eeh 0x331f2d7c	vfio_spapr_pci_eeh_open
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_spapr_eeh 0xac0624b4	vfio_spapr_iommu_eeh_ioctl
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0xc4c45e18	vfio_virqfd_enable
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0xd09e98f1	vfio_virqfd_disable
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0020a7f1	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x08f00ba5	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0e9b847b	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1600c917	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1f2381bc	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x232e27d4	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2deccce2	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x348fe750	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4206f210	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x43ef147a	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x517051fe	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5a47ff2a	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5fc23af7	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x6676d02a	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x73d2d2c7	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x7b75e6b5	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x94ef85ca	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9bcd1d38	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa239804c	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xaad1103c	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb0f81e37	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb7a57865	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb83ee814	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xba2a2cd5	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc96046ba	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xeccc2afe	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xedebb477	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xf14a06c4	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfa874ea7	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfd32ca0f	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x152e013d	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x2a82b427	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x449e5cad	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x67f9d325	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x6a7213f4	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xa6f3ab8c	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xd116aa96	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x00657a29	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x137a0968	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x362128d2	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x57b2b75c	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x5fb5928a	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x7d804637	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x8ad97ebd	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x9e479296	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xf798979c	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xfd9ae4db	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0x10c11783	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x92cf226c	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0xe1636414	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x60298ca3	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x64d99dcf	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x6aeea7f9	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x8e3048a1	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x99ad97a1	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xb06ecf21	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xd7ab5f03	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xf2991889	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xf37b4d1b	w1_reset_bus
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xa6cf6fd1	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xccae7310	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xed4eb740	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x38250388	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x3bff28f0	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xab2ca34e	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xcf3ab20e	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xe6aaabbe	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xec630d3f	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xfc834fa2	lockd_up
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0491f44e	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x079f16d3	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x08887efe	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x09a988f4	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0a06103c	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0a35dcd7	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0a45997e	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0d5083b6	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0da4339a	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x10c9d46f	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1297a872	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1799d7ce	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x17a3755b	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x18296ea2	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1912fc52	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1991628d	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x199c794a	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1a1b13b8	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1e31b48c	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x22049097	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2419d58c	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x241d7011	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26810384	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2a79cd38	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2ccdfea4	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2d74d633	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2ed36eea	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2f929463	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x302f0a41	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3b46ec8f	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3cc5f2b6	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3d307359	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3dd02ea5	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3e6bc3da	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x410a1406	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x420f4985	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f888e1	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x442f0f79	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x447cb8a0	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x47aa1b70	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x487ca243	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4996d663	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4a55edf9	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4aeb9bef	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4b84006f	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4becfd7f	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4f04f44e	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5001eed9	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x50fafa04	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51a2eb6b	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x52deda29	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5413f6eb	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x611e892f	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6266cf28	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x677aa109	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x69dadf36	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6a02d6d4	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6c427573	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6d6d09ad	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6d6ede82	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x746bb729	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x74ac0104	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x763fc1c7	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x78e6b80e	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x799d9eba	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7c9722ba	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7d4ffbde	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x82e3ed0c	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x84114017	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x875515b2	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x88b0d575	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x89d3a5e1	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8b1cc8b0	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8cfea285	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8d90537d	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9266c576	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x961aa807	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x978b7b7c	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x978d23fd	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9ace7385	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9bce6941	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9bd5d1f2	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9c15ed29	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9e0b59a6	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa18a2d4b	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa1fe07bf	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa1fe2bae	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa48f7f61	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa5359caa	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa678649e	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xab5cc48a	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xac81260c	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xae37255b	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb2efa82b	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb6173e57	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbac3d520	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbfd82afa	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc110bbff	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc34b1ba1	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc3709965	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcad221ae	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcc3ff06c	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcc59375e	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd0a06e31	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd4a4614a	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd936f31c	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd947a5be	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd9f7b3be	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdbf4b18b	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe005c5aa	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe0afb47d	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe14e5148	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe3ff6c9b	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe4d78b36	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe7b4af90	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe9eaae3d	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xecef9a36	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xedc96f58	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xefd6141f	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf7d34010	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf811a7bd	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf8ff8989	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb3a4253	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfd1aec08	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfedd1ef1	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0xbd512652	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x00698e91	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x01be322c	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x01f103f7	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0889a638	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0f24c793	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1093b108	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1d5155c6	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1d7b7668	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x291ffc42	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x299ba231	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2c1c1b9f	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2ecf524a	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2f77df31	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x341b63b6	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x353c4853	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x357e0dab	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x36b8f9c4	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4028597d	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x42bc85d2	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x451e162c	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x50ee935d	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x56e08a5b	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5f535152	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6076401d	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6085edbd	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x62b2b944	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x68d32477	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x75f7b9fc	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7994f9b5	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7b9688cb	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7c246b82	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7e92a09c	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x864f4d37	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x86ee67d8	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x923b555a	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x96cda1bb	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9fefd92e	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa1379094	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa588dce3	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa74b9957	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xab498562	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb0480ef3	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb2f84634	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb5f01662	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xba7df7eb	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbda7ffa8	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbfe94a6a	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc476f709	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc4a6288b	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcc31f688	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcf198957	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd08d0446	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd0b5b7dc	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xddeca130	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe1cd2c37	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe1fca6f8	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xea6664f4	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xec678543	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed5f3208	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf8e43d9f	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf958a1a4	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf9d4fb7a	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xbead0d11	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xd737c2cf	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xec074258	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x2b9befeb	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x61f468cf	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36a28a9e	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x414ccc61	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x41a606fa	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4284823b	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x439cd6e5	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x49ccdc82	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x81a17396	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd1b909ef	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf56c2017	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf6d91e53	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x22d2d9b8	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x266a8d09	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x336a0023	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x6c77c86c	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xde0c6c91	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xe1af5498	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x82f29278	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xdc8f9919	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xde97a098	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL kernel/torture 0x050a127e	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x2fc4479c	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xdf90a431	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xda48c513	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xe68f5700	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x1803a6ed	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x2b30f429	raid6_call
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xe4b051cf	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x0adcb055	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x221df614	base_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x4da25bec	base_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x63f42b6a	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x76203267	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xca3140ce	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfa5eee0a	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfc02472a	base_inv_true_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x2e5ea5dd	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x35bb4e83	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/802/garp 0x49e34a0d	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x688cb65b	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0x696a5f80	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0x7ef28891	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0xc1601444	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0xdb11cd49	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x160a0ba6	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x1d2e7734	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x339f426c	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xae7d88c2	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xc8dc5c26	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xe37ca642	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/stp 0x91c24153	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/802/stp 0xe58028d5	stp_proto_register
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x84bc9138	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/9p/9pnet 0xad286722	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xd186f8f3	ax25_register_pid
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x094a57a6	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x10b408a0	bt_debugfs
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x5f672994	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x65c70e54	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x96e90c4d	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x9dba0efa	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xb802185b	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xf7367c4d	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x3ac56222	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x5ba2b980	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x67e55de9	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x919e1c6e	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x9dff3d0c	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xbfbba1e2	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xcc219e22	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xe0b9cc71	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x065128b5	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0xada18b3a	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x008eb402	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0ca77cda	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x13a87924	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x148baee4	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x14bd2784	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x16579c11	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x21d8e13d	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2785cb39	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x282bfa9a	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2a25331e	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x313052ae	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x33b5291d	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x33da8964	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x36ebed91	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x37d8d640	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3cd5abee	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x40e8e43c	compat_dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4b9b86b1	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x512a97ec	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x57157d08	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5df7f0e8	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x684b4c1e	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6b1bbcc4	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x78e82e38	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7d8f39af	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa367a6dd	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xafcbfdd5	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb39d4299	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xba5a7149	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc0b7b890	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc392b284	compat_dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xcdac895c	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xdeba7ab0	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xdef336c1	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe5256155	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf9726c46	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x0201fa8b	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x2699eb13	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x37ce350d	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xa0de6b11	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xb00836fa	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xbaacbe49	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x84ddef92	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xd58dfa29	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xe399fae8	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xe5ea4bfb	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xed8bb6c4	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x3c757078	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xa062bd31	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x11a795a0	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x1eef80b4	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x9240b3b3	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x9dccfac0	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xd5bbf19f	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xfc6af6c1	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0x42f0e6f8	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x0009a5be	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x006c385f	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x007c4b12	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x1004b56d	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x23ea8fe5	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x503a75b0	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x5246d2f0	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x5594d3df	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x613a2362	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8e5d8f7d	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8f75d080	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xa14f73ec	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xb0b3bcfa	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd7343d83	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xe7675a53	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0x09a70eb7	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0x67730c2c	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0x972bfe89	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x0bac7b70	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x26cc2734	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x3f8c5c1b	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x448a6ed5	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xb1036f08	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x93113c42	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x556eb766	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x7927e6cd	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xa350fdde	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xaa37c449	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xd4080ddf	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0x8be3353b	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x2e0aa5f5	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x2efbe334	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x900ee32c	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xb7263727	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xd92b452f	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x6887a5b6	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x6bd14832	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xc21ea326	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xf711752c	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x1896da23	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x25587819	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x3d63e61f	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x6aa8db9e	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x7baa16cb	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x9d879f6d	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xdc37b373	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0xdd5f9a4a	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0xeb480b23	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0x3d3ef12f	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0xd7925945	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0xe7ae7ccb	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0x96d6df3e	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x44f41c3b	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x536a4554	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xaf3adbf9	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xcf34d38f	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xeaf928d5	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x4eea117a	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x0468e6c4	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x202428f2	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x3a2322dc	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x8d390f06	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xe67f0bc3	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0x4aa68dbb	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x07bb1a47	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x2f218397	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x4d248cc5	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x56a45a83	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x68b2ad28	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x7eb954d9	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8c8ce250	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xa531d19f	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xaea3c6dc	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xaee58116	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xb0e402a9	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xb0f54da2	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc422046e	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd7d0db17	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xdc0b1551	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xf72e0c8b	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x31d37411	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x11e1f72f	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x1f216d2c	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x3509d06f	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x3ea7ae2d	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x436b297d	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x48f8c3b7	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x58a151ae	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xa5e2dcf7	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xaa9e22d2	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xbbd912d0	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xbf6baac9	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xd3dc415f	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe335621e	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe3cf924f	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe5ce236c	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xed138827	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xeedf649a	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf02e21ec	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x4aa2a590	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xaaf4714b	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xcf88cd41	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf62259c4	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x15127b71	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x16178d9d	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x35aa1127	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4eab85ea	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x78efbe1f	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7a9e3e43	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x80acd9ad	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x8d90655e	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xabbd5796	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xad02d8d6	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xb7dd0933	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xbdf18266	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc51418a5	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd9ff3348	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xdc07383f	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xecf363d1	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf3b4d4ae	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x7a36bb71	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x7b664850	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x9ea7af34	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xedec70cd	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x01b733a0	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0806b749	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x08abc04b	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x10317300	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1092c645	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1129ea3e	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x14cd659f	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x17200120	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1f5034c8	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x22cd11fb	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x23f2880a	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x255bc382	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x26fb071d	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2844956e	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2932fc9e	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2a3b5279	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2b5ce3d7	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3183c7cf	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x358f4649	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x35b66511	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x36b94799	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37be78e4	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x381255b4	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3ee42c06	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4428c3fa	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x487404df	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4d01f832	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x52125a58	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x52762e7c	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x536925af	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x57e0e79a	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5dcdeefd	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x687ceb94	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6cc1e93d	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6f01b58d	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6f3518c5	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x75c6564d	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x776a147c	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x786ec06c	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7ae9d243	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x821d98a3	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x88bf1551	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8a66c4fc	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8a78cccf	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8e2741e3	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x900f4c12	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x902e1e08	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x910cc258	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9a005f8a	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa0e7daf2	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa2678830	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa38de0c5	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa65adf8c	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa6d11a30	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaa7304bf	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab45ced8	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb0315de2	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb0995cbc	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb1bb8812	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb21b418c	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb514a430	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb5c73cf1	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb74743b9	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb87eb3e3	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb8b637ad	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb8bbc9f3	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb8dd0556	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb9e2a42c	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbedbf140	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc8874d72	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcc79f824	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xccff34eb	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcf1cce19	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd5a7f646	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe581c365	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf1183df7	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf1b802eb	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfec95669	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xff40b965	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xff432ad4	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x8f22f840	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0x6cb9eb8a	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x39eaf9a7	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x2d9cb995	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x422afa80	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x43404dba	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x75145ade	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x77ab6c9d	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x8755ab92	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xa53fac17	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc34d1943	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xcd99edda	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xfca6fa7b	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0x2479848e	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x0f9b1255	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x3963bbfa	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x8b602659	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xd7d1d88e	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x046941dc	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xe6f5714d	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x10e37657	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x19a54450	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x51e2717e	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x8c00f9e0	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xc9ca5b4c	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xf4520007	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xf9725c31	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0xab197045	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0x78f271e6	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x005a5723	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x02dc3b11	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x5b33c2b6	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x922ff3b9	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0964338a	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x1fc86bc1	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x68af5062	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x7d49fc35	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x83cb278b	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xb5574acb	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xd9089592	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xdcdefaf5	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xdf56aaa7	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x59715d03	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xc6682449	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x49c0ee85	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x57541dee	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x5f339439	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x0a2e8dd2	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x242bc9ae	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x2922a9bb	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x2c2fa9b1	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x38627ed0	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x41592345	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x54bc90ec	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5bbb7a37	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x6598a104	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x7ca130a7	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x9735b676	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x9c2f96fe	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcdf195f9	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xd971396f	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xdb8f4e72	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe6ded357	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xeee05298	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x3e89d046	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x4efe90fd	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x638c4bfd	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xc5e85986	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xc62c3339	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xcad6ca43	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xf7d5fc4a	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x13f9fd9c	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x3b14297f	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xb88f62e7	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0x170adad5	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x2061a030	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xca220e4d	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xd17ee5a1	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x2019b74f	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x6277a917	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x627b3405	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xa6263990	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb05807ca	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xff76e639	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x3952f49d	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x6b2c040c	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xd9b1c29c	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x127c8c95	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe826ab40	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x099ffbc1	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x0f25e212	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x161d1417	xt_compat_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x30d4d1d7	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3ee707ee	xt_compat_match_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x520a7425	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x557ffec4	xt_compat_match_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5f82f1f7	xt_compat_flush_offsets
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x691a6d69	xt_compat_calc_jump
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x6d983185	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x73cee41e	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x74a8aacf	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8f781f58	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x93e08676	xt_compat_target_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xa0514c9c	xt_compat_match_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xa4ae47ae	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xaf7f4715	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc0a6b30a	xt_compat_target_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd675edd9	xt_compat_target_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd90dea45	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xda835347	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe0b4971b	xt_compat_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe8114423	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xea70e42b	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xec24fd82	xt_compat_add_offset
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x00204983	xt_rateest_put
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x482b6a12	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x31868ad5	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x38ffbe78	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x4f5d99da	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0xc15b4350	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0xd8f45c9d	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0xe2c2b12d	nci_uart_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x33b60364	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x3969246a	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x3ad476a8	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x5c698805	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x77899f1f	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x7ad1a59c	ovs_vport_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x94d7e6ef	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xc9ecaa04	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xfdf2e2c7	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x06216803	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0x117e2bd1	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x239e4fbc	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x2fb2421a	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x33d13777	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x3aae5ad2	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x3fbd6267	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x510dcbd5	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0x512ee5c7	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x56ed2988	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0x5af9304e	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x6765fff8	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0x6ac3863a	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0x7342a9aa	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x75e9484e	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x7bc62829	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x7ea82da3	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0xac0f64df	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0xae060a48	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc40c839a	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc8b8e5bc	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0xcbe1db3d	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0xd2a629b3	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0xdd630fc8	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0xfa5518f3	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x3587347b	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x35c0fd46	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x1d93cd44	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x3944e31d	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x93d2951f	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x00205858	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0178236d	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x029bc2ff	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x02a9208f	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x02b61de1	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x03085dd4	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x03aeaf66	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x03cd562e	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05b30953	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05cb0e57	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x091a78c4	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0a15a320	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b41a233	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0cde1478	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0da06165	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f69e935	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x10f5cec2	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x13d9a2db	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1419cf1e	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x154eec05	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x15fd90ad	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x16795e5c	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x176f5355	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x177c01ec	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x19afe50b	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1bcf8fde	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1c16ce0a	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1c79404f	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1e5683ed	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1f2a9970	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1f3a28a0	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1faaadf2	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x22973c65	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x23f1a9d0	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24029222	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2463e1b7	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24798edc	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x25e4a117	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x27ba9da6	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x28f05506	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x28f9a39c	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2beacb35	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3121985b	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3333f2cd	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x338eb18b	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x359ef522	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x35b930bf	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3790281c	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x38ca3952	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3a61227f	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3a78d1d6	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3a7e83bd	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c58b1f9	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3fc2b44c	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3fe5aefe	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x41873110	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x422a7162	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x430f6789	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4358a891	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x46e6fc24	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x46eef2b2	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x47bba23f	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4838a49c	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x49bda1e5	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4a1fa87e	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4b40b8b6	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4c97f7e1	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x562de462	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5740bd2f	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x589cc465	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x592afd3e	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5931664b	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b09d677	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b4648ff	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5d273190	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5d2d3b65	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5d3646c9	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5e09b519	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5e7e8ed1	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5ec48605	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5f7002e0	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x60b6fb2d	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x63338c24	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x64889298	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x64b640f5	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x64c45fc3	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x65e7b4e1	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x67008697	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6b661a16	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6f0977f7	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x70442708	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7323910c	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x73ae9673	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7647665d	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x77892d22	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7ace4a0d	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7b40775d	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7b41b366	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7f18136e	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7f642dd2	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8120cef4	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x82b2b541	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8300aa9a	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x84acd527	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x84d0053f	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x84dd43b5	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x866c7c68	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x87380209	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8a329aae	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8a81910b	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8ab18ece	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8d0c7739	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x91d9401b	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x939c9f8e	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x97434093	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98afa717	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ef449af	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ff8ae9b	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa11aa20a	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa152ee39	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa1b052e8	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa3406fbc	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa35b00c2	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa392b9ac	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa48b3156	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa5d07f41	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa8bd49b4	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa9a4e487	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa5203b6	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xac128a1b	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xac852899	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xacb9ff56	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xada71f57	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb38389fc	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb4af5e80	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb8593adc	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xba14d3e7	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbaffc857	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbcd702b5	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbcde3712	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbd7c3ed1	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbdd16a0d	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf93b0c4	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9c1e2a	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc07552ed	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc14314da	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc16d29a7	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc1d8a2e7	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc4ab32a6	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc6f98b9c	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc7317cb4	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcb45d50b	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcb81aacf	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcc9b8b2d	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcf9fa5b2	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcfc96d3e	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd1a95cef	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd4ccfa0b	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd5ad24f1	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd6299b64	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd6cc4bff	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7e4a8a8	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7f3c3a8	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd88dadf6	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd9b71c4c	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdc0b4d59	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdd6b720e	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xddf89bf1	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe0bafeaf	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe0c45ea4	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe14f00d0	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe30c298a	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe35d9c90	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe3820c21	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe48e15ce	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5728e56	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5e3a05a	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5fffcb8	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe6179d77	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe6cd602b	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe7205adc	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe8a3652f	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe90d925c	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef0c21e4	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef21b4b8	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeff83086	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf2551320	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf325b0eb	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf36e613b	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf47c2061	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf4eca3f8	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf753b43c	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf78a7308	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf7ed01ba	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf87f521f	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9c84c3f	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfd0814e6	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xff5f705f	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xff89b4de	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0a071c71	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x229b851c	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x31917dff	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x3a711b8f	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x59d943c8	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x66a4d8eb	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x67218629	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x6b2a9a4e	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7574247c	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x84b6fdc2	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x970b77bc	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xadd34496	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbc8954a0	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xe0892b3b	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf4c8612b	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x2e302cf1	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x44e639d3	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x5073a01b	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x5b667224	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6b125b12	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x7d6adb01	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x91b6c2be	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xaae5e8cb	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xbf4bdb5b	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xe8f43063	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xebc014f8	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xf475534f	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xf560c607	wimax_state_change
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x09570590	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x17dedce0	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x1b80b395	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x2943bf20	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x4d82e95e	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x7d3fc0d2	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x94b629aa	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xa7fe0e64	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xafcc626f	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xc00d7926	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd422dfd0	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xe5582083	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xea0e0e25	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x2a8af3d2	ipcomp_destroy
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x9afdc271	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xa1ddd586	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xf4baa564	ipcomp_input
++EXPORT_SYMBOL_GPL sound/ac97_bus 0xbb551a52	snd_ac97_reset
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0x1540d5aa	aoa_fabric_register
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0x16557fa8	aoa_codec_register
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0x3690bf38	ftr_gpio_methods
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0x73b75b21	pmf_gpio_methods
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0x84a16bc3	aoa_codec_unregister
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0xce561047	aoa_snd_device_new
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0xd135a3b6	aoa_get_card
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0xd6e05915	aoa_fabric_unregister
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0xd6f33f42	aoa_fabric_unlink_codec
++EXPORT_SYMBOL_GPL sound/aoa/core/snd-aoa 0xe95e8b23	aoa_snd_ctl_add
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0x39da679f	soundbus_dev_get
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0x5f9d1118	soundbus_unregister_driver
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0x6325a7e5	soundbus_register_driver
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0xd1c70478	soundbus_add_one
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0xd1d39f53	soundbus_remove_one
++EXPORT_SYMBOL_GPL sound/aoa/soundbus/snd-aoa-soundbus 0xd828afab	soundbus_dev_put
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x4c322ed4	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x8b54ea64	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/core/snd 0x47813dde	snd_device_disconnect
++EXPORT_SYMBOL_GPL sound/core/snd 0x87a096b3	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL sound/core/snd 0xad97d915	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd 0xe06764fd	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd 0xedb349e4	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL sound/core/snd 0xf8f3e16e	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd 0xfa39de9d	snd_device_initialize
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x01bdfd55	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x50437df9	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x520abdb1	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x55c1c3b0	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa8845a67	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xc4f520b4	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xdb59e892	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xfbe4bf5c	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xfcf2cb8f	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x33da9d0d	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x3c826e29	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x4ac0ae82	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x60a55e4b	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x728ae100	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x9396db83	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xa0b17f3e	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xbbf52c5f	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xd1988dc9	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xdaeae569	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xdf85e666	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x1c9dfae8	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x1cec176c	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x47fc6241	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x4e7ed910	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x747746ea	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xdc6d154f	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xf54b34c1	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x00556a6f	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0b2b83a3	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0b5be3ec	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x100e2023	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x119e994b	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x15aa74b5	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x17c3867d	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1abbc92d	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x22d78df7	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x23edad63	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x23f7fd45	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x29188065	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2b447dcc	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3700fbb1	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x37de8864	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x38a574b1	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3c1cc2d8	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x40c23a0a	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x45a79159	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x474f305c	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4c6a182a	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4c8eb369	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4daf463d	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x4e3ab7c5	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x504913d9	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5a6a0bc1	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5d0c3cb8	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5fe9a020	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x60621f94	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x65e28a38	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x662c6a72	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6b29485e	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6b894a71	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7078c865	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x758d67f9	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7d33a577	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8e891e43	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8eda420a	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x913f528a	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9271523b	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9603b0a9	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x97cb1210	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x97fe1b0b	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9cb4fa81	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9e8c77c1	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9f265c13	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa33d0524	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa6a3ee2f	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa6c6c1bf	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa983e1cc	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xae071473	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb6a315f6	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbaed5c22	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc16b669a	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc6b400bc	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc8ddd686	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc93890a0	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd10dca5e	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd188b73d	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd21ac76f	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd445c9b0	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdb892db0	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe7aed970	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf0f2a9bc	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf583e0b4	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf6370613	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf81a37f5	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf92388e2	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfa15fc1f	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfd10b9cf	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfe63404b	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x03810eac	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x292e7897	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xb8920474	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xbdb70ed8	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xd31e1255	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xf6d5a329	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x01324678	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0583d2c6	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x06d4d116	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0b1d079a	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0b619a16	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0bce9f92	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0f32b199	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1160a965	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x117ed84b	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x13cf2571	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x15094ece	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x16ebfc07	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1a992d43	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2120c873	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x24609b09	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x25c8902d	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2988ebab	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2aa07678	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2b2cba7e	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2c7c5b16	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x304e7839	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x32e2f519	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x33bf4592	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3819ff43	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3a30aca1	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x414d8d4a	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x41bff7d2	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x47330cc8	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x47a733bd	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x491f93e4	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4a20bda9	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4a3a86de	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4b277430	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4d226f8d	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4edb06df	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4f40d579	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4fef4769	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5206be38	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x52e95515	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5314174f	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x57bd7ddb	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5860c5d2	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5e8b9b31	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x60aaf041	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x614e5b51	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x64194649	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x64dc0d6a	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x66ae882f	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x67e285c8	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6d663b70	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6db28eb7	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6deccca5	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6dffb25c	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6ecc8518	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6f80267e	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7159c278	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x75650aeb	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x766e41ed	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x77907f6e	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7ef3197e	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x804ac92c	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x80f90bf8	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x82bf1123	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x837914c3	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x83e5ecd4	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x861fc8cc	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8864f700	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8a008635	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8b6a0d83	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8d4b3b24	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8dd569a6	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x906310b2	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9181271d	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x931845e4	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x988c1a4c	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x99b7e6e3	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a0631c8	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9d2ae83b	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9d4c72f4	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9d5e6520	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9e9ca90c	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa0decbe4	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa280bed0	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa8edc45c	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xae2a8a82	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xae4317ad	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaebf14d3	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb2bbaf24	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb6398d53	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb92f49ea	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb9e9a57b	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbdf8d203	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbf00b6ab	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc8a0cf70	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc8a94d09	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcb8ca193	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcc583fa9	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xce4086f8	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xce49edce	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcee92f02	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd05af8c1	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd1f9b930	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd28a4b21	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd65b134d	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd8e94f92	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd9ff1201	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdd11f3af	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdd48362d	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe23db616	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe55a25e1	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe5fa2dcc	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe836431d	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xea488fdb	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf098815d	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf1f85d43	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf3d321eb	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf4128783	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf5d3fed2	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf8503f9b	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfbb33295	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfc2070b1	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfca7eb6d	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfe36f654	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfe7ab4aa	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x012e1696	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x08532869	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x0ed90493	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x31dfdc17	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x3415c440	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x353ee00e	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x4b49b383	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x50d0e85f	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x5741b7ee	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x5f507c91	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x69daada4	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x77fae1e4	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x836b2836	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x8c06ebd0	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xaae3eab0	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xbfa908e8	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xc5eb35f7	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xd334963e	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe39d230c	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe5a3cd35	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xe89a75b7	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x288cb9e2	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x4b1938b1	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x7d05786f	cs4271_dt_ids
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x68ef52a5	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x70aa678c	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x723062b0	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x9b25c2d0	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xfa7c6897	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x42e73429	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0xf8fff8f0	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x5a7ae22e	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x820271ef	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x8fbc5223	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xea77fbe7	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x16e227f9	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x82f739c0	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x926c0b3b	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xc6b166b0	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xea57ee42	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0xede00e6d	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x1a003c99	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x81bc4063	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x03db4d76	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x5e4c4977	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0x41c3eff1	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x1a0e50ff	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x20283b42	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xb02bfeda	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xeb1b40a9	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0x96684a01	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0xfafc784f	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x44e9ef56	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0xd2fb4448	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x04016735	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x092ba9f1	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0c8465db	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0cb2bb34	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0cf33999	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0ec6165c	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0fc01079	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x104f9f9b	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x115bec98	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x11665a65	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x16123639	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x16af5a39	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x17433624	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1804d9fd	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1a2ac4cf	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1b5d524c	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1dadf461	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1fe0e3f8	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x234e8b63	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x23c647a4	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2849a5df	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2b4a2b2f	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2b66bad5	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2bc27ca6	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2e78e3cd	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2f8c0353	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x31228a32	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x315fdc34	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x32561021	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x329e5755	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x335d5817	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x33e84ad8	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x37310ab1	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x38493d00	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3a4d4655	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3d6ae4c3	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3f441a2c	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x417e03ad	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x439d5b38	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x44148178	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4426849e	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x451a4aea	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x472e7489	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x47d50a35	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x48ab1758	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4f9df73c	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x54064568	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5476be4f	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x55c78313	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x56794748	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x582cfefd	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x58c390eb	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x59d1008b	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5a7365f9	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5ac9f700	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5bb7994a	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5beb4ad2	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5c855f05	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5d71edf9	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5e1e78ca	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5fa5a3e4	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5fc037cd	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x62302bf6	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6306f4cb	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x636048f5	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x63700535	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x661e1457	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x666727d9	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x68fefcd6	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6aea6ec9	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6f6cd17a	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x700ae20c	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x70a4368f	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x72d434d9	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x732e8962	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7330cefe	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x75ed3b1c	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x77854522	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x779e82bd	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x77f41c8d	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7844935c	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7b625bf4	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7c1d9969	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e997fde	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7ed61e3d	snd_soc_component_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7fda3d35	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x81bbdeda	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8370a8d6	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8645cec8	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x87859e12	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x885cd993	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x897c4506	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8b189b3e	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8b4ac972	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8f262284	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x91af2687	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x98e77eb5	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9cf2d622	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9d475337	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa1de9210	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa1def2b8	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa57317bc	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa7f83eea	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa836b200	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xadfeaa4e	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb20bf7b3	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb3b68f7d	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb434f115	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb5eb3ca1	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb60ba4b9	snd_soc_component_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbcce02ed	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbd9ec89b	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbe23f011	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbf41af88	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbf673520	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc5f05550	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8a21d13	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8eb21dd	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8ff2506	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc9ee6403	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc9ef6c61	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcb50a639	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xce321379	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcebf21ee	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd0338238	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd0c38a04	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd3d0034c	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd53cba9d	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd5d1080f	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd5d4f88e	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd9266c06	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd9593b7e	snd_soc_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd96a9cdb	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdaee842a	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdbf49068	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe031e50a	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe1a81a8e	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe3261ce1	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe3615c8c	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe39f04a9	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe436e66f	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe6d83032	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe95c0400	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xec1d6e4f	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xedadfbbf	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xee25a445	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeeaf4593	snd_soc_resume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfc4dbb26	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x072dc4b8	line6_write_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x2f362553	line6_pcm_acquire
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x47e02733	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x53802e56	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x5fed077c	line6_read_serial_number
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x71e6cfe5	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x735364ff	line6_read_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x7f66a919	line6_init_midi
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x85da80d8	line6_pcm_release
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x87a4e21b	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xab30153a	line6_send_sysex_message
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xc51bcff0	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xcf488e87	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xf382865b	line6_suspend
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xf6baa983	line6_version_request_async
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x3fe35aea	irq_bypass_unregister_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x418873cc	irq_bypass_register_producer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x888c5be5	irq_bypass_register_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0xf6e772c3	irq_bypass_unregister_producer
++EXPORT_SYMBOL_GPL vmlinux 0x00115d95	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0x0012b231	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x002a1929	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0x002f3e84	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0x00399b76	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x004134b9	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0x0063fd57	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x008026e5	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00aa88b2	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x00c5da3f	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0x00cd9453	__rio_local_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x00f005a6	of_pci_range_parser_init
++EXPORT_SYMBOL_GPL vmlinux 0x00fa4f0b	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x00fb9383	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x0101e73b	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0x011546f1	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x01374e44	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x0146724a	isa_bridge_pcidev
++EXPORT_SYMBOL_GPL vmlinux 0x014c8d19	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0x01605ac7	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x019069cb	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0x0198905e	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x01b4922d	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x01e21df8	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x01f5b8bd	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x021ebfda	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0x02233d44	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0x02616e59	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x026211e2	memory_failure_queue
++EXPORT_SYMBOL_GPL vmlinux 0x02660cf0	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x027b8f71	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x0280ca3b	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x02ac1916	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0x02ad4f7a	of_get_display_timings
++EXPORT_SYMBOL_GPL vmlinux 0x02c19174	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x02d07ef8	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x02fa4cbc	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x030259d1	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x03035f0b	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x030948b4	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x03169d95	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0x031b95ca	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0x031c583d	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x0320231d	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x0321cdbf	of_alias_get_highest_id
++EXPORT_SYMBOL_GPL vmlinux 0x032dfb2a	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x0334631f	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x03604605	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x0361b531	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x0367355f	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0x036b30db	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0x038334e7	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03d1d11d	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x03eac3db	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x03ebdf01	cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x03f2ebf2	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x0402cbbf	preempt_notifier_inc
++EXPORT_SYMBOL_GPL vmlinux 0x043b935f	__tracepoint_io_page_fault
++EXPORT_SYMBOL_GPL vmlinux 0x045450c1	of_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x045a9fd9	dax_clear_blocks
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x049687b2	mpc8xxx_spi_tx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04b5549c	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x04c2ff0e	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04c5b187	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x04c9bf75	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0x04d26e53	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x04df8fbc	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0x05041ca0	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x050e83a3	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x051e9660	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x053494cb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0x0536d8ae	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0x05467eb4	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0x0548aace	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0x054b3775	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x054d71f5	put_hwpoison_page
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x0567496c	inet_csk_compat_getsockopt
++EXPORT_SYMBOL_GPL vmlinux 0x056f5f9e	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x0573de3d	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x0597ba8c	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x059e8d0f	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0x05c236bb	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x05e1cba1	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x05fe65a8	of_cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x061dee59	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x0628b1e3	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x064098e6	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x065d2993	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x06714f8b	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x0673a2a2	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0x0674377c	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x068b3a66	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x072a7bb5	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x074529f5	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x07655946	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x0779693e	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x077eedf8	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x078ab7de	to_nvdimm
++EXPORT_SYMBOL_GPL vmlinux 0x07a2e367	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07cc0d7d	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x07d24e09	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0x07d4f2eb	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0x07f92fcc	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x0842aa74	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x084e557b	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x0875da2a	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0x088bfa7e	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x08bc0870	compat_put_timespec
++EXPORT_SYMBOL_GPL vmlinux 0x08cc4820	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0x08d91c22	mm_iommu_put
++EXPORT_SYMBOL_GPL vmlinux 0x091c824a	machine_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x09243c0c	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0x093a0049	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x094b0def	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x094d41b3	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x0952af60	fb_videomode_from_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x0954e30b	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x096f88f1	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x0977556b	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x09b53db2	rio_mport_get_feature
++EXPORT_SYMBOL_GPL vmlinux 0x09fb1af2	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x0a0ecf04	agp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x0a2372bc	to_nd_blk_region
++EXPORT_SYMBOL_GPL vmlinux 0x0a3ec917	srp_release_transport
++EXPORT_SYMBOL_GPL vmlinux 0x0a51ae5b	virq_to_hw
++EXPORT_SYMBOL_GPL vmlinux 0x0a5c9afe	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x0a6871d5	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0x0a6c4c5b	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0x0a6d92f0	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0x0a6e7413	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x0a762b97	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x0a88f364	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0x0aad42d5	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x0ab099bc	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0x0abaec16	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x0acefebb	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x0af8b653	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b0f9568	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0b10fdf7	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0x0b2919f7	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x0b3da946	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0b72cbc4	of_reserved_mem_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x0b9e957c	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x0bd636eb	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0x0bdf8fdf	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa68d5	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c0eb96c	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x0c1ef682	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x0c26fef0	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c60950a	dax_truncate_page
++EXPORT_SYMBOL_GPL vmlinux 0x0c688bca	pmac_i2c_get_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x0c8049d5	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0caf75d9	opal_flash_erase
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0ce3ee5a	mmu_kernel_ssize
++EXPORT_SYMBOL_GPL vmlinux 0x0cf580b8	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x0d13b0be	rio_release_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x0d2d75db	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d58c7bc	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0x0d5e754a	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x0d655f38	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0d6dbac8	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x0d73a952	GregorianDay
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0d81b833	__giveup_vsx
++EXPORT_SYMBOL_GPL vmlinux 0x0dc87d52	to_of_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x0dcaaaae	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0de06988	cpu_first_thread_of_core
++EXPORT_SYMBOL_GPL vmlinux 0x0df33b44	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x0dff8f75	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x0e0c647f	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0x0e0ca9b7	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x0e4004cd	of_dma_get_range
++EXPORT_SYMBOL_GPL vmlinux 0x0e418f90	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0x0e443de9	of_fdt_unflatten_tree
++EXPORT_SYMBOL_GPL vmlinux 0x0e474955	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0e5323d6	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x0e83fd25	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x0e8d1d94	eeh_add_device_tree_late
++EXPORT_SYMBOL_GPL vmlinux 0x0e906f47	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0x0e9af9fc	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x0ea41f64	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x0ea6d8dd	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x0eb8747f	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0x0ecf823a	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x0f012044	__tracepoint_detach_device_from_domain
++EXPORT_SYMBOL_GPL vmlinux 0x0f312e86	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f403672	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x0f41aac9	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0x0f5675b8	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x0f5a5529	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f8f3d07	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0x0f9bddcb	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x0f9fa85e	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0fbfddf3	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x0fe3904f	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0ff99077	rio_request_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x100a1d99	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0x100c286d	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x106a46aa	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x1075491e	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x108c7b54	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x10ba5857	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x10e506c6	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x10f10e6d	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0x11006b37	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0x1104b38e	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0x1114011d	threads_shift
++EXPORT_SYMBOL_GPL vmlinux 0x11269d31	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x112b9f33	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0x1142453d	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x1143d96b	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x11537678	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x117c7305	hwpoison_filter_dev_major
++EXPORT_SYMBOL_GPL vmlinux 0x11ec9310	pmac_i2c_get_dev_addr
++EXPORT_SYMBOL_GPL vmlinux 0x11f61a66	ps3_mmio_region_init
++EXPORT_SYMBOL_GPL vmlinux 0x121d70f2	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x123c5a06	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x12435e56	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x12586f79	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x126334a4	pmf_get_function
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x126ce3f6	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x1277d31f	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x1285bdd3	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x128f1571	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x12b5a9fd	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x12e99077	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x12f14234	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x131960be	scom_find_parent
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x13299f04	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0x1333d8b3	ps3av_video_mode2res
++EXPORT_SYMBOL_GPL vmlinux 0x1346fc43	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0x134c6b64	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0x1352a964	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x135b6f81	shake_page
++EXPORT_SYMBOL_GPL vmlinux 0x13609dfb	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x136a4ee6	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x136f7c22	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x13816133	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x13879880	__online_page_set_limits
++EXPORT_SYMBOL_GPL vmlinux 0x13a44357	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x13ad647f	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x13b6a69c	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x13c0bae3	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0x13ce87e8	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0x13e5ea13	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0x14368ad1	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x143df0a2	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0x143f5cbf	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x1443f53b	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x14543542	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x14aaa60f	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0x14e69f00	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0x152f15ea	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x1556d068	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x15573bc7	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x158f2a11	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1590b827	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x1593ea78	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x159bd4a6	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0x15a976bc	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x15b73cde	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x15b8b44d	opal_async_wait_response
++EXPORT_SYMBOL_GPL vmlinux 0x15c21e5e	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x15e13a89	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0x15e36486	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x15e982c2	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x15fb444d	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x16368a2d	of_usb_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x163e1425	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x165ded07	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x1665c11a	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x167945e6	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0x16a25c6e	of_irq_parse_and_map_pci
++EXPORT_SYMBOL_GPL vmlinux 0x16a367e8	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0x16c28ca5	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x16dee715	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x16f60e2c	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0x170255ea	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x1713bde3	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0x172df468	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0x172f6b74	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0x173904fb	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x176d6f71	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x176e6f87	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0x1777634e	copro_handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x1784f2b4	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0x178630bf	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0x178ccf99	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x17994d70	memhp_auto_online
++EXPORT_SYMBOL_GPL vmlinux 0x17a728f6	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0x17c9275e	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0x17d00f98	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x17f52b5c	rio_dma_prep_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x18195212	ps3_vuart_port_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1829b9ed	hwpoison_filter_memcg
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x18570516	pmac_i2c_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1876bf5c	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x187fca46	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x189c7398	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x189e1b25	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x189f874d	powernv_get_random_long
++EXPORT_SYMBOL_GPL vmlinux 0x18a2b999	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0x18f07c09	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x18f17aeb	spu_get_profile_private_kref
++EXPORT_SYMBOL_GPL vmlinux 0x18fde2dc	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x19119803	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x19143053	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x19266e2a	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x19952d54	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0x1998135e	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x199b5afa	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19c8181f	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0x19c8f7ef	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0x19eb574f	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1a1186bc	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x1a29cc78	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x1a6ddb4d	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x1a8c5907	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1a997af8	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x1a9c1006	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0x1ac717e3	ps3_os_area_get_rtc_diff
++EXPORT_SYMBOL_GPL vmlinux 0x1ac78aa7	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0x1acdf643	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1ade859e	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x1ae2be00	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0x1b0abdd9	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x1b1e6981	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x1b24ff86	cbe_spu_info
++EXPORT_SYMBOL_GPL vmlinux 0x1b26cce2	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x1b2ed025	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x1b4da982	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0x1b6c3a2a	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0x1b79afe3	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0x1b81e382	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x1b9664d1	__destroy_context
++EXPORT_SYMBOL_GPL vmlinux 0x1b9a92b5	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1b9ae63c	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1be0f269	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x1c046692	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0x1c0b04a1	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x1c0d380a	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x1c17d478	nvdimm_blk_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x1c2ad10a	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c604b23	rio_dev_get
++EXPORT_SYMBOL_GPL vmlinux 0x1c67f56b	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0x1c7df74c	kvm_hv_vm_activated
++EXPORT_SYMBOL_GPL vmlinux 0x1c7ed57b	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c8467a1	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1cc4f463	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x1cc56a8a	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0x1cdb2147	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x1cf04771	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0x1cf6b27b	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0x1cf82066	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d3bbbfb	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x1d48651d	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d612ad5	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x1d652735	__tracepoint_attach_device_to_domain
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1db400d6	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x1db42a0a	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x1dcc65c3	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x1dd352f1	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x1df62b50	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0x1df728cb	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x1dfbcf4c	mpic_msgr_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1e000879	hwpoison_filter_enable
++EXPORT_SYMBOL_GPL vmlinux 0x1e02b132	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x1e10db7e	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x1e21191b	nvdimm_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x1e2b0087	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0x1e3c7bcd	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0x1e50c8aa	of_pci_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1ea4d517	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x1eabc257	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x1eb55386	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebac2bd	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ec78f4a	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x1ecc368a	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x1ece3553	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1eda8b26	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x1edc21cb	hwpoison_filter_flags_mask
++EXPORT_SYMBOL_GPL vmlinux 0x1eff5bc3	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x1f1988f7	hwpoison_filter_flags_value
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1fb2c51a	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x1fc19a87	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x1fc8bf02	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0x1fd583f7	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x1fe29d4b	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x1fe41691	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x1fe970cb	ps3_io_irq_setup
++EXPORT_SYMBOL_GPL vmlinux 0x1ff62646	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x2000f306	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0x20465c18	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x205f9313	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x2078d258	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0x207cc1d8	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0x20969450	force_sig_info
++EXPORT_SYMBOL_GPL vmlinux 0x209741c6	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0x20aa6f51	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x20db3b70	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x20e868b7	rio_mport_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x20ee0880	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x210b6c28	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0x210b7c46	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x21179e28	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0x211850f5	htab_hash_mask
++EXPORT_SYMBOL_GPL vmlinux 0x211910ac	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x212e5c68	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x213235cb	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x213a70be	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0x21740b05	drop_cop
++EXPORT_SYMBOL_GPL vmlinux 0x2174ccd9	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21b15331	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21e6f692	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x21e89329	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0x21f4628d	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0x21f6f76b	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x22051cfc	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x221c1f09	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x22229faa	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0x225a3a85	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x227fb180	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0x229403d9	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x2298af3e	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x22b65606	pcibios_free_controller_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x22c0abc2	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x22c6d82a	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0x22c834ff	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0x22dd5e72	of_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x22e35e01	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x230c44e5	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x2339faa0	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0x234390a7	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0x23499a8b	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x235696b8	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x23ca9708	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x23d09d55	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x23df16fe	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0x23e2664c	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x24011e14	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x241d3137	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x2422c82c	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x242acf30	flush_vsx_to_thread
++EXPORT_SYMBOL_GPL vmlinux 0x242f37f4	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x245b5c6c	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x247382df	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x24a6b0ab	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24b58618	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x24b6528e	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x24c75539	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x24e405c7	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0x24ea8218	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x2506d37a	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x25280496	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0x25470ace	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x254fc109	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x255bfb3c	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x2562ffe7	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x2569be2e	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x25a22ad7	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0x25b4d393	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x25d0854c	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0x25ddaa58	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0x25deb83f	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x25efd276	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x25fc4cc2	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0x25fd63e7	of_property_read_u32_index
++EXPORT_SYMBOL_GPL vmlinux 0x25fd9b0e	dax_pfn_mkwrite
++EXPORT_SYMBOL_GPL vmlinux 0x26030a85	eeh_dev_check_failure
++EXPORT_SYMBOL_GPL vmlinux 0x260b7b3c	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0x26279d3b	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x2665334d	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x267d35b3	register_cxl_calls
++EXPORT_SYMBOL_GPL vmlinux 0x2692314e	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26d57189	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x26e205ec	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x26f0a64e	of_modalias_node
++EXPORT_SYMBOL_GPL vmlinux 0x26f4f193	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x26ffe59b	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x27097470	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x27273f1d	ps3_vuart_cancel_async
++EXPORT_SYMBOL_GPL vmlinux 0x272ef517	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x27467e99	cpu_remove_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0x274e6d73	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0x2753d9fb	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x2758d55f	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0x27594b62	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2767b626	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0x276a409d	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x2783b6c9	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0x27a8f761	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x27b20e4a	of_pci_parse_bus_range
++EXPORT_SYMBOL_GPL vmlinux 0x27c0c4be	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27e122ce	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x27e1bbc0	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x27e4689b	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x27ecff21	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x280737bb	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x28438695	eeh_pe_inject_err
++EXPORT_SYMBOL_GPL vmlinux 0x28964e61	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x28a78079	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0x28aac262	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x28ac9544	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x28b32e8d	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x28c14e9a	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x28cbd918	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x28ee85ae	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x28ff99a9	opal_prd_msg
++EXPORT_SYMBOL_GPL vmlinux 0x290077ca	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0x29193169	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x292051c6	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x29260a91	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0x293014c9	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x294be81c	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x2982dd5e	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x298f792a	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x29ecfd2a	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0x29f09a7a	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x2a1aa454	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0x2a28c9f3	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x2a2b2c69	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x2a2cea1f	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x2a4c28dd	of_property_read_string_helper
++EXPORT_SYMBOL_GPL vmlinux 0x2a522257	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a68e97a	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0x2a9565bc	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0x2a964e31	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x2aa2cdbc	iommu_del_device
++EXPORT_SYMBOL_GPL vmlinux 0x2ae7a523	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0x2ae95ffc	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x2ae9a978	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x2b0cac10	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x2b116fc8	__tracepoint_add_device_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b313b68	rio_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x2b38a8e1	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0x2b4147ed	kvmppc_hcall_impl_hv_realmode
++EXPORT_SYMBOL_GPL vmlinux 0x2b45264d	spu_init_channels
++EXPORT_SYMBOL_GPL vmlinux 0x2b5c303b	smp_send_reschedule
++EXPORT_SYMBOL_GPL vmlinux 0x2b683158	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x2b6c57cc	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x2bb8da89	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0x2bcf63c8	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2bdf83b9	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0x2bf76044	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa985e	nd_cmd_dimm_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2c0d502d	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c252993	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0x2c284aba	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c361163	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0x2c661e79	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0x2c6930ae	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x2c69cd7a	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x2c758288	pcibios_scan_phb
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c8860a4	of_get_nand_on_flash_bbt
++EXPORT_SYMBOL_GPL vmlinux 0x2c97f8a2	of_reconfig_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2cbeb86c	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0x2cc3e675	pmac_i2c_close
++EXPORT_SYMBOL_GPL vmlinux 0x2cce6d4d	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x2cd0b218	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x2cd88f51	kvm_hv_vm_deactivated
++EXPORT_SYMBOL_GPL vmlinux 0x2ce236ee	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x2ce5e7e1	of_get_pci_domain_nr
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2cf7b9a4	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0x2d06ef57	pmac_low_i2c_lock
++EXPORT_SYMBOL_GPL vmlinux 0x2d0af271	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0x2d16ce64	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d51b0b2	to_nd_region
++EXPORT_SYMBOL_GPL vmlinux 0x2d5836bb	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d75d63d	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x2d89aa2b	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x2d93297b	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x2da2024f	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x2db4ed76	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x2dc5a6d1	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0x2dcb6229	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x2dd3fce5	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0x2e04c2eb	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0x2e11c9bb	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x2e11f62e	rio_release_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x2e15ff28	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0x2e1b5216	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0x2e1da9fb	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x2e1e550c	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e36fcd7	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0x2e3c0e31	cpu_remove_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0x2e4041ca	restore_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x2e49c487	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x2e745053	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x2e999cf1	pmf_register_irq_client
++EXPORT_SYMBOL_GPL vmlinux 0x2eabbc8b	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x2eb9a703	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ec0bf00	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x2ef54210	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0x2f0b43b8	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f0e0ef1	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x2f26ab61	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f58aff0	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0x2f5b7348	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f7a75fe	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0x2f7b52b3	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x2f92b9e7	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x2fa8b518	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x2ffb5ff7	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0x300deea0	of_prop_next_u32
++EXPORT_SYMBOL_GPL vmlinux 0x301832fb	opal_async_get_token_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0x3022fe58	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x3033553e	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x303a7c09	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x309f8915	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0x30aa391e	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x311b78c2	ps3_get_spe_id
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x31305867	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x313a769f	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0x315ba222	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0x318686b3	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x31b60a61	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x31bef441	opal_i2c_request
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31f84c2c	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x31fc341a	init_phb_dynamic
++EXPORT_SYMBOL_GPL vmlinux 0x31fc43cf	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x321bdbb1	compat_get_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x323529b7	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0x327d6fb3	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x32994aed	srp_rport_del
++EXPORT_SYMBOL_GPL vmlinux 0x32bc0fcf	preempt_notifier_dec
++EXPORT_SYMBOL_GPL vmlinux 0x32c23606	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32dd3902	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x32e79dfc	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0x32f4a329	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x3309ea64	ps3av_audio_mute
++EXPORT_SYMBOL_GPL vmlinux 0x33398de6	mmu_psize_defs
++EXPORT_SYMBOL_GPL vmlinux 0x334096e0	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x3347e499	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x336fff2b	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x3374cb15	pmac_low_i2c_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x337786fa	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x33adbe17	spu_priv1_ops
++EXPORT_SYMBOL_GPL vmlinux 0x33b1d788	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x33b4ddb4	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x33b57351	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x33ce0df8	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0x33d52338	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x33d8b31e	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x340279ed	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0x340ed33c	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x341e9bd0	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x342238f0	mm_iommu_get
++EXPORT_SYMBOL_GPL vmlinux 0x34400711	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0x34410a8b	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x34425f5c	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x349dd06a	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x34a1b74d	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34a8da5f	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0x34af0adf	opal_ipmi_send
++EXPORT_SYMBOL_GPL vmlinux 0x34b27c27	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x34db461c	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x34ed33a0	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x34ef2930	of_pci_get_host_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x351623ef	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x35369d77	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0x3538c2b6	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x353b5236	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x354f215f	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x3558defa	of_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x356cacad	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x359ed12f	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0x35bf2acd	nd_fletcher64
++EXPORT_SYMBOL_GPL vmlinux 0x35c7782d	of_get_fb_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x35d277ee	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x35d6d095	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0x35d8acd7	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x35db72b0	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x3651377c	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0x36584580	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0x3674cf5c	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0x368932d0	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x368f1fea	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x369e8aa2	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36bda7b0	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x36e5aea5	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x36f06871	eeh_iommu_group_to_pe
++EXPORT_SYMBOL_GPL vmlinux 0x371a939f	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x37661a54	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x37765f3e	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x37a3ab2f	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x37b6ac05	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x37be5e5e	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x37c872c5	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x37c941a2	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x37caf453	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x37ef4a9d	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x37f1eb05	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x3837af69	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x3847f9f7	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0x384e4458	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0x385476a2	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x38639300	of_overlay_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x38783348	macio_find
++EXPORT_SYMBOL_GPL vmlinux 0x3881c304	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0x38861690	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0x389e6c74	nd_cmd_in_size
++EXPORT_SYMBOL_GPL vmlinux 0x38ab32e7	pnv_get_supported_cpuidle_states
++EXPORT_SYMBOL_GPL vmlinux 0x38b5ba5a	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x38c05535	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x38c2e86f	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x38dd20d8	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x38e54285	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x38f37b26	rio_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x3902f52f	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0x391c1c8c	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x391eb929	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x39245a18	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0x392fe739	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x39395eb2	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x39597d25	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x395d370c	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0x395f7b46	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x397927e7	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0x398e0176	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0x3991e541	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x39a7a0cc	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x39aa369f	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39d5a248	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0x39db1b2f	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x39f00ac6	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0x39f04154	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0x39f158c2	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x39f61c73	acop_handle_fault
++EXPORT_SYMBOL_GPL vmlinux 0x3a029178	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x3a048ab6	mpc8xxx_spi_tx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a280cbe	thermal_zone_of_sensor_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3a2daa63	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0x3a3306d1	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0x3a38dc65	memory_failure
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a59ce3a	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3a6f5bdc	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x3a70b60f	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x3a7f40f3	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3ab20ec2	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3ad0e201	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x3afcdd7b	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0x3b07ce7e	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0x3b1c5afc	ps3_vuart_irq_setup
++EXPORT_SYMBOL_GPL vmlinux 0x3b5140b7	cpufreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3b675b2d	rio_release_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x3b694fb6	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0x3b71df96	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x3b7dfe2f	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x3b7e9a8d	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x3b92b1eb	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0x3b993167	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0x3baf1849	ps3_vuart_read_async
++EXPORT_SYMBOL_GPL vmlinux 0x3bc6b107	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x3bd1868e	rio_lock_device
++EXPORT_SYMBOL_GPL vmlinux 0x3be0cbb6	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0x3bf75a57	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x3c000c3d	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x3c392c64	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x3c51ea7c	opal_leds_get_ind
++EXPORT_SYMBOL_GPL vmlinux 0x3c63343e	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0x3c7a8d48	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3c953755	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0x3c9c5837	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0x3ca09ca3	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0x3cb89480	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cee2adc	__nvdimm_bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x3cf69baf	slice_get_unmapped_area
++EXPORT_SYMBOL_GPL vmlinux 0x3d1c3a76	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x3d2510c3	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x3d31b2e2	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d527e95	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x3d612305	iommu_direction_to_tce_perm
++EXPORT_SYMBOL_GPL vmlinux 0x3d70760c	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0x3d795ef3	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0x3d7e8ae0	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x3da67a23	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x3db2a294	mpic_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x3dc526a9	arizona_of_match
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd070a0	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3dd27fce	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x3dd838a9	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3ded5ce0	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x3dfc436e	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x3e015bba	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x3e0ddf60	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0x3e2117c6	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x3e400fbe	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0x3e42f7b3	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0x3e47dee2	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e8a8bf1	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x3e8cb440	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3e9621f1	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0x3e98d9c6	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x3e9fdcad	of_dma_is_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x3ea4bda0	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x3ecf6619	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0x3ed8bf96	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x3efaaa85	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f1cb321	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0x3f58e1f8	sysfs_add_device_to_node
++EXPORT_SYMBOL_GPL vmlinux 0x3f5d7279	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x3f664bdf	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x3f6a5db9	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0x3fa5af9c	nd_cmd_bus_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3fb14423	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x3fb806e5	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3fc488a6	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x3fd6fa78	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0x3fef7431	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x3ff5b7a7	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0x3ff80a3f	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x401bb2fc	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0x402a973f	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40c140a6	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x40c977d0	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x4119488f	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4124f652	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x413eddba	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x413f20a2	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0x416defd1	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0x417a76b0	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x417b0673	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x41896d9c	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0x418d7207	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4199cbb4	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0x41adbc3b	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x41b4195d	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0x41c11406	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x41e57bc7	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x420e9786	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0x42136a7f	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x4229e5e5	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x425523ef	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0x42582fb8	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0x42609e57	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0x42635d55	pm_suspend_global_flags
++EXPORT_SYMBOL_GPL vmlinux 0x42648f20	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x42675247	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x426b2c92	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x426f3637	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x427de547	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42a05112	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x42e39b0a	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0x430b6b9a	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0x432486a3	nvdimm_bus_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x4324a4a0	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x432702e6	mm_iommu_mapped_inc
++EXPORT_SYMBOL_GPL vmlinux 0x43619e1a	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x43649fec	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0x4366baa9	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x436909cd	rio_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x437eeff8	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43af4c7c	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43d023f1	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x43db90d9	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0x43f41712	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x44033b80	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x44083329	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x441f8fe2	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0x442eb53b	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x443943a7	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0x443d8e3d	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x446e3c47	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0x448406f7	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44c027a4	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x44d2ea52	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x450c3895	mmput
++EXPORT_SYMBOL_GPL vmlinux 0x450e2b8d	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0x450fb522	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x4514d904	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x451afa8a	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0x455e77a6	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x4567afb4	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x458eaa2f	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x45946b54	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x459e5e2f	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x45b55ce1	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45d4871a	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x45ee603d	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x4601417b	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x460d2ae8	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x46308019	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0x4634aa78	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x464bcfb2	ps3_system_bus_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x46515d48	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0x46722250	of_dma_router_register
++EXPORT_SYMBOL_GPL vmlinux 0x4673ea46	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x4688c96a	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x46926356	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x46a93abb	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0x46c88362	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x46d9f955	ps3_irq_plug_setup
++EXPORT_SYMBOL_GPL vmlinux 0x46fbb458	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x4741db42	ps3av_set_audio_mode
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x47680206	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0x477e54b1	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x477f2612	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x478ab260	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0x47a1026c	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47acddea	ps3_sys_manager_set_wol
++EXPORT_SYMBOL_GPL vmlinux 0x47c4f7fc	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x47d160ba	of_property_read_u64
++EXPORT_SYMBOL_GPL vmlinux 0x47e4cd9b	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x47eb5808	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x47f2a676	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x47fc8164	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0x47fd2d73	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0x4832e798	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x4840a73b	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0x485c6861	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0x485ff20a	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x486bf6de	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x48aff7c9	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x48bb8e9e	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0x48bf41d8	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0x48f816c3	pmf_put_function
++EXPORT_SYMBOL_GPL vmlinux 0x48fed600	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x49066905	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x4921359a	mpc8xxx_spi_rx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x492da77c	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x4933309b	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x494ecb82	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x495b8089	of_reconfig_get_state_change
++EXPORT_SYMBOL_GPL vmlinux 0x498133d4	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x49871511	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x4992b155	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0x499c82f0	of_node_to_nid
++EXPORT_SYMBOL_GPL vmlinux 0x49adead5	of_get_nand_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0x49ba12de	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0x49bf6415	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0x49c3c4ba	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0x49ca2744	nd_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x49ee0947	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x4a026413	mm_iommu_mapped_dec
++EXPORT_SYMBOL_GPL vmlinux 0x4a16f4f4	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0x4a1b9d86	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x4a2e5570	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a4d1ea6	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x4a4d4bfd	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0x4a5f895b	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0x4a700c3e	of_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x4a90160e	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x4a92033d	pcibios_alloc_controller
++EXPORT_SYMBOL_GPL vmlinux 0x4a994c0e	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x4aa8d9f8	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4ab0b1e5	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x4ad4da2c	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0x4ad5d153	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x4b008779	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0x4b019a05	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0x4b1333e4	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x4b3df8ed	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x4b57744d	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x4b80523f	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL vmlinux 0x4bc3ee06	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0x4bea46aa	of_pci_find_msi_chip_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x4bf69a59	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x4c18f773	ps3_os_area_set_rtc_diff
++EXPORT_SYMBOL_GPL vmlinux 0x4c19375d	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x4c4d331c	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c603341	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0x4c645f9e	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x4c676de5	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x4c71d34c	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4c829b68	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x4c916ce0	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0x4cadc657	pmf_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x4cbc11bf	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0x4cf6a6df	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d12fcf8	device_create
++EXPORT_SYMBOL_GPL vmlinux 0x4d32163a	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0x4d4705be	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0x4d9009d6	mpc8xxx_spi_rx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0x4db00597	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0x4de144a1	of_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4deeb8f4	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x4deeea74	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x4df46a05	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0x4dfcaf97	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x4e082a4a	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e1c6e5e	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e25c6e2	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x4e38031e	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x4e4d79ac	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0x4e4e4fff	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x4e5f3efa	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4e697916	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0x4e83b17d	of_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x4e892d36	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0x4ea5fb41	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4ed0e5df	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x4ef43d29	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f0391de	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x4f05925c	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f345fdf	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x4f425021	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x4f4e3d7d	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0x4f61ebef	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a7cc5	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x4f8a43c5	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x4f9823ea	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0x4fc00c17	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x4fce5339	power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4ff496a6	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x4ffc39f3	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0x5016eb30	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x501c516b	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0x501e044c	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x501f5664	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0x504e9875	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x506997df	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0x507596d8	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x5076529a	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0x507de8c6	add_memory
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x50a362fb	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x50ad71ca	of_pci_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x50b7ad13	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x510e1c71	mm_iommu_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x510e61c6	rio_route_add_entry
++EXPORT_SYMBOL_GPL vmlinux 0x5144bf80	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0x51467922	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x5183cb4d	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x51a07a38	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x51b65a26	rtc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x51d9f999	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x51da4548	nd_region_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x51ee7ec1	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x51f7f7e5	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0x5205e64d	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x520ff6f2	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x5218d569	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0x522f538b	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x5264ceeb	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x5264f366	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x528626bf	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x5289201e	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5299dbd4	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x52b3afa3	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0x52d4c6da	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x52e9b957	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x530d6faa	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0x5323a584	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x53258223	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5335dd11	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x53889528	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x539bc522	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x53c1f2dc	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0x53dd59e3	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x53e34fe6	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x53eaaf7c	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x53eb373b	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x53ef98d2	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x5410c749	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x54215db5	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0x544bef57	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0x544f77d7	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0x54531428	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x546c5565	ppc_tb_freq
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x548c077e	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x5491366d	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54bfb243	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0x54c62b3b	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x54ccc1d7	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x54e5c9ae	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x5500258a	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x5509e598	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x55164f97	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x5526f1a0	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x5588879e	kvmppc_entry_trampoline
++EXPORT_SYMBOL_GPL vmlinux 0x5589736c	md_run
++EXPORT_SYMBOL_GPL vmlinux 0x558e5262	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x55a109d0	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0x55df6fce	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x55f51ef3	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0x560aa1db	opal_tpo_write
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x5647431f	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x56513cfb	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x568ca857	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x569c5a30	__rio_local_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x56a7ebec	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56d7c6dc	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x56da0213	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0x56e0a9e2	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x5715047b	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x57157bd6	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x575036e4	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x575049f6	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x575c5f94	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0x57600630	ps3_gpu_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x57697071	kvm_alloc_hpt
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x57c44d92	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x57ea4d92	nd_blk_region_to_dimm
++EXPORT_SYMBOL_GPL vmlinux 0x58110346	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x581fdb78	rio_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0x5838032e	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x583d8a9b	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x58583248	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x588d119f	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0x5892f832	release_pmc_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x5895f206	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58c87195	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x58d3ed52	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0x58d4aa1a	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0x58fe9409	rio_inb_pwrite_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5904fbbe	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5913b7b7	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0x5929ac7f	nd_device_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x593248cb	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5957c3b9	pmf_find_function
++EXPORT_SYMBOL_GPL vmlinux 0x596d53ec	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x5994b76a	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0x599e9595	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x59b2adbf	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x59b6f8d9	nvdimm_bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x59dcc092	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x59f885dc	to_nd_desc
++EXPORT_SYMBOL_GPL vmlinux 0x5a30682f	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0x5a3f6678	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x5a72809a	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a7eaf4c	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x5a91bcfb	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0x5ab2feaa	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0x5ab5bd40	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x5aca78f9	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x5acfdaad	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0x5af23265	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0x5b00fc83	rio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5b1effd0	of_platform_populate
++EXPORT_SYMBOL_GPL vmlinux 0x5b41f861	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0x5b5b1716	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x5b702413	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x5ba6760f	default_iommu_map_sg
++EXPORT_SYMBOL_GPL vmlinux 0x5bb18080	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x5bb491ba	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bd9cc61	pmf_call_one
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5be2a031	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x5bfee875	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c69d07f	of_mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x5c77f611	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0x5c7f5d4a	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x5c872c89	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0x5ca0ed92	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cabe1ad	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5cda01c0	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x5ce671cd	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x5cfdcca6	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d3065b0	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5d42d0d7	nd_blk_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x5d457e13	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x5d6427bf	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x5d87e069	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x5d91d294	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5da82cc6	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0x5dccaba0	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x5dd1af1e	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0x5e11d1a8	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x5e2a5421	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0x5e359719	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x5e387791	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x5e478cd7	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e5e603d	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x5e6ec7b0	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0x5e769986	ps3_os_area_get_av_multi_out
++EXPORT_SYMBOL_GPL vmlinux 0x5e8a7085	rio_mport_get_efb
++EXPORT_SYMBOL_GPL vmlinux 0x5ea8a39b	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x5ec080b7	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0x5ee7542e	reserve_pmc_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x5f0d1618	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x5f226035	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x5f2444c7	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0x5f6782ef	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0x5f68ca11	of_prop_next_string
++EXPORT_SYMBOL_GPL vmlinux 0x5f699a0e	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0x5f88a3a2	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x5fa55279	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0x5fb6f5d6	cxl_update_properties
++EXPORT_SYMBOL_GPL vmlinux 0x5fc71c05	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x6007a01c	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x60467b06	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x605d1e95	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x605e7795	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x6066ff4f	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0x607d13d3	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x60b7355f	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0x60c4e78c	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0x60cca309	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x60ef8991	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x60f2388f	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0x6100cbbe	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x6139c092	kvmppc_add_revmap_chain
++EXPORT_SYMBOL_GPL vmlinux 0x6154c1bb	of_gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0x617e86ff	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x61963aa2	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x6197d311	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x61a90c54	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x61cdbed9	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x61edf388	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x61ee48d9	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0x61f43742	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0x61f7d2f0	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x6214b16c	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x626083a7	mpc8xxx_spi_rx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x6273d411	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0x62bd5a6d	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x62d263d5	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0x62e94b84	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x6314ac10	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x631a529c	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x6351fa82	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x6359a196	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x636d605b	eeh_add_sysfs_files
++EXPORT_SYMBOL_GPL vmlinux 0x63724b78	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x63738ab8	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x63811c49	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x63c9f9cf	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x63d3bd6c	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0x63d79076	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x63db5a76	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x63f14ebe	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x6414b9fb	rio_local_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x64732c8e	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0x64939621	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x64c26a6d	scom_map_device
++EXPORT_SYMBOL_GPL vmlinux 0x64c37f05	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x64ca6ab1	of_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x64dcf315	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x64e04999	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0x64e80dfb	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x650c0732	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0x650ef77f	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0x65521ede	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x6567aabb	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x657dc1a4	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x659a9b2d	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65be51c0	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0x65cba285	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x660f13c6	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x664f8006	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x665a2b4c	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0x6665421e	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x666884c0	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0x6668c067	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0x6671b418	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0x667a812c	ps3av_set_video_mode
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x66afb53b	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x66b32bb0	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0x66b92c8c	smu_get_ofdev
++EXPORT_SYMBOL_GPL vmlinux 0x66c31a9b	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66dcba03	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0x66e20a9f	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0x6748e6e2	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6761aec0	of_dma_xlate_by_chan_id
++EXPORT_SYMBOL_GPL vmlinux 0x678a4105	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x67d1b945	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x67fb7023	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0x68217b4c	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x6832abc8	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x683a206c	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0x685fe55d	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x687bb305	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0x687c8cc8	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0x68973403	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x689811c2	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x68a8a360	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x68e60e5d	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x68f0ac45	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x6921aa34	compat_put_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x69564c17	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x69571f6d	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x6961604c	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0x69790ef6	__init_new_context
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x697cbbb4	threads_per_core
++EXPORT_SYMBOL_GPL vmlinux 0x698642c6	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x699ec170	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x69c1d134	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x69c3c4c8	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x69d0fe86	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x69fbfd8a	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a181f36	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x6a18b111	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x6a2a8870	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x6a2ffcd1	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a6cafd2	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x6a71af61	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0x6a71e5ae	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a936feb	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x6acb8d84	ppc64_caches
++EXPORT_SYMBOL_GPL vmlinux 0x6ad4d11c	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0x6ae06b43	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x6afd358d	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x6b0324f9	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b48436e	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x6b567c54	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x6b66fdde	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x6b6a966f	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x6b70601b	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6b83c369	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0x6bbaadc7	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0x6bbacfed	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b363d	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c53af6d	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0x6c5f9489	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0x6c685fc7	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x6c6fbf9c	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0x6c783c41	of_reserved_mem_device_release
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6ca0fc31	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cadb246	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x6caf5a80	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x6cc2fb2c	opal_message_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6ccfae5e	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6d0697aa	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x6d06a42b	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d313f02	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x6d477ec0	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0x6d5757e4	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x6d644901	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0x6d682268	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x6d71680b	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0x6d74237c	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x6d791c4b	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x6d7b843a	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x6dae732c	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6df649bb	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e31986a	rio_mport_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x6e369db9	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x6e379526	kernstart_addr
++EXPORT_SYMBOL_GPL vmlinux 0x6e427980	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x6e5a9616	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x6e5bc65c	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0x6e663928	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e8119d8	fsl8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6e872275	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x6e88316a	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6e92f2d7	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x6ed359f8	rio_register_scan
++EXPORT_SYMBOL_GPL vmlinux 0x6ee6dd3a	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6ef3d80d	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6efe0c0b	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x6f055fd0	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x6f152bee	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f360cdb	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x6f4b37bb	__remove_pages
++EXPORT_SYMBOL_GPL vmlinux 0x6f4dfe40	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0x6f606b9a	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6f689beb	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x6f6e9e4c	device_move
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6f87eeac	rio_mport_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x6fa8db37	of_irq_find_parent
++EXPORT_SYMBOL_GPL vmlinux 0x6fbd0d85	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6fcf836f	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6ff05ee8	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x7010fc9a	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0x7044f8af	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x704f57a1	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x70880945	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0x709c5c21	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x70a789a2	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70e1bb20	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x70eb2fef	of_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0x70fe29c3	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x7101aedf	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7110bfec	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x7156ebde	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x717a68b5	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x718e74ec	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0x71a91061	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x71acab98	of_get_dma_window
++EXPORT_SYMBOL_GPL vmlinux 0x71b104b7	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71e16902	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x71e96af2	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0x71fb8368	pcibios_free_controller
++EXPORT_SYMBOL_GPL vmlinux 0x721d7217	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x721ed256	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0x72391179	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x724f8fa0	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0x7261d5ab	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x72798b99	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0x727ebcd2	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x7286fd89	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x72ab49a6	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0x72bd2624	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x72d3b9bb	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x73018c52	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0x73060822	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0x7308f315	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x736e2caa	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x736e5366	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x739aa1a1	pmac_i2c_setmode
++EXPORT_SYMBOL_GPL vmlinux 0x73a360d3	eeh_pe_get_state
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73abf8d1	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x73c2554f	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0x73c48230	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x73c5bce1	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73ddfb05	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x73de64b2	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0x73e8bbc8	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0x73e9366c	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x74325e25	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x74390a4b	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x748b5bc4	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x74a63926	ps3_sys_manager_register_ops
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74c8592e	ps3_vuart_clear_rx_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x74c885b5	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0x74de19be	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x75133f6e	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0x751749e8	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0x751eb0e8	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x75329035	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0x757610ba	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0x7579d7fd	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x757b49d2	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0x75894805	of_usb_update_otg_caps
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x759139cb	of_pci_check_probe_only
++EXPORT_SYMBOL_GPL vmlinux 0x75959a52	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x75b8899e	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x75c9d8c3	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75cdfc6d	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0x75d17d0b	pmac_i2c_open
++EXPORT_SYMBOL_GPL vmlinux 0x75f2a044	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x75f48cdd	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0x76069594	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x760d8c48	kvmppc_clear_ref_hpte
++EXPORT_SYMBOL_GPL vmlinux 0x761ed6ec	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x7628d18d	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x762c0858	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0x765e9398	of_scan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x76719ae1	of_thermal_is_trip_valid
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7692a315	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x76b027e2	device_register
++EXPORT_SYMBOL_GPL vmlinux 0x76ccd7ec	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x76cd5137	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0x76ce2108	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0x76d61579	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x76fec888	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x7746155f	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x7763040e	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0x776d7109	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0x77740214	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x778b260a	pcibios_finish_adding_to_bus
++EXPORT_SYMBOL_GPL vmlinux 0x779544d8	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x77efec3b	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x77f2a4a0	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x78108342	__rio_local_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x78404fe9	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x78641038	copro_flush_all_slbs
++EXPORT_SYMBOL_GPL vmlinux 0x78714791	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x787c882b	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x787fd443	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x78873cdb	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0x7893feea	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78b87114	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x78c5386a	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0x78cc5bec	hugetlb_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x78d042ff	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0x78d7a7bf	hwpoison_filter
++EXPORT_SYMBOL_GPL vmlinux 0x78ec94f0	flush_altivec_to_thread
++EXPORT_SYMBOL_GPL vmlinux 0x78f0d108	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0x78f9ae20	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0x790a27b4	rio_mport_class
++EXPORT_SYMBOL_GPL vmlinux 0x7910a8d5	of_usb_host_tpl_support
++EXPORT_SYMBOL_GPL vmlinux 0x791dc205	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x794dfa65	of_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x795198b5	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x795b6af0	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x798e15a0	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x799402cd	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0x79abc70c	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x79b74a55	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x79e7b063	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x79f6147f	iommu_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x7a0758c5	rio_mport_get_physefb
++EXPORT_SYMBOL_GPL vmlinux 0x7a07f354	kvmppc_do_h_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7a2c2f14	mm_iommu_find
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a533283	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7a559854	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0x7a6dc369	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x7a73ca20	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7a98b3e4	rio_route_get_entry
++EXPORT_SYMBOL_GPL vmlinux 0x7a99a26a	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0x7a9ec81c	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0x7aa03e5e	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0x7aa26595	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b18056b	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b1fd84c	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x7b362a2e	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7b3c5767	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0x7b3f13a0	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0x7b4c7cf7	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b577edb	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0x7b643fc1	srp_remove_host
++EXPORT_SYMBOL_GPL vmlinux 0x7b70ed5c	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x7b9fc5d6	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x7bbfe9a8	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x7bda711f	nd_cmd_out_size
++EXPORT_SYMBOL_GPL vmlinux 0x7c004e17	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x7c1722f6	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0x7c2de8ba	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7c32072a	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x7c37bc89	pseries_ioei_notifier_list
++EXPORT_SYMBOL_GPL vmlinux 0x7c38e871	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x7c6a83fc	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0x7c8b9553	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x7cad8078	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x7cbd1f12	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cedf677	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7cf7de3c	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x7d00c65b	nd_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x7d25358f	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7d2dc6f0	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x7d3bc2ed	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x7d45245a	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7d4ccfc5	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x7d509764	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0x7d552396	component_del
++EXPORT_SYMBOL_GPL vmlinux 0x7d56d8d6	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d7a72e2	__rio_local_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x7d939470	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0x7d990b42	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7db3a30e	iommu_flush_tce
++EXPORT_SYMBOL_GPL vmlinux 0x7db66116	of_display_timings_exist
++EXPORT_SYMBOL_GPL vmlinux 0x7dbe6f90	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x7dc1e388	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0x7dc68405	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7dff0ea2	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0x7e0c94dc	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0x7e17ba7b	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x7e2107c4	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0x7e28e81e	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x7e599be7	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7ea1a2bc	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x7eaddd5e	of_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x7eb1fa00	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x7ec2c089	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x7edebeff	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0x7ee723d0	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0x7f008202	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7f040329	get_slice_psize
++EXPORT_SYMBOL_GPL vmlinux 0x7f068e21	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0x7f0a30d1	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x7f13d491	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x7f1c0420	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f328664	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0x7f39b704	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x7f4ae116	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0x7f52c522	ps3av_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x7f583a30	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x7f6cc2c8	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0x7f7748f3	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x7f7bc710	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7f8098dd	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7fa653b0	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7fc852b8	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x7fd8e703	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0x7ff3621b	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0x7ffbc934	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0x801228d1	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0x803c4c1e	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x804ea02d	__find_linux_pte_or_hugepte
++EXPORT_SYMBOL_GPL vmlinux 0x80507f72	ps3av_audio_mute_analog
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x8082af36	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x80ad0558	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x80b73fba	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80d27299	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x80f87ad0	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0x8104fd68	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x8114b8d6	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x8128000f	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x812ce933	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0x81418abf	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8152e111	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x8188bae2	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x819ef527	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x81a0419c	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0x81b295c5	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x81b3304f	rio_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x81b8be61	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x81c4e2eb	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x81c8fa5c	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x81df9e78	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8233bbbd	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x8246f9a3	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x82491b0b	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x825e2ac1	copro_calculate_slb
++EXPORT_SYMBOL_GPL vmlinux 0x8260c208	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x826e43e8	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x82853498	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x829ea178	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x82b3ff76	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x82b87f74	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x83095671	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0x830fb0ba	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0x833d4602	rio_request_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x834f008b	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0x8369b404	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x836bf314	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x836c6627	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x836d61d0	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x83776d8c	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x837e3245	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x83a17503	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0x83b19899	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0x83db9d28	pmf_unregister_irq_client
++EXPORT_SYMBOL_GPL vmlinux 0x840ac7e7	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0x84368bed	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x84576cfb	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0x84750133	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x8482a069	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x84868601	rio_route_clr_table
++EXPORT_SYMBOL_GPL vmlinux 0x8487a2b6	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x84b57a22	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x84b9a76d	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x84efca58	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x852b31a1	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0x85355d6e	of_console_check
++EXPORT_SYMBOL_GPL vmlinux 0x8549ca9c	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0x854c3441	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0x854db0a7	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0x8579d218	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x858130ba	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x8586b3ce	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0x85912d20	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x85a90231	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0x85aaaec0	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x85c0cbf1	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8616ab18	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x8666a7c5	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x8690e05e	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x8693d598	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x86b1368a	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x86b36511	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8702e548	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x8704ee4e	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0x870a5c64	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0x872db168	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x8758596a	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x87b90cad	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x87bbf295	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x87be32e6	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x87c9717e	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x87d27be6	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x87f6067a	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x87ffc43d	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0x8804af3d	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x8813ca01	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0x88162d8c	ps3_open_hv_device
++EXPORT_SYMBOL_GPL vmlinux 0x882a4396	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0x883cb010	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0x885d3627	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x887dfcd7	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x888d9783	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x88974a04	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x889c7024	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0x889d594c	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88ca64da	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x88cfc015	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8915a047	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x892571a0	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x892717d4	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0x893cf7b6	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x8948966b	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x89559ff4	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0x89575001	dax_do_io
++EXPORT_SYMBOL_GPL vmlinux 0x896cace0	rio_mport_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x898686de	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x8986dbea	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0x89ad6ca2	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89bc2283	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0x89cf36a0	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x89d47b4b	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8a3df144	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x8a43e6f9	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x8a50ebf5	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x8a554a36	mpc8xxx_spi_strmode
++EXPORT_SYMBOL_GPL vmlinux 0x8a561ae4	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a70604b	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0x8a75b7d6	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0x8a7c3144	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0x8a8208cb	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0x8aa3e626	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8ac8df70	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0x8acab0ce	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0x8b03c71a	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x8b0b466f	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x8b2ab54d	kvm_release_hpt
++EXPORT_SYMBOL_GPL vmlinux 0x8b3c770c	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x8b5d4ffb	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x8b6cf894	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x8b70e8ea	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x8b79373c	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8bae000a	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x8bb3b105	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c2704d6	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x8c314535	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x8c31e26b	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x8c3e5acd	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8c414ffa	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x8c60113e	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x8c636253	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8cae54b5	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x8cbfcebd	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0x8cd75623	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8cea765f	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x8cfb125e	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8d0685e9	get_device
++EXPORT_SYMBOL_GPL vmlinux 0x8d0a0298	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x8d0c71c7	spu_setup_kernel_slbs
++EXPORT_SYMBOL_GPL vmlinux 0x8d0dbb3a	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d4d3eaf	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0x8d6481a7	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x8d6577df	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x8d7dc619	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x8d804eb3	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0x8d85367f	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x8d9a7fe3	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x8dab4462	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0x8dbf5a20	kvmppc_hv_entry_trampoline
++EXPORT_SYMBOL_GPL vmlinux 0x8dfd5821	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x8e0cb8e5	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0x8e2b25c2	videomode_from_timings
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e354bde	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0x8ea0ef97	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8ed29ef0	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0x8edc4b0c	cpu_add_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0x8ee3992e	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x8ee5f2e5	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f2104d7	of_platform_default_populate
++EXPORT_SYMBOL_GPL vmlinux 0x8f467370	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x8f4e84b3	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cbeac	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f7ac468	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x8f7ba92f	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x8f7f1a8f	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0x8f93a618	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x8fa9753a	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x8fceb7ff	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x8fced602	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0x8fd840cd	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0x900c5eed	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0x90138998	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x902aacd3	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9039dad2	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x90652b2a	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9077d5ea	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x907980d4	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0x907c221b	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90b730a8	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0x90d62db4	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x90e79a03	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x90ec3c72	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0x90fa9441	kvmppc_h_get_tce
++EXPORT_SYMBOL_GPL vmlinux 0x91057e35	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0x91138484	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0x911d069c	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9122c849	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0x914c85d6	pcibios_claim_one_bus
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x918cfcde	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0x9195924c	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0x919d5079	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x91a17c4d	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x91a20a36	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91d65c2c	of_dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x91d99e22	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x91f0b24c	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x91f0c992	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0x91f0f6ca	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x920cc389	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x9224adc3	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x923e0316	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x9246245b	spu_add_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0x9246879f	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x925da7f6	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x92a1ae3d	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x92b4b0d0	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x92b9fa6e	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x92ceb1e5	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92e27049	of_pci_msi_chip_add
++EXPORT_SYMBOL_GPL vmlinux 0x92edc0e8	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0x9306ca72	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x932d45ae	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x93311080	opal_flash_read
++EXPORT_SYMBOL_GPL vmlinux 0x93336db3	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x9350c5ce	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x935516ca	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x938c0a28	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x93947f9d	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x93c0e77d	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0x93da723e	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0x93dd83c4	iommu_capable
++EXPORT_SYMBOL_GPL vmlinux 0x93f4372a	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x93f76075	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x940a9423	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x94100c02	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x94386449	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0x947de920	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x949f7342	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x94ad1744	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x94b12cb6	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0x94ba34a5	nvdimm_bus_check_dimm_count
++EXPORT_SYMBOL_GPL vmlinux 0x94bbfeb6	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x94ca57b8	ps3_vuart_port_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x94d972b7	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x94de8c8c	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x95034c2f	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x950c1615	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x955b08e1	of_css
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x95797857	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x9596856a	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x95a9f7fc	eeh_pe_reset
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95bfbe37	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0x95ced079	flush_fp_to_thread
++EXPORT_SYMBOL_GPL vmlinux 0x960926aa	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x9642d5c4	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x964a09d5	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x965a78d5	threads_core_mask
++EXPORT_SYMBOL_GPL vmlinux 0x965db1a4	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0x9675ebc8	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x9685141d	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0x96a37f78	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x96b67f03	of_irq_to_resource_table
++EXPORT_SYMBOL_GPL vmlinux 0x96b801a9	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0x96e04b60	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0x96f59192	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x9713224f	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0x97227d41	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0x97271df9	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x972c9252	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0x9735f061	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x974f2bab	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9752eb96	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x9767e2e2	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0x9780c464	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0x979cca41	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0x97a01819	iommu_tce_clear_param_check
++EXPORT_SYMBOL_GPL vmlinux 0x97a5329c	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x97be75a9	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0x97c99ae1	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0x97ddb97a	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x9801ed0a	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0x98212059	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x9825d129	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x982cd486	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x98393437	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x98a02a70	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x98ab6a58	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0x98ae9280	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0x98b9e7b6	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0x98bfa4a4	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x98f9f73d	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x9904dbba	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x99268195	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x99368d65	kvmppc_update_rmap_change
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x99720cc2	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x9973bcc2	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x998187a7	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x9987e6e9	opal_get_sensor_data
++EXPORT_SYMBOL_GPL vmlinux 0x998d79d6	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x99a9ff9a	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99bf3215	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x99c7f097	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x99e9f19a	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x99eafff5	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x99fe23d1	rio_release_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0x99ff8d08	opal_invalid_call
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a253fe0	of_pci_msi_chip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x9a453ce9	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x9a49d937	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0x9a619dfd	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x9a7263e3	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x9a78f022	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9a8c8354	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x9a925b91	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x9aad6540	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x9ab6e9e9	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x9abf5bd2	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9ad11d58	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x9adf08c3	mmu_linear_psize
++EXPORT_SYMBOL_GPL vmlinux 0x9ae33a40	pcibios_map_io_space
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9b0509af	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x9b0efffb	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x9b4947ba	rio_set_port_lockout
++EXPORT_SYMBOL_GPL vmlinux 0x9b50e070	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0x9b522b63	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x9b6f44eb	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0x9ba1cd8c	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0x9ba2bb2b	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x9bc9a0ff	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x9bca03ca	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9bee2e96	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0x9bf05490	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x9bf6c7b4	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9c1239ad	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0x9c132604	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0x9c2232c6	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0x9c4b6758	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x9c893670	mpc8xxx_spi_tx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x9c8ee6b9	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0x9c907ef6	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x9c93d693	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0x9ca0c98b	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cd7e822	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0x9cdc253c	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x9cec34aa	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9d01eef6	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x9d140524	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0x9d1caab7	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0x9d2878cf	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0x9d2f6649	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x9d69d6b0	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x9d7ec533	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9d80a706	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0x9d84ea8d	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x9d9b2384	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x9d9dd8f2	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9db837b3	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9deb5e47	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x9e0ef81a	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x9e112b55	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0x9e277339	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x9e2a9a68	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x9e2cc437	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e6c9d6f	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0x9e72fce9	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x9e909e6f	mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x9ea98d06	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x9eaa920f	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x9eb90ed6	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x9ec82ea0	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x9ec9c669	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ee1cc43	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x9eee8110	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x9ef47e1f	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x9ef5c639	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9ef9b810	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x9f191a84	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0x9f239d15	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0x9f3bb1f7	of_irq_parse_one
++EXPORT_SYMBOL_GPL vmlinux 0x9f42bbb2	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0x9f45740c	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x9f4c0b10	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0x9f576879	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0x9f6ead48	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0x9f7026fa	of_dma_configure
++EXPORT_SYMBOL_GPL vmlinux 0x9fbd0b09	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9fee3b82	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9ff4ab7c	spu_remove_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0xa01f1e78	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xa0335deb	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0xa038087e	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xa071e996	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xa079dc03	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0xa0987b54	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa09f55fc	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa0a27fff	pci_address_to_pio
++EXPORT_SYMBOL_GPL vmlinux 0xa0a3da16	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa0b9113c	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0xa0e0ba16	rio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa102e797	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0xa13c6e85	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0xa1498221	__tracepoint_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xa16982f2	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0xa170b56d	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xa18d519c	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0xa18d9383	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa1951f9c	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xa1ae1d46	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xa1b6030b	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xa1e8a058	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0xa1ed9c8b	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xa215dced	of_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa2718017	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa2816ed2	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xa28603e4	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0xa28b8d8e	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa2968353	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0xa2a098e0	rio_request_mport_dma
++EXPORT_SYMBOL_GPL vmlinux 0xa2ac5519	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2bdc488	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xa2c18cf1	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xa2d4ca0b	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0xa3248c60	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa333c524	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0xa35fd73d	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0xa364cd2e	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0xa36c92e1	rio_unlock_device
++EXPORT_SYMBOL_GPL vmlinux 0xa37d38ba	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xa384918b	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa39b2cc1	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0xa39f4596	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3a2d9af	walk_system_ram_range
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3c5c43b	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xa3c5db1b	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0xa3ca9f19	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0xa3e16693	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa3fbf4f4	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xa40d1f63	rq_flush_dcache_pages
++EXPORT_SYMBOL_GPL vmlinux 0xa419d509	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0xa44c2a75	of_overlay_create
++EXPORT_SYMBOL_GPL vmlinux 0xa44de4df	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0xa4595719	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xa4707ac3	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa499901e	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0xa4b1c997	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0xa4f97615	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0xa5034e4f	nd_numa_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xa51855ee	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa521ea4c	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa52b7364	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0xa560e135	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xa58d5edb	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa5adc277	fb_sys_write
++EXPORT_SYMBOL_GPL vmlinux 0xa5b00659	ppc_proc_freq
++EXPORT_SYMBOL_GPL vmlinux 0xa5d40183	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xa5d41e09	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0xa5dcbc9a	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5efe460	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xa5f2c98f	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0xa60054e6	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa628876b	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0xa62db9e9	iommu_tce_xchg
++EXPORT_SYMBOL_GPL vmlinux 0xa6400a13	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0xa642f399	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0xa64df440	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0xa65a6a4d	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa65aba44	hash_page_mm
++EXPORT_SYMBOL_GPL vmlinux 0xa65dcf84	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0xa6647139	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa67094bb	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xa674bef4	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0xa6797f17	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa67a0d63	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0xa6a6577c	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xa6ae78df	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6b7e295	nd_blk_region_set_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0xa6baad99	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xa6bdcbd1	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa6bf5c2d	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0xa6c28977	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa6d0fc17	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0xa6d439e7	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa6eded6c	opal_xscom_read
++EXPORT_SYMBOL_GPL vmlinux 0xa70a5fd8	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xa717c13a	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xa721bc3f	opal_rtc_write
++EXPORT_SYMBOL_GPL vmlinux 0xa72c65e8	cpu_add_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0xa7303986	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa7344da5	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0xa7592dfa	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xa7619b13	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xa7709ee3	dax_zero_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xa77fa291	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa77ffeca	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xa79142e3	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa793e4af	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0xa79c3852	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0xa7c05aff	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa7c55a5f	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xa7c7f74c	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0xa7dca47c	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa7f5aa64	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0xa82158c5	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xa821a9f8	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0xa82237c5	of_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xa829c0af	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0xa832a99c	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0xa83ca15c	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa862c053	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xa86e4e95	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xa89a00e8	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8e2cf8b	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0xa90f5ee6	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xa919ef92	of_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0xa91e325e	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa93e675c	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0xa98cdb36	ps3_get_firmware_version
++EXPORT_SYMBOL_GPL vmlinux 0xa9aa1b00	opal_poll_events
++EXPORT_SYMBOL_GPL vmlinux 0xa9ce341e	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0xa9d19590	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0xa9dbafb2	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9e6075c	nvdimm_volatile_region_create
++EXPORT_SYMBOL_GPL vmlinux 0xa9ef9fe6	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xaa07a39f	phy_pm_runtime_put
++EXPORT_SYMBOL_GPL vmlinux 0xaa5b0bba	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0xaa65078e	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xaa6dc643	devm_power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xaa7ca970	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaac846e7	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xaae5e01d	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0xaae5edea	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0xaaf1ba0f	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xab0e0ef1	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xab29ad96	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0xab2b243d	ps3_irq_plug_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xab51c2b2	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0xab567d31	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab62b21d	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab7abf25	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0xab8a2720	rio_request_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xaba2db15	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0xabb911fd	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabd3d40c	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0xabfaa71c	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0xac11cc11	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xac232207	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0xac4cf1b6	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xac5961b3	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xac65ec94	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xac7055ed	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0xac74ba32	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xac9b7006	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xacbe6ab4	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xace9dd9b	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0xacfe997e	powerpc_firmware_features
++EXPORT_SYMBOL_GPL vmlinux 0xad19e15e	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0xad38a8aa	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0xad3c340b	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0xad71ea47	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0xad789242	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xad9e496a	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xada41ca3	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadd51533	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xadd56e6f	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0xade18425	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xaded9da1	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xadf029e8	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xadfc9469	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0xae4ffc7f	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae6eaf93	hwpoison_filter_dev_minor
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae81922b	of_overlay_destroy_all
++EXPORT_SYMBOL_GPL vmlinux 0xae84473f	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0xae8a2c9c	dax_fault
++EXPORT_SYMBOL_GPL vmlinux 0xae9793fb	arizona_of_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xae99db01	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0xaeb05ace	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xaec9921f	hash_page
++EXPORT_SYMBOL_GPL vmlinux 0xaecd8bc9	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0xaed8fa30	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0xaee6b267	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0xaeecab00	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xaef0c687	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xaf01f275	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0xaf08f4e9	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0xaf0d9cb9	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xaf279112	opal_leds_set_ind
++EXPORT_SYMBOL_GPL vmlinux 0xaf4ba369	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xaf603917	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0xaf6553ac	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0xaf772d19	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xaf9487b0	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0xafaa19dd	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0xafbe6c9e	kvmppc_hwrng_present
++EXPORT_SYMBOL_GPL vmlinux 0xafd47e2a	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0xaff39556	realmode_pfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0xaff8ce00	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xb00b833e	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb086af53	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0xb0a0a9cc	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0b9d88e	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb0d1656c	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0xb0eb658b	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0xb1014c41	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xb11fed3a	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb16d06c3	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1b370bd	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1c1267c	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0xb1d0142d	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0xb1d9961b	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1e3863d	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xb1ed6e75	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb22429e6	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0xb2336c5f	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0xb26181c7	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0xb26a1add	elfcorehdr_addr
++EXPORT_SYMBOL_GPL vmlinux 0xb2842052	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0xb2bbd8a8	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0xb2c7f7e3	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xb2cd0466	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb3440765	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0xb347bb2c	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0xb3810081	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xb3a8e5ed	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xb3bfc8ab	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0xb3cc331b	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0xb3d2abb1	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xb3e175e1	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xb3e4969d	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xb3e6c6eb	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0xb40679ce	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0xb417b26b	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0xb419d95d	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0xb41f54bd	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0xb41f625c	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xb454be2d	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xb477aa0e	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0xb4815457	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0xb488588e	tb_to_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb4b2cd24	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4c2ed7d	of_pci_range_parser_one
++EXPORT_SYMBOL_GPL vmlinux 0xb4c4b679	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb4ef2863	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0xb4f74411	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb521d583	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb5388c29	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0xb560f8aa	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0xb5610f11	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xb5848bae	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb59a8d9c	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5aa10af	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb5bc2164	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb5c8edf4	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0xb5dbfe23	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0xb5e218bd	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb607b13f	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xb60b5707	of_i8042_aux_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb6150b0d	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb63379b8	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0xb643c250	xics_wake_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xb67f0611	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0xb6874c64	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6b2b4b3	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0xb6ba1a43	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0xb6bc007a	spu_sys_callback
++EXPORT_SYMBOL_GPL vmlinux 0xb701ed4e	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0xb71888b2	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0xb72031c5	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0xb722453d	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0xb7349f60	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xb7489ef5	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0xb7498058	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0xb764a5a6	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb769353c	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0xb775581e	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xb77ad687	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0xb78dc1a3	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0xb7c66962	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0xb7d5888d	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0xb7f48fd5	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb80f23b4	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb84b1aae	ps3_event_receive_port_setup
++EXPORT_SYMBOL_GPL vmlinux 0xb85917a5	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xb859ef1d	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb8a47bc6	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xb8ad8ed9	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xb8b145fb	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xb8c0efca	sysfs_remove_device_from_node
++EXPORT_SYMBOL_GPL vmlinux 0xb8c3538c	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8d810b9	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb8fdbb38	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0xb902dfbf	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb90aadfa	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0xb945ace8	__tracepoint_remove_device_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xb94de068	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xb9611631	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0xb9696403	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0xb981f55d	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xb992bcc8	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9e01789	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0xb9e04c6d	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9f322d6	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0xba06de9e	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0xba158769	rtas_cancel_event_scan
++EXPORT_SYMBOL_GPL vmlinux 0xba1b3bab	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba36b765	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xba61b68b	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xba75d069	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0xba8b11fc	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0xba915b87	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbaa0d318	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xbaa84153	kvmppc_do_h_remove
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbabfd136	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0xbac5b60a	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0xbad3d799	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0xbaf6d630	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb205818	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0xbb211794	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xbb49aafe	spu_64k_pages_available
++EXPORT_SYMBOL_GPL vmlinux 0xbb562731	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0xbb592331	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0xbb6d8f25	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0xbb6f025a	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0xbbafcba9	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xbbb9e232	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0xbbbf6e13	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0xbbc6fca4	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0xbbcfaae3	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xbbd8c410	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbbdd4db8	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbbe7cb0b	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0xbbe8ff9b	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbbeae37d	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xbbf5afed	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0xbbfbbef2	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0xbc12dbc4	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc2fcf42	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xbc3f68d3	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0xbc57816a	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0xbc5904db	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0xbc67164b	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc81c4c3	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcc20a01	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbcc21a08	eeh_pe_set_option
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbcf6917a	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbd0e45f3	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd407c98	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd671048	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xbd787c2c	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0xbd7fa02e	dummy_con
++EXPORT_SYMBOL_GPL vmlinux 0xbdcf3c43	thermal_zone_of_sensor_register
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbde8dc00	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0xbdf0aa76	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0xbdf32c4b	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xbe0c4f62	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0xbe1723bc	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe26225f	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0xbe372eeb	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xbe471cdf	opal_rtc_read
++EXPORT_SYMBOL_GPL vmlinux 0xbe49d084	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0xbe538a64	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe96dfd8	of_reconfig_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbea1021d	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbeb83714	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xbebcd541	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xbec15b5a	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xbec56db0	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0xbec8d1c8	analyse_instr
++EXPORT_SYMBOL_GPL vmlinux 0xbecd21ea	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0xbedbbae7	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf10d313	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0xbf1cc04b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xbf2463ed	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xbf63097f	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0xbf6fc3b1	of_alias_get_id
++EXPORT_SYMBOL_GPL vmlinux 0xbf721d98	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0xbf77054c	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xbf7a8617	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0xbf9c3d7a	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xbfa4363c	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0xbfb1b22f	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfc88b85	to_nvdimm_bus
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xbff3052f	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xbffde8ec	compat_alloc_user_space
++EXPORT_SYMBOL_GPL vmlinux 0xc004975c	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xc00d5f38	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc00eea94	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xc02bec3c	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xc03593d1	ps3_system_bus_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc03a3c69	pmf_call_function
++EXPORT_SYMBOL_GPL vmlinux 0xc0450f32	irq_of_parse_and_map
++EXPORT_SYMBOL_GPL vmlinux 0xc061367e	mpic_msgr_get
++EXPORT_SYMBOL_GPL vmlinux 0xc065a455	cpu_core_index_of_thread
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc091db80	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0xc09eb786	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0d215a9	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0e9d6c8	of_platform_depopulate
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc0fa01eb	of_get_nand_ecc_step_size
++EXPORT_SYMBOL_GPL vmlinux 0xc0fe6881	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0xc129955f	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xc145b7c9	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0xc1613003	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc1692063	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0xc170f1c9	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc17d451e	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xc1830db8	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0xc1a57946	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0xc1b39534	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0xc1c1c529	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xc1c9bacc	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xc1d3606e	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0xc1ed2767	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0xc1f00ad0	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0xc1fa2514	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc2081c79	of_get_nand_ecc_strength
++EXPORT_SYMBOL_GPL vmlinux 0xc2258092	rio_unmap_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc239fdd1	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xc241ad5b	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc2985fbb	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0xc29c95ef	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0xc2c25342	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xc2c7b92d	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0xc2e2ed1b	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xc2e4a016	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0xc2f44c0e	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xc2f92ef1	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0xc3006165	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xc311f8c4	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc357923c	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc372f332	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xc38f36d9	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc3a04506	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc3a3ec05	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0xc3dc7d55	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0xc416bd3d	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc435c8cd	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc4598640	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0xc46fca44	set_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc476da33	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0xc4806c27	unregister_cxl_calls
++EXPORT_SYMBOL_GPL vmlinux 0xc482116a	rio_get_comptag
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc48c12b6	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc4a16a61	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xc4aba300	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4e25a36	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0xc504a8f3	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0xc51a1520	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc54a4419	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc580c8bd	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc58a1687	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xc58ea0a9	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0xc5a2c19f	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc5c3fc85	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0xc5fab5b9	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0xc606cd3c	boot_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0xc617670d	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc622db26	spu_add_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0xc623a88b	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xc627431a	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc63e7d93	static_key_deferred_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc6511656	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc651a7f7	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc66c2311	ps3_vuart_irq_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc679741d	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xc68aa252	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6aa5c8d	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xc6c69a8f	opal_flash_write
++EXPORT_SYMBOL_GPL vmlinux 0xc6cf3529	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc6d1c68a	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc6da7a0a	__tracepoint_map
++EXPORT_SYMBOL_GPL vmlinux 0xc6e2f79a	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc6f6ec2e	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc720deeb	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xc720fdd9	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc726d0bc	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc741eb01	srp_rport_add
++EXPORT_SYMBOL_GPL vmlinux 0xc7561201	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0xc76ebba6	register_spu_syscalls
++EXPORT_SYMBOL_GPL vmlinux 0xc790693f	pmac_i2c_find_bus
++EXPORT_SYMBOL_GPL vmlinux 0xc7908909	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc791613e	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0xc79592da	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7ac8d6f	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7cb6ae5	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0xc7ccdb69	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc7d77ecb	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7fac37a	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xc8141118	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0xc81b0248	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0xc81e3d6b	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc8450c44	pcibios_add_pci_devices
++EXPORT_SYMBOL_GPL vmlinux 0xc853d772	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0xc8562e7b	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xc85943f9	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0xc85de8f9	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0xc85e710d	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc89542e2	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8bea213	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0xc8c3b62d	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0xc8d17ee8	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0xc8d26ce0	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc8d3bb66	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0xc8d9774d	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc90432cb	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0xc90651f8	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0xc90e8d2b	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc92369cf	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xc9247fb9	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0xc9321e41	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0xc93ead0c	pmf_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc94f2512	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc95f3ad3	of_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xc9641b48	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0xc9779d7c	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc97d1140	cpufreq_cooling_get_level
++EXPORT_SYMBOL_GPL vmlinux 0xc9beb904	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc9c4d9b8	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xc9ced521	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0xc9e229b9	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc9f3ed25	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0xc9f6d591	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0xca15d6e0	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xca5c8cd4	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xca5ff4b7	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0xca74835a	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcabe8f4b	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0xcac4843d	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0xcaec2d58	rio_mport_chk_dev_access
++EXPORT_SYMBOL_GPL vmlinux 0xcaf09487	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0xcafcf59c	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcb002c4e	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb2423f2	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0xcb4669a2	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb5a9866	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0xcb5ee621	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0xcb603517	rio_get_asm
++EXPORT_SYMBOL_GPL vmlinux 0xcb80383a	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0xcb8877cc	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0xcbcd58b1	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0xcbd42b85	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0xcbe154ff	__rio_local_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbeb5aa9	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcbf82c2d	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcc09a824	of_irq_get_byname
++EXPORT_SYMBOL_GPL vmlinux 0xcc0d746d	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0xcc0f1009	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xcc1016dc	pmac_i2c_match_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xcc139693	remove_phb_dynamic
++EXPORT_SYMBOL_GPL vmlinux 0xcc344d9f	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0xcc3a5b97	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0xcc3adcb5	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0xcc62d3c0	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xcc7cd02e	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc8c25e7	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xccb7d38d	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccdfa759	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0xcd01db07	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0xcd18ebdf	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0xcd19b7bb	pcibios_unmap_io_space
++EXPORT_SYMBOL_GPL vmlinux 0xcd2b19f8	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0xcd2ebe48	nvdimm_name
++EXPORT_SYMBOL_GPL vmlinux 0xcd664bdb	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd9584b1	of_get_nand_ecc_mode
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9ca363	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcda7b4b6	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdc20b1d	rio_mport_send_doorbell
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcde1038e	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0xcde34ce3	add_memory_resource
++EXPORT_SYMBOL_GPL vmlinux 0xce151a36	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0xce394103	iommu_tce_put_param_check
++EXPORT_SYMBOL_GPL vmlinux 0xce482ffd	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xce4dadbe	__online_page_increment_counters
++EXPORT_SYMBOL_GPL vmlinux 0xce519545	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce8edc34	spu_switch_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xce94c90e	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0xce9f7eca	user_read
++EXPORT_SYMBOL_GPL vmlinux 0xcea8a4e6	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0xceb1f126	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0xced4f57d	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xceee0e9f	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xcf120484	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0xcf449b17	ps3_system_bus_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf5988af	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xcf59d2fd	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xcf5c5c36	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xcf648a43	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0xcf694817	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xcf6a06d3	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0xcf76df76	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0xcf826d8b	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0xcf8a8251	unregister_spu_syscalls
++EXPORT_SYMBOL_GPL vmlinux 0xcf928347	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0xcf9ab2df	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xcfaab69f	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfe3ae86	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0xcff650d9	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0xd00f7a1f	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0xd01320b9	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0xd01afd3f	opal_tpo_read
++EXPORT_SYMBOL_GPL vmlinux 0xd0377207	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd03f933f	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0xd042233a	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0xd054108b	pmac_i2c_get_bus_node
++EXPORT_SYMBOL_GPL vmlinux 0xd05aef92	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd087a2b4	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0d7ab77	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0xd0dc4891	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xd0eacfe8	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0xd0fe63f2	nvdimm_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xd11270fd	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0xd145ac8c	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0xd14dd5d0	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0xd16614fe	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd17736ba	ps3_mmio_region_create
++EXPORT_SYMBOL_GPL vmlinux 0xd180b9ca	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0xd1c8a71f	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xd1cadd01	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0xd1ed562f	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd209ba44	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd25205ed	hugetlb_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd2817892	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xd2a7ec0d	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0xd2ac4537	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0xd2af4203	rio_dma_prep_slave_sg
++EXPORT_SYMBOL_GPL vmlinux 0xd2b05829	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0xd2c1d410	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0xd2d04cb6	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd307ec44	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xd326f814	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd332e3e2	rio_request_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xd36b44de	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xd36d5e25	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xd37804dd	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0xd38695bc	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd39c486d	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3b8162f	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xd3bdcb76	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0xd3bf4ba6	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd3c986da	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0xd3ce7a34	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd3e1aefe	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xd3e63e63	of_get_regulator_init_data
++EXPORT_SYMBOL_GPL vmlinux 0xd3ebdd54	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xd3f00c42	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd404a937	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd4487fd5	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd4506085	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd4574c99	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xd45d6bb6	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd466d937	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xd483c408	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0xd4aefb6b	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0xd4b420dc	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0xd4b61239	user_update
++EXPORT_SYMBOL_GPL vmlinux 0xd4bd66a0	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4c8c9bc	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0xd4d1296f	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0xd4d4ae38	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0xd4d68d1a	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0xd4e1da26	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0xd4e2b0d6	use_cop
++EXPORT_SYMBOL_GPL vmlinux 0xd4ecea7a	scom_controller
++EXPORT_SYMBOL_GPL vmlinux 0xd4edda55	rio_map_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xd4ee8106	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0xd4f10959	of_resolve_phandles
++EXPORT_SYMBOL_GPL vmlinux 0xd53583af	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xd5596d48	opal_xscom_write
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd5642f75	rio_mport_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xd56b5f64	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0xd5af7e25	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0xd5b93f9e	iommu_get_domain_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0xd5bb7493	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5bf183f	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xd5e44c7a	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0xd5e85828	agp_remove_bridge
++EXPORT_SYMBOL_GPL vmlinux 0xd609d211	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd63be9e3	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd63fb4ab	ps3_vuart_write
++EXPORT_SYMBOL_GPL vmlinux 0xd671cb6e	spu_switch_notify
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd681577c	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0xd691539d	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd6a43677	opal_async_release_token
++EXPORT_SYMBOL_GPL vmlinux 0xd6bd1808	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xd6d9c42e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0xd6eccffc	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0xd6f33fac	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0xd6feefa5	agp_num_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd71426f7	rio_request_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xd719872a	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0xd71dcf56	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0xd725f231	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0xd72d2e66	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0xd73134df	rio_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xd749fc93	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd760e4b8	eeh_dev_open
++EXPORT_SYMBOL_GPL vmlinux 0xd76828cf	nvdimm_pmem_region_create
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd785a1e1	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd79c9bd4	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7d83e11	get_hwpoison_page
++EXPORT_SYMBOL_GPL vmlinux 0xd7da634c	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0xd7e2f914	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0xd7e4449e	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0xd7f6bc94	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0xd7fc3e98	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd811a1b9	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd8263870	mmu_slb_size
++EXPORT_SYMBOL_GPL vmlinux 0xd828a786	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0xd8498f4d	ps3av_mode_cs_info
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd880528e	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xd8868a4f	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xd8ae4e0c	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xd8da1e6b	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0xd92b44e9	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0xd930e430	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd934cfca	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0xd93e8e0e	of_get_videomode
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd9497b3c	ps3_os_area_flash_register
++EXPORT_SYMBOL_GPL vmlinux 0xd94aa457	display_timings_release
++EXPORT_SYMBOL_GPL vmlinux 0xd94e03ef	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xd9564793	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd95c642b	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd97878a7	mm_iommu_preregistered
++EXPORT_SYMBOL_GPL vmlinux 0xd97a333a	pcibios_find_pci_bus
++EXPORT_SYMBOL_GPL vmlinux 0xd97c3cf7	rio_mport_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xd9821859	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0xd9b54ffb	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0xd9d07dd6	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0xd9e2de33	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd9e80609	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xda0a4d22	mpic_msgr_enable
++EXPORT_SYMBOL_GPL vmlinux 0xda21392c	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xda2a3f3c	ps3_free_mmio_region
++EXPORT_SYMBOL_GPL vmlinux 0xda397811	kvmppc_h_put_tce
++EXPORT_SYMBOL_GPL vmlinux 0xda430da2	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0xda431e25	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0xda50d9d1	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xda69a9b4	of_irq_parse_pci
++EXPORT_SYMBOL_GPL vmlinux 0xda6fe560	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0xdabc8cec	rio_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xdad3f456	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xdadc10c7	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xdae715e0	videomode_from_timing
++EXPORT_SYMBOL_GPL vmlinux 0xdaec9aee	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdaf9af8e	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0xdb010055	rio_unregister_scan
++EXPORT_SYMBOL_GPL vmlinux 0xdb0ac13b	ps3_compare_firmware_version
++EXPORT_SYMBOL_GPL vmlinux 0xdb220895	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0xdb22aecc	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb6c0c39	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xdb6f9091	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb91e05c	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xdbafb847	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xdbb74571	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc008b61	inet_csk_compat_setsockopt
++EXPORT_SYMBOL_GPL vmlinux 0xdc0de04e	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdc259d3f	eeh_add_device_tree_early
++EXPORT_SYMBOL_GPL vmlinux 0xdc544780	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0xdc5bfa1a	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0xdc74cf71	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc937864	spu_switch_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdcd9e915	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0xdce518c1	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0xdcea8e36	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0xdced1c80	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0xdd043eea	ps3av_get_auto_mode
++EXPORT_SYMBOL_GPL vmlinux 0xdd129959	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd3f629a	of_device_get_modalias
++EXPORT_SYMBOL_GPL vmlinux 0xdd5049b3	fb_sys_read
++EXPORT_SYMBOL_GPL vmlinux 0xdd57e2b5	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0xdd638780	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0xdd7261ee	__rio_local_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xdd729424	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xdd8791fe	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0xdd99882f	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xddab7b89	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddc8b4e6	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0xddcd0c63	early_find_capability
++EXPORT_SYMBOL_GPL vmlinux 0xddcd0e3e	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xdddf70ea	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0xddf05cbf	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0xde08c9aa	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0xde158411	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0xde2ebba0	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xde3608ca	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xde4270f8	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0xde49dbff	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xde561e2c	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0xde5c6db0	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0xde6b607e	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0xde6da45a	component_add
++EXPORT_SYMBOL_GPL vmlinux 0xde921ea3	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0xde928732	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0xde9e2403	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xdec2d313	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xdec3fcce	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xdec99769	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0xded4d15c	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xdedd6f7b	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xdeed364a	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0xdefb4b15	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0xdf0c3252	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0xdf0cfea2	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf15397f	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0xdf22654b	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0xdf32dc64	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0xdf443751	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xdf482153	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0xdf54aa33	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0xdf6c07d3	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdf80476d	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0xdf8aff75	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xdfad4397	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0xdfb7e660	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xdfbd1355	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0xdfd26a00	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xdff7d0f8	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xdffbc775	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe00c281e	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe011f817	ps3flash_bounce_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe036b3e9	mpic_msgr_put
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe073fec3	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xe0752fe5	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xe07587ee	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xe079417a	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe07bc24f	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xe07e39b8	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0xe08651f1	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0xe089cfcc	agp_memory_reserved
++EXPORT_SYMBOL_GPL vmlinux 0xe0a6a270	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xe0ad9a1a	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0xe0e7868c	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0xe121e7ab	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xe1298eca	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0xe12a03d3	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe1531f70	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0xe15be1a3	__add_pages
++EXPORT_SYMBOL_GPL vmlinux 0xe164483b	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0xe171c6a2	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe18607ee	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0xe18d751a	spu_invalidate_slbs
++EXPORT_SYMBOL_GPL vmlinux 0xe19136e4	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0xe1981a2d	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xe19fc092	ps3fb_videomemory
++EXPORT_SYMBOL_GPL vmlinux 0xe1bd6c99	rio_init_mports
++EXPORT_SYMBOL_GPL vmlinux 0xe1bf5fe9	input_class
++EXPORT_SYMBOL_GPL vmlinux 0xe1c8e0b6	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0xe1d01b0a	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0xe1da3a01	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xe1fe0865	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0xe2346f5c	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe23b6342	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xe286afe0	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe28b250b	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0xe29389c0	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xe2a5787e	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0xe2b1812b	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe2b50a11	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0xe2dc7db1	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe3687ee1	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0xe36c550d	kvmppc_invalidate_hpte
++EXPORT_SYMBOL_GPL vmlinux 0xe3721c2a	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe3779286	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0xe394a2fd	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0xe3d7750e	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xe3dea72e	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe4329ad6	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe4419b6c	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe4ad7643	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0xe4c031f8	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4f081e3	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0xe5134e9a	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0xe51c040f	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe526a295	ps3_vuart_read
++EXPORT_SYMBOL_GPL vmlinux 0xe52a9d73	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0xe52e8fba	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0xe535ec02	pmac_i2c_get_controller
++EXPORT_SYMBOL_GPL vmlinux 0xe5540302	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe56aca4e	pmac_i2c_adapter_to_bus
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe59bd37f	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xe5bfb184	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0xe5dca86e	spu_remove_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0xe5eb58ec	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0xe5f620da	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xe5f70db4	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xe600e157	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0xe60abd76	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xe6320309	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xe6337637	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0xe636d80c	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe655c06e	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0xe671f33c	pmac_i2c_get_channel
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6db09b9	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xe6dfb3bc	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe6fb0f0b	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xe7417092	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe74cc960	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0xe768d444	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe7e483ff	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0xe7f18b3c	threads_per_subcore
++EXPORT_SYMBOL_GPL vmlinux 0xe7f736e7	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe826df02	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0xe8320d1b	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe85c55e7	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe86b2f54	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xe88e0034	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0xe89bd243	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xe8c727b7	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xe8d3a2de	iommu_take_ownership
++EXPORT_SYMBOL_GPL vmlinux 0xe8f46963	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0xe909eb95	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0xe91e6553	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0xe9286c62	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0xe93bd7cd	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe94e93e9	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0xe9506579	iommu_tce_direction
++EXPORT_SYMBOL_GPL vmlinux 0xe98006eb	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0xe99aafa5	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0xe9a9fbd5	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xe9af68bc	pmf_do_functions
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xe9d45e2c	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xe9dcb02e	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0xe9f15b44	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xe9fc808f	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea14e553	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xea16c336	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0xea20ab0b	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xea33f2a7	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea51422b	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0xea5bfe27	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0xea628c20	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0xea650705	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0xea72b7e5	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xea7a2aa1	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xeabff440	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0xeac1ca0f	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0xeac1ce5f	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xeacd12ec	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xeaf280f8	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xeafb715b	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0xeaff6623	of_get_display_timing
++EXPORT_SYMBOL_GPL vmlinux 0xeb081667	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0xeb0c5c65	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0xeb1e722d	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0xeb226a3a	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0xeb268919	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0xeb2f5c29	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0xeb33ac04	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0xeb43e685	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0xeb7d183e	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0xeb7ec37a	of_property_count_elems_of_size
++EXPORT_SYMBOL_GPL vmlinux 0xeb811c06	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0xeb8ae736	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0xeba7a517	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xeba9c939	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xebfb5481	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0xec12ae26	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec2c8a8b	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0xec303e9c	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0xec3ddc9f	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xec42f2f4	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xec44981b	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xec458236	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0xec59c391	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xec5c3e84	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0xec5de03c	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xec631f34	remove_memory
++EXPORT_SYMBOL_GPL vmlinux 0xec843bbd	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0xec84df75	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xec8d0c5a	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0xeca183f5	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xeceb9510	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xecf45fcd	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xecf7ab78	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xed015620	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0xed2ab288	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xed3d89f0	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0xed72c320	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0xed8bcb8a	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xed981a16	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xedac84c4	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0xedac9a0d	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0xedbf0f0f	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0xedbf128c	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0xedf9a855	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xee034a87	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0xee206173	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0xee34f80a	of_thermal_get_trip_points
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee851f24	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL vmlinux 0xeeb212e9	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xeec38285	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xeed20a38	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0xeedf5cc1	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xeee22cb8	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xeef54c8e	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0xeefb87c5	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0xef128471	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xef13bec0	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0xef43724d	generic_access_phys
++EXPORT_SYMBOL_GPL vmlinux 0xef45f542	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xef5620de	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0xef5c63e6	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0xef66b522	eeh_pe_configure
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6d007a	sigset_from_compat
++EXPORT_SYMBOL_GPL vmlinux 0xef759bff	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0xef856365	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xef9816e1	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0xefa1c259	of_regulator_match
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefb1d66a	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0xefd6f0d8	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0xefdf7658	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xf01e365b	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf0644a78	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf079f11c	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xf098dd15	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0xf0bfffbe	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0ebc4ea	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf12bce35	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0xf13703e2	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0xf14173b8	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0xf148ae17	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xf14e4d24	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xf158f170	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0xf15b260f	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xf1724073	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0xf181ce08	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf1897326	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf1a62b6f	of_i8042_kbd_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1b4eb99	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0xf1b8af4b	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xf1fde4dd	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf1ffc581	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf2674b10	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xf26a5911	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0xf2781413	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf2962596	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0xf29dce2d	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2de8449	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf3001db2	srp_attach_transport
++EXPORT_SYMBOL_GPL vmlinux 0xf30a4435	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf31943b5	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf32492f3	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf33dc43c	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xf34f933b	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf3558031	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xf3713930	of_pci_get_devfn
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf38722e1	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf3a2e2e0	find_module
++EXPORT_SYMBOL_GPL vmlinux 0xf3af13db	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3c9e0e7	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0xf3ccc195	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0xf3dfe9da	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0xf3e7a4ff	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0xf3eb196b	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0xf3ed91a8	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf3fcedb0	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0xf413c6c4	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xf41a2af7	ps3_close_hv_device
++EXPORT_SYMBOL_GPL vmlinux 0xf42e62bb	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xf433c56c	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf43c2dfe	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0xf4594703	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xf469c705	ps3_io_irq_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xf47bc080	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0xf484e407	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0xf4874466	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xf490a86b	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf4986645	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf49b205d	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xf4d99cb3	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf5379771	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf56f1216	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xf57325fc	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5b6de3b	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0xf5bcf1b2	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0xf5cefb80	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0xf5e119c9	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf6471dc2	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xf64abc42	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xf64cd116	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0xf685b43a	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf689337e	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xf6b2d89d	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0xf6b48028	put_device
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6d53e54	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0xf6d68177	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0xf6db5959	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf6f34aee	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0xf705bddb	of_irq_parse_raw
++EXPORT_SYMBOL_GPL vmlinux 0xf709437c	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0xf71a42ce	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0xf723f9e6	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xf7253763	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0xf73684c1	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0xf770ce0c	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xf7754bd9	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0xf783c698	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xf7873a50	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0xf790ee02	rio_register_mport
++EXPORT_SYMBOL_GPL vmlinux 0xf798d1fa	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xf7a2de26	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xf7a391ff	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0xf7c16db7	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xf7c541dd	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0xf7e00ad5	rio_enable_rx_tx_port
++EXPORT_SYMBOL_GPL vmlinux 0xf7f055da	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0xf82b5435	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf837e0eb	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf8c04853	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0xf8c33d91	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0xf8d33595	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0xf8e398fc	memstart_addr
++EXPORT_SYMBOL_GPL vmlinux 0xf8e6b564	hibernation_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf8ff8a65	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0xf90bc551	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf94a451f	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf9604489	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0xf9782190	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf99ee4fb	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9bdcbc6	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9ccbff7	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0xf9d246ec	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0xf9f04dac	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xf9f206a1	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xf9f5d2f3	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0xfa04db8c	spu_management_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa246d71	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xfa4a05c9	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xfa5a31bf	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0xfa8939a5	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfa901b31	compat_get_timespec
++EXPORT_SYMBOL_GPL vmlinux 0xfa9b5aa1	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xfab31527	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xfab60503	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0xfac09860	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0xfad1d4f2	nd_mapping_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xfae08cb3	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xfae77a15	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0xfb0047f6	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0xfb0e7bb2	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xfb1e5c41	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb390b38	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0xfb3bb20d	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xfb44a7a1	opal_ipmi_recv
++EXPORT_SYMBOL_GPL vmlinux 0xfb471720	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xfb525dfc	pmac_i2c_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xfb52b77d	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0xfb597db6	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb8b0585	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfbcb2e55	nvdimm_create
++EXPORT_SYMBOL_GPL vmlinux 0xfbd3a24d	opal_message_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xfbfcdc2b	ps3_sys_manager_get_wol
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc201b66	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0xfc2b2861	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0xfc45c18a	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xfc836319	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0xfc9a52b7	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0xfc9dcccc	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0xfccbc463	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xfce63118	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0xfcebe1cc	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0xfcffb4e1	pmac_i2c_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0xfd149be7	pcibios_remove_pci_devices
++EXPORT_SYMBOL_GPL vmlinux 0xfd1c3907	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xfd2aec17	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0xfd50128e	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0xfd60af1a	pmf_do_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd887be2	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xfd9587f4	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0xfda75206	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0xfdb53332	spu_set_profile_private_kref
++EXPORT_SYMBOL_GPL vmlinux 0xfdb9363a	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfdc31fdd	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0xfddd285f	mm_iommu_ua_to_hpa
++EXPORT_SYMBOL_GPL vmlinux 0xfde0613a	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0xfde29cce	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0xfe01bfc0	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0xfe18d5bb	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xfe1a78fc	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xfe1a8a6f	iommu_release_ownership
++EXPORT_SYMBOL_GPL vmlinux 0xfe2b650b	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xfe54fa3d	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0xfe565c70	spu_associate_mm
++EXPORT_SYMBOL_GPL vmlinux 0xfe7d4f9a	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0xfe97f56c	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfea1300b	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0xfeb4b61e	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfee67e58	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0xfef04620	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0xfef13b0e	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xfef14bee	arizona_of_get_named_gpio
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff0dacff	ps3av_video_mute
++EXPORT_SYMBOL_GPL vmlinux 0xff0edbef	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xff1134ba	of_thermal_get_ntrips
++EXPORT_SYMBOL_GPL vmlinux 0xff14c26b	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0xff1b0ca0	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0xff381819	__online_page_free
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff7212ac	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xff75d988	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xff9bb9c3	rio_release_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffc209ef	of_irq_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0xffc6a170	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xfff25cbf	i2c_unregister_device
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp.compiler b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp.compiler
+new file mode 100644
+index 0000000..d1936f3
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp.modules b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp.modules
+new file mode 100644
+index 0000000..12458ca
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/powerpc/powerpc64-smp.modules
+@@ -0,0 +1,4368 @@
++3c574_cs
++3c589_cs
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_dw
++8250_mid
++8255
++8255_pci
++8390
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++DAC960
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++ac97_bus
++acard-ahci
++acecad
++acenic
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++ah4
++ah6
++aha152x_cs
++ahci
++ahci_ceva
++ahci_platform
++ahci_qoriq
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airo
++airo_cs
++airport
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++ali-ircc
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am53c974
++amc6821
++amd
++amd-rng
++amd5536udc
++amd8111_edac
++amd8111e
++amd8131_edac
++amdgpu
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apbps2
++apds9300
++apds9802als
++apds990x
++apds9960
++appledisplay
++appletalk
++appletouch
++applicom
++aquantia
++ar1021_i2c
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_emac
++arc_ps2
++arc_uart
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3722-regulator
++as3935
++as5011
++asc7621
++ascot2e
++asix
++ast
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++ata_generic
++ata_piix
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atm
++atmel
++atmel-flexcom
++atmel-hlcdc
++atmel_cs
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp870u
++atusb
++atxp1
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avm_cs
++avma1_cs
++avmfritz
++ax25
++ax88179_178a
++axnet_cs
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1pci
++b1pcmcia
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcma
++bcma-hcd
++bcmsysport
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluecard_cs
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpck
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmsmac
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bsr
++bt3c_cs
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btuart_cs
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++cap11xx
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_das16_cs
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipone_icn8318
++chipreg
++chnl_net
++ci_hdrc
++ci_hdrc_imx
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++clip
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cm4000_cs
++cm4040_cs
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmtp
++cnic
++cobalt
++cobra
++coda
++colibri-vf50-ts
++com20020
++com20020-pci
++com20020_cs
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_isadma
++comedi_parport
++comedi_pci
++comedi_pcmcia
++comedi_test
++comedi_usb
++comm
++configfs
++contec_pci_dio
++cordic
++core
++cp210x
++cpc925_edac
++cpia2
++cpsw_ale
++cpu-notifier-error-inject
++cpufreq_spudemand
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc7
++crc8
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++csiostor
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cxl
++cxlflash
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_cs
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++db9
++dc395x
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++ddbridge
++de2104x
++de4x5
++decnet
++deflate
++defxx
++denali
++denali_pci
++des_generic
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++digicolor-usart
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9601
++dmfe
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++dp83848
++dp83867
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dtl1_cs
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_wdt
++dwc3
++dwc3-pci
++dwc_eth_qos
++dwmac-generic
++dwmac-ipq806x
++dwmac-lpc18xx
++dwmac-meson
++dwmac-rk
++dwmac-socfpga
++dwmac-sti
++dwmac-sunxi
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++earth-pt1
++earth-pt3
++eata
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++echainiv
++echo
++edac_core
++edt-ft5x06
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efs
++egalax_ts
++ehset
++elan_i2c
++electra_cf
++elo
++elsa_cs
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emac_arc
++emac_rockchip
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++empeg
++ems_pci
++ems_pcmcia
++ems_usb
++emu10k1-gp
++enc28j60
++enclosure
++encx24j600
++encx24j600-regmap
++eni
++enic
++epat
++epia
++epic100
++eql
++esas2r
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++ezusb
++f2fs
++f75375s
++f81232
++fakelb
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdomain_cs
++fdp
++fdp_i2c
++fealnx
++ff-memless
++firedtv
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fixed
++fl512
++flexcan
++flexfb
++floppy
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fmvj18x_cs
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fsl-edma
++fsl_elbc_nand
++fsl_lpuart
++ft6236
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu_ts
++g450_pll
++g760a
++g762
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcm
++gdmtty
++gdmulte
++gdmwm
++gdth
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++genwqe_card
++gf128mul
++gf2k
++gfs2
++ghash-generic
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-74x164
++gpio-74xx-mmio
++gpio-addr-flash
++gpio-adnp
++gpio-adp5520
++gpio-adp5588
++gpio-altera
++gpio-amd8111
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-fan
++gpio-generic
++gpio-grgpio
++gpio-ir-recv
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-rdc321x
++gpio-regulator
++gpio-syscon
++gpio-tps65912
++gpio-twl4030
++gpio-twl6040
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mdio
++gpio_mouse
++gpio_tilt_polled
++gpio_wdt
++gr_udc
++grace
++grcan
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++gxt4500
++hackrf
++hamachi
++hampshire
++hangcheck-timer
++hanwang
++hci
++hci_uart
++hci_vhci
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfs
++hfsplus
++hi6421-pmic-core
++hi6421-regulator
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++hih6130
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi504_nand
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hopper
++horus3a
++hostap
++hostap_cs
++hostap_pci
++hostap_plx
++hp100
++hpfs
++hpilo
++hpsa
++hptiop
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++htc-pasic3
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hvcs
++hvcserver
++hwa-hc
++hwa-rc
++hwmon-vid
++hwpoison-inject
++hx8357
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd8111
++i2c-arb-gpio-challenge
++i2c-cbus-gpio
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-kempld
++i2c-matroxfb
++i2c-mpc
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-reg
++i2c-nforce2
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pasemi
++i2c-pca-platform
++i2c-piix4
++i2c-robotfuzz-osif
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i40e
++i40evf
++i5k_amb
++i6300esb
++i740fb
++i82092
++ib_addr
++ib_cm
++ib_core
++ib_ehca
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_qib
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibmaem
++ibmpex
++ibmpowernv
++ibmveth
++ibmvfc
++ibmvnic
++ibmvscsi
++ibmvscsis
++icom
++icp_multi
++icplus
++ics932s401
++ideapad_slidebar
++idma64
++idmouse
++idt77252
++idt_gen2
++idtcps
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imm
++imon
++ims-pcu
++imx074
++imx6ul_tsc
++imx_thermal
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int51x1
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_powernv
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipwireless
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++irlan
++irnet
++irqbypass
++irtty-sir
++iscsi_boot_sysfs
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it913x
++itd1000
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++kafs
++kalmia
++kaweth
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks0108
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kvm
++kvm-hv
++kvm-pr
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l4f00242t03
++l64781
++lan78xx
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-adp5520
++leds-bcm6328
++leds-bcm6358
++leds-bd2802
++leds-blinkm
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-ktd2692
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max77693
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-powernv
++leds-pwm
++leds-regulator
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libahci_platform
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_cs
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++liquidio
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++lis3lv02d_spi
++litelink-sir
++lkkbd
++ll_temac
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac80211
++mac80211_hwsim
++mac802154
++mac_hid
++macb
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mailbox-test
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++marvell
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max5821
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max77693-haptic
++max77693_charger
++max77802
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++md5-ppc
++mdc800
++mdio
++mdio-bcm-unimac
++mdio-bitbang
++mdio-cavium
++mdio-gpio
++mdio-mux
++mdio-mux-gpio
++mdio-mux-mmioreg
++mdio-octeon
++mdio-thunder
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++memory-notifier-error-inject
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++metro-usb
++metronomefb
++mf6x4
++mga
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microtek
++mii
++minix
++mip6
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmc_block
++mmc_spi
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi001
++msi2500
++msp3400
++mspro_block
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtd_dataflash
++mtdblock
++mtdblock_ro
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-sd
++mtouch
++multipath
++multiq3
++musb_hdrc
++mv_u3d_core
++mv_udc
++mvmdio
++mvsas
++mvumi
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxc4005
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxser
++mxuport
++myri10ge
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nci
++nci_spi
++nci_uart
++ncpfs
++nct7802
++nct7904
++nd_blk
++nd_btt
++nd_pmem
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_daq_700
++ni_daq_dio24
++ni_labpc
++ni_labpc_common
++ni_labpc_cs
++ni_labpc_isadma
++ni_labpc_pci
++ni_mio_cs
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicpf
++nicstar
++nicvf
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nmclan_cs
++nosy
++notifier-error-inject
++nouveau
++nozomi
++nps_enet
++ns558
++ns83820
++nsc-ircc
++ntb
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nvidiafb
++nvme
++nvmem_core
++nx-compress
++nx-compress-powernv
++nx-compress-pseries
++nx-crypto
++nxp-nci
++nxp-nci_i2c
++nxp-ptn3460
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_mmc_spi
++of_xilinx_wdt
++ofpart
++old_belkin-sir
++omap4-keypad
++omfs
++omninet
++on20
++on26
++onenand
++opal-prd
++opencores-kbd
++openvswitch
++oprofile
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_cs
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++palmas-pwrbutton
++palmas-regulator
++pandora_bl
++panel
++panel-lg-lg4573
++panel-samsung-ld9040
++panel-samsung-s6e8aa0
++panel-sharp-lq101r1sx01
++panel-simple
++parade-ps8622
++paride
++parkbd
++parport
++parport_ax88796
++parport_cs
++parport_pc
++parport_serial
++pasemi-rng
++pasemi_edac
++pasemi_nand
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_of_platform
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pcmcia
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sis
++pata_sl82c105
++pata_triflex
++pata_via
++pc300too
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_udc
++pci
++pci-stub
++pci200syn
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmcia
++pcmcia_core
++pcmcia_rsrc
++pcmciamtd
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcnet_cs
++pcrypt
++pcspkr
++pcwd_pci
++pcwd_usb
++pd
++pd6729
++pda_power
++pdc_adma
++peak_pci
++peak_pcmcia
++peak_usb
++pegasus
++penmount
++percpu_test
++pf
++pfuze100-regulator
++pg
++phantom
++phonet
++phram
++phy-bcm-kona-usb2
++phy-exynos-usb2
++phy-gpio-vbus-usb
++phy-isp1301
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-tahvo
++phy-tusb1210
++physmap
++physmap_of
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl2303
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8941-wled
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pn533
++pn544
++pn544_i2c
++pn_pep
++poly1305_generic
++port100
++powermate
++powernv-rng
++powernv_flash
++powr1220
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_core
++pps_parport
++pptp
++prism2_usb
++ps2mult
++ps3-lpm
++ps3_gelic
++ps3disk
++ps3flash
++ps3rom
++ps3stor_lib
++ps3vram
++pseries-rng
++pseries_energy
++psmouse
++psnap
++pt
++ptp
++pulsedlight-lidar-lite-v2
++pvrusb2
++pwc
++pwm-beeper
++pwm-fan
++pwm-fsl-ftm
++pwm-lp3943
++pwm-pca9685
++pwm-regulator
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa27x_udc
++qcaspi
++qcaux
++qcom-spmi-iadc
++qcom-spmi-temp-alarm
++qcom-spmi-vadc
++qcom_spmi-regulator
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qlogic_cs
++qlogicfas408
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quatech_daqp_cs
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++rack-meter
++radeon
++radeonfb
++radio-bcm2048
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-shark
++radio-si476x
++radio-tea5764
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++ray_cs
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++reed_solomon
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio-scan
++rio500
++rionet
++rivafb
++rj54n1cb0c
++rk808
++rk808-regulator
++rmd128
++rmd160
++rmd256
++rmd320
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpadlpar_io
++rpaphp
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtas_flash
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-as3722
++rtc-bq32k
++rtc-bq4802
++rtc-cmos
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-generic
++rtc-hid-sensor-time
++rtc-hym8563
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max77802
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-msm6242
++rtc-mt6397
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-ps3
++rtc-r9701
++rtc-rc5t583
++rtc-rk808
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-snvs
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-twl
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtc-zynqmp
++rtc_cmos_setup
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7706h
++safe_serial
++salsa20_generic
++samsung-sxgbe
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_sil
++sata_sil24
++sata_sis
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sbp_target
++sbs-battery
++sc16is7xx
++sc92031
++sca3000
++scanlog
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++sctp
++sctp_probe
++sdhci
++sdhci-of-arasan
++sdhci-of-at91
++sdhci-of-esdhc
++sdhci-of-hlwd
++sdhci-pci
++sdhci-pltfm
++sdhci_f_sdh30
++sdio_uart
++sdricoh_cs
++sedlbauer_cs
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial2002
++serial_cs
++serio_raw
++sermouse
++serpent_generic
++serport
++ses
++sfc
++sh_veu
++sha1-powerpc
++shark2
++shpchp
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sir-dev
++sis
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skd
++skfp
++skge
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++sl811_cs
++slcan
++slip
++slram
++sm501
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smc91c92_cs
++smipcie
++smm665
++smsc
++smsc-ircc2
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4117
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als300
++snd-als4000
++snd-aoa
++snd-aoa-codec-onyx
++snd-aoa-codec-tas
++snd-aoa-codec-toonie
++snd-aoa-fabric-layout
++snd-aoa-i2sbus
++snd-aoa-soundbus
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt3328
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-cs4281
++snd-cs46xx
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1938
++snd-es1968
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm
++snd-pcm-dmaengine
++snd-pcm-oss
++snd-pcxhr
++snd-pdaudiocf
++snd-portman2x4
++snd-powermac
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-sb-common
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-core
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-es8328
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-ssi
++snd-soc-gtm601
++snd-soc-imx-audmux
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rt5631
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-xtfpga-i2s
++snd-sonicvibes
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-usx2y
++snd-usb-variax
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-vxpocket
++snd-ymfpci
++snd_ps3
++snic
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++softdog
++softing
++softing_cs
++solo6x10
++solos-pci
++sony-btf-mpx
++soundcore
++sp2
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_dectlk
++speakup_dummy
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++spectrum_cs
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi-lm70llp
++spi-nor
++spi-oc-tiny
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tle62x0
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spl
++splat
++spmi
++spufs
++sr9700
++sr9800
++ssb
++ssb-hcd
++ssd1307fb
++ssfdc
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++ssu100
++st
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++svgalib
++sx8
++sx8654
++sx9500
++sym53c500_cs
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink
++synclink_cs
++synclink_gt
++synclinkmp
++sysv
++t1pci
++t5403
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc3589x-keypad
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tehuti
++tekram-sir
++teles_cs
++teranetics
++test-hexdump
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tg3
++tgr192
++thmc50
++thunder_bgx
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timeriomem-rng
++tipc
++tlan
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++torture
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_atmel
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps65218-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tsi568
++tsi57x
++tsi721_mport
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl-regulator
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udc-xilinx
++udf
++udl
++udlfb
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_fsl_elbc_gpcm
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++uninorth-agp
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmisc_imx
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vcan
++vcnl4000
++ves1820
++ves1x93
++veth
++vf610_adc
++vfio
++vfio-pci
++vfio_iommu_spapr_tce
++vfio_spapr_eeh
++vfio_virqfd
++vga16fb
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-ircc
++via-rhine
++via-sdmmc
++via-velocity
++via686a
++videobuf-core
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videodev
++vim2m
++viperboard
++viperboard_adc
++virt-dma
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_scsi
++virtual
++visor
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmx-crypto
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vrf
++vringh
++vsock
++vsxxxaa
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83977af_ir
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++walkera0701
++wanxl
++warrior
++wbsd
++wcn36xx
++wd719x
++wdrtas
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++windfarm_ad7417_sensor
++windfarm_core
++windfarm_cpufreq_clamp
++windfarm_fcu_controls
++windfarm_lm75_sensor
++windfarm_lm87_sensor
++windfarm_max6690_sensor
++windfarm_pid
++windfarm_pm112
++windfarm_pm121
++windfarm_pm72
++windfarm_pm81
++windfarm_pm91
++windfarm_rm31
++windfarm_smu_controls
++windfarm_smu_sat
++windfarm_smu_sensors
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wl3501_cs
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x_tables
++xc4000
++xc5000
++xcbc
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xhci-plat-hcd
++xilinx-tpg
++xilinx-video
++xilinx-vtc
++xilinx_ps2
++xilinx_uartps
++xillybus_core
++xillybus_of
++xillybus_pcie
++xirc2ps_cs
++xircom_cb
++xor
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yenta_socket
++yurex
++zaurus
++zavl
++zcommon
++zd1201
++zd1211rw
++zforce_ts
++zfs
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++znvpair
++zpios
++zr364xx
++zram
++zunicode
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/ppc64el/generic b/debian.master/abi/4.4.0-111.134/ppc64el/generic
+new file mode 100644
+index 0000000..7db146e
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/ppc64el/generic
+@@ -0,0 +1,17418 @@
++EXPORT_SYMBOL arch/powerpc/platforms/pseries/hvcserver 0x048d27cc	hvcs_register_connection
++EXPORT_SYMBOL arch/powerpc/platforms/pseries/hvcserver 0x536d329b	hvcs_get_partner_info
++EXPORT_SYMBOL arch/powerpc/platforms/pseries/hvcserver 0xc39c3704	hvcs_free_partner_info
++EXPORT_SYMBOL arch/powerpc/platforms/pseries/hvcserver 0xd0a02396	hvcs_free_connection
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0x6310e901	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/atm/suni 0x3767787f	suni_init
++EXPORT_SYMBOL drivers/bcma/bcma 0xad904fd4	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/bcma/bcma 0xc0beb89b	bcma_core_irq
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x1f20b41b	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x2ed110ba	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x3b13668f	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x40e97e80	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x4267110a	pi_register_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0x533d5374	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0x7021ae0f	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0x850a1127	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x8e5b3139	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xa099d012	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0xb21ba07d	pi_unregister_driver
++EXPORT_SYMBOL drivers/block/paride/paride 0xcdcccfd0	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0xda688311	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0xe351f440	pi_read_regr
++EXPORT_SYMBOL drivers/bluetooth/btbcm 0x72fd5275	btbcm_patchram
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1fae3bac	ipmi_addr_src_to_str
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x34bf5219	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e780260	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x7af4d0b0	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x968a288b	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x9c455efa	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xd69f8567	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0x15b88dc5	st33zp24_probe
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xb97fee93	st33zp24_remove
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xcc83a553	st33zp24_pm_suspend
++EXPORT_SYMBOL drivers/char/tpm/st33zp24/tpm_st33zp24 0xf200a61c	st33zp24_pm_resume
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x25978d50	xillybus_isr
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x6bbe6899	xillybus_endpoint_discovery
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0x77a4173c	xillybus_init_endpoint
++EXPORT_SYMBOL drivers/char/xillybus/xillybus_core 0xa97427d1	xillybus_endpoint_remove
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x2385ffc9	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x27128e93	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x4f396681	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x5da41417	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xa8da6d8d	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xacbc7631	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/edac/edac_core 0x7598135c	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04d0f641	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x09a2b42a	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0f7d6af8	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x11c08bdc	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x26cf0e14	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2e8e7149	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3a4e88d5	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4c9faf6a	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x5e01637b	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x61235a99	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x645b715f	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7257b397	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7adcb050	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7da40075	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8bcd0244	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8eb29233	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8f6d6998	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90c12c77	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x946eedda	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x981f53b8	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa7cf2007	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xabe515b9	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xafd9aa72	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb7b607ae	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xc0226273	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xc7261677	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xd5b9294e	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xebae6876	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xfb49caa9	fw_core_handle_request
++EXPORT_SYMBOL drivers/fmc/fmc 0x71a000fd	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x819f722c	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0x83d1da48	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x95be98de	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xb2ef7fb5	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0xbc19fb03	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0xc2f58625	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xc8735c50	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0xca3fbd83	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xcfe7c3a2	fmc_driver_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xd20a3c5e	fmc_device_register_n
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x00d8eedb	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x01c931b5	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x033c18fc	drm_mode_equal_no_clocks_no_stereo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x03dfac00	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x05039ca9	drm_modeset_lock_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0574f3c5	drm_crtc_check_viewport
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x08716213	drm_atomic_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x091eeaa4	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a404f42	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a596fcd	drm_of_find_possible_crtcs
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a72f765	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0b00e2cf	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0b841825	drm_platform_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0bc7c8ff	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0c7be9ce	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0cf101b4	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0d058693	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0db8b000	drm_legacy_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fe4b887	drm_legacy_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x107742a9	drm_get_subpixel_order_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x10dd008c	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x111b35de	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x120a3c68	drm_atomic_state_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1312e45d	drm_dev_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x15ec78ab	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x16c41002	drm_atomic_set_crtc_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x17dcfaca	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x18c77c2f	drm_mode_create_rotation_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x190dcee6	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x19e4430f	drm_flip_work_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a546ddd	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1b35293c	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1bd3cbd6	drm_flip_work_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c10d22a	drm_crtc_get_hv_timing
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c74e0db	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c83800a	drm_gem_dmabuf_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1cc68c78	drm_property_unreference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1d1adc5d	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1da5c65f	drm_plane_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1dd71f7a	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20056f34	drm_atomic_set_crtc_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22acaf62	drm_get_cea_aspect_ratio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2320f5d1	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x240073cd	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x24bd99d6	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2528ac14	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2594efb8	drm_legacy_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x276f94e9	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x289cb803	drm_bridge_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x28c9e46d	drm_atomic_set_mode_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29a010e6	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2a599ec6	drm_compat_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2a8f98a2	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2b420591	drm_dev_set_unique
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2bcb8bfc	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2becb155	drm_atomic_async_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c2665a3	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2fff042d	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x314d6fd9	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x31b1302a	drm_legacy_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3349bf92	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x340cbf4f	drm_agp_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x342730d5	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x35bf12cb	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x36609431	drm_crtc_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3743885e	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37d703c1	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37ebe743	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x389fef3f	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b663290	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3c1bce64	drm_crtc_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d8a1262	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3f3dee8d	drm_mode_plane_set_obj_prop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x41648e41	drm_plane_from_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x42197ca0	drm_universal_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x430e26bf	drm_crtc_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4421a7dc	drm_bridge_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x443a6e47	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x45eb0a93	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x461980e9	drm_legacy_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4671344f	drm_flip_work_queue_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x46ab831f	drm_agp_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x46c54d33	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48487cc0	drm_crtc_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x487449a8	drm_hdmi_vendor_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48fdeb9a	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x490cfb78	drm_mm_reserve_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4b3270c6	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4bec95dc	drm_encoder_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4cb242fe	drm_atomic_legacy_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4cd9bb75	drm_atomic_state_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ef88efb	drm_modeset_drop_locks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4f6b3954	drm_mode_create_aspect_ratio_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50587215	drm_bridge_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50c0ae55	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e03d1c	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5139fc46	drm_modeset_backoff
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51db353a	drm_vma_offset_manager_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x535a6be9	of_drm_find_bridge
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54571f00	drm_agp_info
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x546ab29b	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x55eba4f7	drm_atomic_state_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x565e4bd5	drm_modeset_acquire_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57b6efe3	drm_ioctl_flags
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x581c3371	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59ef50f0	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5a4bbd4f	drm_panel_detach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5b5ccbfe	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d7318dc	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5dad2550	drm_agp_acquire
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e2df838	drm_modeset_lock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5f3c5720	drm_legacy_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6006576e	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x601b184d	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x624c96a9	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x64bebb35	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x65769b09	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x65aec88f	drm_legacy_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x65c0bbb9	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67633846	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x682da34f	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x689c6b4c	drm_atomic_get_crtc_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68ed607c	drm_flip_work_queue
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68ed8de5	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6905a28c	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69acc20a	drm_connector_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69b2e563	drm_panel_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6c3c4900	drm_agp_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e30ba8e	drm_rect_rotate_inv
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6eeceb53	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x70437adf	drm_crtc_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x704bf914	drm_flip_work_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7072302f	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x71d20cf1	drm_gem_dumb_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7318315e	drm_vma_offset_lookup_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x735ae7a8	drm_gem_get_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x73c1d19e	drm_property_create_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7484b78f	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74a6025c	drm_modeset_unlock
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74f97a8d	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x755ecc5b	drm_dev_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x757bad1b	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7763715e	drm_bridge_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7765d988	drm_gem_create_mmap_offset_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x77e784ec	drm_bridge_post_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x78c441da	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x79339c01	drm_dev_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x79703b9b	drm_atomic_add_affected_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c4ec438	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7ccb3f90	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7cf2dd02	drm_gem_put_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7db083c9	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7f7658ad	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7fd18df3	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82277fcf	drm_atomic_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82c2998f	drm_flip_work_allocate_task
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8330b3cc	drm_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x834823a7	drm_mode_create_suggested_offset_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x83577fe4	drm_atomic_add_affected_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x837c85bb	drm_vma_offset_manager_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x841476ca	drm_legacy_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x855a5823	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x861e74e3	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x866c1b45	drm_crtc_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x879c24b6	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x893cff67	drm_bridge_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x89bd2a10	drm_atomic_state_default_clear
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a0f391c	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a45e8bf	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a7b45e0	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ae1314e	drm_vma_node_revoke
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c3d81ee	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c6b3277	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8cf53804	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d39e32f	drm_modeset_backoff_interruptible
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d5a274e	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d97b5dc	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eb72cc5	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ed999c3	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91a9be84	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91daf280	drm_atomic_clean_old_fb
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92408488	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x924a583b	drm_legacy_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9253bb4d	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x92a43e72	drm_atomic_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x938d26d8	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x944b8db7	drm_legacy_addbufs_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x94642766	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x94f263d0	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x95cd49a0	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x967f0298	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x99766572	drm_crtc_vblank_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9b8a4874	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9badd66f	drm_vma_node_allow
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9bb8bc41	drm_connector_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9cdd4519	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9d3642d3	drm_ioctl_permit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9dd35500	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9e52c2be	drm_agp_unbind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f16b9c2	drm_invalid_op
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f3a8df5	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa08e5c9a	drm_atomic_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1c9c5da	drm_display_info_set_bus_formats
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa28078b2	drm_edid_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa42cb27e	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa4466414	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa56453d7	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa9456586	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaa39bff0	drm_mode_create_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaae660f6	drm_dev_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xab4ad7aa	drm_atomic_check_only
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xabf1e807	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb026e944	drm_of_component_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb053adda	drm_rect_rotate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb0b67cea	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb15619e1	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3492304	drm_atomic_state_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb3bea8ea	drm_crtc_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb413c7b9	drm_property_create_bool
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb43823e8	drm_vblank_no_hw_counter
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb47c933e	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb4b6088e	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb50a9777	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5540008	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5a06523	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb90dee1b	drm_atomic_state_default_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xba47e6fa	drm_atomic_set_mode_prop_for_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbac1eef1	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbba5abde	drm_pci_set_busid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbc1c4b0c	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbebc6728	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbf446a95	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbfda4a6d	drm_panel_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc14b732d	drm_crtc_init_with_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc15e3152	drm_panel_attach
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2a0f2dd	drm_bridge_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2d62667	drm_bridge_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc3026e1e	drm_agp_bind_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc360e7e2	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc36160f7	drm_crtc_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc36e9d34	drm_atomic_get_connector_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc5ba8757	drm_legacy_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc5d1684d	drm_crtc_wait_one_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc67e9d23	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc6943f35	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc7127333	drm_bridge_pre_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc782b9ed	drm_vma_node_is_allowed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc8a03cbe	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc9af1ea7	drm_modeset_legacy_acquire_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc9e1fe4e	drm_modeset_lock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca5c7790	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcab151c6	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcac80958	drm_modeset_acquire_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcad5eb0a	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb2340b8	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcc8ec6ce	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcccccc0d	drm_crtc_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xccec6efd	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd3dbed0	drm_modeset_lock_all_ctx
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcde9b624	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf6ac75a	drm_mode_validate_basic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd1242548	drm_modeset_unlock_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd149ca69	drm_crtc_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd38a3ebb	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3e3fd29	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd52b1d11	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd6b30fbd	drm_mode_get_tile_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd70c8470	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd7fcde2b	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd8ec710c	drm_connector_index
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd97923ea	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd9bc72a1	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdb55d3c1	drm_atomic_get_plane_state
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc072293	drm_agp_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc87d3d3	drm_property_create_signed_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd150721	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf666902	drm_rotation_simplify
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe03edfcb	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe09d2cc9	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe0eca408	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe116bed5	drm_pcie_get_max_link_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2ffd7a5	drm_vma_offset_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe3611724	drm_property_create_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe4428d62	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe4b36f3a	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe4d8d4dd	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe51d89b5	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe539f4af	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe64062fd	drm_property_reference_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7dccd88	drm_vblank_on
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe940302f	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea2f89b1	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xea5b7234	drm_dev_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb242c3c	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeda22970	drm_agp_bind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xee60cca9	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1b098be	drm_vma_offset_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf29a579f	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf38ffe77	drm_mode_connector_set_path_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf66184ae	drm_legacy_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf6f036fd	drm_set_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf81087a9	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf83ae891	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9582e69	drm_panel_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9e4a972	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb8b9f2b	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb98fa2b	drm_atomic_set_fb_for_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc30af03	of_drm_find_panel
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcec0d9d	drm_arm_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcf54a4f	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd063935	drm_edid_to_speaker_allocation
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd54aefa	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd980847	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff39033e	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff3f150b	drm_mode_connector_set_tile_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffafa4e1	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffb57b8a	drm_property_lookup_blob
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x009c9506	drm_atomic_helper_crtc_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x01544fbf	drm_dp_dpcd_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x025318c5	drm_atomic_helper_check_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x052699ef	drm_plane_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x065c043b	drm_dp_mst_detect_port
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x080f7c65	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0854a10e	drm_plane_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x088dacda	drm_helper_crtc_mode_set_base
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x098e47d2	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0b8e863d	drm_atomic_helper_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0e69c2e0	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0ea2854a	drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f50c6bf	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0f96ec70	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x148c3b2c	drm_dp_link_probe
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x149bd81b	drm_fb_helper_sys_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x162d7bbb	drm_dp_dual_mode_set_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x163251c8	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16345e33	drm_dp_mst_hpd_irq
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16b42c6e	drm_fb_helper_release_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x16e91115	drm_dp_aux_dev_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1aacf4db	drm_fb_helper_sys_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1c655fa1	drm_atomic_helper_commit_modeset_disables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x21311601	drm_dp_dual_mode_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x22e180c7	drm_fb_helper_alloc_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x261bd0a5	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x268b2442	drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x26cc2ed6	drm_atomic_helper_prepare_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2a01d4cd	drm_fb_helper_cfb_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2a67b25b	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2d4926e7	drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2e7b34ab	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2f433758	drm_dp_mst_reset_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2f80307d	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2fdfc074	drm_fb_helper_unlink_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x30bfddcf	drm_atomic_helper_plane_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x34871adf	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x39566b3b	drm_atomic_helper_commit_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x39c13113	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3be0de1d	drm_dp_mst_topology_mgr_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3c783fc3	drm_dp_find_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x400ed024	drm_dp_dpcd_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4084ae57	drm_atomic_helper_commit_planes_on_crtc
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4181cdf8	__drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x428e6211	drm_dp_mst_topology_mgr_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x49a0a7d7	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x49b537ca	__drm_atomic_helper_plane_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4a236df5	drm_fb_helper_remove_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4c6d2810	drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4da25a99	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x500d9490	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x514ec489	drm_dp_mst_allocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x51ec52cb	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5407ae9e	drm_dp_get_dual_mode_type_name
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x543d30c6	drm_fb_helper_sys_write
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x55b26105	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x55ef3084	drm_kms_helper_poll_enable_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x59187a6f	drm_dp_dual_mode_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x59954e3b	drm_atomic_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5a583b9b	drm_dp_mst_get_vcpi_slots
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5b4ee447	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5e6a3d70	drm_atomic_helper_update_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5e6ea667	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x614a755b	drm_atomic_helper_plane_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x62c92b59	drm_pick_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x65bb805d	__drm_atomic_helper_connector_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x681149f6	drm_atomic_helper_commit_modeset_enables
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6850fcfa	drm_fb_helper_sys_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x69b8a06f	drm_dp_dual_mode_read
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x69c762e8	drm_primary_helper_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6db1086a	drm_dp_mst_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6e5b9ed5	drm_primary_helper_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6e6b3e9a	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6ffb734a	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x70562ff6	drm_atomic_helper_legacy_gamma_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x73260152	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x744be014	drm_helper_crtc_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x74a05b0d	drm_lspcon_get_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7537f6b5	drm_dp_dual_mode_get_tmds_output
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x75ea672d	drm_atomic_helper_check
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x78b631b9	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x793516b5	drm_atomic_helper_connector_set_property
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7bad3e67	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7d3f6f77	drm_primary_helper_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x838e61e6	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84e924ba	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x86115006	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x88f354c6	__drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8c27f67c	drm_fb_helper_cfb_imageblit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8de5a44b	drm_has_preferred_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x92035256	drm_dp_mst_deallocate_vcpi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9229d049	__drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x92656993	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x93c5c101	drm_dp_mst_topology_mgr_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x93fae800	drm_atomic_helper_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x96281224	drm_atomic_helper_crtc_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9aa0ca6e	drm_atomic_helper_check_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9b3a8819	drm_dp_aux_register_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9e3a94e9	drm_fb_helper_cfb_copyarea
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa47826e4	drm_dp_calc_pbn_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa52cea88	drm_dp_link_configure
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa77858bb	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa9a47abb	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa9a80552	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaa14450b	drm_atomic_helper_framebuffer_changed
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab0e7cd4	drm_fb_helper_modinit
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab50596a	drm_dp_update_payload_part1
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xacce8819	drm_lspcon_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xaea0ccdb	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb25c8c87	drm_dp_mst_dump_topology
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb2a156ee	drm_atomic_helper_connector_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb42da781	drm_dp_mst_topology_mgr_set_mst
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb9ff82bd	drm_atomic_helper_disable_plane
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xba90871b	drm_atomic_helper_wait_for_vblanks
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbd813316	drm_dp_aux_unregister_devnode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc0d395da	drm_plane_helper_check_update
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc17d0252	drm_fb_helper_restore_fbdev_mode_unlocked
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc1f95ead	drm_fb_helper_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc2569ce2	drm_dp_update_payload_part2
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc63a5da3	__drm_atomic_helper_connector_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc668ef7a	drm_fb_helper_unregister_fbi
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc6eca9b3	drm_dp_mst_port_has_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc862d4d3	drm_helper_probe_single_connector_modes_nomerge
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc99f461e	drm_fb_helper_add_one_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcd5cb6eb	drm_atomic_helper_swap_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcd8d98e9	drm_atomic_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcda42e4c	__drm_atomic_helper_crtc_duplicate_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcec25fec	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcfd19e68	drm_atomic_helper_page_flip
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd038f8ea	drm_dp_aux_dev_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd17047ab	drm_dp_aux_unregister
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd194a9bf	drm_dp_aux_register
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd540212e	drm_atomic_helper_crtc_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd61c1baf	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd67f0cd3	drm_helper_crtc_enable_color_mgmt
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd77534ee	drm_atomic_helper_cleanup_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdc6bbcde	drm_fb_helper_sys_fillrect
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xde6b3bb0	drm_atomic_helper_update_legacy_modeset_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe23c92f4	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe6331a58	drm_dp_mst_topology_mgr_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe9e01b6b	drm_atomic_helper_disable_all
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xea0e83f6	drm_dp_link_power_down
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeaf772dc	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xeccabe34	drm_dp_check_act_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xed776c2a	drm_dp_dual_mode_max_tmds_clock
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf4650a49	drm_primary_helper_funcs
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf7cd7385	drm_fb_helper_set_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf90b555a	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf931f7c9	drm_dp_dpcd_read_link_status
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfaf3426d	drm_atomic_helper_suspend
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfca28024	drm_atomic_helper_plane_destroy_state
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfdd841c6	drm_atomic_helper_resume
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfedb6680	drm_dp_link_power_up
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0ec52203	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1481e5d8	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1509cf4b	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x17a01eb5	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x17b224c6	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x187cfb01	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2050b92e	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x20f8758f	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x21e214b2	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x240c634b	ttm_agp_tt_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2cd0f767	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x323a1e23	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x38d365e5	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3db55b01	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3ebf7069	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x40bb9554	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x40f75906	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x417a83e3	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x41860047	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4c7688e2	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4e8dd264	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4fb80bac	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x51dffc96	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x549a26e3	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x564e1aee	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x590e447d	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5a8fdfea	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6052860c	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6165b025	ttm_bo_move_to_lru_tail
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x62205672	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6221f079	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x626985a1	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x62787051	ttm_agp_tt_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x62eba954	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x63eadd30	ttm_bo_mem_compat
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6611c5d5	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6822d849	ttm_prime_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6a685a67	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6f435396	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x72160460	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x772c12c5	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7bbb9eb5	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7d55da85	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7e693bcb	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x849b995d	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x84a13931	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x880a15ad	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x89a443de	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x89f91e05	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8d0db21a	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8d14adbf	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x93f124cc	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x94894449	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x98052c6f	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99d0eb91	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa2a129fd	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa502d46a	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa73de2a9	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xaa5234b2	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xaaa5fc65	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xae3b47a6	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb26785c6	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb63aee85	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb83c6470	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbbd6a594	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc20268f5	ttm_agp_tt_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc4ac4216	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc5f0c2da	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xce6e43a8	ttm_base_object_lookup_for_ref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcf67c299	ttm_ref_object_exists
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd0bc943b	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd7f51742	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd8edb115	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe6dca0ed	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xea2b1942	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfdb3c613	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x7458d385	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x8b580bf6	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xa90b126e	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x2544874f	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x5d832ec3	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0x503f415e	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x0e2481aa	mma9551_gpio_config
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x41ef446c	mma9551_read_accel_scale
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x6634b1b9	mma9551_read_version
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x84bc4b7f	mma9551_app_reset
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x8c4b3ea2	mma9551_write_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0x9e2b7c0c	mma9551_read_status_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xa029637f	mma9551_update_config_bits
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xa7a8a93b	mma9551_read_config_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xb347762f	mma9551_write_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xbcd7fe96	mma9551_sleep
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xd1403301	mma9551_read_status_word
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xdeb1a345	mma9551_read_status_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xe3cb1a43	mma9551_read_config_words
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xea6a0905	mma9551_read_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xeef3b5b6	mma9551_read_accel_chan
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xf61bf590	mma9551_set_device_state
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xf896cf22	mma9551_write_config_byte
++EXPORT_SYMBOL drivers/iio/accel/mma9551_core 0xfa67dbac	mma9551_set_power_state
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x82705b43	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0xd839ca92	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x092cf90b	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/buffer/industrialio-triggered-buffer 0x22a4371b	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0x9756e602	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xb80bcd26	devm_iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xef2d3119	devm_iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/buffer/kfifo_buf 0xfc75c687	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x273423ac	hid_sensor_read_poll_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x2cb65557	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x2ec649c6	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xa48a16bd	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xa95b47cb	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc83a92bf	hid_sensor_format_scale
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xdc1614cd	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x51ed588e	hid_sensor_pm_ops
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x7530d6b9	hid_sensor_power_state
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x9721d4df	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xc55813e3	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x0582025f	ms_sensors_tp_read_prom
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x09763aee	ms_sensors_read_serial
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x1fa7a88c	ms_sensors_show_battery_low
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x211d9f2c	ms_sensors_read_prom_word
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x2b4407d7	ms_sensors_read_temp_and_pressure
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x6456bb58	ms_sensors_ht_read_humidity
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x75304201	ms_sensors_ht_read_temperature
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0x8142892e	ms_sensors_convert_and_read
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xae0d52bd	ms_sensors_write_heater
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xc77b421f	ms_sensors_reset
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xd536d212	ms_sensors_write_resolution
++EXPORT_SYMBOL drivers/iio/common/ms_sensors/ms_sensors_i2c 0xe0e595ca	ms_sensors_show_heater
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x0ee3456d	ssp_change_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0x5124a0b5	ssp_get_sensor_delay
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xd14cdcb6	ssp_register_consumer
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xd512fd7c	ssp_enable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/sensorhub 0xf0cac171	ssp_disable_sensor
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x26c4500f	ssp_common_process_data
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0x6067c309	ssp_common_buffer_postdisable
++EXPORT_SYMBOL drivers/iio/common/ssp_sensors/ssp_iio 0xa7d5dfbf	ssp_common_buffer_postenable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x037534d2	st_sensors_power_disable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x1354869b	st_sensors_validate_device
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x13c126e6	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x2f8d15d1	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x404ec258	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4ac8838a	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4cbb40eb	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6c341502	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6c54f6c2	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x7beba391	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x837a78aa	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x8aaa470e	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x91fcfafc	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x94b18e3f	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x98d14ea7	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf248ce80	st_sensors_power_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf6b09c52	st_sensors_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x29c45d1f	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x483e6b38	st_sensors_of_i2c_probe
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0x69ee8f23	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x3aea9784	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0xe1f50bab	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/humidity/hts221 0xf0fe681d	hts221_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x544781cd	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x756c20b9	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/industrialio 0x0ea6d8f6	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x3de8336c	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0x4afe3a65	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0x5a390dd5	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x5efb8bff	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0x610e72bb	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0x654821a3	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x78869ee4	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0xa5d97feb	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xa712523a	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xa98a5a93	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xac09d222	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0xd335bdee	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xd573018e	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0xd7fc44ca	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xf2b01617	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0xf74afdca	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0x372e650f	iio_triggered_event_cleanup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-event 0xa7fcc90d	iio_triggered_event_setup
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x4dab8f14	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xa7dd0daa	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/ms5611_core 0x85e46687	ms5611_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x4aec7bd6	st_press_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0xf3530b7b	st_press_common_remove
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x08522972	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1ea5767b	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x32a8402c	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x512bbc90	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xa2034ffd	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xf5850aba	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x0f2a3446	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x13b89a9d	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x393614f7	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x3a50b3d7	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x4514e715	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x47f1433e	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x5835f31a	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x734ebeac	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x97d89430	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x99fe917b	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa7aa819e	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xae0f32f9	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xaf70d2bf	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xb74c70de	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd4a478ad	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xdbb6c3f7	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xf6b0774d	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xf8d239b0	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x008cb3a4	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x03d6783e	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x04da5d6f	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x04db8257	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0aa93f8b	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0cf2061d	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0f9b7e9d	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x15155c79	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x16dc2713	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1b947680	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1ca15842	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x22f3cf93	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2647f827	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x275a623b	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x293694f8	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x29f21fde	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2da4e924	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x35c75388	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3a6e1ac6	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3abf1639	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3ffa1570	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4290fbce	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x42be3966	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x458e550c	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x468d1f4f	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x476f5a50	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4b4e5f1f	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4c583bca	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4e46eb17	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x51d6e3e7	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5adb6550	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5c9b422d	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5f48780c	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x60b295b1	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x63aec64b	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6b2de349	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6e939918	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7304705c	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x73230caa	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7330defc	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x747d6be6	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x76e4579f	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7abcf48d	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7d3dcc8d	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x87465f6a	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x87f39651	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8ba8e530	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8f948586	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x916bf420	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x94f71e1c	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x96bbdd8d	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x97c993f5	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9a4159ac	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9d327a31	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9e2f023a	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9f0d9962	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa1c8ed78	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa432baf6	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa48c5afd	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa5956f94	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6d9ea6c	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa7c84b69	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb4949de2	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb9a386ae	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbe258ee4	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc192e6d1	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc2960ff0	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc4ef311e	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc723bd71	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcd37ecc5	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcd69d5be	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd10b1d6a	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd585be1b	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd613278a	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd6191fcb	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdaa68467	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdb2ecbf7	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe01c77bc	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe132f0c5	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5433816	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe7e5afbc	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xecce98f5	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf308adb3	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf88e993e	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf9f21418	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x01c8974f	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x24f4c2bc	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x292ee552	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x3229f95f	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x35286fd9	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x45bb32a0	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7a016d49	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x98272e80	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xb9ffbbed	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xc6e9f437	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xcfd18f6e	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd0cf152e	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xe393b884	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x154e019f	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x5328d7a6	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x79b02e24	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x7e57fea6	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x9a1cd50d	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xb2c6a5fe	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xc45e369d	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xca380964	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xe131bbe7	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xe2c7a5c6	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf5885587	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x893dfa28	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xb21e0b79	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x21b3ab8e	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x2b734b78	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x2c7718df	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x301d5291	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x34d076ab	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x46ea1786	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x530c508f	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x8d007289	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x984c4818	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb44b90b2	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb512e8b1	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xbb1933dd	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xbb3f2335	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xbcb16a17	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xcea82652	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x0e18e2c8	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x23d21ac6	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x387a0e5e	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x51e3ab73	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x55e11ef8	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5ccb37b6	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5ea8073a	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x61fefe22	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x69e4d2d7	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x6bd7f82e	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x78129c7f	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7ba9566f	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xaa7661fc	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xab1e3f1d	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xac94eb1b	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xc4b31b92	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xceefc63d	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xcf97a3f2	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xe9a1929d	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf55e228d	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf64f79ef	rdma_bind_addr
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x0d58e11b	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x0efb1428	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x26ca40eb	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x2d8d9b20	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x7194b439	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x8e7319c8	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x8f74233d	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xb8c5aa13	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xc5c7de1d	gameport_open
++EXPORT_SYMBOL drivers/input/input-polldev 0x03d8651d	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x266a5319	devm_input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x9e4a709d	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xbf691065	input_register_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xcd822ac5	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0xf9220615	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x47aefcd0	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x8578f702	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xd6a13697	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x09466106	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x028e77dc	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x8f9638ff	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xa5be4c95	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xe74cf543	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xfb4e063b	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xfc05a15f	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x260abf4a	ad7879_probe
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xe41e7110	ad7879_pm_ops
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x1eb1018e	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6387ad8e	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x639b8bd0	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6e25a7dd	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7292ab34	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x72a25a72	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8644b5e9	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaae48066	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaf70bfe4	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xbd5a4b5e	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc42d9ec1	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xd4974d63	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xef5e13e5	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xfd552f7a	capi_message2str
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x0dd5bdbe	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x11c027d0	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x23779819	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x3197ae91	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x3a787f2d	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x54932712	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xa03e130c	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xb26e3a78	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xb380f8a3	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xc7b995c2	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xd212b542	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdd6ddb4f	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xe23f4e4c	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xed9ef7f1	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfe213b79	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x08db7478	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x24c84bee	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x40732b25	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xcd6ea402	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xe35f10ef	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xe84a8464	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xeb88ce22	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xf7d914c8	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xfb2fba87	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x247cfe1d	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x6466aae9	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x9a67b570	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xb367379b	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x18cbf8b2	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x601cb718	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x2d6072f5	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x6fe1ca04	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9f987c85	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1bc94b9	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x19dd525b	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x2eecd262	isac_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x4589ee31	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x47d320bc	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xc5135d87	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x6540ad99	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x7a2eb023	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xe6565794	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x06fcebef	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x160cb7f1	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x161bd9da	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1b74a116	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1cf196fb	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x214f35f9	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29fa5b43	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2fa8c43f	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x36ec1940	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3be21029	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3f5c476d	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4b8a7699	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x56606839	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x61b076f6	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6945c73f	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x73715d57	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x73f6e89a	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7c339626	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7f006719	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x84d863fc	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x9bf7c558	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x9dcfc2c6	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb7f5a050	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xca949256	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd8a5220a	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd9d1c3a7	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf015fc57	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x1d89bd11	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x1f529ce8	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x26481f26	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x440b4830	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x44a37d62	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x5b59b856	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x65881412	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7d61e1de	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7daccb73	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x8833b0e8	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xa3c5c702	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xabc42122	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xca5df778	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xce47a6d9	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd2813054	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xdf892351	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe67c2d16	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xec6f33d0	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xecc2e3b7	closure_put
++EXPORT_SYMBOL drivers/md/dm-bufio 0x268682d2	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-log 0x2a2ba98b	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0x3238e8c2	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0x9bf0d476	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0x9e16d88b	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x073f8f01	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x0c076835	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x625e3ef5	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x6b870ca5	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xc659a7cd	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xf185184a	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/raid456 0x0c83501f	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x0e6f39ca	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x27fea75d	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x2bb1a50e	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x366aed31	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x3df6c1be	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x40ae7fdc	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x797a751e	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x7dc26a8c	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x92e8c95c	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xc218168c	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xc8d3cac8	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xcb846c09	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xef2a8a8f	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x291ac060	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x30cb4cd7	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x98dee968	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc7cbe011	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xeb7cfc3b	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0x11073bc8	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x1e7320f4	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x416f8c85	tveeprom_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x01cb9c29	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x03e696e1	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x08d4f238	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0da03dda	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2bf8da1a	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2ccca199	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x30adbe4c	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x32706276	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3c7ff401	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4a95b2ec	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4d2cbaa8	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5170aa58	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5b8f8ac7	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5c0ea535	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5f44ef42	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x70af1058	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x73f30e14	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x78db694b	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7a48bf31	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7f4f9b54	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x85a5e7d3	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x95aca22c	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x986ffc29	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa04207d2	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa3ab49cd	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa75aa468	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xcc1dbbff	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xcf589e8c	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd2a6489a	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd8f7184c	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdee88fa9	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe1b715a2	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe934ed3f	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf28e7431	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf4a4f1dd	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf821d629	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf8fd5dd7	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfbaa7e01	dvb_ringbuffer_write_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfc125d6a	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0x1141b15b	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ascot2e 0xdccbe116	ascot2e_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0x251df176	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x075512fd	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x0c32eea2	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x486a1a96	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x4a4846d1	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x532d8aa9	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x66a53110	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x7cf1b0e2	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x9990ab4e	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xb86ab28a	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0xe68ea354	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0x7966e641	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0x5260a13b	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0x8189edfc	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0x9df96de7	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x233450c0	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x9a11a888	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0x0094af0f	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24120 0xc4c918a9	cx24120_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x2c5c9807	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x858bd962	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0xd373c913	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x4c357c73	cxd2841er_attach_c
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0x5e674f6b	cxd2841er_attach_s
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2841er 0xb42425df	cxd2841er_attach_t
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xae47f75d	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xb99df847	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xca53d00f	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xfe0e1b6e	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xff4db1e5	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x0869441c	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x0b1d248a	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x27ea7270	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x4cc89801	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x4dafc5f2	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x6090024c	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x872a52ab	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x9d5703e4	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xb9ff5f07	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xc0b6572d	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xc3cab8cb	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xd817441e	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xeaa5bf47	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xec990be8	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xeea7faa1	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0xd583a84c	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x0680a70b	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x61715e0a	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x64d11382	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x6ff3350f	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xa24856f6	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xbaf8930a	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x11fc90b7	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x8701ee7c	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xd496085d	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xdbdb61ae	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x248b0cb4	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x3d664e79	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x0e96fb6d	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x4d7d0a80	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x55155da1	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xb14cf0c4	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xe9f86853	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drx39xyj/drx39xyj 0xdf7f16ba	drx39xxj_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0x2a839a47	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0x73aaf4b6	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0x3fba57f2	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0x65306a52	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0xf2a5ec39	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/horus3a 0xe459c86f	horus3a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x88c39521	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x7d596775	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0x8c8186ea	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0x477c0186	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0x040a7341	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0xf5261aec	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0xe3aa02bc	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0xf5b2faca	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3306a 0x94646e34	lgdt3306a_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x6ecf2db8	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0xb32f64ac	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbh25 0x8be74389	lnbh25_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x16b8eb9a	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0xbc50cc1b	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0xe2a8fca4	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x1972bb3b	m88ds3103_get_agc_pwm
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88ds3103 0x4477df6d	m88ds3103_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0x4dda0de3	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0x4a67ac41	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x12776689	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0xf5b1ef32	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0x8c715cd1	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0x47db9655	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0x32138d84	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0xfc056660	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0x88092cf6	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0xa92dff49	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x107770e3	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x6428b4f7	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x9ec829ce	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x29b4d3db	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si2165 0x248fe0f1	si2165_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x3ede8f23	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0x572c56c6	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0x04999407	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0xf9eaf448	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x6fd27550	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0xf9f0e8d3	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0xfaf0ae0e	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0xd25f00a3	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0xd251cba3	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x298d74e3	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x2ad44cf9	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0xfbdbae19	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x757145fa	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x04fab2ad	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0xa4e21baa	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0x999d5a45	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0x67ba2a64	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0x53b9ee66	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x02567768	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x3643df00	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0x8aea19d2	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x6913aa7b	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x3fdaa167	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0x0be78992	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0xe0a714e6	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0x870329c6	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0xa418e891	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0xf68c619f	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x138ea67e	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0x34b96c47	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0x4993357b	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0x6dda266b	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x322dacea	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x3ccd837f	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x44eb0ae6	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x6e63fc68	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x7cd93737	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x9cae520e	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xa0e8bcd4	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x2a56db61	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x38451049	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x9c146e37	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xfbcf7fe9	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x566988e6	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xf458146b	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xfc8fb279	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x45aebbc5	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x4e1a2b81	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x684f36bb	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x71e93333	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x8afc5e03	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x92134e98	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xbaad9ace	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xd1669f48	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe9682ff1	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0xff49b390	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x25d7bd6c	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x3d5965d9	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x5d6ef101	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xd510e735	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xe1fdd3e6	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x7cbc9fba	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x04d5904f	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x117facfc	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x385f00fc	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x69d71ee0	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x81b0c8d7	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xb61f0ae0	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xbdbbbd3c	cx25821_riscmem_alloc
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x02bff4b6	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xee470f03	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x229e7544	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x77ead2c5	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x8e631dd1	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xf8e69e6d	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x0ba5d834	cx8802_start_dma
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x15f26feb	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x57c0cbe7	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x6c112cc6	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x957a9d54	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xa16d6274	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xfb98a68f	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0a85d07e	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0b85a632	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0cb84613	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0eabeb82	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0ecbed4a	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x0f59ac22	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x1658e0ca	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x48a964cf	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4a527adb	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x5151fdd5	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x556faaeb	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6471dd24	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x90e85404	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x9ac892b7	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x9de09a3f	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb1a927f0	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xccd05e57	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xcf49c3d9	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe03af282	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xfc199d85	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x0f42f961	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x109d46bf	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x19576a1d	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x3cc572b1	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x4d0509e1	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x718faa2c	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x7c19d142	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x83d91e22	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa5ba629c	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa99fa38b	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xae538d20	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xd7c5e4bf	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xdabaa3b0	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xdcc303e0	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xeac8e6ab	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xeee96df1	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xf442ae0e	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x049331f9	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x2875747c	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x6a05efce	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x75c66969	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7852f589	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7ac3b444	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x93d29c39	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa352157f	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa3b23ea1	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xb7b69dcd	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xbb73bc97	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xebed3485	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xf972ce67	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xf5759bfc	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x19782dae	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x1e8fa10e	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x26ed0d51	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x3f6f7cbb	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x698c63e2	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xa4e3cdd7	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xd71bc53f	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x29f5a98b	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xdc5dafe2	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x02e51633	snd_tea575x_s_hw_freq_seek
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x198275c0	snd_tea575x_hw_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x42cb572d	snd_tea575x_init
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x84fe4e5c	snd_tea575x_exit
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x8fb755a3	snd_tea575x_g_tuner
++EXPORT_SYMBOL drivers/media/radio/tea575x 0x91d9bbf8	snd_tea575x_set_freq
++EXPORT_SYMBOL drivers/media/radio/tea575x 0xfc3a8d14	snd_tea575x_enum_freq_bands
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x03f8290e	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x48e77ccf	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x5e18f9b0	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x72fd3f57	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xa0ee7085	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xac0dc6af	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xc63f26e0	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xf4c2723e	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x43516ec4	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x5f04dc3f	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0x8e9445d6	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0xb4ceab7e	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x3810dc2a	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x4c140869	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x5b787169	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/max2165 0xb9c85801	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0xda6c038f	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0xc359ee98	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0xfb1159bd	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0xc6e9336e	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0xb705c42d	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0xbf463044	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0x95dfaa34	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x4813c5dd	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0x2ccd2ecd	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0xccce6e2e	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x7b466266	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xd121c485	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x0f0a41ae	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x27ea7844	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x3d04af1f	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x423a32df	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x7f756346	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x8d71cd39	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xbd8e10e9	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xcc05db5e	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xffb03d4c	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x00f9e8d8	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x20fe4fb2	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x5e5d7679	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x9b7482ad	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x9da145e7	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xe1f457c7	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xf9f7ca5e	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xb47b62ef	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x07245b1f	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x0caa3a75	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x11f44c76	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x1aa4f439	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x1c7af8a6	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x466ede8a	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x56701942	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x697ad6cb	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xa0a04e6d	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xba94a20e	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xe2eb774c	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x442b06ec	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xd83c49b0	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x30887a38	go7007_snd_init
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x5fa83e2d	go7007_register_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x720ce3de	go7007_snd_remove
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x7646cb2a	go7007_update_board
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x791352ed	go7007_read_addr
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0x94e0ce79	go7007_alloc
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xcbf012ff	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xd150aba0	go7007_boot_encoder
++EXPORT_SYMBOL drivers/media/usb/go7007/go7007 0xde202d55	go7007_read_interrupt
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x0b34d3e1	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x1a5d3d6d	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x2cd9fae8	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x308fafc3	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x35ee32fd	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x5a919266	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x77fbb2e3	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xcf3c52b3	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x1c4deef6	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x51481423	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xf85d450a	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x4701f318	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x6cc6f2d2	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x58a6afe3	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x897a666b	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xacf371ca	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x28400bb9	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x456c54ab	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x50b39bbe	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xa6fd1ce5	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xb305df9f	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xec325063	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x4fce54f9	vb2_buffer_in_use
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x9753ba8e	vb2_verify_memory_type
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x4ed17dea	vb2_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x513f3dde	vb2_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x69eb3aca	vb2_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0x8c93f11d	vb2_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xd6ea5e91	vb2_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-dvb 0xe09b7466	vb2_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0x52e96379	vb2_destroy_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-memops 0xab31d65a	vb2_create_framevec
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-v4l2 0x391d27b7	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x091e4385	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0928f4a6	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0c4e67f7	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0d4b93eb	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0dc7148d	v4l2_query_ext_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x10b53148	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x11cd9343	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b5c0864	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1e5a6619	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2aa14a35	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2c838f6d	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2d13536f	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36847d11	v4l2_ctrl_get_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3c3193f4	__v4l2_ctrl_s_ctrl_string
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3e5beb80	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3ef4fc3a	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3f890a63	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45a44c24	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x47d548a5	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4a6706a9	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4a9e37a0	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4af1f856	v4l2_of_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b374c99	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4b77c88d	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4d699aef	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x58141592	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x59ad5c47	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5eb654fe	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5f75554e	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5fea4618	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x60f8405d	__v4l2_clk_register_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x63563ce4	v4l2_of_alloc_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6378e39c	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x674b0e9a	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x68f44a79	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6bd73096	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6e427c00	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6e6e39e2	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x70c63fd9	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x71c6bec8	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x742c32d8	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x746c01e6	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x772d005b	__v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7bb05e51	__v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7d3639c3	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7ddb5412	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7e20b3ad	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7f0d1380	v4l2_of_put_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7f89f0a6	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8d7c3e50	v4l2_clk_unregister_fixed
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x96b32098	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa53ca32c	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa54c8a47	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa7b7a903	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xad7cdc2c	v4l2_of_parse_link
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xae7644ae	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xaf12dc7e	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb077c136	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb47507c6	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb9921364	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbd3afbd8	v4l2_of_free_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc2a91015	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xca4d8252	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcb82707d	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe1400ad5	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe64b106e	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe6e225af	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe988d749	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe99e1168	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xefb4282b	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf025b86f	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf5983801	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf6758d12	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf9b88e0d	__v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfaf53ceb	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfb67c93d	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfe5a4d35	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x0a44f0e4	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x16252c4c	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x21be6318	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x7fb92382	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x985fdc6f	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xb41da18a	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xba120369	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xba492a00	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xc6d96a2b	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xd3d77b1f	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xd4bb1dae	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xdc07e67e	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xfe6dc565	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x0405b725	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x05221b5f	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x130a0932	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x13b76b06	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x231bf72e	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3d5356b3	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4632ccd1	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x5e512018	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x667eb2f5	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x69938d57	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6f3e67c4	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x79ce08e1	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x7fe3f558	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8c47af61	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x93f0bab3	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa1084504	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xac0c2376	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xac9df562	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xba17b52b	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xbf1fd9c4	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc26b6c77	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc39886c7	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc9730a7b	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xcc61622f	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd6a86567	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf492edc1	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf84fc165	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf91e0b1c	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xfe290321	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x031bf2a9	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0c83bfbf	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1964eacc	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2c6130e2	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x30505eba	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x3f31c0b3	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x43c64e7b	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x46e3c27f	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4e0d3253	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x6d542720	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7caf0e2b	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x82e5b5cb	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9939112a	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xa04e471c	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xabd50504	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xaf6e4de0	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb0baeacf	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb3075b4a	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb437184d	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xba114682	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc47323d8	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xce3c4477	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xce5a670a	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd050c633	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xde7ebefd	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf46eb6d7	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf740c4d8	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/mfd/dln2 0x4c4e926f	dln2_transfer
++EXPORT_SYMBOL drivers/mfd/dln2 0x6f5c26c1	dln2_register_event_cb
++EXPORT_SYMBOL drivers/mfd/dln2 0xb2549a51	dln2_unregister_event_cb
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x1ad3a67d	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x6b085fc6	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x34756edd	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x38ea177f	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x4d0eaf9c	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x547380e3	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x67ca2b53	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x9576015d	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x96acdcd0	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xbe7b7164	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xd28199f3	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xd727c820	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xee3cf602	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0x69a6c2b8	wm8994_irq_init
++EXPORT_SYMBOL drivers/mfd/wm8994-irq 0xe6b37b35	wm8994_irq_exit
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0x55d1ac97	wm1811_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xb5fa1d43	wm8994_base_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xcab3aeba	wm8958_regmap_config
++EXPORT_SYMBOL drivers/mfd/wm8994-regmap 0xf8891523	wm8994_regmap_config
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x9c1dc384	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xd6a01e45	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x30b3ae49	altera_init
++EXPORT_SYMBOL drivers/misc/c2port/core 0xd98d79c9	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0xe2cec360	c2port_device_register
++EXPORT_SYMBOL drivers/misc/ioc4 0x0061ca03	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0x9cdd3d0e	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/tifm_core 0x2d3407e5	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0x3831808b	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x4a637744	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x5470a5fa	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x572df9e0	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x789ff6ee	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0x81110cc0	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x89b680ec	tifm_add_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x9b691729	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xa8c2ec46	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0xd5e589c5	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xf3a6b8a1	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xfdbc2c02	tifm_remove_adapter
++EXPORT_SYMBOL drivers/mmc/card/mmc_block 0x16799cdd	mmc_cleanup_queue
++EXPORT_SYMBOL drivers/mmc/host/of_mmc_spi 0x8c3324af	mmc_spi_put_pdata
++EXPORT_SYMBOL drivers/mmc/host/of_mmc_spi 0xe3058280	mmc_spi_get_pdata
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x02c9089b	cfi_send_gen_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x092ddf01	cfi_merge_status
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x14084910	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x69114ece	cfi_build_cmd
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x695e85bc	cfi_build_cmd_addr
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xb08f16fd	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xc082a62a	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xff9fa623	cfi_udelay
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x05fc73e0	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x092c6069	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x26777d72	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x7d163012	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0x832b7ed0	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0x63cf58f2	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0x5e1c3ae3	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x28495523	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/mtd 0x60f49742	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x6a3d1df7	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xcc27760d	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x2f279dd1	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x863683bd	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x8ecbb3b8	nand_check_erased_ecc_chunk
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xa25ed29a	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xcbd726d8	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xd19f33b3	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xef859391	onfi_async_timing_mode_to_sdr_timings
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xff77c5cf	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x539f1d58	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x60d331fe	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x655ee84b	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xa918039f	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb1d6a500	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x8cfcf75c	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x0ab570be	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x18b03f4c	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x82541550	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xcab1e3fe	onenand_default_bbt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x04282789	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x291df088	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x52c8e885	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x56a350d2	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6c7b066c	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6f3383c3	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x71922cdd	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x75b17d54	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x8b2b02e7	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x8e3e3d2f	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x22d4d691	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x57cdef5d	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xfd3d9d63	com20020_found
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x0fbe3bcc	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x13194895	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x17008856	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x6e94740f	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xadd90256	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xba5726e1	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xd8148772	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xe24704e3	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xe9978913	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xec42476d	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/bnx2x/bnx2x 0x76b7b24a	bnx2x_schedule_sp_rtnl
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0xbc8c8314	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x0d8be5fd	bgx_lmac_rx_tx_enable
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x285bde59	bgx_get_rx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x42264715	bgx_get_lmac_count
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0x6dc1648d	bgx_get_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc397f585	bgx_lmac_internal_loopback
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xc82be691	bgx_get_map
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xe48ca42a	bgx_get_tx_stats
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf101d1b2	bgx_get_lmac_link_state
++EXPORT_SYMBOL drivers/net/ethernet/cavium/thunder/thunder_bgx 0xf9508980	bgx_set_lmac_mac
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x00cb1760	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x15009284	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x153cc690	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x1652c5da	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x166c1b78	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x2293d944	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x2d6f3878	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x368da86d	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x570c3038	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x67c15c5e	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x6987d7e5	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x728edd0b	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x95d3ccc2	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xdeb279df	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xf5cd9df7	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xf8897aac	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x009d6866	cxgb4_remove_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0b887288	cxgb4_select_ntuple
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x17d587a5	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1a2902b3	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x21f77456	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x2fbfdaed	cxgb4_clip_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x353409db	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x35a7fea9	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4326c7b0	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4c3f465f	cxgb4_create_server6
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x50ee5c07	cxgb4_best_aligned_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x540e4a33	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x56e19c60	cxgb4_read_tpte
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x582d46c0	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x5d2f5f20	cxgb4_read_sge_timestamp
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x66f06625	cxgb4_tp_smt_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x69939324	t4_cleanup_clip_tbl
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6ae25ae0	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6d248ae2	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6fc34b2b	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6fedfd89	cxgb4_clip_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x723ed6ca	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x75945849	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7f1b07c8	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8734f980	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xad91a4c9	cxgb4_dcb_enabled
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xadb4e4e7	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb0687115	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb6263a9d	cxgb4_update_root_dev_clip
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xba72d7e5	cxgb4_bar2_sge_qregs
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc24e732f	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd8fb6d82	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe3a2fbb3	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xef30c82c	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf69d65f5	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xfb115be6	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x0c4e80b6	vnic_dev_get_res_count
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x14551099	vnic_dev_get_res
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0x69d04225	vnic_dev_get_pdev
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xb6fb9939	vnic_dev_register
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xc653c94c	vnic_dev_unregister
++EXPORT_SYMBOL drivers/net/ethernet/cisco/enic/enic 0xd33c66f4	enic_api_devcmd_proxy_by_index
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x0b734959	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xe270c037	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x009019d1	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0778e5d2	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b23f81f	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0d336163	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x143d2fe9	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x158fc4dd	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1a6cc852	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1c3df44f	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1ef8059b	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x383c0c77	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5665dea5	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5b11b93e	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x670207c5	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x69f514d8	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6de0a64d	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6ed27da2	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7351539d	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8075a45e	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x81237e41	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x85867766	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x99592fa5	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9c56bb0d	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa4a66a3b	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa592c822	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa75bd18d	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xad2276c4	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbd99475c	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbe81b470	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc1a27758	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xca4c5947	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd37712fd	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd97e2334	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe3765ca2	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe50ea4f1	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe5e1c129	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf4ea1b08	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf7ef0068	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfec113c7	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x112346f7	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1b006ee8	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x278a7203	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x29c69bfa	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x349884d6	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x361f6a26	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x49449a60	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x49f0d37d	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x592dddfa	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5ebd8fc8	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6792c1d7	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6ecb208d	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x714c65bf	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7c95701b	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x86d87081	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x88ad3d70	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8968cd9a	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8a998e97	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8b6a9560	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8da99b12	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9266459b	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9dd20620	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa2b141f4	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa94829ed	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xadb91a56	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb1a7faaf	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb2012b1d	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb2a8e74e	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb418c5e4	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbab8ef4b	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc89c42a2	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xce9cbf06	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcfa126be	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcfb823c5	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd30425b5	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd3e0a38d	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdbbee33c	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe118c68b	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x148d6e08	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x18251e44	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x2d07a992	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xa7801c0b	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xb30c5b82	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xc0a90902	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdc7e92f7	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdec53276	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x06512589	qed_get_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0x9eeeef48	qed_put_eth_ops
++EXPORT_SYMBOL drivers/net/ethernet/qlogic/qed/qed 0xa209d1af	qed_get_protocol_version
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x0accfa88	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x201d07e4	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x66ccc0a1	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xb1bf78a2	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xe9399d19	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x1635d8a0	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x3004dcff	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x36095a73	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x747b5250	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x9427446b	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x98387222	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xb361d94d	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xbddd320b	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xcd414f08	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xff37031e	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x2375a8fa	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0x35fd1c5c	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0x5e23e268	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0x726d88e0	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0x7db6b41d	mii_link_ok
++EXPORT_SYMBOL drivers/net/mii 0xa27b2fcd	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0xa2e984eb	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0xee145af5	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x436988e0	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0xf56bff89	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0x14381f70	cavium_mdiobus_write
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0x53a13fa0	cavium_mdiobus_read
++EXPORT_SYMBOL drivers/net/phy/mdio-octeon 0x8a1d5c26	octeon_mdiobus_force_mod_depencency
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x41988118	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xe0abf466	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xf1601243	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/vitesse 0x8009f0c8	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x4c0da047	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x78cd81a8	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xff9a4fda	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/sungem_phy 0x32666852	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/team/team 0x135ec401	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0x3ddb27fd	team_options_unregister
++EXPORT_SYMBOL drivers/net/team/team 0x4af8b6f6	team_options_register
++EXPORT_SYMBOL drivers/net/team/team 0x7187f925	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0xb7598090	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0xbdc0f3cd	team_mode_register
++EXPORT_SYMBOL drivers/net/team/team 0xce344c81	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/team/team 0xe041efa1	team_mode_unregister
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x414c8be8	cdc_parse_cdc_header
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x8179a714	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xb36adc57	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xf0f2168f	usbnet_link_change
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x3ee0e475	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x76d8e97f	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x77f42d65	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x79cf63df	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x8dbd2014	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb3d7b3d0	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb5f24f2c	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb772338b	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xdf6fb32c	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xed0aedfb	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xf4fb9232	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0x89c000f2	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/airo 0x1a7ef341	reset_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0x567c7bee	init_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xfb563da6	stop_airo_card
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x0e2cead9	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x12f6ef79	dfs_pattern_detector_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x13a71042	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x6521a18c	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x742cc925	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x792302ab	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x998d38d9	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xa46e8810	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xaafdb617	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb1affa64	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xdc80cad4	ath_is_mybeacon
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xf3529b40	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xf5f06740	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfb4de67a	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x026e9d99	ath10k_htt_hif_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x1aeed0d3	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x35fcc099	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x3947362e	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x4b7d3143	ath10k_htc_tx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x58b8a60a	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x68dd7082	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x73331744	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x9dafa1d5	ath10k_print_driver_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xa0c3bba1	ath10k_core_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xac00dc6f	ath10k_core_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xb610d922	ath10k_htt_t2h_msg_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xb66236bf	ath10k_debug_get_new_fw_crash_data
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xcdd76364	ath10k_htc_rx_completion_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xe9787767	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x166b9c4b	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x30814472	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x37020de9	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4338e261	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b317424	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x80a09613	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x981dddc5	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa6f66cc1	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xaa8449b3	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xaf363254	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xb4fc40e2	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xba5856be	ath6kl_read_tgt_stats
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb014460	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb749582	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xf723287d	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x04c35810	ath9k_cmn_debug_base_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x24669ea2	ath9k_cmn_rx_skb_postprocess
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x27342e9e	ath9k_cmn_spectral_deinit_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d15177d	ath9k_cmn_debug_stat_rx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2d8f641c	ath9k_cmn_rx_accept
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x2fa2f7f1	ath9k_cmn_setup_ht_cap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x3a8b0881	ath9k_cmn_debug_modal_eeprom
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x3abd6138	ath9k_cmn_debug_recv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x4ad39d97	ath9k_cmn_debug_phy_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x69a5ee9c	ath9k_cmn_init_channels_rates
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x8cacdd2e	ath9k_cmn_process_rate
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9555e9c1	ath9k_cmn_reload_chainmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x9c6ae55a	ath9k_cmn_spectral_scan_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb35a1f26	ath9k_cmn_process_rssi
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xb7932300	ath9k_cmn_beacon_config_ap
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xc175af0c	ath9k_cmn_beacon_config_sta
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xc348bdb0	ath9k_cmn_spectral_scan_trigger
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xcfde79d0	ath9k_cmn_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xde5398f9	ath_cmn_process_fft
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xdf94d62e	ath9k_cmn_spectral_init_debug
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe3d9497f	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf4231366	ath9k_cmn_beacon_config_adhoc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf4e21330	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf851c42a	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x022fab4c	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x04570d97	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x076018a7	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x083306cc	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0b8608ad	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0c26003a	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0c9ff169	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0f9fbec3	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x10db3475	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x11d401fe	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x198e2b57	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1a0f55ab	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1a25f69b	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x218445d0	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x274ca7ed	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2c32347e	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2ead11d2	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2f3025eb	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3093f1e8	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x32e2f098	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x337372c1	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x33d1eba5	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3a9cd29a	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x41bfaf52	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x41ee2c86	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x43d8cad1	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4485f820	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x44ba95a5	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x44d9ed24	ath9k_hw_check_nav
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x450e4737	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4578fa0e	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x485eb5e0	ar9003_hw_bb_watchdog_check
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x49635b27	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4ad2d223	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4df83069	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x51679472	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x552002b2	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x561471a8	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5be412c2	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5c90b653	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5fdd998f	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x60cf2640	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x614e5821	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x62332e95	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x68752422	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6ac70754	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6c4f7b12	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6cc81771	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6ef2a8d7	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6f10c6bc	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x751f5253	ath9k_hw_set_tx_filter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7827c616	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7b22aa71	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7b4e52f9	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7b54eef7	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7ce6b0b8	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7edf78bd	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x82c724aa	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x83c2e220	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x84fce887	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x86e16854	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x86e8ac6f	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8e48e9c2	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x90cc0685	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x932acd79	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x948260fa	ath9k_hw_resume_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9741f52f	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9e15a75a	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa1d3cdd3	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa3fbfbe7	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa57af7bb	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaa42abc2	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaa6b3da8	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaec96205	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaf9ddd01	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb2744d8a	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb373a4a3	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb68ca53a	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb973726e	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xba4af31a	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbd025905	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc157e951	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc21ca0ab	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc36c1fae	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc5aa258e	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc8ce3ff1	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcc68816e	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xccb18acb	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xceeb994e	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd3c4a156	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd907f374	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdf23a88e	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdf98a1d9	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe028894c	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe3433d2f	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe3a80734	ath9k_hw_request_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe58e354b	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe8253313	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe9dc3e0a	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xeaee3ea9	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf03a26eb	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf25e0659	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf2956fa3	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf4323705	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf9f68f26	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xffd02408	ath9k_hw_get_tsf_offset
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x561723cf	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x68da2d17	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xeffcd249	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x05362d0a	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x380eea10	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3bda9ac3	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3f2988a1	brcmu_dotrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x6109e820	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x78a494e1	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x7e347ab1	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x844505c5	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9c985657	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9f4b5dcf	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xb539f150	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xc94a723b	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xd261b8a6	brcmu_boardrev_str
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xddd17d00	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xe4931648	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xec02fe63	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x00d5e8d2	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x060f50e7	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x074384d7	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1723ac32	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1d809ab0	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x2bca5560	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x52e29c29	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x53fd353e	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x5ba0b624	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x826fb083	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x830abdbf	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x87764fdc	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x95cbe30f	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x98fa30c0	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xab3f7cfd	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xad4081bb	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xba7bd1fc	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc5ca8a5b	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc89fef4b	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xdbb53d3c	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xdd98cc3c	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe4d5f95e	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe66e72a7	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe7047f51	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe75c1dac	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf883967e	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x05378b18	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x1c639852	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x1c931fed	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x576b3eb0	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5c082220	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5f0c2552	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5f0ec931	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x6f2fa25e	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x76468f41	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x7d1fcedf	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x895a65ae	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x900ff215	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x93dfb4cb	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa2c5bec2	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd09a0c9c	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd0aa8151	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd60d5e98	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd681e9d8	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xdc00af82	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf01e6a10	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf537751c	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0045644e	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x057712ee	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x05c2ed5a	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x08d0ae51	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x091b1ad4	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0b6ca2b1	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x127ee7f5	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x171e1eb0	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1896cbab	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1e374a46	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x203d8b89	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x241fd08a	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x25393459	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2772713f	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x27971d9d	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2857af50	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x28b7b186	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2ac93fb5	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x362eae87	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x398fc874	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3bb37ff1	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3fab8c72	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x41267c20	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x43f61962	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4541f8b5	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4bb089fa	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4efde3cb	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4f84ac44	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4fc7703b	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x520e92ec	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x534c0bcf	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5375c068	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x567a967e	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x57a4cc1d	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5c2960ec	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5e139820	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x60441639	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x65d93281	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6eb02324	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6f6adbdc	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7131d0fe	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7407308f	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x74a57312	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x772a9900	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7c7fb481	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7e822e08	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7ec1daf6	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8057e4d7	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x80a4b11c	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x817a9522	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8912011a	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8bd7d9da	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x91272732	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x941d32fd	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x95843d7b	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9759769e	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x99c209d1	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9afb8504	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa08b66d7	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa212ab65	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa5ee0cb7	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa86378b9	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xad1eddd4	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xad5d00de	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xae3f866a	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xae8c34a9	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xaf227fe2	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb0f26f34	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb9799d95	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xba8b1d3a	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbcb8ac42	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbd9baa88	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc2bb87f5	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc4485791	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc4acb44f	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc792cd95	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xca2dfde0	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd1b9378b	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd350b119	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd362526a	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd47010f8	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd494e0d3	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd4ec20bf	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd90f8a07	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdc78bdd6	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe107afd8	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe1f95cb4	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe2946e19	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe3ac1ca4	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe45a2fa4	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe6befb08	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe981fbf8	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xebbe8b04	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf1a1c3f5	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf2d30ae6	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf3ad8891	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf4793eaa	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfe5b1228	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x1b06ce78	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x2447a6ab	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x314a20a8	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x5e9c24ff	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x8c8ab242	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x9a1b1df9	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xdced6db1	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x0c127c6c	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x10fa5cf7	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x19661981	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x4acfe52d	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x4f4f026a	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5dea5bf1	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5e1f69ce	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x646d1774	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x6e37ede4	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x92ee8eae	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa2cb61b1	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xac3fee07	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xbafeaa4f	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xd9d30cdd	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xdcbc32b4	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xddfee316	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf875ef9d	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/btcoexist/btcoexist 0x061ed64f	rtl_btc_get_ops_pointer
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x02ce79a4	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x04e8fc66	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x199ad6a3	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x1be1018c	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x238bb8aa	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2842f50a	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x2a7917e1	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x333b7bf5	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x3992c634	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x44028ac7	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x4bc339c7	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x54fc53b4	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x598729b5	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x59d0b3e7	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6be7db8a	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6de9c8ff	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6ee0861e	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x6fd2455e	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x70ae7c0e	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x79af69c7	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x85fb7c11	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8c9bc490	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x966c0d28	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x973b42b1	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x9808b810	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x99d6d24f	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x9cec3307	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xaaab8d91	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xab4d716b	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xaf6cfa87	_rtl92c_phy_dbm_to_txpwr_idx
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xb669d394	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xbc3caeff	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc049010d	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc0bbdd89	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc48ab6fb	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc7e7ffe0	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xdd8eeac9	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xe38470ec	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xea7e572c	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xeb13ef86	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xf73bfc9d	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fb9f06f	rtl8723_fill_dummy
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xbda3a1ea	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xc1712ac7	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xeedcc71c	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_pci 0xff2ecd1b	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x30c4d3ab	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x32488776	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x35efc437	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtl_usb 0x6056f803	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x07a8b040	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x08802ede	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0a13cf10	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x1035eedf	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x115e693e	rtl_dm_diginit
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2d8dfaef	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x38ae873e	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x418e8099	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x4347b130	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x442c45ab	rtl_rfreg_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x44d24424	efuse_shadow_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x457f671d	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x5b1d48a5	rtl_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6637c708	rtl_cmd_send_packet
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x751c1d55	rtl_bb_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x7a52a6cb	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x89225c02	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x938d9cd5	rtl_wowlan_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x980848e2	rtl_addr_delay
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x9a2edcdf	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xaf277e51	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xbbb46dc7	efuse_one_byte_read
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xc6cd4e87	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xcab6ecf3	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xcca539c0	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xd6ccde0a	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdd422a12	rtl_hal_pwrseqcmdparsing
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe088c123	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe58708e1	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x43b73f32	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x5132d1cc	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x69a31e3e	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x7536dcec	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x250bb0b8	fdp_nci_remove
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0x9b0453db	fdp_nci_recv_frame
++EXPORT_SYMBOL drivers/nfc/fdp/fdp 0xb1ae6304	fdp_nci_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x39a93a28	microread_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x4655e1de	microread_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0x66dd0a4d	nxp_nci_fw_recv_frame
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xd1e8bad0	nxp_nci_remove
++EXPORT_SYMBOL drivers/nfc/nxp-nci/nxp-nci 0xfd8cfd8e	nxp_nci_probe
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x31ed4433	pn544_hci_probe
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x53a11b9b	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x628d7f8f	s3fwrn5_remove
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0x6fcf6eac	s3fwrn5_recv_frame
++EXPORT_SYMBOL drivers/nfc/s3fwrn5/s3fwrn5 0xad6b5867	s3fwrn5_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x021513df	st_nci_se_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x05f44c41	ndlc_remove
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x19cb4663	st_nci_se_io
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x283cccf0	ndlc_recv
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x33fa694d	ndlc_send
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x53a04198	ndlc_probe
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x685e75c8	st_nci_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0x9d32be5b	st_nci_se_deinit
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xb1f95a84	ndlc_close
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xd89dc0a4	st_nci_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st-nci/st-nci 0xea26eaf1	ndlc_open
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x0472a91f	st21nfca_apdu_reader_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x14fb6500	st21nfca_tm_send_dep_res
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x1aab1630	st21nfca_hci_enable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x2e8bb276	st21nfca_se_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x39ef011c	st21nfca_hci_disable_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x3fa48ccc	st21nfca_im_send_atr_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x4f9e5409	st21nfca_im_send_dep_req
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x5c848ef3	st21nfca_hci_probe
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x6864d8b8	st21nfca_vendor_cmds_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x8fd2e044	st21nfca_hci_loopback_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0x905f1cbe	st21nfca_hci_remove
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xa1d51c8c	st21nfca_se_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xb1faaa39	st21nfca_hci_discover_se
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xd9f81cba	st21nfca_dep_init
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xeb00810f	st21nfca_connectivity_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xeeed082b	st21nfca_dep_event_received
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xf7f4fd52	st21nfca_dep_deinit
++EXPORT_SYMBOL drivers/nfc/st21nfca/st21nfca_hci 0xfb9bf0a8	st21nfca_hci_se_io
++EXPORT_SYMBOL drivers/ntb/ntb 0x038341ed	ntb_clear_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x0b223c79	ntb_set_ctx
++EXPORT_SYMBOL drivers/ntb/ntb 0x143de258	__ntb_register_client
++EXPORT_SYMBOL drivers/ntb/ntb 0x4a4c6da1	ntb_register_device
++EXPORT_SYMBOL drivers/ntb/ntb 0x504f8c11	ntb_unregister_device
++EXPORT_SYMBOL drivers/ntb/ntb 0x66132119	ntb_unregister_client
++EXPORT_SYMBOL drivers/ntb/ntb 0x662c3eff	ntb_db_event
++EXPORT_SYMBOL drivers/ntb/ntb 0xa22a78bb	ntb_link_event
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0x9c71cd58	nvdimm_namespace_detach_btt
++EXPORT_SYMBOL drivers/nvdimm/nd_btt 0xb0cb949f	nvdimm_namespace_attach_btt
++EXPORT_SYMBOL drivers/nvmem/nvmem_core 0x50f3486e	devm_nvmem_cell_put
++EXPORT_SYMBOL drivers/parport/parport 0x00e350ca	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0x028eda43	parport_del_port
++EXPORT_SYMBOL drivers/parport/parport 0x03f11392	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0x06b3c555	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x0b7373f5	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x1522bf2a	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0x1cf6d662	parport_register_dev_model
++EXPORT_SYMBOL drivers/parport/parport 0x2dc5cfd0	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0x2e58dff3	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0x36192721	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x3f4bf25b	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0x408f1787	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0x4149b762	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0x44aa603b	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x53a1b2f9	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0x53cb1c54	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0x5c4e93dc	__parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0x5c8a74c2	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0x5ce93969	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x71448d4a	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x7a1f2a61	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x9139bb22	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xac53eff6	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xb0016d06	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0xb2087cdd	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0xbb8cd686	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0xc9cd5c54	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0xde324204	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0xe7eed140	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0xe9da4222	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0xf1667a39	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0xf4bbeb82	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0x04cf9f9f	parport_pc_probe_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0x803ddf85	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x062aa21e	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x167f6786	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x1e7fc013	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x4d3a4941	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x5a3c015d	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x81bd9aa5	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x98a28e84	rproc_get_by_phandle
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xab2a6ef9	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xc4ff49fe	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xfd37d72b	rproc_put
++EXPORT_SYMBOL drivers/rtc/rtc-ds1685 0xf8712cd1	ds1685_rtc_poweroff
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x4a29ab38	scsi_esp_intr
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x82cdfd38	scsi_esp_unregister
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0x869b71b0	scsi_esp_register
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xa0b3bc8d	scsi_esp_template
++EXPORT_SYMBOL drivers/scsi/esp_scsi 0xe6d2941a	scsi_esp_cmd
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x0b533a35	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x10c25160	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x31abed16	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x3ce18345	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x80ad8f3f	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x8be66e7d	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x9d74d335	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xa3e7c68f	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xbe470a79	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xd51bdc2f	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xec0c09d5	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xf96dcc00	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x04072cde	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0b8bb605	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x13c074f4	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x15341bf5	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x19dcdff9	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1f672c8f	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2ae97065	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2d3254d1	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2ee4be6f	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4038a268	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x42cc6cd6	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4896bab6	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4967afa1	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4988251a	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x520ae8e4	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5303afb0	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5ccc441b	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5df5d996	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5e9e6acd	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x64de7961	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6e12b1a7	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x74b799b2	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x74e5da12	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x81d28a65	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x83a16ce2	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8863fbef	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8af1f083	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8b066375	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8e2c15d7	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x93296fc4	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9845ca46	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb854aef1	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbb79a32e	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbf4c89d5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc0c953e3	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc6b45c40	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd0a66354	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd2ac4a41	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd731e1e6	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xded02ad9	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe4bf405d	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe8bd924a	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe94fbc22	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe99db7eb	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xec0d99ff	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf383f5de	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf85caffa	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfc0c9952	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfc2335fd	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xff3b2592	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x77a2fb8f	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x98002db0	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x9fe7f0e2	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xfb05b35b	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x0614b70f	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x041a22f1	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0b16af09	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0b396a91	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x111a2b8b	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1a7a6a3f	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x22b8c33c	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x2485ae74	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x26c07410	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x2920bdb5	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x307eda0c	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x383686f7	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x430b7f15	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4742624d	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4a5e21c1	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5233acdd	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x54a82460	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x58f340bf	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5fba9f11	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x64fdfcfa	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x69aa5e7c	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6d54eb28	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7db03ea6	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x824a075e	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x87e3e4bc	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9266df76	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x960cf0c5	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x98f9780d	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xad922a25	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc9e21aca	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xca6816df	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcaf92fbd	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcd81d297	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe42c87d0	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe4b825d0	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf7b54f65	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfe06bc9e	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x35334f44	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x48e06f04	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xb5eb7a4f	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xbe105ee9	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xf28dbca1	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xfaafb0ec	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x0eee2b2c	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x257315fc	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x36d94dd3	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x4c3dcd93	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x4e35d4f6	qlt_abort_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x5911cd5c	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x5cda5caa	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x5e9c7dbe	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x81d0c2c0	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x89fcb8c1	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xac389e55	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xc72771dc	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/raid_class 0x5473eb48	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0x9251c5ba	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0xc5179245	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x0027f535	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x2bd116b6	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x5350d0f3	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x5a68afae	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x5bfd8afc	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x68535fae	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x8e066400	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x953b7b5d	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x9b5303fa	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xa154c885	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xfbb9be03	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xfdf25152	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xff803985	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x14a97a19	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2bff35d0	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x46abb599	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5693043c	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5832d882	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5ed52f6c	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x674bdb5c	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6a649116	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7611f081	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x78dc2c26	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7e59edc6	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x8941177e	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x89f50728	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x8cc14988	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x92a23c29	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9d73b668	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa169ff05	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xadd100b0	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xaff31b5f	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc60cfb7a	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd6c89eeb	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xdd2597b8	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe12ce4fe	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe1a1ea99	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe96952df	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf3c687d5	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf5515eee	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf80aec23	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xfd0b70eb	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x015c2582	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x279400b5	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x8140ddad	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xb2090fb7	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xd3baaa0f	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x2bb504c1	ufshcd_alloc_host
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x379e5017	ufshcd_runtime_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x43804e94	ufshcd_runtime_idle
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x6660d3dc	ufshcd_shutdown
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x756886bc	ufshcd_system_resume
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0x91ac6835	ufshcd_system_suspend
++EXPORT_SYMBOL drivers/scsi/ufs/ufshcd 0xd0eae483	ufshcd_runtime_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x06034eb4	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x07b33070	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0x08f7350e	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0x0b085cad	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x1d89c061	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0x2410f1bc	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x24f30e14	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x2ae0f551	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0x5e3e7b40	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0x609fe147	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x6e152476	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x8449dca1	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x9045328d	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0x906d278e	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0xa5a9cb8c	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0xac451e0a	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xc7ef579f	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xd5e726ac	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0xe72e7c34	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xf8ae01a5	ssb_bus_powerup
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x01710daf	fbtft_framebuffer_alloc
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x1fb1c2a7	fbtft_framebuffer_release
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x26ea40fe	fbtft_write_vmem8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x3f2d4e49	fbtft_probe_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x425ab46c	fbtft_write_vmem16_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x43484792	fbtft_write_vmem16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x46445055	fbtft_dbg_hex
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x53ceb310	fbtft_register_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x5564c711	fbtft_register_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x59bba5de	fbtft_write_spi
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x5cb7538d	fbtft_write_gpio16_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x6be4fafb	fbtft_write_reg16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x7ce8f077	fbtft_write_gpio16_wr_latched
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0x90f1c1ec	fbtft_write_reg8_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa1a7a5ff	fbtft_unregister_backlight
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xa60cda17	fbtft_init_display
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xb127451a	fbtft_unregister_framebuffer
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xb593b324	fbtft_write_vmem16_bus16
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xc2f7bb10	fbtft_write_gpio8_wr
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xcafdaf2b	fbtft_write_reg8_bus9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xcc0cbdd7	fbtft_write_reg16_bus8
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xd0417ffe	fbtft_write_spi_emulate_9
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xe5e653e1	fbtft_remove_common
++EXPORT_SYMBOL drivers/staging/fbtft/fbtft 0xebe7b9e6	fbtft_read_spi
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x9c8a5c01	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xf64af9ca	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x779e21e6	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0x849ec501	hmc5843_common_remove
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xb3c50795	hmc5843_common_probe
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xd7a64d99	hmc5843_common_resume
++EXPORT_SYMBOL drivers/staging/iio/magnetometer/hmc5843_core 0xfee7de59	hmc5843_common_suspend
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x0d542a07	ade7854_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x5dad0fc4	ade7854_remove
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0x9653844d	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/most/aim-network/aim_network 0x575c00a7	most_deliver_netinfo
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x00bafad9	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x00bbdd45	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x034eae6f	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0b669b0a	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x136afc74	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x147f4ed4	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1519fca8	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x17322bf5	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x17d39d2d	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x19511ea4	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x19ff78b6	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x23190d4e	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x25094772	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3179faf6	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3255fe95	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3f68597e	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x40af2ad8	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4254ef78	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4765c8ab	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x48707a44	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x50bcc0f1	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5662b439	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x59872354	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x63bbba1f	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x66597aa8	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x67a7e46d	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9071f086	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x97bb12f5	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x981205b9	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x99988d40	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa632506e	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa651c033	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xabe0b1f5	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb3053f0e	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb457d09c	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb5d1bcbc	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb5db3d90	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc02613d8	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc36b76f9	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc3c32fa8	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcd3275b3	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd4d8b652	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdacbebe6	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdbc177b3	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdd1a4df4	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe4bfc66f	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe7c6ae26	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xef6796ab	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf2fdbc2f	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfd38b03b	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x06d6afb7	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0dffbce8	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0f099f61	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x14108a27	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x142aa3d2	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x17f7fdc8	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1a7d73ba	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1bdd417e	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1e829295	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2bc87b9a	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x33f26e17	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3464ce5e	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3f3dd35d	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x44263916	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4595f2ce	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x45f7d1c3	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4880a029	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4d4c026f	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4feaaa07	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5139bfc0	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x61ea895d	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x66d82e34	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6d81a7cb	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7457d72e	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x76650112	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x779893c0	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7e7dbfd1	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8369bef9	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8c6b2bba	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8ed7431c	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x91721dd0	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x966c6b6b	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x97ea2205	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9959c6d8	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9961bf03	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9b800d81	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9c7cb021	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb14680b2	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb22030d8	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb3b7a633	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb5318556	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb53b6832	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb91f9774	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb925be81	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbf129dea	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xda1b9228	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdfe4384b	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe0178e71	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe07936c9	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe0fc0ba2	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe41fcdb7	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe58c5280	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe78d653c	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe8669dac	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xef02a523	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x05bc9123	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x07807153	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x156b9d43	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x2328fdf7	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x2363c314	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x2e2a4fd5	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3526bbe9	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x50d0049d	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x556851f8	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5868be6f	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x59a4db8e	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5cfc8e1e	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x60c4c24b	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x63ddc79e	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6ca58f4f	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6d1d99dc	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x76dbebfe	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x84098665	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x877595d5	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8e451dd6	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb79eef17	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xbb476af6	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc964f7a0	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd613c460	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe15031b3	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf27a6cf5	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf3f15232	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf8261b7d	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/target_core_mod 0x018ce15f	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x137e267b	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2b16ef0f	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2c67bba1	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2d9d8d29	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2ea8696d	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3193d8db	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x35df0d2e	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x38fb0a1a	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3b79e306	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x445144d0	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0x45c8b3ce	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4ce2dd53	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4fcfdebf	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5886cfe7	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x58a0858b	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5f0fc254	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5fd05eaa	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x60a4598d	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x63bf44dc	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6807cdf9	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6b48b6a3	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x700a2da8	transport_init_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7465f7ce	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x74de11fa	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85fb8e6a	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0x87518926	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0x89b1fce7	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8d318b1f	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x91a05f98	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x95332112	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x971189d3	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9d765bd4	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9db735a3	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa5076ab0	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xaa7725f0	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0xaea1d487	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb0ee1ad0	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb73bff4a	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb9a5309e	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbf75dffd	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbfe63cfc	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc4504719	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc484268a	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc4afc5ed	target_nacl_find_deve
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc54012f6	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc6581831	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcc069cd6	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcd2118c9	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd0917c2c	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd2468b54	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd5fdd1fb	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd92564ab	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd957ec94	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdcf5bf96	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0xddb9929e	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdf0e59ee	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe0cc8528	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe150c6eb	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe1630149	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0xecf1be40	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0xed27f7fe	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf0e5e342	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf50c2ba1	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf69d8cad	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf6be29af	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf85bd68e	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfa00cde1	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfca7d9d0	transport_init_se_cmd
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0x765a279c	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/function/usb_f_uvc 0x92e9ebac	uvc_set_trace_param
++EXPORT_SYMBOL drivers/usb/gadget/libcomposite 0x3f57dc02	usb_os_desc_prepare_interf_dir
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0x0c9586c1	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x1868171e	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x403c9f0f	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x510e9c36	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x5a44cffb	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x5ce99d8a	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x6f703bf1	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x7c8928af	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xc2ef2067	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xd2c139f7	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xe2408df5	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xe826fd67	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xf6875dc6	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x4ea8f034	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x8a65866f	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3b304ebb	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3c71c418	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x4311cd91	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x5fedea44	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x97fa07e9	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xde804bb9	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x47bf2d81	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x69a87e5a	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x7f8fae33	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x95765d8c	lcd_device_register
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x02547481	svga_settile
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x37a55976	svga_tilecursor
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x595dcdac	svga_get_caps
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x606a6798	svga_tileblit
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xb90f1f70	svga_tilecopy
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xd78be60a	svga_tilefill
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/fbdev/core/svgalib 0xfd3d51b0	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/fbdev/core/syscopyarea 0x06da84cf	sys_copyarea
++EXPORT_SYMBOL drivers/video/fbdev/core/sysfillrect 0x7d0ceb55	sys_fillrect
++EXPORT_SYMBOL drivers/video/fbdev/core/sysimgblt 0xe96da348	sys_imageblit
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/fbdev/cyber2000fb 0xbf29a43d	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x1bd03d2f	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0x5d62f966	g450_mnp2f
++EXPORT_SYMBOL drivers/video/fbdev/matrox/g450_pll 0xcbf4bb70	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x1040fa43	matrox_mystique
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x40bcf98a	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x66bd9c32	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_DAC1064 0x817bb0e4	matrox_G100
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_Ti3026 0xd5e039c5	matrox_millennium
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_accel 0xc6e2a131	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x277070a5	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x41c52b59	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0x89082804	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_base 0xfed47b4b	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0x7ed848d9	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_g450 0xe36200a0	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x1ac5a71b	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x563c50d1	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x94231309	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0x95b8b034	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xa0d115bf	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/fbdev/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/fbdev/mb862xx/mb862xxfb 0x763efb2e	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/fbdev/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x2b2e69b8	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x6dcb5f81	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xf127520f	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xfb399b1c	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x3b47dc11	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x42326e31	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x9ee357f3	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0xaeb13850	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/wire 0x2891a5b2	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x5f133142	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x670133a9	w1_register_family
++EXPORT_SYMBOL drivers/w1/wire 0x93ef766c	w1_unregister_family
++EXPORT_SYMBOL fs/configfs/configfs 0x0affce88	configfs_register_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0x2ad67713	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x60275af8	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x612cb169	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x618785e7	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x6b0e183f	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x817c60e1	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0x9712d5d7	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0xad67985f	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0xb7c0fe74	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0xb85995db	configfs_unregister_group
++EXPORT_SYMBOL fs/configfs/configfs 0xc5cf9709	configfs_unregister_default_group
++EXPORT_SYMBOL fs/configfs/configfs 0xdd9b29e7	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0xe4bf2567	configfs_register_group
++EXPORT_SYMBOL fs/configfs/configfs 0xf9fc0931	config_item_set_name
++EXPORT_SYMBOL fs/exofs/libore 0x1f07d427	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x54227a80	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x6dada6a6	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0x74159f18	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0x7b308cbd	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x82d9d0bc	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0x8df9e73a	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0x9f9b4663	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xb64ed1d2	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0xe8633081	extract_attr_from_ios
++EXPORT_SYMBOL fs/fscache/fscache 0x006d6bd5	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x01035aa3	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x04f24f68	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x0d391365	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0x151df93e	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0x184bb41a	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x29188f22	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0x2cf5b341	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x334bd071	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x339704cf	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0x4af74e33	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x4dbce31f	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0x4ec6bde3	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0x57cfe893	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x5da8eff6	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x6d06ecf6	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x72453d95	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x798895f1	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x7ba6f778	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x7d914854	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x7fbe5e3c	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x8246541b	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0x82c22818	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0x8389894e	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x87f00265	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x8a4fa4f9	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0xa4562ca0	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0xa7cbfa26	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0xacddfcaf	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0xbad8b19f	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0xcbe3a494	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0xd5c613bb	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xd833ee7e	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0xdb146d7e	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xdce91de6	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0xe16c3f52	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xe973a32e	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xee75ed90	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xf0764445	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0xff612d9f	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x70fb913b	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x9829771a	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0xb104a9ab	qtree_write_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xcb1556f0	qtree_read_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xf690bc08	qtree_delete_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x1a703ba1	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0x6d356209	crc_itu_t
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc7 0x56329ecc	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd09b2cba	crc8
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x0641307b	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0x098d2ed9	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x2d47ac83	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0x2f3dcecb	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0x30b56256	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x4522d82a	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0x4812f064	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x4cf5f5a8	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0x5752f31b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0x7257beee	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0x9134feb7	lc_get
++EXPORT_SYMBOL lib/lru_cache 0xb672aa97	lc_create
++EXPORT_SYMBOL lib/lru_cache 0xbfbe53d5	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0xc3a98c1d	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0xcc979a91	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xefec290a	lc_find
++EXPORT_SYMBOL lib/lru_cache 0xfd525ec7	lc_put
++EXPORT_SYMBOL lib/lz4/lz4_compress 0x0c222eb5	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x682a23e0	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xefc78e77	raid6_empty_zero_page
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x1bd161c9	lowpan_netdev_setup
++EXPORT_SYMBOL net/6lowpan/6lowpan 0x51d05d77	lowpan_nhc_add
++EXPORT_SYMBOL net/6lowpan/6lowpan 0xcf3a8b2b	lowpan_nhc_del
++EXPORT_SYMBOL net/802/p8022 0x723ef5d6	register_8022_client
++EXPORT_SYMBOL net/802/p8022 0xfd05174f	unregister_8022_client
++EXPORT_SYMBOL net/802/p8023 0x13f0992b	make_8023_client
++EXPORT_SYMBOL net/802/p8023 0x6a0dcc2e	destroy_8023_client
++EXPORT_SYMBOL net/802/psnap 0x8928e27e	register_snap_client
++EXPORT_SYMBOL net/802/psnap 0xa3f48f24	unregister_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x0307966d	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0x046c2437	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0x0eafffd5	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x1dad0543	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x33c62190	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x35fa8e92	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x3aeaa2d6	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x3e6c4022	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0x4343d1f5	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0x448c94dc	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x45aeffb7	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x53d58a07	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x56e22e9a	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x5968bf98	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x5a744033	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x6698dc46	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0x6a4c4db3	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x6c40d83b	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0x75f14aa1	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x76b11809	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0x77a1c31a	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0x82f0e99c	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x87f73ff5	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x881b075b	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0x9570aeed	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0x95a0a8c4	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x9b87f358	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0x9c41c426	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x9e84b535	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0xa2cbfc53	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xa3775699	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0xb6bd12a0	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0xba0286ba	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0xc08c6450	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0xc304136e	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xc9938dbe	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0xd026e243	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0xde6f3918	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0xe10e0a99	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xe5b4e09c	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0xeaebd617	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xf9282cfc	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x13be53f0	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0x358ca021	aarp_send_ddp
++EXPORT_SYMBOL net/appletalk/appletalk 0x82f53f01	atrtr_get_dev
++EXPORT_SYMBOL net/appletalk/appletalk 0xa7c07320	alloc_ltalkdev
++EXPORT_SYMBOL net/atm/atm 0x036d572e	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0x1c862f22	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x2bf920fe	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x43210d74	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x539b3486	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x908b8b5e	atm_charge
++EXPORT_SYMBOL net/atm/atm 0x918194e6	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x93ce0645	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x99faeddf	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xa0172a39	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0xa6c66da0	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xbd50226f	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0xc1b7a2b8	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0xca87b453	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/ax25/ax25 0x0eb842de	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x34456502	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0x3afee63e	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x3d0c0743	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x6cc5d5ea	ax25_ip_xmit
++EXPORT_SYMBOL net/ax25/ax25 0x6df03f8f	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0xa7f3015b	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0xaab8ec86	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0xb03def75	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xe21e41e9	ax25_listen_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0a864511	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x17ebf6f8	hci_recv_diag
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x17fc7ba8	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x21db0355	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x25f9befd	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2b1edff4	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x302ec8d3	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3ef3551b	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3ff58e89	hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x408616ed	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x45160265	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x47022514	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4cdb1275	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4e947e82	hci_mgmt_chan_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x58932cce	hci_reset_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x67c38bb1	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6ebe2317	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x70f6ada6	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7a056b51	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7a9b28e8	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x84b4acaf	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8e5aa26b	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x92337f56	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9456905f	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x989ad480	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa55f11a5	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb0539dd6	bt_err_ratelimited
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb31338ae	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb7d7798e	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbb3e21f7	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbf8dd955	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc5f3089c	bt_sock_wait_ready
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xca7f0400	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc466e5f	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcd40051c	hci_mgmt_chan_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd03b9851	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd2700658	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd3e28680	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd7442057	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xeeaef9ce	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf0191f49	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf112da85	bt_warn
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf71d0a16	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xfcdca118	l2cap_chan_close
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xff72c586	l2cap_conn_get
++EXPORT_SYMBOL net/bridge/bridge 0x03eeb6d4	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x7829a989	ebt_do_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x88c2987d	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x9ec72069	ebt_register_table
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x37c7f1c8	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x3884ca5e	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x82eee760	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xa1afabc0	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xe6671257	get_cfcnfg
++EXPORT_SYMBOL net/can/can 0x151c0efc	can_rx_register
++EXPORT_SYMBOL net/can/can 0x38799204	can_ioctl
++EXPORT_SYMBOL net/can/can 0x68c5f85a	can_proto_register
++EXPORT_SYMBOL net/can/can 0x76cfce9f	can_proto_unregister
++EXPORT_SYMBOL net/can/can 0x8162eb78	can_send
++EXPORT_SYMBOL net/can/can 0xb54f86d4	can_rx_unregister
++EXPORT_SYMBOL net/ceph/libceph 0x08bb2319	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0a2263f3	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x0c5307c1	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0x0df2e934	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0x0e00c0ba	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x0f0aab6c	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0x0f2f5907	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0x146ff945	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0x1c7875f8	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0x1db8368a	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x1dfce853	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0x1e13a0dc	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0x2033daab	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x21c60751	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x24d897df	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x28d9d84d	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x2b07e77f	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x34225bab	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0x34af8968	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3af06591	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x3b75c6b7	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0x3b9387f5	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x419cb09b	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x475fe8cf	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0x48603697	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0x48daa2ca	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x49a8336d	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x4ad772ec	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0x4f6f68e5	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0x4fd8adf8	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0x5056085a	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x55751755	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x5b48ccaf	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0x61071785	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0x6254ca5d	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x69e06a1d	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6e722c6a	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x6e83bc20	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0x6fcdafef	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0x703bc5b3	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0x809c108c	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x82f83975	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x87dbd531	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x8db14464	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x8fcc58b5	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0x90aa03ff	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x943988c6	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0x98ff150d	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa23a52c9	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xa4e05958	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0xa4ef26ad	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xa6251879	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xaa11ffc4	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xadbaf7e3	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb1590630	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0xb45989d8	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0xb4a3f002	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xba17e23f	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xc119e657	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc56c55eb	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0xc5a7a797	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xc611e2a0	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xca011496	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xcfb7cc61	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0xcfe8eab4	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xd2a8e218	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd2e1a22b	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0xd7acd83f	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0xdbfa3b1c	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0xddb869f3	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xdeb22bd6	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xe162dbc8	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0xe21e4fbc	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xe3b042ca	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0xe8ea3f6a	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xeabbc8a3	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0xec37100a	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xeca7fcb3	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0xee3c34b4	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0xf0b34391	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0xf164bd38	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xf35cb4d9	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xf4659ee6	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0xf5283719	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0xf5fc7227	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0xf91d066b	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0xfea4fd7c	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0xffaeb923	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x35d84632	dccp_req_err
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x97fd947b	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x0bcdc9b2	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x1dca4543	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x2af59347	wpan_phy_new
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x616193af	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xc729f8ca	wpan_phy_find
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xfe7b2ed6	wpan_phy_for_each
++EXPORT_SYMBOL net/ipv4/fou 0x0738eb38	gue_build_header
++EXPORT_SYMBOL net/ipv4/fou 0x3106aeb4	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0xa3114cda	fou_build_header
++EXPORT_SYMBOL net/ipv4/fou 0xd0750778	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x05c2a1bf	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x1d99f02d	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x473cab47	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x9e499a14	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xc4ea2886	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xd4fbce4d	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x23f87f0c	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x2ebe8995	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xc925c466	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x13f9fdbf	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xd20258c1	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xf3e114b4	ipt_do_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x2ae461c6	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/tunnel4 0x6a064d24	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0x0246f6ca	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x5e2152d2	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x9bb10c18	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xaf3dff42	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xff68c90f	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x24668ff0	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x428650f6	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xe1aa32cb	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x85b26a38	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0xc6e3e650	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x358e4a1a	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x47077d81	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x04e56471	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x3e5baf4e	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x8972caf8	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xb5ea2230	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xc35ab695	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xca8e54bd	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xf101ce65	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xf521626d	ircomm_open
++EXPORT_SYMBOL net/irda/irda 0x0064e0ea	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x0a238f0b	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0x0c8b0a87	irlap_close
++EXPORT_SYMBOL net/irda/irda 0x0f610477	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x1e6cade0	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x207bcdde	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x2fe88569	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x35959f2a	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x38051d0b	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0x3e56064f	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0x42035268	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x4faa45d5	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x56c2ea1b	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x5c6196b0	iriap_open
++EXPORT_SYMBOL net/irda/irda 0x5ca6679e	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0x601bda46	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0x6133b4b1	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6b5fbcef	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x6e0ab3c7	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7f52a8bf	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x81160028	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0x85d88217	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x94a824db	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0xa1d41e58	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0xa91e5119	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0xaa557515	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0xafec079f	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xc68e43be	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0xcc0bda30	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0xcead7dbb	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xd2108314	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0xd68db1db	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0xd6deeaae	irda_setup_dma
++EXPORT_SYMBOL net/irda/irda 0xdc10d10d	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe3199fd3	iriap_close
++EXPORT_SYMBOL net/irda/irda 0xe3463529	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0xe3bde43e	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0xebc6d0ff	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xeecaa7ff	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xef069c2e	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0xf0a694a1	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0xf5876b95	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0xf9996863	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0xfda362be	irlap_open
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x9cdfdd38	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0xcfaca916	l2tp_ioctl
++EXPORT_SYMBOL net/lapb/lapb 0x2add4932	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0x35347da9	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0x4a8c426e	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0x77f465fa	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0x88e5b0b9	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0xc158d626	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0xd83d26b7	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0xff791c2e	lapb_connect_request
++EXPORT_SYMBOL net/llc/llc 0x27ebc086	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x65b8064a	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0x93b0685d	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0xa95da2c7	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0xb2c74d2b	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0xc4ae3238	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0xe6aa3d3d	llc_sap_close
++EXPORT_SYMBOL net/mac80211/mac80211 0x066083b8	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x078766da	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0x093bf376	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x0bd609f2	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x0f5e1034	ieee80211_tx_dequeue
++EXPORT_SYMBOL net/mac80211/mac80211 0x11640eaf	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x118a2f3d	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x136bc57d	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x179bf1d1	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x18ad9c4c	ieee80211_beacon_get_template
++EXPORT_SYMBOL net/mac80211/mac80211 0x1e16776e	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x1fb5d9af	ieee80211_unreserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0x2582296b	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x2a5438dd	ieee80211_tdls_oper_request
++EXPORT_SYMBOL net/mac80211/mac80211 0x2a98e7fc	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x2b96fa86	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x2cf9e0ea	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0x2d506025	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0x2fcc0979	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x324e0b62	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0x32b6f182	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x38d2927a	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x41678057	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x419c0202	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x42212106	ieee80211_alloc_hw_nm
++EXPORT_SYMBOL net/mac80211/mac80211 0x4a5a876f	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0x4c2b011a	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0x4d560e43	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0x4e8dea1e	ieee80211_stop_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x503025f9	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x50ff6eec	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x55f97e4f	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0x569b5e78	ieee80211_start_rx_ba_session_offl
++EXPORT_SYMBOL net/mac80211/mac80211 0x578101db	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0x5806d431	ieee80211_csa_update_counter
++EXPORT_SYMBOL net/mac80211/mac80211 0x5ce8f98e	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x5dc4d558	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x5e8d6898	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0x734d3ef8	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x760b21c6	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0x77ea65c4	ieee80211_update_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0x8213be74	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x826e67af	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0x88b39006	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x8f248aec	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x93c3277f	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x945c41e3	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x95af28f0	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0x9d868723	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x9e1b7cb5	ieee80211_csa_finish
++EXPORT_SYMBOL net/mac80211/mac80211 0x9e909759	ieee80211_tx_prepare_skb
++EXPORT_SYMBOL net/mac80211/mac80211 0x9efe2cbb	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0xa0341e0a	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xa470b72d	ieee80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0xa5bf92ad	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0xaec37457	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xb342f184	ieee80211_rx_napi
++EXPORT_SYMBOL net/mac80211/mac80211 0xbc4abc74	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0xc00a2cd8	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xc02974df	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xc16838e5	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0xc4b4b0c2	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0xc76939e2	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xcbb3406c	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xcc3cd07a	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0xcd193039	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0xcd706fab	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xcf5c322a	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xcf8fd5d4	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0xd2c504ad	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xd4f160a6	ieee80211_csa_is_complete
++EXPORT_SYMBOL net/mac80211/mac80211 0xd72625cb	ieee80211_parse_p2p_noa
++EXPORT_SYMBOL net/mac80211/mac80211 0xd90d86a0	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xde7d2204	ieee80211_tx_status_noskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xdea8789a	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xe047c0bc	ieee80211_reserve_tid
++EXPORT_SYMBOL net/mac80211/mac80211 0xe0bf359c	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xe5199caf	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xe581f93c	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xecd06540	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xed8955c1	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xef65f0ae	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0xeff2c60a	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xfaea3265	ieee80211_register_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x11a01114	ieee802154_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x4aff0ba3	ieee802154_alloc_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0x7d5d54d0	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0x8af61ec6	ieee802154_unregister_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xbbf5c0c0	ieee802154_free_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xde12552b	ieee802154_xmit_complete
++EXPORT_SYMBOL net/mac802154/mac802154 0xe2f158a1	ieee802154_register_hw
++EXPORT_SYMBOL net/mac802154/mac802154 0xfe1e8360	ieee802154_wake_queue
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x1fe43439	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x2cf8f7b9	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x3fdd3acb	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x4fc257a1	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x637a9fce	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x7fbca0f6	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x848e26f1	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x8a6a38f0	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x9782651d	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xa404393e	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xea0d42ed	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xeeb51b3f	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xef21a7fc	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xf4eceaab	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x612293e1	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x89605d6e	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xcbfb40c3	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x4da5c43c	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x97c454f9	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0x991d81c0	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xac2291c5	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0xbab8c773	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0xbddf33c2	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/x_tables 0x20178b3c	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x253e8b44	xt_compat_init_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x621549e7	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x77b6b7db	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x82457150	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x91ae512a	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xa25fc115	xt_compat_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xb3a9e964	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xc02b7256	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0xc816b820	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xf96786c5	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xfb2791f9	xt_unregister_match
++EXPORT_SYMBOL net/nfc/hci/hci 0x010d5acc	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x0b837f92	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0x0cb32982	nfc_hci_reset_pipes
++EXPORT_SYMBOL net/nfc/hci/hci 0x130bd4d9	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x254d8515	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0x2efb0177	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x4466bbf9	nfc_hci_reset_pipes_per_host
++EXPORT_SYMBOL net/nfc/hci/hci 0x482f93f2	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x4bb7a2d3	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x6043002a	nfc_llc_start
++EXPORT_SYMBOL net/nfc/hci/hci 0x646b3dc7	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x97256487	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0xab96222f	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xb17c4dd3	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xb2289674	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xbd23c05d	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0xc7f516c5	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0xc87588bd	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xdb1c3bee	nfc_llc_stop
++EXPORT_SYMBOL net/nfc/hci/hci 0xdd5ef669	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0xe629183c	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x0532c002	nci_core_init
++EXPORT_SYMBOL net/nfc/nci/nci 0x05f6936e	nci_conn_max_data_pkt_payload_size
++EXPORT_SYMBOL net/nfc/nci/nci 0x1bf5863d	nci_send_data
++EXPORT_SYMBOL net/nfc/nci/nci 0x1c63c8f7	nci_core_conn_close
++EXPORT_SYMBOL net/nfc/nci/nci 0x1ec59a1f	nci_hci_set_param
++EXPORT_SYMBOL net/nfc/nci/nci 0x236ff7f5	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x2435bf0e	nci_hci_open_pipe
++EXPORT_SYMBOL net/nfc/nci/nci 0x253e10f7	nci_set_config
++EXPORT_SYMBOL net/nfc/nci/nci 0x29fe00f3	nci_req_complete
++EXPORT_SYMBOL net/nfc/nci/nci 0x3e725e45	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x50ec3166	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x5f072720	nci_hci_connect_gate
++EXPORT_SYMBOL net/nfc/nci/nci 0x6157273a	nci_core_reset
++EXPORT_SYMBOL net/nfc/nci/nci 0x80f2bd86	nci_nfcee_mode_set
++EXPORT_SYMBOL net/nfc/nci/nci 0x8c0af8ce	nci_hci_clear_all_pipes
++EXPORT_SYMBOL net/nfc/nci/nci 0x913cd8fd	nci_send_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0x942322a2	nci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0x97661f50	nci_core_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xab8ed542	nci_hci_get_param
++EXPORT_SYMBOL net/nfc/nci/nci 0xaecc03c3	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xaed21d5f	nci_nfcee_discover
++EXPORT_SYMBOL net/nfc/nci/nci 0xb12ebbba	nci_core_conn_create
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xbdec691c	nci_get_conn_info_by_id
++EXPORT_SYMBOL net/nfc/nci/nci 0xcd12ed86	nci_prop_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xd340a008	nci_hci_dev_session_init
++EXPORT_SYMBOL net/nfc/nci/nci 0xdaf07e98	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xefb59047	nci_hci_send_cmd
++EXPORT_SYMBOL net/nfc/nci/nci 0xf9dae43f	nci_hci_send_event
++EXPORT_SYMBOL net/nfc/nfc 0x05661049	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0x084c73ac	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x08956770	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0x0c9c7b63	nfc_send_to_raw_sock
++EXPORT_SYMBOL net/nfc/nfc 0x16f5904c	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x35197ac4	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0x3e6c934b	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0x415f32f2	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0x4394b22b	__nfc_alloc_vendor_cmd_reply_skb
++EXPORT_SYMBOL net/nfc/nfc 0x51d92170	nfc_find_se
++EXPORT_SYMBOL net/nfc/nfc 0x596dc51f	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0x5fc62891	nfc_vendor_cmd_reply
++EXPORT_SYMBOL net/nfc/nfc 0x724d0b98	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x898a7058	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0x92ca858d	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0xad7cffb2	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0xade52665	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0xadec5ff3	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0xb0afe619	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0xb9f0bc38	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0xc1044735	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0xda4c1cea	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0xe7329bd0	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0xff5e0018	nfc_se_transaction
++EXPORT_SYMBOL net/nfc/nfc_digital 0x35f7e269	nfc_digital_allocate_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x423a8011	nfc_digital_free_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0x5591352c	nfc_digital_register_device
++EXPORT_SYMBOL net/nfc/nfc_digital 0xdf23e16e	nfc_digital_unregister_device
++EXPORT_SYMBOL net/phonet/phonet 0x0b81aec4	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0x3417393b	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0x43661454	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0x556af044	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0xab3db0e5	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0xd665ba25	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0xe6f9d65d	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0xfc81c77a	phonet_stream_ops
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x0673aa8d	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x081daa9c	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x168591e7	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x392cd77c	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x3cfb61a1	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x4d0c249f	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x5ac27b86	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x7650ce12	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x80ffd018	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8ea75d31	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x90c4264b	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xaba59bb6	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb5c33f99	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb69af903	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xbce391c3	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/sctp/sctp 0x01f887f2	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x05945a51	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x599cfe55	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x9996bc31	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x0380a6e4	svc_pool_stats_open
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x4d3dbb39	xdr_truncate_encode
++EXPORT_SYMBOL net/sunrpc/sunrpc 0xc86d3c5a	xdr_restrict_buflen
++EXPORT_SYMBOL net/wimax/wimax 0xb9ec2e5e	wimax_reset
++EXPORT_SYMBOL net/wimax/wimax 0xcd527c29	wimax_rfkill
++EXPORT_SYMBOL net/wireless/cfg80211 0x05955c7a	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0x06c8477a	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x08f6ce19	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x100d237c	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x198ebb40	__cfg80211_send_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x1be8334a	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0x1cb94542	wiphy_new_nm
++EXPORT_SYMBOL net/wireless/cfg80211 0x1d2aa8a8	cfg80211_sched_scan_stopped_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0x1eabc1f0	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0x266b19fe	cfg80211_inform_bss_frame_data
++EXPORT_SYMBOL net/wireless/cfg80211 0x26a3dda2	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x28705d9e	regulatory_set_wiphy_regd
++EXPORT_SYMBOL net/wireless/cfg80211 0x29d4b862	cfg80211_del_sta_sinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0x2fdbe587	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x302e18e8	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x318d449b	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x33987020	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x3433b86e	__cfg80211_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x38db5a6f	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0x39d6e159	cfg80211_abandon_assoc
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d470c4d	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0x3d5a71a4	cfg80211_chandef_dfs_required
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e285fec	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x3e61fc5f	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0x3f449b5a	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0x43faae34	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x47671310	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x4928d07b	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x495457ff	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0x4b39be6d	cfg80211_inform_bss_data
++EXPORT_SYMBOL net/wireless/cfg80211 0x4e944475	cfg80211_get_station
++EXPORT_SYMBOL net/wireless/cfg80211 0x50214c28	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x51a5c680	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x6e4c7da1	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0x74238252	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0x7770ef52	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x7815f20e	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x78bfd028	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x79c187d5	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0x7a3d7fd8	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x7a57e3cc	ieee80211_get_num_supported_channels
++EXPORT_SYMBOL net/wireless/cfg80211 0x7b91e574	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0x7cd5b97e	cfg80211_stop_iface
++EXPORT_SYMBOL net/wireless/cfg80211 0x7d75162f	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fcc03b0	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x830d1dad	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x838a3346	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x8492a430	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x86a9dc4a	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x88d7c343	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x89efa281	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x8a7062a5	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0x8bbc3e2e	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x9010129b	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x91d7a142	ieee80211_ie_split_ric
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x9993ba61	cfg80211_iter_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0x9c2a03e8	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x9cf6a240	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0x9ea45c02	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa47c870b	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xa547aab4	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xa63baf7e	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xa793b1fc	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xb0a2c454	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xb1c24a9c	cfg80211_reg_can_beacon_relax
++EXPORT_SYMBOL net/wireless/cfg80211 0xb2a72513	regulatory_set_wiphy_regd_sync_rtnl
++EXPORT_SYMBOL net/wireless/cfg80211 0xb3ef5783	cfg80211_check_combinations
++EXPORT_SYMBOL net/wireless/cfg80211 0xb424a3a8	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xb4e6cd4f	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0xb80e4192	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xba750204	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xba99b476	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0xbba65334	__cfg80211_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xbd288a78	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0xc2bf5004	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc75c3e9e	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xc90fde22	ieee80211_chandef_to_operating_class
++EXPORT_SYMBOL net/wireless/cfg80211 0xce4b4bd0	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0xd2c21939	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0xd3320934	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0xd50b0a22	ieee80211_ie_split
++EXPORT_SYMBOL net/wireless/cfg80211 0xd932c6fe	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xdba126c1	reg_initiator_name
++EXPORT_SYMBOL net/wireless/cfg80211 0xe1e16265	cfg80211_get_drvinfo
++EXPORT_SYMBOL net/wireless/cfg80211 0xe4cd07c0	cfg80211_ch_switch_started_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe5c68a6c	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0xe5ff4c48	cfg80211_cqm_beacon_loss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe93675ee	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0xecb610af	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0xefc56354	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xefd8e61e	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xf5e588d2	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0xf946d2fd	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/lib80211 0x3bd63405	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0x5045adaf	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0x66de539a	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x99cc8e79	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xe7bb8685	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xf4865663	lib80211_crypt_info_free
++EXPORT_SYMBOL sound/ac97_bus 0x89b6acf3	ac97_bus_type
++EXPORT_SYMBOL sound/core/oss/snd-mixer-oss 0xa7000415	snd_mixer_oss_ioctl_card
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x23c6f7a9	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x4ad428be	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb805e128	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe39a5e4b	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x091def1c	snd_seq_autoload_exit
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x370a0736	snd_seq_autoload_init
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xe4194b7d	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x072d978b	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x13a17752	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x2eed26bf	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x4d5ca523	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x592f6e9b	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xd7c7afcc	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xe60fb228	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xecbde43c	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0x8e4563df	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x0388a368	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0x09b8f6bc	snd_jack_new
++EXPORT_SYMBOL sound/core/snd 0x0c11ca6c	snd_card_new
++EXPORT_SYMBOL sound/core/snd 0x0f3d9a08	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0x0fb5fd8d	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0x14344c08	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0x18e1683f	snd_dma_program
++EXPORT_SYMBOL sound/core/snd 0x191e88cf	snd_dma_pointer
++EXPORT_SYMBOL sound/core/snd 0x198788b4	snd_lookup_oss_minor_data
++EXPORT_SYMBOL sound/core/snd 0x1fbb2cd6	snd_unregister_oss_device
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x2810263f	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0x2ad3776e	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0x2de0ab18	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0x2f0d12e5	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0x342a2354	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x37c7a698	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0x388f670f	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0x389b837d	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x3cba77e7	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0x43c578dc	snd_register_device
++EXPORT_SYMBOL sound/core/snd 0x450ff970	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0x48cbb575	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x4f24aa94	snd_device_new
++EXPORT_SYMBOL sound/core/snd 0x525b4370	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0x5fed454d	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0x60f16a9e	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0x617fce38	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0x70c15ac1	snd_dma_disable
++EXPORT_SYMBOL sound/core/snd 0x72620266	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0x7d286c09	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0x7e6bfcfe	snd_cards
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x86cb7c56	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0x8df3789f	snd_oss_info_register
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x939883a1	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xa348f217	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0xa7506251	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0xad025167	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0xad2b21da	snd_register_oss_device
++EXPORT_SYMBOL sound/core/snd 0xad747974	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0xadf54cc3	snd_ctl_unregister_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0xb1cfdb21	snd_jack_add_new_kctl
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xbca28f69	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0xc1d178d4	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0xd2a4098b	snd_ctl_register_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0xd6be2aa2	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd 0xdca7c4a7	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0xe9a5350d	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0xee097715	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0xeec215d3	snd_mixer_oss_notify_callback
++EXPORT_SYMBOL sound/core/snd 0xef138e6d	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0xef1eac44	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0xf1bdddd4	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0xf84f5ac8	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0xfb50888f	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd 0xfffd89db	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd-hwdep 0xd189c9d0	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x06b310c9	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x0a8f4694	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0x11f46c18	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x15a1d549	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-pcm 0x18676dd3	snd_pcm_hw_constraint_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x1c779216	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x253182ba	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0x2ceb7df7	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0x302da660	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0x34e8421a	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x3aaf9068	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x490a79f6	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x503bd137	snd_interval_ranges
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x573a6a09	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x574162f1	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0x5898dcba	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x6534e6e9	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x68af40f3	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x7a50baef	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0x7f465b6d	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x82c1eec7	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0x834dc955	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x845cb5ce	snd_pcm_lib_mmap_iomem
++EXPORT_SYMBOL sound/core/snd-pcm 0x863ce2cd	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0x871f39de	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0x87633df8	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0x88066ae8	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0x8c2a3e11	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x8d7444d2	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x97ce56af	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0x9c5fef0d	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0x9ede5b31	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0x9f4a5e9a	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xa53fbf4e	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xac437f7b	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xada713d8	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-pcm 0xb0331b5d	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0xb3ab4da5	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0xb5424dfe	snd_pcm_hw_constraint_mask64
++EXPORT_SYMBOL sound/core/snd-pcm 0xb85b1ad1	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xbaa7b719	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0xbc492b0d	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0xbe4d13ea	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0xc11238b3	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0xc9d3ab38	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0xd0b317b9	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0xde0a65d4	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0xde28c01e	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0xe3a456de	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xf5842a9f	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0xf9d3dda7	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0xfb84fce2	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x01126e49	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x014d476a	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x10a29be0	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x20bae4fc	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x2fbbb688	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x3de258f2	__snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x42e7ef33	__snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x447385dd	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x61543a2c	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x6932da94	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x71feaa22	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x74ed2e66	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7fb6af48	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x835ffc89	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x90070771	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x97380df4	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xa2e76da5	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xbc1a6618	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xef87dd62	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-timer 0x049c8867	snd_timer_close
++EXPORT_SYMBOL sound/core/snd-timer 0x0c4ac899	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0x1ea29764	snd_timer_open
++EXPORT_SYMBOL sound/core/snd-timer 0x25cc86e8	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0x27d76a38	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0x5e3acdbc	snd_timer_new
++EXPORT_SYMBOL sound/core/snd-timer 0x656388f8	snd_timer_start
++EXPORT_SYMBOL sound/core/snd-timer 0x7a1eca78	snd_timer_interrupt
++EXPORT_SYMBOL sound/core/snd-timer 0xa8f9c8a9	snd_timer_global_register
++EXPORT_SYMBOL sound/core/snd-timer 0xb8943274	snd_timer_resolution
++EXPORT_SYMBOL sound/core/snd-timer 0xdb6a827f	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0xf35c1e82	snd_timer_pause
++EXPORT_SYMBOL sound/core/snd-timer 0xfabe3b92	snd_timer_stop
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xba3d0546	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x0fedbcea	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x262ec1b5	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x55178bb5	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x88c68ae4	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xc186e857	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xc9f99438	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xcb09e3af	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xd75faa26	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xdeda9ce3	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x226138b0	snd_vx_threaded_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x39ab4e2e	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x42f3d4e5	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x53bfa14f	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x66ee0594	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x72d45c8f	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x9067a850	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xc38fdcea	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xec09230f	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf912cb41	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x03b2cab7	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x180ae917	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x20254e45	amdtp_syt_intervals
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x2201d897	amdtp_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x225483e2	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x2f9d465c	amdtp_stream_set_parameters
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3fff690e	amdtp_stream_add_pcm_hw_constraints
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x47291775	amdtp_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x49d9e5a8	amdtp_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x513c0f39	amdtp_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x520ed289	avc_general_set_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x53ca18e8	amdtp_rate_table
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5573e3c2	snd_fw_async_midi_port_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5977ef5f	amdtp_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x6e391828	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x727c5246	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7aaac69f	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x7c34073a	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x86b01631	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8d1c3d8d	avc_general_get_plug_info
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x90ad54a7	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x99328b08	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa4a40e02	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa59269e0	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa8a647f8	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xaabda014	avc_general_get_sig_fmt
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xab3b1306	amdtp_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xbb063845	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xbe8da4d3	snd_fw_async_midi_port_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc132f7bd	cmp_connection_check_used
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe34d9a30	amdtp_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe35cc514	amdtp_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf2a99bbe	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf5ff6e0a	amdtp_stream_pcm_abort
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0x7fd1a45f	snd_ak4113_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4113 0xa2d9cfbf	snd_ak4113_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x1506387b	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x1c4c126e	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x2401cda2	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x3d9e234b	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x52e75b2d	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x7e996a5f	snd_ak4114_suspend
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x89899653	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xb609f8e5	snd_ak4114_resume
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x05e12f60	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x4a4496c1	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x63908106	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xc66e0616	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0xca4d5941	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0xd06befbf	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x067055de	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x6bc57239	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x9b00d4ea	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x9c83d0a0	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xf472b441	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xfaa7ec70	snd_cs8427_init
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x0eeb0633	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x66c61adc	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x7699d7f1	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x818b6772	snd_i2c_device_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xa380b242	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xb45d931a	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x151c58ed	snd_sbdsp_reset
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x1c528150	snd_sbmixer_resume
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x2144ec47	snd_sbdsp_command
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x40a29e22	snd_sbdsp_get_byte
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x4918139c	snd_sbmixer_suspend
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x668b1c41	snd_sbmixer_write
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x9d255678	snd_sbmixer_add_ctl
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xa71499bc	snd_sbdsp_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xc506ea9c	snd_sbmixer_read
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xfe4745cd	snd_sbmixer_new
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x18b1aa73	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x1c3deff9	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x374dc298	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x37908d2e	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x44a0be3d	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x473a3c32	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x4b37f7dc	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x80cfa12a	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x83d7e115	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x9059736d	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xa40652dd	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb8b02fd5	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xbc023be3	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xbef7c094	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xd9bc2c47	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xe0040234	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xfed334ad	snd_ac97_update
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x17d6f2e4	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x2f0baba9	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x376ecb25	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x4cde7a59	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x52245052	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x788b6b0b	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x869e53f7	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x8b398070	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xf80181a2	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x2b51e128	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x571f30e1	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xdcb3ffc0	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x069f554f	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0f018532	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x1d8bf30c	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x21659ba2	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x27fbe455	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x2905e184	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x2dee8473	oxygen_update_dac_routing
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x3d3fee12	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x66126605	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x66df45fa	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x8de214c9	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x91d61535	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x98216319	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x9bd0643e	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa1ac9885	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb5c9a57c	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xbba8466f	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xccbf1da6	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xd74c6528	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf1aa96ad	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xfd2e7c65	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x165735dc	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x6d8f9166	snd_trident_free_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xa042b517	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xe675dd78	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xf9fb87e0	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x2956ee0f	tlv320aic23_regmap
++EXPORT_SYMBOL sound/soc/codecs/snd-soc-tlv320aic23 0x4aa24119	tlv320aic23_probe
++EXPORT_SYMBOL sound/soc/snd-soc-core 0xc9c1ce8b	snd_soc_alloc_ac97_codec
++EXPORT_SYMBOL sound/soundcore 0x260a38f7	sound_class
++EXPORT_SYMBOL sound/soundcore 0x4b249757	register_sound_special_device
++EXPORT_SYMBOL sound/soundcore 0x4f1ef67b	register_sound_special
++EXPORT_SYMBOL sound/soundcore 0x597f5d35	register_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0x7afc9d8a	unregister_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0x99c95fa5	unregister_sound_special
++EXPORT_SYMBOL sound/soundcore 0x9c7d3a12	register_sound_mixer
++EXPORT_SYMBOL sound/soundcore 0xc97eef8a	register_sound_midi
++EXPORT_SYMBOL sound/soundcore 0xcd083b10	unregister_sound_dsp
++EXPORT_SYMBOL sound/soundcore 0xfdab6de3	unregister_sound_midi
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x336d1d9e	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x3557352e	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x833326ca	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x92bdc596	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xb5b3b03b	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xcce3bdcb	snd_emux_register
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x1d355e15	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x48289adc	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x5cbd38d7	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x641d5856	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x6c68bfef	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xdd72498d	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xdfdb3917	__snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xfca68fba	snd_util_memhdr_free
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x8f3879f8	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xb2af19e1	snd_usbmidi_resume
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xbed43a41	snd_usbmidi_suspend
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL vmlinux 0x00000000	TOC.
++EXPORT_SYMBOL vmlinux 0x000c3f56	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x000e83e9	file_ns_capable
++EXPORT_SYMBOL vmlinux 0x001243fa	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0x00226792	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0x003f7911	passthru_features_check
++EXPORT_SYMBOL vmlinux 0x00432506	rt6_lookup
++EXPORT_SYMBOL vmlinux 0x004d88df	copy_from_iter
++EXPORT_SYMBOL vmlinux 0x00609794	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x0070cd1f	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x0085e1f1	__do_once_done
++EXPORT_SYMBOL vmlinux 0x008b5982	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x00aca98f	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x0122fb79	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0x012a97fc	xor_altivec_4
++EXPORT_SYMBOL vmlinux 0x01431aac	submit_bio
++EXPORT_SYMBOL vmlinux 0x01592922	ihold
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x0172d29b	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0x01790e94	csum_partial_copy
++EXPORT_SYMBOL vmlinux 0x01972a8a	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0x019f437a	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0x01a9b9d5	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x01ce3433	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0x01d517b7	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x01e12269	elv_add_request
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x02233086	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x02290166	scsi_print_result
++EXPORT_SYMBOL vmlinux 0x023a074a	hvc_get_chars
++EXPORT_SYMBOL vmlinux 0x024bf827	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x024d2064	twl6040_power
++EXPORT_SYMBOL vmlinux 0x02500dd7	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0x0258ca71	of_parse_phandle_with_args
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x0291f280	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0x0298e0ba	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02ad20e0	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x02b50903	param_set_bool
++EXPORT_SYMBOL vmlinux 0x02c5aad2	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x02d2dd31	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0x02dec783	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0x02e82557	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x02f4b927	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x02fedf00	udp_poll
++EXPORT_SYMBOL vmlinux 0x0314d2ab	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0x032cef86	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x0341a172	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0x0346fe00	__dst_free
++EXPORT_SYMBOL vmlinux 0x034f370f	lookup_one_len
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x03609bda	paca
++EXPORT_SYMBOL vmlinux 0x036200c8	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x0372ba73	fsync_bdev
++EXPORT_SYMBOL vmlinux 0x0376c5e0	agp_generic_alloc_user
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x039ca0f9	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0x03d74e86	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x03e9aa4a	param_set_ulong
++EXPORT_SYMBOL vmlinux 0x03fc5b48	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x04074f48	ioremap
++EXPORT_SYMBOL vmlinux 0x0407535e	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0x04222c91	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x042ac983	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x044f05ae	vc_cons
++EXPORT_SYMBOL vmlinux 0x046501fd	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0x046e5bd0	mdiobus_read
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x049e5f5d	i2c_transfer
++EXPORT_SYMBOL vmlinux 0x04bba3ef	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04ea5d10	ksize
++EXPORT_SYMBOL vmlinux 0x04eac100	inet_select_addr
++EXPORT_SYMBOL vmlinux 0x04f3e82a	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x050fe71c	dmaengine_get_unmap_data
++EXPORT_SYMBOL vmlinux 0x05186ca4	flush_icache_range
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x0530dede	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x05464c69	__nd_driver_register
++EXPORT_SYMBOL vmlinux 0x055c8559	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x056b3523	netlink_set_err
++EXPORT_SYMBOL vmlinux 0x058a09b4	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0x05a514a1	_insl_ns
++EXPORT_SYMBOL vmlinux 0x05acc12f	seq_open_private
++EXPORT_SYMBOL vmlinux 0x05c5f38c	d_path
++EXPORT_SYMBOL vmlinux 0x05e4ac44	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0x05e86f46	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0x05ef6db9	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x05f3d213	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0x05f85870	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x05fa4304	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0x060f811a	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0x06119951	security_path_mknod
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x06199c09	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0x062a8c0e	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x067ac8a6	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x0688ee61	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x06bec7a8	skb_pull
++EXPORT_SYMBOL vmlinux 0x06ca6f1b	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0x06da7b88	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0x06de71a8	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x0716df91	iunique
++EXPORT_SYMBOL vmlinux 0x071eae21	of_translate_dma_address
++EXPORT_SYMBOL vmlinux 0x07272c37	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x0727c4f3	iowrite8
++EXPORT_SYMBOL vmlinux 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL vmlinux 0x074328bd	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0x074e9213	down_killable
++EXPORT_SYMBOL vmlinux 0x0755a1e3	devm_release_resource
++EXPORT_SYMBOL vmlinux 0x079a7765	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07a9ef84	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x07be86bb	key_type_keyring
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07d7f19b	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x07d9883d	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0x08060d57	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x0833d8d0	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0x083a5679	unregister_console
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x084e83db	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0x0868e224	ibmebus_unregister_driver
++EXPORT_SYMBOL vmlinux 0x086be3a3	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x08baff40	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0x08c7da3b	phy_device_remove
++EXPORT_SYMBOL vmlinux 0x08ea69e7	mipi_dsi_packet_format_is_long
++EXPORT_SYMBOL vmlinux 0x08fadbc1	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x08fb6e29	I_BDEV
++EXPORT_SYMBOL vmlinux 0x08fbad09	migrate_page
++EXPORT_SYMBOL vmlinux 0x09262e10	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0x093f8575	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x0958c23e	__alloc_skb
++EXPORT_SYMBOL vmlinux 0x096c514d	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x09b64a45	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09f1e381	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x09fa627b	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0x0a16d424	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0x0a292872	reservation_seqcount_class
++EXPORT_SYMBOL vmlinux 0x0a3fcfcc	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0x0a557fb8	nvm_register
++EXPORT_SYMBOL vmlinux 0x0a57863e	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x0a770832	register_memory_notifier
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0ab2538f	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x0ab5de80	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0ae9d4a8	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x0b0b7165	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1092b9	of_find_device_by_node
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b2d1458	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0x0b2e1ec7	h_get_mpp
++EXPORT_SYMBOL vmlinux 0x0b49a5f6	of_graph_get_next_endpoint
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b660711	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0x0b6666ec	set_posix_acl
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b7f45f1	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0x0b7faac5	mipi_dsi_dcs_write_buffer
++EXPORT_SYMBOL vmlinux 0x0b95680e	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0x0ba13b32	get_empty_filp
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bce8372	init_buffer
++EXPORT_SYMBOL vmlinux 0x0bf796f8	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x0bf8db55	rtas
++EXPORT_SYMBOL vmlinux 0x0bff2078	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0x0bff65b0	skb_store_bits
++EXPORT_SYMBOL vmlinux 0x0c21d019	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0x0c403cc2	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c517ffa	__napi_complete
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c6bdc3f	vme_master_read
++EXPORT_SYMBOL vmlinux 0x0c7fd14a	vfs_setpos
++EXPORT_SYMBOL vmlinux 0x0c99becb	load_nls_default
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0ca77ace	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cc21918	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x0cd92139	d_splice_alias
++EXPORT_SYMBOL vmlinux 0x0cfa198f	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x0d087d1e	pci_restore_state
++EXPORT_SYMBOL vmlinux 0x0d253c49	vme_bus_error_handler
++EXPORT_SYMBOL vmlinux 0x0d268d45	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0x0d353910	agp_generic_insert_memory
++EXPORT_SYMBOL vmlinux 0x0d3e7486	current_in_userns
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d5d9b34	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x0d5de5e3	ptp_find_pin
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d6c963c	copy_from_user
++EXPORT_SYMBOL vmlinux 0x0d7442b4	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x0d80e0ff	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0da1d535	kobject_init
++EXPORT_SYMBOL vmlinux 0x0dc0ace0	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x0dcbdcf9	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x0dcc4361	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x0dec1325	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x0e1632aa	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0x0e2d2f2e	bdi_register
++EXPORT_SYMBOL vmlinux 0x0e3039a2	agp_put_bridge
++EXPORT_SYMBOL vmlinux 0x0e35f730	set_anon_super
++EXPORT_SYMBOL vmlinux 0x0e524aba	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e8f30f6	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x0eaf3ed7	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x0eb83782	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x0ec4a09b	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL vmlinux 0x0ec820e2	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x0ecf6a00	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f215761	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0x0f2299c0	block_read_full_page
++EXPORT_SYMBOL vmlinux 0x0f293d64	netdev_features_change
++EXPORT_SYMBOL vmlinux 0x0f2d87fe	cpufreq_generic_suspend
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f520cc9	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x0f5faa7e	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x0f66dd77	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f804d98	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x0f9c99c4	agp_generic_type_to_mask_type
++EXPORT_SYMBOL vmlinux 0x0fa24067	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0x0fa80428	mpage_readpage
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fbbfa82	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0x0fe8647d	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x0ff71261	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x1008fdb3	compat_nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x101e12c4	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x10401051	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x10561274	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x106459f5	ip6_xmit
++EXPORT_SYMBOL vmlinux 0x1072a394	csum_partial_copy_from_user
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x10950ee1	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x10a2788c	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0x10acfaaf	cdev_alloc
++EXPORT_SYMBOL vmlinux 0x10db26dc	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x10eefa76	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x111e71a2	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0x111fc7af	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x1124f1bd	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0x11294a03	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x114900a9	poll_initwait
++EXPORT_SYMBOL vmlinux 0x1149f4ac	pnv_pci_get_gpu_dev
++EXPORT_SYMBOL vmlinux 0x1156801c	km_state_expired
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x11667448	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0x116a618b	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0x116a700f	make_kgid
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x1173fbb9	input_mt_drop_unused
++EXPORT_SYMBOL vmlinux 0x1182d83a	cpuidle_disable
++EXPORT_SYMBOL vmlinux 0x11879878	param_get_string
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11a584ec	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x11b5eb1d	mount_ns
++EXPORT_SYMBOL vmlinux 0x11b60cb1	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0x11c7df25	scsi_add_device
++EXPORT_SYMBOL vmlinux 0x11efa18a	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120d67d4	unregister_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x123f82f3	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x124ba659	write_cache_pages
++EXPORT_SYMBOL vmlinux 0x12507560	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x125bba98	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0x12728113	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0x127a2687	of_graph_get_remote_port
++EXPORT_SYMBOL vmlinux 0x1290245f	vfs_writef
++EXPORT_SYMBOL vmlinux 0x12941427	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0x12944fa2	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x12964fa1	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12b1bc58	of_find_node_by_phandle
++EXPORT_SYMBOL vmlinux 0x12b66e23	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0x12dfeb12	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x12e52669	inet6_getname
++EXPORT_SYMBOL vmlinux 0x12e5ef0c	rtas_set_power_level
++EXPORT_SYMBOL vmlinux 0x12e82aee	__module_get
++EXPORT_SYMBOL vmlinux 0x12fe15a5	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0x130a0a64	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x13243d4b	wl1251_get_platform_data
++EXPORT_SYMBOL vmlinux 0x1330424f	__brelse
++EXPORT_SYMBOL vmlinux 0x13306c66	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x1343b2f5	fbcon_rotate_cw
++EXPORT_SYMBOL vmlinux 0x135578fb	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0x135703a0	up_read
++EXPORT_SYMBOL vmlinux 0x135cb1ff	clear_nlink
++EXPORT_SYMBOL vmlinux 0x137b0bb1	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x1394b40e	agp_generic_destroy_pages
++EXPORT_SYMBOL vmlinux 0x13aef01d	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0x13bbbc35	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13e4aecd	powerpc_debugfs_root
++EXPORT_SYMBOL vmlinux 0x13f53da6	CMO_PageSize
++EXPORT_SYMBOL vmlinux 0x1443a1fa	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0x146bde66	flush_signals
++EXPORT_SYMBOL vmlinux 0x146ca521	add_disk
++EXPORT_SYMBOL vmlinux 0x14917db4	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0x1492e0dc	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0x14a14817	pSeries_enable_reloc_on_exc
++EXPORT_SYMBOL vmlinux 0x14a658b5	skb_append
++EXPORT_SYMBOL vmlinux 0x14bf72d5	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x14c13c3a	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0x14c92f5a	dquot_initialize
++EXPORT_SYMBOL vmlinux 0x14ccd857	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x14d88246	bio_split
++EXPORT_SYMBOL vmlinux 0x14df0a78	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x14eeeae8	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x14fe74f3	generic_perform_write
++EXPORT_SYMBOL vmlinux 0x1507fc4d	mipi_dsi_dcs_nop
++EXPORT_SYMBOL vmlinux 0x1525ab37	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x1532d488	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0x15457a62	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x155ae3b8	__inode_permission
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15bc0668	param_set_charp
++EXPORT_SYMBOL vmlinux 0x15c302e1	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0x15d3fd60	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x15deef7a	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x160bd45c	rtas_token
++EXPORT_SYMBOL vmlinux 0x16178004	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x1634980e	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0x164fa6c7	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x16507cb1	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0x1677103b	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x167c5967	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x167cb59d	node_data
++EXPORT_SYMBOL vmlinux 0x1688fe6c	devm_gpiod_put
++EXPORT_SYMBOL vmlinux 0x16c6a8b6	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0x16cfc399	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x16ead958	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x16f06c9d	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0x16f16d29	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x16f23d55	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0x16f4a665	framebuffer_release
++EXPORT_SYMBOL vmlinux 0x16f5a2ec	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0x16fcb5f1	of_device_is_big_endian
++EXPORT_SYMBOL vmlinux 0x17030368	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x17181274	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x171cf5d6	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0x1724460f	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x172b82fb	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0x17403fb3	override_creds
++EXPORT_SYMBOL vmlinux 0x1743414f	__debugger_fault_handler
++EXPORT_SYMBOL vmlinux 0x175d3461	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0x17648396	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x17650a1f	default_llseek
++EXPORT_SYMBOL vmlinux 0x176786b2	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x177a8bc7	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x177d0842	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x1793f685	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0x1795e17d	cont_write_begin
++EXPORT_SYMBOL vmlinux 0x179dabdb	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x17ab8f19	tc_classify
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17c1d3e0	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0x17d46664	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x17e28473	fsl_upm_run_pattern
++EXPORT_SYMBOL vmlinux 0x17f341a0	i8042_lock_chip
++EXPORT_SYMBOL vmlinux 0x180e25cb	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x1812d0cf	serio_interrupt
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x182da9ef	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x18575768	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x1857aa39	proc_dointvec
++EXPORT_SYMBOL vmlinux 0x18732800	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x18a1d83e	set_nlink
++EXPORT_SYMBOL vmlinux 0x18d210ba	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x18eaaa2a	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0x18fb9e68	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0x19056611	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0x1915ec84	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0x19244b74	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x1935e388	of_get_next_parent
++EXPORT_SYMBOL vmlinux 0x19628135	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x196b1ff8	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0x196d007b	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0x19758e4b	keyring_clear
++EXPORT_SYMBOL vmlinux 0x1975cd65	vme_bus_type
++EXPORT_SYMBOL vmlinux 0x197b90ec	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0x198a37c4	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0x1992b73f	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x1998d261	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x199a8526	d_walk
++EXPORT_SYMBOL vmlinux 0x199ec4fb	arch_spin_unlock_wait
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19b20b10	vme_unregister_error_handler
++EXPORT_SYMBOL vmlinux 0x19b33d31	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0x19ba1dc7	fence_enable_sw_signaling
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19cd9343	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0x19d31e13	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x19e78198	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0x19eaf219	xfrm_input
++EXPORT_SYMBOL vmlinux 0x1a1babe8	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x1a383703	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0x1a470116	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0x1a485fcb	pipe_unlock
++EXPORT_SYMBOL vmlinux 0x1a48b16a	param_set_int
++EXPORT_SYMBOL vmlinux 0x1a5b9da5	elv_rb_del
++EXPORT_SYMBOL vmlinux 0x1a6e73c0	force_sig
++EXPORT_SYMBOL vmlinux 0x1a953837	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0x1a9df0fa	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x1aaefc16	giveup_altivec
++EXPORT_SYMBOL vmlinux 0x1ac5d3cb	strcspn
++EXPORT_SYMBOL vmlinux 0x1af0bc5a	flush_dcache_page
++EXPORT_SYMBOL vmlinux 0x1af62a99	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0x1afea1e8	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x1b01592f	agp_generic_alloc_pages
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b132009	rename_lock
++EXPORT_SYMBOL vmlinux 0x1b1b4930	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b2addc1	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x1b2d66ea	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0x1b3f22bd	d_invalidate
++EXPORT_SYMBOL vmlinux 0x1b4a523f	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0x1b625d33	enable_kernel_vsx
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b85b671	nd_namespace_blk_validate
++EXPORT_SYMBOL vmlinux 0x1b8b95ad	i8042_unlock_chip
++EXPORT_SYMBOL vmlinux 0x1ba3bbd9	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bc2ef09	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x1bc4ff03	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0x1bc54df4	vio_enable_interrupts
++EXPORT_SYMBOL vmlinux 0x1bc8bf6b	md_integrity_register
++EXPORT_SYMBOL vmlinux 0x1bcd24c0	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0x1bd6d4d1	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0x1be6fe36	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0x1bf888b5	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0x1bfec830	__iounmap_at
++EXPORT_SYMBOL vmlinux 0x1c030c1c	put_filp
++EXPORT_SYMBOL vmlinux 0x1c0514e8	give_up_console
++EXPORT_SYMBOL vmlinux 0x1c135d5a	nd_device_register
++EXPORT_SYMBOL vmlinux 0x1c193c8a	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0x1c1e8b1f	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0x1c279959	bdput
++EXPORT_SYMBOL vmlinux 0x1c31f0a8	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0x1c3e02e4	memcmp
++EXPORT_SYMBOL vmlinux 0x1c3e1bdf	sock_init_data
++EXPORT_SYMBOL vmlinux 0x1c516cc1	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0x1c51e418	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0x1c530389	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0x1c6208f7	sock_rfree
++EXPORT_SYMBOL vmlinux 0x1c68e581	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x1ca86d2b	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x1ce7e616	mdiobus_write_nested
++EXPORT_SYMBOL vmlinux 0x1ceff42a	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x1cfbdbae	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0x1cfcc880	mutex_lock
++EXPORT_SYMBOL vmlinux 0x1d1056e5	crc32_be
++EXPORT_SYMBOL vmlinux 0x1d162ae0	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0x1d3711c6	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x1d3e111e	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x1d6cb300	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0x1d89551d	mipi_dsi_set_maximum_return_packet_size
++EXPORT_SYMBOL vmlinux 0x1daee28a	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x1dbc4d0c	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dc66b4f	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0x1dc85df8	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0x1dc95710	vme_slave_request
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1dd8e0da	set_cached_acl
++EXPORT_SYMBOL vmlinux 0x1de37861	clear_inode
++EXPORT_SYMBOL vmlinux 0x1df9c960	pnv_cxl_get_irq_count
++EXPORT_SYMBOL vmlinux 0x1e0dadb6	dns_query
++EXPORT_SYMBOL vmlinux 0x1e1eacd9	phy_device_free
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e28a8a5	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0x1e335969	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0x1e5e0252	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e7088df	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0x1e86561e	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0x1e8c46ee	fget_raw
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1eadf088	skb_make_writable
++EXPORT_SYMBOL vmlinux 0x1eb3a159	devm_gpiod_get_array_optional
++EXPORT_SYMBOL vmlinux 0x1ecba395	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0x1ee22de6	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0x1ef4328a	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x1f16d108	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x1f1cda15	bio_copy_data
++EXPORT_SYMBOL vmlinux 0x1f214409	param_get_charp
++EXPORT_SYMBOL vmlinux 0x1f22facd	set_user_nice
++EXPORT_SYMBOL vmlinux 0x1f40bca2	of_match_device
++EXPORT_SYMBOL vmlinux 0x1f4b40c7	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x1f59667a	dst_destroy
++EXPORT_SYMBOL vmlinux 0x1f605a11	compat_ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x1f68af66	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x1f6ad468	f_setown
++EXPORT_SYMBOL vmlinux 0x1f6ce67a	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x1f7d259a	fd_install
++EXPORT_SYMBOL vmlinux 0x1fb16fbd	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fbd5aa5	dev_mc_add
++EXPORT_SYMBOL vmlinux 0x1fc3d674	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x1fca7d1f	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0x1fce34c8	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0x1fcf0d1d	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fd92844	pci_select_bars
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x1ff6e265	kset_unregister
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x2012fa6e	mount_nodev
++EXPORT_SYMBOL vmlinux 0x2026d9a9	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x203b1b91	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x204a9376	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x204fa585	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x20991860	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20bbc5a5	netdev_alert
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20d66962	of_find_compatible_node
++EXPORT_SYMBOL vmlinux 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL vmlinux 0x20eadeb6	ip_compute_csum
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20fd8285	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0x20ff824b	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x20ffe022	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0x211b1df7	nd_integrity_init
++EXPORT_SYMBOL vmlinux 0x211f68f1	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x213fff7e	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x214d648b	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0x214ef523	of_root
++EXPORT_SYMBOL vmlinux 0x2171a516	softnet_data
++EXPORT_SYMBOL vmlinux 0x21722c54	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x21755828	register_netdevice
++EXPORT_SYMBOL vmlinux 0x2190e744	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0x219455e0	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x21ae4bc8	input_release_device
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21eacc79	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0x21edcaca	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0x21f19335	fence_remove_callback
++EXPORT_SYMBOL vmlinux 0x21ff1062	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0x221c568d	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x221ea4a7	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x22300a5e	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0x224b5eed	set_security_override
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x22808ab9	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x228e0355	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0x22a9ad2c	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0x22aacd59	nvdimm_revalidate_disk
++EXPORT_SYMBOL vmlinux 0x22ab84b4	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x22ae3827	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22ba8edd	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x230f2a82	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x23177de5	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x232b2e14	of_find_node_by_type
++EXPORT_SYMBOL vmlinux 0x23335bde	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL vmlinux 0x23403030	vme_slot_num
++EXPORT_SYMBOL vmlinux 0x23457f21	elv_rb_find
++EXPORT_SYMBOL vmlinux 0x2357867c	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0x23591680	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x235e90f3	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x23731ecc	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0x23761b2e	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0x2388b256	vme_irq_request
++EXPORT_SYMBOL vmlinux 0x238d826c	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0x2399eb57	vme_dma_request
++EXPORT_SYMBOL vmlinux 0x239b871d	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23b59d53	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23c3491c	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0x23c7acbf	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23c9891c	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x23cf97db	vm_event_states
++EXPORT_SYMBOL vmlinux 0x23f2243d	mempool_free
++EXPORT_SYMBOL vmlinux 0x23f9c754	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x2401a316	simple_dname
++EXPORT_SYMBOL vmlinux 0x240aad56	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x242a7d00	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x2444da29	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0x244bfc6e	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x24608680	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0x247288ba	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x2484adc3	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0x24855cba	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x2491c94f	of_iomap
++EXPORT_SYMBOL vmlinux 0x249999a3	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0x24a5b941	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x24b633c9	rwsem_wake
++EXPORT_SYMBOL vmlinux 0x24bb750c	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0x24d6b4a6	cur_cpu_spec
++EXPORT_SYMBOL vmlinux 0x24eb9eb2	sock_i_ino
++EXPORT_SYMBOL vmlinux 0x24f00380	ida_init
++EXPORT_SYMBOL vmlinux 0x24f8a0a6	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x2505cd89	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x2518c9ae	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x252114ea	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x25281a08	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0x254f3046	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0x256e8748	cdrom_open
++EXPORT_SYMBOL vmlinux 0x2570a138	reservation_seqcount_string
++EXPORT_SYMBOL vmlinux 0x2572be12	down_read_trylock
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x25a50981	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0x25e05d9b	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0x25e397a6	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0x25e8ed29	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x25f3c974	get_agp_version
++EXPORT_SYMBOL vmlinux 0x263804a4	component_match_add
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x26477c07	__vmalloc
++EXPORT_SYMBOL vmlinux 0x264a54e4	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0x264f2a40	dm_put_device
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x2654f01b	sock_wake_async
++EXPORT_SYMBOL vmlinux 0x265beaab	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0x2665d53a	key_create_or_update
++EXPORT_SYMBOL vmlinux 0x26675fd9	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0x267d9a71	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0x268e03be	pci_release_regions
++EXPORT_SYMBOL vmlinux 0x26e298e0	unregister_memory_notifier
++EXPORT_SYMBOL vmlinux 0x26e3c4b7	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26e7a101	md_done_sync
++EXPORT_SYMBOL vmlinux 0x26e7bd54	netif_skb_features
++EXPORT_SYMBOL vmlinux 0x26ee714d	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x26fec978	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0x27063355	vfs_unlink
++EXPORT_SYMBOL vmlinux 0x270d5d5b	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x273db990	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x275b0b01	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0x2763533f	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0x27646df3	start_thread
++EXPORT_SYMBOL vmlinux 0x2771d7ff	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x277a5a94	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0x278544ea	proc_set_size
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x27aeabc5	dma_find_channel
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27bda1ff	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x27bf7eab	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0x27c60fa1	pcibios_fixup_bus
++EXPORT_SYMBOL vmlinux 0x27d8ff6c	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0x27dc38c1	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x27f5a888	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x2813ca8a	xattr_full_name
++EXPORT_SYMBOL vmlinux 0x2816d2bd	dev_uc_init
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x28318305	snprintf
++EXPORT_SYMBOL vmlinux 0x2850fded	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x2852d1d6	agp_find_bridge
++EXPORT_SYMBOL vmlinux 0x287de0a2	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x288dce6d	agp_alloc_bridge
++EXPORT_SYMBOL vmlinux 0x289b27e5	agp_generic_free_gatt_table
++EXPORT_SYMBOL vmlinux 0x289db3ee	idr_remove
++EXPORT_SYMBOL vmlinux 0x289f3dab	devm_devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0x28a2b29f	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28a7beba	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x28aa817e	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0x28abfe6e	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x28c54f4f	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0x28e2d0d9	of_find_node_opts_by_path
++EXPORT_SYMBOL vmlinux 0x28e6ce45	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x294d01ee	lro_flush_all
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x295b03e4	nd_device_unregister
++EXPORT_SYMBOL vmlinux 0x29703a77	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0x297ae47b	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0x297c7acf	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x297dafaf	sock_no_poll
++EXPORT_SYMBOL vmlinux 0x298daaa4	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x299b13f6	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x29b20d4c	sock_create_lite
++EXPORT_SYMBOL vmlinux 0x29b2279e	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x29cc7eb8	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x29d7e496	__page_symlink
++EXPORT_SYMBOL vmlinux 0x29e4c613	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0x29edd8c3	rtas_online_cpus_mask
++EXPORT_SYMBOL vmlinux 0x29ef6f33	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0x2a18d5b8	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x2a2d0a1b	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0x2a3022b0	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a6b2124	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0x2a75ed32	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x2a7c0309	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0x2a922295	register_md_personality
++EXPORT_SYMBOL vmlinux 0x2a967f62	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0x2aa3996e	sget_userns
++EXPORT_SYMBOL vmlinux 0x2aa83a83	flush_old_exec
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2aadacb6	kern_unmount
++EXPORT_SYMBOL vmlinux 0x2acc7bb7	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2ad7e80c	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x2ae240ab	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b137ad3	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0x2b14fc8a	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b31357d	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0x2b358293	vc_resize
++EXPORT_SYMBOL vmlinux 0x2b3d6153	__scm_send
++EXPORT_SYMBOL vmlinux 0x2b4991ec	xmon
++EXPORT_SYMBOL vmlinux 0x2b51d140	dqput
++EXPORT_SYMBOL vmlinux 0x2b7acb60	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x2b973363	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0x2b989010	do_splice_to
++EXPORT_SYMBOL vmlinux 0x2b9b8daa	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x2b9bb193	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2ba84ce2	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0x2ba8ada5	get_acl
++EXPORT_SYMBOL vmlinux 0x2ba8b1a6	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x2bb02cbd	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0x2bb1ee2b	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0x2bb4505c	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0x2bbc5598	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0x2bc44dd0	compat_sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x2bddcc0f	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0x2bfe9d4e	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0x2c039a8f	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x2c08ab30	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x2c0f151a	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c25c217	ata_link_printk
++EXPORT_SYMBOL vmlinux 0x2c3113ad	page_symlink
++EXPORT_SYMBOL vmlinux 0x2c36a650	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0x2c36fe36	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0x2c3aff14	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x2c4c000a	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0x2c69e66f	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0x2c7b1fca	down_timeout
++EXPORT_SYMBOL vmlinux 0x2c8bdd4b	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0x2c8e8fec	inet_addr_type
++EXPORT_SYMBOL vmlinux 0x2c9ab62a	tty_register_device
++EXPORT_SYMBOL vmlinux 0x2ca289da	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x2cc453a2	put_page
++EXPORT_SYMBOL vmlinux 0x2cc4c56b	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x2cd36bc3	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x2cd6da14	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0x2ced4be5	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0x2cf73cb7	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x2cfc113c	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x2d028aa8	end_page_writeback
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d874ad8	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0x2d92c120	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x2d9464a9	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0x2daf936c	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x2db1e0c6	dql_init
++EXPORT_SYMBOL vmlinux 0x2dd57f6b	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0x2de0c585	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0x2deb686e	pci_clear_master
++EXPORT_SYMBOL vmlinux 0x2dff7de6	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x2e0d2f7f	queue_work_on
++EXPORT_SYMBOL vmlinux 0x2e0fb928	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x2e10c0c5	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0x2e12a93b	ibmebus_request_irq
++EXPORT_SYMBOL vmlinux 0x2e18ec50	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0x2e22fa25	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0x2e2b40d2	strncat
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e593a27	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0x2e7f7f2d	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x2e9ec198	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x2ec74483	inet_frag_find
++EXPORT_SYMBOL vmlinux 0x2ec7ad8a	generic_make_request
++EXPORT_SYMBOL vmlinux 0x2ee74731	nvdimm_namespace_capacity
++EXPORT_SYMBOL vmlinux 0x2ef06736	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x2ef508e4	path_noexec
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2efe8cc0	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f287f0d	copy_to_user
++EXPORT_SYMBOL vmlinux 0x2f2b9584	pps_register_source
++EXPORT_SYMBOL vmlinux 0x2f42ed83	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x2f6f2702	__nd_iostat_start
++EXPORT_SYMBOL vmlinux 0x2f967b2a	sock_i_uid
++EXPORT_SYMBOL vmlinux 0x2f9a5c49	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0x2fae96de	rtas_data_buf_lock
++EXPORT_SYMBOL vmlinux 0x2fb3e368	load_nls
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fb80459	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0x2fbdfe4a	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0x2fd2a178	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0x2fd9bb54	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2fe76940	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0x30056749	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x30226ddf	agp_device_command
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x30429fd3	simple_rmdir
++EXPORT_SYMBOL vmlinux 0x304c90ae	phy_print_status
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x3095582f	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x30a00cc1	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30b8b35c	cpu_to_chip_id
++EXPORT_SYMBOL vmlinux 0x30c77049	pci_bus_get
++EXPORT_SYMBOL vmlinux 0x30cdf4d8	vga_client_register
++EXPORT_SYMBOL vmlinux 0x30d1770a	vfs_readv
++EXPORT_SYMBOL vmlinux 0x30e00037	ilookup5
++EXPORT_SYMBOL vmlinux 0x30f2c4fa	path_is_under
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310f02ec	memremap
++EXPORT_SYMBOL vmlinux 0x31139766	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0x31165edd	complete_request_key
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x3162af6a	drop_nlink
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x31a0c8aa	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x31cd995b	store_fp_state
++EXPORT_SYMBOL vmlinux 0x31ddde2d	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x31dde4a0	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x31f29da1	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0x31f474ce	bio_map_kern
++EXPORT_SYMBOL vmlinux 0x320ef874	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0x324403b0	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x32498342	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x3257b7ed	input_free_device
++EXPORT_SYMBOL vmlinux 0x325c11b2	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x326640fe	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x32708660	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0x327155b4	init_net
++EXPORT_SYMBOL vmlinux 0x32739904	generic_write_end
++EXPORT_SYMBOL vmlinux 0x3284bab3	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0x328dc2e8	kill_bdev
++EXPORT_SYMBOL vmlinux 0x329734d4	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0x329d2845	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0x32a845ac	register_filesystem
++EXPORT_SYMBOL vmlinux 0x32d88402	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x32ddc69b	nd_sb_checksum
++EXPORT_SYMBOL vmlinux 0x32e611ff	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x32e7baf7	blk_make_request
++EXPORT_SYMBOL vmlinux 0x32e8ee47	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0x332f672c	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0x333a38bf	of_device_alloc
++EXPORT_SYMBOL vmlinux 0x333b7560	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x333cb37c	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x33510c69	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x33619e01	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0x339338e1	input_register_handle
++EXPORT_SYMBOL vmlinux 0x33b0192a	skb_find_text
++EXPORT_SYMBOL vmlinux 0x33b84f74	copy_page
++EXPORT_SYMBOL vmlinux 0x33b9e668	netdev_emerg
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33f01469	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x33fcf44a	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0x340361c3	would_dump
++EXPORT_SYMBOL vmlinux 0x344b7b7f	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0x345345f2	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34a194a8	compat_sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x351d3c50	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0x351dfb13	nd_btt_probe
++EXPORT_SYMBOL vmlinux 0x3525c274	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x352f664f	iput
++EXPORT_SYMBOL vmlinux 0x3539f11b	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x35451fe2	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0x354c7e00	d_tmpfile
++EXPORT_SYMBOL vmlinux 0x356461c8	rtc_time64_to_tm
++EXPORT_SYMBOL vmlinux 0x35722fcd	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0x35845689	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0x3585d7e7	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x35924c54	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0x35a0bd5a	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35ab9d64	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x35c32767	xor_altivec_2
++EXPORT_SYMBOL vmlinux 0x35d68588	kill_fasync
++EXPORT_SYMBOL vmlinux 0x35e09980	flex_array_put
++EXPORT_SYMBOL vmlinux 0x35e10e0d	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x35f61658	generic_read_dir
++EXPORT_SYMBOL vmlinux 0x3613d011	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0x3618cb2d	ida_destroy
++EXPORT_SYMBOL vmlinux 0x3628a32a	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x3634068b	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x36527ece	mmc_retune_timer_stop
++EXPORT_SYMBOL vmlinux 0x3655f94e	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0x3668fd48	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0x366f6d27	idr_destroy
++EXPORT_SYMBOL vmlinux 0x36797dce	mipi_dsi_host_unregister
++EXPORT_SYMBOL vmlinux 0x367a8f56	vga_put
++EXPORT_SYMBOL vmlinux 0x36908bba	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x369e1115	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x369fb013	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0x36b0e732	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36d6aa01	srp_reconnect_rport
++EXPORT_SYMBOL vmlinux 0x36d83c84	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0x36dba162	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0x371149a7	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0x3714f789	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x371d2130	check_legacy_ioport
++EXPORT_SYMBOL vmlinux 0x371d9d15	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x37344510	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x37383edd	rtas_get_power_level
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x375cf7d4	seq_dentry
++EXPORT_SYMBOL vmlinux 0x375d8800	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x37625704	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x376ddf69	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37b8b39e	screen_info
++EXPORT_SYMBOL vmlinux 0x37baa47b	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37d07219	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x37ebb37d	inet_sendpage
++EXPORT_SYMBOL vmlinux 0x380b00f9	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x380d769a	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x38698e14	km_report
++EXPORT_SYMBOL vmlinux 0x3877990a	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x3888fa0b	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0x38a25a45	proto_unregister
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38b06981	serio_rescan
++EXPORT_SYMBOL vmlinux 0x38b72414	done_path_create
++EXPORT_SYMBOL vmlinux 0x38b825d1	idr_replace
++EXPORT_SYMBOL vmlinux 0x38dcbbcd	sock_from_file
++EXPORT_SYMBOL vmlinux 0x38de3c03	backlight_device_register
++EXPORT_SYMBOL vmlinux 0x38fb9933	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x3921ce61	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x393d4de9	crc32_le
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x3955fcf6	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x395c5b85	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x397ef21c	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x398623cf	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x399ad043	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0x39a96095	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39ba4a6a	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0x39cdf63c	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x39f4a381	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0x39f9a251	dev_printk
++EXPORT_SYMBOL vmlinux 0x3a189f02	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0x3a28d1e3	param_set_ullong
++EXPORT_SYMBOL vmlinux 0x3a32482b	put_disk
++EXPORT_SYMBOL vmlinux 0x3a6cbb19	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0x3a8f74f0	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3acd6bec	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0x3ae0c8e3	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x3af41a39	blk_rq_init
++EXPORT_SYMBOL vmlinux 0x3afca59f	wireless_send_event
++EXPORT_SYMBOL vmlinux 0x3b3f58cf	agp_unbind_memory
++EXPORT_SYMBOL vmlinux 0x3b417032	inet6_offloads
++EXPORT_SYMBOL vmlinux 0x3b4de7e7	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0x3b566d03	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0x3b615a21	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b67dfe2	pnv_cxl_alloc_hwirqs
++EXPORT_SYMBOL vmlinux 0x3b6c7769	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0x3b76631a	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x3b7aa2f4	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0x3b7b0458	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x3b904cd2	request_key_async
++EXPORT_SYMBOL vmlinux 0x3bb6ff6f	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x3bd27f1b	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0x3bd2c40d	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0x3bd67e5d	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x3c0098f4	dquot_get_state
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c416324	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0x3c483012	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x3c496f21	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x3c4f7c63	inet_bind
++EXPORT_SYMBOL vmlinux 0x3c6e5e9f	poll_freewait
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c84262b	path_get
++EXPORT_SYMBOL vmlinux 0x3cc4b0dc	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3d17ec0a	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x3d1a2341	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0x3d313d2b	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0x3d3a4c8b	register_cdrom
++EXPORT_SYMBOL vmlinux 0x3d51e1e7	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0x3d634294	dqget
++EXPORT_SYMBOL vmlinux 0x3d660bb6	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0x3d7df49d	simple_follow_link
++EXPORT_SYMBOL vmlinux 0x3d8529f9	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x3d888276	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0x3d8a81c0	register_netdev
++EXPORT_SYMBOL vmlinux 0x3dbf36c9	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0x3dc46796	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3df948d1	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3dfe63b8	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x3e04df70	alloc_file
++EXPORT_SYMBOL vmlinux 0x3e05c2da	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x3e2ce6d8	vme_unregister_bridge
++EXPORT_SYMBOL vmlinux 0x3e420960	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0x3e47e1ac	down_write
++EXPORT_SYMBOL vmlinux 0x3e5dc69b	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0x3e6bd3d1	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0x3e868a3f	generic_update_time
++EXPORT_SYMBOL vmlinux 0x3e882943	pcibios_align_resource
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL vmlinux 0x3ec10da2	tty_port_open
++EXPORT_SYMBOL vmlinux 0x3ecaecaa	pci_pme_active
++EXPORT_SYMBOL vmlinux 0x3eedc796	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x3f031183	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0x3f03157a	dquot_operations
++EXPORT_SYMBOL vmlinux 0x3f0546a8	ioread32_rep
++EXPORT_SYMBOL vmlinux 0x3f09f48c	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x3f3cdfa8	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0x3f406a3b	enable_kernel_altivec
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f5a750e	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0x3f9f2636	clear_user_page
++EXPORT_SYMBOL vmlinux 0x3faa1720	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x3fc907c0	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x3fca0799	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0x3fcbbbdb	of_find_i2c_device_by_node
++EXPORT_SYMBOL vmlinux 0x3fe2ccbe	memweight
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x3ff8e495	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0x3ff969e1	follow_down
++EXPORT_SYMBOL vmlinux 0x4017e950	phy_connect
++EXPORT_SYMBOL vmlinux 0x4019a470	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0x401a3d79	nd_region_acquire_lane
++EXPORT_SYMBOL vmlinux 0x402a7653	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4032d026	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0x4049ea96	update_devfreq
++EXPORT_SYMBOL vmlinux 0x404d5b16	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x405f737b	vme_irq_free
++EXPORT_SYMBOL vmlinux 0x40858c09	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0x4096dbf5	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40aafe07	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0x40b2d53d	seq_read
++EXPORT_SYMBOL vmlinux 0x40bc3e9e	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40e6df69	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x41155f0a	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x411a8945	ping_prot
++EXPORT_SYMBOL vmlinux 0x4129c622	of_match_node
++EXPORT_SYMBOL vmlinux 0x412a0cf4	tty_check_change
++EXPORT_SYMBOL vmlinux 0x414187f0	bdi_init
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x41537623	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0x4159c38f	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x415e9c25	phy_attach_direct
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x419048d0	agp_generic_alloc_by_type
++EXPORT_SYMBOL vmlinux 0x419179ea	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x4191c866	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x419a115c	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0x41a3fbf1	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x41add52a	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0x41b04155	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0x41b55ad6	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x41baf194	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0x41c63018	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0x41d26c1a	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x41ebdbd7	dquot_disable
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x42307d0a	new_inode
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x4249be37	__skb_checksum
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x42595e58	vgacon_text_force
++EXPORT_SYMBOL vmlinux 0x426c5f4a	kvmppc_hv_find_lock_hpte
++EXPORT_SYMBOL vmlinux 0x4276372c	security_path_symlink
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42d34c6c	set_binfmt
++EXPORT_SYMBOL vmlinux 0x42dc4158	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0x42f43d36	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x4315fe25	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0x431ee063	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0x43213782	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x434553b9	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0x43466daa	nvdimm_namespace_disk_name
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x4353c972	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0x436c2179	iowrite32
++EXPORT_SYMBOL vmlinux 0x437e728e	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x43986745	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0x439ae425	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0x43a01f90	complete_all
++EXPORT_SYMBOL vmlinux 0x43a4b499	pnv_pci_get_phb_node
++EXPORT_SYMBOL vmlinux 0x43a78649	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0x43bf4dd2	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x43c50e1c	pci_find_hose_for_OF_device
++EXPORT_SYMBOL vmlinux 0x43deedfe	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0x43e4f255	padata_stop
++EXPORT_SYMBOL vmlinux 0x43e60129	downgrade_write
++EXPORT_SYMBOL vmlinux 0x43e86d85	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x440395e9	pps_event
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x4420ae8a	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0x4424af13	init_special_inode
++EXPORT_SYMBOL vmlinux 0x442796f5	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0x442b3bf1	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0x44518b2a	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0x4458cc48	mipi_dsi_dcs_read
++EXPORT_SYMBOL vmlinux 0x446edb89	vio_unregister_device
++EXPORT_SYMBOL vmlinux 0x4475e4e4	vmap
++EXPORT_SYMBOL vmlinux 0x447f2381	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0x4480d48e	netif_device_attach
++EXPORT_SYMBOL vmlinux 0x448968e2	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x448eac3e	kmemdup
++EXPORT_SYMBOL vmlinux 0x449b8e54	of_count_phandle_with_args
++EXPORT_SYMBOL vmlinux 0x44a74f78	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x44aac5ca	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44c14e87	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0x44d34d27	of_io_request_and_map
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44eb192e	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x44ed1675	thaw_super
++EXPORT_SYMBOL vmlinux 0x44f02855	dev_set_group
++EXPORT_SYMBOL vmlinux 0x450aad85	mipi_dsi_dcs_soft_reset
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x457d01c9	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x4584f02c	dst_alloc
++EXPORT_SYMBOL vmlinux 0x459374b1	find_lock_entry
++EXPORT_SYMBOL vmlinux 0x45a55ec8	__iounmap
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45edcda9	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x4602114b	skb_push
++EXPORT_SYMBOL vmlinux 0x4612c59d	down_trylock
++EXPORT_SYMBOL vmlinux 0x461ac773	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x461ebfa0	__copy_tofrom_user
++EXPORT_SYMBOL vmlinux 0x462743e4	tty_free_termios
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL vmlinux 0x46661700	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x467df16d	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0x4693001b	of_cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0x46a0170e	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0x46a93fe9	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x46c47fb6	__node_distance
++EXPORT_SYMBOL vmlinux 0x46d12956	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x46d2b723	nobh_write_end
++EXPORT_SYMBOL vmlinux 0x46d65051	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x4702de31	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x472a4897	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x474c8a5e	path_put
++EXPORT_SYMBOL vmlinux 0x474fcdfa	fb_get_mode
++EXPORT_SYMBOL vmlinux 0x47605df1	scsi_execute
++EXPORT_SYMBOL vmlinux 0x47608718	fence_init
++EXPORT_SYMBOL vmlinux 0x47684d13	dentry_open
++EXPORT_SYMBOL vmlinux 0x476d6a69	dst_discard_out
++EXPORT_SYMBOL vmlinux 0x4782896f	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x47b6465d	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0x47f2fd37	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0x47fbdf8b	mipi_dsi_dcs_set_tear_off
++EXPORT_SYMBOL vmlinux 0x480cadf1	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0x480d98c6	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x4829a47e	memcpy
++EXPORT_SYMBOL vmlinux 0x482b9455	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x48404b9a	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x4841bdee	strnchr
++EXPORT_SYMBOL vmlinux 0x484e5c01	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0x48547679	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0x48552011	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0x4857594e	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x485ea1fd	kill_pid
++EXPORT_SYMBOL vmlinux 0x485ebb3d	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0x486a58a6	of_get_cpu_node
++EXPORT_SYMBOL vmlinux 0x486a5eb0	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0x4873cdfa	dev_deactivate
++EXPORT_SYMBOL vmlinux 0x487588fa	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x487c942a	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0x48a8e536	agp_generic_mask_memory
++EXPORT_SYMBOL vmlinux 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL vmlinux 0x48c25b8b	sock_efree
++EXPORT_SYMBOL vmlinux 0x48d493a6	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0x490179cb	find_get_entry
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x491a2792	stop_tty
++EXPORT_SYMBOL vmlinux 0x49348f4b	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x4947ebc2	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0x494eb344	compat_mc_getsockopt
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x49638f3d	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x4968550e	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x499bfc6d	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49bb3798	nobh_writepage
++EXPORT_SYMBOL vmlinux 0x49bc6bdc	eth_header_cache
++EXPORT_SYMBOL vmlinux 0x49c3190c	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0x49cfd62e	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x49e23d1d	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x49ed0470	arp_tbl
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x49f80077	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0x4a08418f	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0x4a20f0b6	fsl_lbc_ctrl_dev
++EXPORT_SYMBOL vmlinux 0x4a3ca7f1	netlink_capable
++EXPORT_SYMBOL vmlinux 0x4a738d4c	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x4a79b77a	seq_pad
++EXPORT_SYMBOL vmlinux 0x4a8961f5	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x4a95b11c	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0x4a963edc	sk_alloc
++EXPORT_SYMBOL vmlinux 0x4a97d67b	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x4a981223	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x4a9a49d7	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4abe44f5	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0x4ac3af98	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4ad2a57a	opal_event_request
++EXPORT_SYMBOL vmlinux 0x4aec0362	register_console
++EXPORT_SYMBOL vmlinux 0x4afb4b11	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b05ee55	truncate_setsize
++EXPORT_SYMBOL vmlinux 0x4b085dbf	agp3_generic_configure
++EXPORT_SYMBOL vmlinux 0x4b1a5c4d	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0x4b25f030	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x4b2c8b70	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0x4b2ea4e5	may_umount
++EXPORT_SYMBOL vmlinux 0x4b45f5de	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b753947	kernel_accept
++EXPORT_SYMBOL vmlinux 0x4b8326ff	ida_remove
++EXPORT_SYMBOL vmlinux 0x4b96132f	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0x4b9840e7	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x4ba54059	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL vmlinux 0x4baf6152	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x4bc9c445	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0x4bed99b3	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0x4bf6225f	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x4c11435a	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0x4c20286c	of_platform_device_create
++EXPORT_SYMBOL vmlinux 0x4c258239	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0x4c2c5440	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c3d6272	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x4c4fd9ff	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0x4c6e77fe	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0x4c797243	prepare_creds
++EXPORT_SYMBOL vmlinux 0x4ca9669f	scnprintf
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4cdf062a	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0x4ce2b418	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x4d0c7aea	iget_locked
++EXPORT_SYMBOL vmlinux 0x4d2d026c	empty_aops
++EXPORT_SYMBOL vmlinux 0x4d56f911	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x4d5eae25	free_user_ns
++EXPORT_SYMBOL vmlinux 0x4d791953	mempool_resize
++EXPORT_SYMBOL vmlinux 0x4d95c363	vme_irq_generate
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4dbf5359	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x4dc10343	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0x4dca2d49	unregister_netdev
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4deae36b	lwtunnel_build_state
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4dfbf54a	devfreq_recommended_opp
++EXPORT_SYMBOL vmlinux 0x4e00d573	__ps2_command
++EXPORT_SYMBOL vmlinux 0x4e28e513	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e641e98	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x4e68e1cf	kobject_add
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e748e2b	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x4e76c93d	compat_ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x4e83ca3c	phy_read_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x4e9dffb5	ip_fast_csum
++EXPORT_SYMBOL vmlinux 0x4eb20236	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0x4ec348ed	dm_io
++EXPORT_SYMBOL vmlinux 0x4ed81aac	sync_blockdev
++EXPORT_SYMBOL vmlinux 0x4f092f4c	key_validate
++EXPORT_SYMBOL vmlinux 0x4f099504	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x4f14ab7c	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f2250ba	rtc_tm_to_time64
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f3ec407	filemap_flush
++EXPORT_SYMBOL vmlinux 0x4f464ec7	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f5949c5	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0x4f5f7732	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f86f4d9	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0x4f8c2bb0	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0x4fa15389	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0x4fb9cdb3	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x4fbb9a4e	d_rehash
++EXPORT_SYMBOL vmlinux 0x4fc2210f	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x4fdee897	i8042_command
++EXPORT_SYMBOL vmlinux 0x4fed7153	ip_options_compile
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x50133eee	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0x5024dbd4	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x50332d92	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0x5059b691	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0x505a7355	pci_request_region
++EXPORT_SYMBOL vmlinux 0x50627a5c	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x5068e724	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x50870c93	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0x508f4e8e	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x50a90e8d	bsearch
++EXPORT_SYMBOL vmlinux 0x50ba769a	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x50bc1283	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x50dd3774	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x50e4eddc	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x50f1560a	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x50f8c483	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x51164ad9	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x511d58fe	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0x512d469f	agp_create_memory
++EXPORT_SYMBOL vmlinux 0x5152d4d7	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x515e0d51	genphy_aneg_done
++EXPORT_SYMBOL vmlinux 0x515fcfc9	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x516cd74f	vme_new_dma_list
++EXPORT_SYMBOL vmlinux 0x5173c7bf	__blk_end_request
++EXPORT_SYMBOL vmlinux 0x517a3e25	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0x517b4c73	of_dev_get
++EXPORT_SYMBOL vmlinux 0x518ae54c	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0x519946b5	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0x519b0da3	finish_wait
++EXPORT_SYMBOL vmlinux 0x51ab91ea	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0x51bbd7d9	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0x51c985c6	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x51ea9fe1	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0x51ff5ffa	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x523dc469	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0x524ea0f7	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0x524ff01b	phy_resume
++EXPORT_SYMBOL vmlinux 0x526be8e3	noop_llseek
++EXPORT_SYMBOL vmlinux 0x52983a4f	vme_master_write
++EXPORT_SYMBOL vmlinux 0x52da486f	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0x52df3a0c	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x52e9b7b8	simple_readpage
++EXPORT_SYMBOL vmlinux 0x52eaaa17	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x531e50c1	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0x5324a1ec	security_mmap_file
++EXPORT_SYMBOL vmlinux 0x532c2afa	i8042_remove_filter
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x534a4aaf	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0x534e455c	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x534e938f	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL vmlinux 0x536032f6	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0x53641f6d	skb_clone
++EXPORT_SYMBOL vmlinux 0x536cc847	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0x5377e556	hex2bin
++EXPORT_SYMBOL vmlinux 0x539af73c	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x53a88558	security_path_truncate
++EXPORT_SYMBOL vmlinux 0x53bb661d	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0x53cc4f0f	input_open_device
++EXPORT_SYMBOL vmlinux 0x53d66b68	phy_write_mmd_indirect
++EXPORT_SYMBOL vmlinux 0x53e1d373	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0x53ebab1b	_outsl_ns
++EXPORT_SYMBOL vmlinux 0x53f478fa	agp_enable
++EXPORT_SYMBOL vmlinux 0x54015c98	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x5412c7c7	up
++EXPORT_SYMBOL vmlinux 0x5420d52e	of_phy_register_fixed_link
++EXPORT_SYMBOL vmlinux 0x54240da9	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0x54245b39	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0x5439a3b7	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x545a5ce6	pci_bus_put
++EXPORT_SYMBOL vmlinux 0x548a2ef1	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0x549403bd	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54c256e0	vme_check_window
++EXPORT_SYMBOL vmlinux 0x54dd2695	arch_free_page
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54ea815e	request_key
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x5568c553	complete
++EXPORT_SYMBOL vmlinux 0x5577ef9e	udp_table
++EXPORT_SYMBOL vmlinux 0x557d4afd	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x5591d513	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0x55a0150e	of_phy_is_fixed_link
++EXPORT_SYMBOL vmlinux 0x55d481c9	hdmi_infoframe_unpack
++EXPORT_SYMBOL vmlinux 0x55f5019b	__kmalloc_node
++EXPORT_SYMBOL vmlinux 0x56106e2b	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x563fcbcc	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x56558d11	inode_init_once
++EXPORT_SYMBOL vmlinux 0x5673d832	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x5680eef3	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0x568f2f3f	put_vaddr_frames
++EXPORT_SYMBOL vmlinux 0x5696d05b	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x569ef44d	vme_dma_list_exec
++EXPORT_SYMBOL vmlinux 0x56ba6811	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0x56bb97a4	kmem_cache_alloc_node_trace
++EXPORT_SYMBOL vmlinux 0x56c2b95b	rtas_progress
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56d4e468	uart_resume_port
++EXPORT_SYMBOL vmlinux 0x56f6c7de	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0x571072a5	sk_net_capable
++EXPORT_SYMBOL vmlinux 0x5716076a	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0x571a01d3	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0x572647d6	get_mce_fault_addr
++EXPORT_SYMBOL vmlinux 0x57292f82	tty_name
++EXPORT_SYMBOL vmlinux 0x572bf5dd	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x573b42bf	of_get_property
++EXPORT_SYMBOL vmlinux 0x57443645	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x57597eaf	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x577d35f3	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x578d9116	scsi_init_io
++EXPORT_SYMBOL vmlinux 0x5792f848	strlcpy
++EXPORT_SYMBOL vmlinux 0x57a6e9c7	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0x57bf782f	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x57d9e552	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x57ee2745	param_set_byte
++EXPORT_SYMBOL vmlinux 0x57f34254	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x57f4bd39	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x58408de3	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0x584111c3	dquot_destroy
++EXPORT_SYMBOL vmlinux 0x5857b225	ioread16_rep
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x58a079f0	make_kprojid
++EXPORT_SYMBOL vmlinux 0x58b40f10	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58c1601d	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0x58c4584b	devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x58c4d311	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0x58cff7a1	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x594657ae	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x594bc307	blk_put_request
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x59556ade	vga_con
++EXPORT_SYMBOL vmlinux 0x5957d6fc	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0x595d0946	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x598fe3f0	write_inode_now
++EXPORT_SYMBOL vmlinux 0x599df3b8	of_device_unregister
++EXPORT_SYMBOL vmlinux 0x59a882a6	pci_save_state
++EXPORT_SYMBOL vmlinux 0x59aa14cf	fence_release
++EXPORT_SYMBOL vmlinux 0x59adb265	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0x59b3378a	completion_done
++EXPORT_SYMBOL vmlinux 0x59b78983	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0x59bc7c67	pci_iounmap
++EXPORT_SYMBOL vmlinux 0x59c3aa2c	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0x59ca28c3	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x59cfa1be	mipi_dsi_dcs_set_column_address
++EXPORT_SYMBOL vmlinux 0x59f3c3de	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x5a025f7b	arch_local_irq_restore
++EXPORT_SYMBOL vmlinux 0x5a0aaa12	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL vmlinux 0x5a1eed72	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x5a216acf	write_one_page
++EXPORT_SYMBOL vmlinux 0x5a3e380d	blk_complete_request
++EXPORT_SYMBOL vmlinux 0x5a3ea205	tty_port_init
++EXPORT_SYMBOL vmlinux 0x5a449cdb	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x5a4688de	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0x5a4b7817	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0x5a798490	input_flush_device
++EXPORT_SYMBOL vmlinux 0x5a808e08	ilookup
++EXPORT_SYMBOL vmlinux 0x5a8f2df7	vme_master_request
++EXPORT_SYMBOL vmlinux 0x5a921311	strncmp
++EXPORT_SYMBOL vmlinux 0x5a9f1d63	memmove
++EXPORT_SYMBOL vmlinux 0x5aa8aefc	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0x5ac8db52	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x5acefab7	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x5ad937b3	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL vmlinux 0x5b43f1f1	rtas_service_present
++EXPORT_SYMBOL vmlinux 0x5b4cf05a	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0x5b56860c	vm_munmap
++EXPORT_SYMBOL vmlinux 0x5b74568a	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x5b782e5f	tcp_req_err
++EXPORT_SYMBOL vmlinux 0x5b7bfbda	param_get_uint
++EXPORT_SYMBOL vmlinux 0x5b8fd6ce	dget_parent
++EXPORT_SYMBOL vmlinux 0x5b9828c5	dma_spin_lock
++EXPORT_SYMBOL vmlinux 0x5baec765	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0x5bb094b6	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x5bc10524	printk_emit
++EXPORT_SYMBOL vmlinux 0x5bd02244	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x5c200574	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0x5c3221be	generic_file_open
++EXPORT_SYMBOL vmlinux 0x5c37f319	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x5c5ac9dd	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x5c6400e5	__lock_page
++EXPORT_SYMBOL vmlinux 0x5c7c5308	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0x5c8cc638	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0x5c9846e3	mipi_dsi_dcs_exit_sleep_mode
++EXPORT_SYMBOL vmlinux 0x5cb04a27	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x5cdce1ed	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0x5cf30e10	__debugger_ipi
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5d1646a0	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x5d549f36	follow_down_one
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d58a832	compat_mc_setsockopt
++EXPORT_SYMBOL vmlinux 0x5d8dea6f	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0x5d93ebdb	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x5dc98035	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0x5dd1dffe	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0x5dd970c7	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0x5ddaed9e	mipi_dsi_generic_write
++EXPORT_SYMBOL vmlinux 0x5e00c0fb	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0x5e21cd91	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0x5e21e706	mipi_dsi_host_register
++EXPORT_SYMBOL vmlinux 0x5e336987	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x5e3a8a9c	__wake_up
++EXPORT_SYMBOL vmlinux 0x5e3bbe51	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x5e7441e0	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0x5e7701a3	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0x5e800f90	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x5e8105f0	param_ops_int
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5eb2f074	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0x5ecdc458	kobject_get
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5ed315e5	param_set_invbool
++EXPORT_SYMBOL vmlinux 0x5eddb914	lockref_put_return
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f042bc3	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x5f04fedf	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f0b0b85	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x5f16c2f0	mipi_dsi_dcs_get_pixel_format
++EXPORT_SYMBOL vmlinux 0x5f393883	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x5f3d5db9	da903x_query_status
++EXPORT_SYMBOL vmlinux 0x5f46544b	audit_log
++EXPORT_SYMBOL vmlinux 0x5f587f6d	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0x5f5c0a8b	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0x5f8a2728	isa_io_base
++EXPORT_SYMBOL vmlinux 0x5f9203a4	mipi_dsi_dcs_get_power_mode
++EXPORT_SYMBOL vmlinux 0x5f99b18f	mmc_of_parse_voltage
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x5fdc392f	fb_class
++EXPORT_SYMBOL vmlinux 0x5feba23b	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x602a0d20	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x60454b05	vio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x605e0a5e	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0x605e53ea	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x6067998d	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x6069cfe6	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x60717ed0	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x6095199d	reservation_object_reserve_shared
++EXPORT_SYMBOL vmlinux 0x60953c5f	ip_defrag
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60cfd910	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0x60dc285d	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x60f6700e	dst_init
++EXPORT_SYMBOL vmlinux 0x6101b261	tty_write_room
++EXPORT_SYMBOL vmlinux 0x610698ac	nf_log_unset
++EXPORT_SYMBOL vmlinux 0x610766f9	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x610c52fc	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x612eb2d3	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0x61411226	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x614bb773	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x616108a2	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0x618911fc	numa_node
++EXPORT_SYMBOL vmlinux 0x619571e9	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0x61958ff4	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0x619cb7dd	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x61a73fb9	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0x61abd4db	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x61af48b8	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0x61b380cc	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61bc7bc5	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0x61e19b4f	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x61eef2c9	_insb
++EXPORT_SYMBOL vmlinux 0x61ef6170	__tracepoint_fence_emit
++EXPORT_SYMBOL vmlinux 0x62069d0c	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x62178c5e	devm_memremap
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x622f956e	pci_get_class
++EXPORT_SYMBOL vmlinux 0x6238060f	bio_reset
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x62979f5a	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x62b9e52b	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0x62c9518b	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0x62cde0d3	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x62d24f6b	simple_write_end
++EXPORT_SYMBOL vmlinux 0x62de1b26	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x62fa7f49	proc_create_data
++EXPORT_SYMBOL vmlinux 0x63097e0b	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x63396aec	__debugger_break_match
++EXPORT_SYMBOL vmlinux 0x634c7441	input_register_device
++EXPORT_SYMBOL vmlinux 0x6372fedd	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x6373e8c0	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x637c6721	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x638e6a28	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x6391e070	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0x639f592b	param_ops_byte
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63b1ce10	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0x63b28c3e	dma_set_mask
++EXPORT_SYMBOL vmlinux 0x63b657fe	devm_free_irq
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63c5bbd6	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0x63ccbc31	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0x63cf18b3	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x63d60503	d_move
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x6410a3a1	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x64351118	serio_open
++EXPORT_SYMBOL vmlinux 0x64397836	textsearch_register
++EXPORT_SYMBOL vmlinux 0x644764b2	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x6449b54d	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0x644e9b12	agp_generic_create_gatt_table
++EXPORT_SYMBOL vmlinux 0x64835008	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0x6494c5b4	vme_dma_list_free
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x649ab52e	revalidate_disk
++EXPORT_SYMBOL vmlinux 0x64b0ec09	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0x64bbc288	string_unescape
++EXPORT_SYMBOL vmlinux 0x64cba5b9	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0x650b0da1	agp_generic_remove_memory
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x652ce9aa	nla_memcmp
++EXPORT_SYMBOL vmlinux 0x652d98e9	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x65621872	revert_creds
++EXPORT_SYMBOL vmlinux 0x656c1a0e	string_escape_mem
++EXPORT_SYMBOL vmlinux 0x65721b1c	param_get_bool
++EXPORT_SYMBOL vmlinux 0x6578ad5a	pci_disable_device
++EXPORT_SYMBOL vmlinux 0x658b9954	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x65ad14db	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x65aedb5b	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0x65bb58a2	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0x65c88733	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0x65cb4fa8	lease_modify
++EXPORT_SYMBOL vmlinux 0x65d9c3c7	generic_permission
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65e0d6d7	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x65eb74f1	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x6611e437	eth_header
++EXPORT_SYMBOL vmlinux 0x661bfd86	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x6622aec7	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x663eef7d	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x6665506e	phy_driver_register
++EXPORT_SYMBOL vmlinux 0x666c4dc2	kern_path
++EXPORT_SYMBOL vmlinux 0x66754be3	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x6678d97e	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x668cd502	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x66a21250	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0x66b46c03	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x66fe1024	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x66ff6398	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0x6700d6df	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x670f8ba1	input_set_keycode
++EXPORT_SYMBOL vmlinux 0x671cc1c0	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x673f815e	agp_bridges
++EXPORT_SYMBOL vmlinux 0x67591db9	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x677d81c4	mount_bdev
++EXPORT_SYMBOL vmlinux 0x6786095a	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x67a79aeb	get_user_pages
++EXPORT_SYMBOL vmlinux 0x67b52396	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67c13883	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x67c289ab	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0x67e34bff	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0x67e96467	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x67f3ecb1	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x683f23f3	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0x685e3aae	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0x68609857	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x6863831d	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x6887c057	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0x688befde	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x689f370d	frame_vector_to_pages
++EXPORT_SYMBOL vmlinux 0x68a174e5	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0x68ab3d08	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x68b598eb	input_reset_device
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x68c7d25d	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x68da45a2	register_quota_format
++EXPORT_SYMBOL vmlinux 0x68e799a7	i2c_master_send
++EXPORT_SYMBOL vmlinux 0x68fbb5d9	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0x694c19d2	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0x6963d85b	agp_collect_device_status
++EXPORT_SYMBOL vmlinux 0x6965e460	blk_get_request
++EXPORT_SYMBOL vmlinux 0x696d3e18	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x6999602d	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0x69a0ca7d	iowrite16be
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69add0e8	km_policy_expired
++EXPORT_SYMBOL vmlinux 0x69b8fafa	mntput
++EXPORT_SYMBOL vmlinux 0x69b9a794	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x69ce08cf	pci_request_regions
++EXPORT_SYMBOL vmlinux 0x69f2346a	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0x69f52034	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a287e86	set_page_dirty
++EXPORT_SYMBOL vmlinux 0x6a332ea5	pci_get_device
++EXPORT_SYMBOL vmlinux 0x6a4a8438	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x6a5570ec	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a5fa363	sigprocmask
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a89f896	param_array_ops
++EXPORT_SYMBOL vmlinux 0x6a8fe81b	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x6ac773cb	lock_rename
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6acb973d	iowrite32be
++EXPORT_SYMBOL vmlinux 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b5dfe73	__debugger_bpt
++EXPORT_SYMBOL vmlinux 0x6b640864	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6b66c889	fence_free
++EXPORT_SYMBOL vmlinux 0x6b6ce73a	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x6b7d2e56	vga_tryget
++EXPORT_SYMBOL vmlinux 0x6b80959e	__vfs_read
++EXPORT_SYMBOL vmlinux 0x6b93c24c	phy_suspend
++EXPORT_SYMBOL vmlinux 0x6bbe5fcd	of_graph_parse_endpoint
++EXPORT_SYMBOL vmlinux 0x6bbe75e7	elevator_change
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bc5fc5c	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x6bc701ba	ps2_init
++EXPORT_SYMBOL vmlinux 0x6bd2b087	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6bdfaca6	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c0b67b4	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0x6c1026fc	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x6c380732	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0x6c421b41	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c7cc840	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x6c87333f	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x6c9c8079	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0x6c9dde09	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x6c9ed7e6	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0x6cb181fb	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x6ccd8ce6	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0x6cdc5781	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0x6ce22996	__register_chrdev
++EXPORT_SYMBOL vmlinux 0x6ce6d234	register_key_type
++EXPORT_SYMBOL vmlinux 0x6cfd92de	find_vma
++EXPORT_SYMBOL vmlinux 0x6cfdaffd	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0x6d0157ac	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0x6d02515e	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d209b4c	phy_device_create
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d2f549d	md_update_sb
++EXPORT_SYMBOL vmlinux 0x6d3d8687	skb_put
++EXPORT_SYMBOL vmlinux 0x6d63edb6	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x6d84f99a	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0x6da73f3e	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0x6da928f4	_insw_ns
++EXPORT_SYMBOL vmlinux 0x6dafbc6f	kern_path_create
++EXPORT_SYMBOL vmlinux 0x6dc9df29	get_super
++EXPORT_SYMBOL vmlinux 0x6ddba82a	compat_tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6e13f19d	vme_bus_num
++EXPORT_SYMBOL vmlinux 0x6e3c8fc4	file_remove_privs
++EXPORT_SYMBOL vmlinux 0x6e4939fe	get_gendisk
++EXPORT_SYMBOL vmlinux 0x6e4d1d44	d_genocide
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e7d4f0b	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x6e7f0fd2	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x6e8ae907	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0x6e8dad48	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0x6e94c609	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0x6e99390c	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6eb61ca7	agp_bridge
++EXPORT_SYMBOL vmlinux 0x6ecc5aa8	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0x6eda024b	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0x6ee0c799	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0x6f0fa557	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f241a72	submit_bh
++EXPORT_SYMBOL vmlinux 0x6f3aa7a9	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0x6f3ccb74	compat_ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x6f4a3377	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0x6f7b4af5	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0x6f81e3a5	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0x6f88effb	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x6f89ab0c	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fc35ca3	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6fecd212	sk_free
++EXPORT_SYMBOL vmlinux 0x6ff2a80f	of_graph_get_remote_port_parent
++EXPORT_SYMBOL vmlinux 0x70129ab6	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0x701b2fdf	release_pages
++EXPORT_SYMBOL vmlinux 0x702606f1	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7052ec4b	of_gpio_simple_xlate
++EXPORT_SYMBOL vmlinux 0x7054a3e4	request_dma
++EXPORT_SYMBOL vmlinux 0x706bc1b8	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x706d1498	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x70e54210	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x70f6a5b5	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x70f96f88	glob_match
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x715c7e54	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0x71606e93	nvdimm_bus_lock
++EXPORT_SYMBOL vmlinux 0x7162613c	of_find_property
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x71714d61	genphy_update_link
++EXPORT_SYMBOL vmlinux 0x7174f139	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0x71852321	ptp_clock_index
++EXPORT_SYMBOL vmlinux 0x719ace7f	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x71a1afa7	free_task
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71aca86c	agp_free_memory
++EXPORT_SYMBOL vmlinux 0x71d68e7c	igrab
++EXPORT_SYMBOL vmlinux 0x71dc6626	pci_find_bus
++EXPORT_SYMBOL vmlinux 0x71de1dd8	neigh_xmit
++EXPORT_SYMBOL vmlinux 0x71ee0b02	param_ops_bint
++EXPORT_SYMBOL vmlinux 0x7204080a	i8042_install_filter
++EXPORT_SYMBOL vmlinux 0x722ea05a	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0x724ca365	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x724e4248	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0x726bb738	md_check_recovery
++EXPORT_SYMBOL vmlinux 0x726d3c8f	dcb_getapp
++EXPORT_SYMBOL vmlinux 0x7271bb72	deactivate_super
++EXPORT_SYMBOL vmlinux 0x729fffe0	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x72a5137b	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x72b243d4	free_dma
++EXPORT_SYMBOL vmlinux 0x72b6fa56	fence_wait_timeout
++EXPORT_SYMBOL vmlinux 0x72c98139	__arch_hweight64
++EXPORT_SYMBOL vmlinux 0x72ceb068	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x72dd3c76	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x72e8e294	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x72f12df9	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0x730f776e	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x730fcf44	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x731a747a	pci_io_base
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x734858c6	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0x735d8503	add_wait_queue
++EXPORT_SYMBOL vmlinux 0x7362514d	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0x73710a3e	dqstats
++EXPORT_SYMBOL vmlinux 0x73776b4f	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x737c9942	padata_free
++EXPORT_SYMBOL vmlinux 0x737ee111	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x73b6043b	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x73b916bc	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x73bc8c96	alloc_disk
++EXPORT_SYMBOL vmlinux 0x7404be78	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x7408acfc	file_update_time
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x741f9da6	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0x74318636	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x74404d85	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0x74478287	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0x747195f0	hdmi_vendor_infoframe_init
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x74941d58	input_set_capability
++EXPORT_SYMBOL vmlinux 0x749965c6	dquot_resume
++EXPORT_SYMBOL vmlinux 0x749ea464	seq_lseek
++EXPORT_SYMBOL vmlinux 0x74a04b45	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74c6b1a8	srp_rport_put
++EXPORT_SYMBOL vmlinux 0x74cd546c	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74e68050	of_mdiobus_register
++EXPORT_SYMBOL vmlinux 0x74ee5181	compat_sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x74f666d0	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x75124d80	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x751a115b	__devm_release_region
++EXPORT_SYMBOL vmlinux 0x752d94b9	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x7532588a	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0x7536ab8f	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x7538b132	agp_off
++EXPORT_SYMBOL vmlinux 0x75745c33	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x757a5922	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x758c16f9	cdev_add
++EXPORT_SYMBOL vmlinux 0x7597580b	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x7598eeb3	tcf_register_action
++EXPORT_SYMBOL vmlinux 0x75994700	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0x75995d1f	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x759ead7f	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x75a292c4	mipi_dsi_dcs_set_display_off
++EXPORT_SYMBOL vmlinux 0x75b7ef66	save_mount_options
++EXPORT_SYMBOL vmlinux 0x75bd717a	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75be6702	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0x75ce7101	blk_peek_request
++EXPORT_SYMBOL vmlinux 0x75f14ced	ibmebus_register_driver
++EXPORT_SYMBOL vmlinux 0x75f670fa	cad_pid
++EXPORT_SYMBOL vmlinux 0x7604c833	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x761ccd64	sock_wfree
++EXPORT_SYMBOL vmlinux 0x7628673c	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x762c8676	__vio_register_driver
++EXPORT_SYMBOL vmlinux 0x763f916a	nvdimm_namespace_common_probe
++EXPORT_SYMBOL vmlinux 0x7645af6f	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0x7645e571	srp_rport_get
++EXPORT_SYMBOL vmlinux 0x76468c3e	security_path_link
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x76487198	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x764b1fd1	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x765ff474	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x76632489	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0x7663e1ce	iget5_locked
++EXPORT_SYMBOL vmlinux 0x7674d817	inode_init_owner
++EXPORT_SYMBOL vmlinux 0x7677bb48	of_get_next_child
++EXPORT_SYMBOL vmlinux 0x767cefeb	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0x7688bb95	uart_match_port
++EXPORT_SYMBOL vmlinux 0x76a57587	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0x76b59b33	cpu_sibling_map
++EXPORT_SYMBOL vmlinux 0x76c51545	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76f3977a	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x771e32cd	netdev_update_features
++EXPORT_SYMBOL vmlinux 0x773fa409	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x77526ac4	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0x776116a1	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0x7765fa33	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x776ae4af	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77a8141c	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0x77b2227d	mapping_tagged
++EXPORT_SYMBOL vmlinux 0x77b81565	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77c143cd	tcp_prot
++EXPORT_SYMBOL vmlinux 0x77cdeb6d	have_submounts
++EXPORT_SYMBOL vmlinux 0x77d3f48b	tso_build_data
++EXPORT_SYMBOL vmlinux 0x77ed1345	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x77f737ea	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x782ed6d3	param_set_ushort
++EXPORT_SYMBOL vmlinux 0x7830b04f	hvc_put_chars
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x7846af3e	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x786a4154	__bforget
++EXPORT_SYMBOL vmlinux 0x787b0a53	seq_write
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x789bcae1	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0x789d556d	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0x78a9e905	_numa_mem_
++EXPORT_SYMBOL vmlinux 0x78d82aca	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78f629ba	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x78f72384	register_qdisc
++EXPORT_SYMBOL vmlinux 0x78fe1cd0	devm_gpiod_put_array
++EXPORT_SYMBOL vmlinux 0x791537e0	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0x7916fd56	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x792958e5	of_find_net_device_by_node
++EXPORT_SYMBOL vmlinux 0x793295f1	pci_bus_type
++EXPORT_SYMBOL vmlinux 0x79650800	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0x796bc4b6	kfree_put_link
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x797a99ef	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0x7984eefc	key_update
++EXPORT_SYMBOL vmlinux 0x7985d043	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x7992c5c9	of_get_next_available_child
++EXPORT_SYMBOL vmlinux 0x7995e779	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0x799b3ca2	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0x79a33f85	vme_get_size
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79b193e7	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x79b7c8e4	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x79f7f87a	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0x7a27d24a	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x7a398131	of_find_matching_node_and_match
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a6cdedc	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7a7cc38f	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x7a82cd2c	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x7a8ccf54	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7ab411d5	pci_release_region
++EXPORT_SYMBOL vmlinux 0x7ab72e76	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0x7ab76181	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7ada5bb7	secpath_dup
++EXPORT_SYMBOL vmlinux 0x7aea5807	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x7aecf403	km_state_notify
++EXPORT_SYMBOL vmlinux 0x7b10f1c3	devm_devfreq_unregister_opp_notifier
++EXPORT_SYMBOL vmlinux 0x7b16235f	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b2aef6c	__krealloc
++EXPORT_SYMBOL vmlinux 0x7b3c7b83	msi_bitmap_free_hwirqs
++EXPORT_SYMBOL vmlinux 0x7b4183ac	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0x7b5a44f5	bdevname
++EXPORT_SYMBOL vmlinux 0x7b5d1b43	single_release
++EXPORT_SYMBOL vmlinux 0x7b637e28	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0x7b6ca6e5	get_phy_device
++EXPORT_SYMBOL vmlinux 0x7b7f0c99	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x7b887713	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x7b8afe3b	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0x7b9041df	seq_puts
++EXPORT_SYMBOL vmlinux 0x7b9ed868	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0x7ba917d4	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0x7bafad19	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0x7bb756cc	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x7bd3a3e2	ata_print_version
++EXPORT_SYMBOL vmlinux 0x7bd82113	dump_emit
++EXPORT_SYMBOL vmlinux 0x7bf91c79	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0x7c003aef	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x7c132043	mipi_dsi_dcs_write
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c14f1f6	d_obtain_root
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c1897c2	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0x7c28d080	agp_alloc_page_array
++EXPORT_SYMBOL vmlinux 0x7c28d867	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0x7c2d098f	krealloc
++EXPORT_SYMBOL vmlinux 0x7c449fa4	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c4ac635	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c6d7fed	register_sysctl
++EXPORT_SYMBOL vmlinux 0x7c7a3359	sk_capable
++EXPORT_SYMBOL vmlinux 0x7c7c9940	devm_gpiod_get_array
++EXPORT_SYMBOL vmlinux 0x7c82ba27	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0x7c878dc9	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0x7c898a8d	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x7c8faa24	fbcon_set_rotate
++EXPORT_SYMBOL vmlinux 0x7c9479ee	agp_generic_alloc_page
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cd89637	of_graph_get_endpoint_by_regs
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7cee7f3a	mmc_gpiod_request_cd
++EXPORT_SYMBOL vmlinux 0x7cf35220	vme_master_free
++EXPORT_SYMBOL vmlinux 0x7d08eb02	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d3c180c	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x7d41b07b	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0x7d507943	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x7d518284	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0x7d5b2fc4	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0x7d5e358b	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0x7d6d2ddd	__free_pages
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d9514c1	node_to_cpumask_map
++EXPORT_SYMBOL vmlinux 0x7d951c60	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x7d96a621	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0x7da90d3b	napi_disable
++EXPORT_SYMBOL vmlinux 0x7dc97879	rtas_get_error_log_max
++EXPORT_SYMBOL vmlinux 0x7dd5306d	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0x7de5b44d	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7e1c9d6b	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x7e226fa6	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x7e29a426	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x7e307f15	get_io_context
++EXPORT_SYMBOL vmlinux 0x7e46a578	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0x7e4c537e	start_tty
++EXPORT_SYMBOL vmlinux 0x7e5a7311	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0x7e79acbc	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0x7e7cb098	finish_no_open
++EXPORT_SYMBOL vmlinux 0x7e805720	devm_memunmap
++EXPORT_SYMBOL vmlinux 0x7e88da1a	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x7ea38ec4	unlock_page
++EXPORT_SYMBOL vmlinux 0x7eaab944	pnv_pci_get_npu_dev
++EXPORT_SYMBOL vmlinux 0x7eb3bfea	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x7ec01d22	pmem_should_map_pages
++EXPORT_SYMBOL vmlinux 0x7ec6b883	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0x7ecf0205	mntget
++EXPORT_SYMBOL vmlinux 0x7ee31640	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f0370fe	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x7f20a568	seq_open
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f263ed9	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x7f295612	fb_show_logo
++EXPORT_SYMBOL vmlinux 0x7f35ca84	vfs_readf
++EXPORT_SYMBOL vmlinux 0x7f4473bb	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0x7f546887	fb_prepare_logo
++EXPORT_SYMBOL vmlinux 0x7f574cd7	genphy_setup_forced
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f6a0095	vga_get
++EXPORT_SYMBOL vmlinux 0x7f75c967	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0x7f8ea13e	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x7f9fe09b	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0x7fbd10d2	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fe38f48	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x7ff5383e	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x8012e284	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x802c139a	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0x803540b4	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0x80446e5b	phy_attach
++EXPORT_SYMBOL vmlinux 0x80665671	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0x8068c15c	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x8071d1a8	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0x80791a8c	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0x807ed8a1	of_phy_attach
++EXPORT_SYMBOL vmlinux 0x80802bbe	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0x80871574	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0x809eee07	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0x80a20860	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x80b4e06a	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0x80bd508e	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80ce0b61	key_unlink
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x810585e1	unlock_rename
++EXPORT_SYMBOL vmlinux 0x811fadba	agp_backend_release
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x81533963	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x817acd31	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0x818da6ea	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0x81a07f4e	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x81c0a84f	rtas_set_indicator
++EXPORT_SYMBOL vmlinux 0x81c5c88c	of_translate_address
++EXPORT_SYMBOL vmlinux 0x81d0a205	__mdiobus_register
++EXPORT_SYMBOL vmlinux 0x81d29d59	__check_sticky
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81dd8a93	iget_failed
++EXPORT_SYMBOL vmlinux 0x81ee78ea	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x81f25ef7	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x82049a07	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x820e1879	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0x822c5a8c	fence_add_callback
++EXPORT_SYMBOL vmlinux 0x822f510f	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0x82303481	pps_lookup_dev
++EXPORT_SYMBOL vmlinux 0x82413b03	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0x82458f7f	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x824a3acc	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x825d09d2	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0x825ea1bd	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0x82692065	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x82742a0d	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82871b60	dmt_modes
++EXPORT_SYMBOL vmlinux 0x82a613d0	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82c4659b	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x82ce2f6a	__kernel_write
++EXPORT_SYMBOL vmlinux 0x82d6b0d0	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x82e5a238	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x82e85ff3	sock_create
++EXPORT_SYMBOL vmlinux 0x82ea3751	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x832fb64c	from_kuid
++EXPORT_SYMBOL vmlinux 0x8330b257	dev_notice
++EXPORT_SYMBOL vmlinux 0x8373d9aa	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x8376aace	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0x838a0530	dev_alert
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x83968671	is_bad_inode
++EXPORT_SYMBOL vmlinux 0x8396fa38	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x83a37c81	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0x83a5d8cb	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0x83a655e8	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x83f156b5	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x841dc298	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0x844e3767	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0x848c35ea	open_exec
++EXPORT_SYMBOL vmlinux 0x849d971d	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x84a6783b	dput
++EXPORT_SYMBOL vmlinux 0x84b7e5cf	proto_register
++EXPORT_SYMBOL vmlinux 0x84bd69bf	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x84d25c84	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x84df6f4e	vme_register_error_handler
++EXPORT_SYMBOL vmlinux 0x84e04fe8	tty_port_put
++EXPORT_SYMBOL vmlinux 0x84e062d7	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0x84f625f7	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x851e3023	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x852a0745	user_revoke
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x856b8404	do_truncate
++EXPORT_SYMBOL vmlinux 0x8588ac19	get_task_io_context
++EXPORT_SYMBOL vmlinux 0x8597eb47	plpar_hcall
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85bb1fe4	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0x85d227f7	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x860714c6	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x862d30e3	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x86366b87	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0x863c8067	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0x864ce729	__block_write_begin
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x8675b120	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86a4a752	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0x86b8147f	dev_close
++EXPORT_SYMBOL vmlinux 0x86bfaf5e	kdb_current_task
++EXPORT_SYMBOL vmlinux 0x86c5e175	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x86d170fd	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0x86db1cbb	rtas_flash_term_hook
++EXPORT_SYMBOL vmlinux 0x86ddc35f	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x86e54f28	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0x86e7d36a	ppp_input
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x8703e88a	of_get_ddr_timings
++EXPORT_SYMBOL vmlinux 0x870c5479	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0x871b1525	skb_split
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x872f32d2	dev_activate
++EXPORT_SYMBOL vmlinux 0x873a53ea	__arch_hweight8
++EXPORT_SYMBOL vmlinux 0x875167a8	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x8753e862	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x87553a40	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0x87790cc8	param_get_int
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x8794da9e	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0x879c6d6f	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x87bcbb50	up_write
++EXPORT_SYMBOL vmlinux 0x8805d773	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x882592fc	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0x882db37f	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0x883cfd0a	import_iovec
++EXPORT_SYMBOL vmlinux 0x885bb0db	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0x8860186a	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x887fa47e	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x888a9d2b	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0x8893ca0d	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x88ac7cca	fb_blank
++EXPORT_SYMBOL vmlinux 0x88b26517	pps_unregister_source
++EXPORT_SYMBOL vmlinux 0x88b335ea	validate_sp
++EXPORT_SYMBOL vmlinux 0x88b50645	nf_log_trace
++EXPORT_SYMBOL vmlinux 0x88e3d2ee	make_kuid
++EXPORT_SYMBOL vmlinux 0x88f79178	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x890eb1f4	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x89128eb5	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x89151268	iterate_dir
++EXPORT_SYMBOL vmlinux 0x891fbb10	mempool_destroy
++EXPORT_SYMBOL vmlinux 0x892de3fb	__nla_put
++EXPORT_SYMBOL vmlinux 0x893032af	sync_filesystem
++EXPORT_SYMBOL vmlinux 0x8933a8da	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x895108f3	proc_dostring
++EXPORT_SYMBOL vmlinux 0x895577b0	numa_cpu_lookup_table
++EXPORT_SYMBOL vmlinux 0x89684bf1	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x896baab8	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0x89797060	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x897a0b3e	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0x8980fb0b	netdev_crit
++EXPORT_SYMBOL vmlinux 0x89a21246	genphy_suspend
++EXPORT_SYMBOL vmlinux 0x89a45044	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89bc8893	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x8a107aaa	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0x8a15e68e	phy_stop
++EXPORT_SYMBOL vmlinux 0x8a18c0d5	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x8a1901e6	simple_setattr
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a58dfb5	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0x8a5aab2d	param_ops_long
++EXPORT_SYMBOL vmlinux 0x8a5f6b33	kernel_listen
++EXPORT_SYMBOL vmlinux 0x8a66660e	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0x8a6af65c	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x8a72e601	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a84a6e5	netdev_notice
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8acade25	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0x8ada39e1	dst_release
++EXPORT_SYMBOL vmlinux 0x8adf5d15	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x8afe4a5a	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x8b2cfb0e	path_nosuid
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b7c336a	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b9a9668	vfs_read
++EXPORT_SYMBOL vmlinux 0x8be11a5c	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x8bf2ae1f	fsl_lbc_addr
++EXPORT_SYMBOL vmlinux 0x8c183cbe	iowrite16
++EXPORT_SYMBOL vmlinux 0x8c249924	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0x8c2f28ad	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0x8c3597bc	km_is_alive
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c972204	vme_dma_list_add
++EXPORT_SYMBOL vmlinux 0x8ca6bf60	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0x8cc1d777	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x8cc79cab	iowrite16_rep
++EXPORT_SYMBOL vmlinux 0x8cc9fc06	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0x8ceb6273	arp_send
++EXPORT_SYMBOL vmlinux 0x8cf9911f	__vfs_write
++EXPORT_SYMBOL vmlinux 0x8cfaacc6	consume_skb
++EXPORT_SYMBOL vmlinux 0x8d009eba	set_disk_ro
++EXPORT_SYMBOL vmlinux 0x8d015dd4	__bswapdi2
++EXPORT_SYMBOL vmlinux 0x8d155294	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x8d361825	sget
++EXPORT_SYMBOL vmlinux 0x8d44698f	is_nvdimm_bus_locked
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d7fb5a5	nd_region_release_lane
++EXPORT_SYMBOL vmlinux 0x8d944cbb	copy_in_user
++EXPORT_SYMBOL vmlinux 0x8da76c59	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0x8dad5b4b	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x8dadcc6a	gen_pool_dma_alloc
++EXPORT_SYMBOL vmlinux 0x8dbdc2cb	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0x8dc86b40	dquot_drop
++EXPORT_SYMBOL vmlinux 0x8ddbbf82	copy_to_iter
++EXPORT_SYMBOL vmlinux 0x8de0b5ac	mempool_create
++EXPORT_SYMBOL vmlinux 0x8df1482b	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x8df92f66	memchr_inv
++EXPORT_SYMBOL vmlinux 0x8df97bd2	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x8dff40a6	input_unregister_device
++EXPORT_SYMBOL vmlinux 0x8e09ea56	bio_flush_dcache_pages
++EXPORT_SYMBOL vmlinux 0x8e21e64d	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0x8e2514be	fbcon_rotate_ccw
++EXPORT_SYMBOL vmlinux 0x8e67a6a2	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e7d7cf9	elevator_init
++EXPORT_SYMBOL vmlinux 0x8ea842bf	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x8eb8476a	of_dev_put
++EXPORT_SYMBOL vmlinux 0x8ec04552	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0x8ec4604a	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x8ed0e13b	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0x8ed9f6d6	down_read
++EXPORT_SYMBOL vmlinux 0x8f1f5952	vme_unregister_driver
++EXPORT_SYMBOL vmlinux 0x8f289127	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x8f2c5907	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x8f645ee4	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x8f85f835	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x8f976ed3	iterate_mounts
++EXPORT_SYMBOL vmlinux 0x8fc15bf6	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0x8fc59f9b	rtas_offline_cpus_mask
++EXPORT_SYMBOL vmlinux 0x8fc8899c	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0x8fdc9af6	param_set_short
++EXPORT_SYMBOL vmlinux 0x900caca3	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0x900d2a1f	msi_bitmap_alloc_hwirqs
++EXPORT_SYMBOL vmlinux 0x901f3b6b	param_ops_short
++EXPORT_SYMBOL vmlinux 0x9023a30a	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x90349b13	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0x90448829	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x9045d202	of_parse_phandle
++EXPORT_SYMBOL vmlinux 0x9045d322	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0x904da605	bio_add_page
++EXPORT_SYMBOL vmlinux 0x90559869	of_graph_get_port_by_id
++EXPORT_SYMBOL vmlinux 0x90895663	inet_put_port
++EXPORT_SYMBOL vmlinux 0x909a426e	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0x90e16f18	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0x90e8d969	blk_start_request
++EXPORT_SYMBOL vmlinux 0x9104b197	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x910b6393	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0x910facd1	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x9118bb9b	dev_warn
++EXPORT_SYMBOL vmlinux 0x912557ce	rtas_busy_delay
++EXPORT_SYMBOL vmlinux 0x9135c71c	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0x91452caa	keyring_alloc
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x91515d14	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0x91573126	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x915e1208	tb_ticks_per_usec
++EXPORT_SYMBOL vmlinux 0x9166fada	strncpy
++EXPORT_SYMBOL vmlinux 0x9168c033	rtas_get_sensor
++EXPORT_SYMBOL vmlinux 0x916b5fc9	of_mdio_parse_addr
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x9176177a	bd_set_size
++EXPORT_SYMBOL vmlinux 0x917b578b	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x91840e80	invalidate_partition
++EXPORT_SYMBOL vmlinux 0x91862fa3	dma_iommu_ops
++EXPORT_SYMBOL vmlinux 0x918e4aaa	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0x919d1163	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x91ac822f	vscnprintf
++EXPORT_SYMBOL vmlinux 0x91d379f9	i2c_release_client
++EXPORT_SYMBOL vmlinux 0x91d37f68	dev_open
++EXPORT_SYMBOL vmlinux 0x91d7e82a	compat_sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x91e46711	key_revoke
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x91fe89cc	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x920baa95	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0x92293940	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0x922f7ab4	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x92614da7	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0x926aa969	agp_copy_info
++EXPORT_SYMBOL vmlinux 0x926bfb7f	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0x926d99b0	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x927de754	mach_pseries
++EXPORT_SYMBOL vmlinux 0x92861d00	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0x928b16b5	seq_release_private
++EXPORT_SYMBOL vmlinux 0x9291cd3b	memdup_user
++EXPORT_SYMBOL vmlinux 0x9291d615	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0x9296fac5	single_open_size
++EXPORT_SYMBOL vmlinux 0x929fc7fc	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92bf636b	of_device_register
++EXPORT_SYMBOL vmlinux 0x92e18bb7	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0x92ef8023	proc_symlink
++EXPORT_SYMBOL vmlinux 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL vmlinux 0x93022ba6	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x93124adb	keyring_search
++EXPORT_SYMBOL vmlinux 0x9322d9dd	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x93472fce	generic_show_options
++EXPORT_SYMBOL vmlinux 0x9354fcde	ibmebus_free_irq
++EXPORT_SYMBOL vmlinux 0x936e8100	md_reload_sb
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x9378a72a	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93d0857c	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x93da03ed	dma_direct_ops
++EXPORT_SYMBOL vmlinux 0x93da2538	devm_gen_pool_create
++EXPORT_SYMBOL vmlinux 0x93f2d2de	param_set_long
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x94102717	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x9419d0d8	dma_set_coherent_mask
++EXPORT_SYMBOL vmlinux 0x941e8437	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0x94346d37	nonseekable_open
++EXPORT_SYMBOL vmlinux 0x94462f5e	cdev_init
++EXPORT_SYMBOL vmlinux 0x94534258	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0x945882c4	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94987995	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x949b9361	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x94a5cc3b	__find_get_block
++EXPORT_SYMBOL vmlinux 0x94e19a61	inc_nlink
++EXPORT_SYMBOL vmlinux 0x94e42605	of_mm_gpiochip_add
++EXPORT_SYMBOL vmlinux 0x94f449d7	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0x94f92ab3	dump_skip
++EXPORT_SYMBOL vmlinux 0x950a851e	nvm_end_io
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x9514151a	_mcount
++EXPORT_SYMBOL vmlinux 0x9519a168	block_write_end
++EXPORT_SYMBOL vmlinux 0x9521e509	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0x9524b0ae	_outsb
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x9546bf1d	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0x9557e80c	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x955aa9c9	notify_change
++EXPORT_SYMBOL vmlinux 0x956bc1ee	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0x9575f003	of_node_put
++EXPORT_SYMBOL vmlinux 0x95e18864	devm_get_gpiod_from_child
++EXPORT_SYMBOL vmlinux 0x95ea8d5a	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0x95f0bbb3	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x961908c2	security_path_unlink
++EXPORT_SYMBOL vmlinux 0x961ebf2e	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0x9621a819	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0x96230f47	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0x96333ffd	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0x966648df	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0x967a3bae	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0x968e6f0b	tty_kref_put
++EXPORT_SYMBOL vmlinux 0x969987fc	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0x96a029bd	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x96a083d4	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0x96b29254	strncasecmp
++EXPORT_SYMBOL vmlinux 0x96bc0fa5	to_ndd
++EXPORT_SYMBOL vmlinux 0x96c3b7c8	blk_register_region
++EXPORT_SYMBOL vmlinux 0x96c3c61b	mmc_free_host
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96f8e99e	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x9702f99d	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0x970f055e	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x9743ce70	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0x9748927f	_outsw_ns
++EXPORT_SYMBOL vmlinux 0x974c7cb5	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x9754e0e5	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x9758e064	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0x9762c6f2	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x977f5f28	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0x97868aef	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x97a57333	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0x97af46c7	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0x97afba7b	proc_douintvec
++EXPORT_SYMBOL vmlinux 0x97b4238c	param_set_bint
++EXPORT_SYMBOL vmlinux 0x97ba1af0	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0x97ebf39b	phy_disconnect
++EXPORT_SYMBOL vmlinux 0x97ed774e	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0x97f03d6f	vio_cmo_entitlement_update
++EXPORT_SYMBOL vmlinux 0x98018886	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x981d6f97	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x9821221f	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x9829fc11	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0x98314c3a	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0x9835592b	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x987fc124	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x9893855d	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0x98ab9953	misc_deregister
++EXPORT_SYMBOL vmlinux 0x98b64c0b	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x98b9f163	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0x98bc2adb	dquot_acquire
++EXPORT_SYMBOL vmlinux 0x98bdc3ef	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0x98c68c41	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x98c82888	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0x98cf60b3	strlen
++EXPORT_SYMBOL vmlinux 0x98d41c04	free_page_put_link
++EXPORT_SYMBOL vmlinux 0x98ebc98f	posix_test_lock
++EXPORT_SYMBOL vmlinux 0x98f113bf	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x99195078	vsnprintf
++EXPORT_SYMBOL vmlinux 0x9931a5c1	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x9939eba0	backlight_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x99498a85	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x995d7ad3	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x995d9b5e	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0x99665ec7	nd_region_to_nstype
++EXPORT_SYMBOL vmlinux 0x99848f3c	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0x998d52c9	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x9992f62a	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x9996b742	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99afe916	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0x99bb68ce	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x99c9b991	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d3a43c	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x99daa9bf	try_offline_node
++EXPORT_SYMBOL vmlinux 0x99e8442c	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x99f5836d	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0x99ffeee6	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a225cf1	fb_find_mode
++EXPORT_SYMBOL vmlinux 0x9a6d3f46	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0x9a9f851e	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0x9acddbc5	of_find_node_with_property
++EXPORT_SYMBOL vmlinux 0x9ad3eaf9	netdev_info
++EXPORT_SYMBOL vmlinux 0x9ada87ff	pnv_phb_to_cxl_mode
++EXPORT_SYMBOL vmlinux 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL vmlinux 0x9af9c14f	flush_dcache_icache_page
++EXPORT_SYMBOL vmlinux 0x9b0fa0c1	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x9b1fbc43	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0x9b2a6b3b	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b53fc5f	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x9b7e85a6	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9ba90188	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0x9baa6595	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0x9bb6a733	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0x9bd343d2	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0x9bd87e8c	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c6de867	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0x9c6f7fa3	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x9ca62ec3	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cae36e4	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0x9cca084b	srp_start_tl_fail_timers
++EXPORT_SYMBOL vmlinux 0x9cd62a9c	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x9ce82285	input_grab_device
++EXPORT_SYMBOL vmlinux 0x9cf1a258	serio_reconnect
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d0ff847	of_find_all_nodes
++EXPORT_SYMBOL vmlinux 0x9d14983a	ppc_enable_pmcs
++EXPORT_SYMBOL vmlinux 0x9d23e8b1	kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d7a256c	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0x9d7ce8dd	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x9d94aa3f	set_wb_congested
++EXPORT_SYMBOL vmlinux 0x9d9dfc18	load_fp_state
++EXPORT_SYMBOL vmlinux 0x9da05e10	mipi_dsi_create_packet
++EXPORT_SYMBOL vmlinux 0x9dacd4bd	blkdev_get
++EXPORT_SYMBOL vmlinux 0x9dc05333	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x9decedb6	padata_alloc
++EXPORT_SYMBOL vmlinux 0x9dfeb89f	__mutex_init
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e2f8c90	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x9e34257e	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e5047a2	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x9e513c77	kernel_connect
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e665a18	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0x9e6db2ea	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e943de6	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0x9e97375d	rtas_busy_delay_time
++EXPORT_SYMBOL vmlinux 0x9e9d145c	sk_wait_data
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9ea09dd7	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9ed35e4e	__breadahead
++EXPORT_SYMBOL vmlinux 0x9ef05851	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x9efa42d1	seq_file_path
++EXPORT_SYMBOL vmlinux 0x9f04b912	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0x9f0a3a3d	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x9f17ae67	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0x9f1b2096	udp_ioctl
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f5a7af6	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0x9f5fd45d	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0x9f60e474	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x9f68b21f	__f_setown
++EXPORT_SYMBOL vmlinux 0x9f7c1be8	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0x9f81ce2a	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x9f889442	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x9f911629	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9faef447	ppc_md
++EXPORT_SYMBOL vmlinux 0x9fc00878	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x9fd19ee2	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9fe0156c	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x9ff4760b	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa0253a1c	km_query
++EXPORT_SYMBOL vmlinux 0xa02567f7	key_put
++EXPORT_SYMBOL vmlinux 0xa03ef066	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa0442fed	of_find_node_by_name
++EXPORT_SYMBOL vmlinux 0xa0472678	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa05a4d2c	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa0722e44	pci_domain_nr
++EXPORT_SYMBOL vmlinux 0xa0773c95	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0xa07a37f0	memchr
++EXPORT_SYMBOL vmlinux 0xa07c19d0	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0ff74d6	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa10944b4	pci_iomap
++EXPORT_SYMBOL vmlinux 0xa11c4f71	bdget
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa13c0b17	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa145c931	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0xa149974f	console_stop
++EXPORT_SYMBOL vmlinux 0xa1510278	sk_stream_error
++EXPORT_SYMBOL vmlinux 0xa15f3663	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0xa164fa5c	user_path_create
++EXPORT_SYMBOL vmlinux 0xa1830f32	scsi_register
++EXPORT_SYMBOL vmlinux 0xa1996710	nd_iostat_end
++EXPORT_SYMBOL vmlinux 0xa1a49781	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0xa1a5bcb8	page_put_link
++EXPORT_SYMBOL vmlinux 0xa1ae0a6f	md_write_start
++EXPORT_SYMBOL vmlinux 0xa1b75337	scsi_host_put
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1c99385	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0xa1dee5f1	frame_vector_create
++EXPORT_SYMBOL vmlinux 0xa1f8fe75	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0xa202a8e5	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa20d518f	bdget_disk
++EXPORT_SYMBOL vmlinux 0xa221b7d9	mem_section
++EXPORT_SYMBOL vmlinux 0xa238903d	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0xa25aeed1	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0xa2656206	follow_up
++EXPORT_SYMBOL vmlinux 0xa2843bb2	bio_advance
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa29849d1	del_gendisk
++EXPORT_SYMBOL vmlinux 0xa2a335bd	vme_alloc_consistent
++EXPORT_SYMBOL vmlinux 0xa2bbed37	crash_shutdown_register
++EXPORT_SYMBOL vmlinux 0xa2d156a2	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0xa2d6f7aa	iov_iter_init
++EXPORT_SYMBOL vmlinux 0xa2e1835e	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0xa2f1c992	_dev_info
++EXPORT_SYMBOL vmlinux 0xa2fabc52	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0xa2fdbcbe	fence_default_wait
++EXPORT_SYMBOL vmlinux 0xa30227f4	alloc_pages_current
++EXPORT_SYMBOL vmlinux 0xa303d1ff	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0xa303d8ca	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL vmlinux 0xa3202a7f	mipi_dsi_dcs_enter_sleep_mode
++EXPORT_SYMBOL vmlinux 0xa32b8faa	simple_rename
++EXPORT_SYMBOL vmlinux 0xa32e4090	param_ops_uint
++EXPORT_SYMBOL vmlinux 0xa33a0377	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0xa3405883	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0xa343b127	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0xa344557f	of_n_addr_cells
++EXPORT_SYMBOL vmlinux 0xa34cb2af	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0xa35e5992	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0xa36db3c0	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0xa38c0b24	redraw_screen
++EXPORT_SYMBOL vmlinux 0xa39b4cf2	udelay
++EXPORT_SYMBOL vmlinux 0xa3a818a9	vio_cmo_set_dev_desired
++EXPORT_SYMBOL vmlinux 0xa3abc422	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xa3ad70b4	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0xa3c597e3	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0xa3cba662	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0xa3da08e0	of_get_min_tck
++EXPORT_SYMBOL vmlinux 0xa3ef1254	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0xa3f88a9e	fasync_helper
++EXPORT_SYMBOL vmlinux 0xa4085a17	inet_accept
++EXPORT_SYMBOL vmlinux 0xa42be071	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0xa42c57b6	dump_truncate
++EXPORT_SYMBOL vmlinux 0xa4511467	crc16
++EXPORT_SYMBOL vmlinux 0xa4539dc6	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0xa4553ab2	neigh_destroy
++EXPORT_SYMBOL vmlinux 0xa45e6dd5	update_region
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa478df95	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0xa4a73473	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0xa4aa3cec	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0xa4b08294	kobject_put
++EXPORT_SYMBOL vmlinux 0xa4b94fea	iowrite8_rep
++EXPORT_SYMBOL vmlinux 0xa4bc96ed	param_get_long
++EXPORT_SYMBOL vmlinux 0xa4bcd6ed	vm_map_ram
++EXPORT_SYMBOL vmlinux 0xa4cdb971	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0xa4d4f0e6	global_cache_flush
++EXPORT_SYMBOL vmlinux 0xa4e5c641	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0xa541c0e6	flush_icache_user_range
++EXPORT_SYMBOL vmlinux 0xa549e310	dm_get_device
++EXPORT_SYMBOL vmlinux 0xa54bd793	fb_set_var
++EXPORT_SYMBOL vmlinux 0xa551cfba	neigh_table_init
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa55c6830	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0xa55d7237	current_fs_time
++EXPORT_SYMBOL vmlinux 0xa584c274	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0xa58afb71	skb_unlink
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa5a51eee	__crc32c_le
++EXPORT_SYMBOL vmlinux 0xa5e88736	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0xa5ea9614	tso_start
++EXPORT_SYMBOL vmlinux 0xa5f42a52	giveup_vsx
++EXPORT_SYMBOL vmlinux 0xa5f4a392	vme_lm_request
++EXPORT_SYMBOL vmlinux 0xa6257df4	inet_getname
++EXPORT_SYMBOL vmlinux 0xa631df8a	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0xa63322c6	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xa63459bb	phy_set_max_speed
++EXPORT_SYMBOL vmlinux 0xa636bd4c	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0xa6382906	irq_to_desc
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa64aeb17	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0xa65972b8	_memcpy_toio
++EXPORT_SYMBOL vmlinux 0xa65a0722	__lock_buffer
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa6825459	blk_finish_request
++EXPORT_SYMBOL vmlinux 0xa6aeab9f	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0xa6c3602a	bio_endio
++EXPORT_SYMBOL vmlinux 0xa6c4a18b	agp_backend_acquire
++EXPORT_SYMBOL vmlinux 0xa6de8956	block_write_begin
++EXPORT_SYMBOL vmlinux 0xa6f0401d	vme_irq_handler
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa7018070	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xa720678c	lg_global_lock
++EXPORT_SYMBOL vmlinux 0xa72a0f5b	nr_online_nodes
++EXPORT_SYMBOL vmlinux 0xa72f7f97	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa73e975d	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xa743c6c2	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0xa74f4e9b	ida_simple_get
++EXPORT_SYMBOL vmlinux 0xa78e8769	pipe_lock
++EXPORT_SYMBOL vmlinux 0xa799948e	set_groups
++EXPORT_SYMBOL vmlinux 0xa7a14473	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0xa7aac2f9	skb_pad
++EXPORT_SYMBOL vmlinux 0xa7ae6485	scsi_device_get
++EXPORT_SYMBOL vmlinux 0xa7bc2950	dump_page
++EXPORT_SYMBOL vmlinux 0xa7c26270	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0xa7c5fcb2	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0xa81be460	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0xa833b9e8	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa85e4bd2	key_link
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa88911fb	of_get_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0xa8d16324	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0xa8ead9c2	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0xa8ecdc48	acl_by_type
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa901d9f9	nvdimm_bus_unlock
++EXPORT_SYMBOL vmlinux 0xa9070fc4	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0xa9092e78	netif_rx
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa916b694	strnlen
++EXPORT_SYMBOL vmlinux 0xa91d90d3	nla_put
++EXPORT_SYMBOL vmlinux 0xa9220a25	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0xa924b1be	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xa9273e1a	epapr_hypercall_start
++EXPORT_SYMBOL vmlinux 0xa93ba88e	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0xa957e3a8	from_kprojid
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa9801169	__dax_fault
++EXPORT_SYMBOL vmlinux 0xa990f502	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0xa99b39c2	prandom_bytes
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9c85fa4	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0xa9d4d634	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0xaa052309	touch_atime
++EXPORT_SYMBOL vmlinux 0xaa2a9662	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0xaa2ad548	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0xaa46e87e	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0xaa4c80ac	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0xaa61de18	__frontswap_load
++EXPORT_SYMBOL vmlinux 0xaa6e4df5	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa732015	__register_nls
++EXPORT_SYMBOL vmlinux 0xaa89100f	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0xaa926880	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xaa9a0242	get_pci_dma_ops
++EXPORT_SYMBOL vmlinux 0xaa9eefd5	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0xaabbe7f3	backlight_force_update
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaafa180f	eth_header_parse
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab036f3d	vio_disable_interrupts
++EXPORT_SYMBOL vmlinux 0xab20fc13	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0xab210824	__seq_open_private
++EXPORT_SYMBOL vmlinux 0xab4e7a85	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0xab535633	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab7bfeef	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0xab8d0a8c	vfs_link
++EXPORT_SYMBOL vmlinux 0xaba969dc	__bread_gfp
++EXPORT_SYMBOL vmlinux 0xabab2609	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0xabc07a33	netlink_unicast
++EXPORT_SYMBOL vmlinux 0xabc57b48	dev_change_flags
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabcd463e	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0xabcd9c64	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac0e8171	netlink_ack
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac1eabb0	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0xac26b820	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0xac55882c	vfs_fsync
++EXPORT_SYMBOL vmlinux 0xac719a28	eeh_dev_release
++EXPORT_SYMBOL vmlinux 0xac83a4c1	devm_devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xac976877	sock_register
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacc5b5d2	csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xace802a0	setup_new_exec
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xad0027c2	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0xad00af6e	mpage_readpages
++EXPORT_SYMBOL vmlinux 0xad01744f	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad07beb6	pci_match_id
++EXPORT_SYMBOL vmlinux 0xad12babe	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0xad164875	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xad24c7c3	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0xad2af0c8	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xad4c1b51	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0xad50cebb	i8253_lock
++EXPORT_SYMBOL vmlinux 0xad55d853	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0xad776797	machine_id
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad86ea8c	no_llseek
++EXPORT_SYMBOL vmlinux 0xad8a7e7d	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0xad961743	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0xad974cd2	kill_anon_super
++EXPORT_SYMBOL vmlinux 0xada23a6f	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0xada62824	audit_log_start
++EXPORT_SYMBOL vmlinux 0xadb584ba	led_blink_set
++EXPORT_SYMBOL vmlinux 0xadbd1ec2	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0xadbf2167	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0xadcafea2	simple_link
++EXPORT_SYMBOL vmlinux 0xadd1c3be	pid_task
++EXPORT_SYMBOL vmlinux 0xadd95254	scsi_unregister
++EXPORT_SYMBOL vmlinux 0xade43db7	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0xadeda3c5	kobject_set_name
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xae358236	fence_signal
++EXPORT_SYMBOL vmlinux 0xae3bb326	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0xae4a1bda	csum_tcpudp_nofold
++EXPORT_SYMBOL vmlinux 0xae545f06	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xae55cd44	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0xae560ae9	seq_vprintf
++EXPORT_SYMBOL vmlinux 0xae786b18	nvm_register_target
++EXPORT_SYMBOL vmlinux 0xae7dd8cd	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0xae7f704f	mipi_dsi_detach
++EXPORT_SYMBOL vmlinux 0xae8e8bf2	skb_checksum
++EXPORT_SYMBOL vmlinux 0xae9c1a21	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0xaea3d583	fbcon_rotate_ud
++EXPORT_SYMBOL vmlinux 0xaec311b5	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0xaec35db4	flex_array_free
++EXPORT_SYMBOL vmlinux 0xaefa5408	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0xaefb9094	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0xaf063510	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xaf0b758b	scsi_host_get
++EXPORT_SYMBOL vmlinux 0xaf15debb	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0xaf2d872c	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0xaf2f9c60	__quota_error
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf432c7f	__get_page_tail
++EXPORT_SYMBOL vmlinux 0xaf47a615	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0xaf53112c	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0xaf6ae696	kstrndup
++EXPORT_SYMBOL vmlinux 0xaf9340a7	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xaf9d9b49	ps2_command
++EXPORT_SYMBOL vmlinux 0xafb0fd09	gen_pool_create
++EXPORT_SYMBOL vmlinux 0xafb6b3fb	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0xafb92d27	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0xafce89ae	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0xafd753ed	ns_capable
++EXPORT_SYMBOL vmlinux 0xafdaf4c2	commit_creds
++EXPORT_SYMBOL vmlinux 0xafe01d54	module_refcount
++EXPORT_SYMBOL vmlinux 0xafff3d1d	mempool_alloc
++EXPORT_SYMBOL vmlinux 0xb002dd99	sg_miter_next
++EXPORT_SYMBOL vmlinux 0xb0105567	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0xb03f9723	vfs_llseek
++EXPORT_SYMBOL vmlinux 0xb04241b4	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb06ce416	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0xb084bc9f	drop_super
++EXPORT_SYMBOL vmlinux 0xb0880ca9	dev_emerg
++EXPORT_SYMBOL vmlinux 0xb08d9b6e	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0xb09c958f	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0acccef	generic_write_checks
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0c7a8a8	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0xb0ceb3f2	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0ebb22e	km_new_mapping
++EXPORT_SYMBOL vmlinux 0xb0f45f04	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xb1146163	inet6_bind
++EXPORT_SYMBOL vmlinux 0xb118acf4	ether_setup
++EXPORT_SYMBOL vmlinux 0xb118b165	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0xb11c2125	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0xb125417e	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb12e55e4	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0xb147a413	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0xb147a855	dql_reset
++EXPORT_SYMBOL vmlinux 0xb15bd8fa	tb_ticks_per_sec
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb162cb65	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb165ef45	__irq_regs
++EXPORT_SYMBOL vmlinux 0xb16c17b5	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0xb1775421	genphy_soft_reset
++EXPORT_SYMBOL vmlinux 0xb1816af7	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0xb1ae3f28	mac_find_mode
++EXPORT_SYMBOL vmlinux 0xb1b767d5	i2c_smbus_read_i2c_block_data_or_emulated
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1c6e787	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1faf0d5	vme_register_bridge
++EXPORT_SYMBOL vmlinux 0xb217398d	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0xb22bcae4	inode_permission
++EXPORT_SYMBOL vmlinux 0xb23915d4	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0xb2405fb4	udp_prot
++EXPORT_SYMBOL vmlinux 0xb2424673	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb27ac100	bio_init
++EXPORT_SYMBOL vmlinux 0xb284dce9	build_skb
++EXPORT_SYMBOL vmlinux 0xb29dbbc8	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0xb2b11ba0	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0xb2bb0d7e	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2f77074	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0xb309385e	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0xb309abb1	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0xb30c3ffd	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0xb30c4b77	install_exec_creds
++EXPORT_SYMBOL vmlinux 0xb31f8bcc	bio_chain
++EXPORT_SYMBOL vmlinux 0xb3382494	fence_signal_locked
++EXPORT_SYMBOL vmlinux 0xb3549e6e	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0xb36d500e	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xb3889d18	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0xb389a730	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0xb3a26bc2	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0xb3b77636	d_instantiate
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb3fba6de	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0xb4125828	seq_printf
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb4395f5d	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0xb4609d35	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb47189b5	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xb473e2c2	lockref_get
++EXPORT_SYMBOL vmlinux 0xb48fcf0a	inet6_protos
++EXPORT_SYMBOL vmlinux 0xb4a1f1f1	arp_xmit
++EXPORT_SYMBOL vmlinux 0xb4ad7307	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0xb4dfa26a	param_get_short
++EXPORT_SYMBOL vmlinux 0xb51a95d0	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0xb52593a6	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0xb551468d	genphy_read_status
++EXPORT_SYMBOL vmlinux 0xb559f24b	tcp_check_req
++EXPORT_SYMBOL vmlinux 0xb55bf1ab	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0xb570487a	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb578bc5f	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0xb5881f16	security_file_permission
++EXPORT_SYMBOL vmlinux 0xb58c9c2b	dev_err
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5c9c053	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb611c1f2	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb62fc16f	read_cache_page
++EXPORT_SYMBOL vmlinux 0xb63482a9	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0xb63f83d1	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xb64ea6c3	generic_setlease
++EXPORT_SYMBOL vmlinux 0xb6679479	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0xb66ddf63	compat_ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb68bfa9d	node_states
++EXPORT_SYMBOL vmlinux 0xb68fa688	__netif_schedule
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6993245	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0xb69af80e	soft_cursor
++EXPORT_SYMBOL vmlinux 0xb69e2812	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6aa4b2d	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0xb6c93d7a	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0xb6e62728	page_waitqueue
++EXPORT_SYMBOL vmlinux 0xb6edd8cf	decrementer_clockevent
++EXPORT_SYMBOL vmlinux 0xb6ffaee3	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0xb701cf40	inet6_release
++EXPORT_SYMBOL vmlinux 0xb70b0b77	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0xb70dfe30	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xb7419c02	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb7769573	cdrom_release
++EXPORT_SYMBOL vmlinux 0xb77932eb	flex_array_clear
++EXPORT_SYMBOL vmlinux 0xb788217d	hdmi_infoframe_log
++EXPORT_SYMBOL vmlinux 0xb7b888f7	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0xb7c667fa	agp_generic_destroy_page
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7c74731	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0xb7db60fe	dup_iter
++EXPORT_SYMBOL vmlinux 0xb7f61568	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0xb7fe4b6b	mipi_dsi_dcs_set_pixel_format
++EXPORT_SYMBOL vmlinux 0xb8152144	tty_devnum
++EXPORT_SYMBOL vmlinux 0xb81945f8	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0xb8269c8e	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb8381608	generic_listxattr
++EXPORT_SYMBOL vmlinux 0xb84ca673	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0xb86cfd0c	of_scan_pci_bridge
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb879b3a0	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0xb882d73d	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0xb8a4adc6	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0xb8af9fc6	of_create_pci_dev
++EXPORT_SYMBOL vmlinux 0xb8f1361a	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0xb907513f	unpoison_memory
++EXPORT_SYMBOL vmlinux 0xb909c6d8	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0xb925743c	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0xb93de730	skb_trim
++EXPORT_SYMBOL vmlinux 0xb9458b93	bio_put
++EXPORT_SYMBOL vmlinux 0xb945ad55	tty_lock
++EXPORT_SYMBOL vmlinux 0xb94ce330	bioset_free
++EXPORT_SYMBOL vmlinux 0xb955ef4d	neigh_lookup
++EXPORT_SYMBOL vmlinux 0xb959395a	iterate_fd
++EXPORT_SYMBOL vmlinux 0xb96a141c	pnv_cxl_release_hwirq_ranges
++EXPORT_SYMBOL vmlinux 0xb9707dba	freeze_bdev
++EXPORT_SYMBOL vmlinux 0xb9795dac	register_framebuffer
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xb9e93438	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0xba20a44a	netdev_warn
++EXPORT_SYMBOL vmlinux 0xba2a589f	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0xba2d2a19	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xba2ffec2	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0xba31ec35	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0xba3874fb	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0xba44cba4	fput
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba53b437	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0xba594068	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0xba5efad5	kernel_bind
++EXPORT_SYMBOL vmlinux 0xba736632	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0xba7fef41	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0xbabfdeb9	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0xbb025a0e	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb185e60	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0xbb34134a	iov_shorten
++EXPORT_SYMBOL vmlinux 0xbb345b11	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb4f4766	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb5fd403	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0xbb71ca71	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0xbb7a0113	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbbaeb559	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0xbbb6b412	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xbbba10f4	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0xbbcd981c	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0xbbce4f53	fixed_phy_update_state
++EXPORT_SYMBOL vmlinux 0xbbd3cfa1	kset_register
++EXPORT_SYMBOL vmlinux 0xbbd57e4a	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0xbbdfb93b	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0xbbe6a724	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0xbbffee5c	mmc_gpio_set_cd_isr
++EXPORT_SYMBOL vmlinux 0xbc316de4	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0xbc3c8d70	seq_path
++EXPORT_SYMBOL vmlinux 0xbc4f1344	vfs_writev
++EXPORT_SYMBOL vmlinux 0xbc7b48af	mmc_gpiod_request_cd_irq
++EXPORT_SYMBOL vmlinux 0xbc948a62	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0xbc982b06	eeh_subsystem_flags
++EXPORT_SYMBOL vmlinux 0xbcabe945	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0xbcb6acb7	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbce3042f	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0xbcf150f9	xor_altivec_5
++EXPORT_SYMBOL vmlinux 0xbd09c336	request_firmware
++EXPORT_SYMBOL vmlinux 0xbd11a292	do_splice_from
++EXPORT_SYMBOL vmlinux 0xbd213988	of_get_ibm_chip_id
++EXPORT_SYMBOL vmlinux 0xbd27963e	sync_inode
++EXPORT_SYMBOL vmlinux 0xbd4130a3	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0xbd462b55	__kfifo_init
++EXPORT_SYMBOL vmlinux 0xbd47d0ed	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0xbd55fa44	vfs_statfs
++EXPORT_SYMBOL vmlinux 0xbd6920c3	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0xbd6d79f1	__tracepoint_fence_annotate_wait_on
++EXPORT_SYMBOL vmlinux 0xbd89e70f	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbdb8f32f	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0xbdce2046	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0xbde7ca00	tty_unlock
++EXPORT_SYMBOL vmlinux 0xbdf1696c	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0xbdfb943f	param_set_copystring
++EXPORT_SYMBOL vmlinux 0xbe0de973	__napi_schedule
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe2db465	param_set_uint
++EXPORT_SYMBOL vmlinux 0xbe2df2d4	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0xbe4839f6	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0xbe7f11bb	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0xbe879acf	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf0a41ce	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0xbf0be3b5	__page_cache_alloc
++EXPORT_SYMBOL vmlinux 0xbf34b54a	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf85726a	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf925c42	idr_init
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfabfe59	__debugger_iabr_match
++EXPORT_SYMBOL vmlinux 0xbfb8b0b7	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xbfc177bc	iowrite32_rep
++EXPORT_SYMBOL vmlinux 0xbfcc0231	proc_set_user
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xbff8182c	plpar_hcall_norets
++EXPORT_SYMBOL vmlinux 0xbffb728e	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0xbffeaf47	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0xc00536c8	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0xc02b433e	of_get_child_by_name
++EXPORT_SYMBOL vmlinux 0xc03a7b2c	genl_notify
++EXPORT_SYMBOL vmlinux 0xc0562642	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc07758a7	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc0864ab6	mount_subtree
++EXPORT_SYMBOL vmlinux 0xc08894e0	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0xc09c765f	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0a93a3a	brioctl_set
++EXPORT_SYMBOL vmlinux 0xc0babdd1	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0xc0c3aa3e	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0xc11c7aa9	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0xc123e6c9	set_bh_page
++EXPORT_SYMBOL vmlinux 0xc15a44c6	memzero_explicit
++EXPORT_SYMBOL vmlinux 0xc1838946	udplite_prot
++EXPORT_SYMBOL vmlinux 0xc18bda6b	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xc18d1701	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0xc193f07d	dm_register_target
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc2261c50	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0xc22f6ade	touch_buffer
++EXPORT_SYMBOL vmlinux 0xc2424641	agp3_generic_cleanup
++EXPORT_SYMBOL vmlinux 0xc24269f7	con_is_bound
++EXPORT_SYMBOL vmlinux 0xc2778900	mipi_dsi_driver_register_full
++EXPORT_SYMBOL vmlinux 0xc27aa3ac	mach_powernv
++EXPORT_SYMBOL vmlinux 0xc283b3a9	security_path_rename
++EXPORT_SYMBOL vmlinux 0xc29872e7	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0xc29bf967	strspn
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2af3120	nla_append
++EXPORT_SYMBOL vmlinux 0xc2b92055	abort_creds
++EXPORT_SYMBOL vmlinux 0xc2dabac5	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc310b981	strnstr
++EXPORT_SYMBOL vmlinux 0xc340fdf1	tcp_connect
++EXPORT_SYMBOL vmlinux 0xc346531a	tty_set_operations
++EXPORT_SYMBOL vmlinux 0xc34b99fb	devfreq_register_opp_notifier
++EXPORT_SYMBOL vmlinux 0xc3666aee	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0xc37ad991	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0xc37df066	__scm_destroy
++EXPORT_SYMBOL vmlinux 0xc3b8954e	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0xc3c2be91	mipi_dsi_packet_format_is_short
++EXPORT_SYMBOL vmlinux 0xc3c37d7f	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0xc3c6ad05	genphy_config_init
++EXPORT_SYMBOL vmlinux 0xc3e13466	block_write_full_page
++EXPORT_SYMBOL vmlinux 0xc3e299e4	generic_setxattr
++EXPORT_SYMBOL vmlinux 0xc3fce77c	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0xc42ae5c1	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0xc42b60f8	tty_port_close
++EXPORT_SYMBOL vmlinux 0xc43588bc	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0xc45ec28b	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0xc47cdf9c	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0xc48307db	lz4_decompress
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4a33453	check_disk_change
++EXPORT_SYMBOL vmlinux 0xc4b52b28	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0xc4bb6ebc	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0xc4cf838e	misc_register
++EXPORT_SYMBOL vmlinux 0xc4d99f02	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0xc4fc113e	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0xc5084459	free_netdev
++EXPORT_SYMBOL vmlinux 0xc51e2bf3	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0xc5362c6a	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0xc5534d64	ioread16
++EXPORT_SYMBOL vmlinux 0xc558a4cf	generic_readlink
++EXPORT_SYMBOL vmlinux 0xc55de23c	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0xc5652651	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc5ad43cf	__sb_end_write
++EXPORT_SYMBOL vmlinux 0xc5d9c46c	agp_try_unsupported_boot
++EXPORT_SYMBOL vmlinux 0xc5e3a55e	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc628c2d1	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0xc62b359c	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc63abf5a	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xc64308a6	mdiobus_free
++EXPORT_SYMBOL vmlinux 0xc65abeb7	agp3_generic_sizes
++EXPORT_SYMBOL vmlinux 0xc65ac5e3	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0xc65fa0f8	sock_create_kern
++EXPORT_SYMBOL vmlinux 0xc663b075	__ioremap
++EXPORT_SYMBOL vmlinux 0xc666a132	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xc666bdae	vme_master_mmap
++EXPORT_SYMBOL vmlinux 0xc66c365b	do_splice_direct
++EXPORT_SYMBOL vmlinux 0xc6772da2	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xc6774da5	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0xc6781b0f	netpoll_setup
++EXPORT_SYMBOL vmlinux 0xc685e6d6	of_node_get
++EXPORT_SYMBOL vmlinux 0xc69b2ca0	loop_backing_file
++EXPORT_SYMBOL vmlinux 0xc69d5582	filp_open
++EXPORT_SYMBOL vmlinux 0xc69de489	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0xc6a003cb	key_invalidate
++EXPORT_SYMBOL vmlinux 0xc6a744b4	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0xc6b22c71	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0xc6ca27ee	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0xc6cb465a	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6d13d4a	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0xc6dca632	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0xc6e6083f	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0xc6f611e3	of_get_address
++EXPORT_SYMBOL vmlinux 0xc6fd7e4e	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0xc7026a24	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0xc707ddc4	mount_single
++EXPORT_SYMBOL vmlinux 0xc7156530	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc7563db8	twl_set_regcache_bypass
++EXPORT_SYMBOL vmlinux 0xc7591cf0	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0xc75c92e5	of_find_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0xc75cf7e0	skb_insert
++EXPORT_SYMBOL vmlinux 0xc7720cb5	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xc77cae4c	__serio_register_port
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7a68472	agp_generic_free_by_type
++EXPORT_SYMBOL vmlinux 0xc7b19f01	mipi_dsi_driver_unregister
++EXPORT_SYMBOL vmlinux 0xc7d81b15	datagram_poll
++EXPORT_SYMBOL vmlinux 0xc7f39b15	irq_stat
++EXPORT_SYMBOL vmlinux 0xc81188db	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0xc8255a13	__genl_register_family
++EXPORT_SYMBOL vmlinux 0xc82a5430	inet_ioctl
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc83f5cfc	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc8571bcb	idr_for_each
++EXPORT_SYMBOL vmlinux 0xc85ed24f	param_get_byte
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc874faa1	reservation_object_add_shared_fence
++EXPORT_SYMBOL vmlinux 0xc87b49e1	get_super_thawed
++EXPORT_SYMBOL vmlinux 0xc87eeeca	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0xc8841c32	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc899e9e1	seq_release
++EXPORT_SYMBOL vmlinux 0xc8a3c933	agp_generic_enable
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8bac635	phy_start
++EXPORT_SYMBOL vmlinux 0xc8d5d5f5	file_open_root
++EXPORT_SYMBOL vmlinux 0xc90c8dd3	phy_detach
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc9193d6e	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0xc93fbc54	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xc9630b79	d_make_root
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc96402f2	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0xc978479a	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc9b57c28	blk_init_queue
++EXPORT_SYMBOL vmlinux 0xc9bdf2a0	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0xc9bf2319	___pskb_trim
++EXPORT_SYMBOL vmlinux 0xc9c9eb03	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0xc9d0f6b6	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0xc9f4e359	sock_no_getname
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca2b1cd6	ida_pre_get
++EXPORT_SYMBOL vmlinux 0xca2c9f8b	lock_fb_info
++EXPORT_SYMBOL vmlinux 0xca3b28c6	store_vr_state
++EXPORT_SYMBOL vmlinux 0xca5c3af2	blk_start_queue
++EXPORT_SYMBOL vmlinux 0xca5ee09a	vme_free_consistent
++EXPORT_SYMBOL vmlinux 0xca72ddec	phy_init_hw
++EXPORT_SYMBOL vmlinux 0xca832efe	kmalloc_order
++EXPORT_SYMBOL vmlinux 0xca86bae8	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xcaa3de88	mmc_gpiod_request_ro
++EXPORT_SYMBOL vmlinux 0xcaaab321	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0xcaaf988d	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0xcab4e32a	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0xcac56345	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0xcac9e591	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0xcace6297	idr_is_empty
++EXPORT_SYMBOL vmlinux 0xcacf847f	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcaf5a5bf	padata_start
++EXPORT_SYMBOL vmlinux 0xcb0270bc	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb0d2dfe	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0xcb15737d	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xcb1d5bb1	blk_end_request
++EXPORT_SYMBOL vmlinux 0xcb78f883	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0xcb936989	hdmi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc3b94e	eeh_check_failure
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbda930c	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0xcbdd4f18	put_tty_driver
++EXPORT_SYMBOL vmlinux 0xcc13e211	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0xcc17504d	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xcc215573	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc3c7354	ps2_end_command
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc6f6b51	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0xcc7568b9	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0xcc88d139	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0xcc9f85f2	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0xccaa70a2	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xccb3c085	__put_cred
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccc56542	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0xccd8c6cf	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0xcce0f777	agp3_generic_tlbflush
++EXPORT_SYMBOL vmlinux 0xcce10feb	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0xcd0529c7	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0xcd17c9fa	of_find_backlight_by_node
++EXPORT_SYMBOL vmlinux 0xcd20667a	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd2d7cb8	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0xcd534e70	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0xcd57f7b0	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0xcd5ba6ae	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0xcd79d7a8	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0xcd7ede2a	seqno_fence_ops
++EXPORT_SYMBOL vmlinux 0xcd86c87f	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0xcdbd6759	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdd13d1f	mmc_erase
++EXPORT_SYMBOL vmlinux 0xcddd15e8	of_phy_find_device
++EXPORT_SYMBOL vmlinux 0xcde8ce8c	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0xcde96b47	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0xce05bc54	tty_do_resize
++EXPORT_SYMBOL vmlinux 0xce05dcd3	tty_hangup
++EXPORT_SYMBOL vmlinux 0xce0e2d66	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xce1c1a49	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce3b3f09	profile_pc
++EXPORT_SYMBOL vmlinux 0xce3d2870	mmc_add_host
++EXPORT_SYMBOL vmlinux 0xce468505	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0xce4e47b6	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce687dce	tso_count_descs
++EXPORT_SYMBOL vmlinux 0xce7850e1	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0xce8d9a5e	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0xce9ee1b3	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0xcea15d51	bdev_read_only
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xceae504f	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0xced4c2f2	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0xced777cb	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0xced8bdef	put_cmsg
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf147d31	noop_fsync
++EXPORT_SYMBOL vmlinux 0xcf15da65	nf_afinfo
++EXPORT_SYMBOL vmlinux 0xcf1f83e5	registered_fb
++EXPORT_SYMBOL vmlinux 0xcf30b28d	get_fs_type
++EXPORT_SYMBOL vmlinux 0xcf4ec58e	elevator_alloc
++EXPORT_SYMBOL vmlinux 0xcf642ea3	kernel_read
++EXPORT_SYMBOL vmlinux 0xcf64d629	of_get_parent
++EXPORT_SYMBOL vmlinux 0xcf677e49	agp_allocate_memory
++EXPORT_SYMBOL vmlinux 0xcf724497	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0xcf76fa74	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0xcf7e2a4e	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0xcfad048f	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0xcfbe49f3	proc_remove
++EXPORT_SYMBOL vmlinux 0xcfc440ba	ptp_clock_unregister
++EXPORT_SYMBOL vmlinux 0xd003d7a3	input_inject_event
++EXPORT_SYMBOL vmlinux 0xd007f207	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0xd01cc2d9	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd0786054	d_add_ci
++EXPORT_SYMBOL vmlinux 0xd07c970d	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0xd08f6239	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xd09b0199	fence_context_alloc
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a41da7	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0b275e8	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0xd0e483ab	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f241c0	__inet_hash
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0f78348	tty_throttle
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fd6386	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0xd0fef3b2	agp_free_key
++EXPORT_SYMBOL vmlinux 0xd10b0107	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0xd1262886	rtas_data_buf
++EXPORT_SYMBOL vmlinux 0xd129e060	n_tty_compat_ioctl_helper
++EXPORT_SYMBOL vmlinux 0xd15f6dd0	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd16fb187	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xd178ff70	vm_stat
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd185ea02	sk_common_release
++EXPORT_SYMBOL vmlinux 0xd1994653	compat_tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0xd19ec137	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0xd1c3c517	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0xd1c4c2b0	d_alloc
++EXPORT_SYMBOL vmlinux 0xd1c8ea54	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1f61771	key_alloc
++EXPORT_SYMBOL vmlinux 0xd20c3937	flex_array_get
++EXPORT_SYMBOL vmlinux 0xd2343edf	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0xd2417d7e	dev_addr_init
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd254bae8	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd25fd102	seq_putc
++EXPORT_SYMBOL vmlinux 0xd2634a5f	nd_btt_arena_is_valid
++EXPORT_SYMBOL vmlinux 0xd270823d	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0xd279a253	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd2b09ce5	__kmalloc
++EXPORT_SYMBOL vmlinux 0xd2b384a3	of_get_pci_address
++EXPORT_SYMBOL vmlinux 0xd2b59f54	console_start
++EXPORT_SYMBOL vmlinux 0xd2b5e78d	qdisc_reset
++EXPORT_SYMBOL vmlinux 0xd2c28cc7	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd302ce2f	dcb_setapp
++EXPORT_SYMBOL vmlinux 0xd30611d8	nf_register_hook
++EXPORT_SYMBOL vmlinux 0xd31ccb06	of_machine_is_compatible
++EXPORT_SYMBOL vmlinux 0xd329e8af	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0xd32bc01b	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0xd32f380b	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0xd360f209	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0xd36e3d59	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0xd37a91af	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0xd383f57f	kobject_del
++EXPORT_SYMBOL vmlinux 0xd3888e78	finish_open
++EXPORT_SYMBOL vmlinux 0xd3913877	md_register_thread
++EXPORT_SYMBOL vmlinux 0xd39179e8	agp_bind_memory
++EXPORT_SYMBOL vmlinux 0xd3abe991	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3be030d	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0xd3cfdccb	dev_load
++EXPORT_SYMBOL vmlinux 0xd3d5b2b7	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0xd3f61911	icmpv6_send
++EXPORT_SYMBOL vmlinux 0xd3f82a96	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0xd405d910	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0xd4163b87	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0xd4294b8f	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0xd445ad07	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0xd44b7e21	to_tm
++EXPORT_SYMBOL vmlinux 0xd45654b6	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0xd45cc6ca	bin2hex
++EXPORT_SYMBOL vmlinux 0xd45e449f	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0xd478d87f	vio_register_device_node
++EXPORT_SYMBOL vmlinux 0xd48fdeef	dql_completed
++EXPORT_SYMBOL vmlinux 0xd493d153	of_device_is_compatible
++EXPORT_SYMBOL vmlinux 0xd4aebb26	freeze_super
++EXPORT_SYMBOL vmlinux 0xd4bacf0a	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0xd4c1cefa	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0xd4ca3c00	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0xd4df9215	send_sig_info
++EXPORT_SYMBOL vmlinux 0xd4ea17aa	pnv_cxl_alloc_hwirq_ranges
++EXPORT_SYMBOL vmlinux 0xd4ff8926	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0xd501818e	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0xd52311f0	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0xd528f58c	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd55aeacd	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0xd55af6fe	sk_dst_check
++EXPORT_SYMBOL vmlinux 0xd57cdfcc	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0xd58018c2	simple_statfs
++EXPORT_SYMBOL vmlinux 0xd594c904	get_vaddr_frames
++EXPORT_SYMBOL vmlinux 0xd59a8f5e	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0xd59b781f	serio_bus
++EXPORT_SYMBOL vmlinux 0xd5aeabbc	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0xd5b9b457	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0xd5c10220	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0xd5f5d33b	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0xd5f84474	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0xd603298f	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd61f1d6c	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0xd622d9b9	mipi_dsi_attach
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd64681c6	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd65ff744	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0xd66fde3c	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd6af4eda	cpufreq_power_cooling_register
++EXPORT_SYMBOL vmlinux 0xd6bdcb75	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0xd6c489a5	read_code
++EXPORT_SYMBOL vmlinux 0xd6d63e9d	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd6fd4053	__arch_hweight32
++EXPORT_SYMBOL vmlinux 0xd70f5e99	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0xd7367f74	dev_add_offload
++EXPORT_SYMBOL vmlinux 0xd73b5208	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0xd740c510	sock_release
++EXPORT_SYMBOL vmlinux 0xd74a6192	set_blocksize
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd75ca6b0	param_ops_bool
++EXPORT_SYMBOL vmlinux 0xd761a383	ioremap_prot
++EXPORT_SYMBOL vmlinux 0xd77c7a58	mdiobus_read_nested
++EXPORT_SYMBOL vmlinux 0xd786c0ea	plpar_hcall9
++EXPORT_SYMBOL vmlinux 0xd79affdc	devm_gpiod_get_optional
++EXPORT_SYMBOL vmlinux 0xd7b187c5	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0xd7b1e595	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0xd7db0d89	filemap_fault
++EXPORT_SYMBOL vmlinux 0xd7db4e39	napi_complete_done
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd7f676c4	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xd80d9689	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0xd8308bda	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0xd865c977	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0xd86bc09b	send_sig
++EXPORT_SYMBOL vmlinux 0xd878013a	mipi_dsi_dcs_set_page_address
++EXPORT_SYMBOL vmlinux 0xd88272ed	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0xd885b2f4	page_readlink
++EXPORT_SYMBOL vmlinux 0xd896065a	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a1ee52	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8c6e9f7	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0xd8d9e6b0	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e1e06d	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0xd8e34ef8	ptp_clock_event
++EXPORT_SYMBOL vmlinux 0xd8e3e0ae	seq_escape
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd90a6a6a	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0xd911833f	param_get_invbool
++EXPORT_SYMBOL vmlinux 0xd91c655c	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0xd927b405	nd_dev_to_uuid
++EXPORT_SYMBOL vmlinux 0xd93a7afe	put_io_context
++EXPORT_SYMBOL vmlinux 0xd9452ed1	netdev_printk
++EXPORT_SYMBOL vmlinux 0xd9518e5f	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xd954d24d	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xd95f7347	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0xd9746af3	tcp_close
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd98c1193	flow_cache_init
++EXPORT_SYMBOL vmlinux 0xd99c9bc7	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0xd9a557b1	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0xd9a5e026	single_open
++EXPORT_SYMBOL vmlinux 0xd9bac924	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0xd9cb5f34	pci_enable_device
++EXPORT_SYMBOL vmlinux 0xd9d237ac	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9def8e6	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0xd9fa7b91	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0xda23142d	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0xda2f36d1	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0xda332883	vfs_rename
++EXPORT_SYMBOL vmlinux 0xda33cb08	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda3daf6f	read_cache_pages
++EXPORT_SYMBOL vmlinux 0xda4c121c	simple_empty
++EXPORT_SYMBOL vmlinux 0xda79b7d8	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda821c51	phy_device_register
++EXPORT_SYMBOL vmlinux 0xda82df86	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda9544cf	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0xda9fc7ae	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0xdaa5293c	address_space_init_once
++EXPORT_SYMBOL vmlinux 0xdaaf4e9a	of_mdio_find_bus
++EXPORT_SYMBOL vmlinux 0xdabc1ea8	fsl_lbc_find
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdac545b9	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0xdacd5f60	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0xdad5b8de	touchscreen_parse_properties
++EXPORT_SYMBOL vmlinux 0xdad8eb34	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xdae45b0e	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0xdaea6e0d	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0xdb01198e	fsl_upm_find
++EXPORT_SYMBOL vmlinux 0xdb0d4193	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0xdb125649	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0xdb3bcca6	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0xdb599a48	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb6fd76b	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb81cf15	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0xdb936969	dquot_transfer
++EXPORT_SYMBOL vmlinux 0xdb978b73	generic_fillattr
++EXPORT_SYMBOL vmlinux 0xdbae13c2	mipi_dsi_dcs_set_tear_on
++EXPORT_SYMBOL vmlinux 0xdbb58359	inode_init_always
++EXPORT_SYMBOL vmlinux 0xdbb874fd	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0xdbcf7204	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0xdbd0177b	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0xdbe32f39	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0xdbe5eed2	genphy_resume
++EXPORT_SYMBOL vmlinux 0xdbeb8a63	to_nd_btt
++EXPORT_SYMBOL vmlinux 0xdbfe5a21	skb_copy
++EXPORT_SYMBOL vmlinux 0xdc009197	nf_log_register
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc14d593	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc1ba53e	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xdc214961	fence_wait_any_timeout
++EXPORT_SYMBOL vmlinux 0xdc32a64b	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xdc3c41a8	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc512134	backlight_register_notifier
++EXPORT_SYMBOL vmlinux 0xdc8cf8be	pci_map_rom
++EXPORT_SYMBOL vmlinux 0xdc9498dd	down
++EXPORT_SYMBOL vmlinux 0xdc976a13	input_close_device
++EXPORT_SYMBOL vmlinux 0xdca58e2e	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdcb764ad	memset
++EXPORT_SYMBOL vmlinux 0xdcd6ec11	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0xdcd6f05a	init_task
++EXPORT_SYMBOL vmlinux 0xdd45a121	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0xdd47723b	register_gifconf
++EXPORT_SYMBOL vmlinux 0xdd532028	wake_up_process
++EXPORT_SYMBOL vmlinux 0xdd5d56ff	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0xdd64e639	strscpy
++EXPORT_SYMBOL vmlinux 0xdd672930	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0xdd6bcbd9	netif_napi_add
++EXPORT_SYMBOL vmlinux 0xdd752382	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0xdd83bda0	security_path_chown
++EXPORT_SYMBOL vmlinux 0xdd8446dd	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0xdd9030af	current_stack_pointer
++EXPORT_SYMBOL vmlinux 0xdd92ed8b	input_register_handler
++EXPORT_SYMBOL vmlinux 0xdd955144	__debugger
++EXPORT_SYMBOL vmlinux 0xdd999fae	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0xddb31acf	prepare_binprm
++EXPORT_SYMBOL vmlinux 0xddb3769b	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0xddf4b277	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0xddf705f3	of_n_size_cells
++EXPORT_SYMBOL vmlinux 0xddf94f0b	neigh_for_each
++EXPORT_SYMBOL vmlinux 0xde0173f4	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0xde0c2141	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0xde2d3bc6	of_find_mipi_dsi_device_by_node
++EXPORT_SYMBOL vmlinux 0xde48e9ca	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0xde5f67a6	module_put
++EXPORT_SYMBOL vmlinux 0xde6151db	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xde6912c9	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0xde758ea7	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0xde783883	pSeries_disable_reloc_on_exc
++EXPORT_SYMBOL vmlinux 0xde91448c	load_vr_state
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde9b17ed	agp3_generic_fetch_size
++EXPORT_SYMBOL vmlinux 0xdea43b95	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0xdebe04e6	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0xdec3c2f0	of_phy_connect
++EXPORT_SYMBOL vmlinux 0xdefd0b8f	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0xdf050cad	ppp_input_error
++EXPORT_SYMBOL vmlinux 0xdf1ba27f	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0xdf292032	d_drop
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf2f25fb	vfs_create
++EXPORT_SYMBOL vmlinux 0xdf3a76df	pcibus_to_node
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf59b4d2	fget
++EXPORT_SYMBOL vmlinux 0xdf5b5502	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf708894	__getblk_slow
++EXPORT_SYMBOL vmlinux 0xdf7448a7	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0xdf775cab	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdfb42c39	sock_edemux
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xdfd0f879	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0xdfd78618	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL vmlinux 0xe0055788	locks_init_lock
++EXPORT_SYMBOL vmlinux 0xe0081cc5	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0xe00cb7cf	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0xe00f0445	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0xe02a5d41	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0xe0405096	do_SAK
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe061444c	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0xe06a2d59	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe083e246	gen_pool_first_fit_order_align
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0c04e4a	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0xe0c75d7b	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0xe0cb56c7	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xe0cbf78f	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0xe0d40873	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0xe0ea1ff9	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0xe10b95aa	unregister_nls
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe12770c3	udp_del_offload
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe146bf7f	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0xe14c9c50	of_get_mac_address
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe195d86e	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0xe198af19	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0xe1dbf70b	kthread_bind
++EXPORT_SYMBOL vmlinux 0xe1f57bb4	pci_set_master
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe20372ae	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0xe215c096	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0xe2203839	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0xe220ceb8	__debugger_sstep
++EXPORT_SYMBOL vmlinux 0xe2279e5f	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe241c586	dquot_file_open
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe250b0ef	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0xe290a3f5	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2b8b1f7	__neigh_create
++EXPORT_SYMBOL vmlinux 0xe2bd9c59	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xe2be5498	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2d9c62e	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe2f6e1c2	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0xe2f89f37	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0xe300cf18	__sock_create
++EXPORT_SYMBOL vmlinux 0xe301aa10	netdev_err
++EXPORT_SYMBOL vmlinux 0xe305bc2c	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0xe311c99b	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xe314e8fb	cpu_core_map
++EXPORT_SYMBOL vmlinux 0xe317764d	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0xe324e115	inet_listen
++EXPORT_SYMBOL vmlinux 0xe32f8cbd	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0xe36cca74	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0xe375dae3	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0xe376d453	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0xe3a3f1fb	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0xe3a53f4c	sort
++EXPORT_SYMBOL vmlinux 0xe3b19103	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3c6c897	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0xe3c7352b	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xe3c839c9	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3fdbd5e	led_set_brightness
++EXPORT_SYMBOL vmlinux 0xe40b590c	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0xe416b6a3	arp_create
++EXPORT_SYMBOL vmlinux 0xe4229835	compat_nf_getsockopt
++EXPORT_SYMBOL vmlinux 0xe43a43a9	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0xe45567c5	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0xe458362d	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0xe484e35f	ioread32
++EXPORT_SYMBOL vmlinux 0xe49e38d4	vm_mmap
++EXPORT_SYMBOL vmlinux 0xe4a6f9e0	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0xe4b22682	giveup_fpu
++EXPORT_SYMBOL vmlinux 0xe4b494ff	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0xe4bb655b	mmc_release_host
++EXPORT_SYMBOL vmlinux 0xe4cd0913	bmap
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe4eaab2e	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0xe4eb257a	bh_submit_read
++EXPORT_SYMBOL vmlinux 0xe4fe8ca1	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xe5012790	try_module_get
++EXPORT_SYMBOL vmlinux 0xe50470c7	is_nd_btt
++EXPORT_SYMBOL vmlinux 0xe5111d61	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0xe51998b9	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0xe51cee15	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe52b3d9a	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0xe54c165f	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0xe5525710	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0xe56eada3	netdev_state_change
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe591a6f7	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0xe5999600	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5ce0331	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0xe5d662ad	tcp_child_process
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe6025f48	get_cached_acl
++EXPORT_SYMBOL vmlinux 0xe633ec2b	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0xe6599397	fs_bio_set
++EXPORT_SYMBOL vmlinux 0xe65a73d7	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0xe66feeac	kernel_write
++EXPORT_SYMBOL vmlinux 0xe683a7f7	from_kgid
++EXPORT_SYMBOL vmlinux 0xe68478d9	blk_run_queue
++EXPORT_SYMBOL vmlinux 0xe6976d95	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe69a9df4	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xe6f7e6f4	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe7228bd1	mipi_dsi_dcs_set_display_on
++EXPORT_SYMBOL vmlinux 0xe7495d89	sock_no_bind
++EXPORT_SYMBOL vmlinux 0xe74ba8d3	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xe78f2bb0	set_device_ro
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7c009b2	input_enable_softrepeat
++EXPORT_SYMBOL vmlinux 0xe7c1a2f8	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0xe7c784e8	kfree_skb
++EXPORT_SYMBOL vmlinux 0xe7ce7439	_memcpy_fromio
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7f23da1	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0xe804ea6b	scmd_printk
++EXPORT_SYMBOL vmlinux 0xe8189cec	vme_register_driver
++EXPORT_SYMBOL vmlinux 0xe81ef1dd	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe825cff0	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0xe82cc752	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0xe84fe988	d_find_alias
++EXPORT_SYMBOL vmlinux 0xe85bd49b	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe894741c	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8b9a157	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8c438f3	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0xe8c9eeab	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xe8ce7c54	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0xe8ef0ff0	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe919013b	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0xe92e5bb2	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0xe92fb9c0	unregister_key_type
++EXPORT_SYMBOL vmlinux 0xe9355c61	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0xe9378d58	idr_get_next
++EXPORT_SYMBOL vmlinux 0xe9537ee1	cdev_del
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe954ccab	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0xe9557a1b	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0xe95e0842	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0xe95f368f	ptp_clock_register
++EXPORT_SYMBOL vmlinux 0xe971876a	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe97c3034	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0xe98b7641	inet_frags_init
++EXPORT_SYMBOL vmlinux 0xe999cee8	input_get_keycode
++EXPORT_SYMBOL vmlinux 0xe9af0293	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0xe9c96a5f	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xe9ff83d9	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea0a54a7	make_bad_inode
++EXPORT_SYMBOL vmlinux 0xea2eea31	bdgrab
++EXPORT_SYMBOL vmlinux 0xea493c76	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0xea66306a	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0xea7a42f9	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xea968c96	___ratelimit
++EXPORT_SYMBOL vmlinux 0xeaa476dd	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0xeab254a9	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0xeab2b262	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0xeab65a69	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0xeac09f3d	follow_pfn
++EXPORT_SYMBOL vmlinux 0xeae00545	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xeae4bd9a	should_remove_suid
++EXPORT_SYMBOL vmlinux 0xeaf03e2e	of_get_named_gpio_flags
++EXPORT_SYMBOL vmlinux 0xeb1a74ed	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb44339a	free_pages_exact
++EXPORT_SYMBOL vmlinux 0xeb69bc74	md_error
++EXPORT_SYMBOL vmlinux 0xeb745038	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0xeb8ae708	of_mm_gpiochip_remove
++EXPORT_SYMBOL vmlinux 0xeb8c7b7b	cxl_use_count
++EXPORT_SYMBOL vmlinux 0xeb8dbd77	udp_set_csum
++EXPORT_SYMBOL vmlinux 0xeb8e954f	mmc_start_req
++EXPORT_SYMBOL vmlinux 0xeba2a1f7	rtas_indicator_present
++EXPORT_SYMBOL vmlinux 0xebb128b3	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0xebb28239	mipi_dsi_generic_read
++EXPORT_SYMBOL vmlinux 0xebcab3a6	ppc_pci_io
++EXPORT_SYMBOL vmlinux 0xebe2f7bf	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0xebedc165	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xebfb2dd2	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0xec08fd0c	ibmebus_bus_type
++EXPORT_SYMBOL vmlinux 0xec402022	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xec7a361f	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0xec7e00dc	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0xec90bd57	tty_mutex
++EXPORT_SYMBOL vmlinux 0xecb1caae	nf_reinject
++EXPORT_SYMBOL vmlinux 0xecbb926f	xor_altivec_3
++EXPORT_SYMBOL vmlinux 0xecc4f081	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0xecd982a2	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xece6e74f	led_update_brightness
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xed0ffd91	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0xed18348b	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0xed18fc6a	release_firmware
++EXPORT_SYMBOL vmlinux 0xed3aba2f	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0xed408c0d	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed5c3c80	fb_pan_display
++EXPORT_SYMBOL vmlinux 0xed6ad30e	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0xed70c928	bdi_destroy
++EXPORT_SYMBOL vmlinux 0xed9d5252	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedc410d0	udplite_table
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xedfe0def	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0xee0561ba	serio_close
++EXPORT_SYMBOL vmlinux 0xee06452b	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xee13d30c	dquot_release
++EXPORT_SYMBOL vmlinux 0xee14c7f6	pci_dev_put
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee354f5f	tcp_poll
++EXPORT_SYMBOL vmlinux 0xee3e5e4e	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xee54dd6e	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0xee6410ef	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0xee6b60b9	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0xee86327b	__frontswap_test
++EXPORT_SYMBOL vmlinux 0xee8ab5d2	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xee9cea7b	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0xeea009f7	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0xeea3cd7a	nla_reserve
++EXPORT_SYMBOL vmlinux 0xeea61d32	md_flush_request
++EXPORT_SYMBOL vmlinux 0xeea662b8	of_device_is_available
++EXPORT_SYMBOL vmlinux 0xeea788e8	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeee781d4	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xeeeef737	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xeef92b7b	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0xef0c2b04	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0xef1eb1d7	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0xef2f5ddc	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0xef38534a	dquot_commit
++EXPORT_SYMBOL vmlinux 0xef57994c	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0xef76867f	vio_get_attribute
++EXPORT_SYMBOL vmlinux 0xef7ac2d0	devm_gpiod_get_index_optional
++EXPORT_SYMBOL vmlinux 0xef91a8f9	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0xefaea186	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0xefc1f3e6	down_write_trylock
++EXPORT_SYMBOL vmlinux 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefde1bbe	flush_dcache_range
++EXPORT_SYMBOL vmlinux 0xefe56368	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0xefefdd40	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0xeff26904	param_get_ushort
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf00ec75d	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0xf00f6ffd	release_sock
++EXPORT_SYMBOL vmlinux 0xf016ccf1	get_disk
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf029222f	key_task_permission
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf065f629	ioread16be
++EXPORT_SYMBOL vmlinux 0xf067257c	register_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0xf06dc41f	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0xf07a594d	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0xf07fe9a0	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0xf084016e	input_event
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf09dc7b1	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0a8237a	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xf0ad6d6b	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xf0c9f649	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0xf0dd635b	pnv_cxl_ioda_msi_setup
++EXPORT_SYMBOL vmlinux 0xf0deb3cf	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0xf0eacf7e	block_commit_write
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf0fb819a	udp_add_offload
++EXPORT_SYMBOL vmlinux 0xf102cef5	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf10de535	ioread8
++EXPORT_SYMBOL vmlinux 0xf10eb9df	vio_h_cop_sync
++EXPORT_SYMBOL vmlinux 0xf11cd6ce	down_interruptible
++EXPORT_SYMBOL vmlinux 0xf14161ae	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0xf1460735	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf148b4d1	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0xf14af5a6	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0xf1717220	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0xf183189b	__ioremap_at
++EXPORT_SYMBOL vmlinux 0xf185e29e	blk_queue_split
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf19d80b4	dev_uc_del
++EXPORT_SYMBOL vmlinux 0xf1a8f13e	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0xf1ad8787	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0xf1b6e921	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0xf1c00fba	simple_lookup
++EXPORT_SYMBOL vmlinux 0xf1cb5bc8	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0xf1daffab	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1dc7b9d	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1ec2249	vfs_write
++EXPORT_SYMBOL vmlinux 0xf1ee94d2	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf2169d54	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0xf217726d	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0xf22881e8	lg_local_lock
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf2a0af8f	backlight_device_registered
++EXPORT_SYMBOL vmlinux 0xf2a242d9	filp_close
++EXPORT_SYMBOL vmlinux 0xf2a2b163	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0xf2b28c3d	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0xf2c11696	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL vmlinux 0xf2d06742	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0xf2d38ac4	simple_unlink
++EXPORT_SYMBOL vmlinux 0xf2d714aa	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf31eb153	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0xf322a206	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0xf3277833	of_platform_bus_probe
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf33b0f7c	ps2_drain
++EXPORT_SYMBOL vmlinux 0xf33e5b7f	md_write_end
++EXPORT_SYMBOL vmlinux 0xf33ff408	eth_type_trans
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf34d9c53	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf354187c	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0xf35dad0e	devm_request_resource
++EXPORT_SYMBOL vmlinux 0xf376063b	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0xf37ef327	nf_log_set
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf3915fdb	simple_open
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf3989189	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0xf3b7e064	kill_block_super
++EXPORT_SYMBOL vmlinux 0xf3cd1d97	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf3f12425	file_path
++EXPORT_SYMBOL vmlinux 0xf405700b	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0xf410a860	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0xf43a4a3a	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0xf441ac43	ioread8_rep
++EXPORT_SYMBOL vmlinux 0xf44d76ae	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0xf461d048	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf49fc27c	thaw_bdev
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4cd898b	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0xf4d193ae	d_delete
++EXPORT_SYMBOL vmlinux 0xf4e52bda	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0xf4e8d99d	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0xf4ecdb93	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf50ba020	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0xf51ae235	touch_nmi_watchdog
++EXPORT_SYMBOL vmlinux 0xf51b3d36	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xf51bf88b	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xf5222143	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0xf524085f	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf53d6075	ipv4_specific
++EXPORT_SYMBOL vmlinux 0xf5417cdc	reservation_object_add_excl_fence
++EXPORT_SYMBOL vmlinux 0xf55b3b3d	__arch_hweight16
++EXPORT_SYMBOL vmlinux 0xf587a4b9	__break_lease
++EXPORT_SYMBOL vmlinux 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL vmlinux 0xf5a62ecc	_memset_io
++EXPORT_SYMBOL vmlinux 0xf5bd9aea	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xf5c2d34d	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf5e1558d	crash_shutdown_unregister
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf60eebd4	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0xf61113b7	elevator_exit
++EXPORT_SYMBOL vmlinux 0xf6117512	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0xf61a0948	devm_devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf64cc693	irq_set_chip
++EXPORT_SYMBOL vmlinux 0xf6667333	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0xf66720e6	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0xf669d687	param_ops_string
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf6882615	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0xf6888a90	devm_gpiod_get
++EXPORT_SYMBOL vmlinux 0xf6915a00	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0xf6917334	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0xf69ec301	inet_del_offload
++EXPORT_SYMBOL vmlinux 0xf6a28903	d_lookup
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6c5fa21	unload_nls
++EXPORT_SYMBOL vmlinux 0xf6cf2994	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0xf6dffb4a	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0xf6e7e99e	__frontswap_store
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf71671f6	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xf7205607	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0xf72c8f0b	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0xf72e0709	__d_drop
++EXPORT_SYMBOL vmlinux 0xf737ba5c	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf778f0af	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0xf783c80e	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0xf7927b70	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0xf7bf6516	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0xf7cefec9	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0xf7d4e106	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0xf80b3889	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf812cff6	memscan
++EXPORT_SYMBOL vmlinux 0xf8137439	tcp_filter
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf84b075e	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0xf85e7a0e	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0xf85f92fa	phy_find_first
++EXPORT_SYMBOL vmlinux 0xf865f6ce	pci_dev_get
++EXPORT_SYMBOL vmlinux 0xf86ccdac	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0xf87c8555	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0xf8a34572	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0xf8c016fe	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0xf8c77e56	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0xf8ca0349	dev_mc_del
++EXPORT_SYMBOL vmlinux 0xf8d04f09	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0xf8d23071	sock_no_listen
++EXPORT_SYMBOL vmlinux 0xf8e1ea1c	param_get_ullong
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf90161d1	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0xf9038bcf	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0xf90b95e7	bioset_create
++EXPORT_SYMBOL vmlinux 0xf91590cb	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0xf91a965d	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0xf92069b8	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0xf93fcff7	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0xf94168c4	netif_device_detach
++EXPORT_SYMBOL vmlinux 0xf9566d38	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0xf96f1b5c	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0xf997d9fa	simple_getattr
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9c0b663	strlcat
++EXPORT_SYMBOL vmlinux 0xf9f9f729	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0xf9feea4e	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0xfa09668b	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0xfa244cea	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0xfa37ea2f	mdiobus_write
++EXPORT_SYMBOL vmlinux 0xfa47ff4d	__invalidate_device
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa52a9a9	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0xfa5861e9	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa5c93ae	mpage_writepages
++EXPORT_SYMBOL vmlinux 0xfa682315	vfs_getattr
++EXPORT_SYMBOL vmlinux 0xfa8420c0	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0xfa8f58d9	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0xfa988767	ata_port_printk
++EXPORT_SYMBOL vmlinux 0xfa9f5c2c	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0xfabc42fa	of_parse_phandle_with_fixed_args
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfae710e2	PDE_DATA
++EXPORT_SYMBOL vmlinux 0xfaf4af07	devm_gpiod_get_index
++EXPORT_SYMBOL vmlinux 0xfb1b2b2f	icmp_send
++EXPORT_SYMBOL vmlinux 0xfb3bffb2	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0xfb56d6e4	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb712cc2	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0xfb71f560	i2c_use_client
++EXPORT_SYMBOL vmlinux 0xfb8a2483	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0xfb935be6	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbdd4c01	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0xfbe26966	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0xfbf75378	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0xfbfb28d5	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc0e3b96	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0xfc369578	setattr_copy
++EXPORT_SYMBOL vmlinux 0xfc39d476	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0xfc39dd94	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc3b160f	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xfc3f7970	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0xfc7817a0	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0xfc85f6cf	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0xfc8bfbd3	blkdev_put
++EXPORT_SYMBOL vmlinux 0xfc9c54ae	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0xfcb7ec20	dev_crit
++EXPORT_SYMBOL vmlinux 0xfcb926cd	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xfcc16431	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcc4b5f4	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0xfcdc14d6	frame_vector_to_pfns
++EXPORT_SYMBOL vmlinux 0xfce09d40	inet_release
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcf97754	register_shrinker
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfd1460dd	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0xfd48288c	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0xfd5a6be6	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0xfd617c5a	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xfd8f585c	vio_find_node
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfda0665d	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0xfdb36137	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0xfdb6cedc	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0xfdb763d0	dquot_enable
++EXPORT_SYMBOL vmlinux 0xfdb9b629	ioread32be
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfde9b826	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0xfdec73de	account_page_redirty
++EXPORT_SYMBOL vmlinux 0xfdecab6f	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0xfded48ed	enable_kernel_fp
++EXPORT_SYMBOL vmlinux 0xfdf1f87a	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe112c0e	module_layout
++EXPORT_SYMBOL vmlinux 0xfe17047b	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xfe19b937	pnv_cxl_release_hwirqs
++EXPORT_SYMBOL vmlinux 0xfe26fc7c	nr_node_ids
++EXPORT_SYMBOL vmlinux 0xfe2fc7a9	generic_writepages
++EXPORT_SYMBOL vmlinux 0xfe3ca0ea	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0xfe5a2431	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe5dd8e4	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0xfe768039	phys_mem_access_prot
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe916dc6	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0xfe94b54a	of_device_get_match_data
++EXPORT_SYMBOL vmlinux 0xfea385aa	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0xfea5e448	neigh_update
++EXPORT_SYMBOL vmlinux 0xfed47c06	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfeebc7c4	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0xff0cf5fe	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0xff1765c7	rtas_call
++EXPORT_SYMBOL vmlinux 0xff1aadf4	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0xff1ddd68	inet_offloads
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff2f298e	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0xff42c7d8	mmc_request_done
++EXPORT_SYMBOL vmlinux 0xff4a5932	dump_align
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff903b43	frame_vector_destroy
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffb641ed	kthread_stop
++EXPORT_SYMBOL vmlinux 0xffba1262	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xfffe1dd7	netdev_change_features
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x043203a1	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x064fb9de	kvmppc_handle_store
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x08aee50f	kvm_vcpu_write_guest_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x0ad07ce0	kvmppc_load_last_inst
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x0fe7374c	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x134c50fc	kvm_vcpu_read_guest_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x15c0b0f6	kvm_vcpu_mark_page_dirty
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x16b40bde	kvmppc_hv_ops
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x1d5d1d95	kvmppc_sanity_check
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x1e89fd7c	kvm_vcpu_gfn_to_hva
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x1ec74664	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x223a9e8b	kvm_clear_guest
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x280f59bb	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x29ab7c68	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x2ff18f67	kvmppc_set_msr
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x3209ade0	mark_page_dirty
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x36d68cb9	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x3724668a	vcpu_load
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x3e1f72e0	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x40ac0835	kvmppc_core_queue_dec
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x42cc8e39	kvm_vcpu_block
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x48ba1ac2	kvm_vcpu_gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x4ff7d754	kvm_unmap_hva
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x52346a95	gfn_to_hva
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x5e087fb8	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x61eb27cd	kvmppc_core_prepare_to_enter
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x649ee4f5	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x650c3dff	kvm_vcpu_gfn_to_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x68aef45f	kvm_vcpu_read_guest
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x6c3e53cb	kvmppc_handle_load
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x6e519e7d	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x75784662	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x7771202b	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x7c87a42b	kvmppc_h_logical_ci_load
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x7f3ad15c	kvmppc_kvm_pv
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x813d2550	kvm_debugfs_dir
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x8425d817	kvmppc_book3s_queue_irqprio
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x85a5a4b2	__gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x88712884	gfn_to_memslot
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x896aade2	gfn_to_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x8f925005	vcpu_put
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x915c9f76	kvm_vcpu_write_guest
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x944dbe75	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x952d1f40	kvm_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x95806574	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x99168c2e	kvmppc_st
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x9afd4df9	kvm_vcpu_read_guest_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0x9b505464	kvm_vcpu_gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xa461b016	gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xa4d952e9	kvmppc_unfixup_split_real
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xa8e5566b	gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xaa5b8672	kvmppc_rtas_hcall
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xab59d373	kvmppc_free_lpid
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xac0c425f	kvmppc_xics_hcall
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xb13640cf	kvm_write_guest
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xbd4fa6ae	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xc04d88d1	kvm_read_guest
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xc1959760	kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xc3109f8b	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xc70e4b59	kvmppc_claim_lpid
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xcae621c2	kvmppc_ld
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xcbb2efc8	kvm_init
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xcc44961f	kvmppc_alloc_lpid
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xd1888733	kvmppc_core_pending_dec
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xd1c5dd75	kvmppc_gpa_to_pfn
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xd337aa75	kvmppc_prepare_to_enter
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xd9149b61	kvmppc_pr_ops
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xde15a2d8	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xe525cd5a	kvmppc_core_queue_program
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xe6f63ff4	kvm_write_guest_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xeb1f516a	kvm_put_kvm
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xef11cb35	__tracepoint_kvm_ppc_instr
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xefd146dd	kvmppc_emulate_mmio
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf1c04c7f	kvmppc_h_logical_ci_store
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf1c0c14d	kvmppc_core_dequeue_dec
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf36f4fe4	kvm_io_bus_write
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf3a94516	kvm_get_dirty_log
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf3c27064	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf4985bf5	kvm_vcpu_init
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf4da3546	kvmppc_init_lpid
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xf85b1913	kvm_get_kvm
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xfcc5b781	kvm_read_guest_page
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xfe2f5cb6	kvm_flush_remote_tlbs
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm 0xfe30af78	kvm_release_page_clean
++EXPORT_SYMBOL_GPL arch/powerpc/kvm/kvm-pr 0x1c50881e	kvmppc_emulate_instruction
++EXPORT_SYMBOL_GPL crypto/af_alg 0x0009a872	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0x1971a792	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0x2193f901	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x324ea0f0	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x4d0d8f45	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x508e0b94	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x58716898	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0x67ed5d6c	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x71646ff4	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xd951176f	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0xfdb51809	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x8b34f1dd	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x2b888ada	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x4c26ed43	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x038f56fd	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x8537d74c	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x16e9e5a5	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x3e90f4c8	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x487a1661	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xe8caf508	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x3f44b305	async_xor_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0xbbf08e8e	async_xor
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x93ebec2d	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x3d587901	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0xd06dc0ac	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x244abe2b	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x6735a1f7	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/cryptd 0x06b0fa87	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x09b6da83	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x3ab0b20d	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x438f74d1	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x482e8fcd	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x965f1e9a	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xa90e1e64	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xc1199503	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xc64d072d	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xcfb083b2	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0x593af175	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x1116c8f4	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x28596c37	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x4ece78ae	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x53b2c95a	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x6e1e641f	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x7db156f6	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x7e6b7ee7	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x8347667c	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xec456886	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x0bbdcce3	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x8ffeec9b	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xc4440a32	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xf6d84bfc	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x33a3f36b	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0xaaf83a00	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0x1bbe616c	xts_crypt
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x0f371ec5	ahci_host_activate
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x0f4be5d5	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x1a80cafb	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x1e423502	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x30ec2b65	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x30ef516b	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x342f37ce	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x3ac02bd1	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x3af688f3	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x4c1da5fd	ahci_start_fis_rx
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x4cb80a06	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x5e601ce3	ahci_handle_port_intr
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8ba854ac	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xa4af5454	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xabe9bb70	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xbdab21de	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc37bba02	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xcdb31ebc	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe1194706	ahci_qc_issue
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe96c06bc	ahci_error_handler
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xebd64f63	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf4f2582b	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf84c7b19	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xff91b07f	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x0ad9aa49	ahci_platform_get_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x0c2a7faa	ahci_platform_enable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x1d80b5e3	ahci_platform_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x38e4163c	ahci_platform_init_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x58ce4659	ahci_platform_suspend_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x5995f4b4	ahci_platform_enable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x71defb62	ahci_platform_disable_regulators
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x8a156d69	ahci_platform_suspend
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0x8dfe3e0d	ahci_platform_disable_clks
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xa711b615	ahci_platform_enable_resources
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xbda045c0	ahci_platform_resume_host
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xce063504	ahci_platform_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci_platform 0xeea6fe2d	ahci_platform_disable_resources
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0x1ca5a4bb	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/ata/pata_sis 0xf2972347	sis_info133_for_sata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x3d060fa1	__regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0x75f7d4e1	__regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xcdafec84	__devm_regmap_init_spmi_base
++EXPORT_SYMBOL_GPL drivers/base/regmap/regmap-spmi 0xd387b571	__devm_regmap_init_spmi_ext
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x22e361ce	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x26669f36	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x2fa43b9c	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3175d084	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x38266883	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x4cc22733	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x5420efe7	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x5a2e4bfd	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x5e7bcfab	bcma_chipco_b_mii_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x66bcd2b0	bcma_host_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6b7a5e55	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x7b5c04b4	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x927ac710	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xa5921947	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xa98c60ba	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xaccb8fef	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb88a3708	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xbc8349e5	bcma_host_pci_down
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xcf0ac8bb	bcma_host_pci_up
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd5eaca96	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd9e00b71	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd9e37115	bcma_find_core_unit
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdd72bcd6	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe6e194b2	bcma_core_pci_power_save
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x14194ed0	btbcm_setup_patchram
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x25a76212	btbcm_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x5627ad31	btbcm_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0x948eeffd	btbcm_setup_apple
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xb1808136	btbcm_initialize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btbcm 0xdae7687b	btbcm_finalize
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x0c4435dd	btintel_set_diag_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x2c6f242f	btintel_load_ddc_config
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x30fb2e42	btintel_regmap_init
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x3e4e0728	btintel_read_version
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x3ef8cd6b	btintel_set_event_mask_mfg
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x415ec53f	btintel_set_event_mask
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x46263f7b	btintel_hw_error
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x925bcc37	btintel_secure_send
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0x9fd95f9a	btintel_check_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xa35250a3	btintel_version_info
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xa537526c	btintel_set_diag
++EXPORT_SYMBOL_GPL drivers/bluetooth/btintel 0xc90d21a5	btintel_set_bdaddr
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x10c0c3b2	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x1ed6459d	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x21855748	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x251eb094	btmrvl_pscan_window_reporting
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x394111a1	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x67a9b0b3	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x93c17cbb	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xa52e347f	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xb592857c	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xdee93b70	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xe9adb704	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x21b98512	qca_uart_setup_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btqca 0x842ef75d	qca_set_bdaddr_rome
++EXPORT_SYMBOL_GPL drivers/bluetooth/btrtl 0x99340ce3	btrtl_setup_realtek
++EXPORT_SYMBOL_GPL drivers/bluetooth/hci_uart 0x7cf092a7	h4_recv_buf
++EXPORT_SYMBOL_GPL drivers/crypto/nx/nx-compress 0x21419608	nx842_crypto_compress
++EXPORT_SYMBOL_GPL drivers/crypto/nx/nx-compress 0xaab4e508	nx842_crypto_decompress
++EXPORT_SYMBOL_GPL drivers/crypto/nx/nx-compress 0xaef52668	nx842_crypto_exit
++EXPORT_SYMBOL_GPL drivers/crypto/nx/nx-compress 0xf49df54c	nx842_crypto_init
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x15fecf31	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x8db1acac	dw_dma_disable
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x9a790542	dw_dma_filter
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xb6914ae0	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xc46a2534	dw_dma_enable
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x31c68fda	hsu_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0x6b5fe593	hsu_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/hsu/hsu_dma 0xf50a0c95	hsu_dma_irq
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0x7c3c1843	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xc92c5657	vchan_find_desc
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xd3d3ff73	vchan_init
++EXPORT_SYMBOL_GPL drivers/dma/virt-dma 0xece8cf9a	vchan_tx_submit
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x016c50a8	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x017ff173	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0506cf2a	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0bce1c8e	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x22126585	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2a817387	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c8dd6b8	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3d0e047b	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3d8243be	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x451e78a9	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4a355b95	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4c5e569a	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x75b7fd01	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x8cbf48ea	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x93981bac	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa5f6f07b	edac_mc_add_mc_with_groups
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa87846d9	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc6abedf7	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xcccf38d7	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd440b2e7	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd7ac4ffb	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xdc37cf51	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe2d6f207	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf91f48b9	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x021e144d	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x0ff4ccd7	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x63a58967	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x6d22e674	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x81cf0d04	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xbadf9e52	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x380d757a	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x459e8ec0	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x449e46bc	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x782eeee8	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x2f539ace	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x307915c0	drm_display_mode_from_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x3ea14443	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x4656ce8d	drm_do_get_edid
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x7f8a3c5d	of_get_drm_display_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xb7966a80	drm_display_mode_to_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x29640787	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x6adf436b	ttm_prime_fd_to_handle
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x81e6208d	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x98828c4b	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0xce36343e	ttm_prime_handle_to_fd
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x02561241	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x06e9c1e1	__hid_request
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0943dd7d	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x09686230	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x177822f9	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x1f2c46e8	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x1fc49801	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x32352977	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3e54997f	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3fbcce51	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5385a49a	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x61330bdc	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x62d86300	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x68533dae	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x73c6d775	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x95523cd2	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x98be66de	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa22fa653	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa378d4b0	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xaa581441	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xac7ff977	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xad0d207e	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb41135a4	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb703a57c	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbaa7ebc7	hid_field_extract
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbd6bf32f	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc25588d6	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc3d48653	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd0653721	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd6c4bc5f	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xda67bf40	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xde7ff72f	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe609ff38	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe7efd009	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf5856693	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf98929fd	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0xcdead2d2	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x38405b29	roccat_common2_sysfs_write
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x589c8e20	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xc9d4006d	roccat_common2_device_init_struct
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xdb5fd393	roccat_common2_sysfs_read
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xe2cc99d4	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xe8eb24e9	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x003c5073	sensor_hub_device_close
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x12468c65	hid_sensor_get_usage_index
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x28f396e5	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x7222d33e	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x7be27cf5	sensor_hub_device_open
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xaa8e0ba8	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xcdac73f0	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xe59507a9	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xf9684b77	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0xe25e7625	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x0cdc71c4	hsi_port_unregister_clients
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x0eac1ba5	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x0f2ab9c2	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x18794235	hsi_new_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x277b17f7	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x32678851	hsi_add_clients_from_dt
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x3d5a9c48	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x3fc9e582	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x41415a80	hsi_remove_client
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x744b86d1	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x74ec8b98	hsi_get_channel_id_by_name
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x7d9a0da9	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x86305472	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x94e0df18	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xafa2f02b	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xdd9fa13a	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xee71ee6a	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xf18038a5	hsi_async
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x6bf25125	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xb21396af	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xbc75916e	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x00ef47c8	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x027a7def	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x04fe0692	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x1101f398	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x15d56865	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x1fb2fcec	pmbus_write_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x3185b68c	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x395ca342	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x6a706d37	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x8341aeb6	pmbus_regulator_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x8dfb8ee9	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x95329ca0	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xb4bf9b62	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xb785e7ef	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xeca05286	pmbus_update_byte_data
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x43353938	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x4bdabdf6	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x4cbd4fc2	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x53f51ce0	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x8c898b96	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xca05aec1	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xff16246d	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x8962dad6	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xc3bc2649	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xc61fef08	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xd2899138	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xd2da9fe3	stm_source_write
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x20f1d054	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x3a8b606a	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x6a735f1f	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x7facb55d	i2c_dw_probe
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xd898390b	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x10841eee	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xf0de020a	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x747208d3	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xed1ffaf7	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x1d936721	bmc150_accel_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0x3b48d256	bmc150_accel_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/accel/bmc150-accel-core 0xeec7b4ab	bmc150_accel_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x1239a140	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x31849561	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x5046f582	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x5a9459ed	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x61643391	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x64a5f4dd	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x74bdc533	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x8130d9f4	ad_sd_reset
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x83746d28	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x858cfbaa	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/twl4030-madc 0xb1be4a75	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x733650f5	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/buffer/industrialio-buffer-cb 0x9733fdf7	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xb8e0c106	ad5592r_remove
++EXPORT_SYMBOL_GPL drivers/iio/dac/ad5592r-base 0xe747af97	ad5592r_probe
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0x1262d610	bmg160_core_remove
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xb6ba4f64	bmg160_pm_ops
++EXPORT_SYMBOL_GPL drivers/iio/gyro/bmg160_core 0xf4b10589	bmg160_core_probe
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x008b6c41	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x00c73664	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x23663b8f	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x3cc4d2ce	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x47eb5096	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x7e3cc772	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x882046d6	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x9f2e1da7	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xab634346	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xacee641a	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xc459efa6	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xd27e6807	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x016e1ac3	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x050666e9	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x1e8d6cad	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x249f8962	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2daa7124	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x333382ed	iio_write_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x45cfdbf5	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4921882f	devm_iio_device_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x52278b54	devm_iio_device_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x55e305d4	devm_iio_device_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5a7a9ff0	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5af5fa6e	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6badbb88	iio_buffer_put
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x83406057	iio_read_channel_average_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x860e5af6	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x8df4fa15	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x98d447ed	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9dee6076	devm_iio_trigger_alloc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa6dfa960	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa748aed2	devm_iio_trigger_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc33a0df6	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xcbdaedc7	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xcd5811b6	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd393fe66	iio_buffer_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd81d95f2	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe527e371	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe5b4cc5a	devm_iio_device_free
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xeb8bcfe1	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf74a6f0b	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xfa40a32e	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xfaa3697a	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0x4c4646e9	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/matrix-keymap 0xf4028e7d	matrix_keypad_parse_of_params
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xbcebf9f4	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x06667d22	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xcf27c3d4	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xdc2a4d9b	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x5c999043	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x7cff7d6a	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xfea53c8d	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x04bcaa82	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x0a96e91b	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x0b6950f1	tsc200x_regmap_config
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x3defb3d5	tsc200x_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x911a8392	tsc200x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/tsc200x-core 0x916302f0	tsc200x_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x1191a44c	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x187b4c8b	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x42ced889	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x4d5d4fbd	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x5e89a623	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x5f70c5d3	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x77421f40	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x93dac54d	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xc7eae61f	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xc921f3d6	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xf6342c99	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xfd0d4882	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x239e6f62	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x424627bc	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x72a6005a	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xb247d043	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xbb08e1ab	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xc4426582	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xcf298a15	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xf3bf2dd8	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xfa4cefaf	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x014fc676	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x16687bfb	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x21b0177a	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x2ece69f7	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x34a78c98	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x42b8a49c	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x4cf14050	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x59cefa2c	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x6e152a5c	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x70a85432	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa2fab5d1	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa3151853	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa9688f5d	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xb326307b	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xd3a5e63f	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xdac4f531	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xfd252a2c	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xfec0dc3c	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x144abdd0	led_get_flash_fault
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x1c61ae8a	led_set_flash_timeout
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x3036a772	led_set_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x3b0b14c8	led_classdev_flash_unregister
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0x91824a44	led_classdev_flash_register
++EXPORT_SYMBOL_GPL drivers/leds/led-class-flash 0xff3b77aa	led_update_flash_brightness
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x0272b8e0	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x2a227fc7	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x5a9e830c	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x6fe5d110	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x749b7fa5	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x7dce70fc	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x7f416d54	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x9430055f	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x9c7d54d0	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xa69a6133	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xfbd97097	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x07d5978c	wf_unregister_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x0a0527be	wf_register_client
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x1a9f6c52	wf_put_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x332e73bb	wf_unregister_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x69a914d0	wf_put_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x75147afa	wf_set_overtemp
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0x8d72ba7f	wf_get_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xbcace2a5	wf_unregister_client
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xc1414605	wf_register_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xc9aab0df	wf_register_control
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xe9c33c29	wf_get_sensor
++EXPORT_SYMBOL_GPL drivers/macintosh/windfarm_core 0xed82a14f	wf_clear_overtemp
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x3492a885	mcb_request_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x41bcc193	mcb_alloc_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x4f1bc6d6	mcb_device_register
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x6d89a981	mcb_bus_add_devices
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x712f2489	mcb_bus_get
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x87eaf053	mcb_free_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0x8bf52ac0	mcb_release_mem
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xa2d02ef8	mcb_get_irq
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xac9617b1	__mcb_register_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc258de57	mcb_release_bus
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xc6284fdf	mcb_unregister_driver
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xddb02fbd	mcb_alloc_dev
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xe9fa8639	chameleon_parse_cells
++EXPORT_SYMBOL_GPL drivers/mcb/mcb 0xed8e20b3	mcb_bus_put
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x021811cf	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x0f0677b8	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x10e6a889	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1154f7a1	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x15aa8e40	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x174c2a29	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2205bcf9	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3fc7cb7f	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x469f38de	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4ba51ecf	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5b2a89c7	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5d950f2a	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5e21030c	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5ed04550	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6eef9654	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x74ab7b0f	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x84efb763	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8fe32879	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x91f02667	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x93f7fc02	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa1de5277	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa81bf581	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb7d964de	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbbace2cd	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc6673631	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc8a2f711	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe3de2ba2	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe902838d	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xec919105	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xeea27f46	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfad1ec73	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x1e0cb305	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x7c4b27cc	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x977de181	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xbf07c504	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xc86855f1	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xc9ae131c	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xdb6fdd3b	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xe5a9da57	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xf26660a8	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x08ab7ead	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6aba7f5e	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9310ba06	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9c256008	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa1d2413a	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa448e19f	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xafbda3f3	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xcbb1bae2	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x46e94e84	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x62b3edb6	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x9035476b	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x9ce4b44c	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xacfb1ae4	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xb461bdf1	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xc154b9f6	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x21ed4f3a	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x307391e0	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x24b99941	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4430764e	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x45ab972a	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x8768b707	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa68e1f06	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xabc207c8	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xcf24502a	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd0726e06	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xe538bd70	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfad9d53a	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfc62ef4e	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x17c36f29	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42dbdfc3	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x49b35849	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x55b4bd4d	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x827a42f4	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9f624559	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xacaa8c98	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xafeda29f	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd29923fb	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf375d009	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf5455120	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x10c8aa1f	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x53b1d14c	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x7f731366	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xb7d9748c	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xbe865583	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xc30e1ef4	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe7969f4c	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe796f36a	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xf1c91e57	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xfa888ee0	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x0aa92260	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x3b7cb328	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x51e057b7	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xb3ad091a	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xcfab6830	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xeb1175de	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xf4916468	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x0808edf8	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x0bdbb849	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x258dc581	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x28239414	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x30a90d9e	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x4e31041f	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x618a466e	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x623bddf1	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7ef1a8ff	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9426ca85	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x99a81ab3	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xa825d754	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xb5f0f883	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbe439c19	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xcb10f1f5	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xd0b61eff	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xd4a3403a	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xe2cad982	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/as102_fe 0xd2998f8b	as102_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/cx24117 0x59b24dd9	cx24117_attach
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0x1218f455	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/media 0x0de6abd3	media_entity_put
++EXPORT_SYMBOL_GPL drivers/media/media 0x22fd6433	media_entity_get
++EXPORT_SYMBOL_GPL drivers/media/media 0x3a77a5b8	__media_device_register
++EXPORT_SYMBOL_GPL drivers/media/media 0x49d7f9bb	media_entity_pipeline_start
++EXPORT_SYMBOL_GPL drivers/media/media 0x49fe1c2d	media_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/media 0x5b790f8a	media_device_register_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0x5d69ec14	media_entity_cleanup
++EXPORT_SYMBOL_GPL drivers/media/media 0x6c7a6979	media_entity_init
++EXPORT_SYMBOL_GPL drivers/media/media 0x8591e526	media_entity_setup_link
++EXPORT_SYMBOL_GPL drivers/media/media 0x9252527d	media_entity_pipeline_stop
++EXPORT_SYMBOL_GPL drivers/media/media 0x9f724db9	media_device_unregister_entity
++EXPORT_SYMBOL_GPL drivers/media/media 0xa6a4e372	media_entity_create_link
++EXPORT_SYMBOL_GPL drivers/media/media 0xa7a6d5f2	__media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0xda6bf0bf	media_entity_graph_walk_start
++EXPORT_SYMBOL_GPL drivers/media/media 0xdcddc366	media_entity_remote_pad
++EXPORT_SYMBOL_GPL drivers/media/media 0xec7f14e6	media_entity_remove_links
++EXPORT_SYMBOL_GPL drivers/media/media 0xeca28836	media_entity_find_link
++EXPORT_SYMBOL_GPL drivers/media/media 0xecb0a80a	media_entity_graph_walk_next
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0xf0928a3a	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x0427a664	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x1d09973f	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x247c093b	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x60e09851	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x61566994	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x689309f8	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x8a15c5f9	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x9d8e44fd	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xb5046126	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xbbcaa4c9	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xbcc1014a	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xbd86156e	mantis_input_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xbea3cff6	mantis_input_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xc351b10b	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd3202df9	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd7661564	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd9b0ceba	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xe698ee2d	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xf942bf20	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0e90eafb	saa7134_ts_queue_setup
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0f26ae88	saa7134_enum_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x1f9ed219	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x23228797	saa7134_ts_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x2b38e450	saa7134_s_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x2c4d5e1a	saa7134_g_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x2e35cb45	saa7134_g_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x2fcc2fb7	saa7134_querycap
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x3a24623c	saa7134_g_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x689e0e3e	saa7134_s_input
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x6fa62895	saa7134_stop_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x701d7336	saa7134_g_frequency
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x819b18a9	saa7134_ts_start_streaming
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x9e5203f3	saa7134_ts_buffer_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa769bc99	saa7134_querystd
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xb0252da2	saa7134_s_tuner
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc9f88f4d	saa7134_s_std
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xd4108b3c	saa7134_vb2_buffer_queue
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xf2aadab9	saa7134_ts_buffer_prepare
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x17d8ed64	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x1d892a16	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x29543b19	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x3f553479	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x6cd92e3a	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xaa457e3d	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xbe9f4c6b	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x0b2585ce	xvip_get_format_by_fourcc
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x1b299983	xvip_enum_frame_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x38807b1e	xvip_enum_mbus_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x3c7eb685	xvip_set_format_size
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x490bd11c	xvip_get_format_by_code
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x843d4da5	xvip_of_get_format
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0x8d2a2767	xvip_clr_and_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xd36bb7ec	xvip_init_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xd6b1be88	xvip_cleanup_resources
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-video 0xe85e0bdb	xvip_clr_or_set
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x3c16a6b1	xvtc_generator_stop
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0x47d7900b	xvtc_generator_start
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0xa8a0f912	xvtc_put
++EXPORT_SYMBOL_GPL drivers/media/platform/xilinx/xilinx-vtc 0xd359bd79	xvtc_of_get
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x4818e8b6	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0xaab13daa	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x03dc6149	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x0c00e812	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x0f011390	rc_close
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x1361a916	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x1e92dad8	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x1f9186fe	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x36a4c5af	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x45f08bbb	rc_open
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x7c45750b	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9622da38	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9d1dc9f2	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xa8c3d59a	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb1bcc6b8	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb3f3de75	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xbd585b2e	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc60e2e9e	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc62409e3	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xce46c37b	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xe8aa6d5f	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0x601eeca7	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0x591a5d0d	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0x37e14f36	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0xa5e4944a	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0xc087081d	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x01221894	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x703e7a5f	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xd6ab77e6	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x353f2389	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x5684aa30	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0xe6483b3d	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x0fc69163	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x8b124648	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0xd32e9551	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x0ec988d2	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x23bf76b1	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x2d520250	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x3291510b	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x332edff5	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x4219c8d2	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x48011d78	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x5a0fa118	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x615e3e1a	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x76e9a390	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x88b765fe	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x975a4749	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa2bb6b55	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa7a55f57	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xbccf22dc	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xc6cbc473	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd466533b	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xdd7c54aa	cx231xx_get_i2c_adap
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe26c40f8	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe8fd0267	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0x1de81d9b	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0xf17b49f8	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x026a027b	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x0519f84c	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x072913b6	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x08175a4b	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x28c2e489	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3ba607c6	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3c004d27	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x5aef73c4	em28xx_find_led
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x5e94ddac	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x62210b08	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x673cf82d	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6d578f78	em28xx_boards
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x83c8d824	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x93927589	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xb46fabd1	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcc0a348f	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xcd75ef7f	em28xx_free_device
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xe626ad60	em28xx_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xf0cbb048	em28xx_toggle_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xfa16c2f3	em28xx_init_camera
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x06e0e88e	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x9fd19163	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xb516fc9b	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xc25d17c3	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x04d0dabc	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x352f6486	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xbc63bc30	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xc49ea600	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xeb71f0aa	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf345602a	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x08982d59	v4l2_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x4103badb	v4l2_print_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x5491c182	v4l2_enum_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xae15a915	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xb0891da2	v4l2_dv_timings_presets
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xdfa5a008	v4l2_valid_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf0e1988c	v4l2_find_dv_timings_cap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-dv-timings 0xf98d0f9d	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0x0dec5451	v4l2_flash_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-flash-led-class 0xa4464096	v4l2_flash_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x0355a150	v4l2_m2m_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x05520e60	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x06d328be	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x1735c1f9	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x313fe848	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x45acf0a6	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x48cd22fc	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x491d4d01	v4l2_m2m_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x49cdf495	v4l2_m2m_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x5d98e32a	v4l2_m2m_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6076da77	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x619db0f6	v4l2_m2m_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6379ed03	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x693142ae	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6e05e19a	v4l2_m2m_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6f6409a2	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x7b112e85	v4l2_m2m_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9bce585b	v4l2_m2m_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xad7dfdfd	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xca492973	v4l2_m2m_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd0314c41	v4l2_m2m_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd0f7967f	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xde3bef30	v4l2_m2m_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf4ccd95b	v4l2_m2m_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf71aa25a	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf920fe1c	v4l2_m2m_try_schedule
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf97bbfcf	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x063dc6ca	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x0acf549b	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x15f2417f	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x1809889d	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x1b988845	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x2a4da0ae	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x328ab813	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x397603fd	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3b1dc655	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3de1b8fc	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x58105376	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x5a143b0c	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6c968179	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x77d92fc2	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8e5a9cd0	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb1af1bd3	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xc3421766	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xdae9f107	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe6e037e5	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xeaed789e	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xed89d217	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf8a8e60f	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfb56806f	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfeab0158	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x2a8f1ea8	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x3a024489	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x553a86d0	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xd7d07c0b	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xe6bbc9c7	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x185661ba	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x5d497a92	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x60ea0bef	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x027ce85c	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0a8458d9	vb2_core_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0d23800a	vb2_core_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1a80b84a	vb2_core_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d328655	vb2_debug
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x4340c64c	vb2_core_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x4b169341	vb2_core_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x550422e2	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x56d942a3	vb2_core_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x63c65f2c	vb2_core_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x6bb15bef	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x772557be	vb2_discard_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7ed126bf	vb2_core_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x9b02da79	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xbc38eed5	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xbcc956be	vb2_queue_error
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xc31acbcc	vb2_core_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xca545c4c	vb2_core_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd4259756	vb2_core_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x3940f7d2	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xa70deb8a	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x1506d101	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x4a26faa9	vb2_dma_sg_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd30ec30f	vb2_dma_sg_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0xd80827d5	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x06340070	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x077b45c6	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x09a057b1	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x0dbc16ec	_vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x1c87e24b	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x2266b246	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x2ff58b02	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x338cee25	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x4072e3ef	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x51118521	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x51e716fc	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x5d0539fd	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x6243e7cc	vb2_thread_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x6794067b	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x7311ec70	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x876ed788	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8ad00866	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x8cc25398	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x933bf8e2	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0x9e7e8691	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xa3cc9146	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xb556be74	vb2_thread_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc43c1772	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xc833b672	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xcce41a13	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xde404f3a	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xe69f94ab	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xe77e808b	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf005bb2e	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf08d6d10	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xf5c63639	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-v4l2 0xfd70b706	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x0ecf4c7a	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x096bc686	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1021a6c1	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x133adfc4	__tracepoint_vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x14335612	v4l2_compat_ioctl32
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1ef3a428	__tracepoint_vb2_v4l2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2ab9d732	__tracepoint_vb2_v4l2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2f76a77e	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x3a216dae	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4e73fa8d	__tracepoint_vb2_v4l2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x51534b1f	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x53553f00	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x556233e6	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5d54df8e	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5e932b34	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x618a6790	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x6eaf5df6	v4l2_subdev_link_validate
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x70237a64	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x74a017c5	__tracepoint_vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7bfda7d4	__tracepoint_vb2_v4l2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8928cedf	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8ddbd7c2	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9a8a6f1a	v4l2_subdev_link_validate_default
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9b39d719	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa56ab32d	v4l2_src_change_event_subdev_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa5cbaf04	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xaca2544a	__tracepoint_vb2_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xadff61f9	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xbf4878db	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc2379bba	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc6429d8b	__tracepoint_vb2_buf_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc657a259	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xccbcb2a8	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe72c650c	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe8c5f987	v4l2_subdev_notify_event
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf4ddc40c	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf8c179ad	v4l2_src_change_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xfad3cf8d	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x22976912	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x6c0b942d	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xcb4f48fe	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x03230ac9	da9150_bulk_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x55be2c4a	da9150_read_qif
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0x6952de35	da9150_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xa6a70305	da9150_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xc56e2590	da9150_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xf95b7c7c	da9150_bulk_read
++EXPORT_SYMBOL_GPL drivers/mfd/da9150-core 0xfce91b3b	da9150_write_qif
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x2833a4ad	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x3d238735	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x3f2700c4	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x64978e31	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xcfea00a8	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xe9d418b2	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xf7224615	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xfa6efdec	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x114804a3	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x73b32f07	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xf033f088	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x5d91dfcf	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x64dd0194	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x85d20dc6	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x95ca7cfd	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x9f499e33	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xfa961ba7	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xfb08734f	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x7aa14060	lp3943_write_byte
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x85299bfa	lp3943_update_bits
++EXPORT_SYMBOL_GPL drivers/mfd/lp3943 0x858133e5	lp3943_read_byte
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x06ce0f68	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x0f5214e5	mc13xxx_common_exit
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x8b226aa7	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xaafbefa5	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xea41a485	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xf84e51ed	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x0fbce27a	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x425a4682	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x498f2023	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x52018295	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x7593f2b3	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x7624029e	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x77028c68	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x7b492465	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x8140fd53	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xcde10b44	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xec1d02e9	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x17cb0f40	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x7a529ccb	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x421d9c45	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x516110b2	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x9ae6bb17	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xa2f79230	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xdac0b4be	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x06c0a533	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x09f6a4aa	rtsx_pci_dma_unmap_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0e86a880	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3630ab78	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x435ca9b1	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x45140bf2	rtsx_pci_dma_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x594ae696	rtsx_pci_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x60a1e602	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x6d35050b	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x7108d551	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x777dadf2	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x8ce28ae3	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x8cedb527	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x974668ee	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9c51bfe4	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa494e963	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb5d9fa0f	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xbc5ce13a	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xc53f487d	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xcc387070	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd149c933	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xde126545	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xfe9fceeb	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xfef4a078	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x0109fa2e	rtsx_usb_get_rsp
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x3981b4e8	rtsx_usb_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x481606af	rtsx_usb_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x4a7a1256	rtsx_usb_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x5ee0a9dd	rtsx_usb_ep0_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0x91cc0a75	rtsx_usb_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xaa903083	rtsx_usb_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xc61544fa	rtsx_usb_ep0_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xc8c6a8f9	rtsx_usb_get_card_status
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xce208d25	rtsx_usb_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xe39c76f7	rtsx_usb_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xeb25d445	rtsx_usb_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_usb 0xecbb581b	rtsx_usb_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x017c1a99	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x037a1ecd	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0e4599f6	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x17f4be0c	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1c6ef5c4	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x299a88b7	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x320ea4bd	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x392564ef	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x39379446	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x40bd6a1f	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4604028d	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x50102791	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x53799eb2	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5ada2627	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5cc51809	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5e569039	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7f458596	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x80ea806c	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x838d139a	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9332a937	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x94e9f927	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9efaf23a	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9f60b4a2	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xae4ccf49	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb38d6675	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb3fd12ab	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb46affe9	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb522fcd8	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbfcf249b	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc03d8df4	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xdad3a58e	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf368f0ba	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfb004bc3	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xff52b5f7	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x2da6076b	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x6880325a	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x7d556d82	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x8a1e9698	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x940c91fd	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x27c2b436	am335x_tsc_se_set_cache
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x4ae0200b	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xcef000aa	am335x_tsc_se_adc_done
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xe5f6aa17	am335x_tsc_se_set_once
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x3bdf8635	tps65218_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0x5dae03d8	tps65218_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xb11a8c83	tps65218_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/tps65218 0xd26704e3	tps65218_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0x4d5f76e9	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x246c1453	bmp085_regmap_config
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0x9a53b9b2	bmp085_detect
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xf21df7ad	bmp085_remove
++EXPORT_SYMBOL_GPL drivers/misc/bmp085 0xfb4df8a5	bmp085_probe
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x5bb827ab	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xa5b00120	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xaad8a8db	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xe8e536e0	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x0faebc19	cxl_set_master
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x26dafc2c	cxl_perst_reloads_same_image
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x30878ecc	cxl_unmap_afu_irq
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x36637a65	cxl_read_adapter_vpd
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x465f11f7	cxl_fops_get_context
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x49bfc456	cxl_pci_to_afu
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x4a214d52	cxl_psa_map
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x5096095a	cxl_fd_read
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x64b381b6	cxl_release_context
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x650c6637	cxl_map_afu_irq
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x67eaf8ca	cxl_afu_reset
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x7323eb82	cxl_start_context
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x79a109bc	cxl_allocate_afu_irqs
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x81847cc4	cxl_fd_open
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x818ccf52	cxl_fd_poll
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x8740bc47	cxl_psa_unmap
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0x87b82661	cxl_get_context
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xada16397	cxl_fd_ioctl
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xb104bf1e	cxl_get_fd
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xb665d6a3	cxl_process_element
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xb7792b0f	cxl_pci_to_cfg_record
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xc18f9908	cxl_fd_mmap
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xce725fd4	cxl_free_afu_irqs
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xdde8ace6	cxl_dev_context_init
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xf28fd471	cxl_start_work
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xf40437fa	cxl_fd_release
++EXPORT_SYMBOL_GPL drivers/misc/cxl/cxl 0xf79ef942	cxl_stop_context
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/misc/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x793fc8de	eeprom_93cx6_multireadb
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0xdb9ca14b	eeprom_93cx6_readb
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x16c557b0	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x23c0c639	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x39925c83	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x4079c84e	enclosure_component_alloc
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x75f401ad	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xbbf769d9	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xbc0535be	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xeeb67c35	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x10b868f7	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x22a7f39e	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x4a6921d0	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x5694a393	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x7293009b	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x7d840469	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xbc3c88a9	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xc3b11617	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x95ea0797	st_register
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xbe92fb75	st_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x02160476	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x198bc616	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x1f05dd4a	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x22638f92	sdhci_set_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x331f64ab	sdhci_set_uhs_signaling
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x70bcfc61	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x736c6a04	sdhci_set_bus_width
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x77179f11	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x8fda1f06	sdhci_send_command
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x954f0666	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xc4b16d72	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xc72ce78a	sdhci_reset
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xc9c0433b	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xe297edfd	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x4af01d31	sdhci_pltfm_suspend
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x546fb3ed	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x62a17d49	sdhci_pltfm_resume
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x673bd746	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x6df19d32	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x7d54d632	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xa3cd79eb	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xf44d3a92	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xf72be11d	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x2e1491bc	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xd30ab42a	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xec2391c2	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x3f67e958	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xb2cc6d0e	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xcc9e26de	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0x5d594059	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x3dea8726	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xc4b1f058	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xd9f664a2	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0206d65d	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x029c1cee	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x038eb529	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0a6251d3	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2f5cd2b1	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x392fd5dc	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x39e2c0d1	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x53512ba7	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x54fb8240	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x58ec4653	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5d6f65ea	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6f163c3f	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x70554a06	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7b1756cc	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7c7f9303	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7ea0ad37	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8afdcf20	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x92090ac9	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x99a2e484	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9b94a306	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9f113a80	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa3f5a993	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa536bb61	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xac4f4ba7	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xbd0c479f	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xbddbceac	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xbf7814db	mtd_block_isreserved
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc2248903	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc4744323	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd3444381	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd96516e2	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xdc2ebb09	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe1368edf	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe13ecb6e	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe150f84e	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe501784b	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe7123c5a	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf079b1e5	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf5dc71d0	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf9f0fff6	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfac5f0c9	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xff0cef79	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x0952732d	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x76cdf42b	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xb92bc3c5	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xba633ae0	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xffe3dcf5	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x0b80e5fb	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0xc91d7251	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0x57773cd1	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x183042a8	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0xb46b54a9	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/spi-nor/spi-nor 0x0a349ead	spi_nor_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x05edcf1e	ubi_leb_read_sg
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x07c48d94	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x14f3d06e	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5880100d	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x73c15ffc	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8653f163	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x91233bd5	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x952891f1	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xa60021a2	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xcdd7bab6	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xda4ba855	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe22e5641	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe33d247d	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xfdd8f9bc	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xb5bc704d	arcnet_led_event
++EXPORT_SYMBOL_GPL drivers/net/arcnet/arcnet 0xe22f1079	devm_arcnet_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x1d6b2dc6	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x22131009	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x6c168360	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xc15e8e37	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xdd03c0ae	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xfebc187f	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x0eff7d8b	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x27d8af2d	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x2d3908c5	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x324a7098	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x485aa7f3	can_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x4b5326f8	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x5b776d2b	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x5d0a9797	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x6e90ca58	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x89882393	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xa128c507	alloc_canfd_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xaa9cecee	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xad257d0f	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xdd0c5e8c	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xe667c93b	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xee0457e2	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xeefdd475	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xf44f55d5	can_change_state
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x509a7c2c	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x9bcf658f	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xc2ae1427	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xea17ebbc	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x4ea6c099	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x4f3ef0aa	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xae7f7c15	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xefa3523f	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0x2129200f	arc_emac_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/arc/arc_emac 0x9ccafe80	arc_emac_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x03156736	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x04692f27	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x06fbd254	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x075ac7fb	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0df1b2c3	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x104fb361	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x12ea6f1d	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1539b82b	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x15d2a144	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1826b22a	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x19626523	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1a8c8cf2	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1e693e71	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1e83ec84	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x20e1ca1e	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x254f098f	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2c4112a3	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2cb9b631	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2d27145e	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2d941aa7	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2fb71a06	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x337b358e	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x34872d23	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x348bb94c	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x377de9ae	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x38382452	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x394d559a	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x39706db1	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3b662875	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3c23ba51	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3ff9626d	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4216f6de	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4456d5dd	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4492ef9e	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x47177fd6	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x491cf2e1	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4e0e6660	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4fe167ef	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x51de340d	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x560c40e9	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x578d4ef0	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x57ff4262	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5cb64840	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5e36f178	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x63fc9124	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x657b0d8b	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6626e4bf	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x66676850	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6685ff15	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6716a034	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6859a305	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x68c5cc79	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6929b781	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6aec3831	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6e50f5a1	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6e802596	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x71924a78	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7386e84b	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x775d5040	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7ce51310	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7da61eb0	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7e922520	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8264da4f	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8cb05004	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x91a74825	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x91e3b11c	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x930bd1d7	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x934d095d	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x93fbe6a5	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x94209bf5	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x94486c83	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9991d3ae	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x99dead1b	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9d526bf4	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9fbc7cfc	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa03d3771	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa1f5c089	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa45a1016	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa481dbbd	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xae84680f	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaef50277	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaf398500	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb042f36a	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb166398a	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb61a8f9e	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc308483d	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc3846182	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc4a059ab	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc561e8e7	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc593dd68	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc9058e9e	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcc662c51	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcc93365c	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd06adce9	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd0f87a82	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd2a7f6d2	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd48334c4	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd547b290	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd64b2abc	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd8460cb8	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd934ee3e	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd9397152	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd94fb8dd	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdce27407	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdd86bdd4	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdece2073	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe1a3407d	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe280d4f2	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe3d5a34c	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe690e2eb	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xea375e3a	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xeaabc979	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xec7a7bc3	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xece8dfa8	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf0441133	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf1206ad7	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf747da19	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf75c072c	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf765bf83	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf85897d1	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfbf56d0e	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfd319ed2	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfd5b9d05	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfe02da9b	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x008ceed3	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x04a0b65f	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09543b3d	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0ee695e6	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1154ce61	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x11ae5acf	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x13229645	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1fd58f1f	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x226c1b7c	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x25329539	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x26738199	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x310b0f33	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3388322e	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x33d1bac9	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3e4deedb	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x44756d39	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x496a42f5	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5123aa78	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x51e797ce	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x54026e2f	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x657c526d	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6afe28ec	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x73f02dd1	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7696b21c	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7965d52b	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7de3092d	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x821e7449	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x828c9787	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x843c053a	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x84d99a66	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x895093f2	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8ff5c864	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x92725a2e	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa6dd907a	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb9a6922c	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb9ea7653	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc5d2855e	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc8c28605	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcc0b1bcf	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd65f3b42	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd7102a40	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd75b4300	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd9ea9ec3	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe0b2fc60	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe38b24bb	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe7b5d483	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x5e28947e	regmap_encx24j600_spi_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0x8b0e8417	devm_regmap_init_encx24j600
++EXPORT_SYMBOL_GPL drivers/net/ethernet/microchip/encx24j600-regmap 0xac144314	regmap_encx24j600_spi_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x4427b7b5	stmmac_dvr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0x66af9de2	stmmac_dvr_probe
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xaac0ba86	stmmac_suspend
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac 0xe726f50b	stmmac_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x1be552a3	stmmac_get_platform_resources
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x8fb60721	stmmac_probe_config_dt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0x9822a1ea	stmmac_pltfr_pm_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/stmicro/stmmac/stmmac-platform 0xdd9a6728	stmmac_pltfr_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x0cfcca64	cpsw_ale_add_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x0dbf0370	cpsw_ale_del_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x16c2f42b	cpsw_ale_control_get
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x190af9b0	cpsw_ale_stop
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x3e554d38	cpsw_ale_flush_multicast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x3ec252dd	cpsw_ale_control_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x45506363	cpsw_ale_start
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x49694093	cpsw_ale_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x66133ee5	cpsw_ale_set_allmulti
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x870c6375	cpsw_ale_add_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0x9ede023e	cpsw_ale_del_mcast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xa3aea2cb	cpsw_ale_dump
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xef1125d8	cpsw_ale_del_ucast
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xf857f6f9	cpsw_ale_destroy
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/cpsw_ale 0xfecfb566	cpsw_ale_add_ucast
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x1d4507d8	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x557633d5	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x23937ade	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xb9b2fd95	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xea4780d5	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xf357686b	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0x2a581167	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x1ff527ee	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x28c5879e	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x61475ee7	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x6a8ffafa	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x7dddd22b	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xb955e163	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xd3ccf6ed	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xecc587c6	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xf1596aaa	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xf49bc697	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x6318757f	mdio_mux_uninit
++EXPORT_SYMBOL_GPL drivers/net/phy/mdio-mux 0x77253c79	mdio_mux_init
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x39a35f32	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x57e4b95a	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x8ba4b092	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x9c48058c	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x3b8ed378	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x77319996	cdc_ncm_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x79d16593	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x9bb31d24	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xb90ca0c4	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xc6d343e0	cdc_ncm_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xca8eb427	cdc_ncm_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xcdae0b1d	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xce98eb78	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x126039c1	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x27483c55	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x2fac861d	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x761f1938	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xd03d53db	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xf7637821	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x02b7255d	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0583e5cb	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1c4b1bf6	usbnet_update_max_qlen
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x24fd86e2	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2e79c9f5	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x31dd0cef	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x44dcddd3	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x4b9b8d76	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x53d63740	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x5a4a5065	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x613be9ff	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7b146e83	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7f5eb474	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7fbe2dda	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8868f1ca	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8be2e463	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x91436f34	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x93bf0841	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9de09727	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa0d09cc2	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb9b72b14	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbb5026d2	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbc199618	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc84bc32c	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd09e84ab	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd14a543f	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd19b8b13	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd701f82e	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe3b29ada	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe6ce2398	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe8c20335	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xea9fee24	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0x3e55d26a	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0xfcf8a099	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x072afa10	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x19eef3d3	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x29233f8c	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x4cec3841	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x54a9445f	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa4d8c35e	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xaa575a22	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xc564c689	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xcba6b2e3	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xce7229c8	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xd6b92694	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xdc644f6b	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xe67fa232	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf3b5d366	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf621596a	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xfe432b02	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x758ab9e1	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x7da5683b	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xb902b71e	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xbe750a40	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0x6b42f496	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x54d49d21	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x554937d9	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x6f1d4562	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xd55eae29	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xf1d19dc0	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x002b2e74	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0d556623	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0f48dcb7	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x18b78fb4	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x234ceac5	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x30fe705c	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x371f4659	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x51b657cd	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5a40d754	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5f32c1f9	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x622cf855	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x67483e57	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x73eda088	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x746c0eea	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7c77d4b1	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x814f8a6a	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x844e5d4c	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9f44ee10	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9f5ea0b3	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa48908aa	iwl_force_nmi
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa7a56b17	iwl_read32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa7e61401	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa9fc982f	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb23ae967	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb2679f5e	iwl_write8
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb62f1802	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc59cf44b	iwl_parse_nvm_mcc_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc67c31ed	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd70bebef	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xda49f813	iwl_write32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xdc5d1cbf	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe0d3442b	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf5aea4a7	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x1a3cb162	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x212ffde0	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x304edc9a	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x45758af4	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x51d8b406	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x6eb7969c	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x7c998658	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x7e6f3583	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x82d8f3ef	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xb19b35a9	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xce236a9b	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd0b54807	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe00b5f77	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf79c2350	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf9f03dbe	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xfbf94959	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x1aa29aee	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x41e5cc5a	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x5801738c	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x6c1e3390	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xdf39a07a	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xe2af7a81	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xebd548ca	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xfb1803b0	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x23c9f4d0	mwifiex_queue_main_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x31bd9748	mwifiex_alloc_dma_align_buf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x5088defd	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x5961be14	mwifiex_drv_info_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x64cbb578	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x66b3bca9	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x6a866167	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x734aabdd	mwifiex_upload_device_dump
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x8268a240	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x849435d4	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x8bf5d3be	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x94870d57	_mwifiex_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xaacf2324	mwifiex_multi_chan_resync
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xad85b000	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xbd1e3141	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xcc53dd5b	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xce9b3daa	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xcf21fb89	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf91cf4c7	mwifiex_deauthenticate_all
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xfc452914	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x26bc959e	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x5e4b048d	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x5eadd5ac	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x7f994ffa	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x8590f4ac	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xafa1f781	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xc2623839	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xd47d6bae	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xebc0bd78	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x8b8ce10e	dm_savepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0x92c3edb8	dm_restorepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc0eab8a8	dm_writepowerindex
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8192c/rtl8192c-common 0xc2b856e0	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x04f81867	rtl8723_download_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x09e393d5	rtl8723_phy_save_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x0b14abb5	rtl8723_cmd_send_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1783c4db	rtl8723_phy_query_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x183ee268	rtl8723_dm_init_edca_turbo
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x1b7a1609	rtl8723_fw_free_to_go
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x285c569c	rtl8723_save_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x2a36dec8	rtl8723_fw_page_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x30505c27	rtl8723_fw_block_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x33b0b766	rtl8723ae_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x35afbbaf	rtl8723_phy_set_bb_reg
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x37d1dbf0	rtl8723_phy_path_a_standby
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x3f3a8de3	rtl8723_dm_init_dynamic_bb_powersaving
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x5c0cd1e2	rtl8723_phy_init_bb_rf_reg_def
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x64893af0	rtl8723_phy_path_adda_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x6fee3a6c	rtl8723_phy_set_sw_chnl_cmdarray
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x70ef050a	rtl8723be_firmware_selfreset
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x72bd087b	rtl8723_phy_pi_mode_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0x881984ba	rtl8723_dm_init_dynamic_txpower
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xaf4d6d94	rtl8723_phy_calculate_bit_shift
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xc29619f7	rtl8723_phy_rf_serial_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xc878bf83	rtl8723_phy_rf_serial_write
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xc8c425ff	rtl8723_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd27a0f08	rtl8723_phy_path_a_fill_iqk_matrix
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xd27b1509	rtl8723_phy_reload_adda_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xe091e1d2	rtl8723_phy_reload_mac_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xe4bdc1d3	rtl8723_enable_fw_download
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xe86244cf	rtl8723_phy_mac_setting_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtl8723com/rtl8723-common 0xfeabf201	rtl8723_write_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0292beb3	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x0d0b6636	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2921a4d4	rtl_btc_status_false
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x2be8d624	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x3cb7aa0e	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x409fed9f	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x62618823	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x694c8f6c	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x6b4de810	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0x959221a1	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xa3edf5f2	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xab5db05b	rtl_lps_enter
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xaf2db3cb	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb3aa2acb	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xb8aae444	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xcb48cd1d	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdd12830e	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xdea964c8	rtl_lps_leave
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe49d92f3	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xe7ab67b3	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xef59ddad	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/realtek/rtlwifi/rtlwifi 0xf4b821f8	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x7201b98a	rsi_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0x8c3cdb16	rsi_mac80211_detach
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xb4499f7b	rsi_read_pkt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xb98833e5	rsi_91x_deinit
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xdb3ca0e5	rsi_zone_enabled
++EXPORT_SYMBOL_GPL drivers/net/wireless/rsi/rsi_91x 0xea791e33	rsi_91x_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0026b07b	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x03e0a7b8	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0400b07d	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x093efdd8	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x2368374b	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x298af78d	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x2eda3f7c	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x33b61091	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3586f0a9	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x35c4e2de	rt2800_get_key_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x36d3bacc	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x37ef903b	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x39e63ccb	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3c5159d5	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5e58a464	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x71254ff9	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x717338f1	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7faf611a	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x86c57bbf	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x873d10ca	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8e077ee2	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8ebe8bbf	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa47ad9d5	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb452c4d1	rt2800_get_txwi_rxwi_size
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb7d42e8a	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc58513ec	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd10ce8f8	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd34ba75e	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd644f128	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd9e75bb7	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xdd7abb02	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe4374d15	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xea52e093	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf11c534f	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf56c2100	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xfc7852ac	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xfdc69b76	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xff8cac9b	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x0fad1430	rt2800mmio_pretbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x1d91b40e	rt2800mmio_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x2505789d	rt2800mmio_tbtt_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x3e6b2c01	rt2800mmio_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x45529daf	rt2800mmio_get_entry_state
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x487f2408	rt2800mmio_toggle_irq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x58a89ecd	rt2800mmio_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5bf3a843	rt2800mmio_get_txwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5ee1f30a	rt2800mmio_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x5fa4db64	rt2800mmio_interrupt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x77c6684b	rt2800mmio_fill_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x87289158	rt2800mmio_queue_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0x92c0bcd1	rt2800mmio_rxdone_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xbe5159ae	rt2800mmio_write_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc5d1951c	rt2800mmio_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xc6a1455e	rt2800mmio_autowake_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xd2262ee7	rt2800mmio_init_registers
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xe28f94c7	rt2800mmio_txstatus_tasklet
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800mmio 0xf0624f26	rt2800mmio_init_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x095f3d52	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1130020e	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x12fc2512	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1bd8dc37	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1c18f542	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x23868109	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x25d20cc1	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x266719dc	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x281cfdfb	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x32cda13c	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x39d87949	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x43e8fd72	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x494d9593	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x494dc42f	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4ebae4b3	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x58833582	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5c9747fc	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5dc2cb3a	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6641174d	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6f8c5e5e	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x71f2efaa	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7218e9f9	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x796dc1d0	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7aac3f5d	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x84a1364c	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8c2eec14	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8f4fc868	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x90806f7e	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x94d2a847	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x98be9425	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa895876e	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xac3a79b3	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xacea49b1	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xacf9a6c4	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xae87f1fb	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xaea6087c	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb2d8b5a7	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb2e80255	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb6779155	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb8d8a10a	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xca9e0aa0	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd76d5524	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdef31be5	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe71cd050	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xee5baff3	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xff72ab17	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x2487b3d7	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x3832d3a6	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x62b2af40	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x72aac640	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xc7ee847b	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x85aea3e8	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x8bbf2966	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xbbb88056	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xf2971c3c	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x003580f9	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x0661dcd1	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x2142fd25	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x263565d6	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x2f3a6509	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x30e47c48	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x3ce34543	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x4b2edf05	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x4bdb315e	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x70bf0aa7	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xafb0d823	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xc6807674	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xcc538ac2	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xece4f259	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xf5126382	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xffc2caa7	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x29072261	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x2a4c1bff	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x559de382	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x030e24ad	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0774301a	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x082c6c60	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0f1e1432	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x12cae86e	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x173b78aa	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x19693902	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x23e38344	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2e234cb8	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3a7973dd	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4014b187	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4139d940	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4a75d018	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4aeef53e	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4ffc5f4c	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53cce89b	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x593f197a	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5ff26609	wlcore_cmd_generic_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6359ec9f	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x764c4946	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77092dcc	wlcore_get_native_channel_type
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77460f2d	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7890a173	wl1271_ps_elp_wakeup
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x84c985a0	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x87dcbaaa	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x897b8df7	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8b038d2e	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8bfe3538	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8fd19f8e	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x996f37b2	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9bc29651	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9d690fe8	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa43896a4	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb20313a7	wl1271_ps_elp_sleep
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb805a0fa	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc09fb1b8	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc24331d9	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc7ea6bfc	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd0228ece	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd8e4e797	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe3bb6d4c	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe80c44db	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf0d1c279	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfbe83c11	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfcae1540	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xff6f5b69	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x1bb5b1b9	nfcmrvl_nci_recv_frame
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x7062b2cd	nfcmrvl_parse_dt
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0x9ca7bbe9	nfcmrvl_nci_unregister_dev
++EXPORT_SYMBOL_GPL drivers/nfc/nfcmrvl/nfcmrvl 0xb0a694df	nfcmrvl_nci_register_dev
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x3a7ff038	st_nci_hci_event_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x77f0cbbd	st_nci_remove
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0x8a12a845	st_nci_discover_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xabf3f8bc	st_nci_disable_se
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xb1a33d25	st_nci_hci_load_session
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xbfb4629f	st_nci_probe
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xc61d5e6b	st_nci_hci_cmd_received
++EXPORT_SYMBOL_GPL drivers/nfc/st-nci/st-nci 0xe2bf9ab6	st_nci_enable_se
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x0862001f	ntb_transport_tx_free_entry
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x62a4e0ee	ntb_transport_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x8f6a98a2	ntb_transport_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xe92b3732	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf55d6313	ntb_transport_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb_transport 0xf9eb813f	ntb_transport_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x202d4ed6	nvmem_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x224f51bf	nvmem_device_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x3866e217	nvmem_device_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x445a09c0	nvmem_device_cell_write
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x4e5e2b08	nvmem_unregister
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x6c7353cb	devm_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8349a895	nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x85540ebc	nvmem_cell_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8856ca77	nvmem_register
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8c06e340	nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x8d33b9c6	devm_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0x99f018c4	nvmem_cell_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xadcbd63c	devm_nvmem_device_put
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xba2677c8	of_nvmem_cell_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xbaed48ae	nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xc697b0f7	nvmem_device_read
++EXPORT_SYMBOL_GPL drivers/nvmem/nvmem_core 0xebb66632	of_nvmem_device_get
++EXPORT_SYMBOL_GPL drivers/pci/hotplug/rpaphp 0x01cc7086	rpaphp_slot_head
++EXPORT_SYMBOL_GPL drivers/pci/hotplug/rpaphp 0x1daa64e2	rpaphp_deregister_slot
++EXPORT_SYMBOL_GPL drivers/pci/hotplug/rpaphp 0x97abb116	rpaphp_add_slot
++EXPORT_SYMBOL_GPL drivers/pci/hotplug/rpaphp 0xdb7897c3	rpaphp_get_drc_props
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x2afb6d37	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x57a8d3d3	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xac4b80db	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x0b63f457	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x285f5a15	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x61f1c801	mc13xxx_get_num_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xb42133cb	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xd07f5990	mc13xxx_parse_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x49b205f9	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x4f6d5170	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x7ce53d20	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x8819ce0e	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x8a61cc02	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xcc159cc3	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0xcdca81fc	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x011f68fb	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x02816ffe	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x04bf9b7c	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x04cbcfa0	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0942ee7b	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1ab8a105	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x20853fbe	cxgbi_device_find_by_netdev_rcu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x21bdf265	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x276aeace	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2a0dfc62	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2a78c3ae	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x30c6aa4c	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x39bdeffb	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3cc36bbf	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x485e4b3e	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5a0cb834	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5af1d12e	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5d5baa48	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x600a7253	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x604f7ae1	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x62b25092	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x675c431a	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6ab61a7d	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6db4632c	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8b46acab	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8e2d665b	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8fe17b20	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9f25b2fb	cxgbi_device_find_by_netdev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9ffb7d1e	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb98a82d6	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbb65dfe2	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbca6aa5c	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbd070f0d	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbdcbc526	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xbfb73c11	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xcf973ce1	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xda834fc6	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe671f3c8	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe680553f	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe9723c82	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xeb6d85f7	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xec2eb65c	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xecfed4b3	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf1b5a645	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf58d5dfe	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf93dcb50	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x1d6e25e9	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x1fb8a437	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x30453293	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x4db26b9d	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x545aa287	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x57d6c26b	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5d4dbb16	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x61a52e93	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x85851964	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa8296984	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb0533ce8	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb47fe65b	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xe14266b3	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xe2c823ec	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xeddf3ef9	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xef3c728c	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x6eaebea3	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x7d3c3c8b	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x7fb85b43	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x8e171b28	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xdeb56143	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xfa4ab8e4	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x037ed24d	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0f7fbfee	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x178d02a7	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1b10f264	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1b14a1db	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1b6cfac0	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1bf240e8	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x250054f0	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2ed4e65a	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4a3b396c	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4c5a02d4	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5079d492	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5c1c6094	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x68f147a3	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6f551f43	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7d725f17	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x80364701	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x80764564	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x84657b62	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x886f8ee0	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x88ce5c8b	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x96cd014c	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9c4fd3ba	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa9637e6f	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xaebae000	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb24fdab1	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb598a735	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb5efa410	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbc76ca64	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbc8f5596	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc43a1e66	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc4a9d1f4	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc63b0109	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc8a2e748	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc8ee599a	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xce371e12	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd1f77644	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe0c89c47	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe1ce5d7a	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe53cb841	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe6ebcb2c	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfb6bdbbc	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x08f2d328	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x0d2e3b27	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x252b2548	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x272365b3	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2a03da83	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2ab5190c	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x460a903f	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4e08e516	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x53c235f0	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x64feb9ba	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x69d46f73	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xad3282f4	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xb097a06b	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xba4527cf	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xbf5d0379	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xcc6203b5	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xd4ac654a	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x11bbd3ad	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1b3a051a	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3fe628cc	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x41546607	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x46047cac	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x51044b78	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x564e9cb4	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x66498e1a	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7a41e75b	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8022109c	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8874e648	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9828349e	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x98a7b655	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9b16470e	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xabad1791	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xbab10acb	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xbbfb9424	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xbc11b81c	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xbfc863c0	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf65a47a0	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf70591d8	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfc7a5e21	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xff7fc691	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xff8a6114	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x00ba3cb4	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x057c0410	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x05bb455b	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0956405a	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x19b7657e	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1e095b1a	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x20a1ef7a	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x283f5a4b	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x327f7f78	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x48d8aa30	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x52c05093	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5b132fa2	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x66f89d23	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7578772d	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7676eea1	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x789cf564	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x88f40dba	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x88f4bc19	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8ee35953	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x90df5ebd	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9bb3d8b1	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa1762842	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbbda9875	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbf9d45cf	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc2534475	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc5c816ad	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc80ee775	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd1b7cfa7	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd2d8a1dd	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd5d16c08	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xdd9955bf	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe2c9c908	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe4761808	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe78cb1c4	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf0ec72f2	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf18898e1	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf5c52e90	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf8a35cc9	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfc6e42c0	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfd36397c	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x0449675a	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x49fb1732	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x5cb15440	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xc269c20d	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa318dd01	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x16027b33	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x1930b144	ufshcd_dme_set_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x2c48caee	ufshcd_dealloc_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x407fdf33	ufshcd_hold
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x71825feb	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xdd4e4a8f	ufshcd_release
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xebb15f4c	ufshcd_dme_get_attr
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x07b96ac0	ufshcd_pltfrm_runtime_idle
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x127d936a	ufshcd_pltfrm_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x14f504b7	ufshcd_pltfrm_shutdown
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x20c35a90	ufshcd_pltfrm_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x961e42f0	ufshcd_pltfrm_runtime_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0x9b98407c	ufshcd_pltfrm_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd-pltfrm 0xa948ce55	ufshcd_pltfrm_runtime_resume
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x00af1184	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x0dc5f7b4	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x5da8224a	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x6d735915	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xdb55c73d	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x08b4203d	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x1e010b23	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x21144901	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xefa2f622	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x10f55eae	spmi_ext_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1790a12c	spmi_command_wakeup
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x1fad4f1d	spmi_controller_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x2c6351b8	__spmi_driver_register
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x30bcc77d	spmi_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x3ba33462	spmi_device_remove
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x4bb411d1	spmi_controller_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x578158f1	spmi_device_alloc
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x616bdbb4	spmi_device_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x65786914	spmi_ext_register_writel
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8116d2b1	spmi_ext_register_readl
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x840f9457	spmi_command_reset
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x88d49215	spmi_command_shutdown
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8c9ff8ab	spmi_register_zero_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x8cb7437e	spmi_register_read
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0x9f4d254e	spmi_ext_register_write
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xd530f394	spmi_controller_add
++EXPORT_SYMBOL_GPL drivers/spmi/spmi 0xe6381634	spmi_command_sleep
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0x9ffb61fb	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0e4df07e	comedi_buf_read_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x12ab3ab9	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x20ca7b0e	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x210b9292	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x24ccf4b8	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x26079e3b	comedi_dio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2770376a	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x337623ca	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3f9f6918	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4add250b	comedi_nsamples_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4e02a7d3	comedi_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x55d34464	comedi_readback_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x62eee33c	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6771b5b8	comedi_nscans_left
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6c13f03b	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x780dcc17	comedi_dio_update_state
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x7c3e46bc	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x7f21c74e	comedi_set_spriv_auto_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x7fe9dc4b	comedi_timeout
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x88c78b88	comedi_bytes_per_scan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8e7c2833	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8fbe3437	comedi_buf_write_samples
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x93b571e7	comedi_dev_get_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x95a18016	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa06b806b	comedi_inc_scan_progress
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa0991ee5	comedi_dev_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa6cd2e59	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa970cf39	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xaf307a1a	comedi_alloc_subdev_readback
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc19a0e70	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcc9908ba	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd7c67f6e	comedi_alloc_devpriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdf55f2be	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf9ef493f	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xff53d51c	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x346f29ce	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x4d1e60b1	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x4d4ba845	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x4f2c9902	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x7f46e444	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x966734f3	comedi_pci_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0x981fbcd3	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_pci 0xe207e63f	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x11589421	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x5b9204f2	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x5bfc943b	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0x9b3f819a	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xabae15cf	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi_usb 0xe6404f05	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x0438cf49	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x454925f6	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0xeaabd4bd	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_pc236_common 0x295fce86	amplc_pc236_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x051137e3	comedi_8254_subdevice_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x135996a4	comedi_8254_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x144b960f	comedi_8254_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x1ef55896	comedi_8254_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x30e8ff72	comedi_8254_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x433bf99f	comedi_8254_update_divisors
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x8cfbdb22	comedi_8254_set_busy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0x969aa541	comedi_8254_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xa04e83f9	comedi_8254_load
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xb583cf29	comedi_8254_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xc9ef746e	comedi_8254_pacer_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xed302211	comedi_8254_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8254 0xfd97534c	comedi_8254_cascade_ns_to_timer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0x05d77a8b	subdev_8255_mm_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xb2141708	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_8255 0xeb7e2aef	subdev_8255_regbase
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x0d68fcd9	comedi_isadma_poll
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x12fba874	comedi_isadma_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x4191935f	comedi_isadma_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x4a17474e	comedi_isadma_disable_on_sample
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0x6815a033	comedi_isadma_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa3d01a85	comedi_isadma_program
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_isadma 0xa7ebb8a3	comedi_isadma_set_mode
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x66b10775	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x015a2a1b	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x0717e63e	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x0ef2c51e	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x14d9eb71	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x20aa03d0	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x44ba0b1c	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x4ef65d7e	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x577597d6	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x591326ed	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5c867362	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x77e5e92f	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x884a5e3e	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x999874b1	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa0cbca03	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa2e7f6a2	mite_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd02bbab0	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd2e7839b	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd99cecd1	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xde08d8a9	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe1e6b5f3	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xeb06c780	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x7d06637d	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_common 0x9c417bd0	labpc_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x0e65b2a8	labpc_free_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x23db444a	labpc_handle_dma_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x33442f14	labpc_setup_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x603ba0e5	labpc_drain_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc_isadma 0x8c50437b	labpc_init_dma_chan
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x19e79d5e	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x39749ab3	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x47c80f17	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xac0ea4ce	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xaf2b3c8e	ni_tio_insn_write
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xbf7dcc04	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xc0812a17	ni_tio_insn_read
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xc55df192	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x140cc9b6	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x1dec67b1	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x483411d5	ni_tio_acknowledge
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x62a521ab	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x8cda1e6e	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xb09eb983	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x203153c2	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x37b969e2	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x6f298c67	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x70243816	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xaa0133ed	comedi_dio_get_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xafac2ba1	comedi_dio_bitfield2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xf95f6eab	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0xfce171ff	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x02a50b54	channel_has_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x12eaf9d9	most_deregister_interface
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x1444f676	most_register_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x1eeddf27	most_get_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x34066fbe	most_stop_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x66103fee	most_submit_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x696237f2	most_resume_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0x8e141e25	most_stop_enqueue
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xa3c04aaf	most_deregister_aim
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xc227f845	most_start_channel
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xc415119c	most_put_mbo
++EXPORT_SYMBOL_GPL drivers/staging/most/mostcore/mostcore 0xf0a16336	most_register_interface
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0ef1d765	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x20e9b880	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x278c8e3e	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x29336ce6	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x309454e5	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4ffe1375	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x5608cfdd	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x922a9c6e	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb35aaab9	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbd095afd	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc0eec424	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd8b17a2f	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x40dd1c6a	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x7329c3a2	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xd61b0462	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xb0c3706e	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xf7f0d3e0	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x9d2c5a8c	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0xcf428231	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0x52e56049	imx_usbmisc_set_wakeup
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0x6fd9145d	imx_usbmisc_init
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/usbmisc_imx 0xa8d7a95c	imx_usbmisc_init_post
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x042d97bf	ulpi_register_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x35d4ae88	ulpi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x361a6a24	ulpi_read
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0x4647495b	ulpi_unregister_interface
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xbe656168	ulpi_register_driver
++EXPORT_SYMBOL_GPL drivers/usb/common/ulpi 0xc22c16a8	ulpi_write
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x1580dfcb	gether_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x2f87bd8d	gether_set_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x31630f06	gether_get_qmult
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x375f0724	gether_get_host_addr_cdc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x5e38c48d	gether_setup_name_default
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x640cc1d9	gether_get_ifname
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x6efed3cf	gether_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x7630e29d	gether_set_gadget
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xbbf15377	gether_set_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xc43460c7	gether_register_netdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd062fc26	gether_get_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xd243997c	gether_get_host_addr_u8
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xda35aa18	gether_setup_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xe306000b	gether_set_dev_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_ether 0xfc492235	gether_get_host_addr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x0f0c9403	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x38797d75	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0x89ca818c	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/u_serial 0xd371dd12	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0x55a2ee49	ffs_lock
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xa4caf67f	ffs_name_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_fs 0xbd984bce	ffs_single_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x141fce2a	fsg_common_remove_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1710b539	fsg_fs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x17253077	fsg_config_from_params
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1b1cc3af	store_cdrom_address
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1bc472e2	fsg_store_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x1ccb58f7	fsg_common_set_num_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2933ee1d	fsg_ss_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x2d10b6a7	fsg_common_create_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x38c72714	fsg_common_set_cdev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x398778e1	fsg_ss_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x423845e4	fsg_ss_bulk_in_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5255b366	fsg_common_create_luns
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x55ec8804	fsg_lun_fsync_sub
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x56344daf	fsg_hs_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x5a66a644	fsg_store_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x6acb4179	fsg_common_set_inquiry_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x72108cc5	fsg_show_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x72cb1f25	fsg_lun_open
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x7e26d4a5	fsg_common_set_sysfs
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x834029d5	fsg_lun_close
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x857b6dc2	fsg_hs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x95cffb3e	fsg_hs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x99023bfc	fsg_common_put
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9a0221c7	fsg_common_free_buffers
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0x9b9a7c53	fsg_show_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa46e6443	fsg_common_get
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5cae92f	fsg_ss_bulk_out_comp_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xa5f99b69	fsg_fs_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xaa86be55	fsg_store_ro
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb1999d5f	fsg_store_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb52ba28a	fsg_intf_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xb54d0d95	fsg_fs_bulk_in_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xbda894d5	fsg_show_removable
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xe6839bd8	fsg_common_remove_lun
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xe69eb22d	fsg_store_file
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xed936dfe	fsg_show_cdrom
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf4efc0c8	fsg_ss_bulk_out_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_mass_storage 0xf9602265	fsg_show_nofua
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x21ba4418	rndis_borrow_net
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x2424beb5	rndis_add_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x2ca4acb5	rndis_set_param_medium
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x494c2c9f	rndis_deregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x64d7af6b	rndis_msg_parser
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x7cba647e	rndis_rm_hdr
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x8def5396	rndis_free_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0x9827dc87	rndis_signal_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xbd65dd3d	rndis_set_host_mac
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xc1ed02cc	rndis_get_next_response
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xce9863d0	rndis_signal_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xdb4ad289	rndis_uninit
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xdb9bf449	rndis_set_param_vendor
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xe1b32660	rndis_set_param_dev
++EXPORT_SYMBOL_GPL drivers/usb/gadget/function/usb_f_rndis 0xffdde296	rndis_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0564f9c0	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x08661d6b	unregister_gadget_item
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0b1d2252	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0ec4e945	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x105d7c52	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x197e7002	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x208d802d	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x21caf512	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x26b2ea63	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x35fe4e0a	usb_otg_descriptor_init
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x3ae86517	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x459ba287	usb_ep_autoconfig_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4ebeabcb	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6521ecb6	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x68494784	alloc_ep_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6f3a3c33	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6fecf9e4	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7d5a86dd	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7d5f6bd2	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8c6e0e06	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8f6bb173	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9311fe60	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb28ee9f8	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb3b095b5	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xcd76cd49	usb_otg_descriptor_alloc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd7683271	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe14da95a	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe609fdbb	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe8affd96	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf4dd5e05	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf9d8df1c	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xff0ae366	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x1a05a939	gadget_find_ep_by_name
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x3b5aab2b	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x6604e0cc	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x6bda279f	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x83972e96	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0x95e1aa5c	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa4744dba	usb_gadget_giveback_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa4b59ea4	usb_udc_vbus_handler
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xa770ef94	usb_gadget_udc_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xc0b16786	usb_gadget_ep_match_desc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xd5b1dbf3	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xdd0bad21	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xf0812b94	usb_udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc/udc-core 0xfd9c35c6	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x2859b043	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x6b9c41dd	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x0df73205	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x364e8a82	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x396af4e4	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x5b32798b	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x692b5dcc	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xa5156e09	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xb50dc1c4	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xd0fefd4e	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xe6e087ce	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x0892ae1a	musb_writew
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x2e7d9bc6	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x56d31820	musb_writel
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x72234dd6	musb_readw
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x96919667	musb_readl
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xac5f3d70	musb_readb
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xcb32cb36	musb_writeb
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0x42b0aaa5	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x4a67bebe	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x0221b583	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2394b0eb	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x24c259c1	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x26783219	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2ddc4f24	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x3734777b	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x439f7abe	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x50e15361	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x9bee745b	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xaba29ffc	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xb2731713	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xb60d5398	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc3b13e73	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd32afedd	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd701e321	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xdf93f105	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe23694c3	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xec9598cd	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xef2facf4	usb_serial_generic_write_start
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf839312f	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf922a43f	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x2e68ff03	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x39ba3d32	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3aedf9a3	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3da8875e	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4169e0c6	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x454ad413	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4b676cfe	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x544f6f8a	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x63911327	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6afb4db9	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x71e70812	usb_stor_adjust_quirks
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x7605ba00	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x881c9000	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x89a58bf2	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8f14a510	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xa38c69c7	usb_stor_host_template_init
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xa3a31939	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb1f4a755	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb647de28	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xcd077c0a	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe58cfdae	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe7447fcb	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xeaaca89f	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xfd436be2	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x049e178a	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x1c0c006b	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x26ec5a74	usbip_recv
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x43d25e7e	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x7599c2b7	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x7d1319a2	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x967b38a5	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0x9d3264c7	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xcdfcdb66	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xdad09ff4	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xeabb250b	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/usb/usbip/usbip-core 0xf1b3353e	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x0bd816f0	wa_process_errored_transfers_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x122f15ac	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x1fdfb32b	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x743c8fe0	wa_dti_start
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x857b5511	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x898739e6	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x8a62985c	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xa23c1e57	rpipe_clear_feature_stalled
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb71c5af	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x08626696	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x17c608ef	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x306ceea6	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x409ee471	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x483e8033	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x6b4e0a96	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x84e04932	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xc0d3cf14	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xc1be481e	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xcfe5475f	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xe30320be	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xeee7a717	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf4280579	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf8ec632e	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x22eb8f86	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x378aa418	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x6a2e4aa9	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x4d51e93e	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x52e1d367	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x642e8ad0	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x83bfad50	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x8aa726a6	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xc7bc0ac9	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xe5b9f709	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xf24943d5	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0d78016e	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0fc02440	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x17352047	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1a29998b	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2ab8534a	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2b7e7587	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2d87c717	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x32e437c3	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3bb1bf28	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4dbf9234	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x52144b1b	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x53eba93c	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6d40d8a3	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6f5bee79	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7d59b008	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7df4bd60	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7f8c9e15	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x816b9e92	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x84ce300d	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x875db4c4	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x890290c5	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x89741d32	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8a2db0d3	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8ffd5641	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9052ed29	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x93c24b16	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x95d353e9	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9b56f843	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9e5a96d3	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa0edae5d	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa36eb9cb	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa8c7281a	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xab16c795	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xac97316b	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xae503620	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb6511e06	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb97d8c4f	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd19f56ef	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd323ca8e	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe07f0632	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf71426a4	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0xe01b304f	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0371b901	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x114a6665	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x15f7caf0	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1a2700b7	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1e3dc44c	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x258027e3	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2cb95b7c	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2d91d076	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5286ebb1	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5edbe13a	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x6d4b79f7	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x80735ca6	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8116ff9a	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x817d68b7	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x89e28932	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8e7934e1	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9ab93129	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa47630b4	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xac8e0fe2	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb0f81e37	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb17ca525	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbdc3004f	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbdf22321	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc51b7f6e	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd1b616ac	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd75364c1	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xec02cbd1	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xf450fa5d	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xf46b3c46	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfd5b64cf	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x1cfe40b1	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x2feb1c97	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x5804599d	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x90b6cf6f	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xac07009e	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xbea543ca	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xf88387b1	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x02a26e7d	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x07031e16	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x1b6efed6	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x24ee7a58	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x55d92795	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x5e36cea6	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x81c5fdcb	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0x883032d7	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xa3457e0b	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/fbdev/auo_k190x 0xdea9b3a5	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_ddc 0x182c06c1	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0x0a8128fb	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/fbdev/core/fb_sys_fops 0x57b0952a	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x4f33c9ad	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/fbdev/sis/sisfb 0x61a8358c	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x246c0c26	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x49a31fb3	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x6bc0f408	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x8bf5cc71	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x9a355f43	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xc47156cf	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xc482426a	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xeb3a7f5b	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xefb74e12	w1_next_pullup
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x1acd1976	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xd6123212	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xebc0eafc	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x0f18d6c1	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x20dd3bbe	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x22939b5f	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x506a17db	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x6f76e381	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x8508acc0	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x8dc227e7	lockd_down
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0099e87b	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x081d68ec	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x082668c1	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1019ecd1	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x10544d3b	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x12035dbb	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x148463e0	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x14cadec6	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x16db3f6d	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x18ca0bee	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1a1b13b8	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1b235582	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1d136a30	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1e622e56	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1f184d59	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1f3820aa	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1f3ca9b4	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1fad9d6b	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x20a3678b	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2338bd91	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x25334bee	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x25fa8398	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26bc3dfb	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x27e696a9	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x28528b6e	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x28f04a05	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2b14b6de	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2eba29a9	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2ede3d02	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x30bccd81	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3329d332	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x33fd9a24	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x349cb4cc	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x37a5d5b4	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x38852f6d	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x390625dc	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3acd2865	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3fc63f32	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4418a86f	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x47f836c2	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x48d77072	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x48e7f2ee	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4906384f	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9c155	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x53273253	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x54740eec	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5596126b	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x569b0163	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5a4c824e	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5a4e7350	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5d179634	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5f017ac4	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x63c1fdbe	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6457027b	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6559441a	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x659ef8b5	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x66428e73	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6c584c65	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6c7d1e83	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6dc98ddf	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6dd82175	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6f22ab31	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6fffee80	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x799d9eba	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7c9722ba	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7dc1f212	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7dd9ad65	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7e633211	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8035f450	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x81537991	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x876743da	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x87cc972d	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x892eabef	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x893eadee	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8a3ee5c9	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8d0c6aec	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8e17f653	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8f4f8e83	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x92ab6fd9	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x93d4a291	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x95103df3	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x967f0c94	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x96b93335	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9ab34ea0	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9c0666bc	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9f16a684	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa46f725c	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa89e2cc0	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa918f273	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa977e8ca	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaa1387d7	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xab1c132c	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xab732927	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb1138d19	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb22138e8	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb333ce07	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb3a805ae	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb74949b2	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb780b739	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb792e159	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb9a85538	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xba5852b8	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbe6dff07	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc336fa73	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc3a61290	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc9da817e	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcbd23c91	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd6a20991	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd6a46981	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd812c93e	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xda142eab	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdb1bb300	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdca0ff47	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdcf644fd	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe01ab5be	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe4faaf08	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe56cbf5c	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xed63d406	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xee86fab2	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf08dc0ec	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf35def16	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf79c70c9	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf7f48d68	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7207fc	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xffc1dc2c	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0x3017e92d	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x01236fde	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x049ad11b	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0b02fff5	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0e9c7886	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1093b108	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1193e7a7	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x132ccd09	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1be8f9c7	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1c2ef7b1	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x24dcae23	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x26efa541	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x29f8523a	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2a2b6d88	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x308bcfcb	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3b90ab9c	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3dbdd364	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3ed5b6a7	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4d4104da	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4dff4fe5	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x50cd19eb	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x560c7e18	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5c3f1126	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5fd80e17	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6085edbd	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x72c989ca	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x768e6d19	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x78f20289	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7966836b	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x796f6e47	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x812c7f94	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x85430d92	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8bc0fee9	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa0bac4e4	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa1c047cf	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb0480ef3	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb286454c	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb4be8309	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb8de35ec	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbde9b2ce	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc65c8bf8	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc6ba0507	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc83a62a5	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcde7b106	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcfc9a2ab	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd08c2238	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd0b5b7dc	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd14cb595	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd680dd47	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd8e316c2	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd9485bc0	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xda0fbfdf	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xda80b37d	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xde6ead4d	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdfbe77dc	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe1de626a	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe5426e59	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xebedb598	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed0494ff	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xef4c047c	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf213909f	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf64215e8	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf9ed4569	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x9185a375	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xdcc62cca	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xecd23fdb	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x3a9a324b	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x80f812dc	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x12f77f44	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36a28a9e	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x430a6818	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x52091ad4	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x59d8f430	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x6370f889	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x81a17396	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa2a282f5	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xea465bc3	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf56c2017	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x2cdd5d2f	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x4cb2fbc3	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xac2e4658	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xacf50ce1	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xdca44866	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xdecf9ad8	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x1d64e55d	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x8ea485e2	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xc46620e2	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x717b780a	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0x9043a32b	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xe495d957	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x18c0979d	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xe139f3bc	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x1803a6ed	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x2b30f429	raid6_call
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xe4b051cf	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x0adcb055	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x221df614	base_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x4da25bec	base_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x63f42b6a	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x76203267	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xca3140ce	base_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfa5eee0a	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xfc02472a	base_inv_true_key
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0x8272e02d	lowpan_header_compress
++EXPORT_SYMBOL_GPL net/6lowpan/6lowpan 0xc7c4b36d	lowpan_header_decompress
++EXPORT_SYMBOL_GPL net/802/garp 0x2c0019c4	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0x349c29b8	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x70e7a802	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0x8b8dd35f	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x8bc5828b	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0xeb3541d7	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0x22fceac4	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x306de874	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x508f3924	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0x66da81fa	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x88500662	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xbb746d5e	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/stp 0xa2dde8a4	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/802/stp 0xed4b686c	stp_proto_register
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x0de705b3	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x1dc9a79d	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0x4fcfb240	ax25_register_pid
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x1cecb253	l2cap_chan_set_defaults
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x6ccefb77	l2cap_chan_create
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x73f9a49c	l2cap_chan_connect
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x7b82dd26	bt_debugfs
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x7e298611	l2cap_add_psm
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xabfdabc0	l2cap_chan_put
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xcf7188e0	l2cap_chan_send
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xf9715987	l2cap_chan_del
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x01da7d17	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x191653d0	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x579288a1	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x6a31a2da	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x895345e3	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x8fa55a61	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x92b19132	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xb276fdb2	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x291f8a8f	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x68877d96	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x06af6088	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x14bd2784	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x182167e6	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2bb79a0e	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x30d28d4e	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3b9c30ee	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3d191d36	compat_dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4581aace	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x45a525d3	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cf32767	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x55befbf9	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x56a4157b	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5e7ed0ba	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x631273d4	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6e4a014f	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x82062b47	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x8d598071	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x923eb23b	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x97289af5	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x98d5da4d	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9fbfde1d	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa0023933	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa057dc35	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa353ad09	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xaa3d3c52	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb066f542	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xbed7d648	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc0b7b890	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc4862a4c	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xcbc7ee69	compat_dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd499f0d9	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd70895d6	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe5256155	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xeba8ec3d	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf878ddc4	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf9aebd9f	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x047a981d	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x093bbb62	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x6596b726	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x890e4e32	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xbdf25025	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xfeaec26a	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x4d7aef69	ieee802154_max_payload
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0x9bc4190a	ieee802154_hdr_push
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xc8a48426	ieee802154_hdr_peek
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xe0784f1c	ieee802154_hdr_peek_addrs
++EXPORT_SYMBOL_GPL net/ieee802154/ieee802154 0xe3f92593	ieee802154_hdr_pull
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x1ee1ff0f	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x3e2b436d	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x059759e8	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x1e95320f	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x30782395	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x3c632add	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x835828fc	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xa7d5af36	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0xba2de1db	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x1589ac24	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x189f6ebb	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x3e492fe4	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x57aa8011	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x5e99dd62	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x755b00c0	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8e831703	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8e875e21	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xa17b4077	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd38a3189	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xe129ccc7	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xf46d69d8	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xf6201fe9	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xf8e50917	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xfa57d4a0	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0x20b4fddb	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0xd9a7a6c4	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0x1729e034	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x0127d690	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x4393e232	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x5b09b197	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xa907501d	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xd0fc41f5	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x4f8f68c7	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x3cd9fb1b	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x6dd68b73	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x99863b41	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xc620688b	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xdeb97ac1	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0x9e5cd3a8	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x08453b50	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x750140ab	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x99e94ecc	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xb3ebbcd4	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xd535e9d0	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x64dbb79c	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x741be414	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xf807be0a	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xf9492e37	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x0c5f4e9f	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x22051aba	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x387b4d4a	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x4853e928	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x8c68358f	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xa5157300	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xd39552b1	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x7308d84b	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x7d92fe61	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0xd7f8b153	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x16d0931d	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x98504f05	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0xd0d5eb09	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x4f1cfe91	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x8eebd1b9	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xabafedee	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xd30868bf	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xfe64bd49	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x7e7ecadc	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x0a49025e	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x1b8daee3	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x3b75e687	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xaa4f73a6	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xef2f547c	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0x08d5a34c	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x15b5afe4	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x302a3b38	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x331773a3	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x375e861c	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x530192a7	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x698370bd	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x7cb70e80	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8d539f08	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8f156ea9	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x92be62ad	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xa69a0388	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xa8266dee	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xadaa5e57	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xbf4235b0	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xe3b413cd	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xf6cae43f	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x68afbf2e	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x05dba264	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x11e1f72f	ieee80211_set_key_rx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x167e1dc1	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x1f216d2c	ieee80211_set_key_tx_seq
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x29be719b	ieee80211_iterate_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x2e2a5565	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x327630ce	ieee80211_iterate_stations_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x49b9aa47	ieee80211_iterate_active_interfaces_rtnl
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x4fd00958	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x52dbaf01	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x56d9a464	ieee80211_gtk_rekey_add
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x57896025	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x58a151ae	ieee80211_remove_key
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x679dc4c5	ieee80211_vif_to_wdev
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xb0007f41	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xde988fc0	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf09514ad	wdev_to_ieee80211_vif
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf2fc2e2d	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x17e281a3	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x4d9d55ea	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xb67204c3	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xe45957ae	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x012fbb29	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x033d905f	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x096907aa	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x0f0876dc	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x0fa6adaa	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x140a0d92	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x375ba770	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4c4c9a62	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x5df7051b	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x76980612	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7b5e24a7	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7ecc0d3a	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xabc1380d	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xe93b86bc	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf3b4d4ae	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf5576973	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf5f067a1	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x08028cf7	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x89201dbe	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xa56ce4be	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xe6e8f5b3	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x048f1fec	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x04c30563	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x089c5e9f	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0b7a6617	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0c90548c	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0f5b84e1	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1025a3f9	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1462b78e	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x14a8b459	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x18280b59	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x205404f7	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2905ea28	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2da52f59	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3098d99d	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x320097d7	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3233803f	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x328ef162	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x32ebf758	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3429a7e9	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x399de396	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f0a5d58	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f34d9ab	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3ff4dfb3	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x447fb203	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x44ffd416	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4c5bb0ed	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x588caff8	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5c10a0e5	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5fa62323	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x61b8c972	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6fd2931c	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x73cc425f	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x755fcab8	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x765ee93b	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x76c9b694	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7c1eb8d6	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7e6dd26f	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7f2fa7e7	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x83473f69	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x85d38c13	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8a66c4fc	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8e032fed	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8f88fb2f	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9015c59a	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x916ccd11	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9279e4df	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x933dec19	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9ea836d3	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9fe0d153	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa5e3a5d5	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa5ee8a0f	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa6ba5351	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad4799ee	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaed9f696	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb059b907	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb0b5d472	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb15c06a6	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb513cdfc	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbf2f5680	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc5091104	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xca7e9b1e	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcb87fe05	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd36f590a	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd686414f	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd835fd50	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdc372de6	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe66f8c40	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xea1ddfff	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xea665190	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xeac8992e	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xebb0d110	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xed68f842	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xedcd62bb	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf057dc5c	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf10f964a	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf17a09d4	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf2fffeaf	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf7120ed6	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xff40b965	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xff7cc041	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x02be679d	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0xdd99aa6a	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x40dbd59a	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x04076559	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x0fbaa3d7	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x1b980cdd	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x1de8fc4c	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x32178e5b	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x44544a7f	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x7f0c8278	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x93e4e6b8	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc38610e3	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xdead2e5c	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0x63a8a41e	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x096c82f0	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x6edad076	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xfa47eca9	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xfb5ac72b	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xa2d3a687	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xd8942812	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x1f5b7948	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x23111f8a	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x4bb0c04d	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x7102f931	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xd850dba4	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xfdef8411	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xff6f3507	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0x6ce3e00e	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0xdcd9c876	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x1275a34f	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x309ad2a6	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x80790410	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xc02d2448	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0b2fcbd5	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x23af5936	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x5d198628	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x69b67aba	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x7173be5f	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x9c422698	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xa4da6568	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xcff5012f	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xeac9a9db	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x07f66894	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xeffc7d7e	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x27456152	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x7e54d5ec	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x8841d39b	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x00915063	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x097b2390	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1f850812	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x23b805ef	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x30ea0dba	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x3358afe1	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x3457485f	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x47d9b2bb	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x4aa6e78d	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x6ebb8bed	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x703531ba	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x829e4c4b	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x8686daa3	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x8863b2d6	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xd6ce5b93	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xf9688ff8	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xfb5b7dfb	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x0099b91a	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5acd436f	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x84fc5675	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x9bc79741	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xc616c8e2	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xe0377ed6	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xf73a42f2	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x6369f21c	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xc47252ef	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xee322c78	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0xaa9b2101	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xb168d553	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe44a1cb5	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xedb1368f	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x19b26458	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x1ac6a881	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x500071a4	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x5033c7bb	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x60cd3b42	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xa3cc8efe	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x2bc2c185	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x95d259a1	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xca95619d	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x28c469b6	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x6b0ac4d9	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x036b7a8e	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x161d1417	xt_compat_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x207a0abe	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x30c494d5	xt_compat_match_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3f342c8d	xt_compat_target_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x520a4191	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5f82f1f7	xt_compat_flush_offsets
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x62521699	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x691a6d69	xt_compat_calc_jump
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x73cee41e	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x7e290b21	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x996cdadc	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c0cfd91	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbe7ea03a	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc52c8cac	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc6ba49ef	xt_compat_target_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd93147b3	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xde17553c	xt_compat_match_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xde404ffa	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe0b4971b	xt_compat_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe40c4b56	xt_compat_match_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe8b33639	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xec24fd82	xt_compat_add_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xf6b39cdc	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xf7ad6a0b	xt_compat_target_to_user
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x00204983	xt_rateest_put
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x482b6a12	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x0f3b70ef	nci_spi_allocate_spi
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0x6fea6eec	nci_spi_send
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_spi 0xce3aae9f	nci_spi_read
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0x48afb392	nci_uart_unregister
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0xedd26a3c	nci_uart_set_config
++EXPORT_SYMBOL_GPL net/nfc/nci/nci_uart 0xf1a7ca09	nci_uart_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x0796fc83	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x19fb6b61	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x2719049c	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x2b2bba4f	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x64df5f69	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x86c5af80	ovs_vport_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xa357601d	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xa767a551	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xca2b82bf	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x06915aa0	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x0a8e0d38	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0x15ad8642	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x19ff37c6	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x1e116c94	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x2b60ea6d	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3409b768	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x472164bc	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x521d2384	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0x5f02da2b	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x62c6eff3	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x7760e596	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x7bc62829	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x92e67a26	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0x9bc32f86	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0x9ead73fd	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xa5f77a54	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0xa77ecc1c	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0xb1494212	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc42f25ff	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xc66cac2a	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0xd8c7eb43	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0xda47be2b	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0xdf193c53	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0xfd765550	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x6db9fa5d	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xcd4918e2	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x335ef49c	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xa0db44df	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb0b30f7a	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0177adb4	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x03b2c8cb	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x042e5e85	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05405bf1	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0bc82a2d	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0d3f9fdc	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0da06165	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f439650	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f551953	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f7a506d	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x15e7319c	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x162f229a	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x177c01ec	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x190e3bb8	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1c0de57d	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1d99325b	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1dc8d6b3	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1f2a9970	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x215eafd9	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2224655e	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x23388e6c	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x29ca1e63	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2b47b169	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c7662aa	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x30bd985a	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x30d8d250	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31bf2081	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x32f9e79e	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x35f66d81	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x36e03ded	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3729ef64	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x375b9779	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x38edb7a0	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3a1ae6f8	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3ae9fdb4	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3d00490c	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x40625f66	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x41f22c8a	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x423798a0	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x45eaea40	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x48507358	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4b3a16be	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4e0c8457	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5098f5a0	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x51b7376b	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x54858ace	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5520656f	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x55afd2f5	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x55b9ea7a	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x563cc0b7	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x570fbb74	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5796ab98	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5848e985	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x59d1f767	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b686412	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5c424c5c	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6237a63d	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6362faab	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x66eaca9e	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6805b4ec	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x68468739	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x69f3503c	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6a338085	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6a998d92	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6d5e1b89	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6e4302fa	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6efae2aa	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6efaf859	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x73bbd14b	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x745f817a	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x749a03d6	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x74f5760b	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x74fe22d6	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x766f46d6	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x76f8dacc	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x784643fa	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7d3c6429	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7d3d4d63	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7def3fe3	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7f028285	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x81a02743	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x830bc587	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x83232bfa	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8393a6e2	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x83a5ec27	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x871d7dda	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x89c685f8	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8bcff3d1	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8c39ebee	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8c532127	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8de6b52d	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8dfb1112	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9062b6c4	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x92a2244e	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x941349c6	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9831625f	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x988fb6b7	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98de7480	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b50feb8	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b95d1ea	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9c5fc2b4	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ce31077	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9e97c317	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ef449af	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa0df1dd4	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa15a8bfb	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa1966cdc	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa1bb594c	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa204c31f	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa2d92f73	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa35c2b1f	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa5c30d75	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa7b040a6	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa669482	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xabbc731c	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xace1bd7e	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xae21ea02	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb078ff0a	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb11beab4	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb2182e8e	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb234d358	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb2a0e003	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb2bd73fb	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb2c6d6fb	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb3d1b5c9	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb45c6557	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb5c9458e	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb688ee7c	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb7213c7f	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb7c35beb	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xba575a79	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbbb5933e	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbd85171c	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbd9ae97d	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbdc456d5	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf291f19	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbfb0a249	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc07c5837	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc210222a	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc2f6d9de	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3663fc3	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc463cd9f	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc473818d	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc4d0f210	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc4f77717	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc568a306	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc58aeb68	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc84ff3dc	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc901c4a0	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc9b7a7d4	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcb217808	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcb535806	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcb7d9b38	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xccc80dc3	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce0f6c63	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce65af05	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce8d7cef	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd31981c3	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7ceda7c	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7f3c3a8	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd9a5f1c1	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd9cb03d5	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdaf42885	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdd6b720e	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdf5a6e40	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdfa72347	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe0ef07e6	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe2a39a0d	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe3935e02	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe4022499	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe44033ea	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe55cd2e3	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe8759dd0	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe8f12da1	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe9e93657	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xea2d5f41	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xea36a420	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeb5a90e6	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xed9cb59f	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedc11406	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeee5450c	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef0c21e4	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xefeaf894	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf163d149	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf29060d7	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf2a7fe48	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf4333fd4	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf4402c4e	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf451dbca	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf5a62754	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf6ce2f36	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf7830d8b	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf7f0f3e0	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf8ec03c1	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa2c0056	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa6f9ac9	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfc950366	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfe7fde25	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xff5cc6bb	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x32677161	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x40241d7f	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x4cd6b27b	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x54304087	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x59d943c8	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x779c3572	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x79624508	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7e7514a6	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x970b77bc	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x9e3e528b	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa050166a	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbe173fcc	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd80742ac	__vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf004cea5	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf28c05f6	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x0511d946	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x1b151d12	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x1f0a5833	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x24a85187	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x44c0f7ce	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x568d3bc3	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6404cb6c	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6bf2bcf8	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x721536ff	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x7de9eba8	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x8ddb7dde	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x9df33da3	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xefd544bf	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x03c9dda4	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x0bba9124	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x19d987c5	cfg80211_vendor_cmd_reply
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x4b8c2798	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x97cc1931	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xb0146cd0	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xb6823778	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xbdf83087	cfg80211_shutdown_all_interfaces
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd0341344	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xe575ad55	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xf7d09243	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xfe8d1f31	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xffe6a739	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x2eb9a8af	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x3c2dfe8d	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xc6af7776	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xfbc4d3a1	ipcomp_destroy
++EXPORT_SYMBOL_GPL sound/ac97_bus 0xdd2e9f20	snd_ac97_reset
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x1220f886	snd_seq_driver_unregister
++EXPORT_SYMBOL_GPL sound/core/seq/snd-seq-device 0x754bd80a	__snd_seq_driver_register
++EXPORT_SYMBOL_GPL sound/core/snd 0x09c78d20	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd 0x292e0adc	snd_ctl_get_preferred_subdevice
++EXPORT_SYMBOL_GPL sound/core/snd 0x2e690ed6	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd 0x36754171	snd_device_disconnect
++EXPORT_SYMBOL_GPL sound/core/snd 0xa53bf882	snd_card_add_dev_attr
++EXPORT_SYMBOL_GPL sound/core/snd 0xb130c17a	snd_device_initialize
++EXPORT_SYMBOL_GPL sound/core/snd 0xf74bad27	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x24518b7c	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x31a460a9	snd_pcm_stop_xrun
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x35f9574a	snd_pcm_stream_unlock_irqrestore
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x62b75714	_snd_pcm_stream_lock_irqsave
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x6502d000	snd_pcm_stream_lock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x8212a60f	snd_pcm_stream_unlock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xab8bc1a2	snd_pcm_rate_mask_intersect
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xe0d9e17f	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xef5945a6	snd_pcm_stream_unlock_irq
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xfba887c2	snd_pcm_stream_lock
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x03efba2f	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x06051448	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x11c81ede	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x1619b0d8	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x54921ea0	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0x986c5d46	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xaa0815db	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xf18c3b21	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xf23c1f1b	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xfca3b594	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL sound/core/snd-pcm-dmaengine 0xfdb13a1c	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x127a011d	amdtp_am824_set_parameters
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x220eecd2	amdtp_am824_set_pcm_format
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x323ed1d5	amdtp_am824_set_midi_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x4856960d	amdtp_am824_midi_trigger
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0x61dfa924	amdtp_am824_init
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xa8be2b0b	amdtp_am824_set_pcm_position
++EXPORT_SYMBOL_GPL sound/firewire/snd-firewire-lib 0xe9952102	amdtp_am824_add_pcm_hw_constraints
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x01804870	snd_hda_bus_type
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x03237da6	snd_hdac_device_register
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0463639d	snd_hdac_regmap_update_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0541fe15	snd_hdac_codec_write
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x07065593	snd_hdac_power_down
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x0f9f2d55	snd_hdac_device_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x10518364	snd_hdac_stream_set_params
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1106fed7	snd_hdac_stream_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x187979b8	snd_hdac_regmap_add_vendor_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x19843198	snd_hdac_stream_timecounter_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1a4b52a6	snd_hdac_stream_clear
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x1f586d48	snd_hdac_bus_stop_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x216120ef	snd_hdac_bus_exec_verb_unlocked
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x22435d28	snd_hdac_device_unregister
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x2424d841	snd_hdac_bus_add_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x24bc36a6	snd_hdac_stream_sync_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x30220980	snd_hdac_power_up
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3177d3d5	snd_hdac_bus_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3536dae1	snd_hdac_bus_handle_stream_irq
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x36631920	snd_hdac_bus_enter_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x39ead27a	snd_hdac_dsp_prepare
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x3a112b3d	snd_hdac_override_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x416a2035	snd_hdac_get_stream
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x458db976	snd_hdac_get_connections
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x496418cc	snd_hdac_link_power
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x50d8e242	_snd_hdac_read_parm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x53782286	snd_hdac_check_power_state
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x541711ca	snd_hdac_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x554b90d7	snd_hdac_regmap_read_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x554c8857	snd_hdac_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x5de2da7f	snd_hdac_device_set_chip_name
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x62679420	snd_hdac_bus_init_cmd_io
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x650c93a3	snd_hdac_regmap_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x66156211	snd_hdac_stream_setup_periods
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x669fb748	snd_hdac_bus_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x66b5b487	snd_hdac_refresh_widget_sysfs
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6bd26298	snd_hdac_regmap_exit
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x6e4d27f8	snd_hdac_bus_stop_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x71d22ebb	snd_hdac_codec_read
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x72f953ba	snd_hdac_bus_remove_device
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x7b2bed52	snd_hdac_bus_update_rirb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x80c4a5ec	snd_hdac_codec_modalias
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8463d3cd	snd_hdac_stream_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x85b43833	snd_hdac_bus_get_response
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8e26e0f1	snd_hdac_bus_free_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x8fff159e	snd_hdac_read_parm_uncached
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x96ac3e88	snd_hdac_refresh_widgets
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9aac0b45	snd_hdac_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0x9ed4ef34	snd_hdac_regmap_write_raw
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa07f3a8e	snd_hdac_stream_stop
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xa28447a4	snd_hdac_stream_setup
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb4eb421e	snd_hdac_bus_queue_event
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xb6df3206	snd_hdac_exec_verb
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbc0acec5	snd_hdac_bus_send_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbd5c4bcc	hdac_get_device_id
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbd78df14	snd_hdac_stream_assign
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbd8131c2	snd_hdac_bus_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc2022618	snd_hdac_power_up_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xc4d1ba1e	snd_hdac_bus_exit_link_reset
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcbfef4e9	snd_hdac_stream_release
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcd2bd473	snd_hdac_device_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xce9efb4a	snd_hdac_bus_alloc_stream_pages
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xcf7919ad	snd_hdac_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xd683f9ce	snd_hdac_stream_init
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xdd9a804a	snd_hdac_calc_stream_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe32f4e32	snd_hdac_make_cmd
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe37537f9	snd_hdac_bus_init_chip
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe3d7857d	snd_hdac_stream_start
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xe886c7c5	snd_hdac_is_supported_format
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xeaf579f8	snd_hdac_dsp_trigger
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xf66fcd8f	snd_hdac_power_down_pm
++EXPORT_SYMBOL_GPL sound/hda/snd-hda-core 0xfab76519	snd_hdac_stream_sync
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x724fb3f5	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x84e35e29	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xafee0e1c	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xb39764a2	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xe9def609	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xf62a4853	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0272ba7f	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x02bd6acd	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x03488c8d	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x047ef2de	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x053ad4bb	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x06477ff8	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x07f9048a	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x09fc03bd	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0d4bff5c	azx_stop_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x14ee5bb9	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1528dbf9	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1695c76e	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x16b2172f	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x175d8778	azx_free_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x19310b57	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1b99f033	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1d1e5cd8	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1d523c22	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1d80e882	snd_hda_codec_set_name
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1dc17096	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1dc5f859	azx_get_position
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x24c252b4	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x26b5ea85	azx_stop_all_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x274b9461	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2b816128	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2fb994ef	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2fd00fb3	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x313e0928	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x347e7f04	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x353f7c63	azx_get_pos_lpib
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x35e3314f	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x366835dd	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3702e02b	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x37659cea	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x38ce402b	azx_interrupt
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x395542e5	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3aac7ada	snd_hda_codec_load_dsp_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3c64628f	azx_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3c72555b	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3cfe6249	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3d8b7636	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3ee4db91	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x41393527	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4280cef5	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x48e5ef99	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4d82f285	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4fa69cc3	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x50e72efe	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x57822e0d	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5810874e	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5bade731	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5bb40ded	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5f903183	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6042e555	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6273f752	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x68327503	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6b99c062	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x714fab6c	snd_hda_set_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x79f8f884	snd_hda_codec_load_dsp_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x80665d26	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x81c2d806	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x822a787b	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x826ebe38	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x83a628bb	snd_hda_jack_detect_state
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x846a2804	snd_hda_check_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8561ad2b	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x85d0413d	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8ece74e1	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8f549bd1	azx_init_streams
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x91c6ed51	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9524a748	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x99119437	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x99b579c2	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a235edb	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9c0f13ac	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9cecfc58	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa296a94e	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa310d022	snd_hda_codec_pcm_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa3e72de0	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa52ca8e8	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa605cf11	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa68064f9	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa7465a47	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa937d65a	azx_get_pos_posbuf
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaa6dbd5b	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xacfc21d3	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xadc4cebb	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xadcad2b9	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaf79506c	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb1257645	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb4855349	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb771b63b	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb9027098	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xba98d58c	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc1e2bdcb	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc2d89b95	azx_bus_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc2fdbfe9	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc4edcac7	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc6e79dcf	snd_hda_register_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcaf7f183	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcb942c6f	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd0709466	azx_init_chip
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd4c228bd	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd657c8b1	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd7c12c5a	snd_hda_codec_pcm_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd86c0c0b	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd9a0e70a	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xda92c31c	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdc4783c4	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe0fae8bd	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe55807c3	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe63944ca	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe8a8eda6	hda_codec_driver_unregister
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe9b2734b	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe9f06ab6	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeddf2fae	__hda_codec_driver_register
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf0448ffa	snd_hda_codec_load_dsp_trigger
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf556778a	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf7057dc4	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf8100456	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf84bca0d	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf911a2f1	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfa254373	azx_probe_codecs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfafd12f7	snd_hda_pick_pin_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfbae9f70	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x078d1b19	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x2922e34a	snd_hda_gen_path_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x2f41087e	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x346e7ea1	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x3e13f799	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x41e1465f	snd_hda_gen_fix_pin_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x4a45fbb2	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x6ce371e4	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x6e66a989	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x7c53bb38	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0x8ebf2b71	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xb0523452	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xb33cf3f5	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xc5214b36	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xc638e748	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xd5c50728	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xdaab4382	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xec08593c	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xf3dc6446	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xf56d3a07	snd_hda_gen_stream_pm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec-generic 0xf679ecec	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x7d05786f	cs4271_dt_ids
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0x975b6857	cs4271_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs4271 0xf9d7989f	cs4271_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x375ad98c	cs42l51_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x8a80cef5	cs42l51_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42l51 0x8b07a806	cs42l51_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x0245c4f2	cs42xx8_of_match
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x5813c73d	cs42xx8_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x5c553410	cs42xx8_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0x7cac7292	cs42888_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xcd3794c9	cs42448_data
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cs42xx8 0xdc10996e	cs42xx8_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0x29a4d98d	es8328_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-es8328 0xdbdae2e4	es8328_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0x606dedbf	pcm512x_regmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xa0b3f272	pcm512x_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xd8a0464d	pcm512x_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-pcm512x 0xf3d5bb5f	pcm512x_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x18eaf893	sigmadsp_reset
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x632e7c17	devm_sigmadsp_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0x92574f0d	sigmadsp_attach
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xc7655f26	sigmadsp_setup
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp 0xd47582f9	sigmadsp_restrict_params
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sigmadsp-i2c 0x032b87ef	devm_sigmadsp_init_i2c
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0x34656a39	ssm2602_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ssm2602 0xfd6fac57	ssm2602_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x5dc56b23	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xc143c3ec	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ts3a227e 0x9cd8c6d4	ts3a227e_enable_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x2c8035bd	wm8804_probe
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0x5fc4a378	wm8804_remove
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xd1900c54	wm8804_pm
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8804 0xf1731a3f	wm8804_regmap_config
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0xbf65c90e	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0x3fae6ba6	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0x0e94da91	fsl_asrc_get_dma_channel
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-fsl-asrc 0xdf14cd96	fsl_asrc_platform
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL sound/soc/fsl/snd-soc-imx-audmux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x013afbc1	devm_snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x021b6583	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x02fd2e1a	snd_soc_dapm_sync_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0428f0eb	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x04fd4e1f	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x05500b4d	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x08b0162b	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0acecbd7	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0b922fa2	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0c346b73	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0ea9de48	devm_snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x13994d0e	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x16c5b0a5	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x19feb6de	snd_soc_bytes_tlv_callback
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1a9ab9c1	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1b304e89	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1b406328	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1b895110	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1f44f8b2	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x21b92971	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x21e60a9e	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x248de900	snd_soc_resume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x257b8aa7	devm_snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x25f80206	snd_soc_dapm_force_bias_level
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x280300a1	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2cca57ff	snd_soc_component_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2fda945d	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x34f9bfac	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x37dc9f1f	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3a9a2b4b	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3b20efae	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3b56135a	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3bb2c682	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3c7b490f	dapm_mark_endpoints_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3d51b2c1	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3d8bf6dd	snd_soc_component_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x468c9711	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4944c1c8	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4bcb9f75	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4dcb2fc5	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4ebc6e2f	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x4f8ce160	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x53d62e59	snd_soc_info_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x590a8067	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5e0adb22	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5f4345ff	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5fcdbfb2	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x63351c87	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6501ebec	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6628a53b	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x662f295a	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6752761f	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x67b0cd81	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x67fbe8c2	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x69a78461	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6c1fb744	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6c9c5840	snd_soc_card_get_kcontrol
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6ce51519	snd_soc_component_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6e3da4a4	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6fa42b9f	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7291d209	snd_soc_add_component_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x75c8b1f3	snd_soc_dapm_kcontrol_widget
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x76d3cc86	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x78d01167	snd_soc_bytes_info_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7a32d566	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7d5d664d	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e949f3b	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7fa341ac	snd_soc_component_async_complete
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8085ff40	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x816247f9	snd_soc_component_exit_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x82284193	snd_soc_runtime_set_dai_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x82d0d1b6	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x851ffced	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x85f09211	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x86121596	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x87131dc1	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8cb05fa0	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8dbb04a4	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x93f973b9	snd_soc_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x949a4259	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x953ddac7	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x96983328	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x97e8e5bd	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9c276b6e	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9c8acf21	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9cc4edce	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa124fab5	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa2983785	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa2f423b1	snd_soc_component_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa57f6e61	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa782c32d	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa88106a2	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xaae95b5b	snd_soc_jack_add_gpiods
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xaba42611	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb13fc6c9	snd_soc_of_parse_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb1a2f680	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb271ba91	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb27b96f3	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb3bec5d1	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb7903248	snd_soc_component_update_bits_async
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb8c9bb3e	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb8e77000	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbc230885	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbc45c07e	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbd78bca4	snd_soc_dapm_force_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbf2ed7e9	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc468a5b2	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc49a05c0	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc4dc7830	snd_soc_dapm_kcontrol_dapm
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8fec1e3	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc9a82733	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcb24bf19	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcb78e133	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcbc556c5	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcdbcf137	snd_soc_dai_set_bclk_ratio
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xce341c3b	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd173f1af	snd_soc_component_init_regmap
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd5997fb5	snd_soc_dapm_disable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd5e629d6	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd7f1ee7e	snd_soc_set_ac97_ops_of_reset
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd8a93889	dapm_kcontrol_get_value
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd9da213f	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd9de4198	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xda4f0889	snd_soc_of_parse_audio_simple_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdb5e7452	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdc0563c0	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdcbd3b8c	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xde895242	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdf522685	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe009679a	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe178a99c	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe1967a03	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe19b2f3c	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe36bc5ff	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe6044769	snd_soc_of_get_dai_link_codecs
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe88709f2	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe9802b9f	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xef15d364	snd_soc_dapm_nc_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf0bcc8ae	snd_soc_of_get_dai_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf714bc3b	snd_soc_of_parse_audio_prefix
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf8531c3c	snd_soc_card_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf85735a7	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf876ce3d	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf8a36626	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfb8e73f8	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfcc5e890	snd_soc_dapm_enable_pin_unlocked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfd3b1498	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfec07e89	devm_snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x028a695a	line6_version_request_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x202a1b1b	line6_midi_id
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x32e3d20b	line6_read_serial_number
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x588659ad	line6_alloc_sysex_buffer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x5f5f3d4c	line6_suspend
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x6a6808a9	line6_read_data
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x7c71df1c	line6_init_midi
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x8ec973cd	line6_start_timer
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x906c6d6c	line6_pcm_acquire
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0x9786594f	line6_send_raw_message_async
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xa312ea24	line6_init_pcm
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xb452c0e3	line6_pcm_release
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xce69fb91	line6_disconnect
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xd05349d5	line6_resume
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xd21355cd	line6_send_sysex_message
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xe435b4fc	line6_probe
++EXPORT_SYMBOL_GPL sound/usb/line6/snd-usb-line6 0xeef90945	line6_write_data
++EXPORT_SYMBOL_GPL vmlinux 0x005a766e	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0x00602857	_gpiochip_irqchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x00640ffc	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x007b932e	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0x00857a0b	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x009304b6	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00b1ce65	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x00c52e40	regmap_multi_reg_write_bypassed
++EXPORT_SYMBOL_GPL vmlinux 0x00d5a12e	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x00eb96be	of_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x013f1053	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x01437e67	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x014604d3	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0x014ddf17	md_run
++EXPORT_SYMBOL_GPL vmlinux 0x01511371	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x01564da1	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x01663633	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0x0168e690	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x016c9368	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x01781efc	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x0183683f	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0x018d3bad	cpufreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x01c6704d	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x01e6ed1c	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x01f6317a	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0x0209dc80	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0x02174d08	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x021ebfda	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0x02204f1b	serial8250_rpm_put
++EXPORT_SYMBOL_GPL vmlinux 0x026211e2	memory_failure_queue
++EXPORT_SYMBOL_GPL vmlinux 0x027ce3e3	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0x02837de2	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x02908a56	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x02947bc2	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0x02966ae5	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x0299440c	xhci_dbg_trace
++EXPORT_SYMBOL_GPL vmlinux 0x029db5f3	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x02ad4f7a	of_get_display_timings
++EXPORT_SYMBOL_GPL vmlinux 0x02c5fa7d	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x0300aa6b	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0x0309234c	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0x030c2627	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x0321cdbf	of_alias_get_highest_id
++EXPORT_SYMBOL_GPL vmlinux 0x03286448	of_prop_next_u32
++EXPORT_SYMBOL_GPL vmlinux 0x03370c60	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x033832c7	usb_amd_hang_symptom_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x0342af95	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x03442f74	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0349f47d	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0x039fd867	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x03a7e5d0	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x03abffe1	serial8250_do_startup
++EXPORT_SYMBOL_GPL vmlinux 0x03b57026	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x03c5e49c	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x03e969b8	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0402cbbf	preempt_notifier_inc
++EXPORT_SYMBOL_GPL vmlinux 0x040784f2	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0x04226d82	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x043b935f	__tracepoint_io_page_fault
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x0468782b	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x048521bf	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x048ba309	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x049682c9	set_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x04984eaf	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x049b1d62	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04c9bdbd	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x04cbd27a	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x04cbdefb	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0x04df8fbc	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0x04f4a091	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0x0508d53b	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x051ca04e	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0x0533ecd2	devm_devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0x05348e44	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x053494cb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x05539872	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0x0573ebd4	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0x058469a9	of_dma_is_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x05a65522	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0x05ae9600	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x05cf51ab	devm_regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x05d9211a	of_node_to_nid
++EXPORT_SYMBOL_GPL vmlinux 0x05ef2b22	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x061dee59	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x068c2e0f	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0x069c54c7	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x06b96214	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0x06bc8a12	rio_enable_rx_tx_port
++EXPORT_SYMBOL_GPL vmlinux 0x0740542f	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0740cae9	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x074fa924	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x0766d827	rio_request_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x07677de0	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0x077eedf8	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07b60850	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x07be7903	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x07caafa7	spi_finalize_current_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x07cc0d7d	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x07ce6095	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x07e6b496	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x07fa3a9e	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x07ffd187	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x0807629b	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x082c283c	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0x0839bb24	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x0841146f	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x0842aa74	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x0844933c	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x085527b0	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x088b2931	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x088bfa7e	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x08b7b636	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0x08b95b46	tps65217_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x08bc0870	compat_put_timespec
++EXPORT_SYMBOL_GPL vmlinux 0x08d37605	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0x08d91c22	mm_iommu_put
++EXPORT_SYMBOL_GPL vmlinux 0x08e306b6	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x0901e1d9	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x0905dde9	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x090e1f3c	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0x091c824a	machine_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x093559ee	gpiochip_generic_request
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0952af60	fb_videomode_from_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x09664692	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x096fec93	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0x097aae46	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0x097f5ad6	regmap_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x0991ffc0	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x09ae8513	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x09e3e10f	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x09e67ebd	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0x09ebafcc	gpiod_export_link
++EXPORT_SYMBOL_GPL vmlinux 0x0a069d2b	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x0a2a65ec	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x0a339748	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x0a3dbba7	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x0a4b0c0e	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x0a51ae5b	virq_to_hw
++EXPORT_SYMBOL_GPL vmlinux 0x0a6c2929	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x0a762be8	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0x0a7fe7ff	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x0a8418e4	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0aa985c4	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0x0acf31fb	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0x0aead6b6	mpic_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x0aff3cf5	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0b04c696	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b20e567	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0b297602	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0x0b94ebcd	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x0b99acd5	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0x0ba90039	gpiochip_free_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0x0bc2db7c	usb_choose_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x0bca1eb4	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0x0bee0ba8	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0bfd8475	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x0bfe3912	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0ca5f5c1	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0x0caf75d9	opal_flash_erase
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0ce3ee5a	mmu_kernel_ssize
++EXPORT_SYMBOL_GPL vmlinux 0x0cf08d94	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x0cfe1ef7	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0x0d17ade1	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x0d22eb7b	gpiod_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d4edacc	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x0d5be637	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x0d73a952	GregorianDay
++EXPORT_SYMBOL_GPL vmlinux 0x0d79acf2	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0dc10fa9	nd_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x0dcc4849	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0x0dcc9df9	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x0dcf47ca	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0de06988	cpu_first_thread_of_core
++EXPORT_SYMBOL_GPL vmlinux 0x0dedca93	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x0def3f70	regmap_fields_force_write
++EXPORT_SYMBOL_GPL vmlinux 0x0df4b4a8	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x0df90107	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x0e089799	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x0e10f895	regulator_list_hardware_vsel
++EXPORT_SYMBOL_GPL vmlinux 0x0e21245f	rio_dev_get
++EXPORT_SYMBOL_GPL vmlinux 0x0e3908c3	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x0e9a31f4	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0x0ea41f64	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x0ea72ded	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x0ecba3bf	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x0ecf823a	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x0ed52459	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x0ee8e5db	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x0ef2b6b9	rio_unlock_device
++EXPORT_SYMBOL_GPL vmlinux 0x0f012044	__tracepoint_detach_device_from_domain
++EXPORT_SYMBOL_GPL vmlinux 0x0f265f3b	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0x0f312e86	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f5abda2	sysfs_add_device_to_node
++EXPORT_SYMBOL_GPL vmlinux 0x0f5fc807	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0fa72535	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0x0fca80af	copro_flush_all_slbs
++EXPORT_SYMBOL_GPL vmlinux 0x0fe4b676	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0x0ff6fdd9	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x1007097b	mmc_send_tuning
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x1034c948	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0x105d3ade	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0x106f2ddd	serial8250_do_set_mctrl
++EXPORT_SYMBOL_GPL vmlinux 0x108382ce	copro_calculate_slb
++EXPORT_SYMBOL_GPL vmlinux 0x10846468	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x10a8ce84	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x10b2b903	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x10bc0ccc	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL vmlinux 0x10bcd3cf	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x10d1b5cb	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x10d213fd	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x110ae533	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0x1114011d	threads_shift
++EXPORT_SYMBOL_GPL vmlinux 0x11306fd8	iommu_capable
++EXPORT_SYMBOL_GPL vmlinux 0x113494bf	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0x11365cdf	regulator_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x11388f48	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x1142c2f9	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1161793f	power_supply_put
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x117c7305	hwpoison_filter_dev_major
++EXPORT_SYMBOL_GPL vmlinux 0x11904e74	user_read
++EXPORT_SYMBOL_GPL vmlinux 0x119536b6	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0x11c1ffe3	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0x11e40440	dev_coredumpm
++EXPORT_SYMBOL_GPL vmlinux 0x12028845	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0x1205c58c	powercap_unregister_zone
++EXPORT_SYMBOL_GPL vmlinux 0x121a024c	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1225b14a	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0x1237eae0	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x12466ae5	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x12470a1b	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x12618f89	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x12993273	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x12c1cf11	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0x12c6b3a1	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x12cd5903	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x12ee3315	of_property_count_elems_of_size
++EXPORT_SYMBOL_GPL vmlinux 0x1309ddcd	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x136209db	power_supply_reg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x136a4ee6	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x13775d2c	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x1389da84	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0x138cdbb3	ehci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0x13975dff	gpiochip_generic_free
++EXPORT_SYMBOL_GPL vmlinux 0x1398d82c	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0x139c22f1	gpiod_get_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x13a0be72	phy_create_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x13a2672c	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x13ad647f	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x13ce87e8	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0x13d3a50e	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x13d6dd8c	mbox_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x13e5ea13	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0x13f07005	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0x1435e9ad	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0x14462b8f	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x1457116c	devm_regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x146f496a	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0x147aa29c	cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x147e1f0b	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x14b08f84	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x14b4233e	eeh_pe_configure
++EXPORT_SYMBOL_GPL vmlinux 0x14b67acf	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0x14c5eab6	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x14cef720	rio_get_comptag
++EXPORT_SYMBOL_GPL vmlinux 0x14cf1599	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0x14d21308	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0x14e953bb	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x150991ea	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0x150f7243	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x1515cf34	nvdimm_bus_check_dimm_count
++EXPORT_SYMBOL_GPL vmlinux 0x1529e650	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x153d9fbd	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x15665c62	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x1574700a	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x15776917	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x15b8b44d	opal_async_wait_response
++EXPORT_SYMBOL_GPL vmlinux 0x15c21e5e	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x15eb860e	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x160c47d3	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0x162fc6bd	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x16377ab7	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0x16380d30	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0x1645e7bf	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x166389ec	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0x1677ef49	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x167c55f1	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x16984be6	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0x16d65d10	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x16da5a11	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0x16e02407	pci_iomap_wc
++EXPORT_SYMBOL_GPL vmlinux 0x1704a4c3	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0x17101d4e	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0x1717ad0c	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0x171eb1ed	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0x173904fb	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x1752b610	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0x17715696	generic_access_phys
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x1784a0f9	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x17994d70	memhp_auto_online
++EXPORT_SYMBOL_GPL vmlinux 0x179c6390	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x17da158f	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x17e19801	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x1829b9ed	hwpoison_filter_memcg
++EXPORT_SYMBOL_GPL vmlinux 0x1838e539	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x184f05c5	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x185a4e1a	kvmppc_h_get_tce
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x189f874d	powernv_get_random_long
++EXPORT_SYMBOL_GPL vmlinux 0x18a1ece9	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x18c69eb6	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x18c94a64	dax_fault
++EXPORT_SYMBOL_GPL vmlinux 0x190a6556	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x19119803	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x1929b819	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0x1938dcbb	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x193f8543	devm_led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x1979da35	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0x1990bd6c	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0x19957bf8	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19c6776e	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1a16ca9c	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0x1a1e84ff	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0x1a222928	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0x1a319511	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0x1a42a41e	__devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x1a4c2a7e	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0x1a7894d0	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x1a7c1ef9	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x1a8c5907	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0x1a967885	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x1aa9ed37	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1ad0f0cc	rio_mport_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x1b039a13	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1b5162f7	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x1b55a99a	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x1b6a5026	devm_usb_get_phy_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x1b7b1780	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x1b7deca4	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1b9664d1	__destroy_context
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1bab7ab8	gpiod_unexport
++EXPORT_SYMBOL_GPL vmlinux 0x1bbd5a93	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x1bc1872c	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x1bcd575a	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x1bd25fa0	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0x1bdd4cad	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x1be3fc4d	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x1c1215bd	threads_core_mask
++EXPORT_SYMBOL_GPL vmlinux 0x1c1e19a0	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x1c2ad10a	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x1c395548	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0x1c54f675	of_get_nand_ecc_mode
++EXPORT_SYMBOL_GPL vmlinux 0x1c5541bd	cpufreq_boost_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c648fc8	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0x1c6b75e7	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x1c7df74c	kvm_hv_vm_activated
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1ca44887	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0x1cbfe547	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0x1ccb5ee9	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0x1cd484ff	gpiod_to_chip
++EXPORT_SYMBOL_GPL vmlinux 0x1cdb2147	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x1ce9976f	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x1cea530c	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x1cf82066	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x1cff5f1d	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x1d0f23b9	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0x1d13f022	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d22318b	rio_request_mport_dma
++EXPORT_SYMBOL_GPL vmlinux 0x1d44ac7b	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x1d584e4e	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d652735	__tracepoint_attach_device_to_domain
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1d95ee56	devfreq_event_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1d96575b	of_pci_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0x1df9179b	mpc8xxx_spi_rx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0x1e000879	hwpoison_filter_enable
++EXPORT_SYMBOL_GPL vmlinux 0x1e00bd23	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x1e14b635	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0x1e2e1485	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x1e47a247	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0x1e48a69e	__spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1e49c3ad	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e6352a4	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0x1e666f63	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x1e776468	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e8832a0	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0x1e8fac8e	wireless_nlevent_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebac2bd	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1eca3fee	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0x1ecc368a	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x1edc21cb	hwpoison_filter_flags_mask
++EXPORT_SYMBOL_GPL vmlinux 0x1ee140b0	nvdimm_pmem_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x1f00ce56	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0x1f1988f7	hwpoison_filter_flags_value
++EXPORT_SYMBOL_GPL vmlinux 0x1f298f12	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0x1f3eb54e	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0x1f418544	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x1f4948c4	__rio_local_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x1f616682	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8cd142	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1f8f5c49	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x1f96b8a0	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1fa9c1ae	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x1fb0348f	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x1fb113be	of_get_nand_ecc_step_size
++EXPORT_SYMBOL_GPL vmlinux 0x2030522c	xhci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x206656ea	of_pci_range_parser_one
++EXPORT_SYMBOL_GPL vmlinux 0x2067c6f4	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x20a3fdd8	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0x20a6a0f3	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0x20aa6f51	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x20c7a8fa	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x20cc62df	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0x20da7b9f	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0x20e16bc4	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0x20ef8bf9	flush_altivec_to_thread
++EXPORT_SYMBOL_GPL vmlinux 0x20f00322	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x20fcbd60	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x211850f5	htab_hash_mask
++EXPORT_SYMBOL_GPL vmlinux 0x21691abe	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x21704a7d	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21c32c8d	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x22013057	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x221481ce	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x2253324d	kvm_alloc_hpt
++EXPORT_SYMBOL_GPL vmlinux 0x22761aa2	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x22d65391	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x22f25937	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x23026cca	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0x235816a2	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0x235eb49e	__regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x238ba7d9	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x238bc41f	rio_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x238ea3dc	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0x23ad47cf	devm_regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x23b0ca35	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x23d5f97b	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x23df16fe	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x24011e14	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x24014e28	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0x240b0ce4	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x2448316e	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x24515475	rio_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0x245b2f40	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0x246da8bc	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x247d3d54	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2493a5ab	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24be147f	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x251e5a9a	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x25279482	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0x2531d2ee	gpiod_export
++EXPORT_SYMBOL_GPL vmlinux 0x254d1062	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x2563023e	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x2566632d	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0x259c64a5	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0x25d49e8f	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x25ddd2b1	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x25e42779	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x26209a43	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x26323931	dax_pfn_mkwrite
++EXPORT_SYMBOL_GPL vmlinux 0x2646b6fc	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x265fd86d	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x266e4845	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x26969cc9	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x26a4f283	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26c9611e	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x26deb46f	__devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x26ea421b	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0x270450f8	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x2712cbe2	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0x271da1d0	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x272645f3	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0x275a0fbd	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x275e2c51	cpu_add_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0x276a85b3	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x277ece13	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0x27ae1755	rio_release_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x27c0c4be	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27e501fa	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x27feb362	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x280c5c87	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x282cdabc	usb_led_activity
++EXPORT_SYMBOL_GPL vmlinux 0x28779167	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x288bef19	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x28acb287	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x28de33ea	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x28ef7ebc	gpiod_put_array
++EXPORT_SYMBOL_GPL vmlinux 0x28f19dc6	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x28ff99a9	opal_prd_msg
++EXPORT_SYMBOL_GPL vmlinux 0x2914ce45	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x2918c159	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x291bbbaf	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x29660baa	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x297811ca	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x29816ae3	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x29969b1a	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x29b29007	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x29c02d25	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x29dc7740	of_get_fb_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x29e1311a	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x29f47bcb	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x2a0e16c2	cpufreq_freq_attr_scaling_boost_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x2a156e8e	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0x2a1ac940	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0x2a24c162	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x2a2f0295	regmap_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x2a303b31	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0x2a3b0f86	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x2a4656ef	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0x2a664f17	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a8864ef	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0x2a92e8ac	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x2aa4f632	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x2ac0325d	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x2acdeefa	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x2aed93d5	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x2af21994	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x2afcc67a	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x2afdedfd	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0x2b017563	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x2b03caa1	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x2b116fc8	__tracepoint_add_device_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x2b23a594	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2b3b55f9	gpiod_set_raw_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x2b3f8c74	power_supply_external_power_changed
++EXPORT_SYMBOL_GPL vmlinux 0x2b4147ed	kvmppc_hcall_impl_hv_realmode
++EXPORT_SYMBOL_GPL vmlinux 0x2b436739	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0x2b5c303b	smp_send_reschedule
++EXPORT_SYMBOL_GPL vmlinux 0x2b65403e	led_sysfs_enable
++EXPORT_SYMBOL_GPL vmlinux 0x2b84b903	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x2bb4cae4	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0x2bb988f3	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0x2bf03f2e	regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x2bfa985e	nd_cmd_dimm_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c25f741	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c4ad38b	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0x2c6b4752	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x2c721b59	thermal_of_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c871e87	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0x2c97f8a2	of_reconfig_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2cd0b218	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x2cd88f51	kvm_hv_vm_deactivated
++EXPORT_SYMBOL_GPL vmlinux 0x2ce2e0b6	of_get_regulator_init_data
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2cff9a5c	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x2d163d36	of_irq_parse_one
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d278d5c	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d543944	gpiod_get_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d5e14ba	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x2d708191	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x2d808a0c	scom_map_device
++EXPORT_SYMBOL_GPL vmlinux 0x2da663a4	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0x2dc5a6d1	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0x2dcce69e	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2def995f	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0x2df5595f	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2e0e4fde	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0x2e1da9fb	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e63beb1	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2e90ae61	tps65217_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x2eab1ee0	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ed075b7	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0x2ed49bb1	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x2ef26873	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x2efeb9ce	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f126631	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0x2f3013d8	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x2f386a88	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f4c7b2b	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0x2f5a87f1	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2f75aa14	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f87f7d2	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0x2fa5a166	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x2fa79e75	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0x2fbf3cb8	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x2fc126cb	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x2ffb5ff7	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0x301832fb	opal_async_get_token_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0x303ac1e2	cpu_remove_dev_attr
++EXPORT_SYMBOL_GPL vmlinux 0x304accc1	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0x305612c2	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x306f2202	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0x30ab42c0	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x30ce3c6a	rq_flush_dcache_pages
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30e6cb04	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0x30f0025e	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x31202621	rio_mport_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x3136f21b	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x313b60fd	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x313e3744	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x3146d838	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x315fede9	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x3170ee43	hwpoison_filter
++EXPORT_SYMBOL_GPL vmlinux 0x3184abc1	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x31bba0b4	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x31bef441	opal_i2c_request
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c69043	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31f58a11	gpiod_set_array_value
++EXPORT_SYMBOL_GPL vmlinux 0x320f5ab0	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x321bdbb1	compat_get_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x322660b1	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x324846c1	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0x32492525	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x324b37de	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0x32883e2f	gpiochip_unlock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x3296d4d3	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x32ab17d7	of_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x32bc0fcf	preempt_notifier_dec
++EXPORT_SYMBOL_GPL vmlinux 0x32c1760f	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32c7f927	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x32f50aad	mmput
++EXPORT_SYMBOL_GPL vmlinux 0x330debbf	of_dma_configure
++EXPORT_SYMBOL_GPL vmlinux 0x332b1290	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x33398de6	mmu_psize_defs
++EXPORT_SYMBOL_GPL vmlinux 0x33495815	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0x335179b3	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x335f30ce	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x337786fa	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x33810806	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x3399ee50	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0x33b1b114	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x33c5ee22	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x341482a2	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x3417ee94	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0x342238f0	mm_iommu_get
++EXPORT_SYMBOL_GPL vmlinux 0x3432cf5b	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0x34335461	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x343912c4	to_of_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x344275e6	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x34427a35	unregister_cxl_calls
++EXPORT_SYMBOL_GPL vmlinux 0x34429393	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34a8da5f	__tracepoint_xhci_dbg_quirks
++EXPORT_SYMBOL_GPL vmlinux 0x34af0adf	opal_ipmi_send
++EXPORT_SYMBOL_GPL vmlinux 0x34b4f53a	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x34fdfc2b	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x35021edb	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x35097e49	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x350dc79d	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x352a0549	cpufreq_table_validate_and_show
++EXPORT_SYMBOL_GPL vmlinux 0x352cb517	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x354554d0	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0x3567743b	vfio_external_user_iommu_id
++EXPORT_SYMBOL_GPL vmlinux 0x3572c1d3	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x358cd231	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x359fed98	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x35b51836	dax_clear_blocks
++EXPORT_SYMBOL_GPL vmlinux 0x35bf2acd	nd_fletcher64
++EXPORT_SYMBOL_GPL vmlinux 0x35cb0b8c	of_irq_find_parent
++EXPORT_SYMBOL_GPL vmlinux 0x35e5d73f	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0x35e81ac9	rio_release_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x35ed1af9	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0x35fb3884	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x360e9409	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x3610bdea	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0x36150db1	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x362b0266	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0x362b158e	of_pci_find_msi_chip_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x3651377c	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0x36584580	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0x366228eb	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x368f1fea	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36af01ad	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x36b7ee33	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x36bda7b0	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x36ce361d	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x36dab97f	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x36e5d14b	serial8250_rpm_get
++EXPORT_SYMBOL_GPL vmlinux 0x36f87b83	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x372d3ea9	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0x37442ed6	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL vmlinux 0x37583673	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x37586a65	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0x37a8568d	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0x37a9d332	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x37b4a194	of_dma_get_range
++EXPORT_SYMBOL_GPL vmlinux 0x37ef1216	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0x37ef4a9d	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x382985b8	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0x3830f63b	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0x3837af69	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x383b590a	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0x384753ee	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0x38639300	of_overlay_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x387ef1ea	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0x38907651	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0x38ab32e7	pnv_get_supported_cpuidle_states
++EXPORT_SYMBOL_GPL vmlinux 0x38b0f559	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0x38b387a2	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0x38bc00a8	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x38c739a2	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x38c82fcf	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x38c9c3bf	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x38e23f40	put_device
++EXPORT_SYMBOL_GPL vmlinux 0x38fad566	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x391c8bc3	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x3927bd2f	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0x392d367b	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x392fe739	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x39597d25	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x396f334b	of_irq_parse_raw
++EXPORT_SYMBOL_GPL vmlinux 0x39ca07cc	maxim_charger_calc_reg_current
++EXPORT_SYMBOL_GPL vmlinux 0x39ccb4d3	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0x39d0573b	gpiod_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x39d217b1	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0x39db1b2f	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x39ea6c70	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x39f9666a	dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0x3a053339	usb_hub_release_port
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a280cbe	thermal_zone_of_sensor_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3a38dc65	memory_failure
++EXPORT_SYMBOL_GPL vmlinux 0x3a3a8d16	regmap_attach_dev
++EXPORT_SYMBOL_GPL vmlinux 0x3a47dab8	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x3a4813e2	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a5fcb90	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0x3a604322	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0x3a6cb00c	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x3a719b9f	gpiod_set_raw_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x3a773ecf	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0x3a95f5a9	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3ab25b9e	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3abb166b	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3ad0e201	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x3af7f197	mpc8xxx_spi_rx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x3b079dda	extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x3b0e5bf5	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x3b5528ec	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x3b7c01d0	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x3b816f87	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0x3b831365	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x3b924f48	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x3b92b1eb	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0x3ba33302	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0x3ba3604a	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x3bb509af	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x3bc6c748	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x3bf30d51	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x3bf93b86	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3c18835e	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x3c2b1f0d	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x3c391b35	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0x3c3d9794	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x3c51ea7c	opal_leds_get_ind
++EXPORT_SYMBOL_GPL vmlinux 0x3c7a8d48	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x3c844d17	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3c95dfb8	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0x3c9ebb92	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x3cc07c60	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cf69baf	slice_get_unmapped_area
++EXPORT_SYMBOL_GPL vmlinux 0x3d0ec24c	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x3d30574e	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d497c71	user_update
++EXPORT_SYMBOL_GPL vmlinux 0x3d53a2c7	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0x3d612305	iommu_direction_to_tce_perm
++EXPORT_SYMBOL_GPL vmlinux 0x3d70cce1	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x3d840925	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x3d9679f2	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x3da67a23	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x3dc526a9	arizona_of_match
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dcdc52d	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3df5f31f	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0x3dfc436e	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x3dfd45dd	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x3e259239	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e7b8bef	gpiod_get_index
++EXPORT_SYMBOL_GPL vmlinux 0x3eab2407	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x3eb92651	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0x3eefae88	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3efd1dbe	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0x3f01395d	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0x3f1cb321	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0x3f29b457	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3f462cc7	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x3f6093a7	serial8250_set_defaults
++EXPORT_SYMBOL_GPL vmlinux 0x3f66ba55	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0x3f7ff141	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x3f877815	gpiod_get_array_optional
++EXPORT_SYMBOL_GPL vmlinux 0x3fa485cc	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x3fa5af9c	nd_cmd_bus_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3fa5cc3d	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x3fa7339a	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x3fb14423	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x3fb2bd8a	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0x3fbaf525	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0x3fbfa3a6	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0x3fd17cfc	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0x3fe35aea	irq_bypass_unregister_consumer
++EXPORT_SYMBOL_GPL vmlinux 0x3fe9bfaf	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x3fef7431	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x4028d776	devm_extcon_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x403e76e0	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x405fb3b7	of_reserved_mem_device_release
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x406a74de	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x4098be04	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x40a8b1c7	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40b3bcc4	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x40c0467c	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x40c0763d	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x40d38b5e	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40d97c09	ehci_reset
++EXPORT_SYMBOL_GPL vmlinux 0x40e401fc	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x40ea577a	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x40ee652f	of_modalias_node
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x410db046	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x412a50b0	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0x412ebee4	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x41672d37	to_nvdimm_bus
++EXPORT_SYMBOL_GPL vmlinux 0x416e7c4e	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x41717023	vfio_virqfd_enable
++EXPORT_SYMBOL_GPL vmlinux 0x4180759e	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x418873cc	irq_bypass_register_producer
++EXPORT_SYMBOL_GPL vmlinux 0x41ad198c	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x41c50788	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x41d9f243	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x4216ba5d	rio_mport_get_physefb
++EXPORT_SYMBOL_GPL vmlinux 0x4237e56e	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x425ccf19	__spin_yield
++EXPORT_SYMBOL_GPL vmlinux 0x42635d55	pm_suspend_global_flags
++EXPORT_SYMBOL_GPL vmlinux 0x426b2c92	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x4277c016	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x427a1fc3	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x427de547	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x429d7b78	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x42b8ff7f	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0x42f48f37	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x42fd7b26	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0x432702e6	mm_iommu_mapped_inc
++EXPORT_SYMBOL_GPL vmlinux 0x435077ba	spi_statistics_add_transfer_stats
++EXPORT_SYMBOL_GPL vmlinux 0x4356b872	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x43619e1a	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x4364e53d	nd_blk_region_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x43854187	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43ca7eb8	mbox_chan_received_data
++EXPORT_SYMBOL_GPL vmlinux 0x43cef27d	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x440a668b	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x44375c03	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x446e3c47	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x44914ad1	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0x44932f40	to_nd_desc
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44cd911a	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0x44ece53d	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0x44fa8b7c	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x44fc6804	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x450fb522	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x45190b1f	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0x45219911	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x4547de3d	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x456143c6	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x45739781	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x4588e114	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x458eaa2f	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x45a7ef18	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x45ab21bc	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0x45b527d7	inet_csk_compat_getsockopt
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45d18ebe	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x45d95dac	vfio_virqfd_disable
++EXPORT_SYMBOL_GPL vmlinux 0x45f9723c	fixed_phy_register
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x4613adea	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0x463aa8d9	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x46697e64	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x4676c1a9	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x467a1fed	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x4680382b	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x4688c96a	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x46bfd35f	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0x46dc4298	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0x46e25e31	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x46e6ee88	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0x46f5f2a7	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x47340d91	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x473f0ba9	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0x474e4120	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x47542007	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x47622d27	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0x476a5e41	agp_remove_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x47851b42	regmap_get_max_register
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x478edd4c	i2c_generic_gpio_recovery
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47bdef5a	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x47c4f7fc	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x47c85a8c	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0x47d57edd	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4822dd56	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4824bd0f	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x48322f67	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x4857eb8e	input_class
++EXPORT_SYMBOL_GPL vmlinux 0x48652d8d	gpiochip_set_chained_irqchip
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x48c8cc0b	vfio_del_group_dev
++EXPORT_SYMBOL_GPL vmlinux 0x48d63c48	pcibios_finish_adding_to_bus
++EXPORT_SYMBOL_GPL vmlinux 0x48d7ad9b	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x48fb38bc	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x49151610	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x492d1402	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x493f0d06	nvdimm_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x494dcb64	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0x495fa429	rio_unregister_scan
++EXPORT_SYMBOL_GPL vmlinux 0x49654826	arizona_of_get_type
++EXPORT_SYMBOL_GPL vmlinux 0x49847d3c	srp_rport_del
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x4992df91	component_add
++EXPORT_SYMBOL_GPL vmlinux 0x49b34964	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x49bf6927	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0x49c44e7a	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x49c4f2c9	dax_truncate_page
++EXPORT_SYMBOL_GPL vmlinux 0x49d4159a	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4a026413	mm_iommu_mapped_dec
++EXPORT_SYMBOL_GPL vmlinux 0x4a0b8660	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0x4a2a0374	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0x4a2ee477	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0x4a35fd34	of_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0x4a4a10af	__devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a4d1ea6	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x4a5a77d8	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0x4a6cb5d1	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0x4a7b653f	devm_regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4a8c58de	of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4a90160e	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x4a9c3d2d	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0x4aad67ce	remove_phb_dynamic
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4aba8408	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x4acb19e3	of_get_nand_on_flash_bbt
++EXPORT_SYMBOL_GPL vmlinux 0x4ade320d	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4ae299ae	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0x4afb9c3c	tps6586x_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x4b58884b	ehci_adjust_port_wakeup_flags
++EXPORT_SYMBOL_GPL vmlinux 0x4b88171f	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x4b8b1020	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0x4b9611af	mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x4be692f3	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x4c024ed2	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0x4c125af7	to_nd_region
++EXPORT_SYMBOL_GPL vmlinux 0x4c287171	gpiod_direction_output_raw
++EXPORT_SYMBOL_GPL vmlinux 0x4c2cf3a7	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c645f9e	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x4c70824e	regmap_fields_write
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4cc024ac	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x4cd2afdb	gpiochip_line_is_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4cd4d91c	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x4cd7bce1	iommu_del_device
++EXPORT_SYMBOL_GPL vmlinux 0x4ce477f8	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0x4cf50f42	of_overlay_create
++EXPORT_SYMBOL_GPL vmlinux 0x4cf939fe	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d18d24d	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x4d1978c0	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x4d2fff37	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0x4d3af9c3	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x4d3f19f2	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x4d464b1b	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x4d49d38a	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4d7e3f4f	of_irq_parse_and_map_pci
++EXPORT_SYMBOL_GPL vmlinux 0x4d9f61f1	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0x4da563e6	phy_exit
++EXPORT_SYMBOL_GPL vmlinux 0x4dba3788	of_pci_parse_bus_range
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4e0f1978	hash_page_mm
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e2dac59	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x4e54ce48	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x4e5f3efa	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4e709d5f	pcibios_free_controller
++EXPORT_SYMBOL_GPL vmlinux 0x4e94a7e4	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x4e981b7b	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0x4ebcbde4	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0x4ed0363a	phy_remove_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4ee21760	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4ef7e360	irq_map_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x4f05925c	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4f14a78a	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x4f180bd7	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f3b798b	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x4f543b6c	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4f63f48e	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4fb3ce60	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0x4fcff4de	gpiod_get_index_optional
++EXPORT_SYMBOL_GPL vmlinux 0x4fd005c9	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fdd2bdf	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5030fdbb	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x50357718	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x5038c62d	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0x5039c4ab	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0x505c8e3b	to_nd_blk_region
++EXPORT_SYMBOL_GPL vmlinux 0x507596d8	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x507de8c6	add_memory
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x50879147	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x508e37f6	arizona_of_get_named_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x509a7d8b	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0x50a2aa62	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50faa7e3	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x510e1c71	mm_iommu_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x512ce09b	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x5143b7a2	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x51467922	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x516433dc	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0x518d65e1	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0x51b08928	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x51b65a26	rtc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x51cd09f8	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x51d3da6e	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x51d73035	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0x51e722fd	of_irq_parse_pci
++EXPORT_SYMBOL_GPL vmlinux 0x51e72c20	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x51e893b0	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x51f702ac	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x51f9ecd4	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x5205e64d	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x520cb88b	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x522f538b	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x5231c483	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x52325d6b	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x5272d8bc	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0x527fc559	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0x52a41251	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x52a42c92	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x52b092ca	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0x52b3e7c7	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x52de8d28	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x53026441	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x53055501	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0x5335dd11	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x5355dfb4	rio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x5360f4e4	regmap_write_bits
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x53704fc2	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x537e83b2	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0x53845097	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0x5395ee2a	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0x5406d03b	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0x5418179d	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x54215db5	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0x5433656a	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x54462683	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0x54533303	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x54542e73	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x546c5565	ppc_tb_freq
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54d46690	uart_parse_earlycon
++EXPORT_SYMBOL_GPL vmlinux 0x54ed8215	iommu_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x54f2fa9b	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x54f61ede	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x55133960	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x55181239	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0x551d5478	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x552a1800	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0x553b49a4	cpufreq_get_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x555fd81d	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0x5565f9d4	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x5573f3dd	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x55826f58	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0x558754fa	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0x5588879e	kvmppc_entry_trampoline
++EXPORT_SYMBOL_GPL vmlinux 0x559e42fc	kvmppc_do_h_remove
++EXPORT_SYMBOL_GPL vmlinux 0x55cdebbb	nd_cmd_in_size
++EXPORT_SYMBOL_GPL vmlinux 0x55cf7828	find_module
++EXPORT_SYMBOL_GPL vmlinux 0x55dc6fa4	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x55e62f89	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x55e9d516	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x55ee8a0b	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x55eec43b	devm_regulator_bulk_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x55f51ef3	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0x560aa1db	opal_tpo_write
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x5679f49c	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0x567dddca	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0x567f8287	cxl_update_properties
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x56a7ebec	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x56cb8450	extcon_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x575b35b6	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0x575c5f94	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0x576a24b4	of_usb_update_otg_caps
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57a19a5e	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x57bb94c9	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x57c133a4	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0x57c39727	kdb_register_flags
++EXPORT_SYMBOL_GPL vmlinux 0x57e585c3	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x5809fadb	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0x58110346	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x58406724	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0x5843d6df	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x586154a0	usb_hcd_amd_remote_wakeup_quirk
++EXPORT_SYMBOL_GPL vmlinux 0x5892f832	release_pmc_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58b6b899	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0x58ce304a	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x58ced57b	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0x58dd435c	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0x58f22e7b	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x58fe9409	rio_inb_pwrite_handler
++EXPORT_SYMBOL_GPL vmlinux 0x59312802	gpiod_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x5937e987	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x5942991e	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x59536970	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0x59578e34	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0x595a2709	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0x596dd5a6	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x59963dfb	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x59b2adbf	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x59c8d7f4	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x5a024ecd	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x5a0a9543	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0x5a243525	palmas_ext_control_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x5a30682f	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0x5a3a390c	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0x5a74a80c	wm5110_revd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x5a797e31	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a890a91	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0x5a9f17f1	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x5ab83e24	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x5ac2d293	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0x5ad73f14	i2c_recover_bus
++EXPORT_SYMBOL_GPL vmlinux 0x5b05cd0e	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0x5b0a038d	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x5b24abc3	of_reconfig_get_state_change
++EXPORT_SYMBOL_GPL vmlinux 0x5b2e17e0	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0x5b32f419	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x5b332ed9	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0x5b650b73	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x5b75ed8a	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x5b95c772	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5be6bf67	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0x5bed196a	eeh_pe_inject_err
++EXPORT_SYMBOL_GPL vmlinux 0x5c148d91	dmaengine_unmap_put
++EXPORT_SYMBOL_GPL vmlinux 0x5c23fd9b	of_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x5c40df33	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0x5c451940	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x5c518ca4	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x5c5a1b16	tick_broadcast_control
++EXPORT_SYMBOL_GPL vmlinux 0x5c77d6e5	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cbc7160	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5d05b54b	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d39da7d	mpc8xxx_spi_tx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5dd47995	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0x5e196e0c	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0x5e24a93a	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0x5e50cf02	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e6f8c03	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0x5eae874b	usb_gen_phy_init
++EXPORT_SYMBOL_GPL vmlinux 0x5eb57ffc	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x5edbdd1f	rio_route_clr_table
++EXPORT_SYMBOL_GPL vmlinux 0x5edc247f	xhci_run
++EXPORT_SYMBOL_GPL vmlinux 0x5ee6a530	of_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x5ee7542e	reserve_pmc_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x5ef37f03	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x5f0f2c8d	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0x5f1dd573	devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0x5f216581	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x5f226035	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x5f53dd92	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x5f577cde	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0x5fad701a	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x5fe1da56	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x5fe81a9b	regmap_get_raw_read_max
++EXPORT_SYMBOL_GPL vmlinux 0x5ffb42de	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x60467b06	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x605950b8	policy_has_boost_freq
++EXPORT_SYMBOL_GPL vmlinux 0x6078c362	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x607fa6c9	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0x60811ab5	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x6093a232	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0x60987d84	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x60a5ff22	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x60b30d10	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0x60bb0f77	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0x60c00ee6	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x60cca309	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x60e9a5f0	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x60f8ffad	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0x61303a22	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x6154c1bb	of_gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0x61972506	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x619ae620	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0x61a90c54	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x61b18a5a	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x61b678c4	phy_pm_runtime_put_sync
++EXPORT_SYMBOL_GPL vmlinux 0x61c76884	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x61d57e61	phy_pm_runtime_put
++EXPORT_SYMBOL_GPL vmlinux 0x62107b0d	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x62126bbe	reservation_object_get_fences_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x6214b16c	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x622cc597	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0x6248fb21	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0x624cee03	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x6269825c	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x626f70f1	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0x6276b1e7	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x62779524	of_usb_host_tpl_support
++EXPORT_SYMBOL_GPL vmlinux 0x627ecd70	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0x628db191	rio_release_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x62a54c74	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0x62bb152b	serial8250_init_port
++EXPORT_SYMBOL_GPL vmlinux 0x62bd5a6d	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x62bfa294	srp_rport_add
++EXPORT_SYMBOL_GPL vmlinux 0x62d8c128	fwnode_get_named_gpiod
++EXPORT_SYMBOL_GPL vmlinux 0x62d931af	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0x62e74dbd	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x62e9e929	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0x62f43a80	of_property_read_string_helper
++EXPORT_SYMBOL_GPL vmlinux 0x62fd8c38	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x62fe2596	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x631785d6	devm_extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x631cc89b	devm_power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x634e2aca	rio_mport_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x634eccc0	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x63539865	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0x63a31dc9	nvdimm_bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x63b062de	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x63db7118	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x63eda3e7	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0x63f14ebe	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x63f4923b	regmap_get_val_endian
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x64270af6	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x6457d9f0	of_platform_populate
++EXPORT_SYMBOL_GPL vmlinux 0x64a7796f	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x64acec5a	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0x64e80dfb	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x650d3794	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x650eac17	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x65425efd	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x6546740a	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x655306f2	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0x65577457	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x65732814	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x6593f213	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x65ac9505	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65c64f9f	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65d2d6d6	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0x65d66232	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x666df22a	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x668028eb	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x6688a7c9	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x6698cd93	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0x66afb53b	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x66b978ae	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66e3ff9c	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0x672898c4	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0x673cc0e4	of_reserved_mem_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6764ddd9	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x677b6a5c	rio_request_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x67806bab	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x6784375c	register_cxl_calls
++EXPORT_SYMBOL_GPL vmlinux 0x678a4105	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x6797bde0	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x67987447	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x67a9adf1	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x67c369f1	wm8998_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x67c78afc	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x67d83750	irq_of_parse_and_map
++EXPORT_SYMBOL_GPL vmlinux 0x67e979fe	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x67ea1b2a	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x682fc50c	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x684a2cab	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x68583ee3	rio_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x685a33cf	nd_blk_region_set_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x68a0782a	pcibios_alloc_controller
++EXPORT_SYMBOL_GPL vmlinux 0x68a6b2b2	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x68ac6a58	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x68b1ffb8	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x68d0b58f	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0x690cf733	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x69114d15	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x691abaf7	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x691bd6ef	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0x6921aa34	compat_put_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x692f2d16	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x69500344	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x69790ef6	__init_new_context
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x697cbbb4	threads_per_core
++EXPORT_SYMBOL_GPL vmlinux 0x697cdc3e	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0x69800f49	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x699b89c0	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0x69ae4fe8	rio_request_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x69b83e87	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x69bc6e44	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x69d1d113	mmc_regulator_set_vqmmc
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a6a3841	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x6a6bd3ad	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x6a6cafd2	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x6a72d61c	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a936feb	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x6a995e92	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x6aaec63e	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x6ac97ba5	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x6acb8d84	ppc64_caches
++EXPORT_SYMBOL_GPL vmlinux 0x6af59238	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x6afd0b9c	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0x6b1167e2	of_usb_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x6b17ed30	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b81c38b	power_supply_unreg_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6baa5b7d	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x6bb425f3	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x6bb4d222	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0x6bb94a69	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0x6bc4351d	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0x6bc766d7	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0x6bcb61cb	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0x6bd192e6	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x6bf633cd	gpiod_get_array
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c09a4e2	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c5ab859	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x6c5cd052	of_css
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6ca42a23	rio_get_asm
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ca927cd	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6cad2d0e	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0x6caef04f	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x6cc2fb2c	opal_message_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6cd21997	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x6cd6bb3b	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x6d1067f0	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x6d2e941d	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d74237c	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x6da35f0d	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x6db249d4	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0x6dc111a0	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6dcc899e	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x6dd0dacc	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0x6ddd1d50	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x6de496a3	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0x6dee7087	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e1ad3a9	__of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0x6e379526	kernstart_addr
++EXPORT_SYMBOL_GPL vmlinux 0x6e3f364d	of_device_uevent_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x6e48b56a	device_create
++EXPORT_SYMBOL_GPL vmlinux 0x6e584b94	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6e691633	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x6e6e1769	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6e97a336	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0x6eca4eaf	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0x6edb551c	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x6f079801	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f2c1fb2	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0x6f69511c	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x6f749064	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6fb6906c	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0x6fb7e04d	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x70066fae	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0x700e1648	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x70141c9c	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0x70348165	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0x70499f0b	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x7055c935	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x7066c8be	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x707f4c2e	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x70a71770	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x70a789a2	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x70b9e2da	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70d76b3e	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x711d4d80	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0x715815f5	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x7173dd26	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x71904d00	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0x71a45bc2	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0x71b1db89	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x71ce061d	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x71ce9a02	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71f86111	devm_phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x71f87c07	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x71fb949f	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x71ffeab5	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x72005808	cpu_add_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0x720732c1	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x7246a842	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x7253467c	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0x7267d1b5	gpiod_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x727675bf	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x729ea9ce	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0x72a4447a	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0x72b92943	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0x72daf158	ata_sas_port_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x72db35a6	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0x72e1e3c9	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x7301ea39	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x730d1fd8	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0x7324997a	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7334c698	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0x7353d89e	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x7354ec86	pcibios_map_io_space
++EXPORT_SYMBOL_GPL vmlinux 0x73718fa3	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x73785711	nvdimm_provider_data
++EXPORT_SYMBOL_GPL vmlinux 0x7387cbeb	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x73982a8a	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73b61fdf	of_irq_to_resource_table
++EXPORT_SYMBOL_GPL vmlinux 0x73c2554f	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0x73c832f2	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73e2ed1f	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x73fe3ef5	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x73ff39cc	of_regulator_match
++EXPORT_SYMBOL_GPL vmlinux 0x7403ab9f	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x74106d5d	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0x7413f871	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0x74330dd1	usb_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x743d2ad6	dax_zero_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x745dca7c	of_device_get_modalias
++EXPORT_SYMBOL_GPL vmlinux 0x745f7fa2	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7476afd9	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0x7485e9db	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x7497fa20	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x749e0d01	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x74b00ee5	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74d110a5	pcibios_free_controller_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x74fa6746	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x750daee0	mmc_get_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0x75133f6e	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x75329035	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0x757b49d2	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x7590712c	pcibios_scan_phb
++EXPORT_SYMBOL_GPL vmlinux 0x759139cb	of_pci_check_probe_only
++EXPORT_SYMBOL_GPL vmlinux 0x75b47702	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x75b72cf4	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0x75c9d8c3	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75f2a044	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x760495e2	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0x760c7240	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0x761ed6ec	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x762c0858	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0x763114ac	tps65217_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x7631bf05	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x7644fee1	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x76719ae1	of_thermal_is_trip_valid
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7696a3e6	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0x76a29ec9	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0x76a38403	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x76a9f7e0	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0x76bde371	get_hwpoison_page
++EXPORT_SYMBOL_GPL vmlinux 0x76e9e8dc	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x76ee3c01	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x770148ba	rio_route_add_entry
++EXPORT_SYMBOL_GPL vmlinux 0x771c8b79	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x7747c1dd	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x778bece7	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0x779527bb	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0x779630ad	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x77990e64	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x779bc2c6	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0x779fb4a6	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x77ae495d	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0x77dc4faa	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x77fce06f	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0x7800c9e2	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0x781fe685	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x78289964	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x783f777f	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x787c882b	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x787d37e3	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x7883ce15	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78cae98c	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x78cc5bec	hugetlb_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x78fcf550	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x7900e7ea	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x79120a13	of_mpc8xxx_spi_probe
++EXPORT_SYMBOL_GPL vmlinux 0x79140be6	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x79191638	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x791aae59	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x79548f1a	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x795b6af0	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x795b7168	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0x795e3625	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x799625b6	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x79bc1b31	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x79e05bdb	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0x7a096bea	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x7a183f3a	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x7a1d8ad7	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x7a2c2f14	mm_iommu_find
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a8e1570	regmap_get_raw_write_max
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7ac2242c	devfreq_event_reset_event
++EXPORT_SYMBOL_GPL vmlinux 0x7ae97cc2	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0x7b0ec8dc	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b25e60e	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7b2e193d	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7b4ec239	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x7b533a65	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x7b569fb0	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0x7b5c254a	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x7b70ed5c	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x7bb1ad40	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0x7be61fef	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0x7c004e17	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0x7c11d74b	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0x7c1722f6	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0x7c1a09a5	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0x7c296573	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0x7c37bc89	pseries_ioei_notifier_list
++EXPORT_SYMBOL_GPL vmlinux 0x7c67aa4b	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x7c7e31eb	devm_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x7ccedcfe	devm_of_phy_get_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x7cd0f7b0	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cedf677	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7d00c65b	nd_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x7d36ac14	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0x7d3fe47b	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x7d45257d	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0x7d46a95e	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d6b989e	dummy_con
++EXPORT_SYMBOL_GPL vmlinux 0x7d89a79b	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x7d8a01c0	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x7d92dc5f	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x7da54971	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7db3a30e	iommu_flush_tce
++EXPORT_SYMBOL_GPL vmlinux 0x7db66116	of_display_timings_exist
++EXPORT_SYMBOL_GPL vmlinux 0x7dc1e388	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7defddd7	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0x7e0100ca	ohci_hub_status_data
++EXPORT_SYMBOL_GPL vmlinux 0x7e17ba7b	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x7e31edd1	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7e36540d	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7e365e9a	phy_pm_runtime_get
++EXPORT_SYMBOL_GPL vmlinux 0x7e38f210	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7e3a5012	phy_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e7852d5	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x7e84758d	of_dma_xlate_by_chan_id
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7ea1a2bc	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x7eb7f498	ata_sas_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7eb959aa	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x7ebc7701	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x7edebeff	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0x7f008202	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7f0a25c7	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0x7f0a4f2c	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0x7f0b0676	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7f13d491	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f5f0621	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x7f7bc710	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7f89da9a	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x7f9146cb	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x7f99b39b	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0x7fb707df	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7fcd7279	__dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0x7fdb98ab	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0x7fef9fe4	of_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x8011cd92	eeh_add_device_tree_early
++EXPORT_SYMBOL_GPL vmlinux 0x802bd28d	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x802f6cdf	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x804ea02d	__find_linux_pte_or_hugepte
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x807670bd	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x8099a54a	nvdimm_bus_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0x80a6ad55	devm_of_phy_provider_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x80b0aff4	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x80b29719	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x80bbb54b	eeh_iommu_group_to_pe
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80dca1b9	of_cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x80fcd147	rio_release_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x8114b8d6	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x812ee383	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8152e111	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x8164b2d4	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0x8165b463	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x817193de	devm_phy_create
++EXPORT_SYMBOL_GPL vmlinux 0x81916ce2	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x81cd57ab	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x81d1a01f	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0x81e27503	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x81f9d74f	vfio_external_group_match_file
++EXPORT_SYMBOL_GPL vmlinux 0x823bf6b9	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x823caa28	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x82583f98	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0x82622acb	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x826f99a4	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x8278b155	usb_gen_phy_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x8288e414	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x82a58693	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x82b0a701	scom_controller
++EXPORT_SYMBOL_GPL vmlinux 0x82be0ed1	of_get_pci_domain_nr
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82e10fd5	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x82e51bf0	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x82f56068	of_resolve_phandles
++EXPORT_SYMBOL_GPL vmlinux 0x8310edf4	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0x831cb996	flush_fp_to_thread
++EXPORT_SYMBOL_GPL vmlinux 0x83233ed5	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x8361e2c1	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x836d61d0	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x838947cf	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x83950ea5	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x83ad4488	srp_release_transport
++EXPORT_SYMBOL_GPL vmlinux 0x83b9215c	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x83e794a2	gpiod_get_optional
++EXPORT_SYMBOL_GPL vmlinux 0x83ea36c7	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x83ebeddf	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x83f0a366	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x83f7653a	power_supply_property_is_writeable
++EXPORT_SYMBOL_GPL vmlinux 0x8429a7f0	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x84325b66	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x84368bed	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x844625b5	usb_get_maximum_speed
++EXPORT_SYMBOL_GPL vmlinux 0x8447d2c3	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x84480c2c	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0x8487a2b6	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x8492e06a	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x84b57a22	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x84bcc3c9	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0x84c2049a	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x84eba84a	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0x85001b14	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x85094233	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x85150c18	rio_lock_device
++EXPORT_SYMBOL_GPL vmlinux 0x851a77ed	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x856a3472	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0x857ef406	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x8586b3ce	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0x859347ce	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x859f06a5	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85d0422c	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0x85d98da7	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x85f0cfc7	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0x86165b28	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x86235254	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x8647c9c4	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0x864e5311	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0x8666a7c5	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x86929357	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x86a3c365	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0x86a9dc5e	of_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x86b6c518	devm_phy_put
++EXPORT_SYMBOL_GPL vmlinux 0x86beed84	regmap_field_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x86bf5de1	power_supply_get_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f3eeda	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8702e548	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x871093f5	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x877694fe	pcibios_find_pci_bus
++EXPORT_SYMBOL_GPL vmlinux 0x877976e6	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x87927108	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x87a8d5e8	dev_coredumpv
++EXPORT_SYMBOL_GPL vmlinux 0x87aa2b2f	realmode_pfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0x87b600b9	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x87c09fbc	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0x87e6ea3e	mpc8xxx_spi_tx_buf_u32
++EXPORT_SYMBOL_GPL vmlinux 0x88019775	rio_map_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0x8804af3d	usb_anchor_suspend_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x883c2740	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x8840738b	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0x8848c14a	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x88490752	gpiod_count
++EXPORT_SYMBOL_GPL vmlinux 0x885eed37	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0x88605a7c	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x886ca784	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x887a2468	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0x888c5be5	irq_bypass_register_consumer
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88b84bf0	regulator_get_hardware_vsel_register
++EXPORT_SYMBOL_GPL vmlinux 0x88c0370e	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x88c334cf	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x88f1d155	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8901efa9	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x8929c9f9	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x89628238	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x8968233b	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x8980bc61	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x898686de	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x89b57d1b	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0x89bae933	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89bed10e	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0x89d8f989	rio_dma_prep_slave_sg
++EXPORT_SYMBOL_GPL vmlinux 0x89de59b5	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8a28c400	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x8a554a36	mpc8xxx_spi_strmode
++EXPORT_SYMBOL_GPL vmlinux 0x8a56d915	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x8a6b2dde	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x8a7226db	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8a77a8e7	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8abe6974	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x8abe8a7f	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x8acc0186	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x8af6b506	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0x8b03c71a	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0x8b235ee0	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x8b2ceaf7	of_platform_depopulate
++EXPORT_SYMBOL_GPL vmlinux 0x8b3f1a63	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0x8b4166f9	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0x8b5bdb12	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0x8b62eb38	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8b649e33	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8b70e8ea	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x8b813f2d	irq_create_fwspec_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8b989f1c	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x8ba0b014	of_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x8ba75319	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0x8bd62519	gpiod_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x8bdc14ac	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c10d51b	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x8c114468	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0x8c1a7994	desc_to_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x8c52d33c	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0x8c5d9433	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x8c646600	edac_report_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c658bb3	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x8c743fb6	reset_control_status
++EXPORT_SYMBOL_GPL vmlinux 0x8c80d84a	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x8cae54b5	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8cdb2e07	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x8ce3a302	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x8ce4eb09	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x8cea078f	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x8cea765f	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d339165	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0x8d6fbdce	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x8dab4462	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0x8dacbd5a	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0x8dbf5a20	kvmppc_hv_entry_trampoline
++EXPORT_SYMBOL_GPL vmlinux 0x8dc94177	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x8df05322	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x8e2b25c2	videomode_from_timings
++EXPORT_SYMBOL_GPL vmlinux 0x8e2db255	irq_domain_alloc_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0x8e302c95	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x8e4627ad	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0x8e5e6563	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8e6fdb33	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x8e71a3c8	pci_iomap_wc_range
++EXPORT_SYMBOL_GPL vmlinux 0x8ea0ef97	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8ed7d062	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x8ee91a85	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x8ef1ef3f	regmap_update_bits_async
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f9875d9	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0x8fc346bc	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0x8fced602	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0x8fe5be22	vfio_spapr_pci_eeh_release
++EXPORT_SYMBOL_GPL vmlinux 0x8ff80af0	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x8fff5e8e	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x901be65c	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x9029ae2d	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x9077d5ea	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x907f06e2	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x909adea7	rio_mport_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90af38b2	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x90b298c1	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90c1e0f7	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL vmlinux 0x90ea888d	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0x90ef16ab	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x9143950a	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0x916a92e4	devm_extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x919732ce	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x91a307f0	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0x91ac1adf	cpufreq_freq_transition_begin
++EXPORT_SYMBOL_GPL vmlinux 0x91aecd5e	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91d8b77f	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x91e46490	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x91f0c992	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0x92098cdf	powercap_register_zone
++EXPORT_SYMBOL_GPL vmlinux 0x920cc389	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x9215ef40	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x924814b8	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x926dd890	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x92c1ed03	mbox_chan_txdone
++EXPORT_SYMBOL_GPL vmlinux 0x92ce4926	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x92ec8219	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x9320e843	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x932f8d9d	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x93311080	opal_flash_read
++EXPORT_SYMBOL_GPL vmlinux 0x933b5536	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x933df7ea	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0x93461f70	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x935acb2c	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x93602c37	gpiod_set_raw_value
++EXPORT_SYMBOL_GPL vmlinux 0x936c2003	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x936c8ce3	rio_register_scan
++EXPORT_SYMBOL_GPL vmlinux 0x936ca140	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x93734389	regmap_multi_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x9380e257	alarmtimer_get_rtcdev
++EXPORT_SYMBOL_GPL vmlinux 0x93deabd6	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0x93fa2cfd	put_hwpoison_page
++EXPORT_SYMBOL_GPL vmlinux 0x94158478	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x944e6b91	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0x947d4379	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0x94827fb9	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x949f7342	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x94c01037	default_iommu_map_sg
++EXPORT_SYMBOL_GPL vmlinux 0x94d972b7	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x9502cdea	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x950ec818	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x9517ebc8	eeh_dev_open
++EXPORT_SYMBOL_GPL vmlinux 0x951ab876	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x9529c705	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x954e4f92	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x955e0b53	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x95763048	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0x957a2940	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0x958129a9	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x95acfdaf	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95bdb5d0	fsl8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x95d48f55	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0x95daa3bd	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0x95ecb93b	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0x95f409a3	rio_mport_get_feature
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x9631037e	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x964cb37b	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0x965336fc	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9686b2ce	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x96a74593	regmap_parse_val
++EXPORT_SYMBOL_GPL vmlinux 0x96e892a8	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x96f3b828	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x96f6a263	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0x96fb4c4e	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x97256060	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x9735f061	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x973a678d	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x9745d68e	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x9749d5ad	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x9780c464	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0x97a01819	iommu_tce_clear_param_check
++EXPORT_SYMBOL_GPL vmlinux 0x97a96132	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x97adb983	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x97f5f85e	phy_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x980c3bc8	cpufreq_freq_transition_end
++EXPORT_SYMBOL_GPL vmlinux 0x981bbe48	of_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9824318b	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x982fdfba	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x983883b6	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x9840fd2f	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x98566b4b	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x98571ebb	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x985abe41	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x986808a3	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0x9876448a	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9894f145	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x98958fa7	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x989ed6d1	phy_pm_runtime_get_sync
++EXPORT_SYMBOL_GPL vmlinux 0x98a02a70	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x98e750ce	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x98f25d57	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0x98f9f73d	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x9909eec4	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0x990d9a94	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x99368d65	kvmppc_update_rmap_change
++EXPORT_SYMBOL_GPL vmlinux 0x99473852	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x995f2d0b	nvdimm_blk_region_create
++EXPORT_SYMBOL_GPL vmlinux 0x9973add9	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x9987e6e9	opal_get_sensor_data
++EXPORT_SYMBOL_GPL vmlinux 0x998d79d6	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0x9992d3c2	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x9995f355	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x99a9ff9a	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x99b47292	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0x99b91e4a	dma_get_slave_caps
++EXPORT_SYMBOL_GPL vmlinux 0x99ba4ecb	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99c267fd	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x99d491ac	gpiod_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x99dc1da2	devm_regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x99e2bff5	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x99f51152	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x99fa36e2	shake_page
++EXPORT_SYMBOL_GPL vmlinux 0x99ff8d08	opal_invalid_call
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a2964c4	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0x9a296d67	usb_phy_gen_create_phy
++EXPORT_SYMBOL_GPL vmlinux 0x9a42033c	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0x9a46be84	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9a49d937	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0x9a58a832	mbox_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x9a68fc8a	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x9a755e53	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0x9a7941ca	gpiochip_lock_as_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9a817d50	mbox_client_peek_data
++EXPORT_SYMBOL_GPL vmlinux 0x9a8772bf	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9aad6540	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9acda047	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0x9acfebb6	to_nvdimm
++EXPORT_SYMBOL_GPL vmlinux 0x9adf08c3	mmu_linear_psize
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9aec4b52	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x9b176064	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x9b2a8160	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x9b38d96a	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x9b43b922	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x9b64a317	__devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x9b682a2a	init_phb_dynamic
++EXPORT_SYMBOL_GPL vmlinux 0x9b6d89da	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x9b8044af	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0x9b85616d	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x9b8db024	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0x9b8e8b72	__regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x9b992724	component_del
++EXPORT_SYMBOL_GPL vmlinux 0x9ba2bb2b	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x9ba45622	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x9bc11102	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0x9bc18fa0	cpufreq_generic_attr
++EXPORT_SYMBOL_GPL vmlinux 0x9bc35a37	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0x9bca03ca	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c038cc6	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x9c2ebb33	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0x9c41a007	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x9c5a530e	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x9c90a234	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x9ca1f054	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x9ca9185d	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x9cb0df4b	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0x9cc28c0f	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cf4c179	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0x9d0f6b5f	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0x9d10610f	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x9d4f2760	restore_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x9d69bcdc	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0x9d6d4e3c	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0x9d716099	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x9d725b9d	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0x9dadbb88	cpufreq_boost_supported
++EXPORT_SYMBOL_GPL vmlinux 0x9db2d4b1	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0x9dd5b124	regmap_get_reg_stride
++EXPORT_SYMBOL_GPL vmlinux 0x9dde7a86	of_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x9de1c5da	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9de26391	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9e2f673c	of_get_nand_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0x9e460417	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e4b65f9	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x9e6b41a8	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x9e6bf642	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x9e8223d1	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0x9ea32969	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9ea83034	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0x9eaaadbd	kvmppc_add_revmap_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ee8284c	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x9ef5c639	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9efab9cc	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0x9f0a18da	cpu_remove_dev_attr_group
++EXPORT_SYMBOL_GPL vmlinux 0x9f11bdeb	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x9f150e09	devm_of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0x9f18fa11	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x9f24107e	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x9f3a7a3c	of_pci_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x9f63c10d	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x9f9dd27b	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0x9f9fc9a5	pcibios_add_pci_devices
++EXPORT_SYMBOL_GPL vmlinux 0x9fa40d1d	srp_attach_transport
++EXPORT_SYMBOL_GPL vmlinux 0x9fac7da8	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9ff93bea	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x9ffe5483	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0xa00d8a03	of_phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xa02b1274	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0xa054566c	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0xa0558cc1	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xa0625bbe	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0xa071e996	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0xa075683c	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0xa07d9959	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0xa095eecf	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xa096b55b	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0xa0987b54	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa0a27fff	pci_address_to_pio
++EXPORT_SYMBOL_GPL vmlinux 0xa0b139f0	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0xa0c63b75	rio_mport_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xa0d44fc5	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa0f1f088	__online_page_free
++EXPORT_SYMBOL_GPL vmlinux 0xa10a736c	rio_release_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xa1119fbd	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0xa1154705	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xa1245170	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xa12f7c9d	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0xa1475f50	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xa1498221	__tracepoint_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xa1738cdf	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xa17c6877	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0xa18e9821	cpufreq_cpu_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa1989673	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0xa1e34bd0	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa1ed9c8b	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xa1ef4cb1	rio_dma_prep_xfer
++EXPORT_SYMBOL_GPL vmlinux 0xa21eea69	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0xa2351763	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xa24fd44c	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xa260508e	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0xa26240ae	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa2718017	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa2994eba	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0xa2a1f77a	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xa2ac5519	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0xa2ac68dd	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2c0cf7c	usb_phy_generic_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa2e68273	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0xa2f3e44a	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xa2fb36fe	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xa2fe1ae7	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0xa34bb34b	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0xa35f8c2d	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0xa3745967	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0xa374e207	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xa384918b	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa393230c	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3a2d9af	walk_system_ram_range
++EXPORT_SYMBOL_GPL vmlinux 0xa3afb198	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3e16693	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa3e96282	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa3feec3f	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xa40abc36	of_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xa44c1459	ohci_hub_control
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa48fe9ec	tps65217_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa4a56a84	of_irq_get
++EXPORT_SYMBOL_GPL vmlinux 0xa4a98150	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0xa4afb44e	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0xa4c69326	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0xa4dac3f2	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0xa4e46c0e	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0xa4e739fe	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0xa4f83930	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0xa4ffbecd	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0xa51a65a8	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xa53a07b1	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xa552fee4	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0xa5709260	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0xa57520be	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0xa5830360	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xa58cd1de	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0xa59a2b86	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0xa5a62567	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0xa5afe69f	gpiod_get_direction
++EXPORT_SYMBOL_GPL vmlinux 0xa5b00659	ppc_proc_freq
++EXPORT_SYMBOL_GPL vmlinux 0xa5bf8e3d	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xa5d52d90	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0xa5d95a71	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5efe460	usb_anchor_resume_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xa5fd4d7e	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0xa60fbf6c	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0xa61e83c3	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa62db9e9	iommu_tce_xchg
++EXPORT_SYMBOL_GPL vmlinux 0xa62dede4	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa62f5c90	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xa6647139	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa69ee1ae	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6a9a26a	rio_set_port_lockout
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6b68079	rio_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xa6b7f556	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xa6bd0a3d	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa6eded6c	opal_xscom_read
++EXPORT_SYMBOL_GPL vmlinux 0xa6f5c55f	pwmchip_add_with_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xa7207dbf	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0xa721bc3f	opal_rtc_write
++EXPORT_SYMBOL_GPL vmlinux 0xa72debbb	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0xa7460cda	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xa767783b	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0xa769656c	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa7980477	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0xa7b8ed67	of_pci_range_parser_init
++EXPORT_SYMBOL_GPL vmlinux 0xa7b9134c	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0xa7c05aff	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa7cfe109	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xa7dfb142	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa8003a2f	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0xa8121926	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0xa819eac9	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0xa81fd8ab	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0xa826a528	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0xa8371cca	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0xa83b8bb6	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa86cc0d1	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xa86eed71	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0xa87fb087	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xa8845231	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0xa88e42fa	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xa8983038	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0xa8b0253d	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8fb8ebd	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0xa90136e2	devm_devfreq_event_add_edev
++EXPORT_SYMBOL_GPL vmlinux 0xa905df30	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0xa90fd26a	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0xa925bef2	of_platform_default_populate
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa94f202a	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0xa9643795	of_irq_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0xa96b2055	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0xa97a72a2	devfreq_event_set_event
++EXPORT_SYMBOL_GPL vmlinux 0xa97de0e8	of_irq_get_byname
++EXPORT_SYMBOL_GPL vmlinux 0xa98c4b71	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0xa993491e	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xa9aa1b00	opal_poll_events
++EXPORT_SYMBOL_GPL vmlinux 0xa9bea17a	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xa9c2df10	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0xa9ce341e	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0xa9d699db	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9e43c08	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xa9e54b65	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0xa9f4d558	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0xaa8acca1	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0xaa8b796c	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xaaa15b71	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xaaa87b72	copro_handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaaaf77a6	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xaab1e906	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0xaab2fd2a	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0xaab4de8f	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0xaaf1ba0f	gen_pool_get
++EXPORT_SYMBOL_GPL vmlinux 0xaaf4dd7b	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xab09533d	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0xab29ad96	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0xab34d235	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0xab489a37	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xab4cc155	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0xab567d31	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab73b832	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xab9859eb	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0xabbb3ac1	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabd3d40c	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0xac0624b4	vfio_spapr_iommu_eeh_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xac20c70a	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0xac2810f7	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0xac494c65	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0xac5cc33f	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xac63aea1	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0xac7d05b2	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xac9c31f3	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0xacbdf5b1	eeh_add_device_tree_late
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xacfb7f14	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xacfe997e	powerpc_firmware_features
++EXPORT_SYMBOL_GPL vmlinux 0xad017f95	led_init_core
++EXPORT_SYMBOL_GPL vmlinux 0xad141ed0	rio_request_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xad382d86	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xad4172cd	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0xad8d2717	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xade4e8d0	powercap_register_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xaded9da1	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xae14fe6c	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0xae1b839b	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xae36f4bd	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xae57ac4f	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0xae5e2f69	rio_request_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae6eaf93	hwpoison_filter_dev_minor
++EXPORT_SYMBOL_GPL vmlinux 0xae6f06d3	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xae6fb6be	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae81922b	of_overlay_destroy_all
++EXPORT_SYMBOL_GPL vmlinux 0xaea0a093	gpiod_is_active_low
++EXPORT_SYMBOL_GPL vmlinux 0xaeaaa687	serial8250_do_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xaec9921f	hash_page
++EXPORT_SYMBOL_GPL vmlinux 0xaeed520d	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xaefe2365	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0xaf195569	devm_phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xaf279112	opal_leds_set_ind
++EXPORT_SYMBOL_GPL vmlinux 0xaf439131	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0xaf6f62b9	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xaf7128b5	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0xaf8ad54c	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xaf8eb1b7	device_move
++EXPORT_SYMBOL_GPL vmlinux 0xaf9f530e	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xafb79b11	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xafbb9446	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xafbe6c9e	kvmppc_hwrng_present
++EXPORT_SYMBOL_GPL vmlinux 0xafc16b99	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xafc2abbf	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xafca735e	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0xafcc82a6	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xaffdf4b7	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0xb00b833e	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0xb0332e35	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb045c9da	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xb079cd01	devm_extcon_dev_allocate
++EXPORT_SYMBOL_GPL vmlinux 0xb0893004	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0xb0ab7e5e	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0b9085b	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0xb0b9f14d	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xb0c5e807	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb0d1656c	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0xb0e9c565	of_pci_msi_chip_add
++EXPORT_SYMBOL_GPL vmlinux 0xb0f945f7	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb0fba7df	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xb11e90ed	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0xb13b9b51	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb141492a	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb145faa6	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb18cfb03	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0xb1aafdf1	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1b370bd	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1c7b568	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0xb1d263db	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xb1d39543	rio_mport_chk_dev_access
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb20c5931	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb20fadd5	rio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb21ba793	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb22694d7	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0xb232d12c	dax_do_io
++EXPORT_SYMBOL_GPL vmlinux 0xb243f06c	srp_remove_host
++EXPORT_SYMBOL_GPL vmlinux 0xb267fa07	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb26a1add	elfcorehdr_addr
++EXPORT_SYMBOL_GPL vmlinux 0xb27e51ab	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0xb2922376	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0xb2a1e44d	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0xb2a446f1	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xb2b85e5d	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb3035b06	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0xb345d7c8	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb347bb2c	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0xb36a0482	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0xb36eb12e	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xb38a527d	dma_buf_export
++EXPORT_SYMBOL_GPL vmlinux 0xb3ace152	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0xb3b80558	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0xb3dc11fb	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xb40d592e	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0xb42cec8d	power_supply_set_property
++EXPORT_SYMBOL_GPL vmlinux 0xb42dfad3	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xb436eadf	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb43b5c7f	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0xb44a468d	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0xb45f2f48	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xb488588e	tb_to_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb4891679	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xb498e52e	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0xb49cdd34	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xb4a2734f	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb4fdfda9	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb52eb60b	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb55a340a	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xb56c3719	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xb5848bae	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb5855708	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb598392f	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5aa10af	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb5c700fe	agp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0xb5c8edf4	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0xb5d847b8	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb600d419	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0xb603d7ec	gpiochip_request_own_desc
++EXPORT_SYMBOL_GPL vmlinux 0xb60b5707	of_i8042_aux_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb62c3536	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0xb630784d	__rio_local_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xb643c250	xics_wake_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xb6458aa4	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xb668b3e4	regulator_set_load
++EXPORT_SYMBOL_GPL vmlinux 0xb66b065a	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0xb676e2c8	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0xb68af8aa	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xb69c702b	__regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6b293d2	hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xb6d57ece	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xb6e47dee	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xb6fd3acd	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0xb70a59f0	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0xb728a7f6	i2c_generic_scl_recovery
++EXPORT_SYMBOL_GPL vmlinux 0xb749f7bf	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb74a7e8b	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0xb7630744	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xb7a70eca	__rio_local_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xb7abd90d	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xb7ae13ca	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0xb7bdaf86	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xb7bf8ecc	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0xb7cdb501	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xb7d61add	__nvdimm_bus_register
++EXPORT_SYMBOL_GPL vmlinux 0xb7db7f20	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb7fd28c8	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0xb800bffe	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb815651f	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xb85793ab	pcibios_unmap_io_space
++EXPORT_SYMBOL_GPL vmlinux 0xb872cddf	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xb884b430	kvmppc_h_put_tce
++EXPORT_SYMBOL_GPL vmlinux 0xb889a2ef	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0xb88d12ea	nd_numa_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb892f611	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0xb8993ef3	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8d5f53b	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0xb8e609e5	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0xb8eda8a1	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xb8f6dc82	regulator_bulk_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xb8fe204e	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb91007c1	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0xb91acd4d	flush_vsx_to_thread
++EXPORT_SYMBOL_GPL vmlinux 0xb91fb8d2	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb93d5561	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xb93fafd5	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0xb945ace8	__tracepoint_remove_device_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xb99c36b1	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9dbd900	reservation_object_wait_timeout_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xb9dcf4be	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xba0f6e0f	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0xba158769	rtas_cancel_event_scan
++EXPORT_SYMBOL_GPL vmlinux 0xba16a238	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0xba2278a0	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0xba229765	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0xba26f370	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0xba2b7f64	cpufreq_generic_get
++EXPORT_SYMBOL_GPL vmlinux 0xba416a72	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0xba53db0a	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0xba645c98	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0xba7b6cf4	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0xba8bf6f5	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xba915b87	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xba92418b	rio_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xba9d7889	rio_mport_send_doorbell
++EXPORT_SYMBOL_GPL vmlinux 0xba9e498d	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xbab9a9f0	maxim_charger_currents
++EXPORT_SYMBOL_GPL vmlinux 0xbabd12f5	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xbac6115c	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xbad8199d	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0xbadcd89e	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0xbae76441	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0xbaf6d630	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb3e1415	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0xbb49917e	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xbb67d4f7	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0xbb6f025a	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0xbb8611a6	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0xbbaa5c0b	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0xbbaf2e7b	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0xbbb946a0	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0xbbdae490	gpiod_set_array_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0xbbf8722c	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0xbbfb0724	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0xbc12dbc4	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc1d1220	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0xbc1e996e	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xbc2905d3	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0xbc3f509f	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0xbc57450e	__rio_local_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbca6c5fb	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcc857b8	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcd5a2f2	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0xbcd5d2e1	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbce3d83c	of_alias_get_id
++EXPORT_SYMBOL_GPL vmlinux 0xbcf947b3	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xbd0d4a3f	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0xbd34fee0	mpc8xxx_spi_rx_buf_u16
++EXPORT_SYMBOL_GPL vmlinux 0xbd3bff6a	mpc8xxx_spi_tx_buf_u8
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd671048	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xbd991065	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xbd9c8750	of_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xbdb797f4	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xbdcf3c43	thermal_zone_of_sensor_register
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbde8dc00	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0xbe02d78c	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe212b9e	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0xbe24000f	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0xbe267c2a	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0xbe367a02	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0xbe471cdf	opal_rtc_read
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe8cd319	phy_put
++EXPORT_SYMBOL_GPL vmlinux 0xbe906ec1	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xbe933fa7	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0xbe96dfd8	of_reconfig_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbea55788	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbeb03ea5	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0xbebcd541	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xbec19370	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xbec8d1c8	analyse_instr
++EXPORT_SYMBOL_GPL vmlinux 0xbed3531e	irq_find_matching_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xbed9888e	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xbedac660	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf0f61de	of_get_dma_window
++EXPORT_SYMBOL_GPL vmlinux 0xbf1309a1	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0xbf1cc04b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xbf1f821b	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0xbf3074f9	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0xbf3667ba	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0xbf380606	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0xbf5a88d6	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xbf6852e5	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0xbfa32025	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xbfb95de7	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfc77054	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbfd68ca6	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xbfe07ed9	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xbffde8ec	compat_alloc_user_space
++EXPORT_SYMBOL_GPL vmlinux 0xc00f4113	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0xc0178e97	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc02320c6	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0xc02bec3c	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xc03db5cf	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0xc065a455	cpu_core_index_of_thread
++EXPORT_SYMBOL_GPL vmlinux 0xc082eb35	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc090a7fe	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0b072fc	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0xc0b6d12e	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0e013a8	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc0fb2468	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xc10aca1f	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc1303b47	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc180def7	vfio_add_group_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc1944bd5	devfreq_event_get_edev_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xc19cb4d4	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0xc1a2f38e	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xc1ac7b74	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xc1afe84a	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0xc1b68f93	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0xc1d989c5	vfio_external_check_extension
++EXPORT_SYMBOL_GPL vmlinux 0xc1def2c0	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0xc21a45bc	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0xc2268f45	devfreq_event_get_event
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc23c815e	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0xc243fbaa	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0xc2452a8a	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc25b6409	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc2868d55	of_property_read_u32_index
++EXPORT_SYMBOL_GPL vmlinux 0xc294c4c7	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0xc29ede30	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc2a5e30a	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0xc2b63e5e	of_console_check
++EXPORT_SYMBOL_GPL vmlinux 0xc2c25342	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc353635b	rio_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xc357923c	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xc36554a9	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc377b1dd	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0xc38f36d9	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc3916daa	of_pci_get_devfn
++EXPORT_SYMBOL_GPL vmlinux 0xc3a04506	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xc3c4dcc8	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0xc3c60b04	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0xc3cf8ef9	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0xc3d44252	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0xc3e87f64	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xc3fe2a46	regmap_update_bits_check_async
++EXPORT_SYMBOL_GPL vmlinux 0xc3fe5c0f	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xc4166a7a	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc431b12d	phy_pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0xc4418087	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0xc4497527	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0xc4539b6d	get_device
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc4674dbb	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc4913442	vfio_group_put_external_user
++EXPORT_SYMBOL_GPL vmlinux 0xc4a16a61	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xc4aa4c28	__rio_local_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xc4bc5ac8	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4d78142	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0xc4fe2160	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc51c70c2	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0xc52257d8	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0xc537488c	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0xc5375d2a	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc58a1687	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xc5989065	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0xc5a2c19f	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc5d0e6d3	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xc5db3d3d	cpufreq_generic_init
++EXPORT_SYMBOL_GPL vmlinux 0xc60191a6	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0xc606cd3c	boot_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0xc609301d	usb_hub_claim_port
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc61f86f0	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0xc623a88b	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xc627431a	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xc63cec89	of_phy_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc63e7d93	static_key_deferred_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc6581d57	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc667e312	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc66e615a	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0xc679741d	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xc6853ba8	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0xc68a013c	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0xc68aa252	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xc698ee82	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc6997bc4	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6acd099	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xc6adecc5	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0xc6c69a8f	opal_flash_write
++EXPORT_SYMBOL_GPL vmlinux 0xc6d2749b	gpiod_get
++EXPORT_SYMBOL_GPL vmlinux 0xc6da7a0a	__tracepoint_map
++EXPORT_SYMBOL_GPL vmlinux 0xc6f46e7f	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0xc6f5af22	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc6fa2ec3	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0xc71f4bc1	pcibios_remove_pci_devices
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc738b3ec	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xc73d5589	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xc7431027	kvm_release_hpt
++EXPORT_SYMBOL_GPL vmlinux 0xc79b3083	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7fad9b2	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0xc806f11c	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xc82260ea	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0xc835aa9b	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xc8362c09	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0xc83f79b2	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0xc855f2f5	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0xc85a2a74	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xc86c86a5	eeh_pe_get_state
++EXPORT_SYMBOL_GPL vmlinux 0xc8740e1d	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc8882666	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0xc89542e2	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc89f8a50	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8bd23d1	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xc8c55bc9	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc8df0eec	devfreq_event_enable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xc8e35ed5	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xc901ac5f	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc91b4102	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xc91c3b27	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0xc91cdf77	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc9224e9d	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0xc92913e8	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0xc9303468	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc9641b48	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0xc96a741e	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xc979a2e7	devm_mdiobus_free
++EXPORT_SYMBOL_GPL vmlinux 0xc97b5cca	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0xc97d1140	cpufreq_cooling_get_level
++EXPORT_SYMBOL_GPL vmlinux 0xc98f3497	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0xc9dabfa9	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0xc9e96684	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc9fe09c7	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xca081152	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0xca081385	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0xca1482b0	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xca1b966b	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0xca2f132c	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0xca4239c0	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca7e56af	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0xca7ee6d9	get_slice_psize
++EXPORT_SYMBOL_GPL vmlinux 0xca98e475	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0xcaadc59f	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcad213d3	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xcae9421f	mbox_send_message
++EXPORT_SYMBOL_GPL vmlinux 0xcb065b25	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb16e568	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0xcb241187	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb4df0f1	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xcb5ee621	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0xcb5f59ad	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0xcb81567d	__devm_of_phy_provider_register
++EXPORT_SYMBOL_GPL vmlinux 0xcb846d1a	nd_blk_region_to_dimm
++EXPORT_SYMBOL_GPL vmlinux 0xcb92adbc	rio_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcc0f1009	power_supply_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xcc2c5d41	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xcc3105ff	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0xcc38e4d2	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0xcc7b149a	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcca72ff4	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0xccb04918	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccda2c1d	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0xccec3885	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0xccf72bb7	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0xcd04ad1e	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xcd0843d9	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xcd0d0dd4	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0xcd49ba83	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xcd5ec59d	gpiod_put
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcdd5e8de	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xcde34ce3	add_memory_resource
++EXPORT_SYMBOL_GPL vmlinux 0xce151a36	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0xce264a61	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0xce394103	iommu_tce_put_param_check
++EXPORT_SYMBOL_GPL vmlinux 0xce615d7b	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xce637cae	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xcea17be1	devm_hwmon_device_register_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xcea85c42	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0xceb1f126	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0xceb8af85	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0xcec48dca	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0xcec4a0f8	regmap_fields_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xceebbde8	sdio_run_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcefaf646	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xcf02657a	power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0xcf1b00a0	usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0xcf25d020	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xcf411eb2	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0xcf47f745	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf572883	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xcf9244dd	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfceb362	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0xcff10462	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0xcffbfad0	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd00e7f6d	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xd01afd3f	opal_tpo_read
++EXPORT_SYMBOL_GPL vmlinux 0xd028ffd5	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xd0318a25	rio_mport_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd056d3a9	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd07f068a	kvmppc_invalidate_hpte
++EXPORT_SYMBOL_GPL vmlinux 0xd0890011	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0xd0b22ec0	vfio_spapr_pci_eeh_open
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0ec4936	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd1156678	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd11b002c	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xd14f9b40	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0xd157c11e	gpiod_get_value
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd185b34b	power_supply_get_property
++EXPORT_SYMBOL_GPL vmlinux 0xd19f2b48	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd1c33a61	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0xd1c89f33	device_register
++EXPORT_SYMBOL_GPL vmlinux 0xd1d802f7	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd1f52aef	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0xd1ff75df	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd2129d9a	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd2211f82	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xd235c4c5	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0xd25205ed	hugetlb_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd253b7fe	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd276e446	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xd27bb8f9	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0xd2817892	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xd2b43b98	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xd2d33df2	nd_cmd_out_size
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd2edf4b7	ata_get_cmd_descript
++EXPORT_SYMBOL_GPL vmlinux 0xd2f6d6d9	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0xd2fbecd9	gpiod_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0xd317f057	__online_page_set_limits
++EXPORT_SYMBOL_GPL vmlinux 0xd354b765	of_scan_bus
++EXPORT_SYMBOL_GPL vmlinux 0xd36222db	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0xd379e284	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0xd39ad6ab	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd3c23f65	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xd3c4a8a0	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0xd3ca8f42	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0xd3d15e2a	devm_led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd3d99ee2	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0xd3dea496	of_fdt_unflatten_tree
++EXPORT_SYMBOL_GPL vmlinux 0xd3e8a440	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xd3f87ff8	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd404a937	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd411aa0d	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd4368ca5	regulator_unregister_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xd437404b	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xd4487fd5	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd460d3d4	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xd482ed00	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0xd4877418	nvdimm_volatile_region_create
++EXPORT_SYMBOL_GPL vmlinux 0xd48fc809	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0xd49fb64b	pcibios_claim_one_bus
++EXPORT_SYMBOL_GPL vmlinux 0xd4bd66a0	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4df0a60	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0xd4f3fb74	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xd50a31a5	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd520d57c	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0xd536a1b5	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0xd5396ea4	regmap_fields_read
++EXPORT_SYMBOL_GPL vmlinux 0xd54968c5	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xd54fdad1	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0xd5596d48	opal_xscom_write
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd56b5f64	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0xd57cbe36	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0xd584171c	mbox_request_channel_byname
++EXPORT_SYMBOL_GPL vmlinux 0xd5937835	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0xd5961665	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5cb0412	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xd5cd4475	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xd60460d7	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd6282bae	__giveup_vsx
++EXPORT_SYMBOL_GPL vmlinux 0xd62df8bd	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0xd62f19df	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0xd647071a	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0xd66b93b0	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd6759acb	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0xd68fbfb1	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0xd697d33a	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0xd6a43677	opal_async_release_token
++EXPORT_SYMBOL_GPL vmlinux 0xd6ad12b4	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0xd6b74650	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xd6d9c42e	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0xd6dfdec1	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0xd6fd5330	gpio_to_desc
++EXPORT_SYMBOL_GPL vmlinux 0xd6feefa5	agp_num_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd7256d0a	devm_regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0xd74c1121	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0xd74dbd15	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0xd753732b	devfreq_event_remove_edev
++EXPORT_SYMBOL_GPL vmlinux 0xd757a2ef	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0xd76104b4	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0xd761cbcc	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd76c458b	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0xd771e51a	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0xd774b738	eeh_dev_check_failure
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd7a2749a	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd7b0ae2a	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xd7b484d4	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0xd7c895c2	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7e4449e	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0xd7fc3e98	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd80b80b0	phy_pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd8263870	mmu_slb_size
++EXPORT_SYMBOL_GPL vmlinux 0xd828a786	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0xd835a3e2	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0xd8434366	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0xd84673a2	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd87fc0a0	usb_amd_prefetch_quirk
++EXPORT_SYMBOL_GPL vmlinux 0xd895f987	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0xd8a6df7f	dma_get_any_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xd8c9572d	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd8cd0fdb	serial8250_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xd8dab988	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0xd8eedf88	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0xd8f6f54f	eeh_pe_reset
++EXPORT_SYMBOL_GPL vmlinux 0xd8fb8497	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xd92854fe	kvmppc_clear_ref_hpte
++EXPORT_SYMBOL_GPL vmlinux 0xd92988c9	devm_power_supply_register_no_ws
++EXPORT_SYMBOL_GPL vmlinux 0xd9336f5f	early_find_capability
++EXPORT_SYMBOL_GPL vmlinux 0xd933ddcd	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0xd93e8e0e	of_get_videomode
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94aa457	display_timings_release
++EXPORT_SYMBOL_GPL vmlinux 0xd94c60bd	devm_regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd96f2459	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xd97878a7	mm_iommu_preregistered
++EXPORT_SYMBOL_GPL vmlinux 0xd9901483	phy_get
++EXPORT_SYMBOL_GPL vmlinux 0xd9bdb66c	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xd9ca4f1a	rio_mport_get_efb
++EXPORT_SYMBOL_GPL vmlinux 0xd9d73ab0	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0xd9e34ee2	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0xd9e97124	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xda19f4a0	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0xda2503e5	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xda4f46ca	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xda5f5e64	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xda75095f	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0xda7cd6fa	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0xda90f185	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xdaba8b9b	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0xdae715e0	videomode_from_timing
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdaedd95f	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4d548	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdaf9af8e	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0xdb22aecc	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0xdb22d9ee	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0xdb3de02e	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0xdb44917a	irq_domain_free_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xdb6d8465	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb91e05c	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xdba40792	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0xdba99189	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xdbb0936a	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0xdbcd7d3c	devm_hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc04f0df	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0xdc36da90	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0xdc5ec5cf	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xdc5f0d9c	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc711979	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdcc39671	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xdd000ce3	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xdd003439	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xdd17d3b7	usb_alloc_dev
++EXPORT_SYMBOL_GPL vmlinux 0xdd17ffec	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd57e2b5	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0xdd5d780e	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0xdd682a5d	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0xdd6b1f3d	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0xdd729424	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0xdd9344a5	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0xdd98c3b5	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0xdd9fb0c4	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddcdb4dc	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xddfafd8c	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xddfc4280	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0xddfe7340	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xde2ccdc2	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0xde343dee	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xde3e6692	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0xde4862aa	devfreq_event_disable_edev
++EXPORT_SYMBOL_GPL vmlinux 0xde613885	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xde7fa4ad	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0xde90660d	__regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xde9e2403	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xdebda687	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0xdec8b79c	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xdedaade8	of_pci_get_host_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0xdee3b833	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdf0c3252	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf1a4d71	devm_regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xdf259201	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0xdf3bbe23	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0xdf4f5859	of_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0xdf5b87bb	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0xdf6f6892	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xdf784449	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0xdf7fd163	usb_asmedia_modifyflowcontrol
++EXPORT_SYMBOL_GPL vmlinux 0xdf9df5ec	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0xdfb85c07	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0xdfcbdfd0	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xdfd95d3a	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0xdfe186a7	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0xe001f454	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe01e9422	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0xe0272742	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe044c9f7	rio_local_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xe054c216	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xe05cd567	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0xe06ce16c	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe0732217	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0xe089cfcc	agp_memory_reserved
++EXPORT_SYMBOL_GPL vmlinux 0xe0a6b4c6	of_dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xe0b231e0	phy_init
++EXPORT_SYMBOL_GPL vmlinux 0xe0ec02aa	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0xe0ec8d8d	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe16768e0	irq_domain_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe1bd6c99	rio_init_mports
++EXPORT_SYMBOL_GPL vmlinux 0xe1c1f392	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe1d12e98	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0xe1d8124f	regulator_list_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xe1f55b3f	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe2089dfb	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0xe20a72b8	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xe23484ea	sata_lpm_ignore_phy_events
++EXPORT_SYMBOL_GPL vmlinux 0xe23b6342	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xe25a478d	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0xe28a1d1a	sdhci_pci_spt_drive_strength
++EXPORT_SYMBOL_GPL vmlinux 0xe295681d	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0xe2adae65	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0xe2b463e8	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe2d5ffba	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xe2e8423a	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe33f3bd1	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0xe3474dca	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0xe354f098	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xe37a47f0	phy_optional_get
++EXPORT_SYMBOL_GPL vmlinux 0xe3971da0	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe3d3f669	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0xe3d7750e	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xe3f728b0	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0xe40acda6	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xe40cc9bf	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe450b3b8	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe4b6fa3f	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0xe4bab9bc	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0xe4c031f8	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4c578b0	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0xe4d02f08	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0xe4f9d4ee	of_prop_next_string
++EXPORT_SYMBOL_GPL vmlinux 0xe4fa23c3	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0xe51c040f	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe531290c	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe54ccee9	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0xe5540302	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe5543a17	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0xe5571737	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0xe558e90b	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0xe56805e0	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58a47b5	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5944cbe	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0xe59a710d	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0xe5a976a3	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0xe5aa9fb6	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0xe5acb5cf	nvdimm_create
++EXPORT_SYMBOL_GPL vmlinux 0xe5baa938	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xe5d4c157	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0xe5e03e21	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe5e1b3b4	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0xe61d514e	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0xe6431597	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe6466d39	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe66357e5	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xe6bf220f	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6ca3085	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0xe6d84309	phy_power_on
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe6efc9d6	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xe70f762b	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe72239a8	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xe744dce5	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0xe749b0ad	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe7574c6a	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0xe762df98	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0xe768d444	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe7786bb5	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe784fc7a	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0xe79782e6	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xe79b8460	cpufreq_frequency_table_get_index
++EXPORT_SYMBOL_GPL vmlinux 0xe7b8ae40	regulator_map_voltage_linear_range
++EXPORT_SYMBOL_GPL vmlinux 0xe7bf79fe	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0xe7f18b3c	threads_per_subcore
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe8323b12	dma_request_slave_channel_reason
++EXPORT_SYMBOL_GPL vmlinux 0xe840160f	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe85b36fa	scom_find_parent
++EXPORT_SYMBOL_GPL vmlinux 0xe85c55e7	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe884e482	nd_device_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xe89bd243	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xe8b1acae	gpiod_set_value
++EXPORT_SYMBOL_GPL vmlinux 0xe8b4b4c8	rio_mport_class
++EXPORT_SYMBOL_GPL vmlinux 0xe8d3a2de	iommu_take_ownership
++EXPORT_SYMBOL_GPL vmlinux 0xe8db3634	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xe8e4bd88	usb_phy_set_event
++EXPORT_SYMBOL_GPL vmlinux 0xe8f46963	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0xe9180817	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0xe93aa826	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe9506579	iommu_tce_direction
++EXPORT_SYMBOL_GPL vmlinux 0xe97c7336	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0xe9a2cadd	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0xe9aacf74	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0xe9af6da0	usb_phy_generic_register
++EXPORT_SYMBOL_GPL vmlinux 0xe9b990cb	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0xe9c8fed4	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xe9ca52ee	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xe9dcb02e	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0xe9dee4b1	powercap_unregister_control_type
++EXPORT_SYMBOL_GPL vmlinux 0xe9f0345e	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0xe9f36cfa	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0xe9fb7889	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea270a20	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xea2a54d4	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0xea2b21c3	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea4429e2	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xea4831c7	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0xea54c3a8	kvmppc_do_h_enter
++EXPORT_SYMBOL_GPL vmlinux 0xea5f995e	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0xea628c20	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0xea74612b	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xea81dd14	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xeaae7ec7	nd_mapping_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xeab85345	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0xeaff6623	of_get_display_timing
++EXPORT_SYMBOL_GPL vmlinux 0xeb28800a	pstore_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xeb3f7275	devfreq_event_get_edev_count
++EXPORT_SYMBOL_GPL vmlinux 0xeb7176f1	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0xeb7d183e	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0xeb8717d3	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0xeb8ae736	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0xeb8b6e2d	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0xebc14a6c	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0xebdda5dd	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0xebdf1ae5	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xebf0fd0f	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0xebf672fb	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xec0c0932	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec2e574f	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xec631f34	remove_memory
++EXPORT_SYMBOL_GPL vmlinux 0xec87582f	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0xeca02f76	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xecb31c46	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0xecd9b8ea	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0xece74b82	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0xecea7dc2	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xed1537e8	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xed23f1d4	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xed3be118	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0xed52720b	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0xed981a16	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xedacecc4	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xedb37bc1	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0xedbd690f	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0xedc8fd7b	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0xee028b6d	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xee23cbc9	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xee2e73e9	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xee34f80a	of_thermal_get_trip_points
++EXPORT_SYMBOL_GPL vmlinux 0xee37c598	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xee4b0227	dma_get_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xee4f4096	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xee5f48ff	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0xee6447b6	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xee671810	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee763832	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0xee885fd3	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL vmlinux 0xee8ddd94	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0xee972884	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0xee9d379a	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0xeec3ad36	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0xeee1ea07	xhci_gen_setup
++EXPORT_SYMBOL_GPL vmlinux 0xeee22cb8	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xef1db8d4	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0xef4ab17e	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0xef4ee144	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6d007a	sigset_from_compat
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xef9fe7d7	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefc5ea3c	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xefc7bd85	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0xefdd90bc	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0xeff390e8	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xeffad603	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0xf009ffb1	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf05e68c4	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0xf0725c55	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf0805437	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xf092c2ae	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0xf0b6646b	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0cfcf70	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0xf0e07149	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0xf0e80456	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xf0f306b9	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xf0f4adbc	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf11458df	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf11c8e1e	phy_create
++EXPORT_SYMBOL_GPL vmlinux 0xf12146b5	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0xf1219481	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xf12a3c71	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0xf1487ce3	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0xf14e4d24	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xf158f170	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0xf15fae31	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf19b9d63	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0xf1a62b6f	of_i8042_kbd_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf1b0f799	mbox_client_txdone
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1c7df85	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0xf1ee160a	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0xf1fde4dd	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf219dacf	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf23779ca	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0xf2379d3e	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf24649ad	isa_bridge_pcidev
++EXPORT_SYMBOL_GPL vmlinux 0xf264a6e9	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0xf26640c1	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0xf2679f76	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0xf27458ac	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0xf276a063	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf2a8db82	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2ad02c4	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xf2d30dbd	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf2f762fc	__remove_pages
++EXPORT_SYMBOL_GPL vmlinux 0xf2f94ac0	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf30a5502	cpufreq_enable_boost_support
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf3153ca2	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf33dc43c	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xf35ad96f	cpufreq_generic_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0xf37301b8	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf38185cb	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0xf381ca7f	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xf3927a90	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3d5defc	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0xf3d60730	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf3f51b59	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0xf3fa9bd2	rio_unmap_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xf40a2ad2	nd_region_attribute_group
++EXPORT_SYMBOL_GPL vmlinux 0xf41cc7a7	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf42796e1	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0xf4350dbf	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0xf452d967	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0xf453c80c	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xf479adf6	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf4974d3f	iommu_get_domain_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf49c9217	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xf4ae5171	regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf4fea51f	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xf509de58	rio_register_mport
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf5201410	inet_csk_compat_setsockopt
++EXPORT_SYMBOL_GPL vmlinux 0xf5254541	vfio_group_get_external_user
++EXPORT_SYMBOL_GPL vmlinux 0xf535ebfc	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xf5379771	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xf53a24ae	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf5843156	of_property_read_u64
++EXPORT_SYMBOL_GPL vmlinux 0xf5844505	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0xf58a8bbe	__add_pages
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5c766d0	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0xf5d14f89	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf5d9f3d4	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0xf5e1797b	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0xf606bf30	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xf652eee8	power_supply_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xf676f911	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xf684ced3	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0xf685b43a	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf6ba2c46	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf6d8c5f4	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xf6e5e83f	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0xf6e772c3	irq_bypass_unregister_producer
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf6f1e703	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0xf70b8d9e	of_get_nand_ecc_strength
++EXPORT_SYMBOL_GPL vmlinux 0xf745dab8	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xf74a4e56	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xf755b7b1	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf75e6168	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0xf78961a1	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xf78b3a47	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf7930070	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0xf796b6da	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0xf7a2de26	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xf7aa46f5	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xf7c36831	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0xf7eae216	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xf7f14f28	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf83694a5	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0xf837e0eb	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf83d6478	led_sysfs_disable
++EXPORT_SYMBOL_GPL vmlinux 0xf8542412	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf890cc67	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0xf8a1f3fd	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xf8a20e5f	reservation_object_test_signaled_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf8afdb5f	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xf8cc74de	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0xf8cd5e6d	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xf8e398fc	memstart_addr
++EXPORT_SYMBOL_GPL vmlinux 0xf8e9e977	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf9230407	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf93a106c	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf93fb063	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xf9455eb9	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0xf94d15d4	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0xf94e29a0	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf99d8f4f	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9aa270f	eeh_add_sysfs_files
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9de73f6	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0xf9e5ba41	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0xf9f04dac	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xf9f5d2f3	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0xfa041540	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xfa119c4f	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa38dfb2	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0xfa79e632	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0xfa85d18a	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xfa901b31	compat_get_timespec
++EXPORT_SYMBOL_GPL vmlinux 0xfa964d9c	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xfa9c1695	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xfab60503	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0xfab78911	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0xfab7bb91	devm_spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xfad5da60	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xfadc0934	sysfs_remove_device_from_node
++EXPORT_SYMBOL_GPL vmlinux 0xfaec7156	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xfb0047f6	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb44a7a1	opal_ipmi_recv
++EXPORT_SYMBOL_GPL vmlinux 0xfb46439a	of_dma_router_register
++EXPORT_SYMBOL_GPL vmlinux 0xfb52b77d	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb720c47	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xfb7a0233	of_pci_msi_chip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xfb7ff0b7	nvdimm_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb98d1a4	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfbd3a24d	opal_message_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xfbd52abc	devm_power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xfbf3185a	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc077dad	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0xfc201b66	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0xfc3dc4b2	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0xfc4035d4	__rio_local_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xfc6f3332	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xfc703cd6	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xfc9837dc	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xfc9ea2dd	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xfcaa1d38	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xfcb7ccc4	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xfcc5ce94	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xfccef22c	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0xfcf95fbe	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0xfcffbf50	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0xfd33f706	xhci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xfd4b3353	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xfd4d3499	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd801ce5	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0xfda4670e	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0xfda7dcaa	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0xfdb6214d	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xfdc01fd8	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0xfdd85b69	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0xfddd285f	mm_iommu_ua_to_hpa
++EXPORT_SYMBOL_GPL vmlinux 0xfdeab59b	mbox_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xfe1a8a6f	iommu_release_ownership
++EXPORT_SYMBOL_GPL vmlinux 0xfe1e89cc	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0xfe1fa72c	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0xfe2c5482	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0xfe37533f	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0xfe56323d	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0xfe89e7ca	__online_page_increment_counters
++EXPORT_SYMBOL_GPL vmlinux 0xfe8df42a	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfea9cae1	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xfece2a63	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfed24d68	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfeddffdb	devm_regulator_register_supply_alias
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff1134ba	of_thermal_get_ntrips
++EXPORT_SYMBOL_GPL vmlinux 0xff145390	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0xff27d5b3	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xff3190a8	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0xff343569	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xff3d206d	rio_route_get_entry
++EXPORT_SYMBOL_GPL vmlinux 0xff3fe9ee	xhci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xff67ff5f	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0xffa7c938	mbox_free_channel
++EXPORT_SYMBOL_GPL vmlinux 0xffb35dd2	gpiod_set_raw_array_value
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffcff460	eeh_pe_set_option
++EXPORT_SYMBOL_GPL vmlinux 0xffd59fab	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0xffdb76ae	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xffe37f35	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xfff1242b	sock_gen_put
+diff --git a/debian.master/abi/4.4.0-111.134/ppc64el/generic.compiler b/debian.master/abi/4.4.0-111.134/ppc64el/generic.compiler
+new file mode 100644
+index 0000000..a59475f
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/ppc64el/generic.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu/IBM 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/ppc64el/generic.modules b/debian.master/abi/4.4.0-111.134/ppc64el/generic.modules
+new file mode 100644
+index 0000000..1772d5c
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/ppc64el/generic.modules
+@@ -0,0 +1,4256 @@
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_dw
++8250_mid
++8255
++8255_pci
++8390
++842
++842_compress
++842_decompress
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm8607
++88pm860x-ts
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++DAC960
++a100u2w
++a3d
++a8293
++aacraid
++aat2870-regulator
++aat2870_bl
++ab3100
++ab3100-otp
++ac97_bus
++acard-ahci
++acecad
++acenic
++act200l-sir
++act8865-regulator
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++actisys-sir
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5592r
++ad5592r-base
++ad5593r
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad_sigma_delta
++adc128d818
++adcxx
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520-keys
++adp5520_bl
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7511
++adv7604
++adv7842
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++advansys
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++af-rxrpc
++af9013
++af9033
++af_alg
++af_key
++af_packet_diag
++affs
++ah4
++ah6
++ahci
++ahci_ceva
++ahci_platform
++ahci_qoriq
++aic79xx
++aic7xxx
++aic94xx
++aim_cdev
++aim_network
++aim_sound
++aim_v4l2
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airo
++airspy
++ak8975
++al3320a
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++ali-ircc
++alim7101_wdt
++altera-ci
++altera-stapl
++altera_jtaguart
++altera_ps2
++altera_tse
++altera_uart
++alx
++am53c974
++amc6821
++amd
++amd5536udc
++amd8111e
++amdgpu
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc236_common
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci236
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apbps2
++apds9300
++apds9802als
++apds990x
++apds9960
++appledisplay
++appletalk
++appletouch
++applicom
++aquantia
++ar1021_i2c
++ar5523
++ar7part
++arc-rawmode
++arc-rimi
++arc4
++arc_emac
++arc_ps2
++arc_uart
++arcmsr
++arcnet
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arp_tables
++arpt_mangle
++arptable_filter
++as102_fe
++as3711-regulator
++as3711_bl
++as3722-regulator
++as3935
++as5011
++asc7621
++ascot2e
++asix
++ast
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at803x
++at86rf230
++ata_generic
++ata_piix
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atm
++atmel
++atmel-flexcom
++atmel-hlcdc
++atmel_mxt_ts
++atmel_pci
++atmtcp
++atp870u
++atusb
++atxp1
++aty128fb
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo-pixcir-ts
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auth_rpcgss
++authenc
++authencesn
++autofs4
++avmfritz
++ax25
++ax88179_178a
++axp20x-pek
++axp20x-regulator
++axp20x_usb_power
++axp288_adc
++axp288_charger
++axp288_fuel_gauge
++b1
++b1dma
++b1pci
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm-phy-lib
++bcm203x
++bcm3510
++bcm590xx
++bcm590xx-regulator
++bcm5974
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++bcma
++bcma-hcd
++bcmsysport
++bd6107
++bdc
++bdc_pci
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1750
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluetooth
++bluetooth_6lowpan
++bma150
++bma180
++bmc150-accel-core
++bmc150-accel-i2c
++bmc150-accel-spi
++bmc150_magn
++bmg160_core
++bmg160_i2c
++bmg160_spi
++bmp085
++bmp085-i2c
++bmp085-spi
++bmp280
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bnxt_en
++bnxt_en_bpo
++bonding
++bpa10x
++bpck
++bpqether
++bq2415x_charger
++bq24190_charger
++bq24257_charger
++bq24735-charger
++bq25890_charger
++bq27xxx_battery
++br2684
++br_netfilter
++brcmfmac
++brcmsmac
++brcmutil
++brd
++bridge
++broadcom
++broadsheetfb
++bsd_comp
++bsr
++bt878
++btbcm
++btcoexist
++btintel
++btmrvl
++btmrvl_sdio
++btqca
++btrfs
++btrtl
++btsdio
++bttv
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++c4
++c67x00
++c6xdigio
++c_can
++c_can_pci
++c_can_platform
++cachefiles
++cadence_wdt
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++cap11xx
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc2520
++cc770
++cc770_isa
++cc770_platform
++cciss
++ccm
++cdc-acm
++cdc-phonet
++cdc-wdm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc_subset
++ceph
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++ch9200
++chacha20_generic
++chacha20poly1305
++chaoskey
++chipone_icn8318
++chipreg
++chnl_net
++ci_hdrc
++ci_hdrc_imx
++ci_hdrc_msm
++ci_hdrc_pci
++ci_hdrc_usb2
++ci_hdrc_zevio
++cicada
++cifs
++cirrus
++cirrusfb
++clip
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm32181
++cm3232
++cm3323
++cm36651
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmm
++cmtp
++cnic
++cobalt
++cobra
++coda
++colibri-vf50-ts
++com20020
++com20020-pci
++com90io
++com90xx
++comedi
++comedi_8254
++comedi_8255
++comedi_bond
++comedi_isadma
++comedi_parport
++comedi_pci
++comedi_test
++comedi_usb
++comm
++configfs
++contec_pci_dio
++cordic
++core
++cp210x
++cpc925_edac
++cpia2
++cpsw_ale
++cpu-notifier-error-inject
++cramfs
++crc-ccitt
++crc-itu-t
++crc32
++crc7
++crc8
++cryptd
++crypto_user
++cryptoloop
++cs5345
++cs53l32a
++csiostor
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24117
++cx24120
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx8800
++cx8802
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxd2841er
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cxl
++cxlflash
++cy8ctmg110_ts
++cyapatp
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052-hwmon
++da9052-regulator
++da9052_bl
++da9052_onkey
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055-regulator
++da9055_onkey
++da9055_wdt
++da9062-core
++da9062-regulator
++da9062_wdt
++da9063-regulator
++da9063_onkey
++da9063_wdt
++da9150-charger
++da9150-core
++da9150-fg
++da9150-gpadc
++da9210-regulator
++da9211-regulator
++dac02
++daqboard2000
++das08
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++davicom
++db9
++dc395x
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++ddbridge
++de2104x
++de4x5
++decnet
++deflate
++defxx
++denali
++denali_pci
++des_generic
++dgap
++dgnc
++dht11
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++digicolor-usart
++diskonchip
++diva_idi
++diva_mnt
++divacapi
++divadidd
++divas
++dl2k
++dlci
++dlm
++dln2
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dm1105
++dm9601
++dmfe
++dmm32at
++dmx3191d
++dn_rtmsg
++dnet
++docg3
++docg4
++dp83848
++dp83867
++drbd
++drbg
++drm
++drm_kms_helper
++drop_monitor
++drv260x
++drv2665
++drv2667
++drx39xyj
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155
++dt9812
++dummy
++dummy-irq
++dummy_stm
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dvbsky
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb-usb-vp702x
++dvb-usb-vp7045
++dvb_usb_v2
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_wdt
++dwc3
++dwc3-pci
++dwc_eth_qos
++dwmac-generic
++dwmac-ipq806x
++dwmac-lpc18xx
++dwmac-meson
++dwmac-rk
++dwmac-socfpga
++dwmac-sti
++dwmac-sunxi
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e3x0-button
++e4000
++earth-pt1
++earth-pt3
++eata
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ec100
++echainiv
++echo
++edac_core
++edt-ft5x06
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efs
++egalax_ts
++ehci-platform
++ehset
++elan_i2c
++elo
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++em28xx-v4l
++em_canid
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++emac_arc
++emac_rockchip
++emc1403
++emc2103
++emc6w201
++emi26
++emi62
++empeg
++ems_pci
++ems_usb
++emu10k1-gp
++enc28j60
++enclosure
++encx24j600
++encx24j600-regmap
++eni
++enic
++epat
++epia
++epic100
++eql
++esas2r
++esd_usb2
++esi-sir
++esp4
++esp6
++esp_scsi
++et1011c
++et131x
++ethoc
++evbug
++exofs
++extcon-adc-jack
++extcon-arizona
++extcon-axp288
++extcon-gpio
++extcon-max14577
++extcon-max77693
++extcon-max77843
++extcon-max8997
++extcon-palmas
++extcon-rt8973a
++extcon-sm5502
++extcon-usb-gpio
++ezusb
++f2fs
++f75375s
++f81232
++fakelb
++fan53555
++farsync
++faulty
++fb_agm1264k-fl
++fb_bd663474
++fb_ddc
++fb_hx8340bn
++fb_hx8347d
++fb_hx8353d
++fb_hx8357d
++fb_ili9163
++fb_ili9320
++fb_ili9325
++fb_ili9340
++fb_ili9341
++fb_ili9481
++fb_ili9486
++fb_pcd8544
++fb_ra8875
++fb_s6d02a1
++fb_s6d1121
++fb_ssd1289
++fb_ssd1306
++fb_ssd1331
++fb_ssd1351
++fb_st7735r
++fb_st7789v
++fb_sys_fops
++fb_tinylcd
++fb_tls8204
++fb_uc1611
++fb_uc1701
++fb_upd161704
++fb_watterott
++fbtft
++fbtft_device
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdp
++fdp_i2c
++fealnx
++ff-memless
++firedtv
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fixed
++fl512
++flexcan
++flexfb
++floppy
++fm10k
++fm801-gp
++fm_drv
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++forcedeth
++fore_200e
++fotg210-hcd
++fotg210-udc
++fou
++fpga-mgr
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fsl-edma
++fsl_elbc_nand
++fsl_lpuart
++ft6236
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu_ts
++g450_pll
++g760a
++g762
++g_acm_ms
++g_audio
++g_cdc
++g_dbgp
++g_ether
++g_ffs
++g_hid
++g_mass_storage
++g_midi
++g_ncm
++g_nokia
++g_printer
++g_serial
++g_webcam
++g_zero
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++gcm
++gdmtty
++gdmulte
++gdmwm
++gdth
++gen_probe
++generic
++generic-adc-battery
++generic_bl
++genet
++geneve
++gennvm
++genwqe_card
++gf128mul
++gf2k
++gfs2
++ghash-generic
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goodix
++gp2ap002a00f
++gp2ap020a00f
++gpio
++gpio-74x164
++gpio-74xx-mmio
++gpio-addr-flash
++gpio-adnp
++gpio-adp5520
++gpio-adp5588
++gpio-altera
++gpio-amd8111
++gpio-arizona
++gpio-beeper
++gpio-charger
++gpio-crystalcove
++gpio-da9052
++gpio-da9055
++gpio-dln2
++gpio-dwapb
++gpio-fan
++gpio-generic
++gpio-grgpio
++gpio-ir-recv
++gpio-janz-ttl
++gpio-kempld
++gpio-lp3943
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio-pca953x
++gpio-pcf857x
++gpio-rdc321x
++gpio-regulator
++gpio-syscon
++gpio-tps65912
++gpio-twl4030
++gpio-twl6040
++gpio-ucb1400
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++gpio_backlight
++gpio_keys
++gpio_keys_polled
++gpio_mouse
++gpio_tilt_polled
++gpio_wdt
++gr_udc
++grace
++grcan
++gre
++grip
++grip_mp
++gs_fpga
++gs_usb
++gsc_hpdi
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_dtcs033
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stk1135
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_touptek
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++hackrf
++hamachi
++hampshire
++hangcheck-timer
++hanwang
++hci
++hci_uart
++hci_vhci
++hdc100x
++hdlc
++hdlc_cisco
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdlcdrv
++hdm_dim2
++hdm_i2c
++hdm_usb
++hdpvr
++he
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfc_usb
++hfcmulti
++hfcpci
++hfcsusb
++hfs
++hfsplus
++hi6421-pmic-core
++hi6421-regulator
++hi8435
++hid
++hid-a4tech
++hid-alps
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-betopff
++hid-cherry
++hid-chicony
++hid-corsair
++hid-cp2112
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-gembird
++hid-generic
++hid-gfrm
++hid-gt683r
++hid-gyration
++hid-holtek-kbd
++hid-holtek-mouse
++hid-holtekff
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo
++hid-logitech
++hid-logitech-dj
++hid-logitech-hidpp
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hid-penmount
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-plantronics
++hid-primax
++hid-prodikeys
++hid-rmi
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-ryos
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-custom
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-incl-3d
++hid-sensor-magn-3d
++hid-sensor-press
++hid-sensor-prox
++hid-sensor-rotation
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-waltop
++hid-wiimote
++hid-xinmo
++hid-zpff
++hid-zydacron
++hidp
++hih6130
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hisi504_nand
++hmc5843_core
++hmc5843_i2c
++hmc5843_spi
++hmc6352
++hopper
++horus3a
++hostap
++hostap_pci
++hostap_plx
++hp100
++hpfs
++hpilo
++hpsa
++hptiop
++hsi
++hsi_char
++hso
++hsr
++hsu_dma
++htc-pasic3
++hts221
++hts221_i2c
++hts221_spi
++htu21
++huawei_cdc_ncm
++hvcs
++hvcserver
++hwa-hc
++hwa-rc
++hwmon-vid
++hwpoison-inject
++hx8357
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd8111
++i2c-arb-gpio-challenge
++i2c-cbus-gpio
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-diolan-u2c
++i2c-dln2
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-kempld
++i2c-matroxfb
++i2c-mpc
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-reg
++i2c-nforce2
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-piix4
++i2c-robotfuzz-osif
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i40e
++i40evf
++i5k_amb
++i6300esb
++i740fb
++ib_addr
++ib_cm
++ib_core
++ib_ehca
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_qib
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ibmaem
++ibmpex
++ibmpowernv
++ibmveth
++ibmvfc
++ibmvnic
++ibmvscsi
++ibmvscsis
++icom
++icp_multi
++icplus
++ics932s401
++ideapad_slidebar
++idma64
++idmouse
++idt77252
++idt_gen2
++idtcps
++ieee802154
++ieee802154_6lowpan
++ieee802154_socket
++ifb
++iforce
++igb
++igbvf
++igorplugusb
++iguanair
++ii_pci20kc
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++iio_dummy
++iio_hwmon
++ila
++ili210x
++ili922x
++ili9320
++imm
++imon
++ims-pcu
++imx074
++imx6ul_tsc
++imx_thermal
++ina209
++ina2xx
++industrialio
++industrialio-buffer-cb
++industrialio-triggered-buffer
++industrialio-triggered-event
++inet_diag
++inexio
++inftl
++initio
++input-leds
++input-polldev
++int51x1
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++intel_vr_nor
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++ioc4
++iowarrior
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_powernv
++ipmi_poweroff
++ipmi_si
++ipmi_ssif
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++ipw
++ipw2100
++ipw2200
++ipx
++ir-hix5hd2
++ir-jvc-decoder
++ir-kbd-i2c
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++ir-rc5-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sharp-decoder
++ir-sony-decoder
++ir-usb
++ir-xmp-decoder
++ircomm
++ircomm-tty
++irda
++irda-usb
++irlan
++irnet
++irtty-sir
++iscsi_boot_sysfs
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl29125
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isl9305
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it913x
++itd1000
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iw_nes
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jitterentropy_rng
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsa1212
++jsm
++kafs
++kalmia
++kaweth
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keyspan
++keyspan_pda
++keyspan_remote
++keywrap
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kmx61
++kobil_sct
++ks0108
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kvm
++kvm-hv
++kvm-pr
++kxcjk-1013
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l4f00242t03
++l64781
++lan78xx
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++led-class-flash
++leds-88pm860x
++leds-adp5520
++leds-bcm6328
++leds-bcm6358
++leds-bd2802
++leds-blinkm
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-ktd2692
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8501
++leds-lp8788
++leds-lp8860
++leds-lt3593
++leds-max77693
++leds-max8997
++leds-mc13783
++leds-menf21bmc
++leds-pca9532
++leds-pca955x
++leds-pca963x
++leds-powernv
++leds-pwm
++leds-regulator
++leds-tca6507
++leds-tlc591xx
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg-vl600
++lg2160
++lgdt3305
++lgdt3306a
++lgdt330x
++lgs8gxx
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libahci_platform
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++lineage-pem
++linear
++liquidio
++lirc_bt829
++lirc_dev
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++lis3lv02d_spi
++litelink-sir
++lkkbd
++ll_temac
++llc
++llc2
++lm25066
++lm3533-als
++lm3533-core
++lm3533-ctrlbank
++lm3533_bl
++lm3630a_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lms283gf05
++lms501kf03
++lnbh25
++lnbp21
++lnbp22
++lockd
++locktorture
++lp
++lp3943
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp872x
++lp8755
++lp8788-buck
++lp8788-charger
++lp8788-ldo
++lp8788_adc
++lp8788_bl
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2941-battery-gauge
++ltc2945
++ltc2978
++ltc3589
++ltc4151
++ltc4215
++ltc4222
++ltc4245
++ltc4260
++ltc4261
++ltr501
++ltv350qv
++lv5207lp
++lvstest
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m62332
++m88ds3103
++m88rs2000
++m88rs6000t
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++m_can
++ma600-sir
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++mac80211
++mac80211_hwsim
++mac802154
++mac_hid
++macb
++macvlan
++macvtap
++mag3110
++magellan
++mailbox-altera
++mailbox-test
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++marvell
++matrix-keymap
++matrix_keypad
++matrox_w1
++matroxfb_DAC1064
++matroxfb_Ti3026
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++max1027
++max1111
++max11801_ts
++max1363
++max14577
++max14577_charger
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max20751
++max2165
++max3100
++max31790
++max3421-hcd
++max34440
++max517
++max5821
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max77693-haptic
++max77693_charger
++max77802
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8997_haptic
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mcb
++mcb-pci
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp3422
++mcp4531
++mcp4725
++mcp4922
++mcryptd
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md-cluster
++md4
++md5-ppc
++mdc800
++mdio
++mdio-bcm-unimac
++mdio-bitbang
++mdio-cavium
++mdio-gpio
++mdio-mux
++mdio-mux-gpio
++mdio-mux-mmioreg
++mdio-octeon
++mdio-thunder
++mdio-xgene
++me4000
++me_daq
++media
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++memory-notifier-error-inject
++memstick
++men_z135_uart
++men_z188_adc
++mena21_wdt
++menf21bmc
++menf21bmc_hwmon
++menf21bmc_wdt
++metro-usb
++metronomefb
++mf6x4
++mga
++michael_mic
++micrel
++microchip
++microread
++microread_i2c
++microtek
++mii
++minix
++mip6
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlx90614
++mlxsw_core
++mlxsw_pci
++mma8450
++mma8452
++mma9551
++mma9551_core
++mma9553
++mmc35240
++mmc_block
++mmc_spi
++mms114
++mn88472
++mn88473
++mos7720
++mos7840
++mostcore
++moxa
++mpc624
++mpl115
++mpl3115
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpoa
++mpr121_touchkey
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++ms5611_core
++ms5611_i2c
++ms5611_spi
++ms5637
++ms_block
++ms_sensors_i2c
++msdos
++msi001
++msi2500
++msp3400
++mspro_block
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt29f_spinand
++mt312
++mt352
++mt6311-regulator
++mt6397-core
++mt6397-regulator
++mt7601u
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtd_dataflash
++mtdblock
++mtdblock_ro
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtk-sd
++mtouch
++multipath
++multiq3
++musb_hdrc
++mv_u3d_core
++mv_udc
++mvmdio
++mvsas
++mvumi
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxc4005
++mxl111sf-demod
++mxl111sf-tuner
++mxl301rf
++mxl5005s
++mxl5007t
++mxser
++mxuport
++myri10ge
++n_gsm
++n_hdlc
++n_r3964
++n_tracerouter
++n_tracesink
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++national
++natsemi
++nau7802
++navman
++nb8800
++nbd
++nci
++nci_spi
++nci_uart
++ncpfs
++nct7802
++nct7904
++nd_blk
++nd_btt
++nd_pmem
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netrom
++netup-unidvb
++netxen_nic
++newtonkbd
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfc
++nfc_digital
++nfcmrvl
++nfcmrvl_i2c
++nfcmrvl_spi
++nfcmrvl_uart
++nfcmrvl_usb
++nfcsim
++nfcwilink
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nftl
++ngene
++nhc_dest
++nhc_fragment
++nhc_hop
++nhc_ipv6
++nhc_mobility
++nhc_routing
++nhc_udp
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++ni_labpc
++ni_labpc_common
++ni_labpc_isadma
++ni_labpc_pci
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++ni_usb6501
++nicpf
++nicstar
++nicvf
++nilfs2
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nosy
++notifier-error-inject
++nouveau
++nozomi
++nps_enet
++ns558
++ns83820
++nsc-ircc
++ntb
++ntb_netdev
++ntb_pingpong
++ntb_tool
++ntb_transport
++ntc_thermistor
++ntfs
++null_blk
++nvidiafb
++nvme
++nvmem_core
++nx-compress
++nx-compress-powernv
++nx-compress-pseries
++nxp-nci
++nxp-nci_i2c
++nxp-ptn3460
++nxt200x
++nxt6000
++objlayoutdriver
++ocfb
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++ocrdma
++of_mmc_spi
++of_xilinx_wdt
++ofpart
++ohci-platform
++old_belkin-sir
++omap4-keypad
++omfs
++omninet
++on20
++on26
++onenand
++opal-prd
++opencores-kbd
++openvswitch
++oprofile
++opt3001
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlay
++oxu210hp-hcd
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++pa12203001
++palmas-pwrbutton
++palmas-regulator
++pandora_bl
++panel
++panel-lg-lg4573
++panel-samsung-ld9040
++panel-samsung-s6e8aa0
++panel-sharp-lq101r1sx01
++panel-simple
++parade-ps8622
++paride
++parkbd
++parport
++parport_ax88796
++parport_pc
++parport_serial
++pata_ali
++pata_amd
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_of_platform
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sis
++pata_sl82c105
++pata_triflex
++pata_via
++pc300too
++pcap-regulator
++pcap_keys
++pcap_ts
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_udc
++pci
++pci-stub
++pci200syn
++pcips2
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcrypt
++pcspkr
++pcwd_pci
++pcwd_usb
++pd
++pda_power
++pdc_adma
++peak_pci
++peak_usb
++pegasus
++penmount
++percpu_test
++pf
++pfuze100-regulator
++pg
++phantom
++phonet
++phram
++phy-bcm-kona-usb2
++phy-exynos-usb2
++phy-gpio-vbus-usb
++phy-isp1301
++phy-pxa-28nm-hsic
++phy-pxa-28nm-usb2
++phy-tahvo
++phy-tusb1210
++physmap
++physmap_of
++pixcir_i2c_ts
++pkcs7_test_key
++pktcdvd
++pktgen
++pl2303
++plat-ram
++plat_nand
++platform_lcd
++plip
++plusb
++pluto2
++plx_pci
++pm-notifier-error-inject
++pm2fb
++pm3fb
++pm80xx
++pm8941-wled
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pn533
++pn544
++pn544_i2c
++pn_pep
++poly1305_generic
++port100
++powermate
++powernv-rng
++powernv_flash
++powr1220
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++ppp_synctty
++pppoatm
++pppoe
++pppox
++pps-gpio
++pps-ldisc
++pps_parport
++pptp
++prism2_usb
++ps2mult
++pseries-rng
++pseries_energy
++psmouse
++psnap
++pt
++pulsedlight-lidar-lite-v2
++pvrusb2
++pwc
++pwm-beeper
++pwm-fan
++pwm-fsl-ftm
++pwm-lp3943
++pwm-pca9685
++pwm-regulator
++pwm-twl
++pwm-twl-led
++pwm_bl
++pxa27x_udc
++qcaspi
++qcaux
++qcom-spmi-iadc
++qcom-spmi-temp-alarm
++qcom-spmi-vadc
++qcom_spmi-regulator
++qcserial
++qed
++qede
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qm1d1c0042
++qmi_wwan
++qnx4
++qnx6
++qsemi
++qt1010
++qt1070
++qt2160
++quatech2
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r8169
++r8188eu
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8723au
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-bcm2048
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-platform-si4713
++radio-raremono
++radio-shark
++radio-si476x
++radio-tea5764
++radio-usb-si470x
++radio-usb-si4713
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++rbd
++rbtree_test
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-dvbsky
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv-fm53
++rc-encore-enltv2
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-su3000
++rc-tbs-nec
++rc-technisat-ts35
++rc-technisat-usb2
++rc-terratec-cinergy-c-pci
++rc-terratec-cinergy-s2-hd
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan-dtv-cab-ci
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rc5t583-regulator
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++redboot
++redrat3
++reed_solomon
++regmap-spmi
++regulator-haptic
++reiserfs
++remoteproc
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio-scan
++rio500
++rionet
++rivafb
++rj54n1cb0c
++rk808
++rk808-regulator
++rmd128
++rmd160
++rmd256
++rmd320
++rn5t618
++rn5t618-regulator
++rn5t618_wdt
++rndis_host
++rndis_wlan
++rocket
++rohm_bu21023
++romfs
++rose
++rotary_encoder
++rp2
++rpadlpar_io
++rpaphp
++rpcrdma
++rpcsec_gss_krb5
++rpr0521
++rrpc
++rsi_91x
++rsi_sdio
++rsi_usb
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800mmio
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt5033
++rt5033-regulator
++rt5033_battery
++rt61pci
++rt73usb
++rt9455_charger
++rtas_flash
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab-b5ze-s3
++rtc-ab3100
++rtc-abx80x
++rtc-as3722
++rtc-bq32k
++rtc-bq4802
++rtc-cmos
++rtc-da9052
++rtc-da9055
++rtc-da9063
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1343
++rtc-ds1347
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1685
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-generic
++rtc-hid-sensor-time
++rtc-hym8563
++rtc-isl12022
++rtc-isl12057
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max77802
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mcp795
++rtc-msm6242
++rtc-mt6397
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf85063
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-r9701
++rtc-rc5t583
++rtc-rk808
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rv8803
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-s5m
++rtc-snvs
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-twl
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtc-zynqmp
++rtc_cmos_setup
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl2832_sdr
++rtl8150
++rtl8187
++rtl8188ee
++rtl818x_pci
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192ee
++rtl8192se
++rtl8723-common
++rtl8723ae
++rtl8723be
++rtl8821ae
++rtl8xxxu
++rtl_pci
++rtl_usb
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtlwifi
++rts5208
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rtsx_usb
++rtsx_usb_ms
++rtsx_usb_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mpa01
++s2mps11
++s3fb
++s3fwrn5
++s3fwrn5_i2c
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7134-go7007
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7706h
++safe_serial
++salsa20_generic
++samsung-sxgbe
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_sil
++sata_sil24
++sata_sis
++sata_svw
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sbp_target
++sbs-battery
++sc16is7xx
++sc92031
++sca3000
++scanlog
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++sctp
++sctp_probe
++sdhci
++sdhci-of-arasan
++sdhci-of-at91
++sdhci-of-esdhc
++sdhci-of-hlwd
++sdhci-pci
++sdhci-pltfm
++sdhci_f_sdh30
++sdio_uart
++seed
++sensorhub
++seqiv
++ser_gigaset
++serial2002
++serio_raw
++sermouse
++serpent_generic
++serport
++ses
++sfc
++sh_veu
++sha1-powerpc
++shark2
++sht15
++sht21
++shtc1
++si2157
++si2165
++si2168
++si21xx
++si4713
++si476x-core
++si7005
++si7020
++sidewinder
++sierra
++sierra_net
++sil164
++sir-dev
++sis
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skd
++skfp
++skge
++sky2
++sky81452
++sky81452-backlight
++sky81452-regulator
++sl811-hcd
++slcan
++slip
++slram
++sm501
++sm501fb
++sm712fb
++sm750fb
++sm_common
++sm_ftl
++smb347-charger
++smipcie
++smm665
++smsc
++smsc-ircc2
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als300
++snd-als4000
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt3328
++snd-bcd2000
++snd-bebob
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-cs4281
++snd-cs46xx
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dice
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1938
++snd-es1968
++snd-firewire-digi00x
++snd-firewire-lib
++snd-firewire-tascam
++snd-fireworks
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-generic
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-core
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-mixart
++snd-mixer-oss
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxfw
++snd-oxygen
++snd-oxygen-lib
++snd-pcm
++snd-pcm-dmaengine
++snd-pcm-oss
++snd-pcxhr
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-sb-common
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-ac97
++snd-soc-adau1701
++snd-soc-ak4104
++snd-soc-ak4554
++snd-soc-ak4613
++snd-soc-ak4642
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-core
++snd-soc-cs35l32
++snd-soc-cs4265
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs4271-i2c
++snd-soc-cs4271-spi
++snd-soc-cs42l51
++snd-soc-cs42l51-i2c
++snd-soc-cs42l52
++snd-soc-cs42l56
++snd-soc-cs42l73
++snd-soc-cs42xx8
++snd-soc-cs42xx8-i2c
++snd-soc-cs4349
++snd-soc-es8328
++snd-soc-fsl-asrc
++snd-soc-fsl-esai
++snd-soc-fsl-sai
++snd-soc-fsl-spdif
++snd-soc-fsl-ssi
++snd-soc-gtm601
++snd-soc-imx-audmux
++snd-soc-pcm1681
++snd-soc-pcm1792a-codec
++snd-soc-pcm512x
++snd-soc-pcm512x-i2c
++snd-soc-pcm512x-spi
++snd-soc-rt5631
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-sigmadsp
++snd-soc-sigmadsp-i2c
++snd-soc-simple-card
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2602
++snd-soc-ssm2602-i2c
++snd-soc-ssm2602-spi
++snd-soc-ssm4567
++snd-soc-sta32x
++snd-soc-sta350
++snd-soc-sti-sas
++snd-soc-tas2552
++snd-soc-tas5086
++snd-soc-tas571x
++snd-soc-tfa9879
++snd-soc-tlv320aic23
++snd-soc-tlv320aic23-i2c
++snd-soc-tlv320aic23-spi
++snd-soc-tlv320aic31xx
++snd-soc-tlv320aic3x
++snd-soc-tpa6130a2
++snd-soc-ts3a227e
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8804
++snd-soc-wm8804-i2c
++snd-soc-wm8804-spi
++snd-soc-wm8903
++snd-soc-wm8962
++snd-soc-wm8978
++snd-soc-xtfpga-i2s
++snd-sonicvibes
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usb-line6
++snd-usb-pod
++snd-usb-podhd
++snd-usb-toneport
++snd-usb-usx2y
++snd-usb-variax
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx-lib
++snd-vx222
++snd-ymfpci
++snic
++soc_button_array
++soc_camera
++soc_camera_platform
++soc_mediabus
++softdog
++softing
++solo6x10
++solos-pci
++sony-btf-mpx
++soundcore
++sp2
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_dectlk
++speakup_dummy
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spi-cadence
++spi-dln2
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi-lm70llp
++spi-nor
++spi-oc-tiny
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tle62x0
++spi-xcomm
++spi-zynqmp-gqspi
++spi_ks8995
++spidev
++spl
++splat
++spmi
++sr9700
++sr9800
++ssb
++ssb-hcd
++ssd1307fb
++ssfdc
++ssp_accel_sensor
++ssp_gyro_sensor
++ssp_iio
++sst25l
++sstfb
++ssu100
++st
++st-nci
++st-nci_i2c
++st-nci_spi
++st1232
++st21nfca_hci
++st21nfca_i2c
++st_accel
++st_accel_i2c
++st_accel_spi
++st_drv
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++st_magn
++st_magn_i2c
++st_magn_spi
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++starfire
++stb0899
++stb6000
++stb6100
++ste10Xp
++ste_modem_rproc
++stex
++stinger
++stir4200
++stk1160
++stk3310
++stk8312
++stk8ba50
++stkwebcam
++stm_console
++stm_core
++stmmac
++stmmac-platform
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++streamzap
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sun4i-codec
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++sur40
++svgalib
++sx8
++sx8654
++sx9500
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink
++synclink_gt
++synclinkmp
++syscopyarea
++sysfillrect
++sysimgblt
++sysv
++t1pci
++t5403
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++target_core_user
++tc3589x-keypad
++tc74
++tc90522
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tcs3414
++tcs3472
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea575x
++tea5761
++tea5767
++tea6415c
++tea6420
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++tef6862
++tehuti
++tekram-sir
++teranetics
++test-hexdump
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_power
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tgr192
++thmc50
++thunder_bgx
++thunderbolt
++ti-adc081c
++ti-adc128s052
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++ti_usb_3410_5052
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timeriomem-rng
++tipc
++tlan
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmp006
++tmp102
++tmp103
++tmp401
++tmp421
++toim3232-sir
++torture
++toshsd
++touchit213
++touchright
++touchwin
++tpci200
++tpm-rng
++tpm_atmel
++tpm_i2c_atmel
++tpm_i2c_infineon
++tpm_i2c_nuvoton
++tpm_st33zp24
++tpm_st33zp24_i2c
++tpm_st33zp24_spi
++tps40422
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217_bl
++tps65217_charger
++tps65218
++tps65218-pwrbutton
++tps65218-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++trf7970a
++tridentfb
++ts2020
++ts_bm
++ts_fsm
++ts_kmp
++tsc2004
++tsc2005
++tsc2007
++tsc200x-core
++tsc40
++tsi568
++tsi57x
++tsi721_mport
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++tsl4531
++tsys01
++tsys02d
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw68
++tw9903
++tw9906
++tw9910
++twidjoy
++twl-regulator
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_charger
++twl4030_keypad
++twl4030_madc_battery
++twl4030_wdt
++twl6030-gpadc
++twl6040-vibra
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++u_ether
++u_serial
++uartlite
++uas
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udc-xilinx
++udf
++udl
++udlfb
++udp_diag
++udp_tunnel
++ueagle-atm
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_fsl_elbc_gpcm
++uio_mf624
++uio_netx
++uio_pci_generic
++uio_pdrv_genirq
++uio_pruss
++uio_sercos3
++uli526x
++ulpi
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unix_diag
++upd64031a
++upd64083
++us5182d
++usb-serial-simple
++usb-storage
++usb3503
++usb8xxx
++usb_8dev
++usb_debug
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_fs
++usb_f_hid
++usb_f_mass_storage
++usb_f_midi
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_printer
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_f_uac1
++usb_f_uac2
++usb_f_uvc
++usb_gigaset
++usb_wwan
++usbatm
++usbdux
++usbduxfast
++usbduxsigma
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmisc_imx
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usdhi6rol0
++userio
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++uwb
++v4l2-common
++v4l2-dv-timings
++v4l2-flash-led-class
++v4l2-mem2mem
++vcan
++vcnl4000
++ves1820
++ves1x93
++veth
++vf610_adc
++vga16fb
++vgastate
++vgem
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via-ircc
++via-rhine
++via-sdmmc
++via-velocity
++via686a
++videobuf-core
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-dvb
++videobuf2-memops
++videobuf2-v4l2
++videobuf2-vmalloc
++videodev
++vim2m
++viperboard
++viperboard_adc
++virt-dma
++virtio-gpu
++virtio-rng
++virtio_input
++virtio_scsi
++virtual
++visor
++vitesse
++vivid
++vlsi_ir
++vmac
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmx-crypto
++vmxnet3
++vp27smpx
++vport-geneve
++vport-gre
++vport-vxlan
++vrf
++vringh
++vsock
++vsxxxaa
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++vz89x
++w1-gpio
++w1_bq27000
++w1_ds2406
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1_smem
++w1_therm
++w5100
++w5300
++w6692
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83977af_ir
++w83l785ts
++w83l786ng
++wacom
++wacom_i2c
++wacom_serial4
++wacom_w8001
++walkera0701
++wanxl
++warrior
++wbsd
++wcn36xx
++wd719x
++wdrtas
++wdt87xx_i2c
++wdt_pci
++whc-rc
++whci
++whci-hcd
++whiteheat
++wil6210
++wimax
++winbond-840
++windfarm_core
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x-ts
++wm831x_backup
++wm831x_bl
++wm831x_power
++wm831x_wdt
++wm8350-hwmon
++wm8350-regulator
++wm8350_power
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-core
++wm8994-irq
++wm8994-regmap
++wm8994-regulator
++wm97xx-ts
++wp512
++wusb-cbaf
++wusb-wa
++wusbcore
++x25
++x25_asy
++x_tables
++xc4000
++xc5000
++xcbc
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xhci-plat-hcd
++xilinx-tpg
++xilinx-video
++xilinx-vtc
++xilinx_ps2
++xilinx_uartps
++xillybus_core
++xillybus_of
++xillybus_pcie
++xor
++xpad
++xr_usb_serial_common
++xsens_mt
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LED
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xtkbd
++xts
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yurex
++zaurus
++zavl
++zcommon
++zd1201
++zd1211rw
++zforce_ts
++zfs
++zhenhua
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++znvpair
++zpios
++zr364xx
++zram
++zunicode
++zynq-fpga
+diff --git a/debian.master/abi/4.4.0-111.134/s390x/generic b/debian.master/abi/4.4.0-111.134/s390x/generic
+new file mode 100644
+index 0000000..6062728
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/s390x/generic
+@@ -0,0 +1,9001 @@
++EXPORT_SYMBOL arch/s390/oprofile/oprofile 0x06a93370	sampler_cpu_buffer
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/mcryptd 0x841c582a	mcryptd_arm_flusher
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x049ace30	rdma_addr_find_smac_by_sgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x2ae448bb	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x31b0c25a	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3378075e	rdma_addr_find_dmac_by_grh
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x3d57c86d	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xbf7dc5c7	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xd206f3c9	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xdf81984b	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x005d7ffe	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x01b91955	ib_cm_insert_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x106657cd	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x209a2ea5	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x2a778252	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x30c9c721	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x3619378d	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x381f5096	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x398d3fcb	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x73ff1da1	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x994e910e	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x9e42bbc2	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xab0f2c0a	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xb55d6a04	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xb9fc92dd	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xc94bc275	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xe4d22149	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xfef1c82c	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x035fd04d	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x04170557	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x05bf5006	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x06802c6c	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x06830b9a	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x07d7be07	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0a73236a	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c8e9a52	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0f82abd2	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x122dd3e5	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x12760160	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x17219b44	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x197a0414	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e143c29	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x21413468	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x224280b4	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x26082caf	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2a20eaaf	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2b05dd52	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x33b7558c	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x399a4621	ib_alloc_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3b425ed9	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3e91a0fa	ib_destroy_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x423fedb1	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x429ad33d	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4549270f	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4656417c	ibnl_unicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x53dd8392	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x55a03290	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5611cdea	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x562a0eaa	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x580148bb	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5b290ee1	ib_get_net_dev_by_params
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5ce9cbd7	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5ee70353	ib_umem_copy_from
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x63126281	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x635bd122	ib_umem_odp_map_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x70ff5f12	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x71d20111	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x71f4cfc2	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7ae64cc9	zgid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7c92ca14	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7c9aa476	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7d71778b	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7fcfe2ad	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x826d5201	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x88d313ba	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x89d84ca6	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8c3bd85d	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8da81791	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x905e49ce	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x948e49e3	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9f03ce63	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa0a75c4b	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa23afa20	ib_check_mr_status
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa2c1eb13	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa2df6a01	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa6f8108c	ibnl_chk_listeners
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa9370510	ib_resolve_eth_dmac
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa94246f5	ib_create_flow
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xab0a3467	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xad615612	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xafcc5c4f	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb23761a2	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb45982b5	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb74567e8	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb93a52b0	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbadd8259	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbaee538b	ib_umem_odp_unmap_dma_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbbee9498	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbd60871b	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcb81c83a	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xce0e0944	ib_find_gid_by_filter
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcfa2a09f	ib_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd56bf850	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd59464ce	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd663c26d	ib_map_mr_sg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd86425df	ibnl_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdc896711	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe064a883	ib_sg_to_pages
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe0659014	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe22c9e4b	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5840ec6	ib_wc_status_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5ab097e	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xebad27f4	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xec839589	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xef662226	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf3591e46	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf3888748	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf94fbdc0	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf96fc9de	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfbf00ca4	ib_find_cached_gid_by_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc5b79be	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfe2a1ca3	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x067bf3d8	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x0fe4875b	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2afba85b	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2f0ea69e	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x3d671476	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x530c5109	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x5c51bb07	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6a01a975	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6ad24baa	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7479ab16	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x74e357c3	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xa4e9ccdd	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xbb4b41d6	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xbd709fc2	ib_mad_kernel_rmpp_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x0ea4eec9	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x1ea6f23c	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x27afd6fc	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x44ae989f	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x4d472eca	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x7ecfeeab	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x88fbab7b	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x94ac94b1	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xb088d5e9	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xd00c7c2e	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xd1739db2	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf4b9b41b	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x48ef0255	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x4b3892a9	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xca082432	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0xdccb8ab5	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0293b24f	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0361839b	iwpm_add_and_query_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0ff9f042	iwpm_remove_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x17f45c00	iwpm_register_pid_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x4dd0e5d7	iwpm_ack_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5bb86a18	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x5da59312	iwpm_register_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x63cbc625	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6968573d	iwpm_add_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x69c5c5f8	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6c74c344	iwpm_get_remote_info
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x7cc5a48d	iwpm_mapping_error_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x83491d0a	iwpm_remote_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x904609a0	iwpm_remove_mapping
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x91a914d6	iwpm_init
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9327be67	iwpm_exit
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x99edf901	iwpm_valid_pid
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xa493e4b1	iwpm_mapping_info_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xb187e8b6	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xc2a5ef1d	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xc47447c8	iwpm_add_mapping_cb
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xd447b24a	iwpm_create_mapinfo
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xe1345380	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xe9d0fd09	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf380aa0f	iwpm_add_and_query_mapping
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x02260145	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x07c01095	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x11d78f66	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x1233a386	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x1f7c7681	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x244237a0	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x304596fa	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x6cc3db27	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x70aff7f5	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x74f34291	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7e122de2	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x81602b19	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x85bd5db1	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x8fc7ff24	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x907df803	rdma_event_msg
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa2d3ad0d	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xabfdb902	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xb39a2334	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xbd7c3ddf	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd163c7bb	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xe2c61770	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xebab5bdb	rdma_connect
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x013e8678	closure_sub
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x0187bb6a	__bch_bset_search
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x0224fc32	bch_btree_keys_alloc
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x10279740	closure_sync
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x18290c90	bch_bset_sort_state_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x313ff088	bch_bset_init_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x3b42669b	bch_bkey_try_merge
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x594d1f90	bch_bset_build_written_tree
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x6dc1194a	bch_bset_fix_invalidated_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x79711460	bch_btree_iter_next
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7d2e3553	bch_btree_insert_key
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x7e232679	bch_bset_insert
++EXPORT_SYMBOL drivers/md/bcache/bcache 0x946ab452	closure_put
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xbbf73b16	bch_btree_keys_free
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xcb47df76	bch_btree_iter_init
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xd3fa7004	closure_wait
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xdf6f8461	bch_btree_sort_partial
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xf8446678	bch_btree_sort_lazy
++EXPORT_SYMBOL drivers/md/bcache/bcache 0xf920f854	bch_btree_keys_init
++EXPORT_SYMBOL drivers/md/dm-bufio 0x268682d2	dm_bufio_forget
++EXPORT_SYMBOL drivers/md/dm-bufio 0x72f07bf4	dm_bufio_set_minimum_buffers
++EXPORT_SYMBOL drivers/md/dm-log 0x2f34484b	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0x5c77cb47	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-log 0x65234f39	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0x9c6ab8bc	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x02cd8aa6	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x0acd83cd	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x297b0b32	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x2f5d4ab9	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x4cedf23c	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x8a6a0429	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/raid456 0x9929a3c3	raid5_set_cache_size
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x19f1e79d	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x233651b2	mlx4_SET_VPORT_QOS_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x29498218	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2c6bf170	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2c922468	set_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x41da8cc8	mlx4_tunnel_steer_add
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5002ed8d	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5c0811bd	mlx4_SET_PORT_BEACON
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5f0701bc	mlx4_get_slave_from_roce_gid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5f25257c	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x62132f04	mlx4_ALLOCATE_VPP_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x656d89eb	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x68340772	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6d8bc3b2	mlx4_SET_VPORT_QOS_set
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7138b994	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x753b41e9	mlx4_is_eq_shared
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x765bacf9	get_phv_bit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7c65f295	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x88863fea	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8da8ec4e	mlx4_get_module_info
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8f7cf62a	mlx4_SET_PORT_VXLAN
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x95289f55	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x96387043	mlx4_get_roce_gid_from_slave
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x990dc6d6	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x99a952da	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9fe84121	mlx4_SET_PORT_fcs_check
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa5e43c54	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa93008b5	mlx4_ALLOCATE_VPP_get
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xae9a4c7f	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbfa8d6cb	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc2faae74	mlx4_get_eqs_per_port
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc34798ef	mlx4_is_eq_vector_valid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc3ddd24c	mlx4_eq_get_irq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc449fe73	mlx4_get_cpu_rmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd2886420	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf12fd3cf	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf2f73863	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf45abf96	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0857aabd	mlx5_get_flow_table_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0e419e64	mlx5_core_modify_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0eb7287e	mlx5_del_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1bc1899b	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1d65788b	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x392edebd	mlx5_register_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3a83e420	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4f02c3bc	mlx5_core_query_vendor_id
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x58d376ad	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5a160f2b	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x60dda37f	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x61a6bcbe	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x63d4c5da	mlx5_modify_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x64932b05	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6ecf1cc2	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x765f33c7	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7effc107	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x84f4476d	mlx5_core_destroy_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x89cb6119	mlx5_cmd_exec_cb
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9b1fbcc9	mlx5_alloc_map_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9d962b1d	mlx5_unmap_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9df4f3ad	mlx5_get_protocol_dev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9fc11568	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa384497e	mlx5_query_vport_admin_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xad0eed62	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xae4485a2	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbb39111c	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbf4fb70c	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc278317b	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc43e0fbf	mlx5_modify_nic_vport_mac_address
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc5c7fcf0	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc65e6d88	mlx5_unregister_interface
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcc70c42c	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe3d81f17	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe625be44	mlx5_create_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6af33e4	mlx5_destroy_flow_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xea37ddc5	mlx5_vector2eqn
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xeb21a007	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xef4d46f4	mlx5_core_create_psv
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf0b41b0d	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfc728a49	mlx5_add_flow_table_entry
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfd78ead9	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x216eb1d1	mlxsw_core_driver_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x2360a424	mlxsw_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x443843bd	mlxsw_core_rx_listener_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x59955b04	mlxsw_reg_write
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x80822927	mlxsw_core_event_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0x92a7c438	mlxsw_core_bus_device_register
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xdde7e8c0	mlxsw_reg_query
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe1e043ae	mlxsw_core_skb_receive
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xe35d64ba	mlxsw_core_bus_device_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xee8e0771	mlxsw_core_skb_transmit_busy
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xeff3a65c	mlxsw_core_skb_transmit
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xf3a6e097	mlxsw_core_driver_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xf426ec27	mlxsw_core_rx_listener_unregister
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlxsw/mlxsw_core 0xfdd89c3a	mlxsw_core_event_listener_register
++EXPORT_SYMBOL drivers/net/phy/fixed_phy 0x83a92253	fixed_phy_update_state
++EXPORT_SYMBOL drivers/net/phy/libphy 0x0473e481	phy_connect
++EXPORT_SYMBOL drivers/net/phy/libphy 0x04820abf	phy_mac_interrupt
++EXPORT_SYMBOL drivers/net/phy/libphy 0x098b48a8	mdiobus_read
++EXPORT_SYMBOL drivers/net/phy/libphy 0x0a373a52	phy_device_free
++EXPORT_SYMBOL drivers/net/phy/libphy 0x0e6f3bf8	phy_connect_direct
++EXPORT_SYMBOL drivers/net/phy/libphy 0x101cc1c6	phy_disconnect
++EXPORT_SYMBOL drivers/net/phy/libphy 0x137c7ee3	phy_ethtool_set_eee
++EXPORT_SYMBOL drivers/net/phy/libphy 0x1435a77b	phy_print_status
++EXPORT_SYMBOL drivers/net/phy/libphy 0x15d8d87c	phy_device_create
++EXPORT_SYMBOL drivers/net/phy/libphy 0x1813bd40	phy_stop_interrupts
++EXPORT_SYMBOL drivers/net/phy/libphy 0x1c791f35	phy_start_aneg
++EXPORT_SYMBOL drivers/net/phy/libphy 0x229192f8	phy_find_first
++EXPORT_SYMBOL drivers/net/phy/libphy 0x24749234	genphy_read_status
++EXPORT_SYMBOL drivers/net/phy/libphy 0x2743bc5c	phy_start
++EXPORT_SYMBOL drivers/net/phy/libphy 0x27b386f3	phy_mii_ioctl
++EXPORT_SYMBOL drivers/net/phy/libphy 0x2ce7c13b	genphy_suspend
++EXPORT_SYMBOL drivers/net/phy/libphy 0x2dda03a0	phy_stop
++EXPORT_SYMBOL drivers/net/phy/libphy 0x2ffb0bc7	__mdiobus_register
++EXPORT_SYMBOL drivers/net/phy/libphy 0x341be4d2	phy_driver_unregister
++EXPORT_SYMBOL drivers/net/phy/libphy 0x3f77e274	mdiobus_write
++EXPORT_SYMBOL drivers/net/phy/libphy 0x4c8d22ef	phy_register_fixup
++EXPORT_SYMBOL drivers/net/phy/libphy 0x4cd8a23d	mdiobus_scan
++EXPORT_SYMBOL drivers/net/phy/libphy 0x525a0cbf	genphy_soft_reset
++EXPORT_SYMBOL drivers/net/phy/libphy 0x553f9432	phy_attach
++EXPORT_SYMBOL drivers/net/phy/libphy 0x555dc9b5	genphy_aneg_done
++EXPORT_SYMBOL drivers/net/phy/libphy 0x55f9dfa4	genphy_restart_aneg
++EXPORT_SYMBOL drivers/net/phy/libphy 0x5cc6d9b2	phy_drivers_register
++EXPORT_SYMBOL drivers/net/phy/libphy 0x5ee3fcc9	phy_device_remove
++EXPORT_SYMBOL drivers/net/phy/libphy 0x5f8735b7	phy_set_max_speed
++EXPORT_SYMBOL drivers/net/phy/libphy 0x601813b1	phy_drivers_unregister
++EXPORT_SYMBOL drivers/net/phy/libphy 0x631d5696	phy_ethtool_get_eee
++EXPORT_SYMBOL drivers/net/phy/libphy 0x6e72c29d	phy_read_mmd_indirect
++EXPORT_SYMBOL drivers/net/phy/libphy 0x81855532	phy_ethtool_sset
++EXPORT_SYMBOL drivers/net/phy/libphy 0x890c3d34	genphy_setup_forced
++EXPORT_SYMBOL drivers/net/phy/libphy 0x8abd10bd	phy_register_fixup_for_id
++EXPORT_SYMBOL drivers/net/phy/libphy 0x8c0f5398	phy_ethtool_get_wol
++EXPORT_SYMBOL drivers/net/phy/libphy 0x8c9242f8	phy_resume
++EXPORT_SYMBOL drivers/net/phy/libphy 0x9db648a3	phy_register_fixup_for_uid
++EXPORT_SYMBOL drivers/net/phy/libphy 0xa0dc0b58	get_phy_device
++EXPORT_SYMBOL drivers/net/phy/libphy 0xa67ce359	phy_write_mmd_indirect
++EXPORT_SYMBOL drivers/net/phy/libphy 0xa764d61e	phy_ethtool_set_wol
++EXPORT_SYMBOL drivers/net/phy/libphy 0xaafbffd8	phy_attach_direct
++EXPORT_SYMBOL drivers/net/phy/libphy 0xac8fa763	genphy_config_init
++EXPORT_SYMBOL drivers/net/phy/libphy 0xb234c923	phy_start_interrupts
++EXPORT_SYMBOL drivers/net/phy/libphy 0xb311556b	mdio_bus_type
++EXPORT_SYMBOL drivers/net/phy/libphy 0xb52aa767	phy_init_hw
++EXPORT_SYMBOL drivers/net/phy/libphy 0xc1e4ad39	phy_detach
++EXPORT_SYMBOL drivers/net/phy/libphy 0xc222dda2	phy_init_eee
++EXPORT_SYMBOL drivers/net/phy/libphy 0xc2c847f9	mdiobus_read_nested
++EXPORT_SYMBOL drivers/net/phy/libphy 0xc5b561f2	genphy_resume
++EXPORT_SYMBOL drivers/net/phy/libphy 0xc74c4801	genphy_update_link
++EXPORT_SYMBOL drivers/net/phy/libphy 0xc9658336	phy_ethtool_gset
++EXPORT_SYMBOL drivers/net/phy/libphy 0xcc7b0f06	phy_suspend
++EXPORT_SYMBOL drivers/net/phy/libphy 0xcddaf632	mdiobus_unregister
++EXPORT_SYMBOL drivers/net/phy/libphy 0xd3196997	phy_device_register
++EXPORT_SYMBOL drivers/net/phy/libphy 0xd3ac7d46	genphy_config_aneg
++EXPORT_SYMBOL drivers/net/phy/libphy 0xe0213eb4	phy_get_eee_err
++EXPORT_SYMBOL drivers/net/phy/libphy 0xe6d0f2ce	phy_driver_register
++EXPORT_SYMBOL drivers/net/phy/libphy 0xedd137c6	mdiobus_alloc_size
++EXPORT_SYMBOL drivers/net/phy/libphy 0xf096c131	mdiobus_free
++EXPORT_SYMBOL drivers/net/phy/libphy 0xf3e78dd1	mdiobus_write_nested
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x4da29fc2	free_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-bitbang 0x5e9d4775	alloc_mdio_bitbang
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0x1c223b9d	cavium_mdiobus_write
++EXPORT_SYMBOL drivers/net/phy/mdio-cavium 0x88f7292b	cavium_mdiobus_read
++EXPORT_SYMBOL drivers/net/phy/mdio-octeon 0x8a1d5c26	octeon_mdiobus_force_mod_depencency
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0x802c7fd1	xgene_enet_phy_register
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xd4320561	xgene_mdio_rgmii_read
++EXPORT_SYMBOL drivers/net/phy/mdio-xgene 0xf57fbe8a	xgene_mdio_rgmii_write
++EXPORT_SYMBOL drivers/net/phy/vitesse 0xef004596	vsc824x_add_skew
++EXPORT_SYMBOL drivers/net/team/team 0x052069da	team_modeop_port_enter
++EXPORT_SYMBOL drivers/net/team/team 0x1841049b	team_options_register
++EXPORT_SYMBOL drivers/net/team/team 0x1f56372e	team_modeop_port_change_dev_addr
++EXPORT_SYMBOL drivers/net/team/team 0x3c890972	team_mode_register
++EXPORT_SYMBOL drivers/net/team/team 0x5a4b7860	team_mode_unregister
++EXPORT_SYMBOL drivers/net/team/team 0xd113c4d7	team_options_change_check
++EXPORT_SYMBOL drivers/net/team/team 0xe8035fe1	team_option_inst_set_change
++EXPORT_SYMBOL drivers/net/team/team 0xfbf540aa	team_options_unregister
++EXPORT_SYMBOL drivers/pps/pps_core 0xcf915ac0	pps_lookup_dev
++EXPORT_SYMBOL drivers/pps/pps_core 0xd5f8f4f9	pps_register_source
++EXPORT_SYMBOL drivers/pps/pps_core 0xd8944586	pps_event
++EXPORT_SYMBOL drivers/pps/pps_core 0xfcda872d	pps_unregister_source
++EXPORT_SYMBOL drivers/ptp/ptp 0x0f25d41c	ptp_clock_unregister
++EXPORT_SYMBOL drivers/ptp/ptp 0x6e43d8a3	ptp_find_pin
++EXPORT_SYMBOL drivers/ptp/ptp 0x92aa16d5	ptp_clock_index
++EXPORT_SYMBOL drivers/ptp/ptp 0x9745f3fc	ptp_clock_event
++EXPORT_SYMBOL drivers/ptp/ptp 0xd197e798	ptp_clock_register
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x040f8b70	dasd_int_handler
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x08502b2e	dasd_sleep_on_immediatly
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x0b5a8b8d	dasd_log_sense_dbf
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x0ef73135	dasd_debug_area
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x10933d7b	dasd_add_request_tail
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x1fd81a93	dasd_kmalloc_request
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x26348b20	dasd_sleep_on
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x3b204bc5	dasd_free_erp_request
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x3b396740	dasd_set_target_state
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x558dd989	dasd_diag_discipline_pointer
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x58f4d910	dasd_cancel_req
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x5e5313d7	dasd_device_set_timer
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x694e72db	dasd_alloc_erp_request
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x6ce6989d	dasd_sleep_on_interruptible
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x78b5ab5c	dasd_kfree_request
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x8641eb5c	dasd_reload_device
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x94b762fd	dasd_schedule_device_bh
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0x9d6902f0	dasd_enable_device
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xa351d3ae	dasd_default_erp_postaction
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xb4dcb5de	dasd_sleep_on_queue
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xb861f0d3	dasd_add_request_head
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xbcf07089	dasd_default_erp_action
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xbd485c98	dasd_log_sense
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xc0a070ad	dasd_block_set_timer
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xc12f79cc	dasd_smalloc_request
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xc3dd6c43	dasd_eer_write
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xcd4ed569	dasd_start_IO
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xd4b1d4a8	dasd_kick_device
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xd7ab956c	dasd_term_IO
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xdb1732e1	dasd_block_clear_timer
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xdca9b2eb	dasd_schedule_block_bh
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xe0a97392	dasd_sfree_request
++EXPORT_SYMBOL drivers/s390/block/dasd_mod 0xe3443290	dasd_device_clear_timer
++EXPORT_SYMBOL drivers/s390/char/hmcdrv 0x08e57a2c	hmcdrv_ftp_do
++EXPORT_SYMBOL drivers/s390/char/hmcdrv 0x3198b5cb	hmcdrv_ftp_startup
++EXPORT_SYMBOL drivers/s390/char/hmcdrv 0x83a6e87f	hmcdrv_ftp_probe
++EXPORT_SYMBOL drivers/s390/char/hmcdrv 0xba68949c	hmcdrv_ftp_shutdown
++EXPORT_SYMBOL drivers/s390/char/tape 0x0758ae8a	tape_generic_remove
++EXPORT_SYMBOL drivers/s390/char/tape 0x1266e2bd	tape_std_mtrew
++EXPORT_SYMBOL drivers/s390/char/tape 0x12acf804	tape_std_mteom
++EXPORT_SYMBOL drivers/s390/char/tape 0x237f0468	tape_std_mtfsr
++EXPORT_SYMBOL drivers/s390/char/tape 0x2546c415	tape_state_verbose
++EXPORT_SYMBOL drivers/s390/char/tape 0x2aec050b	tape_std_unassign
++EXPORT_SYMBOL drivers/s390/char/tape 0x34e8955b	tape_generic_probe
++EXPORT_SYMBOL drivers/s390/char/tape 0x3851d95a	tape_std_mterase
++EXPORT_SYMBOL drivers/s390/char/tape 0x3cff000e	tape_dump_sense_dbf
++EXPORT_SYMBOL drivers/s390/char/tape 0x3e3c6344	tape_std_assign
++EXPORT_SYMBOL drivers/s390/char/tape 0x4984b674	tape_generic_pm_suspend
++EXPORT_SYMBOL drivers/s390/char/tape 0x49d7d36d	tape_std_mtsetblk
++EXPORT_SYMBOL drivers/s390/char/tape 0x4d7cba1f	tape_std_mtbsfm
++EXPORT_SYMBOL drivers/s390/char/tape 0x4e5f6358	tape_core_dbf
++EXPORT_SYMBOL drivers/s390/char/tape 0x57ce99ec	tape_cancel_io
++EXPORT_SYMBOL drivers/s390/char/tape 0x5e0b9ecf	tape_std_display
++EXPORT_SYMBOL drivers/s390/char/tape 0x609830d5	tape_std_mtcompression
++EXPORT_SYMBOL drivers/s390/char/tape 0x61f7a4e2	tape_do_io
++EXPORT_SYMBOL drivers/s390/char/tape 0x66deb66c	tape_op_verbose
++EXPORT_SYMBOL drivers/s390/char/tape 0x6ada9390	tape_std_mtreten
++EXPORT_SYMBOL drivers/s390/char/tape 0x70edbdc1	tape_med_state_set
++EXPORT_SYMBOL drivers/s390/char/tape 0x77a6ccb9	tape_std_mtfsf
++EXPORT_SYMBOL drivers/s390/char/tape 0x796ded61	tape_alloc_request
++EXPORT_SYMBOL drivers/s390/char/tape 0x7a2057a1	tape_std_read_block
++EXPORT_SYMBOL drivers/s390/char/tape 0x7cd8ea16	tape_std_mtload
++EXPORT_SYMBOL drivers/s390/char/tape 0x84c07da8	tape_state_set
++EXPORT_SYMBOL drivers/s390/char/tape 0x84cbba7c	tape_free_request
++EXPORT_SYMBOL drivers/s390/char/tape 0x85b9ded5	tape_get_device
++EXPORT_SYMBOL drivers/s390/char/tape 0x89399935	tape_std_process_eov
++EXPORT_SYMBOL drivers/s390/char/tape 0x8b63540c	tape_std_mtnop
++EXPORT_SYMBOL drivers/s390/char/tape 0x8ca8f1d4	tape_std_mtfsfm
++EXPORT_SYMBOL drivers/s390/char/tape 0x96296456	tape_std_mtbsr
++EXPORT_SYMBOL drivers/s390/char/tape 0x98867e5a	tape_std_mtweof
++EXPORT_SYMBOL drivers/s390/char/tape 0x9d24fe54	tape_std_write_block
++EXPORT_SYMBOL drivers/s390/char/tape 0xa3d72ec9	tape_std_read_block_id
++EXPORT_SYMBOL drivers/s390/char/tape 0xaa1a1ed7	tape_std_mtreset
++EXPORT_SYMBOL drivers/s390/char/tape 0xad261b1f	tape_std_mtoffl
++EXPORT_SYMBOL drivers/s390/char/tape 0xb16b71d6	tape_std_read_backward
++EXPORT_SYMBOL drivers/s390/char/tape 0xb35ebdce	tape_generic_offline
++EXPORT_SYMBOL drivers/s390/char/tape 0xb4745276	tape_do_io_interruptible
++EXPORT_SYMBOL drivers/s390/char/tape 0xc2f0ac87	tape_std_mtbsf
++EXPORT_SYMBOL drivers/s390/char/tape 0xd6865898	tape_generic_online
++EXPORT_SYMBOL drivers/s390/char/tape 0xe8db840b	tape_mtop
++EXPORT_SYMBOL drivers/s390/char/tape 0xec3f28f3	tape_std_mtunload
++EXPORT_SYMBOL drivers/s390/char/tape 0xf10ffaf9	tape_do_io_async
++EXPORT_SYMBOL drivers/s390/char/tape 0xf7e0b3fb	tape_put_device
++EXPORT_SYMBOL drivers/s390/char/tape_34xx 0xa1676ca9	tape_34xx_dbf
++EXPORT_SYMBOL drivers/s390/char/tape_3590 0x6cba9afb	tape_3590_dbf
++EXPORT_SYMBOL drivers/s390/char/tape_class 0x05635adf	register_tape_dev
++EXPORT_SYMBOL drivers/s390/char/tape_class 0x7d1f3752	unregister_tape_dev
++EXPORT_SYMBOL drivers/s390/cio/ccwgroup 0x23d94066	ccwgroup_driver_unregister
++EXPORT_SYMBOL drivers/s390/cio/ccwgroup 0x3857feed	ccwgroup_set_offline
++EXPORT_SYMBOL drivers/s390/cio/ccwgroup 0x3b2e88f9	ccwgroup_create_dev
++EXPORT_SYMBOL drivers/s390/cio/ccwgroup 0x58802e81	ccwgroup_probe_ccwdev
++EXPORT_SYMBOL drivers/s390/cio/ccwgroup 0x7d652851	ccwgroup_driver_register
++EXPORT_SYMBOL drivers/s390/cio/ccwgroup 0x8dbf32a8	ccwgroup_set_online
++EXPORT_SYMBOL drivers/s390/cio/ccwgroup 0xcfe93c4c	ccwgroup_remove_ccwdev
++EXPORT_SYMBOL drivers/s390/cio/qdio 0x2af0598d	qdio_start_irq
++EXPORT_SYMBOL drivers/s390/cio/qdio 0x5362a156	qdio_get_next_buffers
++EXPORT_SYMBOL drivers/s390/cio/qdio 0x8fda5e51	qdio_stop_irq
++EXPORT_SYMBOL drivers/s390/crypto/ap 0x047d8320	ap_driver_register
++EXPORT_SYMBOL drivers/s390/crypto/ap 0x0ffc9609	ap_recv
++EXPORT_SYMBOL drivers/s390/crypto/ap 0x427fc302	ap_cancel_message
++EXPORT_SYMBOL drivers/s390/crypto/ap 0x5e21cb82	ap_send
++EXPORT_SYMBOL drivers/s390/crypto/ap 0x77247c5e	ap_bus_force_rescan
++EXPORT_SYMBOL drivers/s390/crypto/ap 0x9fcd07e2	ap_queue_message
++EXPORT_SYMBOL drivers/s390/crypto/ap 0xd5e90454	ap_domain_index
++EXPORT_SYMBOL drivers/s390/crypto/ap 0xe428efca	ap_flush_queue
++EXPORT_SYMBOL drivers/s390/crypto/ap 0xf117805b	ap_driver_unregister
++EXPORT_SYMBOL drivers/s390/crypto/zcrypt_api 0x178e2dff	zcrypt_device_unregister
++EXPORT_SYMBOL drivers/s390/crypto/zcrypt_api 0x2b612e6c	zcrypt_device_alloc
++EXPORT_SYMBOL drivers/s390/crypto/zcrypt_api 0x309dedeb	zcrypt_msgtype_request
++EXPORT_SYMBOL drivers/s390/crypto/zcrypt_api 0x4d9d817c	zcrypt_msgtype_unregister
++EXPORT_SYMBOL drivers/s390/crypto/zcrypt_api 0x62c75121	zcrypt_device_put
++EXPORT_SYMBOL drivers/s390/crypto/zcrypt_api 0x67cedaeb	zcrypt_rescan_req
++EXPORT_SYMBOL drivers/s390/crypto/zcrypt_api 0x69acfe2c	zcrypt_device_register
++EXPORT_SYMBOL drivers/s390/crypto/zcrypt_api 0x6e5cd836	zcrypt_msgtype_register
++EXPORT_SYMBOL drivers/s390/crypto/zcrypt_api 0x83fbf76b	zcrypt_device_free
++EXPORT_SYMBOL drivers/s390/crypto/zcrypt_api 0x85c53bff	zcrypt_msgtype_release
++EXPORT_SYMBOL drivers/s390/crypto/zcrypt_api 0x8b169161	zcrypt_device_get
++EXPORT_SYMBOL drivers/s390/net/ctcm 0x40b3051a	ctc_mpc_dealloc_ch
++EXPORT_SYMBOL drivers/s390/net/ctcm 0x56f42138	ctc_mpc_alloc_channel
++EXPORT_SYMBOL drivers/s390/net/ctcm 0x812fa936	ctc_mpc_establish_connectivity
++EXPORT_SYMBOL drivers/s390/net/ctcm 0xf5440dc6	ctc_mpc_flow_control
++EXPORT_SYMBOL drivers/s390/net/fsm 0x0e10e441	fsm_modtimer
++EXPORT_SYMBOL drivers/s390/net/fsm 0x1b770365	kfree_fsm
++EXPORT_SYMBOL drivers/s390/net/fsm 0x3805a87b	fsm_getstate_str
++EXPORT_SYMBOL drivers/s390/net/fsm 0x57b18322	fsm_deltimer
++EXPORT_SYMBOL drivers/s390/net/fsm 0x7af9f0a2	fsm_settimer
++EXPORT_SYMBOL drivers/s390/net/fsm 0xc6696799	fsm_addtimer
++EXPORT_SYMBOL drivers/s390/net/fsm 0xdcbc5aa7	init_fsm
++EXPORT_SYMBOL drivers/s390/net/qeth_l2 0x3688f5b3	qeth_osn_deregister
++EXPORT_SYMBOL drivers/s390/net/qeth_l2 0xb8401e00	qeth_osn_assist
++EXPORT_SYMBOL drivers/s390/net/qeth_l2 0xe9f6fdac	qeth_osn_register
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x40960119	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x68a8b0c9	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x74116f00	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xa7a6e8e7	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xb16b7617	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xba4ad816	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xbe262a38	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xc6d21a54	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xd6591bbe	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xdd564a20	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xe1190154	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xe88e3d01	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x006aa3b2	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x09f3345c	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x13c074f4	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x150b95ab	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1a22e3a8	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1bbbd4be	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1ea6ba87	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2d3254d1	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x32657f51	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x44bedfd7	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4c61f662	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4da5bc12	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x50acad89	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5303afb0	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5b0c4aaf	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6297a443	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x63de36d0	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x67219dce	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x67a9582c	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x72b340fd	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x745e6fbb	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7a49a900	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7b22bbbc	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7ce72f74	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x87176f6a	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9321834c	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9698cf26	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x99970a57	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9fd1ebed	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa70195f3	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb3876112	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb4ef744b	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbcc6735f	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbf4c89d5	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc1286f18	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc1355e9d	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc25acf5a	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc45cfe46	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc6b45c40	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc76ccf2f	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd1cef02b	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd7409983	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdf1a6101	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe250d57a	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe5f458da	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe63cb47e	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xea09eec7	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xeb618e08	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xeeb4db23	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xeef754e3	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x16fa1028	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x30062e4f	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8d5adaa5	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xb47b95b7	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x025f76a8	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x14fbcfaa	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x152c2810	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1f71fcbc	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x22ec0c1a	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x2b31a6d1	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3580d477	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x38af60c8	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3a904a4f	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5ed75494	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x62300e28	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x697b2035	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6dc77c81	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6fe87828	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7e9e8f02	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x82050e0e	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x83fb97e2	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x83fd534f	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x90dcc46e	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa45e6260	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb2b0790d	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb316a7ea	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb8dc39bc	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbafddcad	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc0822c39	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc27e77be	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc9170c7a	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcb40aeb6	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xce63c37a	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd2733398	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd38bc005	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd5ebd7be	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd8ac51dd	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdbde928b	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xedc98f89	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfb5f6b8a	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x1caf2d1b	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x485bb3b8	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x556aa364	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5bbd9f48	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x81c367c5	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xc1009a24	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/raid_class 0x3a0857a1	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0x86808912	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0xa20f3426	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x0e93141f	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x1a6e6af2	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x4e734525	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x53ad2a16	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7cc94a8e	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x8086cf9e	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x8165e797	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x9e95ab11	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xa1badac8	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xa3a78b0d	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xacffff02	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xe7254686	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xf72fd7fa	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x059b66e6	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x08381998	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2fd0f313	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x30c5063a	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x46df2715	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x49a990d9	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x567bd7c7	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x57b1f53b	sas_get_address
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5ad21a44	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5e33e2fa	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5fb4e66f	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x633822a6	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x63d5755b	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x75b78348	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x78a8705c	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7db36136	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x87a03902	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x8c741d8e	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xbf62b9e7	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc032d87f	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc37f3440	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xcbef604c	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd67b42c9	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd8ac3c84	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xda6dcc93	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe15deb36	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xec95ece3	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf16cef47	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf98d1537	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x39a10cf5	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x5cb86f96	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x9d28d9ec	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xa2c4cb24	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xd81173c0	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x1be34130	srp_reconnect_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x3ada403a	srp_rport_put
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0x405b6e05	srp_parse_tmo
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xe3b6c10d	srp_rport_get
++EXPORT_SYMBOL drivers/scsi/scsi_transport_srp 0xf37b0b3b	srp_start_tl_fail_timers
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0622610e	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x08b459ca	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0c863ac8	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0d1d8658	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x11605ac9	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x17d637e2	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x26498f68	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x336de11b	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3803c8d4	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x418dd53c	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x41fd58b7	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4a7c9fcb	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5e03b5e1	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5f18b67e	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6589f519	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x7942d604	iscsit_find_cmd_from_itt
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x891130b7	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x893799ff	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x949e3d7f	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x9989abfe	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa2e88998	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa48343ae	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa757812b	iscsit_release_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xae5092ae	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xaeecc389	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb766c37a	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe87e995c	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe885b20e	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0009a798	target_configure_unmap_from_queue
++EXPORT_SYMBOL drivers/target/target_core_mod 0x01c111ce	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02dfc5bb	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x04f7712e	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x08d17fee	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x09731803	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0b11e81b	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0b36bb77	core_allocate_nexus_loss_ua
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0c397325	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x17fcdd0d	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1a47e86e	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1abb4d16	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1f771821	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x259fcfce	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0x266be1f7	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2e6c82e3	target_tpg_has_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x33859cf6	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x401085b3	target_register_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x46acf568	target_put_nacl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4a7ec2a2	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4cb3b5d3	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x54cc350b	target_show_dynamic_sessions
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5cebe414	target_unregister_template
++EXPORT_SYMBOL drivers/target/target_core_mod 0x616aeeef	sbc_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x63ce2cba	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x64ecdc6a	passthrough_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6918afca	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x69623212	target_undepend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x736c62b8	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x74a607af	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x768dac60	target_depend_item
++EXPORT_SYMBOL drivers/target/target_core_mod 0x775c0dba	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7863098b	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7a9a669b	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7b6bb806	sbc_dif_copy_prot
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x811cd91c	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x84a88c9f	target_backend_unregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8688db62	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8873f626	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x88fa5583	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x893ebfd5	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8c06aea7	target_to_linux_sector
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8ec07d5f	passthrough_attrib_attrs
++EXPORT_SYMBOL drivers/target/target_core_mod 0x924b0ba7	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0x931cea0f	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9517c1f9	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x951c91ca	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0x985b3215	target_lun_is_rdonly
++EXPORT_SYMBOL drivers/target/target_core_mod 0x98d32142	target_complete_cmd_with_length
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9c667e57	sbc_dif_verify
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9c7d8728	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa473ae77	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa70040ba	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa7bdaf7a	core_tpg_get_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa7d0f51b	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa99c0e62	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0xafeefb4f	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb163afd6	transport_backend_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb626aa13	target_alloc_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbd0e5fa9	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbd28f9da	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbd576f62	transport_init_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc5fb913e	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd037e0f6	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe6503995	transport_alloc_session_tags
++EXPORT_SYMBOL drivers/target/target_core_mod 0xeb4f6198	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0xed26d297	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf32ca61b	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0xff7a12e6	target_nacl_find_deve
++EXPORT_SYMBOL drivers/tty/serial/serial_core 0x1b1b985a	uart_match_port
++EXPORT_SYMBOL drivers/tty/serial/serial_core 0x2a1e178d	uart_get_divisor
++EXPORT_SYMBOL drivers/tty/serial/serial_core 0x3460d87e	uart_resume_port
++EXPORT_SYMBOL drivers/tty/serial/serial_core 0x86ea3242	uart_register_driver
++EXPORT_SYMBOL drivers/tty/serial/serial_core 0x889498cc	uart_suspend_port
++EXPORT_SYMBOL drivers/tty/serial/serial_core 0x95b5e074	uart_write_wakeup
++EXPORT_SYMBOL drivers/tty/serial/serial_core 0xa510ed9a	uart_add_one_port
++EXPORT_SYMBOL drivers/tty/serial/serial_core 0xa5181252	uart_remove_one_port
++EXPORT_SYMBOL drivers/tty/serial/serial_core 0xc86d3e99	uart_get_baud_rate
++EXPORT_SYMBOL drivers/tty/serial/serial_core 0xecb5f852	uart_unregister_driver
++EXPORT_SYMBOL drivers/tty/serial/serial_core 0xee6334a2	uart_update_timeout
++EXPORT_SYMBOL drivers/vhost/vringh 0x0617468c	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x0fd987f7	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x14397bb5	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x15a80695	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x32da6f89	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x39c9d7a5	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3fc7a1da	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x42898ba2	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x42903a3b	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x4b40c951	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4f384f8b	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x58abf4ed	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x6432894b	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x8d080d03	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x95e62337	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xb4b63575	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xc578f0f7	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xd355e031	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd609393d	vringh_notify_disable_user
++EXPORT_SYMBOL fs/exofs/libore 0x1691bfa0	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0x1c19f960	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x2d9a359b	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0x33cce235	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x4527e170	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x95f14e1b	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0x9e290bd6	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xc13bdc52	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0xc938530d	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0xc98a2ec5	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0xcbdc9476	extract_attr_from_ios
++EXPORT_SYMBOL fs/fscache/fscache 0x03d00432	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x08862d81	fscache_object_retrying_stale
++EXPORT_SYMBOL fs/fscache/fscache 0x0e2ea6df	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x13cf69b6	fscache_operation_init
++EXPORT_SYMBOL fs/fscache/fscache 0x14118657	__fscache_enable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x1696e617	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x18a7ca3b	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0x1c6df1dd	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0x1c8ee730	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x221e980f	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x28951ec9	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x32b6e28f	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x35bdf87c	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x3c970f53	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x465ae332	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x47513a1f	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x48deffe2	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x4927d82e	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x4dd747b5	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x5aca7ce7	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x6e128015	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0x6ef86a3d	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x749e742e	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0x7df56cdd	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0x81e5826e	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x83dbf321	fscache_object_mark_killed
++EXPORT_SYMBOL fs/fscache/fscache 0x8554a6d9	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x875d3f8b	__fscache_check_consistency
++EXPORT_SYMBOL fs/fscache/fscache 0x88386f09	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x894ffe37	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x901887c2	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xb7e9fac3	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0xc1c75ec3	__fscache_disable_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xc542b7a6	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0xc74003f9	__fscache_readpages_cancel
++EXPORT_SYMBOL fs/fscache/fscache 0xc8191069	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xd294d0c4	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0xd74ef5f7	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xdd80e2ca	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0xeab965c9	__fscache_uncache_page
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x1da1cada	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0x310727a5	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x567de8d6	qtree_read_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x93a462f9	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xfc7abcaf	qtree_write_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x651c2313	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0x276c7e62	crc_itu_t
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc7 0x6b96fbac	crc7_be
++EXPORT_SYMBOL lib/crc7 0x7a222007	crc7_be_syndrome_table
++EXPORT_SYMBOL lib/crc8 0x3e77b340	crc8
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x0f6f0fdb	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0x17c6b1e1	lc_del
++EXPORT_SYMBOL lib/lru_cache 0x52857213	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0x5c460ad5	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x6bb10f2d	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x6f1d0c3b	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0x7869961b	lc_set
++EXPORT_SYMBOL lib/lru_cache 0x79c87149	lc_get
++EXPORT_SYMBOL lib/lru_cache 0x88713f97	lc_create
++EXPORT_SYMBOL lib/lru_cache 0x955d4873	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0xbbc7a78d	lc_put
++EXPORT_SYMBOL lib/lru_cache 0xc1a43316	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0xc3a4ca05	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0xe4a98afa	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0xebae3022	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0xff3f1db8	lc_find
++EXPORT_SYMBOL lib/lru_cache 0xffb12208	lc_is_used
++EXPORT_SYMBOL lib/lz4/lz4_compress 0x32ec514e	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0xab08068b	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0x5a0b73d0	zlib_deflateInit2
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0x6aeefac4	zlib_deflateReset
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xc890c008	zlib_deflateEnd
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xf2c43f3f	zlib_deflate
++EXPORT_SYMBOL net/802/p8022 0x2242ae9c	unregister_8022_client
++EXPORT_SYMBOL net/802/p8022 0xf23a0ce9	register_8022_client
++EXPORT_SYMBOL net/802/psnap 0x0e542e21	register_snap_client
++EXPORT_SYMBOL net/802/psnap 0xa4d5d84e	unregister_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x0a2cbdc7	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x0b57b773	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0x0cd0b84c	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0x14b6e539	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x1546d0c0	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0x18c4fc22	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0x2176926b	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x23ead7e3	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x35a0bf19	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x3a572c0c	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x3da06d9a	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0x44d2c2c0	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x4ba97508	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0x51f05ec9	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0x53153bad	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0x559397f6	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x5a86ee91	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0x63ba05a2	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x646d01bc	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x6710dd05	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0x6dfd57f8	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x7520c34c	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0x78fe62e3	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x80bb847f	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0x897b48ae	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x8ceb970c	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x9117c02b	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0x9bee7182	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x9e2ba351	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0xae523359	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0xbe656d64	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0xc0d1a657	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0xc41aac0a	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xca39d127	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xd21c7466	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0xd4fe1fc0	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0xd7aee6d4	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0xd8c95a6f	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0xe06edf65	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0xe10d09b5	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xf1364ae5	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xf27cb58b	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0xf37d6739	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/bridge/bridge 0x917593e4	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x095a9a50	ebt_do_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x27f5666d	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x82549285	ebt_register_table
++EXPORT_SYMBOL net/ceph/libceph 0x01a2ad19	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x03692086	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0x05c0d251	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x067c5c4d	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x0781e43e	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0f9f2170	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x1445a9c1	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0x150bd443	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x15ff69f4	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x18caf35d	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0x19e1fa73	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x1e2c1b23	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0x1f8efb1b	osd_req_op_alloc_hint_init
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x25dd0ba2	ceph_osdc_put_request
++EXPORT_SYMBOL net/ceph/libceph 0x27dd3754	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x2dcf4536	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0x2fc13dc8	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x32f6952c	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x394900ef	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x3a681eb6	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3c020989	ceph_msg_put
++EXPORT_SYMBOL net/ceph/libceph 0x3cc306d2	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0x3d42fefd	ceph_monc_wait_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x40e9fb59	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x44053808	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x45e283ec	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x4856f103	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0x48e1b47f	ceph_monc_request_next_osdmap
++EXPORT_SYMBOL net/ceph/libceph 0x4a69fadc	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x4bf0271e	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0x4cdc39a7	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0x4dc64701	ceph_oloc_oid_to_pg
++EXPORT_SYMBOL net/ceph/libceph 0x4fcb70ee	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x50a76d31	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0x511b241b	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x551a4792	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x5f947752	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0x61c588d5	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x6687b48d	ceph_print_client_options
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x7241dd2a	ceph_osdc_flush_notifies
++EXPORT_SYMBOL net/ceph/libceph 0x79919e07	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x7c2a5ed3	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x7c552b77	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0x7c5d7e6d	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x817c7eea	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0x8300bc95	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0x8977535d	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x8cd4934c	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0x8df1aa66	ceph_messenger_fini
++EXPORT_SYMBOL net/ceph/libceph 0x92b5801a	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x98160423	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9b61eead	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x9f471e1e	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa1cb2376	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0xa4c83f9f	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0xa5bb86a6	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0xa6791826	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0xa8980573	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0xa93e7677	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0xabe95487	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xaee59d01	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb2752f24	ceph_osdc_cancel_request
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb550ef84	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb9ae51fa	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0xba0cd32b	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xbbeab1f6	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0xbe5aa413	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xbf0c64da	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0xc11386be	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xc1f544bb	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc7672334	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0xc82bf51c	ceph_monc_do_get_version
++EXPORT_SYMBOL net/ceph/libceph 0xc8bfb282	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0xc97baae8	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd51d1c1a	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xd74b6ff4	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0xdb05c143	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0xdf1650bd	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0xe1dd206a	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0xe5b5f4df	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0xe71387a7	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0xe8656faf	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0xec958524	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0xecdde440	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0xedfb8e5a	osd_req_op_xattr_init
++EXPORT_SYMBOL net/ceph/libceph 0xf1c49fab	ceph_msg_get
++EXPORT_SYMBOL net/ceph/libceph 0xf309e8ec	ceph_osdc_get_request
++EXPORT_SYMBOL net/ceph/libceph 0xf731367e	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0xf7c05609	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xf89d6dcb	ceph_con_keepalive
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x1a06eb11	dccp_req_err
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0xfed9f691	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/ipv4/fou 0x3d3b47f7	gue_build_header
++EXPORT_SYMBOL net/ipv4/fou 0x72395c37	fou_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0x934af5fb	gue_encap_hlen
++EXPORT_SYMBOL net/ipv4/fou 0x9912bc6e	fou_build_header
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x07ecb683	ip_tunnel_get_iflink
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x2adb8a79	ip_tunnel_encap
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0x57fb5e87	ip_tunnel_encap_add_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xc95a4059	ip_tunnel_encap_del_ops
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xe32fbaa1	ip_tunnel_dst_reset_all
++EXPORT_SYMBOL net/ipv4/ip_tunnel 0xef1e2955	ip_tunnel_get_link_net
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x07c4a1a4	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x5321653a	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x8e7c89b1	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x48923be3	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x4a1fb4aa	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x6f3302a4	ipt_do_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x10f834ac	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/tunnel4 0x4b8ba979	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/udp_tunnel 0x71147565	udp_sock_create4
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x6a148b43	ip6_tnl_get_iflink
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x7bc965d8	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x86a98b38	ip6_tnl_get_link_net
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xbad3d676	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x7efe3157	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xaa8db64e	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xad2bd599	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x0fbcecd0	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0x54df3fa7	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x8075f97f	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0xba4048bb	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/l2tp/l2tp_core 0xb4015ba2	l2tp_recv_common
++EXPORT_SYMBOL net/l2tp/l2tp_ip 0xb3c113e3	l2tp_ioctl
++EXPORT_SYMBOL net/llc/llc 0x2b839344	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x7ee3bc41	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0x94d8fd81	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0xb2e4a674	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0xbefeda22	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0xdf41989b	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0xe2ffc14f	llc_sap_close
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x0c290bca	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x0dc98728	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x311f92fb	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x449611be	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x4861e5b3	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x894752c1	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x97663fcd	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xa233d0c9	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xa5f12d13	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb137886a	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb448cf3e	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xc9a8524e	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xcafd0ef5	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xcc4c79be	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x19dcef2e	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x6039ab6d	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x882eb22d	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_nat 0x0402d23f	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/nf_nat 0x058fae38	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x5c998520	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0x94f1438c	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0xfcdbff04	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xfd155ce6	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/x_tables 0x22430b2a	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x253e8b44	xt_compat_init_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0x5333ab66	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x555c3243	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x762249c5	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x8f4358ab	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x984d163d	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xa25fc115	xt_compat_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xa48b3a97	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xcda38094	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0xcedc8bfa	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xd216ac4a	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xd87ae60d	xt_check_entry_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0xef5bd8ff	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xf04c636e	xt_unregister_matches
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x0c01d811	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1c565891	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x2d49594f	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x4f4dd860	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x66192cb7	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x6f36d73e	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x761065a6	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8938a15b	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8e112f35	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x945d2c75	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xa92850b0	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb26b0e40	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb3d22658	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xd576e14b	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf4ad3438	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/sctp/sctp 0x1928b6ea	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x0961a5a9	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x5f26f954	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xbb379cb5	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x282ce39a	svc_pool_stats_open
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x735cb918	xdr_truncate_encode
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x900d9d7e	xdr_restrict_buflen
++EXPORT_SYMBOL vmlinux 0x0010e948	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x002f061f	compat_sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x0070cd1f	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0x0073ca48	kill_block_super
++EXPORT_SYMBOL vmlinux 0x008641df	tcf_hash_cleanup
++EXPORT_SYMBOL vmlinux 0x009d8a02	dev_queue_xmit_accel
++EXPORT_SYMBOL vmlinux 0x00a68022	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0x00abed75	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0x00bc800b	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x00e6adb2	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0x00f4a223	_ebc_toupper
++EXPORT_SYMBOL vmlinux 0x00f8ae8b	bioset_create
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x0101d5b1	ip_idents_reserve
++EXPORT_SYMBOL vmlinux 0x013f0281	ccw_device_tm_start_key
++EXPORT_SYMBOL vmlinux 0x016e5c2a	mod_timer
++EXPORT_SYMBOL vmlinux 0x0185a7d7	sclp_pci_deconfigure
++EXPORT_SYMBOL vmlinux 0x018d2bff	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x019070a0	md_done_sync
++EXPORT_SYMBOL vmlinux 0x01e9a7c3	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x01ebcb7b	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0x01ec7e98	skb_find_text
++EXPORT_SYMBOL vmlinux 0x01f1e5f5	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x01f5daff	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0x01fa92fc	posix_acl_fix_xattr_userns
++EXPORT_SYMBOL vmlinux 0x0216a6ee	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x021a1ac5	netif_schedule_queue
++EXPORT_SYMBOL vmlinux 0x022f16df	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x02441f33	ccw_device_tm_start_timeout_key
++EXPORT_SYMBOL vmlinux 0x024bf827	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0x025443d9	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0x02561274	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x0271b6aa	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02a8e63e	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0x02b8f25c	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0x02ca22a8	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0x02ce53b3	free_user_ns
++EXPORT_SYMBOL vmlinux 0x02ea111e	scsi_driverbyte_string
++EXPORT_SYMBOL vmlinux 0x02f171c8	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0x030de082	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x0310a977	do_SAK
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x03356d6c	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x03498156	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x0352d9ad	skb_copy
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x03746fed	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x0388a5d8	idr_init
++EXPORT_SYMBOL vmlinux 0x038e5f9e	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x03a17df7	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x03b15674	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x03cd5d0d	tsb_init
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x04224a92	kill_bdev
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x042612fa	inet6_offloads
++EXPORT_SYMBOL vmlinux 0x0435f26d	lowcore_ptr
++EXPORT_SYMBOL vmlinux 0x0436a92e	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x046c447c	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x046c8dc0	set_binfmt
++EXPORT_SYMBOL vmlinux 0x04810ea5	down_killable
++EXPORT_SYMBOL vmlinux 0x04927208	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x049b26c4	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0x04a17678	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x04bc547c	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0x04cfadbf	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x050b2102	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x052c606c	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x05351c2e	scsi_init_io
++EXPORT_SYMBOL vmlinux 0x05568224	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x0560dc39	register_gifconf
++EXPORT_SYMBOL vmlinux 0x057c4ea5	lockref_get_or_lock
++EXPORT_SYMBOL vmlinux 0x058dfaa6	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0x05934f30	d_walk
++EXPORT_SYMBOL vmlinux 0x05b04cb9	scsi_vpd_tpg_id
++EXPORT_SYMBOL vmlinux 0x05b1ff3e	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0x05cca74d	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0x05d59a7a	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x05dfe463	ipv6_chk_addr_and_flags
++EXPORT_SYMBOL vmlinux 0x05ed7d6d	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x05f3d198	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x05f872e1	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0x06026d3b	sg_copy_buffer
++EXPORT_SYMBOL vmlinux 0x060abd72	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x0641d8de	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x066e8345	lockref_get
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x06a485f2	__krealloc
++EXPORT_SYMBOL vmlinux 0x06aec6a5	console_stop
++EXPORT_SYMBOL vmlinux 0x06ccd967	get_mm_exe_file
++EXPORT_SYMBOL vmlinux 0x06d99939	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x06ea7e78	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x06ed7b77	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x070589de	alloc_skb_with_frags
++EXPORT_SYMBOL vmlinux 0x070e902f	file_path
++EXPORT_SYMBOL vmlinux 0x07134e12	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0x071c2c5d	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x07297511	crc_t10dif_update
++EXPORT_SYMBOL vmlinux 0x07600625	dev_activate
++EXPORT_SYMBOL vmlinux 0x079cd1b0	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x07a4b576	flex_array_free
++EXPORT_SYMBOL vmlinux 0x07a9ef84	release_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x07b850bf	thaw_bdev
++EXPORT_SYMBOL vmlinux 0x07bc85f2	follow_pfn
++EXPORT_SYMBOL vmlinux 0x07c20ee0	configfs_register_group
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07d52b5e	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x07e91433	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x07f4146c	inet6_getname
++EXPORT_SYMBOL vmlinux 0x08044d6f	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x0821fcc0	compat_ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x0835cf21	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0x08707cdd	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x088a1518	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x08a62f81	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x08ace69e	register_external_irq
++EXPORT_SYMBOL vmlinux 0x08c60e76	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0x08d13eb0	set_cached_acl
++EXPORT_SYMBOL vmlinux 0x09576f93	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x09580deb	init_timer_key
++EXPORT_SYMBOL vmlinux 0x09690c82	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0x0971b441	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0x0975ddb5	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x097667df	lru_cache_add_file
++EXPORT_SYMBOL vmlinux 0x097effe6	security_path_truncate
++EXPORT_SYMBOL vmlinux 0x098ab1fa	neigh_destroy
++EXPORT_SYMBOL vmlinux 0x098dd952	request_key
++EXPORT_SYMBOL vmlinux 0x09915f70	udp_table
++EXPORT_SYMBOL vmlinux 0x09bbb488	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c754b2	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09e12aad	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0x09f5ed20	default_llseek
++EXPORT_SYMBOL vmlinux 0x0a02a049	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0x0a4873f9	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x0a57863e	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x0a66b7b3	inet_proto_csum_replace_by_diff
++EXPORT_SYMBOL vmlinux 0x0a6881d2	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x0a770832	register_memory_notifier
++EXPORT_SYMBOL vmlinux 0x0a899bed	nvm_get_blk
++EXPORT_SYMBOL vmlinux 0x0aa069e1	single_open
++EXPORT_SYMBOL vmlinux 0x0aa309cf	synchronize_hardirq
++EXPORT_SYMBOL vmlinux 0x0aacd352	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x0ab9ea47	nf_unregister_net_hook
++EXPORT_SYMBOL vmlinux 0x0ae0f2ed	skb_unlink
++EXPORT_SYMBOL vmlinux 0x0ae1f4be	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0x0af14ab8	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x0af7ea69	send_sig
++EXPORT_SYMBOL vmlinux 0x0afcab85	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1a9848	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b1edd75	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0x0b2cd308	pci_enable_msi_range
++EXPORT_SYMBOL vmlinux 0x0b361701	blk_put_request
++EXPORT_SYMBOL vmlinux 0x0b5f198f	nvm_unregister
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b92e75f	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0x0bae3222	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc35b06	find_inode_nowait
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bd5e482	bioset_create_nobvec
++EXPORT_SYMBOL vmlinux 0x0bec138c	crypto_sha512_finup
++EXPORT_SYMBOL vmlinux 0x0c196fe9	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0x0c21d019	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0x0c30cfaa	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0x0c45fc96	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x0c54919a	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x0c57a5f1	udp_add_offload
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c5f2a5b	idr_get_next
++EXPORT_SYMBOL vmlinux 0x0c7cf7c6	zero_page_mask
++EXPORT_SYMBOL vmlinux 0x0c8610af	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0x0c932c4d	inode_init_always
++EXPORT_SYMBOL vmlinux 0x0c98fa49	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x0ca8bd4b	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cc1270e	iucv_root
++EXPORT_SYMBOL vmlinux 0x0cceac6c	iommu_tbl_range_free
++EXPORT_SYMBOL vmlinux 0x0d07a3a9	kfree_skb
++EXPORT_SYMBOL vmlinux 0x0d15fa77	debug_register_view
++EXPORT_SYMBOL vmlinux 0x0d3a2057	scsi_device_get
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d5cf5f8	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0x0d61eeee	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x0d6285e7	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x0d64ecb1	blk_mq_stop_hw_queues
++EXPORT_SYMBOL vmlinux 0x0d8f83ae	skb_clone
++EXPORT_SYMBOL vmlinux 0x0d949093	set_device_ro
++EXPORT_SYMBOL vmlinux 0x0d94b899	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0dc9f91f	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0x0de3b14a	release_sock
++EXPORT_SYMBOL vmlinux 0x0e079ac7	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x0e1c1001	blk_mq_alloc_tag_set
++EXPORT_SYMBOL vmlinux 0x0e3257d7	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x0e381f36	mount_subtree
++EXPORT_SYMBOL vmlinux 0x0e5d113d	__check_sticky
++EXPORT_SYMBOL vmlinux 0x0e6d0c2b	kern_path_create
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0ea763c3	sclp_sync_wait
++EXPORT_SYMBOL vmlinux 0x0eab56fa	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0x0edc221e	setattr_copy
++EXPORT_SYMBOL vmlinux 0x0eeb6c28	lro_flush_all
++EXPORT_SYMBOL vmlinux 0x0efcbb1b	set_current_groups
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f6a3b5c	string_get_size
++EXPORT_SYMBOL vmlinux 0x0f7a0da5	make_flow_keys_digest
++EXPORT_SYMBOL vmlinux 0x0f9bc5bd	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb2f8a4	mktime64
++EXPORT_SYMBOL vmlinux 0x0fba6d33	dst_discard_out
++EXPORT_SYMBOL vmlinux 0x0fc2d71f	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x0fd07093	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0x0fe87a9f	debug_register
++EXPORT_SYMBOL vmlinux 0x0ffff76b	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0x101dbe7b	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0x10497616	memweight
++EXPORT_SYMBOL vmlinux 0x1054e732	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x105b633a	sock_create
++EXPORT_SYMBOL vmlinux 0x10693979	I_BDEV
++EXPORT_SYMBOL vmlinux 0x107e5878	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x108b4a8c	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0x10950ee1	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x10b48312	unload_nls
++EXPORT_SYMBOL vmlinux 0x10cc3d75	xfrm_state_lookup_byspi
++EXPORT_SYMBOL vmlinux 0x10cee4e4	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0x10e94a5d	configfs_unregister_subsystem
++EXPORT_SYMBOL vmlinux 0x10f2eb76	vsnprintf
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x1115e9ab	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x111c84ab	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x1135467c	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x11401beb	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x1168c994	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x119909ea	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0x11a044f6	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x11a2ee07	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x11b59e8a	proc_remove
++EXPORT_SYMBOL vmlinux 0x11d6b8fd	sock_efree
++EXPORT_SYMBOL vmlinux 0x11ed2eb8	sclp_remove_processed
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120d67d4	unregister_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0x120fc6b1	kstrdup_const
++EXPORT_SYMBOL vmlinux 0x121cf32a	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x1236c5f9	netpoll_poll_disable
++EXPORT_SYMBOL vmlinux 0x123ebfc0	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x123f82f3	getrawmonotonic64
++EXPORT_SYMBOL vmlinux 0x1250e9d7	generic_write_checks
++EXPORT_SYMBOL vmlinux 0x1251a12e	console_mode
++EXPORT_SYMBOL vmlinux 0x12542c4d	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x12981c34	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12dcef33	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0x12e5e0d7	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0x12f8cec5	skb_trim
++EXPORT_SYMBOL vmlinux 0x1318d39c	misc_register
++EXPORT_SYMBOL vmlinux 0x1319449d	secure_modules
++EXPORT_SYMBOL vmlinux 0x131b6e14	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x1322446f	put_filp
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x13315729	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0x133a48cf	from_kgid
++EXPORT_SYMBOL vmlinux 0x1348e0fa	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x136fea83	generic_permission
++EXPORT_SYMBOL vmlinux 0x13738e23	pcie_set_mps
++EXPORT_SYMBOL vmlinux 0x13a349f5	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0x13cd659e	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13d88a4a	seq_dentry
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x13faf009	dquot_enable
++EXPORT_SYMBOL vmlinux 0x1404c0de	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x1410d804	ccw_device_get_id
++EXPORT_SYMBOL vmlinux 0x142c2a1a	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0x142c5397	nvm_addr_to_generic_mode
++EXPORT_SYMBOL vmlinux 0x1432b1a3	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0x14407cec	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x1467cad2	inet_addr_type_dev_table
++EXPORT_SYMBOL vmlinux 0x14757499	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0x14802b4c	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0x14875243	irq_set_chip
++EXPORT_SYMBOL vmlinux 0x148f070a	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0x14af3a7f	simple_open
++EXPORT_SYMBOL vmlinux 0x14c5e5b3	segment_warning
++EXPORT_SYMBOL vmlinux 0x14cee223	kvasprintf_const
++EXPORT_SYMBOL vmlinux 0x14ed6025	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x1549f1d8	bio_reset
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x1568c9a2	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0x15703d64	dm_kobject_release
++EXPORT_SYMBOL vmlinux 0x1591c173	block_commit_write
++EXPORT_SYMBOL vmlinux 0x15bafe29	unregister_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0x15db2927	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x15e3de58	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x16065a2c	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x1617ee2b	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x162896b4	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x162c1f1e	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0x1633e06d	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x1660de32	default_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x1665aeb1	filp_open
++EXPORT_SYMBOL vmlinux 0x16861546	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0x168f8857	skb_checksum_setup
++EXPORT_SYMBOL vmlinux 0x1694928d	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x169b7aee	unregister_adapter_interrupt
++EXPORT_SYMBOL vmlinux 0x16c3add5	scsi_print_result
++EXPORT_SYMBOL vmlinux 0x16ca6ab7	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0x16d65eb0	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0x16e297c3	bit_wait
++EXPORT_SYMBOL vmlinux 0x16e3c791	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0x17124335	__brelse
++EXPORT_SYMBOL vmlinux 0x1718f0ec	sock_kzfree_s
++EXPORT_SYMBOL vmlinux 0x171d0960	blk_mq_start_hw_queues
++EXPORT_SYMBOL vmlinux 0x1726389f	tty_register_device
++EXPORT_SYMBOL vmlinux 0x175b506e	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0x175c3181	from_kgid_munged
++EXPORT_SYMBOL vmlinux 0x176aec96	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x176ea2b6	f_setown
++EXPORT_SYMBOL vmlinux 0x1793f685	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0x17a142df	__copy_from_user
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17c1735f	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x17e05223	raw3270_del_view
++EXPORT_SYMBOL vmlinux 0x181d1a79	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x1829d188	wait_woken
++EXPORT_SYMBOL vmlinux 0x18334061	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x188c0401	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x189b6bac	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x18b87cca	sclp_deactivate
++EXPORT_SYMBOL vmlinux 0x18bf6d5c	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x18c0607d	compat_mc_setsockopt
++EXPORT_SYMBOL vmlinux 0x18c44cd7	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0x18d39d9b	__neigh_create
++EXPORT_SYMBOL vmlinux 0x18dda227	vfs_statfs
++EXPORT_SYMBOL vmlinux 0x18e4f6a6	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x18e60984	__do_once_start
++EXPORT_SYMBOL vmlinux 0x1913b4e7	param_get_long
++EXPORT_SYMBOL vmlinux 0x1915a221	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0x191c82e7	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0x191dd89f	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0x1929abe2	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x192dbce5	seq_release_private
++EXPORT_SYMBOL vmlinux 0x19493b79	xfrm_input_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x195818c2	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x195be1a2	pci_iomap
++EXPORT_SYMBOL vmlinux 0x1963fe81	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19c6bb09	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0x1a032f56	__blk_end_request
++EXPORT_SYMBOL vmlinux 0x1a0b87b4	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x1a0de74f	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x1a29c107	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x1a52392a	freeze_bdev
++EXPORT_SYMBOL vmlinux 0x1a526932	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x1a9a645d	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x1ab9ecdc	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x1ac6c0a9	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x1af28809	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b216d6b	__alloc_skb
++EXPORT_SYMBOL vmlinux 0x1b624e5e	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b84c30b	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0x1bb07a42	lz4_decompress
++EXPORT_SYMBOL vmlinux 0x1bb31047	add_timer
++EXPORT_SYMBOL vmlinux 0x1bc13450	inet_listen
++EXPORT_SYMBOL vmlinux 0x1bc1592d	kernel_write
++EXPORT_SYMBOL vmlinux 0x1bced360	pci_iomap_range
++EXPORT_SYMBOL vmlinux 0x1bfa76d8	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x1c0ef69d	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x1c114a6a	vm_event_states
++EXPORT_SYMBOL vmlinux 0x1c1a583c	do_splice_from
++EXPORT_SYMBOL vmlinux 0x1c1c74c7	iucv_message_receive
++EXPORT_SYMBOL vmlinux 0x1c1dbfc9	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0x1c61b587	raw3270_start
++EXPORT_SYMBOL vmlinux 0x1c80de9c	ip_send_check
++EXPORT_SYMBOL vmlinux 0x1cbf6e94	flow_cache_init
++EXPORT_SYMBOL vmlinux 0x1cd5740f	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x1ceb97a4	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0x1cee8254	release_firmware
++EXPORT_SYMBOL vmlinux 0x1d1f2cd4	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x1d243afa	pci_save_state
++EXPORT_SYMBOL vmlinux 0x1d58749d	path_is_under
++EXPORT_SYMBOL vmlinux 0x1d68266d	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x1d69298d	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0x1d9334cb	__bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x1da294d3	trace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x1df7eaf5	copy_page_from_iter
++EXPORT_SYMBOL vmlinux 0x1dfd16c8	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e3b5df3	arp_send
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e78414d	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0x1e840adc	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0x1e8a161a	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1eba1b2f	dqput
++EXPORT_SYMBOL vmlinux 0x1ef80d82	lwtunnel_input
++EXPORT_SYMBOL vmlinux 0x1f0c2665	blk_rq_init
++EXPORT_SYMBOL vmlinux 0x1f272d75	param_ops_ullong
++EXPORT_SYMBOL vmlinux 0x1f2b9bb2	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0x1f48e77c	__hw_addr_unsync_dev
++EXPORT_SYMBOL vmlinux 0x1f538a4d	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x1f61b15e	ccw_driver_register
++EXPORT_SYMBOL vmlinux 0x1f62eed0	d_tmpfile
++EXPORT_SYMBOL vmlinux 0x1fa33028	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0x1fb22aae	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fe66460	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x200b2041	in6addr_any
++EXPORT_SYMBOL vmlinux 0x2034a5fe	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x205f4d9f	sclp_unregister
++EXPORT_SYMBOL vmlinux 0x206d23f5	iucv_if
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x20973b94	segment_unload
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20ad068a	d_obtain_root
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20ca3cac	sock_create_kern
++EXPORT_SYMBOL vmlinux 0x20e04f6b	netdev_notice
++EXPORT_SYMBOL vmlinux 0x20ecd82f	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0x20fb9236	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x21152d90	kthread_stop
++EXPORT_SYMBOL vmlinux 0x211f68f1	getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x216210ed	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0x21697a21	iucv_message_reject
++EXPORT_SYMBOL vmlinux 0x21dbe59e	blk_mq_free_tag_set
++EXPORT_SYMBOL vmlinux 0x21df74d9	bitmap_set
++EXPORT_SYMBOL vmlinux 0x21e225f3	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0x21eb5b00	sclp_cpi_set_data
++EXPORT_SYMBOL vmlinux 0x221a4401	module_layout
++EXPORT_SYMBOL vmlinux 0x222b3476	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0x222c1add	kobject_get
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x224cb332	down
++EXPORT_SYMBOL vmlinux 0x226413c0	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x226b08a4	idr_is_empty
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x2285961a	bdget
++EXPORT_SYMBOL vmlinux 0x2294b44f	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0x22ac1d06	raw3270_request_set_data
++EXPORT_SYMBOL vmlinux 0x22c1a316	locks_init_lock
++EXPORT_SYMBOL vmlinux 0x22ea6a3f	__generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x22ecf082	idr_remove
++EXPORT_SYMBOL vmlinux 0x23019008	generic_writepages
++EXPORT_SYMBOL vmlinux 0x230fe8b8	account_page_redirty
++EXPORT_SYMBOL vmlinux 0x2365ede7	__irq_regs
++EXPORT_SYMBOL vmlinux 0x236c8c64	memcpy
++EXPORT_SYMBOL vmlinux 0x2389ab67	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23ae70c7	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23d2db96	lockref_mark_dead
++EXPORT_SYMBOL vmlinux 0x23df0574	d_rehash
++EXPORT_SYMBOL vmlinux 0x23e30fe2	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x23ed9f04	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x242f3562	irq_subclass_register
++EXPORT_SYMBOL vmlinux 0x2438387f	tccb_add_dcw
++EXPORT_SYMBOL vmlinux 0x24393601	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x24507258	page_waitqueue
++EXPORT_SYMBOL vmlinux 0x24555ca9	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x2472188e	__percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x248678cc	inode_set_flags
++EXPORT_SYMBOL vmlinux 0x24a5a552	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x24d0c082	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x24d6b708	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x24eb356e	save_mount_options
++EXPORT_SYMBOL vmlinux 0x24ec50c2	__hw_addr_sync_dev
++EXPORT_SYMBOL vmlinux 0x24f54790	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0x24fbd9cb	airq_iv_release
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x25000494	dquot_release
++EXPORT_SYMBOL vmlinux 0x25400fd2	generic_setlease
++EXPORT_SYMBOL vmlinux 0x254201c0	_dev_info
++EXPORT_SYMBOL vmlinux 0x2560d44c	pcie_get_minimum_link
++EXPORT_SYMBOL vmlinux 0x257fe0c0	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x25a62109	iterate_mounts
++EXPORT_SYMBOL vmlinux 0x25b7c4be	scmd_printk
++EXPORT_SYMBOL vmlinux 0x25c3553c	devm_request_resource
++EXPORT_SYMBOL vmlinux 0x25cd6115	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x25e8ed29	sg_nents_for_len
++EXPORT_SYMBOL vmlinux 0x25e9d4bd	resource_list_free
++EXPORT_SYMBOL vmlinux 0x25ead659	class3270
++EXPORT_SYMBOL vmlinux 0x25ec1b28	strlen
++EXPORT_SYMBOL vmlinux 0x25f1fe49	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x2629b28f	md_flush_request
++EXPORT_SYMBOL vmlinux 0x262b29f4	skb_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x26336034	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x264d38ee	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x268006be	init_buffer
++EXPORT_SYMBOL vmlinux 0x26971ce3	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x26ab88dd	memcg_socket_limit_enabled
++EXPORT_SYMBOL vmlinux 0x26e298e0	unregister_memory_notifier
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26f9e4ca	inode_reclaim_rsv_space
++EXPORT_SYMBOL vmlinux 0x26fa50c0	complete
++EXPORT_SYMBOL vmlinux 0x2733ac1a	ccw_device_clear_options
++EXPORT_SYMBOL vmlinux 0x27463739	acl_by_type
++EXPORT_SYMBOL vmlinux 0x27479d14	param_free_charp
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x275b7ec9	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0x2765d85c	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x2773b358	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x2782456c	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27866435	security_xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x2793b29e	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x2798d25a	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x27affedf	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27ca4199	ip_defrag
++EXPORT_SYMBOL vmlinux 0x27cfb890	init_special_inode
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x27e4019b	bioset_free
++EXPORT_SYMBOL vmlinux 0x27e9ade7	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x27f164d8	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x2808a727	put_disk
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x282e7e7a	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0x28343bad	scnprintf
++EXPORT_SYMBOL vmlinux 0x283a27b8	generic_readlink
++EXPORT_SYMBOL vmlinux 0x2843c643	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0x285ed7ff	generic_end_io_acct
++EXPORT_SYMBOL vmlinux 0x289ae4dc	keyring_alloc
++EXPORT_SYMBOL vmlinux 0x28a2b29f	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28d88ccc	end_page_writeback
++EXPORT_SYMBOL vmlinux 0x28da6989	skb_store_bits
++EXPORT_SYMBOL vmlinux 0x290d4014	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x2913843c	security_path_unlink
++EXPORT_SYMBOL vmlinux 0x291f30d8	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0x29242e44	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x292ac45e	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x29391e7d	vm_munmap
++EXPORT_SYMBOL vmlinux 0x293e406f	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0x294b327e	inet_release
++EXPORT_SYMBOL vmlinux 0x294b53a1	ccw_device_tm_start_timeout
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x2977a7de	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0x29789394	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x299947f2	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0x29b2279e	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x29bd3934	sock_edemux
++EXPORT_SYMBOL vmlinux 0x29be53d4	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0x29cc3a1a	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0x29e82508	__skb_checksum
++EXPORT_SYMBOL vmlinux 0x29ec188f	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0x29f800f1	current_fs_time
++EXPORT_SYMBOL vmlinux 0x29f8fbfb	neigh_proc_dointvec
++EXPORT_SYMBOL vmlinux 0x2a1c876e	ilookup5
++EXPORT_SYMBOL vmlinux 0x2a33ef40	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0x2a35456f	setup_new_exec
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a7164da	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x2a905f2b	follow_down_one
++EXPORT_SYMBOL vmlinux 0x2a92e478	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0x2aa22a3a	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x2aad2651	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x2aad35de	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x2accd249	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0x2ace5a18	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x2acf0feb	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x2ae08579	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b1c0d6c	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b4e0529	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0x2b658a1f	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x2b868385	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x2b86a583	__frontswap_test
++EXPORT_SYMBOL vmlinux 0x2b996d01	generic_make_request
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2bc9fc8f	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0x2bd8d2ac	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0x2be753fc	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x2bf126b2	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x2c231c04	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0x2c29a995	__strnlen_user
++EXPORT_SYMBOL vmlinux 0x2c458e9c	tcw_add_tidaw
++EXPORT_SYMBOL vmlinux 0x2c4925bc	padata_alloc
++EXPORT_SYMBOL vmlinux 0x2c4f2791	lwtunnel_output
++EXPORT_SYMBOL vmlinux 0x2c764542	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x2c7a7c9f	dm_put_device
++EXPORT_SYMBOL vmlinux 0x2c897734	tcw_get_tsb
++EXPORT_SYMBOL vmlinux 0x2ca50563	blk_mq_delay_queue
++EXPORT_SYMBOL vmlinux 0x2caf780f	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0x2cbaa35c	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0x2cfba164	seq_read
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d14fd2e	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0x2d1bea57	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x2d30596c	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0x2d32dd23	init_net
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d411820	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x2d5528c9	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x2d5c0f89	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0x2d5f7444	from_kprojid
++EXPORT_SYMBOL vmlinux 0x2d61eedd	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0x2d79c8ce	inet_offloads
++EXPORT_SYMBOL vmlinux 0x2d7a4253	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0x2d7f1a4f	udplite_prot
++EXPORT_SYMBOL vmlinux 0x2d899743	single_release
++EXPORT_SYMBOL vmlinux 0x2d9a3f78	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x2dbb9241	ida_init
++EXPORT_SYMBOL vmlinux 0x2dbe76a6	__skb_gro_checksum_complete
++EXPORT_SYMBOL vmlinux 0x2dbf0090	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0x2dd95f77	iget_failed
++EXPORT_SYMBOL vmlinux 0x2dd9a36b	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x2ddb1ec0	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0x2e0d2f7f	queue_work_on
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e427069	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x2e593a27	timespec64_to_jiffies
++EXPORT_SYMBOL vmlinux 0x2e7ceb2c	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x2e8abdeb	proc_douintvec
++EXPORT_SYMBOL vmlinux 0x2e8b6609	register_qdisc
++EXPORT_SYMBOL vmlinux 0x2e92cc73	set_anon_super
++EXPORT_SYMBOL vmlinux 0x2ea17820	generic_key_instantiate
++EXPORT_SYMBOL vmlinux 0x2ec57297	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x2eedb414	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0x2ef5661d	segment_modify_shared
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2efc102f	tcw_set_data
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f0ec65a	simple_write_end
++EXPORT_SYMBOL vmlinux 0x2f225f05	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x2f328c32	udp_set_csum
++EXPORT_SYMBOL vmlinux 0x2f3fa4f4	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x2f463da1	__alloc_page_frag
++EXPORT_SYMBOL vmlinux 0x2f521c33	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0x2f6b0d13	kset_unregister
++EXPORT_SYMBOL vmlinux 0x2f785210	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0x2fa5a500	memcmp
++EXPORT_SYMBOL vmlinux 0x2fada814	forget_all_cached_acls
++EXPORT_SYMBOL vmlinux 0x2fb3750c	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fd54f84	pcie_get_mps
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2ffffb6f	_ebc_tolower
++EXPORT_SYMBOL vmlinux 0x3001f97e	__genl_register_family
++EXPORT_SYMBOL vmlinux 0x3010310e	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0x302f4d78	send_sig_info
++EXPORT_SYMBOL vmlinux 0x303041c6	udp_flow_hashrnd
++EXPORT_SYMBOL vmlinux 0x303f25fd	get_fs_type
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x3094e50e	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x3096be16	names_cachep
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x30f9c886	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0x30fa617f	pci_disable_device
++EXPORT_SYMBOL vmlinux 0x31010eac	__crypto_memneq
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310dd0b4	__scm_send
++EXPORT_SYMBOL vmlinux 0x31436289	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3151fa8a	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x3174bd79	bitmap_clear
++EXPORT_SYMBOL vmlinux 0x31839543	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0x3198f424	dev_close
++EXPORT_SYMBOL vmlinux 0x31b412dd	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x31be129f	scsi_host_get
++EXPORT_SYMBOL vmlinux 0x31dd2b5d	bdi_register
++EXPORT_SYMBOL vmlinux 0x31e00aa8	ping_prot
++EXPORT_SYMBOL vmlinux 0x31f8ecaa	ccw_device_resume
++EXPORT_SYMBOL vmlinux 0x321b982d	idr_replace
++EXPORT_SYMBOL vmlinux 0x3221bd3f	raw3270_request_set_idal
++EXPORT_SYMBOL vmlinux 0x3238a155	rename_lock
++EXPORT_SYMBOL vmlinux 0x32507b6c	flow_get_u32_src
++EXPORT_SYMBOL vmlinux 0x327256a1	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x3275689f	smp_ctl_set_bit
++EXPORT_SYMBOL vmlinux 0x32c0aa57	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x32c6a2d8	_ebcasc_500
++EXPORT_SYMBOL vmlinux 0x32debb16	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x32f05f74	ccw_device_get_mdc
++EXPORT_SYMBOL vmlinux 0x32f40ab9	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0x32f9c768	unregister_external_irq
++EXPORT_SYMBOL vmlinux 0x3312c40a	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0x331d9679	configfs_undepend_item
++EXPORT_SYMBOL vmlinux 0x334b75e4	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x33696161	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x336f6559	sock_dequeue_err_skb
++EXPORT_SYMBOL vmlinux 0x338bbef8	__ndelay
++EXPORT_SYMBOL vmlinux 0x3391d22a	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0x33970da4	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x3397e364	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x33bee020	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x33c574d5	filp_close
++EXPORT_SYMBOL vmlinux 0x33c7435c	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x33c8e4a5	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x33cb4353	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0x33f74de3	_ascebc_500
++EXPORT_SYMBOL vmlinux 0x33faa6a8	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x341124aa	key_unlink
++EXPORT_SYMBOL vmlinux 0x34154784	debug_sprintf_view
++EXPORT_SYMBOL vmlinux 0x341cbed2	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x342c0597	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x34463ed5	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0x344adbd5	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x3465caa3	cpu_maps_update_begin
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x349eb6f6	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x34c1fd53	vfs_link
++EXPORT_SYMBOL vmlinux 0x34cd00ae	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x34ce3a78	debug_unregister
++EXPORT_SYMBOL vmlinux 0x34e9644b	sk_capable
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x34fada2b	raw3270_reset
++EXPORT_SYMBOL vmlinux 0x34fbab52	seq_pad
++EXPORT_SYMBOL vmlinux 0x35131e78	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x351df49b	__free_pages
++EXPORT_SYMBOL vmlinux 0x353635fa	register_filesystem
++EXPORT_SYMBOL vmlinux 0x3558fa24	crc32_be
++EXPORT_SYMBOL vmlinux 0x356a915d	ccw_device_clear
++EXPORT_SYMBOL vmlinux 0x3579921d	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x3581422e	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x358c27ef	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x359488ed	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0x3596473c	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0x35a88f28	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x35dfd845	bdi_init
++EXPORT_SYMBOL vmlinux 0x3602aba9	raw3270_register_notifier
++EXPORT_SYMBOL vmlinux 0x36060ef7	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0x361af84f	scsi_change_queue_depth
++EXPORT_SYMBOL vmlinux 0x361b6a83	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0x363c067b	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0x36467f88	__debug_sprintf_event
++EXPORT_SYMBOL vmlinux 0x36718ee4	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x36bd681b	groups_alloc
++EXPORT_SYMBOL vmlinux 0x36c9ff8c	key_task_permission
++EXPORT_SYMBOL vmlinux 0x36cb7eff	netdev_info
++EXPORT_SYMBOL vmlinux 0x36d14b75	seq_open_private
++EXPORT_SYMBOL vmlinux 0x36d39222	kernel_accept
++EXPORT_SYMBOL vmlinux 0x36d5e2c6	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0x370ac991	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0x37140153	compat_sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x3718c116	arch_lock_relax
++EXPORT_SYMBOL vmlinux 0x3743705e	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x376119d2	simple_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x3774c96c	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0x377dd269	dst_init
++EXPORT_SYMBOL vmlinux 0x37a40497	sock_release
++EXPORT_SYMBOL vmlinux 0x37af3190	dm_table_run_md_queue_async
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37c708a1	blk_init_queue
++EXPORT_SYMBOL vmlinux 0x37ccdb51	__sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x37d750c0	freeze_super
++EXPORT_SYMBOL vmlinux 0x37d8ab03	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0x37ff4c06	copy_from_user_overflow
++EXPORT_SYMBOL vmlinux 0x380a9956	kbd_free
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x385cba7f	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x385e5050	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0x387860f9	skb_vlan_pop
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x389bd0cc	config_item_put
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38a9f7c5	in6addr_loopback
++EXPORT_SYMBOL vmlinux 0x38b9b6e6	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0x38d1848c	inet_ioctl
++EXPORT_SYMBOL vmlinux 0x38df0543	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x39047373	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x3928efe9	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x3936c3d1	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x39461d6a	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x39674697	ccw_device_set_online
++EXPORT_SYMBOL vmlinux 0x3982961b	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0x3983df29	pci_set_master
++EXPORT_SYMBOL vmlinux 0x39973b13	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x39991865	icmp_global_allow
++EXPORT_SYMBOL vmlinux 0x399d05b8	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x39b52d19	__bitmap_and
++EXPORT_SYMBOL vmlinux 0x39d03e88	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0x39d76fb9	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x39e1c350	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x39ff5470	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0x3a22b55b	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x3a297029	unregister_key_type
++EXPORT_SYMBOL vmlinux 0x3a393593	md_write_end
++EXPORT_SYMBOL vmlinux 0x3a442c0e	migrate_page
++EXPORT_SYMBOL vmlinux 0x3a4c285b	kernel_bind
++EXPORT_SYMBOL vmlinux 0x3a628326	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0x3a8e08bb	itcw_add_dcw
++EXPORT_SYMBOL vmlinux 0x3a9606df	simple_getattr
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3aa11bd1	_raw_read_lock_wait
++EXPORT_SYMBOL vmlinux 0x3aa75614	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0x3ab4140c	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0x3ab41b25	__copy_in_user
++EXPORT_SYMBOL vmlinux 0x3ab7b6f1	__vfs_read
++EXPORT_SYMBOL vmlinux 0x3abc1459	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0x3ada3ddc	inode_init_once
++EXPORT_SYMBOL vmlinux 0x3b052a0b	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0x3b0d12fa	blk_mq_stop_hw_queue
++EXPORT_SYMBOL vmlinux 0x3b1bf350	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0x3b3e566b	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0x3b3f8bc3	__devm_release_region
++EXPORT_SYMBOL vmlinux 0x3b46c4b0	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x3b4f5724	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x3b5638dc	complete_request_key
++EXPORT_SYMBOL vmlinux 0x3b644591	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x3b692424	nvm_generic_to_addr_mode
++EXPORT_SYMBOL vmlinux 0x3b7611c7	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0x3b7aa2f4	t10_pi_type1_ip
++EXPORT_SYMBOL vmlinux 0x3b81e0b6	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0x3b95c1dc	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0x3b965c4a	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x3b9ba685	pci_bus_type
++EXPORT_SYMBOL vmlinux 0x3ba1b0d3	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x3bb4fb49	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0x3be6d10c	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0x3c0b4eee	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0x3c3478aa	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0x3c3fce39	__local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0x3c457ccb	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0x3c483012	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x3c4cb9e4	netif_tx_wake_queue
++EXPORT_SYMBOL vmlinux 0x3c500bb6	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0x3c705a43	ccw_device_start_timeout
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c866656	dst_release
++EXPORT_SYMBOL vmlinux 0x3c8b6aa3	md_register_thread
++EXPORT_SYMBOL vmlinux 0x3caa6bef	param_set_ulong
++EXPORT_SYMBOL vmlinux 0x3cd18150	skb_clone_sk
++EXPORT_SYMBOL vmlinux 0x3ce30011	simple_rename
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3cf558e0	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0x3d07f40a	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x3d117a60	itcw_calc_size
++EXPORT_SYMBOL vmlinux 0x3d3a9854	md_cluster_ops
++EXPORT_SYMBOL vmlinux 0x3d4e6598	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0x3d528fc8	pipe_lock
++EXPORT_SYMBOL vmlinux 0x3d6caee3	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0x3da3da18	__getblk_slow
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3dd734b6	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e2feb1d	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0x3e83760a	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e96f9a2	register_sysctl
++EXPORT_SYMBOL vmlinux 0x3e9910f2	param_get_byte
++EXPORT_SYMBOL vmlinux 0x3ea99125	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0x3eaefab8	blk_mq_kick_requeue_list
++EXPORT_SYMBOL vmlinux 0x3f23f83d	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f7222f6	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0x3f776d14	check_disk_change
++EXPORT_SYMBOL vmlinux 0x3f8337da	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x3fa913da	strspn
++EXPORT_SYMBOL vmlinux 0x3fb0b9e3	__udelay
++EXPORT_SYMBOL vmlinux 0x3fb58b6d	up
++EXPORT_SYMBOL vmlinux 0x3fdab8d1	dump_page
++EXPORT_SYMBOL vmlinux 0x3fe65c4c	dm_io
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x400b8ab5	inc_nlink
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x40335902	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x40469cb2	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0x404c750b	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40b26999	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x40be2a8e	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0x40c66228	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40cb714b	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d59096	unregister_restart_handler
++EXPORT_SYMBOL vmlinux 0x40e6df69	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x40ef74e9	skb_coalesce_rx_frag
++EXPORT_SYMBOL vmlinux 0x40f6a2fd	napi_complete_done
++EXPORT_SYMBOL vmlinux 0x40fccd91	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0x41081802	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0x413d903c	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x4155acfc	qdisc_tree_reduce_backlog
++EXPORT_SYMBOL vmlinux 0x41609a7a	sysctl_ibpb_enabled
++EXPORT_SYMBOL vmlinux 0x416690eb	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0x417652f8	__d_drop
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x4198a4bd	finish_open
++EXPORT_SYMBOL vmlinux 0x41a01442	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x41b52e9a	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x41b6d63e	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0x41baf194	t10_pi_type3_ip
++EXPORT_SYMBOL vmlinux 0x41d5f0d1	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0x41df696c	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0x4211f85a	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL vmlinux 0x421c4d6a	key_invalidate
++EXPORT_SYMBOL vmlinux 0x42285c25	udp_prot
++EXPORT_SYMBOL vmlinux 0x422e8825	csum_and_copy_to_iter
++EXPORT_SYMBOL vmlinux 0x422eda56	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x423a65b2	nvm_submit_ppa
++EXPORT_SYMBOL vmlinux 0x4248ae3c	single_task_running
++EXPORT_SYMBOL vmlinux 0x424d3620	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x428e1393	dcb_setapp
++EXPORT_SYMBOL vmlinux 0x42922bd6	pagecache_isize_extended
++EXPORT_SYMBOL vmlinux 0x42a6ebcb	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x42c9b55e	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0x42d1f25b	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0x42e535a3	tty_port_init
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x434c282b	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0x435021cb	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0x4352665e	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0x437bd1b3	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x43a4938f	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x43bdfa20	console_irq
++EXPORT_SYMBOL vmlinux 0x43cf3bc3	dql_completed
++EXPORT_SYMBOL vmlinux 0x43d9b960	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0x43e43bd8	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x43ee9774	pci_bus_put
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x445606c0	pci_enable_msix_range
++EXPORT_SYMBOL vmlinux 0x447068f1	dump_align
++EXPORT_SYMBOL vmlinux 0x447731c0	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0x449216d5	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0x44a69777	eth_header_parse
++EXPORT_SYMBOL vmlinux 0x44aa2d50	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0x44b1d426	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0x44be415d	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44e9ad1b	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0x44f55268	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x450614f6	icmp_send
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x45530982	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x455a52b6	vfs_setpos
++EXPORT_SYMBOL vmlinux 0x45628318	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x4568c7ed	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x45a04cd3	wake_up_process
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45c92313	VMALLOC_END
++EXPORT_SYMBOL vmlinux 0x45cec08e	seq_release
++EXPORT_SYMBOL vmlinux 0x46013e72	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0x46066e5b	perf_pmu_name
++EXPORT_SYMBOL vmlinux 0x4610daf2	ip_tunnel_metadata_cnt
++EXPORT_SYMBOL vmlinux 0x46261dfd	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0x4627c108	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x4645396c	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x46571d27	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0x465c6bb9	pagecache_get_page
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x468310e6	seq_lseek
++EXPORT_SYMBOL vmlinux 0x468630e0	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x4688d689	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x46b67693	hex2bin
++EXPORT_SYMBOL vmlinux 0x46b7cb09	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x46d59f7d	smp_cpu_mt_shift
++EXPORT_SYMBOL vmlinux 0x46f46ef0	pipe_unlock
++EXPORT_SYMBOL vmlinux 0x46fe3fbb	__break_lease
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x47001d3c	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x470e5956	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0x471cd65e	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0x47379725	security_path_chown
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x4784e052	ccw_device_set_offline
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x47960870	down_write_trylock
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x47ed7aa2	__napi_schedule_irqoff
++EXPORT_SYMBOL vmlinux 0x4804e028	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0x480dfa55	blk_mq_requeue_request
++EXPORT_SYMBOL vmlinux 0x480f1ae7	netif_wake_subqueue
++EXPORT_SYMBOL vmlinux 0x48152d4a	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x4823819e	raw3270_buffer_address
++EXPORT_SYMBOL vmlinux 0x482cacd2	deactivate_super
++EXPORT_SYMBOL vmlinux 0x4896d1c2	nvm_set_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0x489865a1	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0x489ce0a8	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x48ad7014	vfs_iter_write
++EXPORT_SYMBOL vmlinux 0x48d9c25e	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x48e3106e	dqget
++EXPORT_SYMBOL vmlinux 0x48ec569e	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x4907a56d	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x49207989	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x4922141b	kill_fasync
++EXPORT_SYMBOL vmlinux 0x4924c850	_raw_write_trylock_retry
++EXPORT_SYMBOL vmlinux 0x495c96f8	posix_acl_init
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x499a173b	skb_put
++EXPORT_SYMBOL vmlinux 0x49af0077	pci_restore_state
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b21761	sk_net_capable
++EXPORT_SYMBOL vmlinux 0x49c960e7	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x49f71442	dev_close_many
++EXPORT_SYMBOL vmlinux 0x49fb2408	param_get_string
++EXPORT_SYMBOL vmlinux 0x49fe83d5	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0x4a372be5	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x4a4a3ee9	param_get_ushort
++EXPORT_SYMBOL vmlinux 0x4a54fe45	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x4a57c61c	d_invalidate
++EXPORT_SYMBOL vmlinux 0x4a694bd4	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0x4a9d650f	tty_throttle
++EXPORT_SYMBOL vmlinux 0x4ab69e59	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4acd2eec	set_page_dirty
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4af0570f	mount_ns
++EXPORT_SYMBOL vmlinux 0x4afb32ed	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b0026f4	dquot_drop
++EXPORT_SYMBOL vmlinux 0x4b0d1c2f	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x4b5814ef	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0x4b5b87a1	kill_pid
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b630390	kern_path_mountpoint
++EXPORT_SYMBOL vmlinux 0x4b72e8d7	inet_sendpage
++EXPORT_SYMBOL vmlinux 0x4b7af093	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0x4ba01dce	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x4ba6880c	eth_gro_receive
++EXPORT_SYMBOL vmlinux 0x4bb2d144	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0x4bcf2e10	textsearch_register
++EXPORT_SYMBOL vmlinux 0x4be2c440	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0x4beb7fef	security_mmap_file
++EXPORT_SYMBOL vmlinux 0x4c346a53	kvasprintf
++EXPORT_SYMBOL vmlinux 0x4c4c956e	nla_memcmp
++EXPORT_SYMBOL vmlinux 0x4c6d0010	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x4c7cb4c9	kmem_cache_size
++EXPORT_SYMBOL vmlinux 0x4c989b2c	truncate_inode_pages_final
++EXPORT_SYMBOL vmlinux 0x4c9aeae0	dev_get_phys_port_name
++EXPORT_SYMBOL vmlinux 0x4cb0fcae	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4d2c6bdb	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0x4d2f2af7	proto_unregister
++EXPORT_SYMBOL vmlinux 0x4d4e28b6	filemap_flush
++EXPORT_SYMBOL vmlinux 0x4d50cfdb	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d994d97	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4dab8e75	dquot_quotactl_sysfile_ops
++EXPORT_SYMBOL vmlinux 0x4dbf3e43	iterate_dir
++EXPORT_SYMBOL vmlinux 0x4dda726b	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4de4854d	napi_disable
++EXPORT_SYMBOL vmlinux 0x4dea1053	memchr
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4dfeb73e	nvm_put_blk_unlocked
++EXPORT_SYMBOL vmlinux 0x4e14e7ec	key_type_keyring
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e36334d	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x4e3c43bd	simple_rmdir
++EXPORT_SYMBOL vmlinux 0x4e50bd6d	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x4e68e9be	rb_next_postorder
++EXPORT_SYMBOL vmlinux 0x4e79076c	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0x4e974113	skb_copy_datagram_iter
++EXPORT_SYMBOL vmlinux 0x4ea1c130	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x4ec1a99a	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0x4ed948c4	d_set_fallthru
++EXPORT_SYMBOL vmlinux 0x4ef4f163	tccb_init
++EXPORT_SYMBOL vmlinux 0x4f134a37	register_key_type
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f1f9464	page_put_link
++EXPORT_SYMBOL vmlinux 0x4f22f0ea	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0x4f2cd1b5	__cpcmd
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f4983e3	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x4f621704	do_splice_direct
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f8d7d34	noop_fsync
++EXPORT_SYMBOL vmlinux 0x4fa10761	udp6_set_csum
++EXPORT_SYMBOL vmlinux 0x4fa3cec8	rwsem_wake
++EXPORT_SYMBOL vmlinux 0x4fc96aa6	md_error
++EXPORT_SYMBOL vmlinux 0x4fe6f244	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x4ff99d3b	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x50226456	dquot_destroy
++EXPORT_SYMBOL vmlinux 0x5023794d	raw3270_activate_view
++EXPORT_SYMBOL vmlinux 0x502b7cb2	__fib6_flush_trees
++EXPORT_SYMBOL vmlinux 0x502f0491	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x5063df40	__posix_acl_create
++EXPORT_SYMBOL vmlinux 0x50720c5f	snprintf
++EXPORT_SYMBOL vmlinux 0x50744d3a	eth_header
++EXPORT_SYMBOL vmlinux 0x508022e7	inet_frag_find
++EXPORT_SYMBOL vmlinux 0x50908266	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0x50abc73b	d_add_ci
++EXPORT_SYMBOL vmlinux 0x50b09d71	tcp_proto_cgroup
++EXPORT_SYMBOL vmlinux 0x50b7ca24	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0x50ba769a	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x50c9c195	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0x50d26d0a	have_submounts
++EXPORT_SYMBOL vmlinux 0x50ded37c	__posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x50e0f71a	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x50f0b34e	posix_acl_update_mode
++EXPORT_SYMBOL vmlinux 0x510c2535	xz_dec_run
++EXPORT_SYMBOL vmlinux 0x5111880c	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x511206bc	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x5112ae75	dget_parent
++EXPORT_SYMBOL vmlinux 0x51164ad9	cmdline_parts_set
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x5132d881	vm_map_ram
++EXPORT_SYMBOL vmlinux 0x5134657a	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0x513bdc11	prepare_creds
++EXPORT_SYMBOL vmlinux 0x516ab68f	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x51942ce2	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0x51b52abd	arp_xmit
++EXPORT_SYMBOL vmlinux 0x51c3c0e4	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0x51cd4da0	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x52115db9	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0x52125d03	kbd_keycode
++EXPORT_SYMBOL vmlinux 0x521901d4	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x522e951c	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x52497496	poll_initwait
++EXPORT_SYMBOL vmlinux 0x524a5f08	notify_change
++EXPORT_SYMBOL vmlinux 0x52847220	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x5285e33d	free_netdev
++EXPORT_SYMBOL vmlinux 0x52971547	__lock_buffer
++EXPORT_SYMBOL vmlinux 0x52a787a6	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x52d02abc	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x52d29162	elv_add_request
++EXPORT_SYMBOL vmlinux 0x530a95a0	d_instantiate_no_diralias
++EXPORT_SYMBOL vmlinux 0x530b5985	skb_vlan_push
++EXPORT_SYMBOL vmlinux 0x531132f2	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0x531cbdc5	kernel_param_lock
++EXPORT_SYMBOL vmlinux 0x531e1c4a	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0x5328b4bd	take_dentry_name_snapshot
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x535c6772	read_cache_page
++EXPORT_SYMBOL vmlinux 0x5364aed0	dev_warn
++EXPORT_SYMBOL vmlinux 0x5372b409	write_one_page
++EXPORT_SYMBOL vmlinux 0x539af73c	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x53d89549	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0x53f04062	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x53f61870	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x540862e2	diag14
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x5420a052	iov_iter_npages
++EXPORT_SYMBOL vmlinux 0x543d146b	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x5442f268	force_sig
++EXPORT_SYMBOL vmlinux 0x544cddc5	load_nls_default
++EXPORT_SYMBOL vmlinux 0x54a4ea6f	printk_emit
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54ae18ae	may_umount
++EXPORT_SYMBOL vmlinux 0x54ae5706	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x54b597f7	d_make_root
++EXPORT_SYMBOL vmlinux 0x54bedea1	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x54cb1eb0	set_bh_page
++EXPORT_SYMBOL vmlinux 0x54df1680	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x550e66d6	__dax_fault
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x55293873	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x5530a59e	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x55678b4b	bsearch
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x5596bfee	set_disk_ro
++EXPORT_SYMBOL vmlinux 0x5596c993	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x55a3f3e0	sclp_add_request
++EXPORT_SYMBOL vmlinux 0x55a79e7c	configfs_register_subsystem
++EXPORT_SYMBOL vmlinux 0x55d436e1	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x55d94fc1	inet_put_port
++EXPORT_SYMBOL vmlinux 0x55e3b2c4	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x55fbaf1d	smsg_unregister_callback
++EXPORT_SYMBOL vmlinux 0x560b168d	diag_stat_inc
++EXPORT_SYMBOL vmlinux 0x562849b6	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x564d0b95	__quota_error
++EXPORT_SYMBOL vmlinux 0x566e7a56	cookie_ecn_ok
++EXPORT_SYMBOL vmlinux 0x56790e69	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x56a99f01	__tty_insert_flip_char
++EXPORT_SYMBOL vmlinux 0x56b37ea4	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x56bddb81	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56d396fc	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x56e61e21	follow_up
++EXPORT_SYMBOL vmlinux 0x56ee4390	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0x570c3899	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x5734cc16	load_nls
++EXPORT_SYMBOL vmlinux 0x573ddae0	dev_add_offload
++EXPORT_SYMBOL vmlinux 0x574c2e74	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x57639b70	inet_addr_type_table
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x5769f3cc	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x577a0b8f	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0x5786dfcc	path_nosuid
++EXPORT_SYMBOL vmlinux 0x579955da	set_nlink
++EXPORT_SYMBOL vmlinux 0x57a8dcc8	__do_once_done
++EXPORT_SYMBOL vmlinux 0x57b76024	done_path_create
++EXPORT_SYMBOL vmlinux 0x57bb132b	copy_page_to_iter
++EXPORT_SYMBOL vmlinux 0x5810af69	netlink_net_capable
++EXPORT_SYMBOL vmlinux 0x581f98da	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x5823cdd3	completion_done
++EXPORT_SYMBOL vmlinux 0x584469b2	tty_devnum
++EXPORT_SYMBOL vmlinux 0x5847b8af	tcw_finalize
++EXPORT_SYMBOL vmlinux 0x5850ae32	__sock_create
++EXPORT_SYMBOL vmlinux 0x5852e938	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0x585cd390	netdev_change_features
++EXPORT_SYMBOL vmlinux 0x586319dc	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0x58647d17	config_group_init_type_name
++EXPORT_SYMBOL vmlinux 0x5866a757	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x587616f1	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0x58b73bc7	match_wildcard
++EXPORT_SYMBOL vmlinux 0x58cd1b54	string_escape_mem
++EXPORT_SYMBOL vmlinux 0x58d239f8	nvm_unregister_mgr
++EXPORT_SYMBOL vmlinux 0x58e3306d	bit_wait_io
++EXPORT_SYMBOL vmlinux 0x58ebb9f9	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x58f0c853	km_state_expired
++EXPORT_SYMBOL vmlinux 0x59039aee	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x5939b5a6	netdev_class_remove_file_ns
++EXPORT_SYMBOL vmlinux 0x593e3820	param_get_short
++EXPORT_SYMBOL vmlinux 0x594c7e79	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x5954ecaa	add_disk
++EXPORT_SYMBOL vmlinux 0x596d79fe	xfrm6_protocol_register
++EXPORT_SYMBOL vmlinux 0x5981975d	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x598a293d	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x598e4904	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0x59966df2	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x59aaece5	blk_run_queue
++EXPORT_SYMBOL vmlinux 0x59c9a864	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x5a19e3da	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x5a34a45c	__kmalloc
++EXPORT_SYMBOL vmlinux 0x5a4241ed	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x5a5aef12	dup_iter
++EXPORT_SYMBOL vmlinux 0x5a5e7ea3	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x5a6d7223	lease_modify
++EXPORT_SYMBOL vmlinux 0x5aeb4e2f	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0x5afc94e2	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x5b08aafe	__dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x5b0b04b5	vfs_readv
++EXPORT_SYMBOL vmlinux 0x5b188b99	sock_update_memcg
++EXPORT_SYMBOL vmlinux 0x5b27c487	module_refcount
++EXPORT_SYMBOL vmlinux 0x5b28bf5d	memremap
++EXPORT_SYMBOL vmlinux 0x5b47a58f	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x5b604bd1	segment_type
++EXPORT_SYMBOL vmlinux 0x5b7e5cc4	tcp_connect
++EXPORT_SYMBOL vmlinux 0x5b955460	vfs_getxattr_alloc
++EXPORT_SYMBOL vmlinux 0x5bae8b07	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0x5bb74cfa	trace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0x5bbff0f8	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x5bf20da3	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0x5c07d59d	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0x5c0fcd92	d_move
++EXPORT_SYMBOL vmlinux 0x5c3bd83a	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0x5c575445	unregister_service_level
++EXPORT_SYMBOL vmlinux 0x5c58e943	vfs_whiteout
++EXPORT_SYMBOL vmlinux 0x5cad5048	raw3270_deactivate_view
++EXPORT_SYMBOL vmlinux 0x5cb34030	kmem_cache_alloc_node_trace
++EXPORT_SYMBOL vmlinux 0x5cc32bdc	bitmap_copy_le
++EXPORT_SYMBOL vmlinux 0x5cca971c	cdev_add
++EXPORT_SYMBOL vmlinux 0x5cde339a	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0x5d0f86d7	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x5d11d95c	trace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x5d3a39e6	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x5d43475f	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d57f209	__skb_get_hash
++EXPORT_SYMBOL vmlinux 0x5d60dca9	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x5d61e3f9	bio_add_page
++EXPORT_SYMBOL vmlinux 0x5d6cb516	debug_event_common
++EXPORT_SYMBOL vmlinux 0x5d84ab70	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x5da21f25	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x5dbbe98e	memmove
++EXPORT_SYMBOL vmlinux 0x5dbe5093	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x5dbfb642	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0x5dc0f338	diag_stat_inc_norecursion
++EXPORT_SYMBOL vmlinux 0x5dd6c6fe	spec_ctrl_mutex
++EXPORT_SYMBOL vmlinux 0x5de1ca19	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0x5de4df4a	sock_i_uid
++EXPORT_SYMBOL vmlinux 0x5df08f8c	address_space_init_once
++EXPORT_SYMBOL vmlinux 0x5df5e340	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0x5dfe12b3	devm_memremap
++EXPORT_SYMBOL vmlinux 0x5e0148a4	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0x5e1881e0	bio_advance
++EXPORT_SYMBOL vmlinux 0x5e19f00e	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x5e2f675a	blk_get_request
++EXPORT_SYMBOL vmlinux 0x5e448a76	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0x5e68677e	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0x5e6c5de2	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x5e86171d	raw3270_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x5e89b4ce	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x5e8cc2b8	ipv6_mc_check_mld
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5e97488d	kern_unmount
++EXPORT_SYMBOL vmlinux 0x5ea0f1e0	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ec26101	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0x5ec5638e	skb_make_writable
++EXPORT_SYMBOL vmlinux 0x5edf1a4f	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x5ee3c32a	zerocopy_sg_from_iter
++EXPORT_SYMBOL vmlinux 0x5ee55110	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0x5efb8771	sock_recv_errqueue
++EXPORT_SYMBOL vmlinux 0x5efffd12	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f08bf8d	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0x5f098b2a	in6addr_interfacelocal_allrouters
++EXPORT_SYMBOL vmlinux 0x5f15f345	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0x5f1a07f1	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x5f3231ee	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x5f4b2de8	cio_irb
++EXPORT_SYMBOL vmlinux 0x5f4c73b0	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0x5f5d2c3f	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0x5f6c048b	skb_get_hash_perturb
++EXPORT_SYMBOL vmlinux 0x5f778261	raw3270_request_alloc
++EXPORT_SYMBOL vmlinux 0x5f8da53c	noop_llseek
++EXPORT_SYMBOL vmlinux 0x5f8fe173	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x5fac6e24	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x5fd2298e	strnstr
++EXPORT_SYMBOL vmlinux 0x5fda0227	vfs_stat
++EXPORT_SYMBOL vmlinux 0x5fe3cac3	register_console
++EXPORT_SYMBOL vmlinux 0x5ff60f43	prepare_binprm
++EXPORT_SYMBOL vmlinux 0x5ffaf2de	arch_spin_trylock_retry
++EXPORT_SYMBOL vmlinux 0x6005c351	zpool_has_pool
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x608e5cbf	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x6091644e	flow_keys_dissector
++EXPORT_SYMBOL vmlinux 0x609602bd	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60a279fa	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0x60b92c41	tty_mutex
++EXPORT_SYMBOL vmlinux 0x60df1e3b	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x611136e8	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x612d35f0	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0x614a85d5	udp_del_offload
++EXPORT_SYMBOL vmlinux 0x614bb773	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0x614d095c	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x616eaeb4	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x617d1cca	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0x61917ea2	dev_uc_init
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61b93212	mod_virt_timer_periodic
++EXPORT_SYMBOL vmlinux 0x61c0966e	sg_miter_skip
++EXPORT_SYMBOL vmlinux 0x61dbea6b	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0x61e5137e	iov_iter_get_pages_alloc
++EXPORT_SYMBOL vmlinux 0x61e743ae	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0x61f7b551	compat_nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x61f84731	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0x620b7d87	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x621a1427	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x6238e247	padata_start
++EXPORT_SYMBOL vmlinux 0x62477c78	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x625ba9c4	blk_peek_request
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x628cfa17	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x629e744b	inet_addr_type
++EXPORT_SYMBOL vmlinux 0x629fd01d	tso_count_descs
++EXPORT_SYMBOL vmlinux 0x62d0f585	seq_printf
++EXPORT_SYMBOL vmlinux 0x62d7ca43	seq_vprintf
++EXPORT_SYMBOL vmlinux 0x62ddf82d	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x6319b8e9	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x631e5ce4	vfs_readf
++EXPORT_SYMBOL vmlinux 0x6332ea0c	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0x633a2d16	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x63420993	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0x63488071	xfrm4_protocol_register
++EXPORT_SYMBOL vmlinux 0x6357c2b3	inet6_bind
++EXPORT_SYMBOL vmlinux 0x637e3e67	generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x6399cc4d	register_cdrom
++EXPORT_SYMBOL vmlinux 0x63a1ac2f	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0x63a7c28c	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x63ab3b8f	dns_query
++EXPORT_SYMBOL vmlinux 0x63c4d61f	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x63ead3ef	__put_cred
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63f80226	pci_dev_get
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x640e51c9	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x64127b67	bitmap_find_next_zero_area_off
++EXPORT_SYMBOL vmlinux 0x641487c9	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x6419aec0	__vfs_write
++EXPORT_SYMBOL vmlinux 0x641f932b	km_report
++EXPORT_SYMBOL vmlinux 0x6431b30d	tcp_destroy_cgroup
++EXPORT_SYMBOL vmlinux 0x644e53e6	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0x644ef03e	proc_symlink
++EXPORT_SYMBOL vmlinux 0x647d78ef	proc_set_size
++EXPORT_SYMBOL vmlinux 0x6483e27d	always_delete_dentry
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64ead80b	zpool_unregister_driver
++EXPORT_SYMBOL vmlinux 0x64f980ca	simple_unlink
++EXPORT_SYMBOL vmlinux 0x65194b7c	xfrm_input
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x653a80e8	__blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x6546c0c7	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x65b49e45	__netif_schedule
++EXPORT_SYMBOL vmlinux 0x65b6ba57	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x65b871f8	param_ops_byte
++EXPORT_SYMBOL vmlinux 0x65ba4f28	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0x65d20730	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0x65daa364	tcw_set_tsb
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65ee898e	kern_path
++EXPORT_SYMBOL vmlinux 0x65f1765e	netif_tx_stop_all_queues
++EXPORT_SYMBOL vmlinux 0x66094e28	__sb_end_write
++EXPORT_SYMBOL vmlinux 0x66130485	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0x662084ae	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0x6655b29e	prepare_to_wait_event
++EXPORT_SYMBOL vmlinux 0x668a522b	file_open_root
++EXPORT_SYMBOL vmlinux 0x668c3971	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0x66c4d05f	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x66e69897	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0x66e927f5	generic_file_open
++EXPORT_SYMBOL vmlinux 0x66f24545	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0x670cf5ae	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x672144bd	strlcpy
++EXPORT_SYMBOL vmlinux 0x6724e119	crc32_le
++EXPORT_SYMBOL vmlinux 0x67267630	netdev_all_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0x67733cf4	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x677a90fa	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0x67a0757b	override_creds
++EXPORT_SYMBOL vmlinux 0x67adb2a4	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67d70951	cdrom_open
++EXPORT_SYMBOL vmlinux 0x67f8b9cc	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0x6808b453	__unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x684151a0	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0x6843a88f	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x686c30bf	seq_file_path
++EXPORT_SYMBOL vmlinux 0x6871adbb	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0x687422cb	vfs_create
++EXPORT_SYMBOL vmlinux 0x687701af	kill_anon_super
++EXPORT_SYMBOL vmlinux 0x6889c788	vlan_dev_vlan_proto
++EXPORT_SYMBOL vmlinux 0x6898c688	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x68a33e98	netpoll_poll_enable
++EXPORT_SYMBOL vmlinux 0x68b83ac6	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0x6903d165	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x69224ca5	console_start
++EXPORT_SYMBOL vmlinux 0x693110be	get_super
++EXPORT_SYMBOL vmlinux 0x693cf883	inet_csk_complete_hashdance
++EXPORT_SYMBOL vmlinux 0x6974c52e	lwtunnel_fill_encap
++EXPORT_SYMBOL vmlinux 0x698f3afe	debug_dflt_header_fn
++EXPORT_SYMBOL vmlinux 0x699483cf	tty_port_open
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69ba725b	seq_hex_dump
++EXPORT_SYMBOL vmlinux 0x69c9ee86	param_ops_string
++EXPORT_SYMBOL vmlinux 0x69ccb8a9	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0x69d2b661	skb_set_owner_w
++EXPORT_SYMBOL vmlinux 0x69f6de90	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a5fa363	sigprocmask
++EXPORT_SYMBOL vmlinux 0x6a603118	iput
++EXPORT_SYMBOL vmlinux 0x6a63f0c4	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x6a69949f	release_pages
++EXPORT_SYMBOL vmlinux 0x6a73cb33	skb_append
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a8ced7c	scsi_vpd_lun_id
++EXPORT_SYMBOL vmlinux 0x6a8d45b2	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x6a962b19	vfs_write
++EXPORT_SYMBOL vmlinux 0x6ac08549	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0x6acafd5b	cookie_timestamp_decode
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b37e0b1	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x6b3e58fe	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0x6b4ca037	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x6b651d6a	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x6b831ab5	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x6bb2898d	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x6bbc6619	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bc7c311	kmalloc_order
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6be15d2c	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x6be2fa64	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x6bede136	iov_iter_zero
++EXPORT_SYMBOL vmlinux 0x6c09c2a4	del_timer
++EXPORT_SYMBOL vmlinux 0x6c1350a2	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0x6c1914f5	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0x6c1eb6b5	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x6c1eff06	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0x6c2280f0	km_query
++EXPORT_SYMBOL vmlinux 0x6c2dd8b6	from_kprojid_munged
++EXPORT_SYMBOL vmlinux 0x6c31b0a6	blk_mq_add_to_requeue_list
++EXPORT_SYMBOL vmlinux 0x6c440651	init_virt_timer
++EXPORT_SYMBOL vmlinux 0x6c51a836	sysctl_tcp_notsent_lowat
++EXPORT_SYMBOL vmlinux 0x6c546d9a	dev_set_group
++EXPORT_SYMBOL vmlinux 0x6c5660b9	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c729edd	get_empty_filp
++EXPORT_SYMBOL vmlinux 0x6c73c1fd	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x6cb36d4a	__seq_open_private
++EXPORT_SYMBOL vmlinux 0x6ce8dedd	key_put
++EXPORT_SYMBOL vmlinux 0x6cef5cf9	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0x6cf4207d	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d126a41	set_wb_congested
++EXPORT_SYMBOL vmlinux 0x6d1ea6ec	strlcat
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d509146	tcw_get_intrg
++EXPORT_SYMBOL vmlinux 0x6d562249	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0x6d5cf03d	clear_wb_congested
++EXPORT_SYMBOL vmlinux 0x6d6ce3f2	lwtunnel_encap_add_ops
++EXPORT_SYMBOL vmlinux 0x6d8a6007	passthru_features_check
++EXPORT_SYMBOL vmlinux 0x6d9288d2	idr_for_each
++EXPORT_SYMBOL vmlinux 0x6da5eafb	nf_afinfo
++EXPORT_SYMBOL vmlinux 0x6dab08a4	config_group_find_item
++EXPORT_SYMBOL vmlinux 0x6db4d0a5	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0x6db8df06	nvm_erase_ppa
++EXPORT_SYMBOL vmlinux 0x6dbad639	udp_poll
++EXPORT_SYMBOL vmlinux 0x6ddca21d	down_trylock
++EXPORT_SYMBOL vmlinux 0x6ddd4934	lockref_get_not_dead
++EXPORT_SYMBOL vmlinux 0x6deb3179	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6df1aaf1	kernel_sigaction
++EXPORT_SYMBOL vmlinux 0x6dff3eed	elevator_exit
++EXPORT_SYMBOL vmlinux 0x6e00b8cb	_ebcasc
++EXPORT_SYMBOL vmlinux 0x6e0148ac	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0x6e0218c7	cdev_del
++EXPORT_SYMBOL vmlinux 0x6e08582f	netdev_printk
++EXPORT_SYMBOL vmlinux 0x6e1bf6f2	vfs_getattr
++EXPORT_SYMBOL vmlinux 0x6e4413b8	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e72de2a	trace_print_array_seq
++EXPORT_SYMBOL vmlinux 0x6e7f0fd2	cmdline_parts_parse
++EXPORT_SYMBOL vmlinux 0x6e828aad	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x6e9ad290	cpu_have_feature
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6eb58e4d	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x6ed52769	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x6f055127	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0x6f164daa	xfrm4_rcv_cb
++EXPORT_SYMBOL vmlinux 0x6f200b03	tcw_set_intrg
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f5ef93d	memchr_inv
++EXPORT_SYMBOL vmlinux 0x6f6d1eb9	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0x6f915271	airq_iv_create
++EXPORT_SYMBOL vmlinux 0x6f943e50	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x6fb983c6	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x6fbf07cd	__free_page_frag
++EXPORT_SYMBOL vmlinux 0x6fc7e626	memzero_explicit
++EXPORT_SYMBOL vmlinux 0x6fd6e15c	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0x7004a806	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x7009948c	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x70596eb7	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x706d051c	del_timer_sync
++EXPORT_SYMBOL vmlinux 0x70706076	fget_raw
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x70c4cf5b	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x70cc4873	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0x71052b6b	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x712bd9d1	blk_start_queue_async
++EXPORT_SYMBOL vmlinux 0x7139c2c5	nf_log_register
++EXPORT_SYMBOL vmlinux 0x7145aef0	segment_load
++EXPORT_SYMBOL vmlinux 0x715c4d51	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x717581b3	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71c0c3a8	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0x71ca3fee	path_get
++EXPORT_SYMBOL vmlinux 0x71e90e9f	alloc_file
++EXPORT_SYMBOL vmlinux 0x71ef0456	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x71f7bbf7	inet_reqsk_alloc
++EXPORT_SYMBOL vmlinux 0x721bbc75	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0x723c6f60	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0x7242e96d	strnchr
++EXPORT_SYMBOL vmlinux 0x7255beeb	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x725f76a4	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x72875a12	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x72a0b37a	netlink_unicast
++EXPORT_SYMBOL vmlinux 0x72a98315	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x72e33a44	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x730d4e0b	lg_local_lock
++EXPORT_SYMBOL vmlinux 0x73271f13	__lock_page
++EXPORT_SYMBOL vmlinux 0x732fdc16	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x738077e2	gro_find_complete_by_type
++EXPORT_SYMBOL vmlinux 0x738dc1ac	vmemmap
++EXPORT_SYMBOL vmlinux 0x73a7ec88	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0x73bf20c6	_ascebc
++EXPORT_SYMBOL vmlinux 0x73d45815	param_get_charp
++EXPORT_SYMBOL vmlinux 0x73d662c7	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x73e578dd	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0x73e7b0b5	ccw_device_halt
++EXPORT_SYMBOL vmlinux 0x73eb99c2	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0x7410aba2	strreplace
++EXPORT_SYMBOL vmlinux 0x741f70a9	debug_stop_all
++EXPORT_SYMBOL vmlinux 0x742625c8	get_acl
++EXPORT_SYMBOL vmlinux 0x74408894	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0x7445c996	netdev_master_upper_dev_link_private
++EXPORT_SYMBOL vmlinux 0x7446b28e	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x7459d982	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0x745af689	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0x745f44c0	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x747da64d	file_ns_capable
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x74aadf80	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x74bc0f34	xfrm_lookup_route
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74c3917e	udplite_table
++EXPORT_SYMBOL vmlinux 0x74e1b79a	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x75452ce8	tty_write_room
++EXPORT_SYMBOL vmlinux 0x75555cd0	param_array_ops
++EXPORT_SYMBOL vmlinux 0x7564622f	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x757530e8	mem_cgroup_end_page_stat
++EXPORT_SYMBOL vmlinux 0x758eb23c	revert_creds
++EXPORT_SYMBOL vmlinux 0x758fdcf1	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x75a958ec	sk_ns_capable
++EXPORT_SYMBOL vmlinux 0x75ac0197	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x75ac5cbf	finish_no_open
++EXPORT_SYMBOL vmlinux 0x75ad7134	gro_find_receive_by_type
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75bec21c	bh_submit_read
++EXPORT_SYMBOL vmlinux 0x75d10cae	debugfs_create_automount
++EXPORT_SYMBOL vmlinux 0x75d6b195	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0x75ec1e5d	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x75f687ca	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x76112f13	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x7611ff7f	from_kuid
++EXPORT_SYMBOL vmlinux 0x76387c53	padata_free
++EXPORT_SYMBOL vmlinux 0x7642537b	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x7671baa8	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x768f84b1	blk_mq_init_queue
++EXPORT_SYMBOL vmlinux 0x768f8dda	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0x76c5f70a	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0x76cac177	devm_release_resource
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76db593e	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0x76dde437	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x76f46433	vfs_writev
++EXPORT_SYMBOL vmlinux 0x770431b2	set_blocksize
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x777e33ee	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x7792edb4	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x7797ce63	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77c923d1	param_ops_bint
++EXPORT_SYMBOL vmlinux 0x77d22fa1	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x77f768b0	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0x7803dffc	__wake_up
++EXPORT_SYMBOL vmlinux 0x78043489	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0x780b64d6	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0x782acba5	crc_t10dif
++EXPORT_SYMBOL vmlinux 0x782c1e79	alloc_disk
++EXPORT_SYMBOL vmlinux 0x782d2fd2	mpage_readpages
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x785ebf62	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x7864414c	add_virt_timer_periodic
++EXPORT_SYMBOL vmlinux 0x786d88e9	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x788a663d	ether_setup
++EXPORT_SYMBOL vmlinux 0x78952031	page_symlink
++EXPORT_SYMBOL vmlinux 0x7898bcbc	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78b9cf85	__napi_alloc_skb
++EXPORT_SYMBOL vmlinux 0x78c6f2b7	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x78cd444f	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78fc66a9	generic_fillattr
++EXPORT_SYMBOL vmlinux 0x791fc072	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x792e0d45	lockref_get_not_zero
++EXPORT_SYMBOL vmlinux 0x7951a4f1	generic_update_time
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x79707cb1	inet_accept
++EXPORT_SYMBOL vmlinux 0x797a325a	scsi_execute
++EXPORT_SYMBOL vmlinux 0x797dd0f6	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x7985d043	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x799d9b97	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79b62961	mod_virt_timer
++EXPORT_SYMBOL vmlinux 0x79f21dd2	empty_aops
++EXPORT_SYMBOL vmlinux 0x7a01bf83	blk_finish_request
++EXPORT_SYMBOL vmlinux 0x7a0a2a30	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0x7a169106	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0x7a198ff0	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0x7a24bcce	user_path_at_empty
++EXPORT_SYMBOL vmlinux 0x7a3754e1	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a4a88be	dev_crit
++EXPORT_SYMBOL vmlinux 0x7a64c8af	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0x7a6cdedc	do_settimeofday64
++EXPORT_SYMBOL vmlinux 0x7a939ca7	up_read
++EXPORT_SYMBOL vmlinux 0x7aa1756e	kvfree
++EXPORT_SYMBOL vmlinux 0x7aa86d49	commit_creds
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ad050b9	qid_lt
++EXPORT_SYMBOL vmlinux 0x7ad5e94f	get_cached_acl_rcu
++EXPORT_SYMBOL vmlinux 0x7addce80	neigh_xmit
++EXPORT_SYMBOL vmlinux 0x7ae73de1	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0x7b167909	bitmap_from_u32array
++EXPORT_SYMBOL vmlinux 0x7b36d73e	set_groups
++EXPORT_SYMBOL vmlinux 0x7b45e07a	put_tty_driver
++EXPORT_SYMBOL vmlinux 0x7b5a7137	strncat
++EXPORT_SYMBOL vmlinux 0x7b5d2049	__register_chrdev
++EXPORT_SYMBOL vmlinux 0x7b638328	neigh_proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x7b79bc84	find_get_entry
++EXPORT_SYMBOL vmlinux 0x7b884110	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0x7b8f4c40	key_create_or_update
++EXPORT_SYMBOL vmlinux 0x7bb529d9	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x7bf479fe	resource_list_create_entry
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c173634	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0x7c246f22	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0x7c251169	irq_to_desc
++EXPORT_SYMBOL vmlinux 0x7c3dbaac	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x7c5d4a3a	sclp_reactivate
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c689ec0	inet_twsk_deschedule_put
++EXPORT_SYMBOL vmlinux 0x7c7362ad	tcw_get_data
++EXPORT_SYMBOL vmlinux 0x7c74b9e6	blk_start_queue
++EXPORT_SYMBOL vmlinux 0x7ca88cf2	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0x7ca95ecd	blk_start_request
++EXPORT_SYMBOL vmlinux 0x7cacd979	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cb1f1fa	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x7cdda3af	vfs_rename
++EXPORT_SYMBOL vmlinux 0x7cdfbb9e	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x7ce18c9f	from_kqid
++EXPORT_SYMBOL vmlinux 0x7cff93ea	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x7d0847fb	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d33cac2	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0x7d4444c5	mntput
++EXPORT_SYMBOL vmlinux 0x7d57fde5	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0x7d705738	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x7d76399f	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0x7d99b5cb	import_iovec
++EXPORT_SYMBOL vmlinux 0x7d9f4fcb	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x7dc99cd0	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0x7def10a4	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7e31268e	dev_mc_add
++EXPORT_SYMBOL vmlinux 0x7e802869	xattr_full_name
++EXPORT_SYMBOL vmlinux 0x7e9c1127	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0x7ead5569	ihold
++EXPORT_SYMBOL vmlinux 0x7ec60f70	arp_tbl
++EXPORT_SYMBOL vmlinux 0x7ec81ad3	__skb_get_hash_flowi6
++EXPORT_SYMBOL vmlinux 0x7ec98f84	dev_notice
++EXPORT_SYMBOL vmlinux 0x7ee52175	blk_queue_chunk_sectors
++EXPORT_SYMBOL vmlinux 0x7ee6d93a	nsecs_to_jiffies64
++EXPORT_SYMBOL vmlinux 0x7ee9eba3	iucv_register
++EXPORT_SYMBOL vmlinux 0x7f02188f	__msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x7f144384	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f263ed9	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x7f2846ab	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0x7f32a25e	inet6_csk_route_req
++EXPORT_SYMBOL vmlinux 0x7f46db15	generic_start_io_acct
++EXPORT_SYMBOL vmlinux 0x7f62a045	cpu_maps_update_done
++EXPORT_SYMBOL vmlinux 0x7f8c542b	skb_checksum
++EXPORT_SYMBOL vmlinux 0x7f8d050f	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x7f98ceff	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0x7fbd10d2	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0x7fce7be2	__inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7ff59443	secpath_dup
++EXPORT_SYMBOL vmlinux 0x8013131a	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x8015e9a6	tty_name
++EXPORT_SYMBOL vmlinux 0x80281877	read_code
++EXPORT_SYMBOL vmlinux 0x8034fc58	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0x803ec16b	compat_tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x805485ab	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0x805db99f	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x805f251e	napi_consume_skb
++EXPORT_SYMBOL vmlinux 0x8068c15c	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x807067c6	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x8073ac77	down_interruptible
++EXPORT_SYMBOL vmlinux 0x80791a8c	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0x80906917	dev_printk
++EXPORT_SYMBOL vmlinux 0x809be2b2	lock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0x80a8c8ab	kobject_add
++EXPORT_SYMBOL vmlinux 0x80c032f6	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0x80c91f82	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80daf4a1	__invalidate_device
++EXPORT_SYMBOL vmlinux 0x8128c039	smsg_register_callback
++EXPORT_SYMBOL vmlinux 0x813870ce	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x8155059f	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x81647fb5	eth_gro_complete
++EXPORT_SYMBOL vmlinux 0x8193d172	blk_mq_start_stopped_hw_queues
++EXPORT_SYMBOL vmlinux 0x819cf049	mount_bdev
++EXPORT_SYMBOL vmlinux 0x81a9c43a	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x81c58404	__breadahead
++EXPORT_SYMBOL vmlinux 0x81d35bfe	tcw_get_tccb
++EXPORT_SYMBOL vmlinux 0x81d9a403	tcp_req_err
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x82387170	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x824519f1	finish_wait
++EXPORT_SYMBOL vmlinux 0x82458f7f	radix_tree_delete_item
++EXPORT_SYMBOL vmlinux 0x8255bc12	bio_clone_fast
++EXPORT_SYMBOL vmlinux 0x82701365	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0x827d3c57	bio_put
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x8284ef71	block_write_end
++EXPORT_SYMBOL vmlinux 0x828a970e	fput
++EXPORT_SYMBOL vmlinux 0x82a0ea81	security_path_rename
++EXPORT_SYMBOL vmlinux 0x82a5175e	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0x82a867a1	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82b5912f	nvm_unregister_target
++EXPORT_SYMBOL vmlinux 0x82c30cae	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0x82ce1c16	nobh_writepage
++EXPORT_SYMBOL vmlinux 0x83020000	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x830dce28	__dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0x835ab8f5	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0x836cf18e	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0x838989ad	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x838e847e	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0x839430b2	__register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8394460f	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0x83a06ac9	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0x83b009ea	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x83c52fba	xfrm4_protocol_init
++EXPORT_SYMBOL vmlinux 0x842ab4ee	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0x8431732c	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0x843d13cb	dquot_commit
++EXPORT_SYMBOL vmlinux 0x843f118f	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0x843f9f68	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0x844e3767	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0x8468bc1b	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0x847060aa	simple_nosetlease
++EXPORT_SYMBOL vmlinux 0x8475060b	raw3270_request_add_data
++EXPORT_SYMBOL vmlinux 0x847765e9	__crc32c_le
++EXPORT_SYMBOL vmlinux 0x84884ed2	skb_checksum_trimmed
++EXPORT_SYMBOL vmlinux 0x84968f1d	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0x8498f693	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0x84a02c72	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x84a16b47	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x84d7118e	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x84d75752	blk_mq_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x84db8785	iucv_bus
++EXPORT_SYMBOL vmlinux 0x84e4405d	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0x84e84188	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x85010da8	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0x8521beb3	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x8532fb9d	tty_free_termios
++EXPORT_SYMBOL vmlinux 0x855f0f4d	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x85abc85f	strncmp
++EXPORT_SYMBOL vmlinux 0x85c1ce03	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0x85cc21ba	n_tty_compat_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85efc7e0	zero_pfn
++EXPORT_SYMBOL vmlinux 0x862041c1	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0x8644ccb2	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x864dcf28	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x86865a36	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x8692f00e	inet_csk_reqsk_queue_drop_and_put
++EXPORT_SYMBOL vmlinux 0x8694be8e	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0x869aa7ee	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x86a256a7	xfrm4_protocol_deregister
++EXPORT_SYMBOL vmlinux 0x86a26b38	flow_hash_from_keys
++EXPORT_SYMBOL vmlinux 0x86ad1505	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x86b6e14e	blk_mq_alloc_request
++EXPORT_SYMBOL vmlinux 0x86c0f3fe	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x86e15713	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x870af89b	page_readlink
++EXPORT_SYMBOL vmlinux 0x870d72c4	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0x8718b540	dquot_operations
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x872263ad	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0x87297f6a	set_user_nice
++EXPORT_SYMBOL vmlinux 0x874cf864	consume_skb
++EXPORT_SYMBOL vmlinux 0x87636dd9	tcw_set_tccb
++EXPORT_SYMBOL vmlinux 0x87774fe1	__kernel_write
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x8790f3a8	neigh_table_init
++EXPORT_SYMBOL vmlinux 0x879a220d	pci_release_regions
++EXPORT_SYMBOL vmlinux 0x87c58a96	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x87e92b05	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x880026b5	scsi_add_device
++EXPORT_SYMBOL vmlinux 0x8800dcf8	netdev_crit
++EXPORT_SYMBOL vmlinux 0x88146973	idr_destroy
++EXPORT_SYMBOL vmlinux 0x88256823	get_gendisk
++EXPORT_SYMBOL vmlinux 0x8833bc7e	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0x883aa781	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0x887fa47e	__getnstimeofday64
++EXPORT_SYMBOL vmlinux 0x888847b0	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x88a80ffd	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0x88b0ce0c	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0x88b48729	nvm_register_target
++EXPORT_SYMBOL vmlinux 0x88c238d3	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x88c38505	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0x88cea752	node_states
++EXPORT_SYMBOL vmlinux 0x88d59144	devm_ioremap_wc
++EXPORT_SYMBOL vmlinux 0x88f5d71d	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x88f8425b	param_get_ullong
++EXPORT_SYMBOL vmlinux 0x88fc6022	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0x88fcd027	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x8914abe8	_raw_read_trylock_retry
++EXPORT_SYMBOL vmlinux 0x891a5080	dev_err
++EXPORT_SYMBOL vmlinux 0x892de3fb	__nla_put
++EXPORT_SYMBOL vmlinux 0x898df814	md_write_start
++EXPORT_SYMBOL vmlinux 0x899b6002	d_genocide
++EXPORT_SYMBOL vmlinux 0x89a438d2	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89c59df4	sk_wait_data
++EXPORT_SYMBOL vmlinux 0x89c7d3b7	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0x89ca1fd4	down_read_trylock
++EXPORT_SYMBOL vmlinux 0x89cbaa25	md_cluster_mod
++EXPORT_SYMBOL vmlinux 0x89effab2	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0x89fcc950	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0x89ff68fa	ida_pre_get
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a26b4fe	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x8a31058b	__ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x8a51d565	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x8a607c79	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x8a62ef55	nobh_write_end
++EXPORT_SYMBOL vmlinux 0x8a6ace06	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a92357f	__scm_destroy
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8a9f9cac	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x8b000af7	__register_nls
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b7d476e	sock_no_poll
++EXPORT_SYMBOL vmlinux 0x8b7fe311	kmemdup
++EXPORT_SYMBOL vmlinux 0x8b8059bd	in_group_p
++EXPORT_SYMBOL vmlinux 0x8b957622	add_virt_timer
++EXPORT_SYMBOL vmlinux 0x8b99123f	kernel_read
++EXPORT_SYMBOL vmlinux 0x8ba4029a	netdev_update_features
++EXPORT_SYMBOL vmlinux 0x8bb28aab	ccw_device_is_multipath
++EXPORT_SYMBOL vmlinux 0x8bb4f178	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x8bcd9ea8	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x8bd3e641	__inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x8c168e4a	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0x8c4d0dcf	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c7d83fe	param_ops_long
++EXPORT_SYMBOL vmlinux 0x8c8a9663	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0x8cc6b464	__get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0x8cd5e0c2	dquot_get_state
++EXPORT_SYMBOL vmlinux 0x8cfb9fe2	blk_end_request
++EXPORT_SYMBOL vmlinux 0x8d08c78a	lwtunnel_state_alloc
++EXPORT_SYMBOL vmlinux 0x8d33b6b7	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d55bb8a	qid_eq
++EXPORT_SYMBOL vmlinux 0x8d64dff8	del_gendisk
++EXPORT_SYMBOL vmlinux 0x8d73278e	hex_asc_upper
++EXPORT_SYMBOL vmlinux 0x8d764d1b	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0x8d99b1a6	crc32_le_shift
++EXPORT_SYMBOL vmlinux 0x8daa3202	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x8dae4221	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x8dd69c5c	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x8de1e667	simple_statfs
++EXPORT_SYMBOL vmlinux 0x8df004b4	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x8e2bc44a	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0x8e63475e	netif_napi_add
++EXPORT_SYMBOL vmlinux 0x8e6b65d3	del_random_ready_callback
++EXPORT_SYMBOL vmlinux 0x8e73c97a	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0x8e74e192	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0x8e879bb7	__vmalloc
++EXPORT_SYMBOL vmlinux 0x8ebc6e09	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0x8ec7782b	blk_mq_all_tag_busy_iter
++EXPORT_SYMBOL vmlinux 0x8ef8b622	netdev_warn
++EXPORT_SYMBOL vmlinux 0x8ef95e6c	skb_split
++EXPORT_SYMBOL vmlinux 0x8efd1e35	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x8f5e72cb	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x8f636d23	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x8fc39f2d	param_ops_short
++EXPORT_SYMBOL vmlinux 0x8fdf05d7	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x8fe5806b	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0x9001b5e6	generic_setxattr
++EXPORT_SYMBOL vmlinux 0x900654e7	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x904cf22c	tty_hangup
++EXPORT_SYMBOL vmlinux 0x90684486	nonseekable_open
++EXPORT_SYMBOL vmlinux 0x9085ccdb	bio_init
++EXPORT_SYMBOL vmlinux 0x90e0c532	dev_emerg
++EXPORT_SYMBOL vmlinux 0x90e4bd9a	md_integrity_register
++EXPORT_SYMBOL vmlinux 0x90f371fc	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0x91034570	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x9106d3f7	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x9116b417	save_fpu_regs
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x914707b0	param_set_bint
++EXPORT_SYMBOL vmlinux 0x915d792b	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0x9161143e	inet_getname
++EXPORT_SYMBOL vmlinux 0x916627e2	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0x916cfe4f	neigh_update
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x91b1c937	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x91b6bf71	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0x91f6f464	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0x91f7a7f2	__get_hash_from_flowi4
++EXPORT_SYMBOL vmlinux 0x9204a0c1	dst_alloc
++EXPORT_SYMBOL vmlinux 0x9221372c	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x92230ab3	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x92392cd9	iov_shorten
++EXPORT_SYMBOL vmlinux 0x924d90ef	nvm_put_blk
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92e4b7c4	__block_write_begin
++EXPORT_SYMBOL vmlinux 0x92e850a3	__inet_hash
++EXPORT_SYMBOL vmlinux 0x92fe6ff2	lg_global_lock
++EXPORT_SYMBOL vmlinux 0x932ca4d5	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x933d0772	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0x9347696e	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x935db38e	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x93727ceb	nvm_dev_dma_alloc
++EXPORT_SYMBOL vmlinux 0x937733e3	qid_valid
++EXPORT_SYMBOL vmlinux 0x938f4521	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93c72874	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x93d675fb	param_get_bool
++EXPORT_SYMBOL vmlinux 0x93e9d3b4	iommu_tbl_pool_init
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x9402a6a5	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x94190fd1	security_path_symlink
++EXPORT_SYMBOL vmlinux 0x942b6f11	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0x944fe0ea	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x945775a5	segment_save
++EXPORT_SYMBOL vmlinux 0x946c8a97	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0x947617a8	dquot_resume
++EXPORT_SYMBOL vmlinux 0x9481965f	new_inode
++EXPORT_SYMBOL vmlinux 0x948a1894	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94a57592	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x94bc1f21	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x94c08b45	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x94d3c9fd	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x950e56ce	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x9514151a	_mcount
++EXPORT_SYMBOL vmlinux 0x95219742	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x952460a3	register_quota_format
++EXPORT_SYMBOL vmlinux 0x952dc7d9	raw3270_request_set_cmd
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x954d0b09	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x95697e40	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x95718ca8	submit_bio
++EXPORT_SYMBOL vmlinux 0x9581ea62	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0x9585c0bd	dev_open
++EXPORT_SYMBOL vmlinux 0x95a9d861	sk_common_release
++EXPORT_SYMBOL vmlinux 0x95c93188	iunique
++EXPORT_SYMBOL vmlinux 0x95ccdefa	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0x95ceb864	key_update
++EXPORT_SYMBOL vmlinux 0x95d212ea	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x95d96e05	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x95e250a1	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0x95eab63b	param_set_short
++EXPORT_SYMBOL vmlinux 0x95fd965a	simple_follow_link
++EXPORT_SYMBOL vmlinux 0x96332610	security_path_mknod
++EXPORT_SYMBOL vmlinux 0x96404e39	itcw_set_data
++EXPORT_SYMBOL vmlinux 0x964076ca	__module_get
++EXPORT_SYMBOL vmlinux 0x96432693	netdev_bonding_info_change
++EXPORT_SYMBOL vmlinux 0x9669ecc8	monotonic_clock
++EXPORT_SYMBOL vmlinux 0x9671cdb5	mem_cgroup_from_task
++EXPORT_SYMBOL vmlinux 0x9679917b	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0x96a0e5d9	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x97196302	netlink_set_err
++EXPORT_SYMBOL vmlinux 0x971ae8e1	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x973f8080	simple_link
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x975feb17	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x97669d73	netdev_emerg
++EXPORT_SYMBOL vmlinux 0x977a194d	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x97933a04	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0x97a907dd	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x97abc7c9	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0x97b694ba	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x97bdd413	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0x97c92892	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x97e71711	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x97e9a316	seq_open
++EXPORT_SYMBOL vmlinux 0x98082893	__copy_to_user
++EXPORT_SYMBOL vmlinux 0x982a4e35	netdev_class_create_file_ns
++EXPORT_SYMBOL vmlinux 0x98314900	drop_nlink
++EXPORT_SYMBOL vmlinux 0x9831e9e4	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0x983cbeee	blk_mq_start_hw_queue
++EXPORT_SYMBOL vmlinux 0x983f23f5	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0x98536c87	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x98ab50f9	dump_skip
++EXPORT_SYMBOL vmlinux 0x98c001d7	sock_register
++EXPORT_SYMBOL vmlinux 0x98c68c41	__gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x98cea64f	config_item_init_type_name
++EXPORT_SYMBOL vmlinux 0x98f01aa3	seq_putc
++EXPORT_SYMBOL vmlinux 0x990c34dd	_raw_write_lock_wait
++EXPORT_SYMBOL vmlinux 0x9914a64c	sock_create_lite
++EXPORT_SYMBOL vmlinux 0x992dc7bd	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x9937105d	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0x993d5bd6	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x9942ec77	itcw_finalize
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x996d128e	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x997823ae	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99b7ea87	get_cached_acl
++EXPORT_SYMBOL vmlinux 0x99c394fe	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d3a43c	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x99d97a9a	bdi_register_owner
++EXPORT_SYMBOL vmlinux 0x99daa9bf	try_offline_node
++EXPORT_SYMBOL vmlinux 0x9a014c15	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0x9a148244	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a38082f	tty_set_operations
++EXPORT_SYMBOL vmlinux 0x9a3c8045	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x9a3fd59e	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0x9a5723fc	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0x9a6d5a3e	param_set_ushort
++EXPORT_SYMBOL vmlinux 0x9a906daf	memscan
++EXPORT_SYMBOL vmlinux 0x9a9d96cb	d_delete
++EXPORT_SYMBOL vmlinux 0x9aabc564	crc16
++EXPORT_SYMBOL vmlinux 0x9ad9cde8	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0x9af17468	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x9b05fd5f	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x9b25fa5e	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b3c374d	get_disk
++EXPORT_SYMBOL vmlinux 0x9b51750b	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0x9b76848a	blk_register_region
++EXPORT_SYMBOL vmlinux 0x9b8d07aa	strnlen
++EXPORT_SYMBOL vmlinux 0x9b9c30b4	__generic_file_write_iter
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bb4fc20	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x9bbe88b3	flex_array_put
++EXPORT_SYMBOL vmlinux 0x9be20c50	audit_log_start
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9beeeb88	kbd_alloc
++EXPORT_SYMBOL vmlinux 0x9c245340	from_kuid_munged
++EXPORT_SYMBOL vmlinux 0x9c32bec9	iucv_unregister
++EXPORT_SYMBOL vmlinux 0x9c383d9f	proc_set_user
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c6519b4	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0x9c7ea758	dql_init
++EXPORT_SYMBOL vmlinux 0x9c8ac6e6	nf_register_net_hooks
++EXPORT_SYMBOL vmlinux 0x9c91b1d4	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0x9ca95a0e	sort
++EXPORT_SYMBOL vmlinux 0x9cc268d4	raw3270_wait_queue
++EXPORT_SYMBOL vmlinux 0x9cc718fe	dump_truncate
++EXPORT_SYMBOL vmlinux 0x9ce10424	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x9cea348f	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x9d052b14	kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d1f7113	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d3fa1a7	param_get_int
++EXPORT_SYMBOL vmlinux 0x9d4a7880	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0x9d4f8825	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0x9d6b26a7	simple_empty
++EXPORT_SYMBOL vmlinux 0x9d7d2df5	poll_freewait
++EXPORT_SYMBOL vmlinux 0x9d84f2bd	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x9d85b459	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x9d8da91b	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x9daf1171	dm_get_device
++EXPORT_SYMBOL vmlinux 0x9dc94e90	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x9df127a3	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x9df9814a	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x9dfbd41a	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0x9e0068ab	s390_epoch_delta_notifier
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e201d5a	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x9e4da5f2	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e53f8ac	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e763530	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x9e80e6c3	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x9e9fdd9d	memunmap
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9ed4c8e8	scsi_ioctl_reset
++EXPORT_SYMBOL vmlinux 0x9ee1d031	pci_get_device
++EXPORT_SYMBOL vmlinux 0x9f05ae4a	xfrm_input_register_afinfo
++EXPORT_SYMBOL vmlinux 0x9f3e7b0a	nvm_erase_blk
++EXPORT_SYMBOL vmlinux 0x9f4017db	d_splice_alias
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f558ab5	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x9f7b0e69	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x9f92ea8f	user_revoke
++EXPORT_SYMBOL vmlinux 0x9f943004	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9faed7a0	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0x9fb40545	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0x9fce5bc9	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x9fd7cda1	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9ff8dde5	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa005a59c	netif_device_attach
++EXPORT_SYMBOL vmlinux 0xa03bbdd1	unlock_two_nondirectories
++EXPORT_SYMBOL vmlinux 0xa0436e98	in6addr_linklocal_allnodes
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa0524674	iget_locked
++EXPORT_SYMBOL vmlinux 0xa0587d8a	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa05eb875	sclp
++EXPORT_SYMBOL vmlinux 0xa0710e44	proto_register
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa084749a	__bitmap_or
++EXPORT_SYMBOL vmlinux 0xa09767b7	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0xa0a89765	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0d3d560	ksize
++EXPORT_SYMBOL vmlinux 0xa0dad88e	netdev_adjacent_get_private
++EXPORT_SYMBOL vmlinux 0xa0dc8328	neigh_for_each
++EXPORT_SYMBOL vmlinux 0xa0df1179	iov_iter_get_pages
++EXPORT_SYMBOL vmlinux 0xa0df3daa	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0xa0e3232e	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0xa0ebd14c	sysctl_tcp_mem
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0ff74d6	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xa100bdf7	mempool_alloc
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa1472245	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0xa149d105	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0xa14b3f5d	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0xa14bceb0	__tracepoint_s390_diagnose
++EXPORT_SYMBOL vmlinux 0xa14d8cb4	param_get_invbool
++EXPORT_SYMBOL vmlinux 0xa1565f2b	fget
++EXPORT_SYMBOL vmlinux 0xa15b1786	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0xa1783895	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0xa1807eba	compat_mc_getsockopt
++EXPORT_SYMBOL vmlinux 0xa19065ea	down_timeout
++EXPORT_SYMBOL vmlinux 0xa1b055af	compat_ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1cf30e5	unregister_nls
++EXPORT_SYMBOL vmlinux 0xa1d5979b	find_first_bit_inv
++EXPORT_SYMBOL vmlinux 0xa1da85aa	udp_proc_register
++EXPORT_SYMBOL vmlinux 0xa1e06281	path_noexec
++EXPORT_SYMBOL vmlinux 0xa1e79ead	key_alloc
++EXPORT_SYMBOL vmlinux 0xa1ec8f1c	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0xa209451c	bitmap_fold
++EXPORT_SYMBOL vmlinux 0xa2516bbb	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0xa26fa4c8	pid_task
++EXPORT_SYMBOL vmlinux 0xa2777255	xfrm6_rcv_cb
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa2964702	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0xa2c402ea	__page_cache_alloc
++EXPORT_SYMBOL vmlinux 0xa2cd392e	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0xa2f36f08	mpage_readpage
++EXPORT_SYMBOL vmlinux 0xa2fd5aec	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0xa310a706	__iucv_message_receive
++EXPORT_SYMBOL vmlinux 0xa3112bc7	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xa335701d	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0xa33f7c7c	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0xa376d3a7	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0xa37e78b6	flex_array_get
++EXPORT_SYMBOL vmlinux 0xa38b0d95	iov_iter_bvec
++EXPORT_SYMBOL vmlinux 0xa3a98780	pcim_iomap
++EXPORT_SYMBOL vmlinux 0xa3c25075	find_lock_entry
++EXPORT_SYMBOL vmlinux 0xa3de2757	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0xa3ebfabe	rt6_lookup
++EXPORT_SYMBOL vmlinux 0xa3eef17e	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0xa4051a50	register_netdevice
++EXPORT_SYMBOL vmlinux 0xa40be272	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0xa4111201	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0xa41d079c	key_revoke
++EXPORT_SYMBOL vmlinux 0xa4237791	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0xa433af5f	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0xa44b520a	__scsi_format_command
++EXPORT_SYMBOL vmlinux 0xa44cebae	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa4810e8c	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0xa48f4046	dput
++EXPORT_SYMBOL vmlinux 0xa4a94d26	find_next_bit_le
++EXPORT_SYMBOL vmlinux 0xa4c41694	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xa4c935c5	tcp_rtx_synack
++EXPORT_SYMBOL vmlinux 0xa4cfa80d	keyring_search
++EXPORT_SYMBOL vmlinux 0xa4e188e7	strscpy
++EXPORT_SYMBOL vmlinux 0xa4f55075	iucv_message_send
++EXPORT_SYMBOL vmlinux 0xa5041515	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0xa5096843	param_ops_uint
++EXPORT_SYMBOL vmlinux 0xa51f51ef	file_remove_privs
++EXPORT_SYMBOL vmlinux 0xa51fcc03	padata_stop
++EXPORT_SYMBOL vmlinux 0xa5233224	migrate_page_copy
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa55f154b	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0xa56a871f	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0xa57160b4	request_firmware
++EXPORT_SYMBOL vmlinux 0xa575f18e	bd_set_size
++EXPORT_SYMBOL vmlinux 0xa588d262	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0xa59cb687	iucv_path_quiesce
++EXPORT_SYMBOL vmlinux 0xa59f7d1a	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0xa5a6cb8e	up_write
++EXPORT_SYMBOL vmlinux 0xa5eae887	kbd_ascebc
++EXPORT_SYMBOL vmlinux 0xa5f45b65	crypto_sha1_finup
++EXPORT_SYMBOL vmlinux 0xa636c58c	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0xa6421a7d	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0xa6447987	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0xa64505c2	pci_request_region
++EXPORT_SYMBOL vmlinux 0xa652bb6c	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa6d2402c	vfs_iter_read
++EXPORT_SYMBOL vmlinux 0xa6dec091	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0xa6ffec60	woken_wake_function
++EXPORT_SYMBOL vmlinux 0xa7076e08	nvm_dev_dma_free
++EXPORT_SYMBOL vmlinux 0xa720d6b2	dentry_open
++EXPORT_SYMBOL vmlinux 0xa723ff52	blk_mq_abort_requeue_list
++EXPORT_SYMBOL vmlinux 0xa72a0f5b	nr_online_nodes
++EXPORT_SYMBOL vmlinux 0xa731a15d	__neigh_set_probe_once
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa7373e70	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0xa745fc8b	ccw_device_tm_start
++EXPORT_SYMBOL vmlinux 0xa747246f	unregister_console
++EXPORT_SYMBOL vmlinux 0xa755e56b	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0xa78bddec	tcp_prot
++EXPORT_SYMBOL vmlinux 0xa7a6debf	d_alloc
++EXPORT_SYMBOL vmlinux 0xa7b179c7	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0xa7d63ce2	perf_reserve_sampling
++EXPORT_SYMBOL vmlinux 0xa7d6ce0b	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xa8035b9b	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0xa806fb5e	bdevname
++EXPORT_SYMBOL vmlinux 0xa80dd31e	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0xa82c41d4	tcp_get_cookie_sock
++EXPORT_SYMBOL vmlinux 0xa83780c8	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa886a958	krealloc
++EXPORT_SYMBOL vmlinux 0xa8a332fa	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0xa8a51e7a	__frontswap_store
++EXPORT_SYMBOL vmlinux 0xa8b51710	add_random_ready_callback
++EXPORT_SYMBOL vmlinux 0xa8b5c213	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0xa8c7a852	sk_mc_loop
++EXPORT_SYMBOL vmlinux 0xa8cf0a7c	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0xa8d0887e	ip_do_fragment
++EXPORT_SYMBOL vmlinux 0xa8de80d9	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa90b8d77	ccw_device_get_ciw
++EXPORT_SYMBOL vmlinux 0xa90f71e6	blk_get_queue
++EXPORT_SYMBOL vmlinux 0xa9168676	xmit_recursion
++EXPORT_SYMBOL vmlinux 0xa91b6adf	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0xa91d90d3	nla_put
++EXPORT_SYMBOL vmlinux 0xa9220a25	t10_pi_type3_crc
++EXPORT_SYMBOL vmlinux 0xa923d899	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0xa93deeb6	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0xa93f5d17	ida_remove
++EXPORT_SYMBOL vmlinux 0xa9490dae	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0xa9741474	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0xa976957d	bitmap_remap
++EXPORT_SYMBOL vmlinux 0xa9802ba5	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0xa992b13d	try_to_release_page
++EXPORT_SYMBOL vmlinux 0xa9b22e6d	forget_cached_acl
++EXPORT_SYMBOL vmlinux 0xa9b8f8f6	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0xa9c283f3	sk_alloc
++EXPORT_SYMBOL vmlinux 0xa9c41db3	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0xa9c63b69	security_xfrm_policy_free
++EXPORT_SYMBOL vmlinux 0xa9caf84f	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0xa9da599c	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0xa9e43814	tcp_child_process
++EXPORT_SYMBOL vmlinux 0xaa128008	tcp_openreq_init_rwin
++EXPORT_SYMBOL vmlinux 0xaa1bd1de	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0xaa1c8e79	__ethtool_get_link_ksettings
++EXPORT_SYMBOL vmlinux 0xaa2df2c2	skb_vlan_untag
++EXPORT_SYMBOL vmlinux 0xaa31959f	elv_register_queue
++EXPORT_SYMBOL vmlinux 0xaa4a0578	block_read_full_page
++EXPORT_SYMBOL vmlinux 0xaa6dd92b	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xaa7f93a2	nf_register_hook
++EXPORT_SYMBOL vmlinux 0xaa85bfb5	nvm_get_blk_unlocked
++EXPORT_SYMBOL vmlinux 0xaaa113cf	seq_write
++EXPORT_SYMBOL vmlinux 0xaab905d2	sk_filter_trim_cap
++EXPORT_SYMBOL vmlinux 0xaabe6704	airq_iv_free
++EXPORT_SYMBOL vmlinux 0xaad0ae78	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0xaae14754	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0xaaf33305	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xaafe909c	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xab0dbcbd	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0xab1a667b	dev_deactivate
++EXPORT_SYMBOL vmlinux 0xab1bb381	inet_bind
++EXPORT_SYMBOL vmlinux 0xab24e604	kernel_listen
++EXPORT_SYMBOL vmlinux 0xab62a4a6	tty_lock
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab7385ec	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0xab797d7c	dquot_initialize
++EXPORT_SYMBOL vmlinux 0xabb1f387	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac0e2ab0	d_path
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac322f23	single_open_size
++EXPORT_SYMBOL vmlinux 0xac398912	flex_array_clear
++EXPORT_SYMBOL vmlinux 0xac4e3cd8	try_module_get
++EXPORT_SYMBOL vmlinux 0xac50c4e7	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0xac5748df	path_put
++EXPORT_SYMBOL vmlinux 0xac697dca	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0xac6c3a71	crypto_sha256_finup
++EXPORT_SYMBOL vmlinux 0xac77aefa	invalidate_partition
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacc5b5d2	csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0xacca4415	audit_log
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacd81eb3	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xace3db62	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad2138e0	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0xad22874f	__skb_flow_get_ports
++EXPORT_SYMBOL vmlinux 0xad4aee39	strncpy
++EXPORT_SYMBOL vmlinux 0xad4cd138	perf_release_sampling
++EXPORT_SYMBOL vmlinux 0xad707583	get_user_pages_locked
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xadab63b9	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0xadfdfcef	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0xadfe01b8	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0xae19b91c	tcp_conn_request
++EXPORT_SYMBOL vmlinux 0xae240927	open_check_o_direct
++EXPORT_SYMBOL vmlinux 0xae26133c	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0xae2f6d36	__inode_permission
++EXPORT_SYMBOL vmlinux 0xae65d933	configfs_register_default_group
++EXPORT_SYMBOL vmlinux 0xae68497d	should_remove_suid
++EXPORT_SYMBOL vmlinux 0xae81aead	vfs_getattr_nosec
++EXPORT_SYMBOL vmlinux 0xae946cdc	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0xae9b3c2c	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0xae9ee729	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0xaed6c211	lock_rename
++EXPORT_SYMBOL vmlinux 0xaee9aec4	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0xaeec5484	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0xaf08e8fe	vprintk_emit
++EXPORT_SYMBOL vmlinux 0xaf307357	proc_create_data
++EXPORT_SYMBOL vmlinux 0xaf3c7b32	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf63d983	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0xaf89d750	capable_wrt_inode_uidgid
++EXPORT_SYMBOL vmlinux 0xaf98162a	sync_filesystem
++EXPORT_SYMBOL vmlinux 0xaf9dbd37	fasync_helper
++EXPORT_SYMBOL vmlinux 0xafd41342	cdev_init
++EXPORT_SYMBOL vmlinux 0xafe82e10	strcspn
++EXPORT_SYMBOL vmlinux 0xaff18ffb	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0xb0026a42	bio_map_kern
++EXPORT_SYMBOL vmlinux 0xb0064155	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0xb024c2e6	make_kprojid
++EXPORT_SYMBOL vmlinux 0xb04de57c	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0xb05294c4	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb0602fa8	bio_chain
++EXPORT_SYMBOL vmlinux 0xb061ef38	module_put
++EXPORT_SYMBOL vmlinux 0xb07dad92	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0xb0967710	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0xb09f2214	kobject_del
++EXPORT_SYMBOL vmlinux 0xb0b4d158	security_skb_classify_flow
++EXPORT_SYMBOL vmlinux 0xb0bcfef0	tty_do_resize
++EXPORT_SYMBOL vmlinux 0xb0d7269e	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0xb0dabfdb	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb1158bf3	ip_cmsg_recv_offset
++EXPORT_SYMBOL vmlinux 0xb11ea6c2	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0xb12b85ba	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb1545066	iget5_locked
++EXPORT_SYMBOL vmlinux 0xb15cb614	security_xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb1656f2a	brioctl_set
++EXPORT_SYMBOL vmlinux 0xb181cd77	sk_dst_check
++EXPORT_SYMBOL vmlinux 0xb18533ad	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0xb1bba555	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0xb1bd5919	submit_bh
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1ec8369	down_read
++EXPORT_SYMBOL vmlinux 0xb1f30962	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0xb1fc4ac4	netif_skb_features
++EXPORT_SYMBOL vmlinux 0xb20c096a	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xb23345c2	iov_iter_init
++EXPORT_SYMBOL vmlinux 0xb23e85fd	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0xb25d9dcf	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xb25e9e77	bio_endio
++EXPORT_SYMBOL vmlinux 0xb263109e	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0xb26648c6	pci_find_bus
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb26a893c	blk_mq_tag_to_rq
++EXPORT_SYMBOL vmlinux 0xb2876171	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xb29879f4	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0xb2b0d772	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0xb2bb5933	airq_iv_scan
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2c44304	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0xb2fb56a8	locks_lock_inode_wait
++EXPORT_SYMBOL vmlinux 0xb319d713	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0xb3247bb2	sock_i_ino
++EXPORT_SYMBOL vmlinux 0xb3305a04	get_task_io_context
++EXPORT_SYMBOL vmlinux 0xb33a4314	tcp_v4_mtu_reduced
++EXPORT_SYMBOL vmlinux 0xb33d7dc3	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0xb347f551	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0xb352177e	find_first_bit
++EXPORT_SYMBOL vmlinux 0xb3590c20	pci_pme_active
++EXPORT_SYMBOL vmlinux 0xb3796e9a	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0xb3b967a1	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0xb3c51185	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0xb3d2c76d	scsi_hostbyte_string
++EXPORT_SYMBOL vmlinux 0xb3da1869	blkdev_get
++EXPORT_SYMBOL vmlinux 0xb3dcfa84	inet_csk_reqsk_queue_drop
++EXPORT_SYMBOL vmlinux 0xb3ead46c	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb3ff1f69	free_pages_exact
++EXPORT_SYMBOL vmlinux 0xb40ef8bd	zpool_register_driver
++EXPORT_SYMBOL vmlinux 0xb4112c99	skb_ensure_writable
++EXPORT_SYMBOL vmlinux 0xb4202747	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0xb4538140	dev_get_phys_port_id
++EXPORT_SYMBOL vmlinux 0xb4591590	netdev_state_change
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb47ab193	filemap_map_pages
++EXPORT_SYMBOL vmlinux 0xb4cf631f	nvm_end_io
++EXPORT_SYMBOL vmlinux 0xb4e4f69f	get_phys_clock
++EXPORT_SYMBOL vmlinux 0xb4e7ce70	param_get_uint
++EXPORT_SYMBOL vmlinux 0xb519bad4	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0xb51efd87	md_check_recovery
++EXPORT_SYMBOL vmlinux 0xb53ab385	nvm_submit_io
++EXPORT_SYMBOL vmlinux 0xb5426b96	__dev_get_by_flags
++EXPORT_SYMBOL vmlinux 0xb56ab60f	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb59fcc29	kbd_ioctl
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5af5aec	seq_escape
++EXPORT_SYMBOL vmlinux 0xb5baf843	tod_to_timeval
++EXPORT_SYMBOL vmlinux 0xb5c55756	config_item_get
++EXPORT_SYMBOL vmlinux 0xb5dcca08	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0xb60e2152	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb62516eb	dquot_file_open
++EXPORT_SYMBOL vmlinux 0xb639f98d	thaw_super
++EXPORT_SYMBOL vmlinux 0xb646d92c	tty_kref_put
++EXPORT_SYMBOL vmlinux 0xb659bc81	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xb672adb5	iter_file_splice_write
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb6860944	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6b35eb4	pci_clear_master
++EXPORT_SYMBOL vmlinux 0xb6cff705	iucv_path_sever
++EXPORT_SYMBOL vmlinux 0xb6d76547	proc_dointvec
++EXPORT_SYMBOL vmlinux 0xb6dd7225	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0xb6efd94f	param_set_bool
++EXPORT_SYMBOL vmlinux 0xb7014664	__page_symlink
++EXPORT_SYMBOL vmlinux 0xb70c25cd	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0xb70d750c	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0xb710030c	build_skb
++EXPORT_SYMBOL vmlinux 0xb713eb7a	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0xb7180c76	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0xb71bed39	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0xb73b1211	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0xb7402d23	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0xb745cc2c	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0xb7488905	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0xb7558f3f	devm_request_any_context_irq
++EXPORT_SYMBOL vmlinux 0xb767136e	compat_sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0xb7705124	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0xb77131b1	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xb7899c6e	mempool_free
++EXPORT_SYMBOL vmlinux 0xb7b08f29	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0xb7c6db70	sysctl_max_skb_frags
++EXPORT_SYMBOL vmlinux 0xb7f0b1d0	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0xb7f12aac	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0xb8366900	cdev_alloc
++EXPORT_SYMBOL vmlinux 0xb839012c	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0xb843447a	mount_nodev
++EXPORT_SYMBOL vmlinux 0xb844ccca	tty_check_change
++EXPORT_SYMBOL vmlinux 0xb850a5b5	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0xb85a316e	inet6_release
++EXPORT_SYMBOL vmlinux 0xb85a574b	locks_copy_conflock
++EXPORT_SYMBOL vmlinux 0xb8648f42	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0xb86ffb73	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb890b2ed	component_match_add
++EXPORT_SYMBOL vmlinux 0xb8934399	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0xb894958a	bdget_disk
++EXPORT_SYMBOL vmlinux 0xb8b08c54	get_task_exe_file
++EXPORT_SYMBOL vmlinux 0xb8b1eb8c	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0xb8d95c61	ilookup
++EXPORT_SYMBOL vmlinux 0xb915ceca	itcw_init
++EXPORT_SYMBOL vmlinux 0xb9249d16	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0xb928aa45	netdev_rss_key_fill
++EXPORT_SYMBOL vmlinux 0xb92c8f06	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0xb9547c49	pci_bus_get
++EXPORT_SYMBOL vmlinux 0xb95ffade	scsi_register
++EXPORT_SYMBOL vmlinux 0xb9778bf3	__skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0xb978a48a	ccw_device_start_key
++EXPORT_SYMBOL vmlinux 0xb9a78b62	raw3270_find_view
++EXPORT_SYMBOL vmlinux 0xb9dfe0f8	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0xb9e8e2cc	in6addr_sitelocal_allrouters
++EXPORT_SYMBOL vmlinux 0xba28be9b	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0xba445ed9	skb_pad
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba5ea42a	skb_insert
++EXPORT_SYMBOL vmlinux 0xba80eaab	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0xba8dceaf	pci_dev_put
++EXPORT_SYMBOL vmlinux 0xba966e30	get_guest_storage_key
++EXPORT_SYMBOL vmlinux 0xbaa2782a	kstrndup
++EXPORT_SYMBOL vmlinux 0xbaa532b4	pci_iounmap
++EXPORT_SYMBOL vmlinux 0xbaa7a6f5	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0xbab44465	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0xbaed44d4	vmap
++EXPORT_SYMBOL vmlinux 0xbaf61771	dcb_getapp
++EXPORT_SYMBOL vmlinux 0xbb0540aa	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0xbb160e3f	tcp_init_cgroup
++EXPORT_SYMBOL vmlinux 0xbb1f72b6	inet_add_offload
++EXPORT_SYMBOL vmlinux 0xbb2b279e	set_guest_storage_key
++EXPORT_SYMBOL vmlinux 0xbb35675b	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xbb3b8d25	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb63b779	request_key_async
++EXPORT_SYMBOL vmlinux 0xbb9d0dc5	bin2hex
++EXPORT_SYMBOL vmlinux 0xbbbf5aa6	param_set_long
++EXPORT_SYMBOL vmlinux 0xbbc54453	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0xbbd9f808	generic_show_options
++EXPORT_SYMBOL vmlinux 0xbc2d2b4a	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0xbc2d7c00	kset_register
++EXPORT_SYMBOL vmlinux 0xbc3784be	free_cgroup_ns
++EXPORT_SYMBOL vmlinux 0xbc896762	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0xbcb87d13	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0xbcc0fcbb	cont_write_begin
++EXPORT_SYMBOL vmlinux 0xbcc99d21	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0xbcccc0a7	debug_exception_common
++EXPORT_SYMBOL vmlinux 0xbcdd7c9d	simple_dname
++EXPORT_SYMBOL vmlinux 0xbce00f46	inet_frags_init
++EXPORT_SYMBOL vmlinux 0xbd100793	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0xbd1bb191	nvm_register_mgr
++EXPORT_SYMBOL vmlinux 0xbd35f581	abort_creds
++EXPORT_SYMBOL vmlinux 0xbd7c52cf	netdev_lower_get_next_private_rcu
++EXPORT_SYMBOL vmlinux 0xbd803510	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xbd9074b1	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0xbd98f0b3	mapping_tagged
++EXPORT_SYMBOL vmlinux 0xbda01d46	ns_capable_noaudit
++EXPORT_SYMBOL vmlinux 0xbdcff76e	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0xbde64b30	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0xbdfb851f	___ratelimit
++EXPORT_SYMBOL vmlinux 0xbe04f63e	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0xbe0641f8	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0xbe1bb112	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xbe2d2f06	blk_queue_virt_boundary
++EXPORT_SYMBOL vmlinux 0xbe381650	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xbe923918	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0xbe95bc25	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0xbe9978f9	nvm_register
++EXPORT_SYMBOL vmlinux 0xbe9e2173	pci_request_regions
++EXPORT_SYMBOL vmlinux 0xbea5c34b	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0xbeb94aa7	copy_to_iter
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf03dc92	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0xbf0b5fe6	blk_queue_split
++EXPORT_SYMBOL vmlinux 0xbf1b26ab	__tcf_hash_release
++EXPORT_SYMBOL vmlinux 0xbf20c01a	nf_log_trace
++EXPORT_SYMBOL vmlinux 0xbf3549bc	ip6_xmit
++EXPORT_SYMBOL vmlinux 0xbf4c7a77	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf8f3aca	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfc5e194	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0xbfcc8a66	vfs_writef
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xc003c637	__strncpy_from_user
++EXPORT_SYMBOL vmlinux 0xc01a2154	raw3270_request_reset
++EXPORT_SYMBOL vmlinux 0xc03357e4	__f_setown
++EXPORT_SYMBOL vmlinux 0xc04108e8	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0xc062a510	clear_nlink
++EXPORT_SYMBOL vmlinux 0xc076a2de	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0xc09976ca	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0xc099b000	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0a96529	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0xc0ed7b81	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xc100835c	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0xc1033c39	skb_push
++EXPORT_SYMBOL vmlinux 0xc167e1c8	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0xc1a54486	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0xc1bc4a0a	no_llseek
++EXPORT_SYMBOL vmlinux 0xc1d5e82a	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0xc1d8cfaf	__fdget
++EXPORT_SYMBOL vmlinux 0xc1e50c0b	rtnl_nla_parse_ifla
++EXPORT_SYMBOL vmlinux 0xc2041290	__vlan_find_dev_deep_rcu
++EXPORT_SYMBOL vmlinux 0xc212f2ab	prandom_bytes
++EXPORT_SYMBOL vmlinux 0xc21afbb3	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xc22157cc	__netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0xc234dc04	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xc281907e	iucv_message_reply
++EXPORT_SYMBOL vmlinux 0xc2a128a3	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0xc2a64a18	user_path_create
++EXPORT_SYMBOL vmlinux 0xc2a7502f	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0xc2af3120	nla_append
++EXPORT_SYMBOL vmlinux 0xc2b03889	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0xc2b70841	cad_pid
++EXPORT_SYMBOL vmlinux 0xc2ba5571	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0xc2c1d605	inet_csk_reqsk_queue_add
++EXPORT_SYMBOL vmlinux 0xc2d34652	inode_change_ok
++EXPORT_SYMBOL vmlinux 0xc2ddc293	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc2f8ce92	seq_path
++EXPORT_SYMBOL vmlinux 0xc319d7ce	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xc34cffe2	kstrtobool_from_user
++EXPORT_SYMBOL vmlinux 0xc350a489	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0xc369af28	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0xc385cb58	perf_num_counters
++EXPORT_SYMBOL vmlinux 0xc39fb3cf	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0xc3abe9ee	__mutex_init
++EXPORT_SYMBOL vmlinux 0xc3e29276	dump_emit
++EXPORT_SYMBOL vmlinux 0xc3eff24d	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0xc4112c2a	stop_tty
++EXPORT_SYMBOL vmlinux 0xc42a3ff3	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0xc45755de	find_next_zero_bit_le
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4b56f15	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0xc4beace5	proc_create_mount_point
++EXPORT_SYMBOL vmlinux 0xc4f2dd43	tso_build_hdr
++EXPORT_SYMBOL vmlinux 0xc4ffdd39	km_is_alive
++EXPORT_SYMBOL vmlinux 0xc51d972e	ccw_device_tm_intrg
++EXPORT_SYMBOL vmlinux 0xc5298b0e	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0xc5313c15	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0xc5461869	configfs_unregister_default_group
++EXPORT_SYMBOL vmlinux 0xc5499359	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0xc599a772	security_xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xc5ad93b8	sie_exit
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc60afd18	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0xc60f99d7	netdev_lower_dev_get_private
++EXPORT_SYMBOL vmlinux 0xc61a8620	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0xc622ea97	stsi
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc63dbc5c	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0xc65782ad	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xc65a8c06	netdev_upper_get_next_dev_rcu
++EXPORT_SYMBOL vmlinux 0xc66f71ea	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0xc675d6d6	sock_no_listen
++EXPORT_SYMBOL vmlinux 0xc6772da2	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0xc68ac4c7	tty_register_driver
++EXPORT_SYMBOL vmlinux 0xc6916834	copy_from_iter
++EXPORT_SYMBOL vmlinux 0xc69bdfde	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0xc6a81b3e	start_tty
++EXPORT_SYMBOL vmlinux 0xc6b3e217	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6e03b28	register_service_level
++EXPORT_SYMBOL vmlinux 0xc6e9b19d	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0xc6ea5fd0	eth_platform_get_mac_address
++EXPORT_SYMBOL vmlinux 0xc6f674b8	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0xc7247f76	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0xc7324c20	inode_init_owner
++EXPORT_SYMBOL vmlinux 0xc7466f82	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0xc74af6d6	dev_alert
++EXPORT_SYMBOL vmlinux 0xc777d175	blk_make_request
++EXPORT_SYMBOL vmlinux 0xc77c8233	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a24d76	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7c77734	dentry_needs_remove_privs
++EXPORT_SYMBOL vmlinux 0xc7e52bd8	dev_load
++EXPORT_SYMBOL vmlinux 0xc7ffe48c	pci_release_region
++EXPORT_SYMBOL vmlinux 0xc81ff02e	icmpv6_send
++EXPORT_SYMBOL vmlinux 0xc83b4d5b	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xc83f5cfc	cmdline_parts_find
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc852e5c9	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0xc85c6591	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0xc86a6174	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0xc872fd85	in6addr_interfacelocal_allnodes
++EXPORT_SYMBOL vmlinux 0xc879e8a8	get_user_pages_unlocked
++EXPORT_SYMBOL vmlinux 0xc894dd61	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0xc8963197	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc8a91f5b	cpumask_local_spread
++EXPORT_SYMBOL vmlinux 0xc8abac95	sock_rfree
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8cd7b4b	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0xc8e32480	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0xc9070e6a	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0xc911b9d5	eth_get_headlen
++EXPORT_SYMBOL vmlinux 0xc9579d28	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0xc95de9c3	param_set_invbool
++EXPORT_SYMBOL vmlinux 0xc9634df9	in6addr_linklocal_allrouters
++EXPORT_SYMBOL vmlinux 0xc98e3414	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0xc98f0c4a	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0xca02bdf9	compat_tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0xca09fe9f	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0xca0f4667	readlink_copy
++EXPORT_SYMBOL vmlinux 0xca2ad76e	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0xca4c923d	vscnprintf
++EXPORT_SYMBOL vmlinux 0xca541fbe	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0xca59aeb2	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0xca5df765	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0xca5e3222	__debug_sprintf_exception
++EXPORT_SYMBOL vmlinux 0xca8e41f6	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xca97ae53	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xca9a8e79	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0xca9b58d4	sg_miter_next
++EXPORT_SYMBOL vmlinux 0xcad0835e	debug_register_mode
++EXPORT_SYMBOL vmlinux 0xcadc9956	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0xcaf2c603	scsi_sd_pm_domain
++EXPORT_SYMBOL vmlinux 0xcb020a29	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xcb04e2fe	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0xcb436e3c	__destroy_inode
++EXPORT_SYMBOL vmlinux 0xcb566c8c	dst_destroy
++EXPORT_SYMBOL vmlinux 0xcb629af4	touch_buffer
++EXPORT_SYMBOL vmlinux 0xcb87312f	devm_iounmap
++EXPORT_SYMBOL vmlinux 0xcb9ff433	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0xcba8629b	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0xcbb44ebe	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbcd080b	clear_inode
++EXPORT_SYMBOL vmlinux 0xcc12d8da	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0xcc4b42ba	dev_change_proto_down
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc5bc9b0	kobject_get_unless_zero
++EXPORT_SYMBOL vmlinux 0xcc694543	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0xcc6fee8c	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0xcc8f8764	__dst_free
++EXPORT_SYMBOL vmlinux 0xcca506ae	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0xcca94125	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0xccc1bb4b	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0xccc8c404	skb_tx_error
++EXPORT_SYMBOL vmlinux 0xccf58ba1	security_path_link
++EXPORT_SYMBOL vmlinux 0xccf8ab8d	msi_desc_to_pci_dev
++EXPORT_SYMBOL vmlinux 0xcd26b404	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd45d906	touch_atime
++EXPORT_SYMBOL vmlinux 0xcd57f7b0	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0xcd609f54	pci_wait_for_pending_transaction
++EXPORT_SYMBOL vmlinux 0xcd6e7f05	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0xcd7e018f	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xcd816cf6	arch_spin_lock_wait
++EXPORT_SYMBOL vmlinux 0xcd885061	param_set_int
++EXPORT_SYMBOL vmlinux 0xcd96dd7b	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcddae134	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xcdf7484b	proc_dostring
++EXPORT_SYMBOL vmlinux 0xcdf8a4ad	tty_port_put
++EXPORT_SYMBOL vmlinux 0xcdf98a4c	kobject_init
++EXPORT_SYMBOL vmlinux 0xce00336a	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0xce076c41	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0xce0e2d66	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xce218455	debug_hex_ascii_view
++EXPORT_SYMBOL vmlinux 0xce26ebe2	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce48655a	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce6b7d9f	devm_free_irq
++EXPORT_SYMBOL vmlinux 0xce8e4b25	unlock_page
++EXPORT_SYMBOL vmlinux 0xcea20ca8	blk_mq_can_queue
++EXPORT_SYMBOL vmlinux 0xceab0311	strchrnul
++EXPORT_SYMBOL vmlinux 0xceae504f	cmdline_parts_free
++EXPORT_SYMBOL vmlinux 0xcec3a908	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0xceccdc32	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0xced3d912	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0xcedf0886	cpu_relax
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcef94e3f	bdev_read_only
++EXPORT_SYMBOL vmlinux 0xcf14f8cd	iucv_message_purge
++EXPORT_SYMBOL vmlinux 0xcf1c8bf0	current_in_userns
++EXPORT_SYMBOL vmlinux 0xcf1cc9b5	param_ops_int
++EXPORT_SYMBOL vmlinux 0xcf2817d5	ida_simple_get
++EXPORT_SYMBOL vmlinux 0xcf2a5bec	fs_bio_set
++EXPORT_SYMBOL vmlinux 0xcf6288d6	bio_split
++EXPORT_SYMBOL vmlinux 0xcf733408	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0xcf8198e6	__get_page_tail
++EXPORT_SYMBOL vmlinux 0xcfa3b047	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0xcfbc01fe	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0xcfeae122	lockref_put_return
++EXPORT_SYMBOL vmlinux 0xd00b57b3	__dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0xd01acbf0	param_set_uint
++EXPORT_SYMBOL vmlinux 0xd05d38b4	do_truncate
++EXPORT_SYMBOL vmlinux 0xd05f80f2	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0xd066334a	set_posix_acl
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd079d312	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0xd0843656	unregister_netdev
++EXPORT_SYMBOL vmlinux 0xd0886827	page_cache_prev_hole
++EXPORT_SYMBOL vmlinux 0xd08a11fe	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0xd0a2847c	sha_init
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0baa7ed	generic_file_read_iter
++EXPORT_SYMBOL vmlinux 0xd0c31534	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0xd0dd6e0d	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd10f2da4	nf_unregister_net_hooks
++EXPORT_SYMBOL vmlinux 0xd13a0886	xfrm_policy_hash_rebuild
++EXPORT_SYMBOL vmlinux 0xd160c96d	sysctl_ibrs_enabled
++EXPORT_SYMBOL vmlinux 0xd171ed0a	elv_rb_del
++EXPORT_SYMBOL vmlinux 0xd178ff70	vm_stat
++EXPORT_SYMBOL vmlinux 0xd17b8e63	param_ops_bool
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd199d498	tcw_init
++EXPORT_SYMBOL vmlinux 0xd19f13f7	del_virt_timer
++EXPORT_SYMBOL vmlinux 0xd1afaab9	read_cache_pages
++EXPORT_SYMBOL vmlinux 0xd1bf098a	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xd1ca4707	netdev_features_change
++EXPORT_SYMBOL vmlinux 0xd1d87e92	scsi_mlreturn_string
++EXPORT_SYMBOL vmlinux 0xd1f01c34	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0xd1f152ad	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0xd225cb78	pci_choose_state
++EXPORT_SYMBOL vmlinux 0xd228fd6a	blk_mq_map_queue
++EXPORT_SYMBOL vmlinux 0xd231c5d2	iommu_tbl_range_alloc
++EXPORT_SYMBOL vmlinux 0xd2389919	dcache_readdir
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd269294f	tcp_filter
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd27d1b53	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0xd2858d0c	node_to_cpumask_map
++EXPORT_SYMBOL vmlinux 0xd2ae6e80	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0xd2b51ae7	netdev_lower_get_next_private
++EXPORT_SYMBOL vmlinux 0xd2bd7dee	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2db305e	netif_rx
++EXPORT_SYMBOL vmlinux 0xd2e0bb73	sie64a
++EXPORT_SYMBOL vmlinux 0xd2e5f6e2	param_set_byte
++EXPORT_SYMBOL vmlinux 0xd2f684bd	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0xd2fbd067	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0xd2ffd87d	mntget
++EXPORT_SYMBOL vmlinux 0xd31c393b	iucv_path_accept
++EXPORT_SYMBOL vmlinux 0xd3461167	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0xd34a48ef	put_page
++EXPORT_SYMBOL vmlinux 0xd34cba55	iterate_fd
++EXPORT_SYMBOL vmlinux 0xd382f18b	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0xd39a78ce	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0xd3af979c	memdup_user
++EXPORT_SYMBOL vmlinux 0xd3bc530e	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xd3d122de	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0xd3d844e4	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0xd3e0a507	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0xd410d271	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0xd41d21b1	param_set_ullong
++EXPORT_SYMBOL vmlinux 0xd4216410	tcp_enter_cwr
++EXPORT_SYMBOL vmlinux 0xd4219d40	compat_sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0xd434be76	blk_complete_request
++EXPORT_SYMBOL vmlinux 0xd43545f0	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0xd452a4cb	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0xd452b2f8	netdev_lower_get_next
++EXPORT_SYMBOL vmlinux 0xd454c60d	unlock_rename
++EXPORT_SYMBOL vmlinux 0xd45d2f68	inet_select_addr
++EXPORT_SYMBOL vmlinux 0xd4652bdc	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0xd4773502	param_set_charp
++EXPORT_SYMBOL vmlinux 0xd4ab1860	tso_start
++EXPORT_SYMBOL vmlinux 0xd4ad8b62	nf_log_set
++EXPORT_SYMBOL vmlinux 0xd4b9f9d3	pci_select_bars
++EXPORT_SYMBOL vmlinux 0xd4d750f1	dquot_disable
++EXPORT_SYMBOL vmlinux 0xd4d912d0	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0xd4d95f6b	free_task
++EXPORT_SYMBOL vmlinux 0xd4e37272	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0xd537f098	tc_classify
++EXPORT_SYMBOL vmlinux 0xd54f41ce	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd55121f5	neigh_proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0xd553458d	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0xd58b3dd5	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0xd5aa0f53	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0xd5ba3100	sock_wake_async
++EXPORT_SYMBOL vmlinux 0xd5df3d71	md_reload_sb
++EXPORT_SYMBOL vmlinux 0xd5e47095	blkdev_put
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd61bd76a	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd645b378	ccw_device_set_options_mask
++EXPORT_SYMBOL vmlinux 0xd666a588	smp_ctl_clear_bit
++EXPORT_SYMBOL vmlinux 0xd687d480	nvm_dev_factory
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd6987375	tcp_poll
++EXPORT_SYMBOL vmlinux 0xd6a188f1	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0xd6b84d51	pci_match_id
++EXPORT_SYMBOL vmlinux 0xd6c63c9d	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0xd6eac06c	search_binary_handler
++EXPORT_SYMBOL vmlinux 0xd6ead35e	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd70d84a2	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0xd75a8ae2	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd79866bb	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0xd7cc93f1	revalidate_disk
++EXPORT_SYMBOL vmlinux 0xd7e49c9e	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd85a05eb	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0xd877a45e	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0xd87a4e4d	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0xd8837d4d	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a994eb	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0xd8b4b5ad	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0xd8c9c176	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0xd8ded085	radix_tree_maybe_preload
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd8f186dc	put_cmsg
++EXPORT_SYMBOL vmlinux 0xd8fcda72	cpcmd
++EXPORT_SYMBOL vmlinux 0xd9043982	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xd9333ada	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0xd9333eef	find_vma
++EXPORT_SYMBOL vmlinux 0xd958e067	d_lookup
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd9911acc	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0xd9994453	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xd9a69451	misc_deregister
++EXPORT_SYMBOL vmlinux 0xd9b15b26	down_write
++EXPORT_SYMBOL vmlinux 0xd9b3f97d	console_devno
++EXPORT_SYMBOL vmlinux 0xd9b64c36	nosteal_pipe_buf_ops
++EXPORT_SYMBOL vmlinux 0xd9c4840d	flow_cache_fini
++EXPORT_SYMBOL vmlinux 0xd9c7c2ca	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0xd9cdb15f	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0xd9d8fd16	register_restart_handler
++EXPORT_SYMBOL vmlinux 0xd9eede83	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0xda1e39c7	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0xda26d81c	device_get_mac_address
++EXPORT_SYMBOL vmlinux 0xda2f6f89	dev_addr_init
++EXPORT_SYMBOL vmlinux 0xda366905	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda482531	debug_unregister_view
++EXPORT_SYMBOL vmlinux 0xda518c39	sock_init_data
++EXPORT_SYMBOL vmlinux 0xda528d84	md_update_sb
++EXPORT_SYMBOL vmlinux 0xda61b669	pci_msi_vec_count
++EXPORT_SYMBOL vmlinux 0xda7f4f69	open_exec
++EXPORT_SYMBOL vmlinux 0xda839a98	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0xdab79791	would_dump
++EXPORT_SYMBOL vmlinux 0xdac4913a	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0xdad7832a	blk_mq_start_request
++EXPORT_SYMBOL vmlinux 0xdae162cb	string_unescape
++EXPORT_SYMBOL vmlinux 0xdaff1540	key_link
++EXPORT_SYMBOL vmlinux 0xdb06d0ea	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0xdb0f2470	nvm_free_rqd_ppalist
++EXPORT_SYMBOL vmlinux 0xdb185e7b	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0xdb2cc7b8	sk_free
++EXPORT_SYMBOL vmlinux 0xdb2df64a	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0xdb39ee27	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0xdb3bcca6	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0xdb5d544b	simple_readpage
++EXPORT_SYMBOL vmlinux 0xdb64be1f	__iucv_message_send
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb83c8fa	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0xdba14cce	arch_spin_lock_wait_flags
++EXPORT_SYMBOL vmlinux 0xdbba8b2e	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0xdbc4ec41	skb_flow_dissector_init
++EXPORT_SYMBOL vmlinux 0xdbde72b6	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0xdbe8a5fd	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0xdbfc185e	kill_litter_super
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc0bac47	write_inode_now
++EXPORT_SYMBOL vmlinux 0xdc0f56d4	sock_from_file
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc1f0254	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0xdc3c8574	block_write_full_page
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc4d27dd	raw3270_start_irq
++EXPORT_SYMBOL vmlinux 0xdc58a7ad	ccw_driver_unregister
++EXPORT_SYMBOL vmlinux 0xdc6045f5	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0xdc66dfbc	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0xdc8deed3	flush_signals
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdd177b1b	devm_kvasprintf
++EXPORT_SYMBOL vmlinux 0xdd446c88	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0xdd455807	mount_single
++EXPORT_SYMBOL vmlinux 0xdd4f0bea	tcp_close
++EXPORT_SYMBOL vmlinux 0xdd4f3c09	netdev_alert
++EXPORT_SYMBOL vmlinux 0xdd821580	dqstats
++EXPORT_SYMBOL vmlinux 0xdd9125c2	netdev_lower_get_first_private_rcu
++EXPORT_SYMBOL vmlinux 0xdd983aca	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0xdda08c00	__crc32c_le_shift
++EXPORT_SYMBOL vmlinux 0xddc4add3	tty_unlock
++EXPORT_SYMBOL vmlinux 0xddc9afd8	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0xddd3004d	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0xdddea373	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0xddefc526	peernet2id_alloc
++EXPORT_SYMBOL vmlinux 0xde0bdcff	memset
++EXPORT_SYMBOL vmlinux 0xde48a247	mempool_create
++EXPORT_SYMBOL vmlinux 0xde4ee9e4	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0xde6151db	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xde64c3f3	register_md_cluster_operations
++EXPORT_SYMBOL vmlinux 0xde8b4f8b	airq_iv_alloc
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xdea765d5	blk_mq_run_hw_queues
++EXPORT_SYMBOL vmlinux 0xdf060159	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf5c0162	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdfa9acca	smp_cpu_mtid
++EXPORT_SYMBOL vmlinux 0xdfbf0dad	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xdfe4ea65	pci_find_pcie_root_port
++EXPORT_SYMBOL vmlinux 0xdfe92555	key_validate
++EXPORT_SYMBOL vmlinux 0xdfee80ec	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0xdff727e9	lwtunnel_cmp_encap
++EXPORT_SYMBOL vmlinux 0xe016b45e	alloc_pages_current
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe0614a83	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0xe06e4199	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0xe0752f5c	config_item_set_name
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe07d1960	arp_create
++EXPORT_SYMBOL vmlinux 0xe0812a9e	register_adapter_interrupt
++EXPORT_SYMBOL vmlinux 0xe0864fc6	ipv6_sock_mc_drop
++EXPORT_SYMBOL vmlinux 0xe0875eb1	kstrtobool
++EXPORT_SYMBOL vmlinux 0xe0a06210	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0xe0ae16f8	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0bc4fb2	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0xe0c61143	elv_rb_find
++EXPORT_SYMBOL vmlinux 0xe0c88692	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0xe0cbc7e9	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0xe0eb76ca	tso_build_data
++EXPORT_SYMBOL vmlinux 0xe0ee4a6b	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0xe0f99c64	kmem_cache_free_bulk
++EXPORT_SYMBOL vmlinux 0xe10d3189	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0xe112a784	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0xe133dbbd	flow_get_u32_dst
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe19b23e2	kthread_bind
++EXPORT_SYMBOL vmlinux 0xe1af2a79	raw3270_add_view
++EXPORT_SYMBOL vmlinux 0xe1e0d558	ccw_device_start
++EXPORT_SYMBOL vmlinux 0xe1f931cb	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe20372ae	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0xe2114879	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe24a8cca	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe24eec7f	km_policy_expired
++EXPORT_SYMBOL vmlinux 0xe2761a6e	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0xe29753fb	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0xe29b274e	iov_iter_alignment
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2d29133	d_find_alias
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2f425e7	rps_cpu_mask
++EXPORT_SYMBOL vmlinux 0xe30cf042	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0xe313601e	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0xe317764d	jiffies_to_timespec64
++EXPORT_SYMBOL vmlinux 0xe3389c34	inet_del_offload
++EXPORT_SYMBOL vmlinux 0xe33ee397	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0xe34e2784	lookup_one_len
++EXPORT_SYMBOL vmlinux 0xe3632f6a	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0xe37a6298	posix_test_lock
++EXPORT_SYMBOL vmlinux 0xe3ab9865	security_file_permission
++EXPORT_SYMBOL vmlinux 0xe3baeb78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0xe3c5ae9d	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0xe3e2a065	cdrom_release
++EXPORT_SYMBOL vmlinux 0xe3e91888	netif_device_detach
++EXPORT_SYMBOL vmlinux 0xe40c2aa6	blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xe41b341b	devm_memunmap
++EXPORT_SYMBOL vmlinux 0xe4202ac9	drop_super
++EXPORT_SYMBOL vmlinux 0xe42e92b7	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0xe4409190	mem_section
++EXPORT_SYMBOL vmlinux 0xe4644802	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xe467f9aa	sclp_register
++EXPORT_SYMBOL vmlinux 0xe479a964	dump_fpu
++EXPORT_SYMBOL vmlinux 0xe4a40d2f	diag210
++EXPORT_SYMBOL vmlinux 0xe4a5ba02	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0xe4ac8c1d	filemap_fault
++EXPORT_SYMBOL vmlinux 0xe4e8078a	bitmap_to_u32array
++EXPORT_SYMBOL vmlinux 0xe4e83aa3	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0xe4eaab2e	t10_pi_type1_crc
++EXPORT_SYMBOL vmlinux 0xe4ffb1bd	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0xe5094832	page_table_allocate_pgste
++EXPORT_SYMBOL vmlinux 0xe51fed85	complete_all
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe54036ef	mempool_resize
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe5957ef0	vm_mmap
++EXPORT_SYMBOL vmlinux 0xe5a292e9	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xe5b276aa	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0xe5c0bf36	datagram_poll
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe5f20b04	register_md_personality
++EXPORT_SYMBOL vmlinux 0xe5f863c1	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0xe61b30c9	bdgrab
++EXPORT_SYMBOL vmlinux 0xe63309c5	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0xe63e9382	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0xe67211a7	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0xe682649c	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0xe6896172	inet6_protos
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe6d89c7a	sync_blockdev
++EXPORT_SYMBOL vmlinux 0xe6f1486d	dql_reset
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe70a708c	lwtunnel_get_encap_size
++EXPORT_SYMBOL vmlinux 0xe713a97a	irq_subclass_unregister
++EXPORT_SYMBOL vmlinux 0xe74b04c2	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0xe74ba8d3	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xe75de6e3	pci_get_class
++EXPORT_SYMBOL vmlinux 0xe7661e50	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7e49e82	kfree_put_link
++EXPORT_SYMBOL vmlinux 0xe7f75776	truncate_setsize
++EXPORT_SYMBOL vmlinux 0xe8116e08	__kmalloc_node
++EXPORT_SYMBOL vmlinux 0xe812e9ff	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0xe81fb945	tcf_register_action
++EXPORT_SYMBOL vmlinux 0xe8214184	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0xe82693f4	netlink_ack
++EXPORT_SYMBOL vmlinux 0xe8279f71	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0xe8381e6f	ccw_device_start_timeout_key
++EXPORT_SYMBOL vmlinux 0xe8518fbd	skb_copy_datagram_from_iter
++EXPORT_SYMBOL vmlinux 0xe860548c	__bread_gfp
++EXPORT_SYMBOL vmlinux 0xe8751b0e	vfs_llseek
++EXPORT_SYMBOL vmlinux 0xe8924368	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0xe8a73aaf	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xe8b7851f	fsync_bdev
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8c7da0d	scsi_unregister
++EXPORT_SYMBOL vmlinux 0xe8c978d7	sget_userns
++EXPORT_SYMBOL vmlinux 0xe8da88e7	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0xe8ef0ff0	current_kernel_time64
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe91c58c7	skb_pull
++EXPORT_SYMBOL vmlinux 0xe91ed0cf	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0xe9335972	tty_port_close
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe95e00cf	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0xe96366c0	sdev_prefix_printk
++EXPORT_SYMBOL vmlinux 0xe9654115	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0xe9656159	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0xe967d8e8	vfs_unlink
++EXPORT_SYMBOL vmlinux 0xe97261ee	node_data
++EXPORT_SYMBOL vmlinux 0xe979bf3c	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0xe98d8f22	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0xe9989c8c	itcw_get_tcw
++EXPORT_SYMBOL vmlinux 0xe9c71aef	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0xe9dc40c3	replace_mount_options
++EXPORT_SYMBOL vmlinux 0xe9f03b26	udp_ioctl
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea0f3fc7	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0xea2ae9fa	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0xea3deb5f	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xea4bea17	flush_old_exec
++EXPORT_SYMBOL vmlinux 0xea4c35d5	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0xea5f41bd	add_wait_queue
++EXPORT_SYMBOL vmlinux 0xea6aec67	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0xea7a42f9	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xea872313	find_next_bit_inv
++EXPORT_SYMBOL vmlinux 0xeaa88db6	configfs_depend_item
++EXPORT_SYMBOL vmlinux 0xeac89a9d	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0xead4c580	__test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0xead58fb9	print_hex_dump
++EXPORT_SYMBOL vmlinux 0xeadf4ec9	lookup_bdev
++EXPORT_SYMBOL vmlinux 0xeaf16d3e	make_kgid
++EXPORT_SYMBOL vmlinux 0xeb0c2a92	do_splice_to
++EXPORT_SYMBOL vmlinux 0xeb18151e	dm_put_table_device
++EXPORT_SYMBOL vmlinux 0xeb2a98fe	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0xeb2ed062	km_state_notify
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb3a16ea	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0xeb4abed0	ip_mc_check_igmp
++EXPORT_SYMBOL vmlinux 0xeb5b894e	alloc_anon_inode
++EXPORT_SYMBOL vmlinux 0xeb685fa0	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0xeb71a848	raw3270_start_locked
++EXPORT_SYMBOL vmlinux 0xeb71e55c	genl_notify
++EXPORT_SYMBOL vmlinux 0xeb9dc12b	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0xebbf1dba	strncasecmp
++EXPORT_SYMBOL vmlinux 0xebc3d624	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0xebe3f2a0	mutex_lock
++EXPORT_SYMBOL vmlinux 0xec151e51	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0xec1a992e	__napi_complete
++EXPORT_SYMBOL vmlinux 0xec27c4d1	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0xec32caf1	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0xec37195d	downgrade_write
++EXPORT_SYMBOL vmlinux 0xec706b19	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0xec7b24ed	netif_napi_del
++EXPORT_SYMBOL vmlinux 0xec856f4c	simple_lookup
++EXPORT_SYMBOL vmlinux 0xec8df34c	migrate_page_move_mapping
++EXPORT_SYMBOL vmlinux 0xecb880c8	skb_orphan_partial
++EXPORT_SYMBOL vmlinux 0xeccae0a4	dquot_acquire
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xece9a658	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0xecef11eb	iucv_path_connect
++EXPORT_SYMBOL vmlinux 0xecf4bb37	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0xed0e5f4f	simple_dentry_operations
++EXPORT_SYMBOL vmlinux 0xed17f70f	netlink_capable
++EXPORT_SYMBOL vmlinux 0xed1c2a15	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0xed1f0c4d	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0xed2d75aa	memory_cgrp_subsys
++EXPORT_SYMBOL vmlinux 0xed347ffd	__pskb_copy_fclone
++EXPORT_SYMBOL vmlinux 0xed4338cc	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xed5511d9	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed697031	block_write_begin
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedbf68ee	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0xedf3cc6f	get_random_long
++EXPORT_SYMBOL vmlinux 0xedf5e968	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0xee1596e8	mem_cgroup_begin_page_stat
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee3e5e4e	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xee86b514	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0xee8c0d72	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0xee91879b	rb_first_postorder
++EXPORT_SYMBOL vmlinux 0xeea3cd7a	nla_reserve
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeed110d6	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xeeec7e8b	get_io_context
++EXPORT_SYMBOL vmlinux 0xeef161aa	groups_free
++EXPORT_SYMBOL vmlinux 0xef06457a	dquot_reclaim_space_nodirty
++EXPORT_SYMBOL vmlinux 0xef1926ac	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0xef291dd4	seq_puts
++EXPORT_SYMBOL vmlinux 0xef2b8906	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0xef45d32c	__kfifo_init
++EXPORT_SYMBOL vmlinux 0xef5cceda	blk_mq_complete_request
++EXPORT_SYMBOL vmlinux 0xef87a5c1	ip_options_compile
++EXPORT_SYMBOL vmlinux 0xef889101	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0xefa88608	blk_rq_set_block_pc
++EXPORT_SYMBOL vmlinux 0xefa8dabd	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xefb057ad	put_io_context
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefe68164	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0xefee9d2f	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0xeff51455	register_netdev
++EXPORT_SYMBOL vmlinux 0xeffe76a8	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf0024ba5	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf033fafe	sync_inode
++EXPORT_SYMBOL vmlinux 0xf052bbce	fd_install
++EXPORT_SYMBOL vmlinux 0xf067257c	register_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0xf0732b62	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0xf08c67de	napi_alloc_frag
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0a8237a	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xf0aa3047	kernel_connect
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf10526ac	verify_spi_info
++EXPORT_SYMBOL vmlinux 0xf10b5b8d	ccw_device_get_path_mask
++EXPORT_SYMBOL vmlinux 0xf10f81db	sock_cmsg_send
++EXPORT_SYMBOL vmlinux 0xf11543ff	find_first_zero_bit
++EXPORT_SYMBOL vmlinux 0xf11ac5fd	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0xf122c1c5	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xf1269488	dm_register_target
++EXPORT_SYMBOL vmlinux 0xf15694ce	debug_set_level
++EXPORT_SYMBOL vmlinux 0xf17ea804	d_drop
++EXPORT_SYMBOL vmlinux 0xf186210f	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0xf18fe7a8	tty_vhangup
++EXPORT_SYMBOL vmlinux 0xf1969a8e	__usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xf1bc85f2	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0xf1d3f818	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1e8c7ba	iov_iter_kvec
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1f0bafc	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0xf1f5adaf	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0xf1f6ca03	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0xf1f7045b	skb_copy_and_csum_datagram_msg
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf224adfc	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0xf225ed6a	set_security_override
++EXPORT_SYMBOL vmlinux 0xf229818c	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xf22cccf0	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf250c0ca	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0xf27bf3db	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0xf2818c5b	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf2b324ee	free_page_put_link
++EXPORT_SYMBOL vmlinux 0xf2b8465f	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0xf2dc1102	init_task
++EXPORT_SYMBOL vmlinux 0xf2e71187	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf3266162	memcg_kmem_enabled_key
++EXPORT_SYMBOL vmlinux 0xf32e6ace	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0xf32e7a96	bio_copy_data
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf3488d5a	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0xf34a6393	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf38181d9	generic_read_dir
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf399e3fe	file_update_time
++EXPORT_SYMBOL vmlinux 0xf3a20313	dev_get_iflink
++EXPORT_SYMBOL vmlinux 0xf3b51799	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0xf3b86cd5	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0xf3e3c483	install_exec_creds
++EXPORT_SYMBOL vmlinux 0xf3e6402e	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xf3eb3fe2	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0xf3f73e46	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0xf41cf94e	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0xf43a6a13	nf_register_net_hook
++EXPORT_SYMBOL vmlinux 0xf44a9ec4	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0xf4528073	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0xf474c21c	bitmap_print_to_pagebuf
++EXPORT_SYMBOL vmlinux 0xf474fdcb	kfree_const
++EXPORT_SYMBOL vmlinux 0xf48808d8	eth_type_trans
++EXPORT_SYMBOL vmlinux 0xf493f029	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0xf496f4c3	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0xf4b80c36	nf_reinject
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4d3e514	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0xf4d75dbe	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0xf4e2b10f	netlink_ns_capable
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf4f1d73f	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0xf4f26f72	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0xf5224298	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf5697f7a	xfrm6_protocol_deregister
++EXPORT_SYMBOL vmlinux 0xf58c21f9	get_super_thawed
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf5ebe2fb	ccw_device_is_pathgroup
++EXPORT_SYMBOL vmlinux 0xf5f74c7f	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0xf61a4495	csum_and_copy_from_iter
++EXPORT_SYMBOL vmlinux 0xf61c48fd	__skb_get_hash_flowi4
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf63d63dd	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0xf66c9edd	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0xf6770391	mac_pton
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf68bac6c	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0xf6a220df	PDE_DATA
++EXPORT_SYMBOL vmlinux 0xf6a24c9b	make_kuid
++EXPORT_SYMBOL vmlinux 0xf6ae9225	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xf6c40ea6	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6fc8791	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xf72174a8	compat_ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0xf7248ffd	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0xf729534e	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0xf72be9d6	__find_get_block
++EXPORT_SYMBOL vmlinux 0xf7505300	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0xf750e760	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0xf77868e6	d_instantiate
++EXPORT_SYMBOL vmlinux 0xf77d03be	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0xf7917788	keyring_clear
++EXPORT_SYMBOL vmlinux 0xf796623a	kobject_put
++EXPORT_SYMBOL vmlinux 0xf7a198c8	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0xf7b1aac0	udp_disconnect
++EXPORT_SYMBOL vmlinux 0xf7bb51e0	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0xf7c02886	ccw_device_set_options
++EXPORT_SYMBOL vmlinux 0xf7d71918	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0xf7e74261	kmem_cache_alloc_bulk
++EXPORT_SYMBOL vmlinux 0xf7ed77d3	write_cache_pages
++EXPORT_SYMBOL vmlinux 0xf7f2d25d	iucv_message_send2way
++EXPORT_SYMBOL vmlinux 0xf7f39f82	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf8140823	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf83e05da	blk_mq_end_request
++EXPORT_SYMBOL vmlinux 0xf840cdbf	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0xf842dc40	netdev_err
++EXPORT_SYMBOL vmlinux 0xf84ad3b4	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0xf84e1b8e	page_cache_next_hole
++EXPORT_SYMBOL vmlinux 0xf84e3cd7	dev_get_nest_level
++EXPORT_SYMBOL vmlinux 0xf89cfde7	VMALLOC_START
++EXPORT_SYMBOL vmlinux 0xf8e60de6	softnet_data
++EXPORT_SYMBOL vmlinux 0xf8efb3d2	__get_hash_from_flowi6
++EXPORT_SYMBOL vmlinux 0xf8f6ae57	loop_backing_file
++EXPORT_SYMBOL vmlinux 0xf91c7e2e	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0xf94a7484	register_shrinker
++EXPORT_SYMBOL vmlinux 0xf95d5641	ida_destroy
++EXPORT_SYMBOL vmlinux 0xf96827da	elevator_change
++EXPORT_SYMBOL vmlinux 0xf97d7f4c	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0xf99b09d4	generic_write_end
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9b96fdb	pci_msix_vec_count
++EXPORT_SYMBOL vmlinux 0xf9d6800b	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0xf9fc18c5	sget
++EXPORT_SYMBOL vmlinux 0xfa18a76f	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0xfa20d0d2	configfs_unregister_group
++EXPORT_SYMBOL vmlinux 0xfa445400	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0xfa4b0ea9	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0xfa5176b4	scsi_set_sense_information
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa5bf6af	blk_mq_unique_tag
++EXPORT_SYMBOL vmlinux 0xfa6d4c7e	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0xfa8c408d	sock_wfree
++EXPORT_SYMBOL vmlinux 0xfaa09920	trace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0xfac60968	lg_lock_init
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacc8289	copy_from_iter_nocache
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfb055260	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0xfb0898e6	eth_header_cache
++EXPORT_SYMBOL vmlinux 0xfb0eaf6b	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0xfb1c03da	__getblk_gfp
++EXPORT_SYMBOL vmlinux 0xfb2a6ae0	inode_permission
++EXPORT_SYMBOL vmlinux 0xfb37c45d	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb6b6f74	raw3270_request_free
++EXPORT_SYMBOL vmlinux 0xfb725329	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xfb747809	get_ccwdev_by_busid
++EXPORT_SYMBOL vmlinux 0xfb82f131	get_user_pages
++EXPORT_SYMBOL vmlinux 0xfb85fd1d	follow_down
++EXPORT_SYMBOL vmlinux 0xfb8ec191	bdi_destroy
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbafe94a	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0xfbb9a101	pci_map_rom
++EXPORT_SYMBOL vmlinux 0xfbc4f89e	io_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xfbc91b67	igrab
++EXPORT_SYMBOL vmlinux 0xfbcda83c	tcf_em_register
++EXPORT_SYMBOL vmlinux 0xfbf39aa8	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc2876b7	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0xfc2e232f	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0xfc30acf3	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0xfc46bb96	itcw_add_tidaw
++EXPORT_SYMBOL vmlinux 0xfc49dda6	__bforget
++EXPORT_SYMBOL vmlinux 0xfc59d0bc	mempool_destroy
++EXPORT_SYMBOL vmlinux 0xfc5f04c4	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0xfc69c348	simple_setattr
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcca5164	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0xfce7976d	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcee1111	__blkdev_reread_part
++EXPORT_SYMBOL vmlinux 0xfcf97b68	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0xfcffe8ca	sclp_pci_configure
++EXPORT_SYMBOL vmlinux 0xfd10b4f6	lwtunnel_encap_del_ops
++EXPORT_SYMBOL vmlinux 0xfd124f27	bdput
++EXPORT_SYMBOL vmlinux 0xfd1358d1	blk_init_tags
++EXPORT_SYMBOL vmlinux 0xfd25040e	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0xfd593e67	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0xfd6f2e8f	bmap
++EXPORT_SYMBOL vmlinux 0xfd746545	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0xfd751b07	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0xfd86db02	debug_raw_view
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfdc81161	qdisc_list_add
++EXPORT_SYMBOL vmlinux 0xfdce49e8	generic_perform_write
++EXPORT_SYMBOL vmlinux 0xfdd79990	nf_log_unset
++EXPORT_SYMBOL vmlinux 0xfdeeffa7	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0xfdf2cff8	compat_nf_getsockopt
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe17047b	kblockd_schedule_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xfe26fc7c	nr_node_ids
++EXPORT_SYMBOL vmlinux 0xfe3d4b08	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0xfe4041c4	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe6375f3	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xfe6d5dfb	config_group_init
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe7eca4b	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xfea40cb9	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xfebc3e87	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0xfed590f6	vfs_read
++EXPORT_SYMBOL vmlinux 0xfedb7f22	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfee988e7	elevator_init
++EXPORT_SYMBOL vmlinux 0xfef298e9	dev_change_flags
++EXPORT_SYMBOL vmlinux 0xfef9667e	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0xfefbdea0	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0xff171933	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff279aac	ns_capable
++EXPORT_SYMBOL vmlinux 0xff349d2f	compat_ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xff41a165	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0xff50201e	lockref_put_or_lock
++EXPORT_SYMBOL vmlinux 0xff51e23a	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xff570c1a	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0xff5b2c32	kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0xff7052e9	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff82ed64	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0xffa0327f	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0xffa85753	is_bad_inode
++EXPORT_SYMBOL vmlinux 0xffc07803	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0xffd04f47	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0xffd553ff	ipv6_sock_mc_join
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffd8b7d4	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0xfff8dc19	lwtunnel_build_state
++EXPORT_SYMBOL_GPL arch/s390/crypto/sha_common 0x1adc76ca	s390_sha_final
++EXPORT_SYMBOL_GPL arch/s390/crypto/sha_common 0xd4c42f82	s390_sha_update
++EXPORT_SYMBOL_GPL crypto/af_alg 0x012639b3	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x01f19ae4	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0x457a8a0a	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0x592e131c	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0x5b16c603	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x63d34a0e	af_alg_release_parent
++EXPORT_SYMBOL_GPL crypto/af_alg 0x709d575c	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x7876dd6e	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x97bde168	af_alg_link_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xa544b18e	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0xb2b71911	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x5ef70b3e	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x0083e32a	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x1d4633b2	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x5008e7b1	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0xba84d3d8	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x0e1d93fc	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x1ed84a61	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x6afe6476	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x29ff4319	async_xor
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0xe64e2a4e	async_xor_val
++EXPORT_SYMBOL_GPL crypto/authenc 0x587ef278	crypto_authenc_extractkeys
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x7a2982f9	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0xa846941e	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0xb5ab4ed0	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x048e0543	crypto_chacha20_init
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0x7ead122d	crypto_chacha20_crypt
++EXPORT_SYMBOL_GPL crypto/chacha20_generic 0xc94d6fa7	crypto_chacha20_setkey
++EXPORT_SYMBOL_GPL crypto/cryptd 0x662c9c1c	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x6ed943fa	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x7e68c4eb	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xbd5cc79e	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xcc1fb973	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0xd8934272	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xdb31a269	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0xdc435dec	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xe7f0d75e	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0xf125b9a9	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/des_generic 0xf8c78d49	__des3_ede_setkey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/lrw 0xd64784f6	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x277397f6	shash_ahash_mcryptd_final
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x37a94fc3	shash_ahash_mcryptd_update
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x656383ce	mcryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x8347667c	mcryptd_flusher
++EXPORT_SYMBOL_GPL crypto/mcryptd 0x940fea13	mcryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xc471e7a1	mcryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xd0e5b4e9	shash_ahash_mcryptd_digest
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xdb89e325	shash_ahash_mcryptd_finup
++EXPORT_SYMBOL_GPL crypto/mcryptd 0xe6941907	mcryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3bd37495	crypto_poly1305_setdesckey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x3f8385b7	crypto_poly1305_setkey
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0x84721ca8	crypto_poly1305_update
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xb9380013	crypto_poly1305_init
++EXPORT_SYMBOL_GPL crypto/poly1305_generic 0xf69b6ce0	crypto_poly1305_final
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0xc01c1d1f	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x1b302355	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0xe1e70f29	xts_crypt
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x37081fb7	of_fpga_mgr_get
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x4e2dab23	fpga_mgr_unregister
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x511d7c5c	fpga_mgr_firmware_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0x82a85e75	fpga_mgr_put
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xb89e9cbf	fpga_mgr_buf_load
++EXPORT_SYMBOL_GPL drivers/fpga/fpga-mgr 0xfea3f4b7	fpga_mgr_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x1151d17f	intel_th_free
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x3c9a15aa	intel_th_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x5b6ff8f4	intel_th_alloc
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0x908a758f	intel_th_set_output
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xa0108eaa	intel_th_driver_register
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xa5eb2115	intel_th_trace_enable
++EXPORT_SYMBOL_GPL drivers/hwtracing/intel_th/intel_th 0xd4cc0360	intel_th_trace_disable
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x0589e439	stm_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x060da7d1	stm_unregister_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0x177e7171	stm_source_register_device
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xac15ec46	stm_source_write
++EXPORT_SYMBOL_GPL drivers/hwtracing/stm/stm_core 0xd48f5ec8	stm_source_unregister_device
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x00472318	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x01d3b9ec	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x04698e56	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x13de3a79	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x17951453	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x25e0e29d	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2e196d5e	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x40eb8ce7	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x480d259c	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x50f963e8	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5de357e7	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x734e256b	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x76478393	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7b3bd777	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7dc83a0f	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x99e96e83	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa1ee0faa	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa20d04ab	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa5fc5b3c	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa7aae64e	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa8749832	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xae6f41b8	__tracepoint_bcache_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xaffc6d0d	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb7de1e4f	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd0e0d4c5	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd4c1f373	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd5c4d672	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe08585f9	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe55e9c32	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf7cf2aa7	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfdc6ed3a	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x258650ce	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x26e0baf1	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x37053c3b	dm_cell_promote_or_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x3943a1ec	dm_cell_visit_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x57f94761	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6696449d	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x753e20b2	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x7824e16d	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xbea9d701	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xd859dd37	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x41407800	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6aba7f5e	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9310ba06	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9c256008	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa1d2413a	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa448e19f	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xafbda3f3	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xcbb1bae2	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x6118e911	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x65f462cc	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x8f132724	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x9e982d9e	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x9f53d912	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x9f779012	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xa4228567	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x26bc38b2	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x724d9780	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x1be153f4	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3c578a24	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4430764e	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x45ab972a	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4e197d14	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x88e8c4d7	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x89742a32	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa602e0ea	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa68e1f06	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfad9d53a	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfc62ef4e	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0604db1b	dm_btree_remove_leaves
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x07c4a1ea	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x24fa6664	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f40da68	dm_bm_set_read_write
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32350144	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3646e38f	dm_tm_issue_prefetches
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x3ad0f55b	dm_bm_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42d1207a	dm_btree_lookup_next
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x4360913e	dm_btree_find_lowest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x48e323be	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5aed1dd7	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x67660b4e	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7657e859	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x80afbcf5	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x8605e0ec	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x88295b96	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x8c195a05	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x95a52abd	dm_bm_is_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x98925a60	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa7e46220	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab96bd2d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xab9b03ca	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xba47c03a	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xe118796a	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xe2d7194c	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed58cfa1	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf12ec3cd	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xffff2ac3	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x00b15733	mlx4_mr_rereg_mem_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x045b360a	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0530a885	mlx4_get_active_ports
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0572d85c	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x06c79a71	mlx4_mr_hw_change_pd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x08565256	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b943a8d	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0c09cb46	mlx4_slave_convert_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0c0f9f27	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0c8486ff	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0d4ee321	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x13138423	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1741ea0b	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1ba0b01d	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x20e668f3	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x21a7d408	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x221756e2	mlx4_get_counter_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2263b8bf	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x233bd93f	mlx4_unbond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2549ba49	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x283c26e0	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2b951e21	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2d4a258d	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2ece4936	mlx4_get_base_gid_ix
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2f95e247	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x38095393	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x38accea8	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3e860563	mlx4_get_default_counter_index
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3f0fb727	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x447f2cc8	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4769414c	mlx4_mr_hw_change_access
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4acf02af	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4d051fd1	mlx4_mr_hw_get_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4fb11c6c	mlx4_update_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4fc5b7bb	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x50c95de8	mlx4_find_cached_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x51197a6d	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x51e1f8e3	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x54a5ad5c	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5a270fe8	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5ce306e0	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x62b36539	mlx4_get_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x63a91eb1	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x63efc5f7	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6623fe5a	mlx4_get_vf_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x66df0ffd	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x67f2a903	mlx4_set_admin_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x682e745e	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x69373555	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x695336d1	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6d88095b	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6d8b38db	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6f1fb0f3	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x70f95c66	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7412d177	mlx4_port_map_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x74d342da	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7982a978	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7cd94971	mlx4_ACCESS_PTYS_REG
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7eef954f	mlx4_set_vf_rate
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7f6a9723	mlx4_config_vxlan_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x83c1285e	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x851d9ea9	mlx4_bond
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x879e316b	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8892f30f	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8f371b24	mlx4_mr_hw_put_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9151106d	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x91d71117	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9565de35	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9638a845	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x96e9e34d	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9b793fba	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9cf9595d	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9fc51aff	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa463f277	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa49197e0	mlx4_vf_set_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa738a31c	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa8610451	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa9179f22	mlx4_phys_to_slaves_pport_actv
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaa034206	mlx4_phys_to_slave_port
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb189937f	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb20c130b	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb345b1f3	mlx4_mr_rereg_mem_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb6f34717	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbaf9327c	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb78e222	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbc197b39	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbf37e2ca	mlx4_vf_get_enable_smi_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc0d27abd	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc15735c9	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc341477e	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc36b3ed8	mlx4_get_slave_default_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc4d607e2	mlx4_mr_hw_write_mpt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc5011ffb	mlx4_config_dev_retrieval
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc77c5f34	mlx4_FLOW_STEERING_IB_UC_QP_RANGE
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xca362971	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcbd7ff71	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xce13cc93	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd172eadc	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd223248b	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd3880960	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd38a2e4c	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd493b1b8	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd54480fe	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd5c09df4	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdc5e52fb	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdd49a234	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xde3dcd31	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe06b2cc8	mlx4_vf_smi_enabled
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe14f6fcf	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe19373e8	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe1f31878	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe4faacb2	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe5deacaa	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe60c26ef	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xef768210	mlx4_replace_zero_macs
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf07a0861	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf0ca3f6d	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf2e3b310	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf4f58a4f	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf6475d3d	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf706ceb1	mlx4_get_internal_clock_params
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf76a7af3	mlx4_phys_to_slaves_pport
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xff27b7ca	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xffe3e27e	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x077389d6	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x09543b3d	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x10055e84	mlx5_query_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x11365704	mlx5_query_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x11fe29ea	mlx5_query_port_ptys
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1a83c36d	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1ed83b9c	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2128188d	mlx5_query_hca_vport_context
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x22ed3e24	mlx5_query_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x23fb152f	mlx5_query_port_max_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x27058da4	mlx5_modify_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x289369af	mlx5_query_hca_vport_gid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2bbe0080	mlx5_modify_nic_vport_mac_list
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x351ca3b1	mlx5_set_port_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x38fb897b	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3b003ed1	mlx5_set_port_admin_status
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x42a9507b	mlx5_query_port_proto_admin
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4711c6d8	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x47fd4c0e	mlx5_query_nic_vport_vlans
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4884fa37	mlx5_modify_nic_vport_promisc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x4a82c8e9	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x52336422	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x55696410	mlx5_query_port_link_width_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5e8c8e90	mlx5_query_port_proto_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x603d370f	mlx5_query_hca_vport_node_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7fe94c03	mlx5_query_port_oper_mtu
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x944b6c6d	mlx5_query_nic_vport_mac_address
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x990e073f	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa4a8f0e6	mlx5_query_port_proto_oper
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xae2eb4c4	mlx5_core_page_fault_resume
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb0a9fb00	mlx5_query_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb1575ca5	mlx5_query_hca_vport_pkey
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xbbe7caf8	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd4fe771e	mlx5_query_vport_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdfb5f067	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdffed502	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe08f5cea	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe4f4b483	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xeab8d915	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xec29e2a4	mlx5_db_alloc_node
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xeffe3b2c	mlx5_set_port_pause
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf1aa4e34	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf1cf612b	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf212a4b3	mlx5_query_port_vl_hw_cap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf80f2781	mlx5_query_hca_vport_system_image_guid
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf814d0db	mlx5_set_port_proto
++EXPORT_SYMBOL_GPL drivers/net/geneve 0x1ddeb2da	geneve_get_rx_port
++EXPORT_SYMBOL_GPL drivers/net/geneve 0xc27242d0	geneve_dev_create_fb
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x06be78b5	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x3cb81eaa	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xb862da5a	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xf0b744c1	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0xa6f1cfa6	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x040221cb	bcm_phy_read_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x22f1d3be	bcm_phy_write_misc
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x2d44b534	bcm_phy_ack_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x2e3e2238	bcm_phy_config_intr
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x3bba3732	bcm_phy_write_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x641c2046	bcm_phy_read_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x9eb7ac52	bcm_phy_enable_eee
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0x9f2dac9a	bcm_phy_read_exp
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xa6131011	bcm_phy_enable_apd
++EXPORT_SYMBOL_GPL drivers/net/phy/bcm-phy-lib 0xa6977fcb	bcm_phy_write_shadow
++EXPORT_SYMBOL_GPL drivers/net/phy/fixed_phy 0x43d01fc1	fixed_phy_add
++EXPORT_SYMBOL_GPL drivers/net/phy/fixed_phy 0x608ef673	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL drivers/net/phy/fixed_phy 0x95f7304f	fixed_phy_register
++EXPORT_SYMBOL_GPL drivers/net/phy/fixed_phy 0xab5a5de4	fixed_phy_del
++EXPORT_SYMBOL_GPL drivers/net/phy/libphy 0x4dadf3d6	devm_mdiobus_alloc_size
++EXPORT_SYMBOL_GPL drivers/net/phy/libphy 0x9e3f8201	devm_mdiobus_free
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0xa6664e38	vxlan_dev_create
++EXPORT_SYMBOL_GPL drivers/net/vxlan 0xc8806d18	vxlan_get_rx_port
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x08bf2960	dasd_generic_restore_device
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x09c40bbb	dasd_free_block
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x19227556	dasd_nopav
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x1a22fe89	dasd_generic_probe
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x257e4295	dasd_generic_path_operational
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x2fa5df19	dasd_generic_path_event
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x314b9129	dasd_device_is_ro
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x5564a1aa	dasd_put_device_wake
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x584568c8	dasd_generic_uc_handler
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x584c9136	dasd_generic_set_online
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x627a037d	dasd_get_sense
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x64ef7ecd	dasd_generic_last_path_gone
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x7729a916	dasd_generic_handle_state_change
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x8560f86d	dasd_generic_read_dev_chars
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x957f72dc	dasd_generic_verify_path
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x978e3a85	dasd_generic_notify
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x9c4848ca	dasd_flush_device_queue
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0x9d49b912	dasd_alloc_block
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0xb31f3899	dasd_wakeup_cb
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0xb38fe028	dasd_page_cache
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0xc6e8dc08	dasd_device_remove_stop_bits
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0xe70c4437	dasd_generic_remove
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0xefc24d83	dasd_generic_set_offline
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0xf15784f5	dasd_nofcx
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0xf8e98572	dasd_generic_pm_freeze
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0xfe727642	dasd_generic_shutdown
++EXPORT_SYMBOL_GPL drivers/s390/block/dasd_mod 0xff7ed75f	dasd_device_set_stop_bits
++EXPORT_SYMBOL_GPL drivers/s390/cio/eadm_sch 0x24f2806e	eadm_start_aob
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0x2070f615	qdio_free
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0x30ea084d	do_QDIO
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0x40d8e0e9	qdio_allocate
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0x4afa0766	qdio_shutdown
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0x51016153	qdio_activate
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0x52d49616	qdio_alloc_buffers
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0x73852c2c	qdio_pnso_brinfo
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0x75e5ec56	qdio_get_ssqd_desc
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0x8184dc41	qdio_reset_buffers
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0x919b89dd	qdio_establish
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0xc6755f2b	qdio_release_aob
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0xc8e3f47d	qdio_free_buffers
++EXPORT_SYMBOL_GPL drivers/s390/cio/qdio 0xcd4af5dd	qdio_allocate_aob
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x03ba9058	qeth_print_status_message
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x0b3c570b	qeth_prepare_ipa_cmd
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x16c1b604	qeth_send_ipa_cmd
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x17c142ad	qeth_set_recovery_task
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x19047e71	qeth_query_ipassists
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x1fb8be7a	qeth_threads_running
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x2248c066	qeth_close_dev
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x24eb92c4	qeth_send_setassparms
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x2cd9e4cc	qeth_core_header_cache
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x2f06e489	qeth_clear_cmd_buffers
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x304ee325	qeth_core_get_next_skb
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x325b65c6	qeth_queue_input_buffer
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x36336777	qeth_setadp_promisc_mode
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x3de2a918	qeth_init_qdio_queues
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x3e6ece65	qeth_get_elements_no
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x3ee79eae	IPA_PDU_HEADER
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x3f0aea55	qeth_schedule_recovery
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x43594e0f	qeth_get_elements_for_frags
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x4a2ffd56	qeth_clear_working_pool_list
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x4b521a54	qeth_wq
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x4bf697ab	qeth_qdio_input_handler
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x4ff2f1f0	qeth_generic_devtype
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x51a5262b	qeth_prepare_control_data
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x54397780	qeth_wait_for_threads
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x54aaeed8	qeth_release_buffer
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x5641f8a8	qeth_snmp_command
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x564fdeae	qeth_trace_features
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x5a423cd2	qeth_do_send_packet_fast
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x5e608b86	qeth_qdio_start_poll
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x5ec9e5ed	qeth_qdio_clear_card
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x5f52f3b9	qeth_card_hw_is_reachable
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x5fb292f7	qeth_hdr_chk_and_bounce
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x632c6f3e	qeth_set_access_ctrl_online
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x6d4cf347	qeth_start_ipa_tx_checksum
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x6defc507	qeth_wait_for_buffer
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x700607ae	qeth_get_ipacmd_buffer
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x7b8e45b3	qeth_query_switch_attributes
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x80159cf0	qeth_core_card_list
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x8222d9bb	qeth_get_priority_queue
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x825124c1	qeth_core_get_sset_count
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x848f4e7f	qeth_clear_qdio_buffers
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x850991eb	qeth_core_get_ethtool_stats
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x85639daf	qeth_change_mtu
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x8b405917	qeth_clear_recovery_task
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x8d21d0ee	qeth_configure_cq
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x8d5ca1f4	qeth_core_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x954c4d4f	qeth_send_simple_setassparms
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0x9d177401	qeth_mdio_read
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xa3f73ce3	qeth_send_control_data
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xa70de99a	qeth_device_blkt_group
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xa7abca37	qeth_qdio_output_handler
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xb3c1471d	qeth_do_run_thread
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xbb44d478	qeth_hw_trap
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xbbd91444	qeth_set_allowed_threads
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xbf3e597a	qeth_clear_thread_running_bit
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xbf80caa0	qeth_device_attr_group
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xc0dc8e9d	qeth_set_rx_csum
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xc47cd5ba	qeth_query_oat_command
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xcb34d034	qeth_tx_timeout
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xce11c266	qeth_check_qdio_errors
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xd1c1919f	qeth_setadpparms_change_macaddr
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xd25267f1	qeth_dbf
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xd52ae66f	qeth_core_ethtool_get_settings
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xe3bbd7c3	qeth_do_send_packet
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xe5bf3a3c	qeth_dbf_longtext
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xe8270a23	qeth_clear_thread_start_bit
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xe8b55b60	qeth_query_setadapterparms
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xe9f23679	qeth_core_hardsetup_card
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xebee9b52	qeth_get_stats
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xf706a267	qeth_realloc_buffer_pool
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xfc8ab814	qeth_clear_ipacmd_list
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth 0xffc040ae	qeth_core_get_strings
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth_l2 0x0996d358	qeth_l2_discipline
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth_l2 0x1743fa7d	qeth_bridgeport_query_ports
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth_l2 0xf72fbe47	qeth_bridgeport_an_set
++EXPORT_SYMBOL_GPL drivers/s390/net/qeth_l3 0x24e7a576	qeth_l3_discipline
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0581d7f8	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x05fd0ef4	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x18a5c3e9	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x1da85242	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x1e49bb07	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x274a0862	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x3450eda9	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x394b72e5	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x3b437080	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x49d4d381	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5c1f5954	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5c7d6417	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5ce433d9	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x7cb3c6f5	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xcaf26967	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf8f497c6	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x0efe1fe5	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x3c710d21	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x3ff8fbea	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x4bb802dd	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x4dd2f263	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xedd11c92	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x07bd11b4	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x22c0d954	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2b2a109d	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2b6f4f85	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x39514104	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3a605f15	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3bef2f73	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x45b03644	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x460680bc	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4731dbba	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x54dea7fe	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x598fb748	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x61efbed5	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x672d5c62	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x698a43d4	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7526e8d0	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7566ac96	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7619860d	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7818293a	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x78bdf137	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x812662c4	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x81f58958	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x841a9937	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d303b1b	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8fa22dbf	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa41515d9	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa6d9df6f	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa7967eaa	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa8c39d38	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa9e2f6bf	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xaa6aba48	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb610353e	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbce450e8	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbd45eee1	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbf8c9136	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd9bb5f24	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe45ac8d1	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe6a92185	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe91711c1	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xea28ffb6	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xedab85fb	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xede938bc	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xee9c7d23	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf2b11ab3	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfc9586b2	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x15946e1c	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x1a4fcd00	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x293ecc16	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2d8be941	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x41704dc1	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x47ed0403	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x48248cbd	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4852480f	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x52e8972c	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x60a86b8f	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x7e4253b4	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x95e84ace	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x98c980b1	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x997238f3	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xc92f2a2f	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xd29cdde0	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe501e6c2	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1475c36a	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x17a702bd	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x26eef8a0	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x289e7b28	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2c70824b	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x360d832e	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3bc60080	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3e1f0905	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x50889f3c	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5b372162	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x620eda16	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6a1e9608	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6e666c21	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7b438f83	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7e1760e8	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x90be78af	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x91f37f38	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xaa72132e	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb240b8a5	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xcd5490d4	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe1114389	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xec437717	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf6af2ada	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x042d2c51	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x14a4a17e	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x230f2a6d	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x235fdf97	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2bd8d760	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2e92ced2	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x323d2881	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4817f75e	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x52897ff0	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5b8a9bd2	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x601e1080	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x61a427fe	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x64e43432	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6b291db8	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x772640d1	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7e4d5a8b	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7f4441a7	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x831e5d15	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x84a005f1	iscsi_get_router_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8e6f5737	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x90142f10	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x92d6ec84	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9552edeb	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9939e4c8	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9abedd42	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9bfa906f	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa72ccaa9	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb038d744	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb0f23eae	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb225d9cf	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xba53159f	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xbc071179	iscsi_get_ipaddress_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd32a236f	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd669014a	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd7d23da7	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe81d0f7f	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf63ef43f	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf7e82804	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf8583110	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfb2ee404	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfd29c089	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfe4cf79b	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xc44dae78	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xf0275b2b	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xf5489044	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xffe9ee21	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x1e4affcc	spi_populate_tag_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x147cc829	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x2b40aa88	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x2bcb9e14	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x31150201	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x9a9be5e9	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xcedc0634	srp_stop_rport_timers
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xee891cc0	srp_tmo_valid
++EXPORT_SYMBOL_GPL drivers/tty/serial/serial_core 0x690baccf	uart_insert_char
++EXPORT_SYMBOL_GPL drivers/tty/serial/serial_core 0xa85b3fa8	uart_handle_cts_change
++EXPORT_SYMBOL_GPL drivers/tty/serial/serial_core 0xc210976a	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3567743b	vfio_external_user_iommu_id
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x5d6e3d54	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x78747382	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xbce14088	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc1d989c5	vfio_external_check_extension
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc3ac11a5	vfio_group_get_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc4913442	vfio_group_put_external_user
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xc56b1cb6	vfio_external_group_match_file
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xd05aea4d	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xeacc2f0f	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0x54257835	vfio_virqfd_disable
++EXPORT_SYMBOL_GPL drivers/vfio/vfio_virqfd 0xfd9949fd	vfio_virqfd_enable
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0347e0ad	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x08541e34	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0eb3b73b	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x156cf8fb	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1930b9fc	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1ebafaa5	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2125cdb3	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x26aa0bd6	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2d86cd64	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x42e3c42b	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4f5eab60	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5605bd94	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x80664392	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x856506be	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8cb0bfed	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8ccc2bc7	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8eb497bb	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa47c67de	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xaf961071	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xda7d5333	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xdbb3ce8f	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xdd9c4337	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe02d06ae	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe18e9fb8	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe1eb5438	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe6e61d4f	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xecce48ba	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfa1aad5b	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfd6bc50b	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfe965b70	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x807662b2	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x8bfbad19	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdcf381b6	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x0a2e2eb8	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x15fb201c	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x1a7193b7	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x2cc9a1ff	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x39dceba3	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x8723e797	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x8daf227a	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x05e747d7	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x06aaa5aa	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0b12a28b	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0c8bb39b	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0f4e7def	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0ffa35a3	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x10420961	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x15a503c6	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x16288ee3	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x16371371	nfs_pgio_header_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x18654c5f	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x198a010b	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1abe063c	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1b79c7ec	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1bb92512	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1c125a0b	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1c4a377a	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x202cf9c6	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x20bf4185	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x22b20f01	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x24ad99d2	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2754d23e	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x28523892	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x28ab82e1	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x29d0c75c	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2c1627ab	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2c283de3	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x36574332	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x37838a34	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3e89ace3	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3fb24613	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x40739385	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x420edfae	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x44da545d	nfs_writeback_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x46554cee	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x48d30171	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4ad0ba9a	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4cb9e001	recover_lost_locks
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x52592699	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x53f9f9c3	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x55644fad	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x56e6d526	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x56fa6ed1	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x584b8482	nfs_inc_attr_generation_counter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x58bc8f97	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x592c46c1	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5ee21bfb	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5f79d231	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5fcee119	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x62920b7f	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6a77425d	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6d87e38b	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x72f9011e	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x73e84bdf	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x74b4a691	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x76ac902f	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x76dcca1a	__tracepoint_nfs_fsync_exit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7ae72ecd	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7bd0274e	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7dc58aed	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7f0fe26c	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x830a98d5	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x838f70f4	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x83e39f7f	nfs_fscache_open_file
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x89365f16	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8978ebc7	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x89902947	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8a3d663a	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8b0f950e	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8c960e8b	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a3c8fc	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x956b981d	nfs_pageio_resend
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9a48faf9	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9edb05a8	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa4f18e74	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa700360b	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xae1b6f4f	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xae213a55	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaeaaaa05	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaf6eec8c	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb06832a3	nfs_pgio_header_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb2861eb7	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb297d394	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb3d6e793	nfs_initiate_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb3f85c6e	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb450a6d5	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb606e716	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb6f46a6f	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb80fd99d	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb8dd976e	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbdea5e4f	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbe734293	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc19f7b3e	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc31157c9	nfs_get_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc32d1a44	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc38a75b0	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4ff1e9f	nfs_auth_info_match
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xca2a9979	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcb360e62	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcbc17f03	nfs_put_lock_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xccc2f104	__tracepoint_nfs_fsync_enter
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xce9f3db5	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2513081	_nfs_display_fhandle_hash
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd641360d	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd68879fc	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd876f6bf	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd908aa23	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdacd4257	nfs_sync_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdc2e5e41	nfs_request_add_commit_list_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdd71b808	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe10b66e6	nfs_server_remove_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe10db30c	nfs_generic_pgio
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe165dacb	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe269698b	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe286d4d5	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe2e983d4	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe4d47c97	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe557a04c	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe8592f52	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe92c510d	nfs_direct_set_resched_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe949c629	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xea1650d4	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xea7d4523	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeb7e9651	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xed1a130d	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf037a645	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf16ed65b	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf4c777da	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf69e2bc1	nfs_pgio_current_mirror
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf81ec5a7	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf8970e8a	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb7ee006	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc619abd	_nfs_display_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfcff7264	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv3 0xe0d67a1b	nfs3_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x001f6997	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x023bec08	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x04086ed6	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x04766ea9	pnfs_error_mark_layout_for_return
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x054bef45	layoutstats_timer
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0607200c	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0770d078	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x081c5702	nfs4_pnfs_ds_add
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0b34f80e	pnfs_put_lseg_locked
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0ec50e65	nfs4_schedule_lease_moved_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x140540a3	pnfs_generic_layout_insert_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x14f35ce3	pnfs_generic_recover_commit_reqs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x15fc5837	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x21a4e8ee	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x21e89837	nfs4_pnfs_ds_connect
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x22ee2510	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x36af9a79	nfs41_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3c0b497a	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x4185dd91	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x43a03d35	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x465135ac	pnfs_report_layoutstat
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x54010c22	nfs4_decode_mp_ds_addr
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x54b6b5c4	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x57084c82	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x598146aa	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5f278299	nfs4_pnfs_ds_put
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6691ec4f	__tracepoint_nfs4_pnfs_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x68d9c1df	pnfs_generic_prepare_to_resend_writes
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69d3558d	pnfs_generic_rw_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6c3ef6d8	pnfs_generic_clear_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x776a0cec	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7bdeb84d	pnfs_layout_mark_request_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7c4d2d2a	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8146bff0	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x83ae6aaa	nfs4_pnfs_v3_ds_connect_unload
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x84665b14	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x85cc084d	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x85d084a7	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8ebb8ae2	pnfs_layoutcommit_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9611e06e	pnfs_read_resend_pnfs
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x962ff6d5	pnfs_nfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9d6335ea	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9e5f6cbc	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa06d13b0	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xac62d225	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb71cbe99	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb8d91df9	nfs4_schedule_migration_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb943b5c1	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbbbf4d0e	pnfs_generic_write_commit_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbc4975c7	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc3331772	nfs_map_string_to_numeric
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc8e23963	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcb8589fc	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd21b4d53	__tracepoint_nfs4_pnfs_commit_ds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd62631d4	nfs40_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd780ffdf	pnfs_generic_sync
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xda994a8d	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdff4e37c	__tracepoint_nfs4_pnfs_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe52c1851	nfs4_sequence_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe9c6df72	pnfs_generic_pg_cleanup
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe9f1be46	pnfs_generic_commit_pagelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf4384bc2	pnfs_generic_scan_commit_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf7430ddc	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf999267e	pnfs_generic_commit_release
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfe103e31	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xff10ccfa	nfs4_find_or_create_ds_client
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x1fe1e1ad	locks_end_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0x7fe22a0a	locks_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xd0299317	opens_in_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/grace 0xe30ca23d	locks_start_grace
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x59083ecc	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x5cb9a244	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x11736b03	__mlog_printk
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1e987caf	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4f6e697e	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x521e0726	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x77ed48dd	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x81a17396	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa00cfeec	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa1ae48e1	o2hb_check_node_heartbeating_no_sem
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbc7f1974	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc45b2db9	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xe1f6a0f2	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf56c2017	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x1ac2f709	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x3e877361	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x43ea3d5f	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x5f727c4e	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7016820d	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x8c4f298a	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x269d63fd	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x316904e1	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3bcef5f3	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x40718c92	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4226705d	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x424241c9	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x60f4bcef	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x71465995	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x9ccafa05	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xa06fbc10	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbf9068ab	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xc40d8095	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xd16ab9a5	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xda2053b6	ocfs2_is_o2cb_active
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL kernel/torture 0x1b2fca48	torture_must_stop_irq
++EXPORT_SYMBOL_GPL kernel/torture 0x1be7d8be	torture_onoff_failures
++EXPORT_SYMBOL_GPL kernel/torture 0x1c04438e	_torture_stop_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x21ab34ac	_torture_create_kthread
++EXPORT_SYMBOL_GPL kernel/torture 0x3e9619f5	torture_onoff_stats
++EXPORT_SYMBOL_GPL kernel/torture 0x4c7529bd	torture_shutdown_absorb
++EXPORT_SYMBOL_GPL kernel/torture 0x52665f8b	torture_random
++EXPORT_SYMBOL_GPL kernel/torture 0x5346b23b	torture_shuffle_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0x6364b2f0	stutter_wait
++EXPORT_SYMBOL_GPL kernel/torture 0x679d9e50	torture_must_stop
++EXPORT_SYMBOL_GPL kernel/torture 0x688e6a64	torture_cleanup_end
++EXPORT_SYMBOL_GPL kernel/torture 0x6bdeda8f	torture_onoff_init
++EXPORT_SYMBOL_GPL kernel/torture 0x8b0e1d2f	torture_shuffle_init
++EXPORT_SYMBOL_GPL kernel/torture 0x9393908f	torture_shuffle_task_register
++EXPORT_SYMBOL_GPL kernel/torture 0xc1361afc	torture_onoff_cleanup
++EXPORT_SYMBOL_GPL kernel/torture 0xc6527045	torture_init_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xc67a49d4	torture_cleanup_begin
++EXPORT_SYMBOL_GPL kernel/torture 0xdbc5277a	torture_shutdown_init
++EXPORT_SYMBOL_GPL kernel/torture 0xe6989fd3	torture_init_end
++EXPORT_SYMBOL_GPL kernel/torture 0xe9ff1468	torture_stutter_init
++EXPORT_SYMBOL_GPL kernel/torture 0xf6d34fb5	torture_kthread_stopping
++EXPORT_SYMBOL_GPL lib/842/842_compress 0x1ce013cf	sw842_compress
++EXPORT_SYMBOL_GPL lib/842/842_decompress 0x0d22f116	sw842_decompress
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x05753d9b	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x185db0bd	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x18efd32f	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x391d9714	raid6_call
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xa51bfd9f	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x096acf0d	base_inv_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x0ea96336	base_inv_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x23bf768a	base_inv_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x28a031c0	base_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x5a14472f	base_inv_old_false_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x71398562	base_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0x90ae1c4c	base_old_true_key
++EXPORT_SYMBOL_GPL lib/test_static_key_base 0xec4c111e	base_false_key
++EXPORT_SYMBOL_GPL net/802/garp 0x2dfc4e23	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0x2fa1922b	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0x6547cfbf	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0x95379974	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0xd734adc5	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0xffa060f8	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x4cf265b4	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x51912fe4	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x589b514d	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x9ad27350	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xd4bee2cb	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0xf03de4aa	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/stp 0xb5aaeb56	stp_proto_register
++EXPORT_SYMBOL_GPL net/802/stp 0xffd5085a	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x6a4b8fae	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x8a60b6c3	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/bridge/br_netfilter 0x0cb0f8b7	br_netfilter_enable
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x0a1133df	br_deliver
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x4f4c0b3c	nf_br_ops
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x59054fa4	br_multicast_list_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x83960215	br_handle_frame_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0x9b22f414	br_multicast_has_querier_adjacent
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xcfad7258	br_multicast_has_querier_anywhere
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xe278c729	br_forward_finish
++EXPORT_SYMBOL_GPL net/bridge/bridge 0xf1a2b224	br_dev_queue_push_xmit
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x20f6ce4c	nft_bridge_ip6hdr_validate
++EXPORT_SYMBOL_GPL net/bridge/netfilter/nf_tables_bridge 0x6e4d8064	nft_bridge_iphdr_validate
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x08371fa4	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0d05092c	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x13570e0c	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1dfd36d6	compat_dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x304a74b1	compat_dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x313e8bfe	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x43dc02a6	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4e4bc548	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4f148bbe	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x51b7b76f	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59814a84	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x668f2628	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x67d868e3	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x69c5eb57	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6df08ef2	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x785cb12a	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x8349bbb8	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x844df451	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x95ac018c	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x96c25737	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x96f1b148	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9acf3715	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9e977023	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa68875d9	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa6eb141e	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa930c92a	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xaf7cb69a	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb1f8a82f	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb80e2df6	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc3fba7f4	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc717ee4f	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd22e36ab	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd6c96063	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd6f8ef05	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd8f86a68	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe5cd8bf7	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe70e4615	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x15837a0c	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x2ea140c8	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x72bf4260	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x8c0ab3ed	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x9488769c	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xc0309bb3	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x8759b197	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xc09ce595	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x10608515	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x33ef0ea1	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x6a8afb9f	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x77fab5ff	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xcd03e1c6	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xdfe531eb	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/ip_gre 0xf30a9165	gretap_fb_dev_create
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x09505ef0	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x1adc48ed	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x318b6d89	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x32c1aa6c	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x3fe5abb6	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x5d4c0945	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x72ccf274	__ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x7b0f0403	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8ceb15b0	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x9433f95e	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x9af9aa12	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xa09e5db4	ip_tunnel_encap_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xd2022ba2	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xeaa018f0	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xebaa7b70	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0x6bf83758	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0x63d297f0	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_dup_ipv4 0x6fe2bd0a	nf_dup_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x42d11eaa	nf_nat_ipv4_out
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x63e3a90d	nf_nat_ipv4_local_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x867e2962	nf_nat_ipv4_in
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xb26e1bc5	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xbd8b722c	nf_nat_ipv4_fn
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0x3f5c468e	nf_nat_masquerade_ipv4_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xcc8fc8ac	nf_nat_masquerade_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_masquerade_ipv4 0xfedbf252	nf_nat_masquerade_ipv4_register_notifier
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x10f2fd75	nf_reject_iphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x1ffcaba8	nf_reject_ip_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0x8f385baa	nf_send_unreach
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xb0eec586	nf_reject_ip_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_reject_ipv4 0xeeab387f	nf_send_reset
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_tables_ipv4 0x3426a9ff	nft_af_ipv4
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x364b4c36	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x3f7e7ebc	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x8716fbcb	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x8eae5738	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xf31cf249	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0x792d0602	udp_tun_rx_dst
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xa254163c	udp_tunnel_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xb59a2815	setup_udp_tunnel_sock
++EXPORT_SYMBOL_GPL net/ipv4/udp_tunnel 0xd1a448c8	udp_tunnel_sock_release
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x0b0f419d	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x1ba8e50d	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x4e067925	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x80baf5ad	ip6_tnl_dst_destroy
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x9e82cdef	ip6_tnl_dst_init
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xc710f0ae	ip6_tnl_dst_get
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xd19198f6	ip6_tnl_dst_set
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0x59b690c3	udp_tunnel6_xmit_skb
++EXPORT_SYMBOL_GPL net/ipv6/ip6_udp_tunnel 0xae5c5565	udp_sock_create6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0xb4f963a6	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x2f0c444a	nf_ct_frag6_gather
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x5079a8a2	nf_ct_frag6_consume_orig
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_dup_ipv6 0x36d97851	nf_dup_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x2429b2cc	nf_nat_ipv6_in
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xb3b73107	nf_nat_ipv6_out
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xc04324ab	nf_nat_ipv6_local_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xc483af6d	nf_nat_ipv6_fn
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0xe739550c	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x2293972c	nf_nat_masquerade_ipv6_unregister_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0x38d4401a	nf_nat_masquerade_ipv6_register_notifier
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_masquerade_ipv6 0xb1c55192	nf_nat_masquerade_ipv6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0x4c3d148b	nf_reject_ip6_tcphdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xa5a7f493	nf_send_unreach6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xb67eeab7	nf_reject_ip6_tcphdr_get
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xcf9f1d01	nf_send_reset6
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_reject_ipv6 0xe382d913	nf_reject_ip6hdr_put
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_tables_ipv6 0x16d781ef	nft_af_ipv6
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x304fe64e	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x377e9058	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x41e35281	l2tp_session_get_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x5539341c	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x5cd82bb8	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x6b595886	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x772f011b	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x80537e98	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x886b17e8	l2tp_session_set_header_len
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x90540002	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xb164d45b	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xb5e9af4e	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xb654834e	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xccf1d522	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xdb8649a1	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xf3dbac8a	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x299e6046	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0x3efce9f9	mpls_dev_mtu
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xb8b911db	mpls_pkt_too_big
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xeb6269cb	mpls_output_possible
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xef278e46	nla_put_labels
++EXPORT_SYMBOL_GPL net/mpls/mpls_router 0xf67d707a	nla_get_labels
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x036a9e3d	ip_set_put_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x0b2310aa	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x0f2c3e25	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x17c01df0	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4e5aecc3	ip_set_elem_len
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x73829e02	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7756bb77	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7bda203b	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x83004dad	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x95852da9	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa51fc4ce	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa6f9d784	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa7c61fd5	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc3505335	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xcc001bd9	ip_set_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf3003c0c	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf3e42ac4	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xfb87ad54	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x17528dfd	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x1835e088	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xac62a926	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xbe131491	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x01205f13	nf_ct_seq_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x02d02cb0	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0a466e90	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0a5c2613	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0e628d8f	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0ed05487	nf_conntrack_locks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1197fe77	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x137334d5	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x14191013	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x16ea54f2	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x18577a2a	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1964356c	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1d7c3ec5	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x23a19cf5	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x268aa4fd	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2840bd92	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2972c4d2	nf_ct_seqadj_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2aece362	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2b678ad5	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x35774344	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x371c39d5	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3bbbdb78	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3d6885c1	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3dc298da	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3e6cbc47	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x40d972fa	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4440b76b	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x48610d5b	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x48a6ae42	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x49feee8c	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4e7bb50f	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x51ab9b8c	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x536321d4	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x59f8860c	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5a1d6303	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5efa352d	nf_ct_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5f32f25e	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5fd44e87	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x664c7416	nf_ct_tmpl_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7222c825	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x77f8d001	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78c408cc	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x790cd726	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7a2f759a	nf_connlabels_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x80822395	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9091bda5	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x984f268a	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x990fb8da	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9b0d390c	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9b949b9c	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9d29cb3d	nf_connlabels_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa1cd6218	nf_ct_delete
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab39da58	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xae6efb1e	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xafd11a97	nf_ct_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb5b0ca50	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xccc6ec5a	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xccd5a945	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd17d8de8	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd1f03340	nf_ct_tmpl_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd888854e	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd8e64551	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xda678b48	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdbc5a5d9	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdc1b8933	nf_conntrack_expect_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xde32cce5	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xde47b8dc	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe480fa67	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe6e5d5d3	nf_ct_tcp_seqadj_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe75493c2	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xeda2dd21	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf0b6158f	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf0d1af1c	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf22ffe45	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfa50fcee	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfada4861	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfae32f02	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfcac34ba	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfdb5550f	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfdece399	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x86adc0c3	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0xe7091ae7	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0xb1fdd94f	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x0b9d8840	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x17ee94b9	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x1adea851	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x25a272a5	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x2acc0b75	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x464cc42b	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x4e7431f5	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x7d32fc73	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x83e2e8d4	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xacff49ed	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0xef701f69	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x3451b3f6	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x82d6fbde	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xbbb22fcd	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xd09bc429	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x5970b4ee	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xc063d2dd	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x4d0f2934	nf_nat_sip_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xa7d5f4f0	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xbd73db60	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xc0c89154	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xca6a66f9	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xdb9404e6	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xe3873d54	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0x86c249fa	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0xb212f038	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x016ab90a	nf_log_dump_tcp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0x584f5450	nf_log_dump_packet_common
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xc96a3aa2	nf_log_dump_sk_uid_gid
++EXPORT_SYMBOL_GPL net/netfilter/nf_log_common 0xec9ff7e1	nf_log_dump_udp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x3a88f0b5	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x4301647a	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x58ccebf9	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x6521dcf7	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xab2c6bd8	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xcdc1885c	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xe7fa32e8	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xf9b10782	nf_nat_alloc_null_binding
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xfc9ba08b	nf_ct_nat_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0x2c9b2f05	nf_nat_redirect_ipv6
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat_redirect 0xd27c0ff8	nf_nat_redirect_ipv4
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x11a006b5	synproxy_check_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x3ce65d68	synproxy_parse_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x5f339439	synproxy_build_options
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0x90298227	synproxy_init_timestamp_cookie
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xb42e336a	synproxy_options_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xbc2166d5	synproxy_tstamp_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_synproxy_core 0xef7db50c	synproxy_net_id
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x0c7e05e1	nft_register_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1dd5c74d	nft_register_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x1e6b75a3	nft_parse_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x44a394f0	nft_unregister_expr
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x49a145fb	nft_set_gc_batch_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x4f39532c	nft_unregister_chain_type
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5778f241	nft_chain_validate_hooks
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x5ffd88c5	nft_validate_register_store
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x6695069c	nft_register_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x68088bee	nft_data_uninit
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x93842565	nft_register_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0x971cc42e	nft_dump_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xad5314a2	nft_do_chain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbb7dee34	nft_data_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xbf63bb61	nft_set_gc_batch_release
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xcf03e214	nft_chain_validate_dependency
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xd1947a79	nft_unregister_basechain
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xd251eb0e	nft_set_elem_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xdab65adc	nft_data_dump
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe09dada2	nft_set_ext_types
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe4b132c7	nft_unregister_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xe873211c	nft_register_afinfo
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xed33c632	nft_validate_register_load
++EXPORT_SYMBOL_GPL net/netfilter/nf_tables 0xfc71ec61	nft_unregister_set
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x182b6163	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x4c5f8ba9	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x53ab6e83	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x8fef852f	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x9c6348c8	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xd29cda93	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xd9b30d8e	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x290ea0ba	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x480d733d	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x4ee6ef3b	nfnl_acct_overquota
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0xd58ec464	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0x4b5d112f	nft_masq_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xe3b8ea21	nft_masq_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xea0dd581	nft_masq_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_masq 0xf1c2c41e	nft_masq_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x3493043e	nft_meta_get_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x595efb00	nft_meta_get_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0x71f3f5aa	nft_meta_get_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xafed0a6f	nft_meta_set_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xb80e8358	nft_meta_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xd3ab08ef	nft_meta_set_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_meta 0xe3db1a33	nft_meta_set_eval
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x20349e9a	nft_redir_validate
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0x8093b3d6	nft_redir_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xa5be1e1e	nft_redir_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_redir 0xb9fa5da5	nft_redir_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0x81a2e841	nft_reject_dump
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xa2db3c7f	nft_reject_policy
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xd9d61e5b	nft_reject_init
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xddf15889	nft_reject_icmp_code
++EXPORT_SYMBOL_GPL net/netfilter/nft_reject 0xe8cdab4e	nft_reject_icmpv6_code
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x0c64e7bb	xt_compat_match_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x161d1417	xt_compat_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x1b5e98a0	xt_compat_target_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x24c8e482	xt_copy_counters_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x2bd86013	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3c0c3f26	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3c664d4d	xt_compat_match_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x3e14227f	xt_tee_enabled
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x4225aebc	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x545665e3	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5f82f1f7	xt_compat_flush_offsets
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x63df646a	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x691a6d69	xt_compat_calc_jump
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x7b925d82	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x81f4b4c7	xt_compat_target_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8d5030e6	xt_compat_target_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9c995c69	xt_percpu_counter_alloc
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xa68ceba9	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xaa603338	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbf9e7fd8	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xbfacb837	xt_percpu_counter_free
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd2935adf	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd3b259ca	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe0b4971b	xt_compat_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xec24fd82	xt_compat_add_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xee7d24cf	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xf61921c5	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xfb3b2e90	xt_compat_match_offset
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x7c470866	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xc0f395bf	xt_rateest_put
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x1c47b3bd	ovs_vport_deferred_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x26dcc189	ovs_vport_ops_unregister
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x30a1b13f	ovs_vport_alloc
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x4f1edf85	ovs_netdev_link
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x5e08bb2a	ovs_netdev_detach_dev
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x67b588bb	ovs_vport_receive
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0x89949138	ovs_netdev_tunnel_destroy
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xda83411d	ovs_net_id
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xe1fc3023	ovs_vport_free
++EXPORT_SYMBOL_GPL net/openvswitch/openvswitch 0xf208b88f	__ovs_vport_ops_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x01609617	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x1e89eccb	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0x23b44301	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0x2bdfebfc	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x368ec3ac	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0x3a02e67a	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x40fcb3bb	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0x43972a41	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0x47f1fb7f	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x5c3db36c	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x63722a28	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0x6fbd3b79	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x7b8c7c4d	rds_send_xmit
++EXPORT_SYMBOL_GPL net/rds/rds 0x7eb36b0c	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0x89565e2b	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x93c23246	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0xadce35ce	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0xb441e98a	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0xb82cdee3	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xbf80a305	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2da8e38	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xd840c305	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0xde414929	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0xe68e9a66	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0xef67d94e	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x80714ad5	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x89cfbcb0	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x83db63e4	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xd19a7127	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf54daf8d	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x02ed6495	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x03789340	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x054c905f	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05fbf77d	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x087aa52a	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x08dd1ed4	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0a081e38	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b90381e	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0fb0f9cd	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x10979a1e	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x12acbb9a	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x12efa992	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x144f93da	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x14e9ea1e	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x17971216	cache_seq_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x186f6afc	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x18d99e50	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x19937823	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1a566ce1	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1c9b0dc8	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1ee719c3	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1f05ecfd	cache_seq_stop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x22a57c31	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24bd6172	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x28030847	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x28f13f10	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2929c398	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x297bb9f0	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x29bda115	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x313ab7a5	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x319063cc	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31bf4332	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31e3d9fc	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x35180b01	svc_rqst_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3530a1a7	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x36ed25fe	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x36f25665	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x378bc399	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x392679da	rpc_remove_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3bebabfa	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c1d673e	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c613804	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3cb6adc5	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3cde73d4	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3d7e1c16	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x44de25c1	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x453efa54	svc_pool_map
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x45744117	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x460bb9bf	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4665d2ea	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x48d4d88e	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x493d5ccc	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4a51159a	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4aea7d88	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4b6cce43	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4b7bfc75	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4c0d8ec9	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4c95acd6	rpcauth_key_timeout_notify
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4ed1673a	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4fde279e	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x505e6441	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5070d328	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x50d8f4b6	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x530d8245	rpc_add_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5414c397	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5575c739	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x55c592a1	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5617dae2	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x58ac7619	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x59995b47	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5a03a793	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b1be196	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5ee21083	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5f3d5ac6	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x60bc4e25	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x62898510	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x640100d9	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x646a2efe	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6578478d	rpc_clnt_swap_activate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x65e1cefa	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6632f1f1	rpcauth_stringify_acceptor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x668f64a4	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x67a01086	xdr_commit_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x67f709f0	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x683f51c5	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6a8efbbd	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6b11dca3	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6b3f768c	svc_rqst_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6bbf0605	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6c5ee8c7	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6c7c3ea5	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6eaa6798	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6ee401d3	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6f155fe5	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6f2ddbb4	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6fcf763c	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x70f6abd1	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x711fc393	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7166b785	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71887f40	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7450fc43	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x76b0f473	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7b59d304	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7d0bfb2b	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7dcb1159	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7f6b37aa	cache_seq_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x81dc8eb0	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x822763d5	rpc_clnt_swap_deactivate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x86a6d728	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x89acd733	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8a09020d	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8a80bcf1	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8bdd0569	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8bfec61f	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8dfb4761	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x910be66b	rpcauth_cred_key_to_expire
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9133994a	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x928540c0	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9325b707	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x93fae1ea	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9472e08a	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x95a97b80	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x970fd05a	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x974d6ef9	rpc_find_or_alloc_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9aca49ab	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b90b8c7	rpc_lookup_cred_nonblock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ce403d5	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9e77bb6e	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa13acdb8	svc_pool_map_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa3733621	rpc_count_iostats_metrics
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa3d327a3	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa535eb32	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa654ca8e	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa656919e	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa70c63f2	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa14573a	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xac7a5b45	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xae999b87	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaefa9be9	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf77197f	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb0506442	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb14b9a89	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb29861e5	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb2bf9bb3	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb312d0c4	svc_pool_map_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb705e711	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb8be2c03	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb922aa1b	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xba999d3f	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xba9ab4b7	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbae47ddd	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbbade1a4	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf969ace	rpcauth_lookupcred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc23ead75	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc37f55b9	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc417eea4	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc41bf21d	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc465e4e6	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc4a91c88	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc62f809b	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc7b32c80	gssd_running
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc865cb31	rpc_init_pipe_dir_object
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc9281579	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc9bca220	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcc2a31c2	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xccb65910	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce25491e	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcf3b947d	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcfa7fec1	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd325b653	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd87d2316	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd8bc486b	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd924f15d	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd961c85c	rpc_init_pipe_dir_head
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdbe0e3cd	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdc570343	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdf1347f6	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe14b4d30	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1780972	rpc_switch_client_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1bd8052	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe2c4f5fb	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe654d3fb	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe6cd8fa6	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe7c712ca	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe853b124	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe88d474a	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe9292348	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe975620e	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe99c8efb	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe9d203be	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xecc9e0cf	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef9fab61	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf1168dd8	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf3596c76	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf375dbeb	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf3c376ff	svc_xprt_do_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf88ad177	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9cd4bf5	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa2267e4	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfc27b910	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfef34a8f	svc_alien_sock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xffd6cae4	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0241a0dc	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x08121c96	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x10bf63ec	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x10e03a5e	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x17f33d20	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x1c9c8414	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x3365080d	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x94c7c94e	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x95884178	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x970b77bc	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa0c178e5	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa7188c30	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xcb321662	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xe9051518	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xecfd07bd	__vsock_core_init
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x3bf471d7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x47b34e60	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x60b73277	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x834ba96d	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xa6e66685	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xaa762fe2	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xad1b60ed	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdbfc35c8	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xdfea3a6d	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x4e9f3d9c	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xaf8f8f75	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xbf773553	ipcomp_destroy
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xc2d01894	ipcomp_output
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x3fe35aea	irq_bypass_unregister_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x418873cc	irq_bypass_register_producer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0x888c5be5	irq_bypass_register_consumer
++EXPORT_SYMBOL_GPL virt/lib/irqbypass 0xf6e772c3	irq_bypass_unregister_producer
++EXPORT_SYMBOL_GPL vmlinux 0x0007dcd3	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x000e74c0	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL vmlinux 0x000f2496	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x0019a61a	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0x002cbf81	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x004d787a	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x0060a102	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x006820b4	pci_write_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x00aca905	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x00b783a9	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x00cc3d11	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0x00ced6e0	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0x00d1efac	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0x00d40cc6	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x0114d6c2	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x01413c5f	css_schedule_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0x017c8e21	kvm_put_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x01d457eb	get_ccwdev_by_dev_id
++EXPORT_SYMBOL_GPL vmlinux 0x02436ade	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x0289adcf	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x02931659	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x02ebef25	cpuset_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x02fe00c1	splice_to_pipe
++EXPORT_SYMBOL_GPL vmlinux 0x02fea2ae	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x030f49c5	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x0319411e	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x031b3287	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x03783978	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x038ba9cc	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x03a3f42d	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0x03bf7230	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x03e677d0	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x0402cbbf	preempt_notifier_inc
++EXPORT_SYMBOL_GPL vmlinux 0x041df56b	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x042e575b	bpf_prog_create
++EXPORT_SYMBOL_GPL vmlinux 0x045760a6	irq_set_chained_handler_and_data
++EXPORT_SYMBOL_GPL vmlinux 0x0496352d	sched_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x04a79848	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0x04b5549c	__cookie_v6_check
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04ea8706	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0x04eb2ebf	security_kernel_fw_from_file
++EXPORT_SYMBOL_GPL vmlinux 0x0521475f	devm_hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x052c8772	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0x05449c14	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x055c2a16	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x057eca95	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x05c0d3bd	kvm_get_dirty_log
++EXPORT_SYMBOL_GPL vmlinux 0x05cb3241	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x05de8acb	bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x05f0a28b	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x061f3251	tpm_seal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x0654d685	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0x0658097f	net_cls_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x06654a8d	gmap_discard
++EXPORT_SYMBOL_GPL vmlinux 0x066d97b3	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0x0688ba4c	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x06b5b35b	kvm_vcpu_gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x06c65b75	tpm_try_get_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0797d532	scsi_ioctl_block_when_processing_errors
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07db2ef5	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0x0808fbd0	debugfs_create_devm_seqfile
++EXPORT_SYMBOL_GPL vmlinux 0x08156773	name_to_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0x0829446c	blk_set_queue_dying
++EXPORT_SYMBOL_GPL vmlinux 0x084d702d	rhashtable_insert_rehash
++EXPORT_SYMBOL_GPL vmlinux 0x088bfa7e	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x088ced52	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x089a5539	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x08bc0870	compat_put_timespec
++EXPORT_SYMBOL_GPL vmlinux 0x08f6cca4	css_general_characteristics
++EXPORT_SYMBOL_GPL vmlinux 0x08f870ff	ccw_device_siosl
++EXPORT_SYMBOL_GPL vmlinux 0x09059c80	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0x0914a894	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x09150f61	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x09373b7c	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x09670047	rhashtable_walk_stop
++EXPORT_SYMBOL_GPL vmlinux 0x096db2ff	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x09872f4d	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0x09c1348d	blkdev_read_iter
++EXPORT_SYMBOL_GPL vmlinux 0x09d05ece	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x09f1a48f	list_lru_add
++EXPORT_SYMBOL_GPL vmlinux 0x0a47a756	zpci_stop_device
++EXPORT_SYMBOL_GPL vmlinux 0x0a5f478a	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x0a6841ef	debugfs_read_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x0a790dc5	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0x0a8a62d2	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0x0a93dab4	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0x0a9ed33b	sysfs_rename_link_ns
++EXPORT_SYMBOL_GPL vmlinux 0x0aa75e07	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0x0ab486a9	blk_mq_free_hctx_request
++EXPORT_SYMBOL_GPL vmlinux 0x0acc6280	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x0afcef52	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b112872	device_for_each_child_reverse
++EXPORT_SYMBOL_GPL vmlinux 0x0b2f2faf	__clocksource_update_freq_scale
++EXPORT_SYMBOL_GPL vmlinux 0x0b572b5e	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0x0b901ed8	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x0ba68b6d	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0x0bac8e31	css_sch_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0bd178f5	cpu_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c0af9a3	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c4e0217	gmap_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x0c7a1d2f	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x0c9e49cb	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x0cb506de	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0d1f84f3	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0x0d313239	platform_unregister_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x0d4961de	nf_log_buf_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d4f4735	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0x0d7d4d70	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0da1e4cd	shmem_add_seals
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb1cd7	llist_reverse_order
++EXPORT_SYMBOL_GPL vmlinux 0x0dde4cd8	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0x0e31b543	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x0e53d52b	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x0e790904	gfn_to_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x0e8a640e	kvm_flush_remote_tlbs
++EXPORT_SYMBOL_GPL vmlinux 0x0ea41f64	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x0ebaabc8	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x0f2a63a3	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x0f336d7f	rcutorture_get_gp_data
++EXPORT_SYMBOL_GPL vmlinux 0x0f469892	blk_mq_request_started
++EXPORT_SYMBOL_GPL vmlinux 0x0f81d811	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x0f9ec1ed	list_lru_del
++EXPORT_SYMBOL_GPL vmlinux 0x0fa09a38	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x0fa6d907	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x10339722	zpci_iomap_start
++EXPORT_SYMBOL_GPL vmlinux 0x10a7de77	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x10d62848	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x10fbbaec	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x10fefdb9	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x11016d00	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x11099eb5	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0x110c8c50	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0x111ea5e9	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0x1142d34f	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x115706d5	devm_kasprintf
++EXPORT_SYMBOL_GPL vmlinux 0x116cf2ed	smpboot_register_percpu_thread_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x118124a7	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x11942318	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x11962a94	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0x119af014	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0x11b790aa	inet_csk_compat_getsockopt
++EXPORT_SYMBOL_GPL vmlinux 0x11c51773	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x11ccf3c5	blkg_print_stat_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x11ed0bba	virtio_config_changed
++EXPORT_SYMBOL_GPL vmlinux 0x12125331	gmap_fault
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x122a64c2	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0x123e644c	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x12564b9d	posix_acl_access_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x1266d8eb	device_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x12798697	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x129b1523	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x12bbf308	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0x12d2cdbc	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x12df0000	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x12f32624	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0x12f4a757	task_cls_state
++EXPORT_SYMBOL_GPL vmlinux 0x130bc12a	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0x131d9aab	dax_truncate_page
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x13679f6a	cpu_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x13900921	msi_desc_to_pci_sysdata
++EXPORT_SYMBOL_GPL vmlinux 0x13ad647f	scatterwalk_bytes_sglen
++EXPORT_SYMBOL_GPL vmlinux 0x13d7d273	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0x140191bb	pci_stop_and_remove_bus_device_locked
++EXPORT_SYMBOL_GPL vmlinux 0x14078f33	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x1445554f	posix_acl_create
++EXPORT_SYMBOL_GPL vmlinux 0x1459db92	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0x14657228	pci_try_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x14ba2a14	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x151fde4e	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x152f52dd	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0x1534aa5c	device_get_child_node_count
++EXPORT_SYMBOL_GPL vmlinux 0x153d4924	bpf_prog_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x153f2224	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x156f2483	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x157bc422	s390_enable_skey
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x158dd537	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x158eb7d2	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x15c43555	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x15ea3bf8	kernfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x15efd446	rcu_batches_started
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x161409f1	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x161edc82	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0x1644a522	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0x164ad4aa	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x167216e6	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0x168da3a8	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x169df052	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x16ed7695	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x16ef0140	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x173a88e5	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0x17781775	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x17994d70	memhp_auto_online
++EXPORT_SYMBOL_GPL vmlinux 0x179abb91	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0x17a88983	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0x17ceb23c	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x17d6430c	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1888bb37	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL vmlinux 0x18896cdb	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x18ad658e	rhashtable_free_and_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x18d4e912	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x191e8682	skb_to_sgvec_nomark
++EXPORT_SYMBOL_GPL vmlinux 0x1926a393	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0x194dd5f5	pkey_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x1977676c	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x1979e4e1	crypto_alloc_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x199792af	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0x19b589b5	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x19ef4098	trace_seq_bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x19f462ab	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x1a56527d	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0x1a5a2f47	device_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x1acef7d2	pm_freezing
++EXPORT_SYMBOL_GPL vmlinux 0x1b1e3c8f	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x1b3a8f06	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x1b4bdccd	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1b6c5a67	chsc_error_from_response
++EXPORT_SYMBOL_GPL vmlinux 0x1b7da603	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1ba33c06	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x1bc516e3	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0x1c2ac28f	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c5cd9fe	l3mdev_fib_table_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x1c6dda6c	pci_ioremap_wc_bar
++EXPORT_SYMBOL_GPL vmlinux 0x1c6e9a8e	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0x1c734bee	wait_on_page_bit_killable_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1c9e2f4f	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0x1cddb262	put_device
++EXPORT_SYMBOL_GPL vmlinux 0x1d222ced	irq_get_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d4004cd	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0x1d4ca144	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d5f991e	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x1d6058e2	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x1d6201c8	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0x1d63f77b	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x1d6caf6b	dev_pm_domain_attach
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c0168	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1d8f85e5	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x1d90b778	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1ea70c39	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0x1ea9a1c6	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebac2bd	getboottime64
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ed2b4aa	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1f1aa653	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x1f1d250e	virtio_break_device
++EXPORT_SYMBOL_GPL vmlinux 0x1f71eb98	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1f8fe38a	crypto_unregister_rngs
++EXPORT_SYMBOL_GPL vmlinux 0x1f94f50e	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x1fbad117	kthread_park
++EXPORT_SYMBOL_GPL vmlinux 0x1fe3a6ea	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x2052a168	pci_generic_config_write
++EXPORT_SYMBOL_GPL vmlinux 0x2061559f	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x207e5935	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL vmlinux 0x213d9be3	hugetlb_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x213ec619	__tracepoint_unmap
++EXPORT_SYMBOL_GPL vmlinux 0x21a98ae5	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21cd536a	crypto_put_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x21df9855	iptunnel_metadata_reply
++EXPORT_SYMBOL_GPL vmlinux 0x21f40c07	trace_call_bpf
++EXPORT_SYMBOL_GPL vmlinux 0x221fdf80	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2228fa11	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x2249da5d	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x22537c0e	call_filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x226f8172	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x227fa6ad	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x228a9c7b	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x22e20b10	chsc_siosl
++EXPORT_SYMBOL_GPL vmlinux 0x2316195d	gmap_enable
++EXPORT_SYMBOL_GPL vmlinux 0x233f5316	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0x23552114	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0x235f362e	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0x236578bf	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x236bbca8	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x237d59f6	zpci_load
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x23b0e9f5	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x23c5ba50	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x23c8b358	fwnode_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x23e6a807	blk_mq_alloc_request_hctx
++EXPORT_SYMBOL_GPL vmlinux 0x23f4fcbc	request_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x23f92ab7	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x23fc34c7	find_extend_vma
++EXPORT_SYMBOL_GPL vmlinux 0x241bfd9f	zpci_store_block
++EXPORT_SYMBOL_GPL vmlinux 0x24457174	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x247b0271	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0x249d092b	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24b31cc7	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x24c6beee	nr_iowait
++EXPORT_SYMBOL_GPL vmlinux 0x24eb60fc	user_read
++EXPORT_SYMBOL_GPL vmlinux 0x24fa4e35	gfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0x251f6614	ktime_get_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x255acba5	kvm_vcpu_mark_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x255b9dbb	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0x25bafc98	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0x25bb7d63	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x25c7b6e2	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x2607a61d	css_chsc_characteristics
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x2669f4b8	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x266b7638	interval_tree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x268e14ed	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0x26b15f87	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26eb5a35	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL vmlinux 0x2704cdbf	pm_runtime_force_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2741c3cf	gmap_unregister_ipte_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x276775a1	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x27a950e3	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x27c283ad	__online_page_increment_counters
++EXPORT_SYMBOL_GPL vmlinux 0x27c842cc	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x28169f66	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0x2827a23c	percpu_down_write
++EXPORT_SYMBOL_GPL vmlinux 0x28423b78	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0x28afeab0	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x28c893c8	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0x28d5d9b5	percpu_ida_free_tags
++EXPORT_SYMBOL_GPL vmlinux 0x2921b5f8	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x295871fe	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x29980371	rsa_parse_priv_key
++EXPORT_SYMBOL_GPL vmlinux 0x29ad8791	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x29d03794	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x29eba37f	current_is_async
++EXPORT_SYMBOL_GPL vmlinux 0x2a0c7055	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x2a1538ca	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0x2a1564cf	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a74d6b0	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0x2a97e262	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x2a987779	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x2abf46b3	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x2b10890c	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x2b27c257	snmp_get_cpu_field
++EXPORT_SYMBOL_GPL vmlinux 0x2bad91fe	ipl_info
++EXPORT_SYMBOL_GPL vmlinux 0x2c28cfdb	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x2c2c9918	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x2c3054f9	net_inc_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2c340609	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x2ca00b53	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x2cba54e6	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x2cdc04d9	__tracepoint_remove_device_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x2cdefb58	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d4f4339	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x2d6eb39a	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0x2dbb3b8b	blkcipher_aead_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x2df1ba0d	memory_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x2df8d909	page_endio
++EXPORT_SYMBOL_GPL vmlinux 0x2e0c469f	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x2e143790	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x2e1d43cf	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e48b2cb	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ec92012	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x2ed9f634	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0x2ee2ac58	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2f251a4c	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0x2f3616cb	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f55098e	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x2f66c85e	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0x2fad5f73	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0x2fc11137	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2fc45184	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x30367e77	kvm_read_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x305f3da4	x509_free_certificate
++EXPORT_SYMBOL_GPL vmlinux 0x305ff19a	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0x3067d88d	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x30772f60	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0x30789d74	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0x309b6d68	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x30a4f572	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x30c40c3a	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0x30ceade4	dm_internal_resume
++EXPORT_SYMBOL_GPL vmlinux 0x30cfdb08	devices_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x3106d364	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x310d8534	__alloc_percpu_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x3136fd34	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0x3171d9ea	trace_seq_path
++EXPORT_SYMBOL_GPL vmlinux 0x317c1820	percpu_ida_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x319e2abc	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31d0c728	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x31e8e33e	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x31fb61dc	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x3208167e	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x320aa53b	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x321bdbb1	compat_get_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x324b2cff	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x324e0068	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x32611bd7	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x32876061	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x32978503	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0x329f4b3f	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x32a79bfc	kvm_write_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x32bc0fcf	preempt_notifier_dec
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32ce8b43	scsi_dh_activate
++EXPORT_SYMBOL_GPL vmlinux 0x32f30e13	disable_cmf
++EXPORT_SYMBOL_GPL vmlinux 0x334b461d	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x335c2c38	vcpu_load
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x33610248	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x33e3c64c	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x33f62439	net_prio_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x33f7ca8c	crypto_alg_extsize
++EXPORT_SYMBOL_GPL vmlinux 0x34096e96	blkg_print_stat_ios
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x34a6fa23	__bpf_call_base
++EXPORT_SYMBOL_GPL vmlinux 0x34afa50a	kvm_get_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x34bef5fb	s390_dma_ops
++EXPORT_SYMBOL_GPL vmlinux 0x34d3ba58	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x34ee2b6e	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x35176301	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x353ebe70	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x35895567	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x35a656b6	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x35b56878	bpf_prog_create_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x35d058fa	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0x35eb139d	gmap_test_and_clear_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x35ee0cf6	__blk_run_queue_uncond
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x362acfa3	pci_debug_err_id
++EXPORT_SYMBOL_GPL vmlinux 0x365d95ec	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x365f151b	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x3687941d	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36f3ddec	kvm_vcpu_read_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x370dbbf9	crypto_alloc_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x370eb881	ptp_classify_raw
++EXPORT_SYMBOL_GPL vmlinux 0x371dbd7c	gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x37b890dd	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0x37ceea7b	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x37d0a334	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x38051aae	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0x3812b6d5	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x381321af	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0x3827f835	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x3833bc56	dev_fill_metadata_dst
++EXPORT_SYMBOL_GPL vmlinux 0x384a6981	__gfn_to_pfn_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x3868ed6a	blk_mq_register_disk
++EXPORT_SYMBOL_GPL vmlinux 0x38c39d04	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x38c63310	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x38eeaa02	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x390161b3	__tracepoint_powernv_throttle
++EXPORT_SYMBOL_GPL vmlinux 0x39037828	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x390d1faf	appldata_register_ops
++EXPORT_SYMBOL_GPL vmlinux 0x391e8af3	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x393ffa6f	asymmetric_key_generate_id
++EXPORT_SYMBOL_GPL vmlinux 0x39433796	pci_generic_config_read
++EXPORT_SYMBOL_GPL vmlinux 0x395e1a90	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0x398dbf0c	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x39a27a3b	system_verify_data
++EXPORT_SYMBOL_GPL vmlinux 0x39e61495	nf_logger_request_module
++EXPORT_SYMBOL_GPL vmlinux 0x3a0583ea	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a6a52ed	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x3a6c2230	clockevents_unbind_device
++EXPORT_SYMBOL_GPL vmlinux 0x3a9be019	asymmetric_key_id_partial
++EXPORT_SYMBOL_GPL vmlinux 0x3ab9fbb1	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3afddda6	tpm2_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x3afe1cef	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0x3b386851	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x3b4afdec	rhashtable_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x3b8794fd	__tracepoint_attach_device_to_domain
++EXPORT_SYMBOL_GPL vmlinux 0x3bc5f5e4	blockdev_superblock
++EXPORT_SYMBOL_GPL vmlinux 0x3bcf82dc	bpf_prog_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x3bf86160	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0x3c104e2a	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x3c250814	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x3c32a0eb	klp_unregister_patch
++EXPORT_SYMBOL_GPL vmlinux 0x3c66c8d4	bpf_prog_realloc
++EXPORT_SYMBOL_GPL vmlinux 0x3c795564	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cea4c9b	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3cfa2c8a	component_unbind_all
++EXPORT_SYMBOL_GPL vmlinux 0x3d157ad7	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0x3d35e687	blk_mq_tags_cpumask
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d7c2bea	tpm2_startup
++EXPORT_SYMBOL_GPL vmlinux 0x3d92b95b	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd148dd	filter_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x3dd1f8a9	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x3dd74130	nd_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3dfc436e	percpu_ref_kill_and_confirm
++EXPORT_SYMBOL_GPL vmlinux 0x3e1f72e0	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL vmlinux 0x3e208778	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x3e258c38	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0x3e5e1937	rcu_batches_started_sched
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e84d467	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0x3e948de9	unregister_reset_call
++EXPORT_SYMBOL_GPL vmlinux 0x3ea28653	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x3ec81de7	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x3ec9e2f3	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f06a7da	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x3f0fdcf2	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0x3f466527	mark_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x3f5f6cc9	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3f7ba3fb	ccw_device_get_chp_desc
++EXPORT_SYMBOL_GPL vmlinux 0x3fae9450	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0x3fbe1e2d	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x3fc55363	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x3fd2f6fb	chsc_sadc
++EXPORT_SYMBOL_GPL vmlinux 0x3ff2df31	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0x401156c2	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x401c09be	list_lru_count_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x405202c0	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x40689fe6	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x406c4cb1	hrtimer_resolution
++EXPORT_SYMBOL_GPL vmlinux 0x40774f7a	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0x40d2cbd2	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x40d3f798	kvm_vcpu_block
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40d8d34c	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x40ebc04d	enable_cmf
++EXPORT_SYMBOL_GPL vmlinux 0x410a431e	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL vmlinux 0x41105308	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0x414937eb	request_firmware_direct
++EXPORT_SYMBOL_GPL vmlinux 0x41567f41	__mmu_notifier_invalidate_range
++EXPORT_SYMBOL_GPL vmlinux 0x416704cc	ip6_route_output_flags
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x4181f1ca	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x41b3b6f0	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x41d094f3	hash_algo_name
++EXPORT_SYMBOL_GPL vmlinux 0x4223ee4b	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x42792ba7	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x428d751e	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x42f4004b	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0x431809dd	sysfs_remove_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x431a5da4	dev_pm_enable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x43443c35	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x43619e1a	scatterwalk_ffwd
++EXPORT_SYMBOL_GPL vmlinux 0x436f7015	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x439791c0	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43b466b0	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x43bdf180	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x43c33665	isc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x43d246f2	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x43eca819	pkcs7_parse_message
++EXPORT_SYMBOL_GPL vmlinux 0x4409af18	klp_enable_patch
++EXPORT_SYMBOL_GPL vmlinux 0x4412d07f	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x4426cb5d	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x442b74dc	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x4432ca7e	platform_device_add_properties
++EXPORT_SYMBOL_GPL vmlinux 0x4446568a	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0x445e4900	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x44bae227	bit_wait_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x44c16504	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x44cafe27	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x44eb3994	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x453ac28e	cpuacct_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x4566e16b	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x456ad091	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x456cab38	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x45848270	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x4594dbef	device_property_present
++EXPORT_SYMBOL_GPL vmlinux 0x45960716	__tracepoint_io_page_fault
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45f8a8b0	shmem_get_seals
++EXPORT_SYMBOL_GPL vmlinux 0x46013233	net_dec_ingress_queue
++EXPORT_SYMBOL_GPL vmlinux 0x462090a8	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0x462130fa	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0x463d24ea	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x46681d9e	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x4685667b	gmap_map_segment
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x46a93f8b	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0x46c18b41	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x46e71c94	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0x472f1c9a	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x479165b4	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0x479e8f14	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0x47c4f7fc	nr_swap_pages
++EXPORT_SYMBOL_GPL vmlinux 0x47dc6cff	set_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x47eb816f	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x482d5c88	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x483fb5dd	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0x4840d95b	device_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0x4858f867	blkg_lookup_slowpath
++EXPORT_SYMBOL_GPL vmlinux 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL vmlinux 0x4868c3b4	rcu_batches_started_bh
++EXPORT_SYMBOL_GPL vmlinux 0x487c5d33	nf_log_buf_add
++EXPORT_SYMBOL_GPL vmlinux 0x48819aa2	bitmap_copy_from_slot
++EXPORT_SYMBOL_GPL vmlinux 0x488c4f50	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x48925530	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x48a442c7	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x48bf94b6	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x48c62e4a	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x48f2cace	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x494d1f4b	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x49c7a313	nfnl_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0x49cfacf1	io_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x49e96999	cond_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4a3ca9b2	crypto_rng_reset
++EXPORT_SYMBOL_GPL vmlinux 0x4a4c10a9	pkey_id_type_name
++EXPORT_SYMBOL_GPL vmlinux 0x4a6538df	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x4a7417d2	fib_select_path
++EXPORT_SYMBOL_GPL vmlinux 0x4a87123f	validate_xmit_skb_list
++EXPORT_SYMBOL_GPL vmlinux 0x4a8b5408	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x4a9eb822	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x4aa9624a	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4abe26d1	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x4b01f099	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4b1106fb	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x4b18565b	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x4b1bc5c6	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x4b2dce97	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0x4b2f68e7	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0x4b4c6a73	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0x4b840dfd	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x4b9660ef	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x4bc99708	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x4bf192a7	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0x4c031db0	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0x4c3a2ba6	blkg_print_stat_ios_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4cc19c00	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x4cc85c94	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x4cf00b85	bio_associate_current
++EXPORT_SYMBOL_GPL vmlinux 0x4d0015e2	cpu_hotplug_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4d03ec65	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x4da1add6	devm_kmemdup
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e198663	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x4e1aa0db	tpm_chip_register
++EXPORT_SYMBOL_GPL vmlinux 0x4e31eb99	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x4e52b730	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x4e67e5cf	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x4eb00964	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x4ec153c6	nr_running
++EXPORT_SYMBOL_GPL vmlinux 0x4ee48765	component_del
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f30b379	hash_digest_size
++EXPORT_SYMBOL_GPL vmlinux 0x4f415bc0	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0x4f6a07fe	show_rcu_gp_kthreads
++EXPORT_SYMBOL_GPL vmlinux 0x4f83961f	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x4f886fb6	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x4f89627f	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x4f9271c8	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0x4f9bc0ab	hrtimer_active
++EXPORT_SYMBOL_GPL vmlinux 0x4fc539b5	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x500fcdb6	scsi_device_from_queue
++EXPORT_SYMBOL_GPL vmlinux 0x5012ab91	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x503d374d	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x507de8c6	add_memory
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x50e63136	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x5111088b	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0x51175977	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x5120cc15	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x513bde18	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0x51405201	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0x514dbc9c	tpm_is_tpm2
++EXPORT_SYMBOL_GPL vmlinux 0x5157d77f	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x51685f4a	restore_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x516c585b	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x51abd3bb	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0x51b1ce34	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x51dee03a	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x528475a2	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0x52c0bf53	__tracepoint_map
++EXPORT_SYMBOL_GPL vmlinux 0x52ef6951	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x52f9c9a6	blk_mq_free_request
++EXPORT_SYMBOL_GPL vmlinux 0x52fca12b	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x52fd6889	ipv6_stub
++EXPORT_SYMBOL_GPL vmlinux 0x53040d26	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x5324d04f	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x53889704	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x5394820b	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x5394ac40	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0x53ca39d8	sysfs_create_groups
++EXPORT_SYMBOL_GPL vmlinux 0x53fd96d3	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54ab9a60	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x54d3d9e2	kvm_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x54db0003	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x54e74155	bpf_prog_select_runtime
++EXPORT_SYMBOL_GPL vmlinux 0x54ef3d03	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x551b3435	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x55454c41	pci_ignore_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0x554e33fc	sysfs_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x55628467	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x5565c774	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0x558dc6d8	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0x55a47fa1	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x55bf1185	vtime_account_irq_enter
++EXPORT_SYMBOL_GPL vmlinux 0x55c90c1b	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x55eecff4	bit_wait_io_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x55f2580b	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x55fe98f9	fwnode_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x560e23d4	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x560fd987	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x5616a72d	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0x56256e8a	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x56338794	class_create_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x563c5c66	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x56586c49	pkcs7_get_content_data
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x5680a039	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x56b087d4	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56e11c83	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x5739e0d1	genlmsg_new_unicast
++EXPORT_SYMBOL_GPL vmlinux 0x575c5f94	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0x575fb0a9	crypto_register_aead
++EXPORT_SYMBOL_GPL vmlinux 0x578178c1	device_get_dma_attr
++EXPORT_SYMBOL_GPL vmlinux 0x578a35a3	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x5790e7a0	pci_unlock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0x579bae21	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x579c0bc4	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0x579d42e7	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57a0486c	blk_mq_unfreeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0x57a1c922	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x57bf75f7	pci_msi_mask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x57d839ae	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x57d9a9e8	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0x57dcdceb	kernfs_put
++EXPORT_SYMBOL_GPL vmlinux 0x58715b0d	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0x588a285f	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x589493fd	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x58b921ce	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x5911ece8	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0x591a9e0f	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x59a105f8	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0x59c85025	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x59cb9e3a	device_remove_file_self
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x5a4276ec	blk_mq_freeze_queue_start
++EXPORT_SYMBOL_GPL vmlinux 0x5a5e2cd4	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x5a669778	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5aa5752f	inet_ehash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x5ac2727f	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x5b35615e	sysfs_create_mount_point
++EXPORT_SYMBOL_GPL vmlinux 0x5b394b5b	cio_disable_subchannel
++EXPORT_SYMBOL_GPL vmlinux 0x5b5e32b7	device_property_read_string_array
++EXPORT_SYMBOL_GPL vmlinux 0x5b5fa2e7	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x5b663fa4	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5bcbbc7e	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0x5bd0748f	crypto_del_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5bdbac4e	rcu_unexpedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x5c1d11c7	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x5c289837	virtqueue_get_used
++EXPORT_SYMBOL_GPL vmlinux 0x5c2f2906	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x5c425ebb	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0x5c453fa2	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0x5c71d21a	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x5c7361f0	perf_pmu_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5c899403	trace_output_call
++EXPORT_SYMBOL_GPL vmlinux 0x5ca6760a	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cc509a4	nsecs_to_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x5cdeae59	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0x5d1939df	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x5da67adc	zs_compact
++EXPORT_SYMBOL_GPL vmlinux 0x5dac5214	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0x5daf640b	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5db2539d	bpf_prog_get
++EXPORT_SYMBOL_GPL vmlinux 0x5de1e707	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x5e0bd896	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0x5e313b1a	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x5e3a50d1	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0x5e4ab9d6	__tracepoint_detach_device_from_domain
++EXPORT_SYMBOL_GPL vmlinux 0x5e522ddf	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5e96c933	ccw_device_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x5ea865f7	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x5ee17ced	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0x5f054e09	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0x5f05e25b	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0x5f226035	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0x5f32574b	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x5f34c4d3	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x5f351356	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x5f3565ff	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x5f3d744d	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x5fae64ca	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x5fc23404	list_lru_walk_one
++EXPORT_SYMBOL_GPL vmlinux 0x5fca1e35	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x602754b7	dev_pm_qos_expose_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0x602c82e6	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x6030a977	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0x6049bdb2	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x60694bcb	crypto_alloc_rng
++EXPORT_SYMBOL_GPL vmlinux 0x6090dbef	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0x609ce894	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL_GPL vmlinux 0x60b5259b	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x60c53640	handle_bad_irq
++EXPORT_SYMBOL_GPL vmlinux 0x60c65e78	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0x60c95db0	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x60d14dc2	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x6179bfa8	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x61a97e5f	register_reset_call
++EXPORT_SYMBOL_GPL vmlinux 0x61b00e3d	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0x61b4fcbd	devm_get_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x621c3c93	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x62aa0de1	skb_append_pagefrags
++EXPORT_SYMBOL_GPL vmlinux 0x62b97f96	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x62f3870f	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0x630f7914	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x632e7a04	devm_kmalloc
++EXPORT_SYMBOL_GPL vmlinux 0x6353ac2c	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x63565487	blkg_dev_name
++EXPORT_SYMBOL_GPL vmlinux 0x6390afbc	__platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0x63f4dc09	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x63ff36fe	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x6410e160	ktime_mono_to_any
++EXPORT_SYMBOL_GPL vmlinux 0x6418bb3c	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x64346bb3	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x643e0ce5	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0x64652f67	fuse_dev_free
++EXPORT_SYMBOL_GPL vmlinux 0x646723ba	unregister_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x64743400	dax_fault
++EXPORT_SYMBOL_GPL vmlinux 0x64796ba3	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0x648661e2	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0x64a9c872	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0x64d30920	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0x65132a2b	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x651b060a	aead_init_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x65577313	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65e744df	sched_clock_base_cc
++EXPORT_SYMBOL_GPL vmlinux 0x65f6d831	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x6619a388	net_cls_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x6636c3c9	irq_set_vcpu_affinity
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x668d9466	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x66994a93	pci_debug_msg_id
++EXPORT_SYMBOL_GPL vmlinux 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x66a25234	chsc_ssqd
++EXPORT_SYMBOL_GPL vmlinux 0x66c6b8a7	tcp_ca_get_name_by_key
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x670bc723	scsi_dh_attach
++EXPORT_SYMBOL_GPL vmlinux 0x67178e95	device_get_next_child_node
++EXPORT_SYMBOL_GPL vmlinux 0x674849ec	tcp_ca_openreq_child
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x677381f9	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x677e4043	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0x678c98a1	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x67ab8695	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x67cb0766	pci_msi_unmask_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6816eb6b	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0x68324a41	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0x68ce2004	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x68f8cc23	dev_pm_clear_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6918b3a3	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x6921aa34	compat_put_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x69511034	handle_fasteoi_irq
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x69923695	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x69a0e06d	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x69aa1c00	__add_pages
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f623b	mmu_notifier_synchronize
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a8f04e9	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b7dcbc8	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0x6bb8e16b	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x6bd27bc6	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6be020d8	blkdev_write_iter
++EXPORT_SYMBOL_GPL vmlinux 0x6be5162c	freezer_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x6c07d933	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0x6c11934f	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0x6c190223	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0x6c1a46b5	ima_file_check
++EXPORT_SYMBOL_GPL vmlinux 0x6c844229	check_syslog_permissions
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6cbc8ef4	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6cbefbb3	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x6cd779ac	pm_runtime_force_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6cf579f2	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x6cf800c5	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x6d1a2716	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d360923	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x6d4041b6	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x6d4ac43a	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x6d59045b	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x6d692a19	mddev_congested
++EXPORT_SYMBOL_GPL vmlinux 0x6d8f52f6	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x6e645e20	tty_buffer_lock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e977850	crypto_register_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0x6ebdfb72	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6ed4fe92	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x6ef60373	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x6f6c4d46	crypto_ahash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x6f7e5c91	bpf_skb_vlan_pop_proto
++EXPORT_SYMBOL_GPL vmlinux 0x6f821920	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x6fd0240d	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x6fd670c6	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6fda2463	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6fe7ca7f	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x700078a1	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x702c4432	klp_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x707e6967	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x70c52dc5	nf_skb_duplicated
++EXPORT_SYMBOL_GPL vmlinux 0x70e27b7d	metadata_dst_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x710c309f	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x71489677	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x7148f9b4	find_module
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x717c662d	pkcs7_validate_trust
++EXPORT_SYMBOL_GPL vmlinux 0x718bf785	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71e2fdf4	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x71f325db	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x72282a8e	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0x7246d445	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x72a32871	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0x72acc164	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x72b71e8d	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0x72dcd684	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0x72e465a6	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x730c8177	l3mdev_master_ifindex_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x732ad2da	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x73884276	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0x73ce5442	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73ec02ee	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x742cfcdf	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x74477c71	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x746253c8	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x74937272	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x7493d174	posix_acl_default_xattr_handler
++EXPORT_SYMBOL_GPL vmlinux 0x74b5ea68	lcm_not_zero
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74cc5d98	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x74e5940a	kvm_vcpu_init
++EXPORT_SYMBOL_GPL vmlinux 0x74f48120	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x74fa78e3	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x7512bbe1	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x7544c06b	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0x755d249f	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0x7563b5ad	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0x7573d6de	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x75cbfb09	add_interrupt_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x75e8f777	dev_pm_disable_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7637c36a	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x76436cf8	perf_event_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x76645d40	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x76abb7a1	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x76b4110b	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x76d8e197	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x76ead8af	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x773c3d60	get_device
++EXPORT_SYMBOL_GPL vmlinux 0x7754bc11	dm_hold
++EXPORT_SYMBOL_GPL vmlinux 0x775dad68	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x7762ce4a	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0x777237ce	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x77867fd7	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x778c8dfd	cpu_device_create
++EXPORT_SYMBOL_GPL vmlinux 0x77b9bb90	__gmap_translate
++EXPORT_SYMBOL_GPL vmlinux 0x77bac45a	pids_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x77c72a35	md_run
++EXPORT_SYMBOL_GPL vmlinux 0x77db6647	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x77eacea9	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x77efdda0	scm_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7826d3a9	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0x78392807	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x783ed3c0	debugfs_create_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x785a93b4	si_mem_available
++EXPORT_SYMBOL_GPL vmlinux 0x78ae8175	smp_call_function_single_async
++EXPORT_SYMBOL_GPL vmlinux 0x78c551ce	device_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0x78e985a7	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0x791ddb43	pm_complete_with_resume_check
++EXPORT_SYMBOL_GPL vmlinux 0x79230cae	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794b7271	orderly_reboot
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x79a9c55c	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0x79defbe1	kthread_should_park
++EXPORT_SYMBOL_GPL vmlinux 0x7a3317b5	skb_zerocopy
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7aa53c30	fuse_dev_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL vmlinux 0x7ab2c4b1	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b16e616	gfn_to_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x7b30a53f	gfn_to_hva
++EXPORT_SYMBOL_GPL vmlinux 0x7b42f38a	zpci_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x7b6bc85c	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0x7b70ed5c	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x7bdfe123	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0x7be19179	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x7bfeba0b	dm_get_table_device
++EXPORT_SYMBOL_GPL vmlinux 0x7cc9c4c0	crypto_aead_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x7cde2282	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x7ce28559	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d72a346	pkcs7_verify
++EXPORT_SYMBOL_GPL vmlinux 0x7d83ea27	trace_event_buffer_commit
++EXPORT_SYMBOL_GPL vmlinux 0x7dda30af	unregister_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7de1919b	trace_clock
++EXPORT_SYMBOL_GPL vmlinux 0x7e927f92	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x7e978fdd	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7ebe5ba0	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0x7f13d491	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x7f18b463	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7f2321b8	x509_check_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7f76d45a	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x7f7cbc64	ip_tunnel_need_metadata
++EXPORT_SYMBOL_GPL vmlinux 0x7f8b9873	x509_request_asymmetric_key
++EXPORT_SYMBOL_GPL vmlinux 0x7fbed5b5	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x803919b5	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0x806209ff	dev_pm_set_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8065a4fc	mmu_notifier_call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x806b182b	debugfs_create_file_size
++EXPORT_SYMBOL_GPL vmlinux 0x8085fc6b	scsi_register_device_handler
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x80c0ae41	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x80c68137	nf_log_buf_close
++EXPORT_SYMBOL_GPL vmlinux 0x80d5d7dc	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80eb1d15	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x8114467b	cn_netlink_send_mult
++EXPORT_SYMBOL_GPL vmlinux 0x81280fc5	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x8128a78b	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0x8148ae6b	smpboot_update_cpumask_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x81622e8c	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x819035c4	component_master_add_with_match
++EXPORT_SYMBOL_GPL vmlinux 0x81a4e88e	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x81ccbb10	__list_lru_init
++EXPORT_SYMBOL_GPL vmlinux 0x82053c30	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0x826f6231	list_lru_count_node
++EXPORT_SYMBOL_GPL vmlinux 0x82944e7a	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x82d4ace1	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82f1709f	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0x8317c39c	rhashtable_insert_slow
++EXPORT_SYMBOL_GPL vmlinux 0x83203d8e	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x83672b28	mmput
++EXPORT_SYMBOL_GPL vmlinux 0x836fa9b1	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x8374170d	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x8379c7a7	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0x837aedd2	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x83ae85bf	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x83b0816e	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0x83bac790	__dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x83c58727	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x83fe0ea5	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0x8403d77f	ip6_datagram_connect_v6_only
++EXPORT_SYMBOL_GPL vmlinux 0x840c9180	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x8487a2b6	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x84978fe0	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x84b42af1	cond_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x84c8dd1e	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x84e3bed5	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x850b8a1c	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x854619f9	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8578cbc5	aead_exit_geniv
++EXPORT_SYMBOL_GPL vmlinux 0x859c21d5	tpm_chip_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85da5a50	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0x85fb86fe	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0x861c4ad7	percpu_ida_for_each_free
++EXPORT_SYMBOL_GPL vmlinux 0x8623709b	cio_update_schib
++EXPORT_SYMBOL_GPL vmlinux 0x863152ff	kvm_vcpu_read_guest_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x863ca66e	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x8646ada9	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0x86786286	klist_add_behind
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x8691523e	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x86b07fb9	__bpf_prog_free
++EXPORT_SYMBOL_GPL vmlinux 0x86c18440	zpci_store
++EXPORT_SYMBOL_GPL vmlinux 0x86ed23e5	perf_event_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x86f0d974	get_cached_msi_msg
++EXPORT_SYMBOL_GPL vmlinux 0x86f32c68	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86fdc4ba	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0x8702e548	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x8733b7c1	trace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x87485421	kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0x8786ff8f	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0x87a9342e	md_find_rdev_nr_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x87c798cd	kvm_init
++EXPORT_SYMBOL_GPL vmlinux 0x87ceb397	hypervisor_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x885985d0	inet_ehash_locks_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x88732f36	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x888e0f35	cgrp_dfl_root
++EXPORT_SYMBOL_GPL vmlinux 0x889441d6	device_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0x88d3d996	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0x88d5683f	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x88dd5fa6	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x88e6879c	udp4_hwcsum
++EXPORT_SYMBOL_GPL vmlinux 0x88eb58eb	param_ops_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x895c46ce	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0x89695c1c	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x89a1d796	sysfs_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0x89bcf2db	pci_domain_nr
++EXPORT_SYMBOL_GPL vmlinux 0x89c081f3	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0x89cb0b72	default_iommu_map_sg
++EXPORT_SYMBOL_GPL vmlinux 0x89cec74a	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x89f908c5	__tracepoint_mc_event
++EXPORT_SYMBOL_GPL vmlinux 0x8a00ecec	blkg_print_stat_bytes_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x8a0e75ad	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x8a2a9710	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0x8a8205d6	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x8a86f82f	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0x8a910442	tpm_put_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8a934158	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8ac06ab4	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x8b1a157c	ccw_device_force_console
++EXPORT_SYMBOL_GPL vmlinux 0x8b336a18	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8b5a8a97	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x8bb6893e	event_triggers_call
++EXPORT_SYMBOL_GPL vmlinux 0x8c0215f2	pm_system_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c2369a8	get_device_system_crosststamp
++EXPORT_SYMBOL_GPL vmlinux 0x8c52c34d	inet_csk_compat_setsockopt
++EXPORT_SYMBOL_GPL vmlinux 0x8c57c093	skb_complete_tx_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x8c61b5a6	static_key_deferred_flush
++EXPORT_SYMBOL_GPL vmlinux 0x8c73ba0b	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x8cd2941a	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x8cd8dc77	x509_get_sig_params
++EXPORT_SYMBOL_GPL vmlinux 0x8cdbfdf9	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d6b5d7e	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x8d82842e	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0x8d8fdbf9	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x8da5dc93	cpu_topology
++EXPORT_SYMBOL_GPL vmlinux 0x8da9c579	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0x8daf7aad	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x8db616a5	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x8dc3f279	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x8dc661d9	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x8dd2bfcf	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x8dfd5821	__cookie_v6_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL vmlinux 0x8e753070	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x8edea1cf	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0x8f0748af	rcu_expedite_gp
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f77758e	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x8fac80d9	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0x900ec0fa	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x903b627c	list_lru_isolate_move
++EXPORT_SYMBOL_GPL vmlinux 0x905817fc	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0x905eae0f	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90c1c4f0	css_sch_is_valid
++EXPORT_SYMBOL_GPL vmlinux 0x90e5d678	trace_seq_bitmask
++EXPORT_SYMBOL_GPL vmlinux 0x90ed0204	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x914da882	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x916eedad	rhashtable_init
++EXPORT_SYMBOL_GPL vmlinux 0x9177fe07	virtqueue_get_avail
++EXPORT_SYMBOL_GPL vmlinux 0x9184484e	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x918fff00	devm_free_pages
++EXPORT_SYMBOL_GPL vmlinux 0x91cb7fdc	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x925a7de4	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x92ad11df	css_sched_sch_todo
++EXPORT_SYMBOL_GPL vmlinux 0x92b0ad3e	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0x92b1e410	trace_clock_global
++EXPORT_SYMBOL_GPL vmlinux 0x92d65195	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x92db8f68	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x931bbbac	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x931f05d3	ktime_get_raw
++EXPORT_SYMBOL_GPL vmlinux 0x932b50db	x509_cert_parse
++EXPORT_SYMBOL_GPL vmlinux 0x9344cc78	__compat_only_sysfs_link_entry_to_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x93f72cc4	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x94157524	crypto_register_aeads
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x942235ef	kvm_vcpu_gfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0x9470371b	device_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x9482b4b3	get_state_synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x949053c4	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0x9492a68b	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x94fe67dd	bdev_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x95026eea	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x9504df26	irq_wake_thread
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x953e1b9e	ktime_get_real_seconds
++EXPORT_SYMBOL_GPL vmlinux 0x95459672	appldata_diag
++EXPORT_SYMBOL_GPL vmlinux 0x954bc1f9	event_triggers_post_call
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x956b19ce	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x95aeb0ff	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0x95ec25e7	mmu_notifier_unregister_no_release
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x9643a24f	tpm_unseal_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x96560fa1	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0x965eb878	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0x96873f40	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0x968a250a	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x9695e545	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x96a3aecd	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0x96a86bd6	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0x96e3a9ad	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x96e407cc	pci_reset_bridge_secondary_bus
++EXPORT_SYMBOL_GPL vmlinux 0x96e49785	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x96fa8f45	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0x975519c1	asymmetric_key_id_same
++EXPORT_SYMBOL_GPL vmlinux 0x9757ff2c	crypto_grab_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x97814aa5	debugfs_write_file_bool
++EXPORT_SYMBOL_GPL vmlinux 0x978793f5	freezer_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0x9797cffa	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL vmlinux 0x97c4b19f	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x97c98ff7	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x97e97ded	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x9819d3ce	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0x982509f8	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x982cd486	__cookie_v4_init_sequence
++EXPORT_SYMBOL_GPL vmlinux 0x98314fd2	tcp_ca_get_key_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x983f2d48	component_master_add_child
++EXPORT_SYMBOL_GPL vmlinux 0x984a49d3	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x98537a5f	netdev_is_rx_handler_busy
++EXPORT_SYMBOL_GPL vmlinux 0x9871a680	cio_enable_subchannel
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x98c3283a	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x98f8b355	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0x98fa1e20	dm_get_reserved_rq_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0x98fcf128	irq_work_queue_on
++EXPORT_SYMBOL_GPL vmlinux 0x991ad54e	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x9921a0de	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x997c4347	unmap_kernel_range
++EXPORT_SYMBOL_GPL vmlinux 0x99840d00	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x999ebd40	trace_print_bitmask_seq
++EXPORT_SYMBOL_GPL vmlinux 0x99bab161	nf_ct_zone_dflt
++EXPORT_SYMBOL_GPL vmlinux 0x99eb8070	list_lru_walk_node
++EXPORT_SYMBOL_GPL vmlinux 0x99fa21e6	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a2c1ce7	pci_try_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9a470627	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9a4c9c58	pci_common_swizzle
++EXPORT_SYMBOL_GPL vmlinux 0x9a5b33eb	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9a5d26f6	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9a92b096	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x9a9a0cd3	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x9ab0b220	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9aea73a0	__hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9affff09	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x9b00e6c2	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x9b4d69c9	add_disk_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x9ba87a50	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x9bd8fd66	dev_pm_domain_detach
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c38a298	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x9c60376e	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x9c891595	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x9c970c9c	rtnl_delete_link
++EXPORT_SYMBOL_GPL vmlinux 0x9c973142	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0x9caaa444	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0x9caf85c6	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x9cb22298	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ccd4108	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x9ce00c9c	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0x9cf8ba23	kernfs_path
++EXPORT_SYMBOL_GPL vmlinux 0x9d2d5e4f	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9d5080ca	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x9d71ac38	register_trace_event
++EXPORT_SYMBOL_GPL vmlinux 0x9d8b9e8b	kvm_io_bus_write
++EXPORT_SYMBOL_GPL vmlinux 0x9d9c3529	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x9e060242	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x9e472f5f	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0x9e7920a4	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0x9ed9ce8e	securityfs_create_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x9ee74958	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x9effe52c	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0x9f06b5bd	mddev_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x9f18dd8b	pci_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9f2bcce5	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x9f3ec5ad	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0x9f6f117e	l3mdev_fib_table_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x9f76c1e4	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0x9f871975	hugetlb_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0x9fafad95	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x9fb5467b	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0xa04d77a6	crypto_unregister_aeads
++EXPORT_SYMBOL_GPL vmlinux 0xa0d4a844	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0xa1198fd9	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0xa171f3b6	bio_trim
++EXPORT_SYMBOL_GPL vmlinux 0xa17d2443	cmf_readall
++EXPORT_SYMBOL_GPL vmlinux 0xa18f9433	mpi_read_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xa19991b2	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xa1bcd053	kernfs_get
++EXPORT_SYMBOL_GPL vmlinux 0xa1c3997f	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0xa1f20f89	pci_probe_reset_bus
++EXPORT_SYMBOL_GPL vmlinux 0xa21939ce	dax_pfn_mkwrite
++EXPORT_SYMBOL_GPL vmlinux 0xa225d2a1	kvm_vcpu_read_guest
++EXPORT_SYMBOL_GPL vmlinux 0xa23f00d1	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa2a97b66	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0xa2ac5519	percpu_ref_init
++EXPORT_SYMBOL_GPL vmlinux 0xa2bafa40	interval_tree_insert
++EXPORT_SYMBOL_GPL vmlinux 0xa2bf268f	vcpu_put
++EXPORT_SYMBOL_GPL vmlinux 0xa3049980	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0xa31214dc	kvm_clear_guest
++EXPORT_SYMBOL_GPL vmlinux 0xa31df8b6	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0xa35ee633	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0xa3845d18	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0xa385eadb	crypto_unregister_akcipher
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa3b958ce	reset_hung_task_detector
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa41e8371	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0xa43487a4	pids_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xa442d693	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0xa45143aa	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0xa4534734	pskb_put
++EXPORT_SYMBOL_GPL vmlinux 0xa4a42813	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0xa4a7cdbb	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0xa4bf96c9	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0xa4eeb1d4	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xa51f644f	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0xa5481736	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xa567f1aa	pci_generic_config_write32
++EXPORT_SYMBOL_GPL vmlinux 0xa5954702	__gmap_zap
++EXPORT_SYMBOL_GPL vmlinux 0xa59f77ef	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa5cce108	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa6030e28	trace_seq_puts
++EXPORT_SYMBOL_GPL vmlinux 0xa61b6723	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0xa61f1938	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xa62203e8	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa62d630a	io_cgrp_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xa62e388a	css_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xa64e77f8	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0xa6660ed0	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0xa6a3db58	__dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0xa6b10c4f	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6c5400d	__tracepoint_wbc_writepage
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa72c2970	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xa73b115c	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xa7b3b735	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xa80619fe	trace_seq_putc
++EXPORT_SYMBOL_GPL vmlinux 0xa816bed6	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xa84ed0c5	devices_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa89218d5	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0xa8a7ac46	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xa8b76a68	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xa8eba1b1	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa919bb0d	blk_mq_cancel_requeue_work
++EXPORT_SYMBOL_GPL vmlinux 0xa928e137	class_remove_file_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa9320d27	ktime_get_seconds
++EXPORT_SYMBOL_GPL vmlinux 0xa988f7c0	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xa9aef2e1	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9eee080	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0xa9ff15b9	s390_enable_sie
++EXPORT_SYMBOL_GPL vmlinux 0xaa10fc9e	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0xaa20a08d	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xaa28e48f	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0xaa82668a	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0xaaa62767	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xab21671b	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0xab2842b2	__wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0xab4761c1	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0xab567d31	percpu_ref_reinit
++EXPORT_SYMBOL_GPL vmlinux 0xab59c049	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab97a97d	s390_handle_mcck
++EXPORT_SYMBOL_GPL vmlinux 0xabc640f3	list_lru_isolate
++EXPORT_SYMBOL_GPL vmlinux 0xabe12262	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0xac165696	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xac208973	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0xac3b8d17	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0xac3d2d5f	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0xac945902	perf_pmu_register
++EXPORT_SYMBOL_GPL vmlinux 0xac9902a7	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xaccd395f	wbc_account_io
++EXPORT_SYMBOL_GPL vmlinux 0xacf54b32	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xacf84c48	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xad063b7b	__skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0xad2399ad	dev_pm_qos_update_user_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xad3dfa13	lgr_info_log
++EXPORT_SYMBOL_GPL vmlinux 0xad7a699c	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0xad89e574	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0xad9b63ef	user_update
++EXPORT_SYMBOL_GPL vmlinux 0xada01ca8	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0xadaaa3ae	diag308
++EXPORT_SYMBOL_GPL vmlinux 0xadbd6eae	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0xadc76691	__netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xadfe8985	bio_associate_blkcg
++EXPORT_SYMBOL_GPL vmlinux 0xae017403	wb_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0xae4fadfe	devres_alloc_node
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae76991a	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xaf657ab8	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xaf89d4be	gmap_do_ipte_notify
++EXPORT_SYMBOL_GPL vmlinux 0xaf8dbafe	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0xaf96b3c8	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0xaf9b4e2e	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0xb00a8738	kobject_move
++EXPORT_SYMBOL_GPL vmlinux 0xb00e1224	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xb02b3a54	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0xb034c3c6	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0xb0400c6b	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0xb044c5e2	scsi_dh_set_params
++EXPORT_SYMBOL_GPL vmlinux 0xb08c07ec	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0xb0b55e9d	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0xb0b5a6c9	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0c46a87	kvm_release_page_clean
++EXPORT_SYMBOL_GPL vmlinux 0xb10c828a	blk_mq_freeze_queue
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb1584176	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb1975477	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1b66edb	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1e9a41f	device_add
++EXPORT_SYMBOL_GPL vmlinux 0xb1ed128f	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb2436173	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0xb26a1add	elfcorehdr_addr
++EXPORT_SYMBOL_GPL vmlinux 0xb2ce8447	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0xb2f463e2	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb2fc1858	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xb30295ac	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0xb32ea9a7	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0xb3310062	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xb341ba32	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xb347bb2c	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0xb3f2d9d5	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0xb40c2f21	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xb4221fec	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0xb42db28c	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0xb43e0f2e	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0xb44c182f	list_lru_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xb45b4f7e	chsc_pnso_brinfo
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4be4e0a	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0xb4bf7556	device_add_property_set
++EXPORT_SYMBOL_GPL vmlinux 0xb4da5371	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0xb4f94827	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0xb51c9d3d	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0xb52e0511	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb5381118	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xb5458a33	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xb58cfbb2	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb58e2401	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5b7f816	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb60e94eb	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb643b9bb	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0xb6925658	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xb6b5cf1c	trace_seq_to_user
++EXPORT_SYMBOL_GPL vmlinux 0xb6d98b51	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xb70b3ba4	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0xb70bc3ec	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xb74f84ed	trace_seq_putmem_hex
++EXPORT_SYMBOL_GPL vmlinux 0xb755f6ce	is_skb_forwardable
++EXPORT_SYMBOL_GPL vmlinux 0xb7b0aa4f	klp_disable_patch
++EXPORT_SYMBOL_GPL vmlinux 0xb7be49ea	fwnode_property_read_u64_array
++EXPORT_SYMBOL_GPL vmlinux 0xb8095bfe	percpu_ida_free
++EXPORT_SYMBOL_GPL vmlinux 0xb82c555f	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0xb8345ec8	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0xb883512c	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0xb88dbfce	irq_set_irqchip_state
++EXPORT_SYMBOL_GPL vmlinux 0xb8cd3a7f	nf_logger_put
++EXPORT_SYMBOL_GPL vmlinux 0xb8fd91da	virtio_device_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb9052bf2	pci_proc_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb907b442	scm_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb92255ac	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0xb93e981c	fwnode_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xb983281f	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xb9946077	tpm2_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9de7d47	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0xb9ea9c8a	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xb9f065de	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xb9fb6de4	tpmm_chip_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xba211a15	virtio_device_restore
++EXPORT_SYMBOL_GPL vmlinux 0xba257277	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xba364ebf	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xba3b9f64	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xba7a8d66	crypto_get_default_null_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xba8741e6	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xba8ea3b7	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0xbab59458	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0xbac43340	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0xbadee137	kvm_vcpu_write_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xbaf6d630	mpi_read_raw_from_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xbaf90e39	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb056ed0	pci_generic_config_read32
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb128381	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xbb401e70	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0xbba6e3aa	devm_kstrdup
++EXPORT_SYMBOL_GPL vmlinux 0xbbc11963	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xbbc40a71	x509_decode_time
++EXPORT_SYMBOL_GPL vmlinux 0xbbd58005	gmap_ipte_notify
++EXPORT_SYMBOL_GPL vmlinux 0xbc10ac59	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xbc6bec66	free_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbc6dabe4	ipv6_proxy_select_ident
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcbbd266	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0xbcbe4277	klist_prev
++EXPORT_SYMBOL_GPL vmlinux 0xbcc3be74	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbcdf89c4	pci_probe_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xbcebca65	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xbcf45046	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xbd04a9f2	zpci_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0xbd0f9279	device_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0xbd3fe1e3	disable_hardirq
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd65f72b	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0xbd9f5274	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0xbdcffdb6	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbe173412	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0xbe2dde81	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xbe3e4b2e	vfs_fallocate
++EXPORT_SYMBOL_GPL vmlinux 0xbe5d116e	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xbe652b6e	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0xbe687e88	wake_up_all_idle_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xbe6ca664	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0xbe6d0e4e	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0xbe8da52f	kthread_unpark
++EXPORT_SYMBOL_GPL vmlinux 0xbea50c64	sysfs_remove_groups
++EXPORT_SYMBOL_GPL vmlinux 0xbea5ff1e	static_key_initialized
++EXPORT_SYMBOL_GPL vmlinux 0xbed224d7	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xbee21107	dm_internal_suspend_noflush
++EXPORT_SYMBOL_GPL vmlinux 0xbef2241d	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0xbef4475b	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0xbf0f37d1	__securityfs_setup_d_inode
++EXPORT_SYMBOL_GPL vmlinux 0xbf177ba7	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xbf2bf743	io_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xbf595bad	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0xbf5eebbe	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0xbf617613	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0xbf7facd4	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0xbfbbe50f	skb_zerocopy_headlen
++EXPORT_SYMBOL_GPL vmlinux 0xbfe5616d	tick_broadcast_oneshot_control
++EXPORT_SYMBOL_GPL vmlinux 0xbfed24dd	skb_splice_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbffa4f2b	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0xbffacab8	component_add
++EXPORT_SYMBOL_GPL vmlinux 0xbffde8ec	compat_alloc_user_space
++EXPORT_SYMBOL_GPL vmlinux 0xc081f77c	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc08a8573	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0xc08befff	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0xc0a0efc7	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0xc0a96e14	rcu_gp_is_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xc0b3c5bd	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0df8865	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0xc0f0458a	ip_tunnel_unneed_metadata
++EXPORT_SYMBOL_GPL vmlinux 0xc130b03e	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0xc18b5983	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0xc1aa26f8	vfs_submount
++EXPORT_SYMBOL_GPL vmlinux 0xc2089f00	kvm_vcpu_write_guest
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc23882e6	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc250d5c3	tty_buffer_unlock_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xc2517490	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0xc2725020	of_css
++EXPORT_SYMBOL_GPL vmlinux 0xc283d775	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0xc29922f1	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0xc2a7d371	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xc2c9262c	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xc2cddd7a	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xc2db540b	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0xc2e574e7	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xc2e58432	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0xc2ebce1d	__percpu_ida_init
++EXPORT_SYMBOL_GPL vmlinux 0xc2efdf06	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0xc31fb5ed	pci_try_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc34e2c32	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0xc357923c	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xc35c7e63	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xc35d1c2c	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc4788f23	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0xc4d0226d	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0xc4db606e	virtqueue_is_broken
++EXPORT_SYMBOL_GPL vmlinux 0xc4ec47b3	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0xc4f895ec	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xc511cd47	snprint_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xc5192366	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0xc542933a	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0xc5484e89	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc54f093e	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xc553b9cd	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0xc556bc26	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc5a86646	bdev_direct_access
++EXPORT_SYMBOL_GPL vmlinux 0xc5b6b582	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc62f1f3b	__skb_get_hash_symmetric
++EXPORT_SYMBOL_GPL vmlinux 0xc633d949	crypto_register_rng
++EXPORT_SYMBOL_GPL vmlinux 0xc63d847d	ktime_get_mono_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc64abd56	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0xc64b9ebe	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xc64f55ba	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc66d242c	scm_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xc6812d18	crypto_register_rngs
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6b8e59c	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0xc6f45b9f	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0xc705f5dc	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0xc7121e0f	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7a762e9	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7ec2cce	tracepoint_probe_register_prio
++EXPORT_SYMBOL_GPL vmlinux 0xc7f89ff8	kernfs_find_and_get_ns
++EXPORT_SYMBOL_GPL vmlinux 0xc7fdc049	device_create
++EXPORT_SYMBOL_GPL vmlinux 0xc803c99b	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0xc878fb59	__remove_pages
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8bd0cda	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0xc8d6ddf9	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc8de802f	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xc8fbd73c	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0xc92f3cc7	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0xc97429d4	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0xc97677da	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0xc9c43a1e	__ip_route_output_key_hash
++EXPORT_SYMBOL_GPL vmlinux 0xc9dc325b	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xca418722	component_bind_all
++EXPORT_SYMBOL_GPL vmlinux 0xca5d1b72	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xca5d66ee	rhashtable_walk_next
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xcac41364	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xcb054720	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0xcb176afb	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb501ab5	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0xcb5373c6	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0xcb8fe7bb	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0xcbb13a8f	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0xcbbf5e2f	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0xcbe56bc2	zs_get_total_pages
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcc4704bb	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc911e9f	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0xccb537fa	for_each_kernel_tracepoint
++EXPORT_SYMBOL_GPL vmlinux 0xccb91f4e	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0xccce6279	__tracepoint_suspend_resume
++EXPORT_SYMBOL_GPL vmlinux 0xccec8fa4	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0xccf2bf57	cgroup_path_ns
++EXPORT_SYMBOL_GPL vmlinux 0xccf60d12	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0xccfedfd0	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcd13984b	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0xcd2fb4a0	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0xcd37cd6f	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0xcd3a4134	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xcd449a56	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0xcd55ba44	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd974f00	rcu_all_qs
++EXPORT_SYMBOL_GPL vmlinux 0xcd9cd2ff	wakeme_after_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xcdb6adcc	ras_userspace_consumers
++EXPORT_SYMBOL_GPL vmlinux 0xcdbeed0e	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0xcdc27785	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0xcdc8b515	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcde34ce3	add_memory_resource
++EXPORT_SYMBOL_GPL vmlinux 0xcde574ac	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0xcdf315f0	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xce5f8f42	___ptrace_may_access
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6b9ee0	devm_hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0xce6db656	rcu_is_watching
++EXPORT_SYMBOL_GPL vmlinux 0xce71a10e	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xcea64ff0	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xcecba454	percpu_ida_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xcf120057	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0xcf2c3505	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0xcf3be4d8	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0xcf3dbf5d	device_move
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf737037	gmap_translate
++EXPORT_SYMBOL_GPL vmlinux 0xcf7b0223	chsc_scm_info
++EXPORT_SYMBOL_GPL vmlinux 0xcf854ddc	dev_pm_qos_hide_latency_tolerance
++EXPORT_SYMBOL_GPL vmlinux 0xcf886923	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0xcf8d69bb	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0xcfb5871c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfd4718b	iommu_get_domain_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0xcfdeb8fb	crypto_unregister_rng
++EXPORT_SYMBOL_GPL vmlinux 0xcfea77af	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xd008bef5	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd00b91ed	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0xd031b589	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd05d0918	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0c06665	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0xd0d13177	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0xd0dc6fc8	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0xd0e1a156	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL vmlinux 0xd0eb00a4	percpu_down_read
++EXPORT_SYMBOL_GPL vmlinux 0xd10c5ed7	component_master_del
++EXPORT_SYMBOL_GPL vmlinux 0xd10f71df	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xd11d5e4c	system_trusted_keyring
++EXPORT_SYMBOL_GPL vmlinux 0xd137af42	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd19a9523	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0xd1aaf2da	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xd1caddfd	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0xd1e7c1b2	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0xd1f2eee2	nf_logger_find_get
++EXPORT_SYMBOL_GPL vmlinux 0xd20ab993	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd247b5db	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd24cc89b	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0xd25766c1	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0xd25c2d24	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd29b33c1	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0xd29b73a9	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0xd2e00625	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0xd31eedde	kvm_read_guest_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xd3243ae8	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0xd328ae39	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xd34354a5	rhashtable_walk_start
++EXPORT_SYMBOL_GPL vmlinux 0xd352638b	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xd352f029	trace_seq_putmem
++EXPORT_SYMBOL_GPL vmlinux 0xd3b15669	public_key_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd41fffab	interval_tree_iter_first
++EXPORT_SYMBOL_GPL vmlinux 0xd4395d22	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0xd4831e10	component_master_add
++EXPORT_SYMBOL_GPL vmlinux 0xd487b454	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0xd4994f2f	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4d8c52f	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xd54768e0	gmap_free
++EXPORT_SYMBOL_GPL vmlinux 0xd5541799	pkcs7_free_message
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd56b5f64	ktime_get_ts64
++EXPORT_SYMBOL_GPL vmlinux 0xd5a4c838	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5db1efd	pci_remove_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xd60c99b5	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0xd60d23ba	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0xd63b550b	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xd6538036	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xd66bbcac	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xd6712402	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd6870ca5	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd68d5a06	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0xd69f5c95	tty_buffer_space_avail
++EXPORT_SYMBOL_GPL vmlinux 0xd6bd5ff4	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0xd6c36106	tcp_send_ack
++EXPORT_SYMBOL_GPL vmlinux 0xd6cadcff	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0xd6d672b0	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xd702695b	set_primary_fwnode
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd72b5798	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xd742ad15	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd7859ea6	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0xd7a33e78	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0xd7c0b6be	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd7c8e8cd	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7ef7fd0	__inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xd7f3d14d	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0xd7fe7138	get_net_ns_by_fd
++EXPORT_SYMBOL_GPL vmlinux 0xd803a600	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd838cf6a	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0xd8419862	gmap_disable
++EXPORT_SYMBOL_GPL vmlinux 0xd843d80e	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0xd8565f5a	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd88516a3	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0xd887a168	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0xd88a2f53	css_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd8a40ed7	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0xd8a769cb	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0xd8aae3c9	bpf_prog_put
++EXPORT_SYMBOL_GPL vmlinux 0xd8db78b1	task_cputime_adjusted
++EXPORT_SYMBOL_GPL vmlinux 0xd933e506	tpm2_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xd93b37fe	__sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd96babb4	interval_tree_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xd96e1839	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xd9843ff6	__tracepoint_block_split
++EXPORT_SYMBOL_GPL vmlinux 0xd9c56b06	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0xd9e5dda9	kvm_write_guest
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xd9f3131c	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0xda3242ad	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0xda3706c7	dax_do_io
++EXPORT_SYMBOL_GPL vmlinux 0xda3f3e8a	isc_register
++EXPORT_SYMBOL_GPL vmlinux 0xda6b62a4	iptunnel_handle_offloads
++EXPORT_SYMBOL_GPL vmlinux 0xda79aa52	dm_accept_partial_bio
++EXPORT_SYMBOL_GPL vmlinux 0xda90c43d	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0xdaed3073	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0xdb7280ec	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc858dfe	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdca14503	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd57e2b5	percpu_ref_exit
++EXPORT_SYMBOL_GPL vmlinux 0xdd73ae31	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0xdd7671e3	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xdd96c3fe	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xdd97a466	device_register
++EXPORT_SYMBOL_GPL vmlinux 0xdda4e80e	appldata_unregister_ops
++EXPORT_SYMBOL_GPL vmlinux 0xddbeeecc	pci_lock_rescan_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddd55a69	fib6_get_table
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xddf98b65	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xddfc074f	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xde0a3b99	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0xde13f1b7	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0xde1637d3	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0xde32b1ac	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0xde55b21c	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0xde8e3487	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0xdea218ef	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0xded301ac	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0xded5d8e0	irq_stat
++EXPORT_SYMBOL_GPL vmlinux 0xded6cc34	dax_pmd_fault
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf23c011	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0xdf3f5951	pci_device_is_present
++EXPORT_SYMBOL_GPL vmlinux 0xdf78022a	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xdf821352	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xdf82e3ba	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0xdf8e0927	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0xdf999e33	trace_event_buffer_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xdfa6dd04	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0xdfb33080	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0xdfb4e848	aead_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe00d8968	tpm2_probe
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe0513a87	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0xe06388fd	add_hwgenerator_randomness
++EXPORT_SYMBOL_GPL vmlinux 0xe071d05d	zs_pool_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe0837434	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe098eef8	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xe0ae2ce6	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0xe112cc95	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xe117d953	dev_pm_set_dedicated_wake_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe11c2925	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0xe12bf682	pm_runtime_get_if_in_use
++EXPORT_SYMBOL_GPL vmlinux 0xe132f71e	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xe1775ee7	dm_get_reserved_bio_based_ios
++EXPORT_SYMBOL_GPL vmlinux 0xe17b7a9e	__platform_register_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xe1e06997	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xe20172da	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0xe209a466	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xe22474b6	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0xe285ad0a	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0xe286b79c	kvm_vcpu_gfn_to_hva
++EXPORT_SYMBOL_GPL vmlinux 0xe2c67a52	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xe2fb4223	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0xe2febdc2	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe33c3b84	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xe358af79	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe40cc595	ccw_device_get_schid
++EXPORT_SYMBOL_GPL vmlinux 0xe42a98cb	__ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe45fec6c	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0xe464bce4	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0xe4689576	ktime_get_with_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe4900def	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0xe490fc81	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0xe4971ade	tracing_alloc_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0xe4ac4d98	dax_clear_blocks
++EXPORT_SYMBOL_GPL vmlinux 0xe4c511c3	bpf_skb_vlan_push_proto
++EXPORT_SYMBOL_GPL vmlinux 0xe4f7f8fd	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xe5612af5	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0xe56267e3	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5c60450	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe5e99dcf	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xe607f4d3	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0xe615ec0f	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xe6346654	pci_reset_slot
++EXPORT_SYMBOL_GPL vmlinux 0xe6355fb4	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0xe64ce6a4	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe652de93	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe6a6d5af	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0xe6abc3fc	skb_gso_transport_seglen
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6ef4abf	dm_internal_resume_fast
++EXPORT_SYMBOL_GPL vmlinux 0xe70a7e02	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0xe7151498	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0xe74a742f	fwnode_property_present
++EXPORT_SYMBOL_GPL vmlinux 0xe76012f3	iommu_capable
++EXPORT_SYMBOL_GPL vmlinux 0xe7617f8d	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe76c19a7	trace_event_ignore_this_pid
++EXPORT_SYMBOL_GPL vmlinux 0xe7822b34	out_of_line_wait_on_bit_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xe7b718df	chsc_determine_channel_path_desc
++EXPORT_SYMBOL_GPL vmlinux 0xe7bf96fb	pci_stop_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xe7cab89d	kobj_sysfs_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe7cf93a5	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0xe7f6467d	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe8092b2b	insn_to_mnemonic
++EXPORT_SYMBOL_GPL vmlinux 0xe853f157	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0xe8557947	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe869062e	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0xe86d7ca5	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0xe8d09f2f	chp_ssd_get_mask
++EXPORT_SYMBOL_GPL vmlinux 0xe8e019ae	chp_get_sch_opm
++EXPORT_SYMBOL_GPL vmlinux 0xe92bd8e8	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe969f05b	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xe987b420	gmap_unmap_segment
++EXPORT_SYMBOL_GPL vmlinux 0xe9999393	__tracepoint_add_device_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xe9a5ab5d	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea2b261b	s390_reset_cmma
++EXPORT_SYMBOL_GPL vmlinux 0xea4829d2	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0xea730606	cmf_read
++EXPORT_SYMBOL_GPL vmlinux 0xea836e79	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0xea8ef65d	dm_get_dev_t
++EXPORT_SYMBOL_GPL vmlinux 0xea907a44	kvm_read_guest
++EXPORT_SYMBOL_GPL vmlinux 0xea913242	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xea95cb5a	memory_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xeaaf3922	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0xeabaa784	handle_mm_fault
++EXPORT_SYMBOL_GPL vmlinux 0xeaf08820	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0xeb4e1391	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0xeb5452d6	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0xeb901258	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xeb97f855	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0xeba3233f	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0xeba3b545	gmap_register_ipte_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xeba745e1	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xebd23139	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xec030e2a	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0xec13c83c	si_swapinfo
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec4a8b5e	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0xec631f34	remove_memory
++EXPORT_SYMBOL_GPL vmlinux 0xec92948b	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xec93328b	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xecac82e6	tpm2_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xecb263b2	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xecb2ec85	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xecbd936c	md_kick_rdev_from_array
++EXPORT_SYMBOL_GPL vmlinux 0xecbe5b59	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0xece1e345	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xed69e9f0	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xed8f9b7a	__online_page_set_limits
++EXPORT_SYMBOL_GPL vmlinux 0xeda3a884	cpuset_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xedb2dedc	pci_assign_unassigned_bus_resources
++EXPORT_SYMBOL_GPL vmlinux 0xedd31b00	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0xedea3824	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0xedf62944	tty_buffer_set_limit
++EXPORT_SYMBOL_GPL vmlinux 0xee09dcd8	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0xee0b66ef	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0xee2e3fa9	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xee497f08	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0xee544cd9	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0xee6d0865	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0xeedd1428	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0xeef1e08e	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xef13106c	nr_threads
++EXPORT_SYMBOL_GPL vmlinux 0xef27c1e5	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6d007a	sigset_from_compat
++EXPORT_SYMBOL_GPL vmlinux 0xef86e566	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0xefa2c27d	register_tracepoint_module_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xefa7ae0c	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xefe6ab44	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xeffc6731	param_set_bool_enable_only
++EXPORT_SYMBOL_GPL vmlinux 0xf01e9938	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0xf03c072f	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0xf0727f12	ktime_get_raw_fast_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf07c3783	metadata_dst_alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xf099103d	__sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xf0c272cf	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0xf0c3c535	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0xf0c4c51f	rsa_verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xf0c8774d	__platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf1156ed9	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xf1263573	vtime_account_system
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf1ab9364	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0xf1b141d1	rsa_free_key
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1d6ccfa	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0xf2126288	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf2ac9f0e	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0xf2acdcf8	fwnode_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf2d6b721	inode_congested
++EXPORT_SYMBOL_GPL vmlinux 0xf311e156	key_being_used_for
++EXPORT_SYMBOL_GPL vmlinux 0xf318b340	__percpu_init_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf33fe1ca	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0xf3733469	device_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0xf37a8e3e	fwnode_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0xf3808cb1	get_state_synchronize_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xf393cb2e	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0xf3bcc9ea	dm_internal_suspend_fast
++EXPORT_SYMBOL_GPL vmlinux 0xf3df8b1e	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0xf3eeef3d	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18238	ktime_get_resolution_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf407dda4	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xf4586e69	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0xf488dedf	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4a70616	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0xf4cdbd9d	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf4fdb75f	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xf510d389	rsa_parse_pub_key
++EXPORT_SYMBOL_GPL vmlinux 0xf5247d53	rhashtable_walk_init
++EXPORT_SYMBOL_GPL vmlinux 0xf5494bc6	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xf54ae3f7	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5ba9820	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0xf5bcf1b2	__cookie_v4_check
++EXPORT_SYMBOL_GPL vmlinux 0xf5cad930	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xf5d149db	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xf5d67c8b	device_remove_property_set
++EXPORT_SYMBOL_GPL vmlinux 0xf60c7fbe	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0xf6625a9c	sock_gen_put
++EXPORT_SYMBOL_GPL vmlinux 0xf6636730	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xf67110c4	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf6893854	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0xf6a72a0d	fwnode_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xf6b6952b	sched_setscheduler_nocheck
++EXPORT_SYMBOL_GPL vmlinux 0xf6c8dc62	cpu_hotplug_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf70c3dd3	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0xf70ef850	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0xf7321dc3	percpu_up_read
++EXPORT_SYMBOL_GPL vmlinux 0xf7649396	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0xf790eb0e	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0xf79e906e	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf7b94f86	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0xf7c713e5	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf7ed5b77	kernfs_path_from_node
++EXPORT_SYMBOL_GPL vmlinux 0xf7fd7f87	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf82a73dc	trace_clock_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf83b7f5d	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xf868921a	rhashtable_walk_exit
++EXPORT_SYMBOL_GPL vmlinux 0xf8782b35	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf88c07d6	fwnode_handle_put
++EXPORT_SYMBOL_GPL vmlinux 0xf8ad196c	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0xf8ada807	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0xf8ba6ca0	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0xf8dd3fcb	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xf8e4fad0	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0xf8e6b564	hibernation_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8fd9e9d	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf90d2ec9	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf93f3237	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xf95322f4	kthread_parkme
++EXPORT_SYMBOL_GPL vmlinux 0xf972fa35	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf991c09f	rcu_qs_ctr
++EXPORT_SYMBOL_GPL vmlinux 0xf993e900	net_prio_cgrp_subsys_enabled_key
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9e36e8a	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf9e382b3	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf9f04dac	mpi_write_to_sgl
++EXPORT_SYMBOL_GPL vmlinux 0xfa0812cb	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa901b31	compat_get_timespec
++EXPORT_SYMBOL_GPL vmlinux 0xfa9e335e	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfadac245	user_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xfb1ee939	pci_create_root_bus
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb3f6f38	crypto_unregister_aead
++EXPORT_SYMBOL_GPL vmlinux 0xfb57ad89	bdev_write_page
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfbbd41ca	no_action
++EXPORT_SYMBOL_GPL vmlinux 0xfbd68fda	percpu_up_write
++EXPORT_SYMBOL_GPL vmlinux 0xfc017654	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc1098dc	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0xfc20bea7	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0xfc4fcde8	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xfc5c8257	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xfc5eb088	cpuacct_cgrp_subsys_on_dfl_key
++EXPORT_SYMBOL_GPL vmlinux 0xfc6d739c	__online_page_free
++EXPORT_SYMBOL_GPL vmlinux 0xfcbb5148	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0xfd204645	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0xfd2203b3	dax_zero_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xfd548f90	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xfd7a50ea	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0xfd7f64a5	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0xfdb8f5ad	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL vmlinux 0xfde90140	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xfdff8ecb	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xfe135ba0	user_free_preparse
++EXPORT_SYMBOL_GPL vmlinux 0xfe6bfba6	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xfe8301d2	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xfe94e4fe	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff288dce	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0xff29b22c	kvm_vcpu_gfn_to_pfn
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff633558	vprintk_default
++EXPORT_SYMBOL_GPL vmlinux 0xffb74af4	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xffdf079f	__pm_runtime_resume
+diff --git a/debian.master/abi/4.4.0-111.134/s390x/generic.compiler b/debian.master/abi/4.4.0-111.134/s390x/generic.compiler
+new file mode 100644
+index 0000000..d1936f3
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/s390x/generic.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu 5.4.0-6ubuntu1~16.04.5) 5.4.0 20160609
+diff --git a/debian.master/abi/4.4.0-111.134/s390x/generic.modules b/debian.master/abi/4.4.0-111.134/s390x/generic.modules
+new file mode 100644
+index 0000000..855320f
+--- /dev/null
++++ b/debian.master/abi/4.4.0-111.134/s390x/generic.modules
+@@ -0,0 +1,846 @@
++8021q
++842
++842_compress
++842_decompress
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++act_bpf
++act_connmark
++act_csum
++act_gact
++act_ipt
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++act_vlan
++aes_s390
++af-rxrpc
++af_alg
++af_iucv
++af_key
++af_packet_diag
++ah4
++ah6
++algif_aead
++algif_hash
++algif_rng
++algif_skcipher
++amd
++ansi_cprng
++anubis
++ap
++appldata_mem
++appldata_net_sum
++appldata_os
++aquantia
++arc4
++arp_tables
++arpt_mangle
++arptable_filter
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at803x
++aufs
++auth_rpcgss
++authenc
++authencesn
++bcache
++bcm-phy-lib
++bcm7038_wdt
++bcm7xxx
++bcm87xx
++binfmt_misc
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bonding
++br_netfilter
++brd
++bridge
++broadcom
++btrfs
++cachefiles
++camellia_generic
++cast5_generic
++cast6_generic
++cast_common
++ccm
++ccwgroup
++ceph
++ch
++chacha20_generic
++chacha20poly1305
++chsc_sch
++cicada
++cifs
++cls_basic
++cls_bpf
++cls_cgroup
++cls_flow
++cls_flower
++cls_fw
++cls_matchall
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cmac
++coda
++cordic
++cpu-notifier-error-inject
++crc-ccitt
++crc-itu-t
++crc32
++crc7
++crc8
++cryptd
++crypto_user
++ctcm
++ctr
++cts
++cuse
++dasd_diag_mod
++dasd_eckd_mod
++dasd_fba_mod
++dasd_mod
++davicom
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++dcssblk
++deflate
++des_generic
++des_s390
++diag288_wdt
++dlm
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-cache-smq
++dm-crypt
++dm-delay
++dm-era
++dm-flakey
++dm-log
++dm-log-userspace
++dm-log-writes
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dp83848
++dp83867
++drbd
++drbg
++drop_monitor
++dummy
++dummy_stm
++eadm_sch
++ebt_802_3
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++echainiv
++em_cmp
++em_ipset
++em_meta
++em_nbyte
++em_text
++em_u32
++eql
++esp4
++esp6
++et1011c
++faulty
++fcoe
++fcrypt
++fixed_phy
++fou
++fpga-mgr
++fs3270
++fscache
++fsm
++garp
++gcm
++geneve
++gennvm
++genwqe_card
++gf128mul
++gfs2
++ghash-generic
++ghash_s390
++grace
++gre
++hangcheck-timer
++hmcdrv
++ib_addr
++ib_cm
++ib_core
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ib_mthca
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++icplus
++ifb
++ila
++inet_diag
++intel_th
++intel_th_gth
++intel_th_msu
++intel_th_pci
++intel_th_pti
++intel_th_sth
++interval_tree_test
++ip6_gre
++ip6_tables
++ip6_tunnel
++ip6_udp_tunnel
++ip6_vti
++ip6t_MASQUERADE
++ip6t_NPT
++ip6t_REJECT
++ip6t_SYNPROXY
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_mh
++ip6t_rpfilter
++ip6t_rt
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6table_security
++ip_gre
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipmark
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_mac
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netnet
++ip_set_hash_netport
++ip_set_hash_netportnet
++ip_set_list_set
++ip_tables
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_fo
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_ovf
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipcomp
++ipcomp6
++ipip
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_SYNPROXY
++ipt_ah
++ipt_rpfilter
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++iptable_security
++ipvlan
++irqbypass
++iscsi_boot_sysfs
++iscsi_target_mod
++iscsi_tcp
++isofs
++iw_cm
++jitterentropy_rng
++kafs
++keywrap
++khazad
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++lcs
++libceph
++libcrc32c
++libfc
++libfcoe
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libphy
++libsas
++linear
++llc
++lockd
++locktorture
++lru_cache
++lrw
++lxt
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++macvlan
++macvtap
++marvell
++mcryptd
++md-cluster
++md4
++mdio-bcm-unimac
++mdio-bitbang
++mdio-cavium
++mdio-octeon
++mdio-thunder
++mdio-xgene
++memory-notifier-error-inject
++michael_mic
++micrel
++microchip
++mip6
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mlxsw_core
++mlxsw_pci
++monreader
++monwriter
++mpls_gso
++mpls_iptunnel
++mpls_router
++mpt3sas
++mrp
++msdos
++national
++nb8800
++nbd
++netconsole
++netiucv
++netlink_diag
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_dup_ipv4
++nf_dup_ipv6
++nf_log_arp
++nf_log_bridge
++nf_log_common
++nf_log_ipv4
++nf_log_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_masquerade_ipv4
++nf_nat_masquerade_ipv6
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_redirect
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nf_reject_ipv4
++nf_reject_ipv6
++nf_synproxy_core
++nf_tables
++nf_tables_arp
++nf_tables_bridge
++nf_tables_inet
++nf_tables_ipv4
++nf_tables_ipv6
++nf_tables_netdev
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfs_layout_flexfiles
++nfs_layout_nfsv41_files
++nfsd
++nfsv2
++nfsv3
++nfsv4
++nft_chain_nat_ipv4
++nft_chain_nat_ipv6
++nft_chain_route_ipv4
++nft_chain_route_ipv6
++nft_compat
++nft_counter
++nft_ct
++nft_dup_ipv4
++nft_dup_ipv6
++nft_exthdr
++nft_hash
++nft_limit
++nft_log
++nft_masq
++nft_masq_ipv4
++nft_masq_ipv6
++nft_meta
++nft_meta_bridge
++nft_nat
++nft_queue
++nft_rbtree
++nft_redir
++nft_redir_ipv4
++nft_redir_ipv6
++nft_reject
++nft_reject_bridge
++nft_reject_inet
++nft_reject_ipv4
++nft_reject_ipv6
++nilfs2
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++notifier-error-inject
++ntfs
++null_blk
++objlayoutdriver
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocfs2_stackglue
++openvswitch
++oprofile
++osd
++osdblk
++osst
++overlay
++p8022
++pcbc
++pci-stub
++pcrypt
++percpu_test
++pkcs7_test_key
++pktgen
++pm-notifier-error-inject
++poly1305_generic
++pps_core
++prng
++psnap
++ptp
++qdio
++qeth
++qeth_l2
++qeth_l3
++qsemi
++quota_tree
++quota_v1
++quota_v2
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++rbd
++rbtree_test
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++realtek
++rmd128
++rmd160
++rmd256
++rmd320
++rpcrdma
++rpcsec_gss_krb5
++rrpc
++rxkad
++salsa20_generic
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_hhf
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_pie
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++sclp_async
++sclp_cpi
++scm_block
++scsi_debug
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++seed
++seqiv
++serial_core
++serpent_generic
++sha1_s390
++sha256_s390
++sha512_s390
++sha_common
++sit
++smsc
++smsgiucv_app
++softdog
++spl
++splat
++st
++ste10Xp
++stm_console
++stm_core
++stp
++sunrpc
++tape
++tape_34xx
++tape_3590
++tape_class
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++tcm_fc
++tcm_loop
++tcp_bic
++tcp_cdg
++tcp_dctcp
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tea
++team
++team_mode_activebackup
++team_mode_broadcast
++team_mode_loadbalance
++team_mode_random
++team_mode_roundrobin
++teranetics
++test-hexdump
++test-kstrtox
++test-string_helpers
++test_bpf
++test_firmware
++test_module
++test_printf
++test_static_key_base
++test_static_keys
++test_udelay
++test_user_copy
++tgr192
++tipc
++torture
++tpm-rng
++ts_bm
++ts_fsm
++ts_kmp
++tunnel4
++tunnel6
++twofish_common
++twofish_generic
++uartlite
++udf
++udp_diag
++udp_tunnel
++unix_diag
++veth
++vfio
++vfio-pci
++vfio_iommu_type1
++vfio_virqfd
++vhost
++vhost_net
++vhost_scsi
++virtio-rng
++virtio_scsi
++vitesse
++vmac
++vmlogrdr
++vmur
++vport-geneve
++vport-gre
++vport-vxlan
++vrf
++vringh
++vsock
++vxlan
++wp512
++x_tables
++xcbc
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xor
++xt_AUDIT
++xt_CHECKSUM
++xt_CLASSIFY
++xt_CONNSECMARK
++xt_CT
++xt_DSCP
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_LOG
++xt_NETMAP
++xt_NFLOG
++xt_NFQUEUE
++xt_RATEEST
++xt_REDIRECT
++xt_SECMARK
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_TEE
++xt_TPROXY
++xt_TRACE
++xt_addrtype
++xt_bpf
++xt_cgroup
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_conntrack
++xt_cpu
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_ipcomp
++xt_iprange
++xt_ipvs
++xt_l2tp
++xt_length
++xt_limit
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_nfacct
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_realm
++xt_recent
++xt_sctp
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_tcpudp
++xt_time
++xt_u32
++xts
++zavl
++zcommon
++zcrypt_api
++zcrypt_cex2a
++zcrypt_cex4
++zcrypt_msgtype50
++zcrypt_msgtype6
++zcrypt_pcixcc
++zfcp
++zfs
++zlib
++zlib_deflate
++znvpair
++zpios
++zram
++zunicode
++zynq-fpga
+diff --git a/debian.master/abi/perm-blacklist b/debian.master/abi/perm-blacklist
+new file mode 100644
+index 0000000..e69de29
+diff --git a/debian.master/changelog b/debian.master/changelog
+new file mode 100644
+index 0000000..fea7d8f
+--- /dev/null
++++ b/debian.master/changelog
+@@ -0,0 +1,25085 @@
++linux (4.4.0-112.135) xenial; urgency=low
++
++  * linux: 4.4.0-112.135 -proposed tracker (LP: #1744244)
++
++  * CVE-2017-5715 // CVE-2017-5753
++    - x86/cpuid: Provide get_scattered_cpuid_leaf()
++    - SAUCE: Fix spec_ctrl support in KVM
++    - SAUCE: s390: improve cpu alternative handling for gmb and nobp
++    - SAUCE: s390: print messages for gmb and nobp
++    - [Config] KERNEL_NOBP=y
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Fri, 19 Jan 2018 11:03:51 +0100
++
++linux (4.4.0-111.134) xenial; urgency=low
++
++  * linux: 4.4.0-111.134 -proposed tracker (LP: #1743362)
++
++  * Do not duplicate changelog entries assigned to more than one bug or CVE
++    (LP: #1743383)
++    - [Packaging] git-ubuntu-log -- handle multiple bugs/cves better
++
++  * CVE-2017-5715 // CVE-2017-5753
++    - SAUCE: x86/microcode: Extend post microcode reload to support IBPB feature
++      -- repair missmerge
++    - Revert "x86/svm: Add code to clear registers on VM exit"
++    - kvm: vmx: Scrub hardware GPRs at VM-exit
++
++  * CVE-2017-5754
++    - SAUCE: powerpc: use sync instead of hwsync mnemonic
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Mon, 15 Jan 2018 15:05:02 +0100
++
++linux (4.4.0-110.133) xenial; urgency=low
++
++  * linux: 4.4.0-110.133 -proposed tracker (LP: #1742995)
++
++  * CVE-2017-5753
++    - x86/microcode/AMD: Add support for fam17h microcode loading
++    - bpf: add bpf_patch_insn_single helper
++    - bpf: prepare bpf_int_jit_compile/bpf_prog_select_runtime apis
++    - bpf: add generic constant blinding for use in jits
++    - locking/barriers: introduce new memory barrier gmb()
++    - bpf: prevent speculative execution in eBPF interpreter
++    - x86, bpf, jit: prevent speculative execution when JIT is enabled
++    - uvcvideo: prevent speculative execution
++    - carl9170: prevent speculative execution
++    - qla2xxx: prevent speculative execution
++    - Thermal/int340x: prevent speculative execution
++    - userns: prevent speculative execution
++    - ipv6: prevent speculative execution
++    - fs: prevent speculative execution
++    - net: mpls: prevent speculative execution
++    - udf: prevent speculative execution
++    - x86/feature: Enable the x86 feature to control Speculation
++    - x86/feature: Report presence of IBPB and IBRS control
++    - x86/enter: MACROS to set/clear IBRS and set IBPB
++    - x86/enter: Use IBRS on syscall and interrupts
++    - x86/idle: Disable IBRS entering idle and enable it on wakeup
++    - x86/idle: Disable IBRS when offlining cpu and re-enable on wakeup
++    - x86/mm: Set IBPB upon context switch
++    - x86/mm: Only set IBPB when the new thread cannot ptrace current thread
++    - x86/entry: Stuff RSB for entry to kernel for non-SMEP platform
++    - x86/kvm: add MSR_IA32_SPEC_CTRL and MSR_IA32_PRED_CMD to kvm
++    - x86/kvm: Set IBPB when switching VM
++    - x86/kvm: Toggle IBRS on VM entry and exit
++    - x86/kvm: Pad RSB on VM transition
++    - x86/spec_ctrl: Add sysctl knobs to enable/disable SPEC_CTRL feature
++    - x86/spec_ctrl: Add lock to serialize changes to ibrs and ibpb control
++    - x86/syscall: Clear unused extra registers on syscall entrance
++    - x86/syscall: Clear unused extra registers on 32-bit compatible syscall
++      entrance
++    - x86/entry: Use retpoline for syscall's indirect calls
++    - x86/cpu/amd, kvm: Satisfy guest kernel reads of IC_CFG MSR
++    - x86/cpu/AMD: Add speculative control support for AMD
++    - x86/microcode: Extend post microcode reload to support IBPB feature
++    - KVM: SVM: Do not intercept new speculative control MSRs
++    - x86/svm: Set IBRS value on VM entry and exit
++    - x86/svm: Set IBPB when running a different VCPU
++    - KVM: x86: Add speculative control CPUID support for guests
++    - x86/svm: Add code to clobber the RSB on VM exit
++    - x86/svm: Add code to clear registers on VM exit
++    - x86/cpu/AMD: Make the LFENCE instruction serialized
++    - x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC feature
++    - powerpc: add gmb barrier
++    - s390/spinlock: add gmb memory barrier
++    - SAUCE: x86/kvm: Fix stuff_RSB() for 32-bit
++    - arm64: no gmb() implementation yet
++    - arm: no gmb() implementation yet
++
++  * CVE-2017-5715
++    - x86/microcode/AMD: Add support for fam17h microcode loading
++    - bpf: add bpf_patch_insn_single helper
++    - bpf: prepare bpf_int_jit_compile/bpf_prog_select_runtime apis
++    - bpf: add generic constant blinding for use in jits
++    - locking/barriers: introduce new memory barrier gmb()
++    - bpf: prevent speculative execution in eBPF interpreter
++    - x86, bpf, jit: prevent speculative execution when JIT is enabled
++    - uvcvideo: prevent speculative execution
++    - carl9170: prevent speculative execution
++    - qla2xxx: prevent speculative execution
++    - Thermal/int340x: prevent speculative execution
++    - userns: prevent speculative execution
++    - ipv6: prevent speculative execution
++    - fs: prevent speculative execution
++    - net: mpls: prevent speculative execution
++    - udf: prevent speculative execution
++    - x86/feature: Enable the x86 feature to control Speculation
++    - x86/feature: Report presence of IBPB and IBRS control
++    - x86/enter: MACROS to set/clear IBRS and set IBPB
++    - x86/enter: Use IBRS on syscall and interrupts
++    - x86/idle: Disable IBRS entering idle and enable it on wakeup
++    - x86/idle: Disable IBRS when offlining cpu and re-enable on wakeup
++    - x86/mm: Set IBPB upon context switch
++    - x86/mm: Only set IBPB when the new thread cannot ptrace current thread
++    - x86/entry: Stuff RSB for entry to kernel for non-SMEP platform
++    - x86/kvm: add MSR_IA32_SPEC_CTRL and MSR_IA32_PRED_CMD to kvm
++    - x86/kvm: Set IBPB when switching VM
++    - x86/kvm: Toggle IBRS on VM entry and exit
++    - x86/kvm: Pad RSB on VM transition
++    - x86/spec_ctrl: Add sysctl knobs to enable/disable SPEC_CTRL feature
++    - x86/spec_ctrl: Add lock to serialize changes to ibrs and ibpb control
++    - x86/syscall: Clear unused extra registers on syscall entrance
++    - x86/syscall: Clear unused extra registers on 32-bit compatible syscall
++      entrance
++    - x86/entry: Use retpoline for syscall's indirect calls
++    - x86/cpu/amd, kvm: Satisfy guest kernel reads of IC_CFG MSR
++    - x86/cpu/AMD: Add speculative control support for AMD
++    - x86/microcode: Extend post microcode reload to support IBPB feature
++    - KVM: SVM: Do not intercept new speculative control MSRs
++    - x86/svm: Set IBRS value on VM entry and exit
++    - x86/svm: Set IBPB when running a different VCPU
++    - KVM: x86: Add speculative control CPUID support for guests
++    - x86/svm: Add code to clobber the RSB on VM exit
++    - x86/svm: Add code to clear registers on VM exit
++    - x86/cpu/AMD: Make the LFENCE instruction serialized
++    - x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC feature
++    - powerpc: add gmb barrier
++    - s390/spinlock: add gmb memory barrier
++    - SAUCE: x86/kvm: Fix stuff_RSB() for 32-bit
++    - arm64: no gmb() implementation yet
++    - arm: no gmb() implementation yet
++
++  * powerpc: flush L1D on return to use (LP: #1742772)
++    - SAUCE: powerpc: Secure memory rfi flush
++    - SAUCE: rfi-flush: Make DEBUG_RFI a CONFIG option
++    - SAUCE: rfi-flush: Add HRFI_TO_UNKNOWN and use it in denorm
++    - SAUCE: Fixup rfid in kvmppc_skip_Hinterrupt should be hrfid
++    - SAUCE: rfi-flush: kvmppc_skip_(H)interrupt returns to host
++    - SAUCE: KVM: Revert the implementation of H_GET_CPU_CHARACTERISTICS
++    - SAUCE: rfi-flush: Implement congruence-first fallback flush
++    - SAUCE: rfi-flush: Make l1d_flush_type bit flags
++    - SAUCE: rfi-flush: Push the instruction selection down to the patching
++      routine
++    - SAUCE: rfi-flush: Expand the RFI section to two nop slots
++    - SAUCE: rfi-flush: Support more than one flush type at once
++    - SAUCE: rfi-flush: Allow HV to advertise multiple flush types
++    - SAUCE: rfi-flush: Add speculation barrier before ori 30,30,0 flush
++    - SAUCE: powerpc/asm: Allow including ppc_asm.h in asm files
++    - SAUCE: Remove setup.h include file otherwise compilation complains about
++      missing header file.
++    - SAUCE: Fix compilation errors for arch/powerpc/lib/feature-fixups.c
++    - SAUCE: rfi-flush: Add barriers to the fallback L1D flushing
++    - SAUCE: rfi-flush: Rework powernv logic to be more cautious
++    - SAUCE: rfi-flush: Rework pseries logic to be more cautious
++    - SAUCE: rfi-flush: Fix the fallback flush to actually activate
++    - SAUCE: rfi-flush: Fix HRFI_TO_UNKNOWN
++    - SAUCE: rfi-flush: Refactor the macros so the nops are defined once
++    - SAUCE: rfi-flush: Add no_rfi_flush and nopti comandline options
++    - SAUCE: rfi-flush: Use rfi-flush in printks
++    - SAUCE: rfi-flush: Fallback flush add load dependency
++    - SAUCE: rfi-flush: Fix the 32-bit KVM build
++    - SAUCE: rfi-flush: Fix some RFI conversions in the KVM code
++    - SAUCE: UBUNTU: [Config] Disable CONFIG_PPC_DEBUG_RFI
++
++  * s390: add ppa to kernel entry/exit (LP: #1742771)
++    - s390: introduce CPU alternatives
++    - s390: add ppa to kernel entry / exit
++
++  * CVE-2017-5754
++    - x86/tlb: Drop the _GPL from the cpu_tlbstate export
++    - Map the vsyscall page with _PAGE_USER
++    - s390: introduce CPU alternatives
++    - s390: add ppa to kernel entry / exit
++    - SAUCE: powerpc: Secure memory rfi flush
++    - SAUCE: rfi-flush: Make DEBUG_RFI a CONFIG option
++    - SAUCE: rfi-flush: Add HRFI_TO_UNKNOWN and use it in denorm
++    - SAUCE: Fixup rfid in kvmppc_skip_Hinterrupt should be hrfid
++    - SAUCE: rfi-flush: kvmppc_skip_(H)interrupt returns to host
++    - SAUCE: KVM: Revert the implementation of H_GET_CPU_CHARACTERISTICS
++    - SAUCE: rfi-flush: Implement congruence-first fallback flush
++    - SAUCE: rfi-flush: Make l1d_flush_type bit flags
++    - SAUCE: rfi-flush: Push the instruction selection down to the patching
++      routine
++    - SAUCE: rfi-flush: Expand the RFI section to two nop slots
++    - SAUCE: rfi-flush: Support more than one flush type at once
++    - SAUCE: rfi-flush: Allow HV to advertise multiple flush types
++    - SAUCE: rfi-flush: Add speculation barrier before ori 30,30,0 flush
++    - SAUCE: powerpc/asm: Allow including ppc_asm.h in asm files
++    - SAUCE: Remove setup.h include file otherwise compilation complains about
++      missing header file.
++    - SAUCE: Fix compilation errors for arch/powerpc/lib/feature-fixups.c
++    - SAUCE: rfi-flush: Add barriers to the fallback L1D flushing
++    - SAUCE: rfi-flush: Rework powernv logic to be more cautious
++    - SAUCE: rfi-flush: Rework pseries logic to be more cautious
++    - SAUCE: rfi-flush: Fix the fallback flush to actually activate
++    - SAUCE: rfi-flush: Fix HRFI_TO_UNKNOWN
++    - SAUCE: rfi-flush: Refactor the macros so the nops are defined once
++    - SAUCE: rfi-flush: Add no_rfi_flush and nopti comandline options
++    - SAUCE: rfi-flush: Use rfi-flush in printks
++    - SAUCE: rfi-flush: Fallback flush add load dependency
++    - SAUCE: rfi-flush: Fix the 32-bit KVM build
++    - SAUCE: rfi-flush: Fix some RFI conversions in the KVM code
++    - SAUCE: UBUNTU: [Config] Disable CONFIG_PPC_DEBUG_RFI
++
++ -- Marcelo Henrique Cerri <marcelo.cerri@canonical.com>  Fri, 12 Jan 2018 14:47:54 -0200
++
++linux (4.4.0-109.132) xenial; urgency=low
++
++  * linux: 4.4.0-109.132 -proposed tracker (LP: #1742252)
++
++  * Kernel trace with xenial 4.4  (4.4.0-108.131, Candidate kernels for PTI fix)
++    (LP: #1741934)
++    - SAUCE: kaiser: fix perf crashes - fix to original commit
++
++ -- Marcelo Henrique Cerri <marcelo.cerri@canonical.com>  Tue, 09 Jan 2018 15:56:26 -0200
++
++linux (4.4.0-108.131) xenial; urgency=low
++
++  * linux: 4.4.0-108.131 -proposed tracker (LP: #1741727)
++
++  * CVE-2017-5754
++    - x86/mm: Disable PCID on 32-bit kernels
++
++ -- Marcelo Henrique Cerri <marcelo.cerri@canonical.com>  Sun, 07 Jan 2018 11:46:05 -0200
++
++linux (4.4.0-107.130) xenial; urgency=low
++
++  * linux: 4.4.0-107.130 -proposed tracker (LP: #1741643)
++
++  * CVE-2017-5754
++    - Revert "UBUNTU: SAUCE: arch/x86/entry/vdso: temporarily disable vdso"
++    - KPTI: Report when enabled
++    - x86, vdso, pvclock: Simplify and speed up the vdso pvclock reader
++    - x86/vdso: Get pvclock data from the vvar VMA instead of the fixmap
++    - x86/kasan: Clear kasan_zero_page after TLB flush
++    - kaiser: Set _PAGE_NX only if supported
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Sat, 06 Jan 2018 17:13:03 +0100
++
++linux (4.4.0-106.129) xenial; urgency=low
++
++  * linux: 4.4.0-106.129 -proposed tracker (LP: #1741528)
++
++  * CVE-2017-5754
++    - KAISER: Kernel Address Isolation
++    - kaiser: merged update
++    - kaiser: do not set _PAGE_NX on pgd_none
++    - kaiser: stack map PAGE_SIZE at THREAD_SIZE-PAGE_SIZE
++    - kaiser: fix build and FIXME in alloc_ldt_struct()
++    - kaiser: KAISER depends on SMP
++    - kaiser: fix regs to do_nmi() ifndef CONFIG_KAISER
++    - kaiser: fix perf crashes
++    - kaiser: ENOMEM if kaiser_pagetable_walk() NULL
++    - kaiser: tidied up asm/kaiser.h somewhat
++    - kaiser: tidied up kaiser_add/remove_mapping slightly
++    - kaiser: kaiser_remove_mapping() move along the pgd
++    - kaiser: cleanups while trying for gold link
++    - kaiser: name that 0x1000 KAISER_SHADOW_PGD_OFFSET
++    - kaiser: delete KAISER_REAL_SWITCH option
++    - kaiser: vmstat show NR_KAISERTABLE as nr_overhead
++    - x86/mm: Enable CR4.PCIDE on supported systems
++    - x86/mm: Build arch/x86/mm/tlb.c even on !SMP
++    - x86/mm, sched/core: Uninline switch_mm()
++    - x86/mm: Add INVPCID helpers
++    - x86/mm: If INVPCID is available, use it to flush global mappings
++    - kaiser: enhanced by kernel and user PCIDs
++    - kaiser: load_new_mm_cr3() let SWITCH_USER_CR3 flush user
++    - kaiser: PCID 0 for kernel and 128 for user
++    - kaiser: x86_cr3_pcid_noflush and x86_cr3_pcid_user
++    - kaiser: paranoid_entry pass cr3 need to paranoid_exit
++    - kaiser: _pgd_alloc() without __GFP_REPEAT to avoid stalls
++    - kaiser: fix unlikely error in alloc_ldt_struct()
++    - kaiser: add "nokaiser" boot option, using ALTERNATIVE
++    - x86/kaiser: Rename and simplify X86_FEATURE_KAISER handling
++    - x86/boot: Add early cmdline parsing for options with arguments
++    - x86/kaiser: Check boottime cmdline params
++    - kaiser: use ALTERNATIVE instead of x86_cr3_pcid_noflush
++    - kaiser: drop is_atomic arg to kaiser_pagetable_walk()
++    - kaiser: asm/tlbflush.h handle noPGE at lower level
++    - kaiser: kaiser_flush_tlb_on_return_to_user() check PCID
++    - x86/paravirt: Dont patch flush_tlb_single
++    - x86/kaiser: Reenable PARAVIRT
++    - kaiser: disabled on Xen PV
++    - x86/kaiser: Move feature detection up
++    - kvm: x86: fix RSM when PCID is non-zero
++    - SAUCE: arch/x86/entry/vdso: temporarily disable vdso
++    - [Config]: CONFIG_KAISER=y
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Fri, 05 Jan 2018 19:53:41 +0100
++
++linux (4.4.0-104.127) xenial; urgency=low
++
++  * linux: 4.4.0-104.127 -proposed tracker (LP: #1737511)
++
++  * upgrading linux-image package to 4.4.0-103.126 breaks Ceph network file
++    system connection (LP: #1737033)
++    - Revert "libceph: MOSDOpReply v7 encoding"
++    - Revert "libceph: advertise support for TUNABLES5"
++    - Revert "crush: decode and initialize chooseleaf_stable"
++    - Revert "crush: add chooseleaf_stable tunable"
++    - Revert "crush: ensure take bucket value is valid"
++    - Revert "crush: ensure bucket id is valid before indexing buckets array"
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Mon, 11 Dec 2017 12:20:36 +0100
++
++linux (4.4.0-103.126) xenial; urgency=low
++
++  * linux: 4.4.0-103.126 -proposed tracker (LP: #1736181)
++
++  * CVE-2017-1000405
++    - mm, thp: Do not make page table dirty unconditionally in touch_p[mu]d()
++
++  * CVE-2017-16939
++    - netlink: add a start callback for starting a netlink dump
++    - ipsec: Fix aborted xfrm policy dump crash
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Mon, 04 Dec 2017 16:50:53 +0100
++
++linux (4.4.0-102.125) xenial; urgency=low
++
++  * linux: 4.4.0-102.125 -proposed tracker (LP: #1733541)
++
++  * tar -x sometimes fails on overlayfs (LP: #1728489)
++    - ovl: check if all layers are on the same fs
++    - ovl: persistent inode number for directories
++
++  * NVMe timeout is too short (LP: #1729119)
++    - nvme: update timeout module parameter type
++
++  * Set PANIC_TIMEOUT=10 on Power Systems (LP: #1730660)
++    - [Config]: Set PANIC_TIMEOUT=10 on ppc64el
++
++  * Cannot pair BLE remote devices when using combo BT SoC (LP: #1731467)
++    - Bluetooth: increase timeout for le auto connections
++
++  * CIFS errors on 4.4.0-98, but not on 4.4.0-97 with same config (LP: #1729337)
++    - SMB3: Validate negotiate request must always be signed
++
++  * Plantronics P610 does not support sample rate reading (LP: #1719853)
++    - ALSA: usb-audio: Add sample rate quirk for Plantronics P610
++
++  * Invalid btree pointer causes the kernel NULL pointer dereference
++    (LP: #1729256)
++    - xfs: reinit btree pointer on attr tree inactivation walk
++
++  * Samba mount/umount in docker container triggers kernel Oops (LP: #1729637)
++    - ipv6: only call ip6_route_dev_notify() once for NETDEV_UNREGISTER
++    - ipv6: fix NULL dereference in ip6_route_dev_notify()
++
++  * [kernel] tty/hvc: Use opal irqchip interface if available (LP: #1728098)
++    - tty/hvc: Use opal irqchip interface if available
++
++  * Device hotplugging with MPT SAS cannot work for VMWare ESXi (LP: #1730852)
++    - scsi: mptsas: Fixup device hotplug for VMWare ESXi
++
++  * NMI watchdog: BUG: soft lockup on Guest upon boot (KVM) (LP: #1727331)
++    - KVM: PPC: Book3S: Treat VTB as a per-subcore register, not per-thread
++
++  * Attempt to map rbd image from ceph jewel/luminous hangs (LP: #1728739)
++    - crush: ensure bucket id is valid before indexing buckets array
++    - crush: ensure take bucket value is valid
++    - crush: add chooseleaf_stable tunable
++    - crush: decode and initialize chooseleaf_stable
++    - libceph: advertise support for TUNABLES5
++    - libceph: MOSDOpReply v7 encoding
++
++  * Xenial update to 4.4.98 stable release (LP: #1732698)
++    - adv7604: Initialize drive strength to default when using DT
++    - video: fbdev: pmag-ba-fb: Remove bad `__init' annotation
++    - PCI: mvebu: Handle changes to the bridge windows while enabled
++    - xen/netback: set default upper limit of tx/rx queues to 8
++    - drm: drm_minor_register(): Clean up debugfs on failure
++    - KVM: PPC: Book 3S: XICS: correct the real mode ICP rejecting counter
++    - iommu/arm-smmu-v3: Clear prior settings when updating STEs
++    - powerpc/corenet: explicitly disable the SDHC controller on kmcoge4
++    - ARM: omap2plus_defconfig: Fix probe errors on UARTs 5 and 6
++    - crypto: vmx - disable preemption to enable vsx in aes_ctr.c
++    - iio: trigger: free trigger resource correctly
++    - phy: increase size of MII_BUS_ID_SIZE and bus_id
++    - serial: sh-sci: Fix register offsets for the IRDA serial port
++    - usb: hcd: initialize hcd->flags to 0 when rm hcd
++    - netfilter: nft_meta: deal with PACKET_LOOPBACK in netdev family
++    - IPsec: do not ignore crypto err in ah4 input
++    - Input: mpr121 - handle multiple bits change of status register
++    - Input: mpr121 - set missing event capability
++    - IB/ipoib: Change list_del to list_del_init in the tx object
++    - s390/qeth: issue STARTLAN as first IPA command
++    - (config) Add NET_DSA=n
++    - net: dsa: select NET_SWITCHDEV
++    - platform/x86: hp-wmi: Fix detection for dock and tablet mode
++    - cdc_ncm: Set NTB format again after altsetting switch for Huawei devices
++    - KEYS: trusted: sanitize all key material
++    - KEYS: trusted: fix writing past end of buffer in trusted_read()
++    - platform/x86: hp-wmi: Fix error value for hp_wmi_tablet_state
++    - platform/x86: hp-wmi: Do not shadow error values
++    - x86/uaccess, sched/preempt: Verify access_ok() context
++    - workqueue: Fix NULL pointer dereference
++    - crypto: x86/sha1-mb - fix panic due to unaligned access
++    - KEYS: fix NULL pointer dereference during ASN.1 parsing [ver #2]
++    - ARM: 8720/1: ensure dump_instr() checks addr_limit
++    - ALSA: seq: Fix OSS sysex delivery in OSS emulation
++    - ALSA: seq: Avoid invalid lockdep class warning
++    - MIPS: microMIPS: Fix incorrect mask in insn_table_MM
++    - MIPS: Fix CM region target definitions
++    - MIPS: SMP: Use a completion event to signal CPU up
++    - MIPS: Fix race on setting and getting cpu_online_mask
++    - MIPS: SMP: Fix deadlock & online race
++    - test: firmware_class: report errors properly on failure
++    - selftests: firmware: add empty string and async tests
++    - selftests: firmware: send expected errors to /dev/null
++    - tools: firmware: check for distro fallback udev cancel rule
++    - MIPS: AR7: Defer registration of GPIO
++    - MIPS: AR7: Ensure that serial ports are properly set up
++    - Input: elan_i2c - add ELAN060C to the ACPI table
++    - drm/vmwgfx: Fix Ubuntu 17.10 Wayland black screen issue
++    - rbd: use GFP_NOIO for parent stat and data requests
++    - can: sun4i: handle overrun in RX FIFO
++    - can: c_can: don't indicate triple sampling support for D_CAN
++    - x86/oprofile/ppro: Do not use __this_cpu*() in preemptible context
++    - PKCS#7: fix unitialized boolean 'want'
++    - Linux 4.4.98
++
++  * ELANTECH Touchpad is not detected in 'Lenovo Ideapad 320 14AST' after fresh
++    install (LP: #1727544)
++    - Input: elan_i2c - add ELAN060C to the ACPI table
++
++  * Xenial update to 4.4.97 stable release (LP: #1731915)
++    - ALSA: timer: Add missing mutex lock for compat ioctls
++    - ALSA: seq: Fix nested rwsem annotation for lockdep splat
++    - cifs: check MaxPathNameComponentLength != 0 before using it
++    - KEYS: return full count in keyring_read() if buffer is too small
++    - KEYS: fix out-of-bounds read during ASN.1 parsing
++    - ASoC: adau17x1: Workaround for noise bug in ADC
++    - arm64: ensure __dump_instr() checks addr_limit
++    - ARM: dts: mvebu: pl310-cache disable double-linefill
++    - ARM: 8715/1: add a private asm/unaligned.h
++    - ocfs2: fstrim: Fix start offset of first cluster group during fstrim
++    - perf tools: Fix build failure on perl script context
++    - drm/msm: Fix potential buffer overflow issue
++    - drm/msm: fix an integer overflow test
++    - tracing/samples: Fix creation and deletion of simple_thread_fn creation
++    - Fix tracing sample code warning.
++    - PM / wakeirq: report a wakeup_event on dedicated wekup irq
++    - mmc: s3cmci: include linux/interrupt.h for tasklet_struct
++    - ARM: pxa: Don't rely on public mmc header to include leds.h
++    - mfd: ab8500-sysctrl: Handle probe deferral
++    - mfd: axp20x: Fix axp288 PEK_DBR and PEK_DBF irqs being swapped
++    - staging: rtl8712u: Fix endian settings for structs describing network
++      packets
++    - ext4: fix stripe-unaligned allocations
++    - ext4: do not use stripe_width if it is not set
++    - i2c: riic: correctly finish transfers
++    - drm/amdgpu: when dpm disabled, also need to stop/start vce.
++    - perf tools: Only increase index if perf_evsel__new_idx() succeeds
++    - cx231xx: Fix I2C on Internal Master 3 Bus
++    - xen/manage: correct return value check on xenbus_scanf()
++    - scsi: aacraid: Process Error for response I/O
++    - platform/x86: intel_mid_thermal: Fix module autoload
++    - staging: lustre: llite: don't invoke direct_IO for the EOF case
++    - staging: lustre: hsm: stack overrun in hai_dump_data_field
++    - staging: lustre: ptlrpc: skip lock if export failed
++    - exynos4-is: fimc-is: Unmap region obtained by of_iomap()
++    - mei: return error on notification request to a disconnected client
++    - s390/dasd: check for device error pointer within state change interrupts
++    - bt8xx: fix memory leak
++    - xen: don't print error message in case of missing Xenstore entry
++    - staging: r8712u: Fix Sparse warning in rtl871x_xmit.c
++    - Linux 4.4.97
++
++  * Xenial update to 4.4.96 stable release (LP: #1731882)
++    - workqueue: replace pool->manager_arb mutex with a flag
++    - ALSA: hda/realtek - Add support for ALC236/ALC3204
++    - ALSA: hda - fix headset mic problem for Dell machines with alc236
++    - ceph: unlock dangling spinlock in try_flush_caps()
++    - usb: xhci: Handle error condition in xhci_stop_device()
++    - spi: uapi: spidev: add missing ioctl header
++    - fuse: fix READDIRPLUS skipping an entry
++    - xen/gntdev: avoid out of bounds access in case of partial gntdev_mmap()
++    - Input: elan_i2c - add ELAN0611 to the ACPI table
++    - Input: gtco - fix potential out-of-bound access
++    - assoc_array: Fix a buggy node-splitting case
++    - scsi: zfcp: fix erp_action use-before-initialize in REC action trace
++    - scsi: sg: Re-fix off by one in sg_fill_request_table()
++    - can: sun4i: fix loopback mode
++    - can: kvaser_usb: Correct return value in printout
++    - can: kvaser_usb: Ignore CMD_FLUSH_QUEUE_REPLY messages
++    - regulator: fan53555: fix I2C device ids
++    - x86/microcode/intel: Disable late loading on model 79
++    - ecryptfs: fix dereference of NULL user_key_payload
++    - Revert "drm: bridge: add DT bindings for TI ths8135"
++    - Linux 4.4.96
++
++  * Touchpad not detected - Lenovo ideapad 320-15IKB (LP: #1723736)
++    - Input: elan_i2c - add ELAN0611 to the ACPI table
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Tue, 21 Nov 2017 15:37:52 +0100
++
++linux (4.4.0-101.124) xenial; urgency=low
++
++  * linux: 4.4.0-101.124 -proposed tracker (LP: #1731264)
++
++  * s390/mm: fix write access check in gup_huge_pmd() (LP: #1730596)
++    - s390/mm: fix write access check in gup_huge_pmd()
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Fri, 10 Nov 2017 08:24:10 -0200
++
++linux (4.4.0-100.123) xenial; urgency=low
++
++  * linux: 4.4.0-100.123 -proposed tracker (LP: #1729273)
++
++  * Xenial update to 4.4.95 stable release (LP: #1729107)
++    - USB: devio: Revert "USB: devio: Don't corrupt user memory"
++    - USB: core: fix out-of-bounds access bug in usb_get_bos_descriptor()
++    - USB: serial: metro-usb: add MS7820 device id
++    - usb: cdc_acm: Add quirk for Elatec TWN3
++    - usb: quirks: add quirk for WORLDE MINI MIDI keyboard
++    - usb: hub: Allow reset retry for USB2 devices on connect bounce
++    - ALSA: usb-audio: Add native DSD support for Pro-Ject Pre Box S2 Digital
++    - can: gs_usb: fix busy loop if no more TX context is available
++    - usb: musb: sunxi: Explicitly release USB PHY on exit
++    - usb: musb: Check for host-mode using is_host_active() on reset interrupt
++    - can: esd_usb2: Fix can_dlc value for received RTR, frames
++    - drm/nouveau/bsp/g92: disable by default
++    - drm/nouveau/mmu: flush tlbs before deleting page tables
++    - ALSA: seq: Enable 'use' locking in all configurations
++    - ALSA: hda: Remove superfluous '-' added by printk conversion
++    - i2c: ismt: Separate I2C block read from SMBus block read
++    - brcmsmac: make some local variables 'static const' to reduce stack size
++    - bus: mbus: fix window size calculation for 4GB windows
++    - clockevents/drivers/cs5535: Improve resilience to spurious interrupts
++    - rtlwifi: rtl8821ae: Fix connection lost problem
++    - KEYS: encrypted: fix dereference of NULL user_key_payload
++    - lib/digsig: fix dereference of NULL user_key_payload
++    - KEYS: don't let add_key() update an uninstantiated key
++    - pkcs7: Prevent NULL pointer dereference, since sinfo is not always set.
++    - parisc: Avoid trashing sr2 and sr3 in LWS code
++    - parisc: Fix double-word compare and exchange in LWS code on 32-bit kernels
++    - sched/autogroup: Fix autogroup_move_group() to never skip sched_move_task()
++    - f2fs crypto: replace some BUG_ON()'s with error checks
++    - f2fs crypto: add missing locking for keyring_key access
++    - fscrypt: fix dereference of NULL user_key_payload
++    - KEYS: Fix race between updating and finding a negative key
++    - fscrypto: require write access to mount to set encryption policy
++    - FS-Cache: fix dereference of NULL user_key_payload
++    - Linux 4.4.95
++
++  * Xenial update to 4.4.94 stable release (LP: #1729105)
++    - percpu: make this_cpu_generic_read() atomic w.r.t. interrupts
++    - drm/dp/mst: save vcpi with payloads
++    - MIPS: Fix minimum alignment requirement of IRQ stack
++    - sctp: potential read out of bounds in sctp_ulpevent_type_enabled()
++    - bpf/verifier: reject BPF_ALU64|BPF_END
++    - udpv6: Fix the checksum computation when HW checksum does not apply
++    - ip6_gre: skb_push ipv6hdr before packing the header in ip6gre_header
++    - net: emac: Fix napi poll list corruption
++    - packet: hold bind lock when rebinding to fanout hook
++    - bpf: one perf event close won't free bpf program attached by another perf
++      event
++    - isdn/i4l: fetch the ppp_write buffer in one shot
++    - vti: fix use after free in vti_tunnel_xmit/vti6_tnl_xmit
++    - l2tp: Avoid schedule while atomic in exit_net
++    - l2tp: fix race condition in l2tp_tunnel_delete
++    - tun: bail out from tun_get_user() if the skb is empty
++    - packet: in packet_do_bind, test fanout with bind_lock held
++    - packet: only test po->has_vnet_hdr once in packet_snd
++    - net: Set sk_prot_creator when cloning sockets to the right proto
++    - tipc: use only positive error codes in messages
++    - Revert "bsg-lib: don't free job in bsg_prepare_job"
++    - locking/lockdep: Add nest_lock integrity test
++    - watchdog: kempld: fix gcc-4.3 build
++    - irqchip/crossbar: Fix incorrect type of local variables
++    - mac80211_hwsim: check HWSIM_ATTR_RADIO_NAME length
++    - mac80211: fix power saving clients handling in iwlwifi
++    - net/mlx4_en: fix overflow in mlx4_en_init_timestamp()
++    - netfilter: nf_ct_expect: Change __nf_ct_expect_check() return value.
++    - iio: adc: xilinx: Fix error handling
++    - Btrfs: send, fix failure to rename top level inode due to name collision
++    - f2fs: do not wait for writeback in write_begin
++    - md/linear: shutup lockdep warnning
++    - sparc64: Migrate hvcons irq to panicked cpu
++    - net/mlx4_core: Fix VF overwrite of module param which disables DMFS on new
++      probed PFs
++    - crypto: xts - Add ECB dependency
++    - ocfs2/dlmglue: prepare tracking logic to avoid recursive cluster lock
++    - slub: do not merge cache if slub_debug contains a never-merge flag
++    - scsi: scsi_dh_emc: return success in clariion_std_inquiry()
++    - net: mvpp2: release reference to txq_cpu[] entry after unmapping
++    - i2c: at91: ensure state is restored after suspending
++    - ceph: clean up unsafe d_parent accesses in build_dentry_path
++    - uapi: fix linux/rds.h userspace compilation errors
++    - uapi: fix linux/mroute6.h userspace compilation errors
++    - target/iscsi: Fix unsolicited data seq_end_offset calculation
++    - nfsd/callback: Cleanup callback cred on shutdown
++    - cpufreq: CPPC: add ACPI_PROCESSOR dependency
++    - Revert "tty: goldfish: Fix a parameter of a call to free_irq"
++    - Linux 4.4.94
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 01 Nov 2017 16:54:28 -0200
++
++linux (4.4.0-99.122) xenial; urgency=low
++
++  * linux: 4.4.0-99.122 -proposed tracker (LP: #1728945)
++
++  * Remove vmbus-rdma driver from Xenial kernel (LP: #1721538)
++    - SAUCE: remove hv_network_direct driver
++    - [Config]: Remove hv_network_direct driver
++
++  * usb 3-1: 2:1: cannot get freq at ep 0x1 (LP: #1708499)
++    - ALSA: usb-audio: Add sample rate quirk for Plantronics C310/C520-M
++
++  * Plantronics Blackwire C520-M - Cannot get freq at ep 0x1, 0x81
++    (LP: #1709282)
++    - ALSA: usb-audio: Add sample rate quirk for Plantronics C310/C520-M
++
++  * wait-for-root fails to detect nbd root (LP: #696435)
++    - nbd: Create size change events for userspace
++
++  * Fix OpenNSL GPL bugs found by CoverityScan static analysis (LP: #1718388)
++    - SAUCE: opennsl: bcm-knet: check for null sinfo to avoid a null pointer
++      dereference
++    - SAUCE: opennsl: bcm-knet: remove redundant null checks on dev->name
++    - SAUCE: opennsl: bde: check for out-of-bounds index io.dev
++
++  * HID: multitouch: Correct ALPS PTP Stick and Touchpad devices ID
++    (LP: #1722719)
++    - Revert "HID: multitouch: Support ALPS PTP stick with pid 0x120A"
++
++  * Xenial update to 4.4.93 stable release (LP: #1724836)
++    - brcmfmac: add length check in brcmf_cfg80211_escan_handler()
++    - ext4: in ext4_seek_{hole,data}, return -ENXIO for negative offsets
++    - CIFS: Reconnect expired SMB sessions
++    - nl80211: Define policy for packet pattern attributes
++    - iwlwifi: mvm: use IWL_HCMD_NOCOPY for MCAST_FILTER_CMD
++    - rcu: Allow for page faults in NMI handlers
++    - USB: dummy-hcd: Fix deadlock caused by disconnect detection
++    - MIPS: math-emu: Remove pr_err() calls from fpu_emu()
++    - dmaengine: edma: Align the memcpy acnt array size with the transfer
++    - HID: usbhid: fix out-of-bounds bug
++    - crypto: shash - Fix zero-length shash ahash digest crash
++    - KVM: nVMX: fix guest CR4 loading when emulating L2 to L1 exit
++    - usb: renesas_usbhs: Fix DMAC sequence for receiving zero-length packet
++    - iommu/amd: Finish TLB flush in amd_iommu_unmap()
++    - ALSA: usb-audio: Kill stray URB at exiting
++    - ALSA: seq: Fix use-after-free at creating a port
++    - ALSA: seq: Fix copy_from_user() call inside lock
++    - ALSA: caiaq: Fix stray URB at probe error path
++    - ALSA: line6: Fix leftover URB at error-path during probe
++    - usb: gadget: composite: Fix use-after-free in
++      usb_composite_overwrite_options
++    - direct-io: Prevent NULL pointer access in submit_page_section
++    - fix unbalanced page refcounting in bio_map_user_iov
++    - USB: serial: ftdi_sio: add id for Cypress WICED dev board
++    - USB: serial: cp210x: add support for ELV TFD500
++    - USB: serial: option: add support for TP-Link LTE module
++    - Revert "UBUNTU: SAUCE: USB: serial: qcserial: add Dell DW5818, DW5819"
++    - USB: serial: qcserial: add Dell DW5818, DW5819
++    - USB: serial: console: fix use-after-free after failed setup
++    - x86/alternatives: Fix alt_max_short macro to really be a max()
++    - Linux 4.4.93
++
++  * NULL pointer dereference in tty_write() in kernel 4.4.0-93.116+
++    (LP: #1721065)
++    - tty: Prepare for destroying line discipline on hangup
++
++  * Xenial update to 4.4.92 stable release (LP: #1724783)
++    - usb: gadget: inode.c: fix unbalanced spin_lock in ep0_write
++    - USB: gadgetfs: Fix crash caused by inadequate synchronization
++    - USB: gadgetfs: fix copy_to_user while holding spinlock
++    - usb: gadget: udc: atmel: set vbus irqflags explicitly
++    - usb-storage: unusual_devs entry to fix write-access regression for Seagate
++      external drives
++    - usb: renesas_usbhs: fix the BCLR setting condition for non-DCP pipe
++    - usb: renesas_usbhs: fix usbhsf_fifo_clear() for RX direction
++    - ALSA: usb-audio: Check out-of-bounds access by corrupted buffer descriptor
++    - usb: pci-quirks.c: Corrected timeout values used in handshake
++    - USB: dummy-hcd: fix connection failures (wrong speed)
++    - USB: dummy-hcd: fix infinite-loop resubmission bug
++    - USB: dummy-hcd: Fix erroneous synchronization change
++    - USB: devio: Don't corrupt user memory
++    - usb: gadget: mass_storage: set msg_registered after msg registered
++    - USB: g_mass_storage: Fix deadlock when driver is unbound
++    - lsm: fix smack_inode_removexattr and xattr_getsecurity memleak
++    - ALSA: compress: Remove unused variable
++    - ALSA: usx2y: Suppress kernel warning at page allocation failures
++    - driver core: platform: Don't read past the end of "driver_override" buffer
++    - Drivers: hv: fcopy: restore correct transfer length
++    - stm class: Fix a use-after-free
++    - ftrace: Fix kmemleak in unregister_ftrace_graph
++    - HID: i2c-hid: allocate hid buffers for real worst case
++    - iwlwifi: add workaround to disable wide channels in 5GHz
++    - scsi: sd: Do not override max_sectors_kb sysfs setting
++    - USB: uas: fix bug in handling of alternate settings
++    - USB: core: harden cdc_parse_cdc_header
++    - usb: Increase quirk delay for USB devices
++    - USB: fix out-of-bounds in usb_set_configuration
++    - xhci: fix finding correct bus_state structure for USB 3.1 hosts
++    - iio: adc: twl4030: Fix an error handling path in 'twl4030_madc_probe()'
++    - iio: adc: twl4030: Disable the vusb3v1 rugulator in the error handling path
++      of 'twl4030_madc_probe()'
++    - iio: ad_sigma_delta: Implement a dedicated reset function
++    - staging: iio: ad7192: Fix - use the dedicated reset function avoiding dma
++      from stack.
++    - iio: core: Return error for failed read_reg
++    - iio: ad7793: Fix the serial interface reset
++    - iio: adc: mcp320x: Fix readout of negative voltages
++    - iio: adc: mcp320x: Fix oops on module unload
++    - uwb: properly check kthread_run return value
++    - uwb: ensure that endpoint is interrupt
++    - brcmfmac: setup passive scan if requested by user-space
++    - drm/i915/bios: ignore HDMI on port A
++    - sched/cpuset/pm: Fix cpuset vs. suspend-resume bugs
++    - ext4: fix data corruption for mmap writes
++    - ext4: Don't clear SGID when inheriting ACLs
++    - ext4: don't allow encrypted operations without keys
++    - Linux 4.4.92
++
++  * Xenial update to 4.4.91 stable release (LP: #1724772)
++    - drm_fourcc: Fix DRM_FORMAT_MOD_LINEAR #define
++    - drm: bridge: add DT bindings for TI ths8135
++    - GFS2: Fix reference to ERR_PTR in gfs2_glock_iter_next
++    - RDS: RDMA: Fix the composite message user notification
++    - ARM: dts: r8a7790: Use R-Car Gen 2 fallback binding for msiof nodes
++    - MIPS: Ensure bss section ends on a long-aligned address
++    - MIPS: ralink: Fix incorrect assignment on ralink_soc
++    - igb: re-assign hw address pointer on reset after PCI error
++    - extcon: axp288: Use vbus-valid instead of -present to determine cable
++      presence
++    - sh_eth: use correct name for ECMR_MPDE bit
++    - hwmon: (gl520sm) Fix overflows and crash seen when writing into limit
++      attributes
++    - iio: adc: axp288: Drop bogus AXP288_ADC_TS_PIN_CTRL register modifications
++    - iio: adc: hx711: Add DT binding for avia,hx711
++    - ARM: 8635/1: nommu: allow enabling REMAP_VECTORS_TO_RAM
++    - tty: goldfish: Fix a parameter of a call to free_irq
++    - IB/ipoib: Fix deadlock over vlan_mutex
++    - IB/ipoib: rtnl_unlock can not come after free_netdev
++    - IB/ipoib: Replace list_del of the neigh->list with list_del_init
++    - drm/amdkfd: fix improper return value on error
++    - USB: serial: mos7720: fix control-message error handling
++    - USB: serial: mos7840: fix control-message error handling
++    - partitions/efi: Fix integer overflow in GPT size calculation
++    - ASoC: dapm: handle probe deferrals
++    - audit: log 32-bit socketcalls
++    - usb: chipidea: vbus event may exist before starting gadget
++    - ASoC: dapm: fix some pointer error handling
++    - MIPS: Lantiq: Fix another request_mem_region() return code check
++    - net: core: Prevent from dereferencing null pointer when releasing SKB
++    - net/packet: check length in getsockopt() called with PACKET_HDRLEN
++    - team: fix memory leaks
++    - usb: plusb: Add support for PL-27A1
++    - mmc: sdio: fix alignment issue in struct sdio_func
++    - bridge: netlink: register netdevice before executing changelink
++    - netfilter: invoke synchronize_rcu after set the _hook_ to NULL
++    - MIPS: IRQ Stack: Unwind IRQ stack onto task stack
++    - exynos-gsc: Do not swap cb/cr for semi planar formats
++    - netfilter: nfnl_cthelper: fix incorrect helper->expect_class_max
++    - parisc: perf: Fix potential NULL pointer dereference
++    - iommu/io-pgtable-arm: Check for leaf entry before dereferencing it
++    - rds: ib: add error handle
++    - md/raid10: submit bio directly to replacement disk
++    - i2c: meson: fix wrong variable usage in meson_i2c_put_data
++    - xfs: remove kmem_zalloc_greedy
++    - libata: transport: Remove circular dependency at free time
++    - drivers: firmware: psci: drop duplicate const from psci_of_match
++    - IB/qib: fix false-postive maybe-uninitialized warning
++    - ARM: remove duplicate 'const' annotations'
++    - ALSA: au88x0: avoid theoretical uninitialized access
++    - ttpci: address stringop overflow warning
++    - Linux 4.4.91
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Tue, 31 Oct 2017 11:49:30 -0200
++
++linux (4.4.0-98.121) xenial; urgency=low
++
++  * linux: 4.4.0-98.121 -proposed tracker (LP: #1722299)
++
++  * Controller lockup detected on ProLiant DL380 Gen9 with P440 Controller
++    (LP: #1720359)
++    - scsi: hpsa: limit transfer length to 1MB
++
++  * [Dell Docking IE][0bda:8153] Realtek USB Ethernet leads to system hang
++    (LP: #1720977)
++    - r8152: fix the list rx_done may be used without initialization
++
++  * Add installer support for Broadcom BCM573xx network drivers. (LP: #1720466)
++    - d-i: Add bnxt_en to nic-modules.
++
++  * snapcraft.yaml: add dpkg-dev to the build deps (LP: #1718886)
++    - snapcraft.yaml: add dpkg-dev to the build deps
++
++  * Support setting I2C_TIMEOUT via ioctl for i2c-designware (LP: #1718578)
++    - i2c: designware: Use transfer timeout from ioctl I2C_TIMEOUT
++
++  * 5U84 - ses driver isn't binding right - cannot blink lights on 1 of the 2
++    5u84 (LP: #1693369)
++    - scsi_transport_sas: add function to get SAS endpoint address
++    - ses: fix discovery of SATA devices in SAS enclosures
++    - scsi: sas: provide stub implementation for scsi_is_sas_rphy
++    - scsi: ses: Fix SAS device detection in enclosure
++
++  * multipath -ll is not showing the disks which are actually multipath
++    (LP: #1718397)
++    - fs: aio: fix the increment of aio-nr and counting against aio-max-nr
++
++  * Support Dell Wireless DW5819/5818 WWAN devices (LP: #1721455)
++    - SAUCE: USB: serial: qcserial: add Dell DW5818, DW5819
++
++  * CVE-2017-10911
++    - xen-blkback: don't leak stack data via response ring
++
++  * implement 'complain mode' in seccomp for developer mode with snaps
++    (LP: #1567597)
++    - seccomp: Provide matching filter for introspection
++    - seccomp: Sysctl to display available actions
++    - seccomp: Operation for checking if an action is available
++    - seccomp: Sysctl to configure actions that are allowed to be logged
++    - seccomp: Selftest for detection of filter flag support
++    - seccomp: Action to log before allowing
++
++  * implement errno action logging in seccomp for strict mode with snaps
++    (LP: #1721676)
++    - seccomp: Provide matching filter for introspection
++    - seccomp: Sysctl to display available actions
++    - seccomp: Operation for checking if an action is available
++    - seccomp: Sysctl to configure actions that are allowed to be logged
++    - seccomp: Selftest for detection of filter flag support
++    - seccomp: Filter flag to log all actions except SECCOMP_RET_ALLOW
++
++  * [Xenial] update OpenNSL kernel modules to 6.5.10 (LP: #1721511)
++    - SAUCE: update OpenNSL kernel modules to 6.5.10
++
++  * Xenial update to 4.4.90 stable release (LP: #1721550)
++    - cifs: release auth_key.response for reconnect.
++    - mac80211: flush hw_roc_start work before cancelling the ROC
++    - KVM: PPC: Book3S: Fix race and leak in kvm_vm_ioctl_create_spapr_tce()
++    - tracing: Fix trace_pipe behavior for instance traces
++    - tracing: Erase irqsoff trace with empty write
++    - md/raid5: fix a race condition in stripe batch
++    - md/raid5: preserve STRIPE_ON_UNPLUG_LIST in break_stripe_batch_list
++    - scsi: scsi_transport_iscsi: fix the issue that iscsi_if_rx doesn't parse
++      nlmsg properly
++    - crypto: talitos - Don't provide setkey for non hmac hashing algs.
++    - crypto: talitos - fix sha224
++    - KEYS: fix writing past end of user-supplied buffer in keyring_read()
++    - KEYS: prevent creating a different user's keyrings
++    - KEYS: prevent KEYCTL_READ on negative key
++    - powerpc/pseries: Fix parent_dn reference leak in add_dt_node()
++    - Fix SMB3.1.1 guest authentication to Samba
++    - SMB: Validate negotiate (to protect against downgrade) even if signing off
++    - SMB3: Don't ignore O_SYNC/O_DSYNC and O_DIRECT flags
++    - vfs: Return -ENXIO for negative SEEK_HOLE / SEEK_DATA offsets
++    - nl80211: check for the required netlink attributes presence
++    - bsg-lib: don't free job in bsg_prepare_job
++    - seccomp: fix the usage of get/put_seccomp_filter() in seccomp_get_filter()
++    - arm64: Make sure SPsel is always set
++    - arm64: fault: Route pte translation faults via do_translation_fault
++    - KVM: VMX: Do not BUG() on out-of-bounds guest IRQ
++    - kvm: nVMX: Don't allow L2 to access the hardware CR8
++    - PCI: Fix race condition with driver_override
++    - btrfs: fix NULL pointer dereference from free_reloc_roots()
++    - btrfs: propagate error to btrfs_cmp_data_prepare caller
++    - btrfs: prevent to set invalid default subvolid
++    - x86/fpu: Don't let userspace set bogus xcomp_bv
++    - gfs2: Fix debugfs glocks dump
++    - timer/sysclt: Restrict timer migration sysctl values to 0 and 1
++    - KVM: VMX: do not change SN bit in vmx_update_pi_irte()
++    - KVM: VMX: remove WARN_ON_ONCE in kvm_vcpu_trigger_posted_interrupt
++    - cxl: Fix driver use count
++    - dmaengine: mmp-pdma: add number of requestors
++    - ARM: pxa: add the number of DMA requestor lines
++    - ARM: pxa: fix the number of DMA requestor lines
++    - KVM: VMX: use cmpxchg64
++    - video: fbdev: aty: do not leak uninitialized padding in clk to userspace
++    - swiotlb-xen: implement xen_swiotlb_dma_mmap callback
++    - fix xen_swiotlb_dma_mmap prototype
++    - Linux 4.4.90
++
++  * Xenial update to 4.4.89 stable release (LP: #1721477)
++    - ipv6: accept 64k - 1 packet length in ip6_find_1stfragopt()
++    - ipv6: add rcu grace period before freeing fib6_node
++    - ipv6: fix sparse warning on rt6i_node
++    - qlge: avoid memcpy buffer overflow
++    - Revert "net: phy: Correctly process PHY_HALTED in phy_stop_machine()"
++    - Revert "net: use lib/percpu_counter API for fragmentation mem accounting"
++    - Revert "net: fix percpu memory leaks"
++    - gianfar: Fix Tx flow control deactivation
++    - ipv6: fix memory leak with multiple tables during netns destruction
++    - ipv6: fix typo in fib6_net_exit()
++    - f2fs: check hot_data for roll-forward recovery
++    - x86/fsgsbase/64: Report FSBASE and GSBASE correctly in core dumps
++    - md/raid5: release/flush io in raid5_do_work()
++    - nfsd: Fix general protection fault in release_lock_stateid()
++    - mm: prevent double decrease of nr_reserved_highatomic
++    - tty: improve tty_insert_flip_char() fast path
++    - tty: improve tty_insert_flip_char() slow path
++    - tty: fix __tty_insert_flip_char regression
++    - Input: i8042 - add Gigabyte P57 to the keyboard reset table
++    - MIPS: math-emu: <MAX|MAXA|MIN|MINA>.<D|S>: Fix quiet NaN propagation
++    - MIPS: math-emu: <MAX|MAXA|MIN|MINA>.<D|S>: Fix cases of both inputs zero
++    - MIPS: math-emu: <MAX|MIN>.<D|S>: Fix cases of both inputs negative
++    - MIPS: math-emu: <MAXA|MINA>.<D|S>: Fix cases of input values with opposite
++      signs
++    - MIPS: math-emu: <MAXA|MINA>.<D|S>: Fix cases of both infinite inputs
++    - MIPS: math-emu: MINA.<D|S>: Fix some cases of infinity and zero inputs
++    - crypto: AF_ALG - remove SGL terminator indicator when chaining
++    - ext4: fix incorrect quotaoff if the quota feature is enabled
++    - ext4: fix quota inconsistency during orphan cleanup for read-only mounts
++    - powerpc: Fix DAR reporting when alignment handler faults
++    - block: Relax a check in blk_start_queue()
++    - md/bitmap: disable bitmap_resize for file-backed bitmaps.
++    - skd: Avoid that module unloading triggers a use-after-free
++    - skd: Submit requests to firmware before triggering the doorbell
++    - scsi: zfcp: fix queuecommand for scsi_eh commands when DIX enabled
++    - scsi: zfcp: add handling for FCP_RESID_OVER to the fcp ingress path
++    - scsi: zfcp: fix capping of unsuccessful GPN_FT SAN response trace records
++    - scsi: zfcp: fix passing fsf_req to SCSI trace on TMF to correlate with HBA
++    - scsi: zfcp: fix missing trace records for early returns in TMF eh handlers
++    - scsi: zfcp: fix payload with full FCP_RSP IU in SCSI trace records
++    - scsi: zfcp: trace HBA FSF response by default on dismiss or timedout late
++      response
++    - scsi: zfcp: trace high part of "new" 64 bit SCSI LUN
++    - scsi: megaraid_sas: Check valid aen class range to avoid kernel panic
++    - scsi: megaraid_sas: Return pended IOCTLs with cmd_status
++      MFI_STAT_WRONG_STATE in case adapter is dead
++    - scsi: storvsc: fix memory leak on ring buffer busy
++    - scsi: sg: remove 'save_scat_len'
++    - scsi: sg: use standard lists for sg_requests
++    - scsi: sg: off by one in sg_ioctl()
++    - scsi: sg: factor out sg_fill_request_table()
++    - scsi: sg: fixup infoleak when using SG_GET_REQUEST_TABLE
++    - scsi: qla2xxx: Fix an integer overflow in sysfs code
++    - ftrace: Fix selftest goto location on error
++    - tracing: Apply trace_clock changes to instance max buffer
++    - ARC: Re-enable MMU upon Machine Check exception
++    - PCI: shpchp: Enable bridge bus mastering if MSI is enabled
++    - media: v4l2-compat-ioctl32: Fix timespec conversion
++    - media: uvcvideo: Prevent heap overflow when accessing mapped controls
++    - bcache: initialize dirty stripes in flash_dev_run()
++    - bcache: Fix leak of bdev reference
++    - bcache: do not subtract sectors_to_gc for bypassed IO
++    - bcache: correct cache_dirty_target in __update_writeback_rate()
++    - bcache: Correct return value for sysfs attach errors
++    - bcache: fix for gc and write-back race
++    - bcache: fix bch_hprint crash and improve output
++    - ftrace: Fix memleak when unregistering dynamic ops when tracing disabled
++    - Linux 4.4.89
++
++  * ETPS/2 Elantech Touchpad inconsistently detected (Gigabyte P57W laptop)
++    (LP: #1594214)
++    - Input: i8042 - add Gigabyte P57 to the keyboard reset table
++
++  * Xenial update to 4.4.88 stable release (LP: #1718195)
++    - usb: quirks: add delay init quirk for Corsair Strafe RGB keyboard
++    - USB: serial: option: add support for D-Link DWM-157 C1
++    - usb: Add device quirk for Logitech HD Pro Webcam C920-C
++    - usb:xhci:Fix regression when ATI chipsets detected
++    - USB: core: Avoid race of async_completed() w/ usbdev_release()
++    - staging/rts5208: fix incorrect shift to extract upper nybble
++    - driver core: bus: Fix a potential double free
++    - intel_th: pci: Add Cannon Lake PCH-H support
++    - intel_th: pci: Add Cannon Lake PCH-LP support
++    - ath10k: fix memory leak in rx ring buffer allocation
++    - rtlwifi: rtl_pci_probe: Fix fail path of _rtl_pci_find_adapter
++    - Bluetooth: Add support of 13d3:3494 RTL8723BE device
++    - dlm: avoid double-free on error path in dlm_device_{register,unregister}
++    - mwifiex: correct channel stat buffer overflows
++    - drm/nouveau/pci/msi: disable MSI on big-endian platforms by default
++    - workqueue: Fix flag collision
++    - cs5536: add support for IDE controller variant
++    - scsi: sg: protect against races between mmap() and SG_SET_RESERVED_SIZE
++    - scsi: sg: recheck MMAP_IO request length with lock held
++    - drm: adv7511: really enable interrupts for EDID detection
++    - drm/bridge: adv7511: Fix mutex deadlock when interrupts are disabled
++    - drm/bridge: adv7511: Use work_struct to defer hotplug handing to out of irq
++      context
++    - drm/bridge: adv7511: Switch to using drm_kms_helper_hotplug_event()
++    - drm/bridge: adv7511: Re-write the i2c address before EDID probing
++    - btrfs: resume qgroup rescan on rw remount
++    - locktorture: Fix potential memory leak with rw lock test
++    - ALSA: msnd: Optimize / harden DSP and MIDI loops
++    - ARM: 8692/1: mm: abort uaccess retries upon fatal signal
++    - NFS: Fix 2 use after free issues in the I/O code
++    - xfs: XFS_IS_REALTIME_INODE() should be false if no rt device present
++    - Linux 4.4.88
++
++  * Kernel has troule recognizing Corsair Strafe RGB keyboard (LP: #1678477)
++    - usb: quirks: add delay init quirk for Corsair Strafe RGB keyboard
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Tue, 10 Oct 2017 08:52:24 -0300
++
++linux (4.4.0-97.120) xenial; urgency=low
++
++  * linux: 4.4.0-97.120 -proposed tracker (LP: #1718149)
++
++  * blk-mq: possible deadlock on CPU hot(un)plug (LP: #1670634)
++    - [Config] s390x -- disable CONFIG_{DM, SCSI}_MQ_DEFAULT
++
++  * Xenial update to 4.4.87 stable release (LP: #1715678)
++    - irqchip: mips-gic: SYNC after enabling GIC region
++    - i2c: ismt: Don't duplicate the receive length for block reads
++    - i2c: ismt: Return EMSGSIZE for block reads with bogus length
++    - ceph: fix readpage from fscache
++    - cpumask: fix spurious cpumask_of_node() on non-NUMA multi-node configs
++    - cpuset: Fix incorrect memory_pressure control file mapping
++    - alpha: uapi: Add support for __SANE_USERSPACE_TYPES__
++    - CIFS: remove endian related sparse warning
++    - wl1251: add a missing spin_lock_init()
++    - xfrm: policy: check policy direction value
++    - drm/ttm: Fix accounting error when fail to get pages for pool
++    - kvm: arm/arm64: Fix race in resetting stage2 PGD
++    - kvm: arm/arm64: Force reading uncached stage2 PGD
++    - epoll: fix race between ep_poll_callback(POLLFREE) and ep_free()/ep_remove()
++    - crypto: algif_skcipher - only call put_page on referenced and used pages
++    - Linux 4.4.87
++
++  * Xenial update to 4.4.86 stable release (LP: #1715430)
++    - scsi: isci: avoid array subscript warning
++    - ALSA: au88x0: Fix zero clear of stream->resources
++    - btrfs: remove duplicate const specifier
++    - i2c: jz4780: drop superfluous init
++    - gcov: add support for gcc version >= 6
++    - gcov: support GCC 7.1
++    - lightnvm: initialize ppa_addr in dev_to_generic_addr()
++    - p54: memset(0) whole array
++    - lpfc: Fix Device discovery failures during switch reboot test.
++    - arm64: mm: abort uaccess retries upon fatal signal
++    - x86/io: Add "memory" clobber to insb/insw/insl/outsb/outsw/outsl
++    - arm64: fpsimd: Prevent registers leaking across exec
++    - scsi: sg: protect accesses to 'reserved' page array
++    - scsi: sg: reset 'res_in_use' after unlinking reserved array
++    - drm/i915: fix compiler warning in drivers/gpu/drm/i915/intel_uncore.c
++    - Linux 4.4.86
++
++  * Xenial update to 4.4.85 stable release (LP: #1714298)
++    - af_key: do not use GFP_KERNEL in atomic contexts
++    - dccp: purge write queue in dccp_destroy_sock()
++    - dccp: defer ccid_hc_tx_delete() at dismantle time
++    - ipv4: fix NULL dereference in free_fib_info_rcu()
++    - net_sched/sfq: update hierarchical backlog when drop packet
++    - ipv4: better IP_MAX_MTU enforcement
++    - sctp: fully initialize the IPv6 address in sctp_v6_to_addr()
++    - tipc: fix use-after-free
++    - ipv6: reset fn->rr_ptr when replacing route
++    - ipv6: repair fib6 tree in failure case
++    - tcp: when rearming RTO, if RTO time is in past then fire RTO ASAP
++    - irda: do not leak initialized list.dev to userspace
++    - net: sched: fix NULL pointer dereference when action calls some targets
++    - net_sched: fix order of queue length updates in qdisc_replace()
++    - mei: me: add broxton pci device ids
++    - mei: me: add lewisburg device ids
++    - Input: trackpoint - add new trackpoint firmware ID
++    - Input: elan_i2c - add ELAN0602 ACPI ID to support Lenovo Yoga310
++    - ALSA: core: Fix unexpected error at replacing user TLV
++    - ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
++    - ARCv2: PAE40: Explicitly set MSB counterpart of SLC region ops addresses
++    - i2c: designware: Fix system suspend
++    - drm: Release driver tracking before making the object available again
++    - drm/atomic: If the atomic check fails, return its value first
++    - drm: rcar-du: lvds: Fix PLL frequency-related configuration
++    - drm: rcar-du: lvds: Rename PLLEN bit to PLLON
++    - drm: rcar-du: Fix crash in encoder failure error path
++    - drm: rcar-du: Fix display timing controller parameter
++    - drm: rcar-du: Fix H/V sync signal polarity configuration
++    - tracing: Fix freeing of filter in create_filter() when set_str is false
++    - cifs: Fix df output for users with quota limits
++    - cifs: return ENAMETOOLONG for overlong names in cifs_open()/cifs_lookup()
++    - nfsd: Limit end of page list when decoding NFSv4 WRITE
++    - perf/core: Fix group {cpu,task} validation
++    - Bluetooth: hidp: fix possible might sleep error in hidp_session_thread
++    - Bluetooth: cmtp: fix possible might sleep error in cmtp_session
++    - Bluetooth: bnep: fix possible might sleep error in bnep_session
++    - binder: use group leader instead of open thread
++    - binder: Use wake up hint for synchronous transactions.
++    - ANDROID: binder: fix proc->tsk check.
++    - iio: imu: adis16480: Fix acceleration scale factor for adis16480
++    - iio: hid-sensor-trigger: Fix the race with user space powering up sensors
++    - staging: rtl8188eu: add RNX-N150NUB support
++    - ASoC: simple-card: don't fail if sysclk setting is not supported
++    - ASoC: rsnd: disable SRC.out only when stop timing
++    - ASoC: rsnd: avoid pointless loop in rsnd_mod_interrupt()
++    - ASoC: rsnd: Add missing initialization of ADG req_rate
++    - ASoC: rsnd: ssi: 24bit data needs right-aligned settings
++    - ASoC: rsnd: don't call update callback if it was NULL
++    - ntb_transport: fix qp count bug
++    - ntb_transport: fix bug calculating num_qps_mw
++    - ACPI: ioapic: Clear on-stack resource before using it
++    - ACPI / APEI: Add missing synchronize_rcu() on NOTIFY_SCI removal
++    - Linux 4.4.85
++
++  * Xenial update to 4.4.84 stable release (LP: #1713729)
++    - audit: Fix use after free in audit_remove_watch_rule()
++    - parisc: pci memory bar assignment fails with 64bit kernels on dino/cujo
++    - crypto: x86/sha1 - Fix reads beyond the number of blocks passed
++    - Input: elan_i2c - Add antoher Lenovo ACPI ID for upcoming Lenovo NB
++    - ALSA: seq: 2nd attempt at fixing race creating a queue
++    - Revert "UBUNTU: SAUCE: (no-up) ALSA: usb-audio: Add quirk for sennheiser
++      officerunner"
++    - ALSA: usb-audio: Apply sample rate quirk to Sennheiser headset
++    - ALSA: usb-audio: Add mute TLV for playback volumes on C-Media devices
++    - mm/mempolicy: fix use after free when calling get_mempolicy
++    - xen: fix bio vec merging
++    - x86/asm/64: Clear AC on NMI entries
++    - irqchip/atmel-aic: Fix unbalanced of_node_put() in aic_common_irq_fixup()
++    - irqchip/atmel-aic: Fix unbalanced refcount in aic_common_rtc_irq_fixup()
++    - Sanitize 'move_pages()' permission checks
++    - pids: make task_tgid_nr_ns() safe
++    - perf/x86: Fix LBR related crashes on Intel Atom
++    - usb: optimize acpi companion search for usb port devices
++    - usb: qmi_wwan: add D-Link DWM-222 device ID
++    - Linux 4.4.84
++
++  * Intel i40e PF reset due to incorrect MDD detection (LP: #1713553)
++    - i40e: Limit TX descriptor count in cases where frag size is greater than 16K
++
++  * Neighbour confirmation broken, breaks ARP cache aging (LP: #1715812)
++    - sock: add sk_dst_pending_confirm flag
++    - net: add dst_pending_confirm flag to skbuff
++    - sctp: add dst_pending_confirm flag
++    - tcp: replace dst_confirm with sk_dst_confirm
++    - net: add confirm_neigh method to dst_ops
++    - net: use dst_confirm_neigh for UDP, RAW, ICMP, L2TP
++    - net: pending_confirm is not used anymore
++
++  * CVE-2017-14106
++    - tcp: initialize rcv_mss to TCP_MIN_MSS instead of 0
++
++  * [CIFS] Fix maximum SMB2 header size (LP: #1713884)
++    - CIFS: Fix maximum SMB2 header size
++
++  * Middle button of trackpoint doesn't work (LP: #1715271)
++    - Input: trackpoint - assume 3 buttons when buttons detection fails
++
++  * kernel BUG at /build/linux-lts-xenial-_hWfOZ/linux-lts-
++    xenial-4.4.0/security/apparmor/include/context.h:69! (LP: #1626984)
++    - SAUCE: fix oops when disabled and module parameters, are accessed
++
++  * Touchpad not detected (LP: #1708852)
++    - Input: elan_i2c - add ELAN0608 to the ACPI table
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Tue, 19 Sep 2017 17:55:11 +0200
++
++linux (4.4.0-96.119) xenial; urgency=low
++
++  * linux: 4.4.0-96.119 -proposed tracker (LP: #1716613)
++
++  * kernel panic -not syncing: Fatal exception: panic_on_oops (LP: #1708399)
++    - s390/mm: no local TLB flush for clearing-by-ASCE IDTE
++    - SAUCE: s390/mm: fix local TLB flushing vs. detach of an mm address space
++    - SAUCE: s390/mm: fix race on mm->context.flush_mm
++
++  * CVE-2017-1000251
++    - Bluetooth: Properly check L2CAP config option output buffer length
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Tue, 12 Sep 2017 15:40:01 +0200
++
++linux (4.4.0-95.118) xenial; urgency=low
++
++  * linux: 4.4.0-95.118 -proposed tracker (LP: #1715651)
++
++  * Xenial update to 4.4.78 stable release broke Address Sanitizer
++    (LP: #1715636)
++    - mm: revert x86_64 and arm64 ELF_ET_DYN_BASE base changes
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Thu, 07 Sep 2017 17:26:15 +0200
++
++linux (4.4.0-94.117) xenial; urgency=low
++
++  * linux: 4.4.0-94.117 -proposed tracker (LP: #1713462)
++
++  * mwifiex causes kernel oops when AP mode is enabled (LP: #1712746)
++    - SAUCE: net/wireless: do not dereference invalid pointer
++    - SAUCE: mwifiex: do not dereference invalid pointer
++
++  * Backport more recent Broadcom bnxt_en driver (LP: #1711056)
++    - SAUCE: bnxt_en_bpo: Import bnxt_en driver version 1.8.1
++    - SAUCE: bnxt_en_bpo: Drop distro out-of-tree detection logic
++    - SAUCE: bnxt_en_bpo: Remove unnecessary compile flags
++    - SAUCE: bnxt_en_bpo: Move config settings to Kconfig
++    - SAUCE: bnxt_en_bpo: Remove PCI_IDs handled by the regular driver
++    - SAUCE: bnxt_en_bpo: Rename the backport driver to bnxt_en_bpo
++    - bnxt_en_bpo: [Config] Enable CONFIG_BNXT_BPO=m
++
++  * HID: multitouch: Support ALPS PTP Stick and Touchpad devices (LP: #1712481)
++    - HID: multitouch: Support PTP Stick and Touchpad device
++    - SAUCE: HID: multitouch: Support ALPS PTP stick with pid 0x120A
++
++  * igb: Support using Broadcom 54616 as PHY (LP: #1712024)
++    - SAUCE: igb: add support for using Broadcom 54616 as PHY
++
++  * IPR driver causes multipath to fail paths/stuck IO on Medium Errors
++    (LP: #1682644)
++    - scsi: ipr: do not set DID_PASSTHROUGH on CHECK CONDITION
++
++  * accessing /dev/hvc1 with stress-ng on Ubuntu xenial causes crash
++    (LP: #1711401)
++    - tty/hvc: Use IRQF_SHARED for OPAL hvc consoles
++
++  * memory-hotplug test needs to be fixed (LP: #1710868)
++    - selftests: typo correction for memory-hotplug test
++    - selftests: check hot-pluggagble memory for memory-hotplug test
++    - selftests: check percentage range for memory-hotplug test
++    - selftests: add missing test name in memory-hotplug test
++    - selftests: fix memory-hotplug test
++
++  * HP lt4132 LTE/HSPA+ 4G Module (03f0:a31d) does not work (LP: #1707643)
++    - net: cdc_mbim: apply "NDP to end" quirk to HP lt4132
++
++  * Migrating KSM page causes the VM lock up as the KSM page merging list is too
++    large (LP: #1680513)
++    - ksm: introduce ksm_max_page_sharing per page deduplication limit
++    - ksm: fix use after free with merge_across_nodes = 0
++    - ksm: cleanup stable_node chain collapse case
++    - ksm: swap the two output parameters of chain/chain_prune
++    - ksm: optimize refile of stable_node_dup at the head of the chain
++
++  * sort ABI files with C.UTF-8 locale (LP: #1712345)
++    - [Packaging] sort ABI files with C.UTF-8 locale
++
++  * Include Broadcom GPL modules in Xenial Kernel (LP: #1665783)
++    - [Config] OpenNSL Kconfig/Makefile
++    - Import OpenNSL v3.1.0.17
++    - [Config] CONFIG_OPENNSL=y for amd64
++    - OpenNSL: Enable Kconfig and build
++    - SAUCE: opennsl: add proper CFLAGS
++
++  * Xenial update to 4.4.83 stable release (LP: #1711557)
++    - cpuset: fix a deadlock due to incomplete patching of cpusets_enabled()
++    - mm: ratelimit PFNs busy info message
++    - iscsi-target: fix memory leak in iscsit_setup_text_cmd()
++    - iscsi-target: Fix iscsi_np reset hung task during parallel delete
++    - fuse: initialize the flock flag in fuse_file on allocation
++    - nfs/flexfiles: fix leak of nfs4_ff_ds_version arrays
++    - USB: serial: option: add D-Link DWM-222 device ID
++    - USB: serial: cp210x: add support for Qivicon USB ZigBee dongle
++    - USB: serial: pl2303: add new ATEN device id
++    - usb: musb: fix tx fifo flush handling again
++    - USB: hcd: Mark secondary HCD as dead if the primary one died
++    - staging:iio:resolver:ad2s1210 fix negative IIO_ANGL_VEL read
++    - iio: accel: bmc150: Always restore device to normal mode after suspend-
++      resume
++    - iio: light: tsl2563: use correct event code
++    - uas: Add US_FL_IGNORE_RESIDUE for Initio Corporation INIC-3069
++    - USB: Check for dropped connection before switching to full speed
++    - usb: core: unlink urbs from the tail of the endpoint's urb_list
++    - usb: quirks: Add no-lpm quirk for Moshi USB to Ethernet Adapter
++    - usb:xhci:Add quirk for Certain failing HP keyboard on reset after resume
++    - iio: adc: vf610_adc: Fix VALT selection value for REFSEL bits
++    - pnfs/blocklayout: require 64-bit sector_t
++    - pinctrl: sunxi: add a missing function of A10/A20 pinctrl driver
++    - pinctrl: samsung: Remove bogus irq_[un]mask from resource management
++    - Linux 4.4.83
++
++  * Xenial update to 4.4.82 stable release (LP: #1711535)
++    - tcp: avoid setting cwnd to invalid ssthresh after cwnd reduction states
++    - net: fix keepalive code vs TCP_FASTOPEN_CONNECT
++    - bpf, s390: fix jit branch offset related to ldimm64
++    - net: sched: set xt_tgchk_param par.nft_compat as 0 in ipt_init_target
++    - tcp: fastopen: tcp_connect() must refresh the route
++    - net: avoid skb_warn_bad_offload false positives on UFO
++    - sparc64: Prevent perf from running during super critical sections
++    - KVM: arm/arm64: Handle hva aging while destroying the vm
++    - mm/mempool: avoid KASAN marking mempool poison checks as use-after-free
++    - Linux 4.4.82
++
++  * Xenial update to 4.4.81 stable release (LP: #1711526)
++    - libata: array underflow in ata_find_dev()
++    - workqueue: restore WQ_UNBOUND/max_active==1 to be ordered
++    - ALSA: hda - Fix speaker output from VAIO VPCL14M1R
++    - ASoC: do not close shared backend dailink
++    - KVM: async_pf: make rcu irq exit if not triggered from idle task
++    - mm/page_alloc: Remove kernel address exposure in free_reserved_area()
++    - ext4: fix SEEK_HOLE/SEEK_DATA for blocksize < pagesize
++    - ext4: fix overflow caused by missing cast in ext4_resize_fs()
++    - ARM: dts: armada-38x: Fix irq type for pca955
++    - media: platform: davinci: return -EINVAL for VPFE_CMD_S_CCDC_RAW_PARAMS
++      ioctl
++    - target: Avoid mappedlun symlink creation during lun shutdown
++    - iscsi-target: Always wait for kthread_should_stop() before kthread exit
++    - iscsi-target: Fix early sk_data_ready LOGIN_FLAGS_READY race
++    - iscsi-target: Fix initial login PDU asynchronous socket close OOPs
++    - iscsi-target: Fix delayed logout processing greater than
++      SECONDS_FOR_LOGOUT_COMP
++    - iser-target: Avoid isert_conn->cm_id dereference in isert_login_recv_done
++    - mm, mprotect: flush TLB if potentially racing with a parallel reclaim
++      leaving stale TLB entries
++    - media: lirc: LIRC_GET_REC_RESOLUTION should return microseconds
++    - f2fs: sanity check checkpoint segno and blkoff
++    - drm: rcar-du: fix backport bug
++    - saa7164: fix double fetch PCIe access condition
++    - ipv4: ipv6: initialize treq->txhash in cookie_v[46]_check()
++    - net: Zero terminate ifr_name in dev_ifname().
++    - ipv6: avoid overflow of offset in ip6_find_1stfragopt
++    - ipv4: initialize fib_trie prior to register_netdev_notifier call.
++    - rtnetlink: allocate more memory for dev_set_mac_address()
++    - mcs7780: Fix initialization when CONFIG_VMAP_STACK is enabled
++    - openvswitch: fix potential out of bound access in parse_ct
++    - packet: fix use-after-free in prb_retire_rx_blk_timer_expired()
++    - ipv6: Don't increase IPSTATS_MIB_FRAGFAILS twice in ip6_fragment()
++    - net: ethernet: nb8800: Handle all 4 RGMII modes identically
++    - dccp: fix a memleak that dccp_ipv6 doesn't put reqsk properly
++    - dccp: fix a memleak that dccp_ipv4 doesn't put reqsk properly
++    - dccp: fix a memleak for dccp_feat_init err process
++    - sctp: don't dereference ptr before leaving _sctp_walk_{params, errors}()
++    - sctp: fix the check for _sctp_walk_params and _sctp_walk_errors
++    - net/mlx5: Fix command bad flow on command entry allocation failure
++    - net: phy: Correctly process PHY_HALTED in phy_stop_machine()
++    - net: phy: Fix PHY unbind crash
++    - xen-netback: correctly schedule rate-limited queues
++    - sparc64: Measure receiver forward progress to avoid send mondo timeout
++    - wext: handle NULL extra data in iwe_stream_add_point better
++    - sh_eth: R8A7740 supports packet shecksumming
++    - net: phy: dp83867: fix irq generation
++    - tg3: Fix race condition in tg3_get_stats64().
++    - x86/boot: Add missing declaration of string functions
++    - phy state machine: failsafe leave invalid RUNNING state
++    - scsi: qla2xxx: Get mutex lock before checking optrom_state
++    - drm/virtio: fix framebuffer sparse warning
++    - virtio_blk: fix panic in initialization error path
++    - ARM: 8632/1: ftrace: fix syscall name matching
++    - mm, slab: make sure that KMALLOC_MAX_SIZE will fit into MAX_ORDER
++    - lib/Kconfig.debug: fix frv build failure
++    - signal: protect SIGNAL_UNKILLABLE from unintentional clearing.
++    - mm: don't dereference struct page fields of invalid pages
++    - workqueue: implicit ordered attribute should be overridable
++    - Linux 4.4.81
++
++  * Xenial update to 4.4.80 stable release (LP: #1710646)
++    - af_key: Add lock to key dump
++    - pstore: Make spinlock per zone instead of global
++    - powerpc/pseries: Fix of_node_put() underflow during reconfig remove
++    - crypto: authencesn - Fix digest_null crash
++    - md/raid5: add thread_group worker async_tx_issue_pending_all
++    - drm/vmwgfx: Fix gcc-7.1.1 warning
++    - drm/nouveau/bar/gf100: fix access to upper half of BAR2
++    - KVM: PPC: Book3S HV: Context-switch EBB registers properly
++    - KVM: PPC: Book3S HV: Restore critical SPRs to host values on guest exit
++    - KVM: PPC: Book3S HV: Reload HTM registers explicitly
++    - KVM: PPC: Book3S HV: Save/restore host values of debug registers
++    - Revert "powerpc/numa: Fix percpu allocations to be NUMA aware"
++    - Staging: comedi: comedi_fops: Avoid orphaned proc entry
++    - drm/rcar: Nuke preclose hook
++    - drm: rcar-du: Perform initialization/cleanup at probe/remove time
++    - drm: rcar-du: Simplify and fix probe error handling
++    - perf intel-pt: Fix ip compression
++    - perf intel-pt: Fix last_ip usage
++    - perf intel-pt: Use FUP always when scanning for an IP
++    - perf intel-pt: Ensure never to set 'last_ip' when packet 'count' is zero
++    - xfs: don't BUG() on mixed direct and mapped I/O
++    - nfc: fdp: fix NULL pointer dereference
++    - net: phy: Do not perform software reset for Generic PHY
++    - isdn: Fix a sleep-in-atomic bug
++    - isdn/i4l: fix buffer overflow
++    - ath10k: fix null deref on wmi-tlv when trying spectral scan
++    - wil6210: fix deadlock when using fw_no_recovery option
++    - mailbox: always wait in mbox_send_message for blocking Tx mode
++    - mailbox: skip complete wait event if timer expired
++    - mailbox: handle empty message in tx_tick
++    - mpt3sas: Don't overreach ioc->reply_post[] during initialization
++    - kaweth: fix firmware download
++    - kaweth: fix oops upon failed memory allocation
++    - sched/cgroup: Move sched_online_group() back into css_online() to fix crash
++    - PM / Domains: defer dev_pm_domain_set() until genpd->attach_dev succeeds if
++      present
++    - RDMA/uverbs: Fix the check for port number
++    - libnvdimm, btt: fix btt_rw_page not returning errors
++    - ipmi/watchdog: fix watchdog timeout set on reboot
++    - v4l: s5c73m3: fix negation operator
++    - pstore: Allow prz to control need for locking
++    - pstore: Correctly initialize spinlock and flags
++    - pstore: Use dynamic spinlock initializer
++    - net: skb_needs_check() accepts CHECKSUM_NONE for tx
++    - sched/cputime: Fix prev steal time accouting during CPU hotplug
++    - xen/blkback: don't free be structure too early
++    - xen/blkback: don't use xen_blkif_get() in xen-blkback kthread
++    - tpm: fix a kernel memory leak in tpm-sysfs.c
++    - tpm: Replace device number bitmap with IDR
++    - x86/mce/AMD: Make the init code more robust
++    - r8169: add support for RTL8168 series add-on card.
++    - ARM: dts: n900: Mark eMMC slot with no-sdio and no-sd flags
++    - net/mlx4: Remove BUG_ON from ICM allocation routine
++    - drm/msm: Ensure that the hardware write pointer is valid
++    - drm/msm: Verify that MSM_SUBMIT_BO_FLAGS are set
++    - vfio-pci: use 32-bit comparisons for register address for gcc-4.5
++    - irqchip/keystone: Fix "scheduling while atomic" on rt
++    - ASoC: tlv320aic3x: Mark the RESET register as volatile
++    - spi: dw: Make debugfs name unique between instances
++    - ASoC: nau8825: fix invalid configuration in Pre-Scalar of FLL
++    - irqchip/mxs: Enable SKIP_SET_WAKE and MASK_ON_SUSPEND
++    - openrisc: Add _text symbol to fix ksym build error
++    - dmaengine: ioatdma: Add Skylake PCI Dev ID
++    - dmaengine: ioatdma: workaround SKX ioatdma version
++    - dmaengine: ti-dma-crossbar: Add some 'of_node_put()' in error path.
++    - ARM64: zynqmp: Fix W=1 dtc 1.4 warnings
++    - ARM64: zynqmp: Fix i2c node's compatible string
++    - ARM: s3c2410_defconfig: Fix invalid values for NF_CT_PROTO_*
++    - ACPI / scan: Prefer devices without _HID/_CID for _ADR matching
++    - usb: gadget: Fix copy/pasted error message
++    - Btrfs: adjust outstanding_extents counter properly when dio write is split
++    - tools lib traceevent: Fix prev/next_prio for deadline tasks
++    - xfrm: Don't use sk_family for socket policy lookups
++    - perf tools: Install tools/lib/traceevent plugins with install-bin
++    - perf symbols: Robustify reading of build-id from sysfs
++    - video: fbdev: cobalt_lcdfb: Handle return NULL error from devm_ioremap
++    - vfio-pci: Handle error from pci_iomap
++    - arm64: mm: fix show_pte KERN_CONT fallout
++    - nvmem: imx-ocotp: Fix wrong register size
++    - sh_eth: enable RX descriptor word 0 shift on SH7734
++    - ALSA: usb-audio: test EP_FLAG_RUNNING at urb completion
++    - HID: ignore Petzl USB headlamp
++    - scsi: fnic: Avoid sending reset to firmware when another reset is in
++      progress
++    - scsi: snic: Return error code on memory allocation failure
++    - ASoC: dpcm: Avoid putting stream state to STOP when FE stream is paused
++    - Linux 4.4.80
++
++  * Please only recommend or suggest initramfs-tools | linux-initramfs-tool for
++    kernels able to boot without initramfs (LP: #1700972)
++    - [Debian] Don't depend on initramfs-tools
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Mon, 28 Aug 2017 17:07:08 +0200
++
++linux (4.4.0-93.116) xenial; urgency=low
++
++  * linux: 4.4.0-93.116 -proposed tracker (LP: #1709296)
++
++  * Creating conntrack entry failure with kernel 4.4.0-89 (LP: #1709032)
++    - Revert "Revert "netfilter: synproxy: fix conntrackd interaction""
++    - netfilter: nf_ct_ext: fix possible panic after nf_ct_extend_unregister
++
++  * CVE-2017-1000112
++    - Revert "udp: consistently apply ufo or fragmentation"
++    - udp: consistently apply ufo or fragmentation
++
++  * CVE-2017-1000111
++    - Revert "net-packet: fix race in packet_set_ring on PACKET_RESERVE"
++    - packet: fix tp_reserve race in packet_set_ring
++
++  * kernel BUG at [tty_ldisc_reinit] mm/slub.c! (LP: #1709126)
++    - tty: Simplify tty_set_ldisc() exit handling
++    - tty: Reset c_line from driver's init_termios
++    - tty: Handle NULL tty->ldisc
++    - tty: Move tty_ldisc_kill()
++    - tty: Use 'disc' for line discipline index name
++    - tty: Refactor tty_ldisc_reinit() for reuse
++    - tty: Destroy ldisc instance on hangup
++
++  * atheros bt failed after S3 (LP: #1706833)
++    - SAUCE: Bluetooth: Make request workqueue freezable
++
++  * The Precision Touchpad(PTP) button sends incorrect event code (LP: #1708372)
++    - HID: multitouch: handle external buttons for Precision Touchpads
++
++  * Set CONFIG_SATA_HIGHBANK=y on armhf (LP: #1703430)
++    - [Config] CONFIG_SATA_HIGHBANK=y
++
++  * xfs slab objects (memory) leak when xfs shutdown is called (LP: #1706132)
++    - xfs: fix xfs_log_ticket leak in xfs_end_io() after fs shutdown
++
++  * Adt tests of src:linux time out often on armhf lxc containers (LP: #1705495)
++    - [Packaging] tests -- reduce rebuild test to one flavour
++
++  * CVE-2017-7495
++    - ext4: fix data exposure after a crash
++
++  * ubuntu/rsi driver downlink wifi throughput drops to 5-6 Mbps when BT
++    keyboard is connected (LP: #1706991)
++    - SAUCE: Redpine: enable power save by default for coex mode
++    - SAUCE: Redpine: uapsd configuration changes
++
++  * [Hyper-V] hv_netvsc: Exclude non-TCP port numbers from vRSS hashing
++    (LP: #1690174)
++    - hv_netvsc: Exclude non-TCP port numbers from vRSS hashing
++
++  * ath10k doesn't report full RSSI information (LP: #1706531)
++    - ath10k: add per chain RSSI reporting
++
++  * ideapad_laptop don't support v310-14isk (LP: #1705378)
++    - platform/x86: ideapad-laptop: Add several models to no_hw_rfkill
++
++  * [8087:0a2b] Failed to load bluetooth firmware(might affect some other Intel
++    bt devices) (LP: #1705633)
++    - Bluetooth: btintel: Create common Intel Version Read function
++    - Bluetooth: Use switch statement for Intel hardware variants
++    - Bluetooth: Replace constant hw_variant from Intel Bluetooth firmware
++      filename
++    - Bluetooth: hci_intel: Fix firmware file name to use hw_variant
++    - Bluetooth: btintel: Add MODULE_FIRMWARE entries for iBT 3.5 controllers
++
++  * xhci_hcd: ERROR Transfer event TRB DMA ptr not part of current TD ep_index 2
++    comp_code 13 (LP: #1667750)
++    - xhci: Bad Ethernet performance plugged in ASM1042A host
++
++  * OpenPower: Some multipaths temporarily have only a single path
++    (LP: #1696445)
++    - scsi: ses: don't get power status of SES device slot on probe
++
++  * Hotkeys on new Thinkpad systems aren't working (LP: #1705169)
++    - platform/x86: thinkpad_acpi: Adding new hotkey ID for Lenovo thinkpad
++    - platform/x86: thinkpad_acpi: guard generic hotkey case
++    - platform/x86: thinkpad_acpi: add mapping for new hotkeys
++
++  * CVE-2015-7837
++    - SAUCE: (no-up) kexec/uefi: copy secure_boot flag in boot params across kexec
++      reboot
++
++  * misleading kernel warning skb_warn_bad_offload during checksum calculation
++    (LP: #1705447)
++    - net: reduce skb_warn_bad_offload() noise
++
++  * bonding: stack dump when unregistering a netdev (LP: #1704102)
++    - bonding: avoid NETDEV_CHANGEMTU event when unregistering slave
++
++  * Ubuntu 16.04 IOB Error when the Mustang board rebooted (LP: #1693673)
++    - drivers: net: xgene: Fix redundant prefetch buffer cleanup
++
++  * Ubuntu16.04: NVMe 4K+T10 DIF/DIX format returns I/O error on dd with split
++    op (LP: #1689946)
++    - blk-mq: NVMe 512B/4K+T10 DIF/DIX format returns I/O error on dd with split
++      op
++
++  * linux >= 4.2: bonding 802.3ad does not work with 5G, 25G and 50G link speeds
++    (LP: #1697892)
++    - bonding: add 802.3ad support for 100G speeds
++    - bonding: fix 802.3ad aggregator reselection
++    - bonding: add 802.3ad support for 25G speeds
++    - bonding: fix 802.3ad support for 5G and 50G speeds
++
++  * Xenial update to 4.4.79 stable release (LP: #1707233)
++    - disable new gcc-7.1.1 warnings for now
++    - ir-core: fix gcc-7 warning on bool arithmetic
++    - s5p-jpeg: don't return a random width/height
++    - thermal: cpu_cooling: Avoid accessing potentially freed structures
++    - ath9k: fix tx99 use after free
++    - ath9k: fix tx99 bus error
++    - NFC: fix broken device allocation
++    - NFC: nfcmrvl_uart: add missing tty-device sanity check
++    - NFC: nfcmrvl: do not use device-managed resources
++    - NFC: nfcmrvl: use nfc-device for firmware download
++    - NFC: nfcmrvl: fix firmware-management initialisation
++    - nfc: Ensure presence of required attributes in the activate_target handler
++    - nfc: Fix the sockaddr length sanitization in llcp_sock_connect
++    - NFC: Add sockaddr length checks before accessing sa_family in bind handlers
++    - perf intel-pt: Move decoder error setting into one condition
++    - perf intel-pt: Improve sample timestamp
++    - perf intel-pt: Fix missing stack clear
++    - perf intel-pt: Ensure IP is zero when state is INTEL_PT_STATE_NO_IP
++    - perf intel-pt: Clear FUP flag on error
++    - Bluetooth: use constant time memory comparison for secret values
++    - wlcore: fix 64K page support
++    - ASoC: compress: Derive substream from stream based on direction
++    - PM / Domains: Fix unsafe iteration over modified list of device links
++    - PM / Domains: Fix unsafe iteration over modified list of domain providers
++    - scsi: ses: do not add a device to an enclosure if enclosure_add_links()
++      fails.
++    - iscsi-target: Add login_keys_workaround attribute for non RFC initiators
++    - powerpc/64: Fix atomic64_inc_not_zero() to return an int
++    - powerpc: Fix emulation of mcrf in emulate_step()
++    - powerpc: Fix emulation of mfocrf in emulate_step()
++    - powerpc/asm: Mark cr0 as clobbered in mftb()
++    - af_key: Fix sadb_x_ipsecrequest parsing
++    - PCI/PM: Restore the status of PCI devices across hibernation
++    - ipvs: SNAT packet replies only for NATed connections
++    - xhci: fix 20000ms port resume timeout
++    - xhci: Fix NULL pointer dereference when cleaning up streams for removed host
++    - usb: storage: return on error to avoid a null pointer dereference
++    - USB: cdc-acm: add device-id for quirky printer
++    - usb: renesas_usbhs: fix usbhsc_resume() for !USBHSF_RUNTIME_PWCTRL
++    - usb: renesas_usbhs: gadget: disable all eps when the driver stops
++    - md: don't use flush_signals in userspace processes
++    - x86/xen: allow userspace access during hypercalls
++    - cx88: Fix regression in initial video standard setting
++    - Raid5 should update rdev->sectors after reshape
++    - s390/syscalls: Fix out of bounds arguments access
++    - drm/amd/amdgpu: Return error if initiating read out of range on vram
++    - drm/radeon/ci: disable mclk switching for high refresh rates (v2)
++    - drm/radeon: Fix eDP for single-display iMac10,1 (v2)
++    - ipmi: use rcu lock around call to intf->handlers->sender()
++    - ipmi:ssif: Add missing unlock in error branch
++    - f2fs: Don't clear SGID when inheriting ACLs
++    - vfio: Fix group release deadlock
++    - vfio: New external user group/file match
++    - ftrace: Fix uninitialized variable in match_records()
++    - MIPS: Fix mips_atomic_set() retry condition
++    - MIPS: Fix mips_atomic_set() with EVA
++    - MIPS: Negate error syscall return in trace
++    - x86/acpi: Prevent out of bound access caused by broken ACPI tables
++    - x86/ioapic: Pass the correct data to unmask_ioapic_irq()
++    - MIPS: Fix MIPS I ISA /proc/cpuinfo reporting
++    - MIPS: Save static registers before sysmips
++    - MIPS: Actually decode JALX in `__compute_return_epc_for_insn'
++    - MIPS: Fix unaligned PC interpretation in `compute_return_epc'
++    - MIPS: math-emu: Prevent wrong ISA mode instruction emulation
++    - MIPS: Send SIGILL for BPOSGE32 in `__compute_return_epc_for_insn'
++    - MIPS: Rename `sigill_r6' to `sigill_r2r6' in `__compute_return_epc_for_insn'
++    - MIPS: Send SIGILL for linked branches in `__compute_return_epc_for_insn'
++    - MIPS: Fix a typo: s/preset/present/ in r2-to-r6 emulation error message
++    - Input: i8042 - fix crash at boot time
++    - NFS: only invalidate dentrys that are clearly invalid.
++    - udf: Fix deadlock between writeback and udf_setsize()
++    - target: Fix COMPARE_AND_WRITE caw_sem leak during se_cmd quiesce
++    - perf annotate: Fix broken arrow at row 0 connecting jmp instruction to its
++      target
++    - Revert "perf/core: Drop kernel samples even though :u is specified"
++    - staging: rtl8188eu: add TL-WN722N v2 support
++    - ceph: fix race in concurrent readdir
++    - RDMA/core: Initialize port_num in qp_attr
++    - drm/mst: Fix error handling during MST sideband message reception
++    - drm/mst: Avoid dereferencing a NULL mstb in drm_dp_mst_handle_up_req()
++    - drm/mst: Avoid processing partially received up/down message transactions
++    - of: device: Export of_device_{get_modalias, uvent_modalias} to modules
++    - spmi: Include OF based modalias in device uevent
++    - tracing: Fix kmemleak in instance_rmdir
++    - alarmtimer: don't rate limit one-shot timers
++    - Linux 4.4.79
++
++  * Xenial update to 4.4.78 stable release (LP: #1705707)
++    - net_sched: fix error recovery at qdisc creation
++    - net: sched: Fix one possible panic when no destroy callback
++    - net/phy: micrel: configure intterupts after autoneg workaround
++    - ipv6: avoid unregistering inet6_dev for loopback
++    - net: dp83640: Avoid NULL pointer dereference.
++    - tcp: reset sk_rx_dst in tcp_disconnect()
++    - net: prevent sign extension in dev_get_stats()
++    - bpf: prevent leaking pointer via xadd on unpriviledged
++    - net: handle NAPI_GRO_FREE_STOLEN_HEAD case also in napi_frags_finish()
++    - ipv6: dad: don't remove dynamic addresses if link is down
++    - net: ipv6: Compare lwstate in detecting duplicate nexthops
++    - vrf: fix bug_on triggered by rx when destroying a vrf
++    - rds: tcp: use sock_create_lite() to create the accept socket
++    - brcmfmac: fix possible buffer overflow in brcmf_cfg80211_mgmt_tx()
++    - cfg80211: Define nla_policy for NL80211_ATTR_LOCAL_MESH_POWER_MODE
++    - cfg80211: Validate frequencies nested in NL80211_ATTR_SCAN_FREQUENCIES
++    - cfg80211: Check if PMKID attribute is of expected size
++    - irqchip/gic-v3: Fix out-of-bound access in gic_set_affinity
++    - parisc: Report SIGSEGV instead of SIGBUS when running out of stack
++    - parisc: use compat_sys_keyctl()
++    - parisc: DMA API: return error instead of BUG_ON for dma ops on non dma devs
++    - parisc/mm: Ensure IRQs are off in switch_mm()
++    - tools/lib/lockdep: Reduce MAX_LOCK_DEPTH to avoid overflowing lock_chain/:
++      Depth
++    - kernel/extable.c: mark core_kernel_text notrace
++    - mm/list_lru.c: fix list_lru_count_node() to be race free
++    - fs/dcache.c: fix spin lockup issue on nlru->lock
++    - checkpatch: silence perl 5.26.0 unescaped left brace warnings
++    - binfmt_elf: use ELF_ET_DYN_BASE only for PIE
++    - arm: move ELF_ET_DYN_BASE to 4MB
++    - arm64: move ELF_ET_DYN_BASE to 4GB / 4MB
++    - powerpc: move ELF_ET_DYN_BASE to 4GB / 4MB
++    - s390: reduce ELF_ET_DYN_BASE
++    - exec: Limit arg stack to at most 75% of _STK_LIM
++    - vt: fix unchecked __put_user() in tioclinux ioctls
++    - mnt: In umount propagation reparent in a separate pass
++    - mnt: In propgate_umount handle visiting mounts in any order
++    - mnt: Make propagate_umount less slow for overlapping mount propagation trees
++    - selftests/capabilities: Fix the test_execve test
++    - tpm: Get rid of chip->pdev
++    - tpm: Provide strong locking for device removal
++    - Add "shutdown" to "struct class".
++    - tpm: Issue a TPM2_Shutdown for TPM2 devices.
++    - mm: fix overflow check in expand_upwards()
++    - crypto: talitos - Extend max key length for SHA384/512-HMAC and AEAD
++    - crypto: atmel - only treat EBUSY as transient if backlog
++    - crypto: sha1-ssse3 - Disable avx2
++    - crypto: caam - fix signals handling
++    - sched/topology: Fix overlapping sched_group_mask
++    - sched/topology: Optimize build_group_mask()
++    - PM / wakeirq: Convert to SRCU
++    - PM / QoS: return -EINVAL for bogus strings
++    - tracing: Use SOFTIRQ_OFFSET for softirq dectection for more accurate results
++    - KVM: x86: disable MPX if host did not enable MPX XSAVE features
++    - kvm: vmx: Do not disable intercepts for BNDCFGS
++    - kvm: x86: Guest BNDCFGS requires guest MPX support
++    - kvm: vmx: Check value written to IA32_BNDCFGS
++    - kvm: vmx: allow host to access guest MSR_IA32_BNDCFGS
++    - Linux 4.4.78
++
++  * Xenial update to 4.4.77 stable release (LP: #1705238)
++    - fs: add a VALID_OPEN_FLAGS
++    - fs: completely ignore unknown open flags
++    - driver core: platform: fix race condition with driver_override
++    - bgmac: reset & enable Ethernet core before using it
++    - mm: fix classzone_idx underflow in shrink_zones()
++    - tracing/kprobes: Allow to create probe with a module name starting with a
++      digit
++    - usb: dwc3: replace %p with %pK
++    - USB: serial: cp210x: add ID for CEL EM3588 USB ZigBee stick
++    - Add USB quirk for HVR-950q to avoid intermittent device resets
++    - usb: usbip: set buffer pointers to NULL after free
++    - usb: Fix typo in the definition of Endpoint[out]Request
++    - mac80211_hwsim: Replace bogus hrtimer clockid
++    - sysctl: don't print negative flag for proc_douintvec
++    - sysctl: report EINVAL if value is larger than UINT_MAX for proc_douintvec
++    - pinctrl: sh-pfc: r8a7791: Fix SCIF2 pinmux data
++    - pinctrl: meson: meson8b: fix the NAND DQS pins
++    - pinctrl: sunxi: Fix SPDIF function name for A83T
++    - pinctrl: mxs: atomically switch mux and drive strength config
++    - pinctrl: sh-pfc: Update info pointer after SoC-specific init
++    - USB: serial: option: add two Longcheer device ids
++    - USB: serial: qcserial: new Sierra Wireless EM7305 device ID
++    - gfs2: Fix glock rhashtable rcu bug
++    - x86/tools: Fix gcc-7 warning in relocs.c
++    - x86/uaccess: Optimize copy_user_enhanced_fast_string() for short strings
++    - ath10k: override CE5 config for QCA9377
++    - KEYS: Fix an error code in request_master_key()
++    - RDMA/uverbs: Check port number supplied by user verbs cmds
++    - mqueue: fix a use-after-free in sys_mq_notify()
++    - tools include: Add a __fallthrough statement
++    - tools string: Use __fallthrough in perf_atoll()
++    - tools strfilter: Use __fallthrough
++    - perf top: Use __fallthrough
++    - perf intel-pt: Use __fallthrough
++    - perf thread_map: Correctly size buffer used with dirent->dt_name
++    - perf scripting perl: Fix compile error with some perl5 versions
++    - perf tests: Avoid possible truncation with dirent->d_name + snprintf
++    - perf bench numa: Avoid possible truncation when using snprintf()
++    - perf tools: Use readdir() instead of deprecated readdir_r()
++    - perf thread_map: Use readdir() instead of deprecated readdir_r()
++    - perf script: Use readdir() instead of deprecated readdir_r()
++    - perf tools: Remove duplicate const qualifier
++    - perf annotate browser: Fix behaviour of Shift-Tab with nothing focussed
++    - perf pmu: Fix misleadingly indented assignment (whitespace)
++    - perf dwarf: Guard !x86_64 definitions under #ifdef else clause
++    - perf trace: Do not process PERF_RECORD_LOST twice
++    - perf tests: Remove wrong semicolon in while loop in CQM test
++    - perf tools: Use readdir() instead of deprecated readdir_r() again
++    - md: fix incorrect use of lexx_to_cpu in does_sb_need_changing
++    - md: fix super_offset endianness in super_1_rdev_size_change
++    - tcp: fix tcp_mark_head_lost to check skb len before fragmenting
++    - staging: vt6556: vnt_start Fix missing call to vnt_key_init_table.
++    - staging: comedi: fix clean-up of comedi_class in comedi_init()
++    - ext4: check return value of kstrtoull correctly in reserved_clusters_store
++    - x86/mm/pat: Don't report PAT on CPUs that don't support it
++    - saa7134: fix warm Medion 7134 EEPROM read
++    - Linux 4.4.77
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Fri, 11 Aug 2017 16:51:50 +0200
++
++linux (4.4.0-92.115) xenial; urgency=low
++
++  * linux: 4.4.0-92.115 -proposed tracker (LP: #1709812)
++
++  * Creating conntrack entry failure with kernel 4.4.0-89 (LP: #1709032)
++    - Revert "netfilter: synproxy: fix conntrackd interaction"
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Thu, 10 Aug 2017 10:29:51 +0200
++
++linux (4.4.0-91.114) xenial; urgency=low
++
++  * CVE-2017-1000112
++    - ipv4: Should use consistent conditional judgement for ip fragment in
++      __ip_append_data and ip_finish_output
++    - ipv6: Don't use ufo handling on later transformed packets
++    - udp: avoid ufo handling on IP payload compression packets
++    - ipv6: Should use consistent conditional judgement for ip6 fragment between
++      __ip6_append_data and ip6_finish_output
++    - net: account for current skb length when deciding about UFO
++    - udp: consistently apply ufo or fragmentation
++
++  * CVE-2017-1000111
++    - net-packet: fix race in packet_set_ring on PACKET_RESERVE
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Mon, 07 Aug 2017 13:14:36 +0200
++
++linux (4.4.0-89.112) xenial; urgency=low
++
++  * CVE-2017-7533
++    - dentry name snapshots
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Mon, 31 Jul 2017 14:50:32 -0300
++
++linux (4.4.0-88.111) xenial; urgency=low
++
++  * linux: 4.4.0-88.111 -proposed tracker (LP: #1705270)
++
++  * [Xenial] nvme: Quirks for PM1725 controllers (LP: #1704435)
++    - nvme: Quirks for PM1725 controllers
++
++  * Upgrade Redpine WLAN/BT driver to ver. 1.2 (production release)
++    (LP: #1697829)
++    - SAUCE: Redpine: Upgrade to ver. 1.2 production release
++
++  * ubuntu/rsi driver has several issues as picked up by static analysis
++    (LP: #1694733)
++    - SAUCE: Redpine: Upgrade to ver. 1.2 production release
++
++  * Redpine vendor driver - Switching to AP mode causes kernel panic
++    (LP: #1700941)
++    - SAUCE: Redpine: Upgrade to ver. 1.2 production release
++
++  * CVE-2017-10810
++    - drm/virtio: don't leak bo on drm_gem_object_init failure
++
++  * Ath10k to read different board data file if specify in SMBIOS (LP: #1666742)
++    - ath10k: search SMBIOS for OEM board file extension
++
++  * make snap-pkg support (LP: #1700747)
++    - SAUCE: make snap-pkg support
++
++  * ISST-LTE: Briggs:Stratton:UbuntuKVM:  ics_opal_set_affinity on host kernel
++    log using Intel X710 (i40e driver) (LP: #1703663)
++    - i40e: use valid online CPU on q_vector initialization
++
++  * Update snapcraft.yaml (LP: #1700480)
++    - snapcraft.yaml: various improvements
++
++  * Xenial update to 4.4.76 stable release (LP: #1702863)
++    - ipv6: release dst on error in ip6_dst_lookup_tail
++    - net: don't call strlen on non-terminated string in dev_set_alias()
++    - decnet: dn_rtmsg: Improve input length sanitization in
++      dnrmg_receive_user_skb
++    - net: Zero ifla_vf_info in rtnl_fill_vfinfo()
++    - af_unix: Add sockaddr length checks before accessing sa_family in bind and
++      connect handlers
++    - Fix an intermittent pr_emerg warning about lo becoming free.
++    - net: caif: Fix a sleep-in-atomic bug in cfpkt_create_pfx
++    - igmp: acquire pmc lock for ip_mc_clear_src()
++    - igmp: add a missing spin_lock_init()
++    - ipv6: fix calling in6_ifa_hold incorrectly for dad work
++    - net/mlx5: Wait for FW readiness before initializing command interface
++    - decnet: always not take dst->__refcnt when inserting dst into hash table
++    - net: 8021q: Fix one possible panic caused by BUG_ON in free_netdev
++    - sfc: provide dummy definitions of vswitch functions
++    - ipv6: Do not leak throw route references
++    - rtnetlink: add IFLA_GROUP to ifla_policy
++    - netfilter: xt_TCPMSS: add more sanity tests on tcph->doff
++    - netfilter: synproxy: fix conntrackd interaction
++    - NFSv4: fix a reference leak caused WARNING messages
++    - drm/ast: Handle configuration without P2A bridge
++    - mm, swap_cgroup: reschedule when neeed in swap_cgroup_swapoff()
++    - MIPS: Avoid accidental raw backtrace
++    - MIPS: pm-cps: Drop manual cache-line alignment of ready_count
++    - MIPS: Fix IRQ tracing & lockdep when rescheduling
++    - ALSA: hda - Fix endless loop of codec configure
++    - ALSA: hda - set input_path bitmap to zero after moving it to new place
++    - drm/vmwgfx: Free hash table allocated by cmdbuf managed res mgr
++    - usb: gadget: f_fs: Fix possibe deadlock
++    - sysctl: enable strict writes
++    - mm: numa: avoid waiting on freed migrated pages
++    - KVM: x86: fix fixing of hypercalls
++    - scsi: sd: Fix wrong DPOFUA disable in sd_read_cache_type
++    - scsi: lpfc: Set elsiocb contexts to NULL after freeing it
++    - qla2xxx: Fix erroneous invalid handle message
++    - ARM: dts: BCM5301X: Correct GIC_PPI interrupt flags
++    - net: mvneta: Fix for_each_present_cpu usage
++    - MIPS: ath79: fix regression in PCI window initialization
++    - net: korina: Fix NAPI versus resources freeing
++    - MIPS: ralink: MT7688 pinmux fixes
++    - MIPS: ralink: fix USB frequency scaling
++    - MIPS: ralink: Fix invalid assignment of SoC type
++    - MIPS: ralink: fix MT7628 pinmux typos
++    - MIPS: ralink: fix MT7628 wled_an pinmux gpio
++    - mtd: bcm47xxpart: limit scanned flash area on BCM47XX (MIPS) only
++    - bgmac: fix a missing check for build_skb
++    - mtd: bcm47xxpart: don't fail because of bit-flips
++    - bgmac: Fix reversed test of build_skb() return value.
++    - net: bgmac: Fix SOF bit checking
++    - net: bgmac: Start transmit queue in bgmac_open
++    - net: bgmac: Remove superflous netif_carrier_on()
++    - powerpc/eeh: Enable IO path on permanent error
++    - gianfar: Do not reuse pages from emergency reserve
++    - Btrfs: fix truncate down when no_holes feature is enabled
++    - virtio_console: fix a crash in config_work_handler
++    - swiotlb-xen: update dev_addr after swapping pages
++    - xen-netfront: Fix Rx stall during network stress and OOM
++    - scsi: virtio_scsi: Reject commands when virtqueue is broken
++    - platform/x86: ideapad-laptop: handle ACPI event 1
++    - amd-xgbe: Check xgbe_init() return code
++    - net: dsa: Check return value of phy_connect_direct()
++    - drm/amdgpu: check ring being ready before using
++    - vfio/spapr: fail tce_iommu_attach_group() when iommu_data is null
++    - virtio_net: fix PAGE_SIZE > 64k
++    - vxlan: do not age static remote mac entries
++    - ibmveth: Add a proper check for the availability of the checksum features
++    - kernel/panic.c: add missing \n
++    - HID: i2c-hid: Add sleep between POWER ON and RESET
++    - scsi: lpfc: avoid double free of resource identifiers
++    - spi: davinci: use dma_mapping_error()
++    - mac80211: initialize SMPS field in HT capabilities
++    - x86/mpx: Use compatible types in comparison to fix sparse error
++    - coredump: Ensure proper size of sparse core files
++    - swiotlb: ensure that page-sized mappings are page-aligned
++    - s390/ctl_reg: make __ctl_load a full memory barrier
++    - be2net: fix status check in be_cmd_pmac_add()
++    - perf probe: Fix to show correct locations for events on modules
++    - net/mlx4_core: Eliminate warning messages for SRQ_LIMIT under SRIOV
++    - sctp: check af before verify address in sctp_addr_id2transport
++    - ravb: Fix use-after-free on `ifconfig eth0 down`
++    - jump label: fix passing kbuild_cflags when checking for asm goto support
++    - xfrm: fix stack access out of bounds with CONFIG_XFRM_SUB_POLICY
++    - xfrm: NULL dereference on allocation failure
++    - xfrm: Oops on error in pfkey_msg2xfrm_state()
++    - watchdog: bcm281xx: Fix use of uninitialized spinlock.
++    - sched/loadavg: Avoid loadavg spikes caused by delayed NO_HZ accounting
++    - ARM64/ACPI: Fix BAD_MADT_GICC_ENTRY() macro implementation
++    - ARM: 8685/1: ensure memblock-limit is pmd-aligned
++    - x86/mpx: Correctly report do_mpx_bt_fault() failures to user-space
++    - x86/mm: Fix flush_tlb_page() on Xen
++    - ocfs2: o2hb: revert hb threshold to keep compatible
++    - iommu/vt-d: Don't over-free page table directories
++    - iommu: Handle default domain attach failure
++    - iommu/amd: Fix incorrect error handling in amd_iommu_bind_pasid()
++    - cpufreq: s3c2416: double free on driver init error path
++    - KVM: x86: fix emulation of RSM and IRET instructions
++    - KVM: x86/vPMU: fix undefined shift in intel_pmu_refresh()
++    - KVM: x86: zero base3 of unusable segments
++    - KVM: nVMX: Fix exception injection
++    - Linux 4.4.76
++
++  * Xenial update to 4.4.75 stable release (LP: #1702118)
++    - fs/exec.c: account for argv/envp pointers
++    - autofs: sanity check status reported with AUTOFS_DEV_IOCTL_FAIL
++    - lib/cmdline.c: fix get_options() overflow while parsing ranges
++    - KVM: PPC: Book3S HV: Preserve userspace HTM state properly
++    - CIFS: Improve readdir verbosity
++    - HID: Add quirk for Dell PIXART OEM mouse
++    - signal: Only reschedule timers on signals timers have sent
++    - powerpc/kprobes: Pause function_graph tracing during jprobes handling
++    - Input: i8042 - add Fujitsu Lifebook AH544 to notimeout list
++    - time: Fix clock->read(clock) race around clocksource changes
++    - target: Fix kref->refcount underflow in transport_cmd_finish_abort
++    - iscsi-target: Reject immediate data underflow larger than SCSI transfer
++      length
++    - drm/radeon: add a PX quirk for another K53TK variant
++    - drm/radeon: add a quirk for Toshiba Satellite L20-183
++    - drm/amdgpu/atom: fix ps allocation size for EnableDispPowerGating
++    - drm/amdgpu: adjust default display clock
++    - USB: usbip: fix nonconforming hub descriptor
++    - rxrpc: Fix several cases where a padded len isn't checked in ticket decode
++    - of: Add check to of_scan_flat_dt() before accessing initial_boot_params
++    - mtd: spi-nor: fix spansion quad enable
++    - powerpc/slb: Force a full SLB flush when we insert for a bad EA
++    - usb: gadget: f_fs: avoid out of bounds access on comp_desc
++    - net: phy: Initialize mdio clock at probe function
++    - net: phy: fix marvell phy status reading
++    - Linux 4.4.75
++
++  * Xenial update to 4.4.74 stable release (LP: #1702104)
++    - configfs: Fix race between create_link and configfs_rmdir
++    - can: gs_usb: fix memory leak in gs_cmd_reset()
++    - cpufreq: conservative: Allow down_threshold to take values from 1 to 10
++    - vb2: Fix an off by one error in 'vb2_plane_vaddr'
++    - mac80211: don't look at the PM bit of BAR frames
++    - mac80211/wpa: use constant time memory comparison for MACs
++    - mac80211: fix CSA in IBSS mode
++    - mac80211: fix IBSS presp allocation size
++    - serial: efm32: Fix parity management in 'efm32_uart_console_get_options()'
++    - x86/mm/32: Set the '__vmalloc_start_set' flag in initmem_init()
++    - mfd: omap-usb-tll: Fix inverted bit use for USB TLL mode
++    - staging: rtl8188eu: prevent an underflow in rtw_check_beacon_data()
++    - iio: proximity: as3935: recalibrate RCO after resume
++    - USB: hub: fix SS max number of ports
++    - usb: core: fix potential memory leak in error path during hcd creation
++    - pvrusb2: reduce stack usage pvr2_eeprom_analyze()
++    - USB: gadget: dummy_hcd: fix hub-descriptor removable fields
++    - usb: r8a66597-hcd: select a different endpoint on timeout
++    - usb: r8a66597-hcd: decrease timeout
++    - drivers/misc/c2port/c2port-duramar2150.c: checking for NULL instead of
++      IS_ERR()
++    - usb: xhci: ASMedia ASM1042A chipset need shorts TX quirk
++    - USB: gadgetfs, dummy-hcd, net2280: fix locking for callbacks
++    - mm/memory-failure.c: use compound_head() flags for huge pages
++    - swap: cond_resched in swap_cgroup_prepare()
++    - genirq: Release resources in __setup_irq() error path
++    - alarmtimer: Prevent overflow of relative timers
++    - usb: dwc3: exynos fix axius clock error path to do cleanup
++    - MIPS: Fix bnezc/jialc return address calculation
++    - alarmtimer: Rate limit periodic intervals
++    - Linux 4.4.74
++
++  * Side Button (Display Toggle) fails on Dell AIO systems (LP: #1702541)
++    - dell-wmi: Add a WMI event code for display on/off
++
++  * Intel i40e PF reset under load (LP: #1700834)
++    - i40e/i40evf: Limit TSO to 7 descriptors for payload instead of 8 per packet
++
++  * update ENA driver to 1.2.0k from net-next (LP: #1701575)
++    - net: ena: remove superfluous check in ena_remove()
++    - net: ena: fix rare uncompleted admin command false alarm
++    - net: ena: add missing return when ena_com_get_io_handlers() fails
++    - net: ena: fix race condition between submit and completion admin command
++    - net: ena: add missing unmap bars on device removal
++    - net: ena: fix theoretical Rx hang on low memory systems
++    - net: ena: disable admin msix while working in polling mode
++    - net: ena: bug fix in lost tx packets detection mechanism
++    - net: ena: update ena driver to version 1.1.7
++    - net: ena: change return value for unsupported features unsupported return
++      value
++    - net: ena: add hardware hints capability to the driver
++    - net: ena: change sizeof() argument to be the type pointer
++    - net: ena: add reset reason for each device FLR
++    - net: ena: add support for out of order rx buffers refill
++    - net: ena: use napi_schedule_irqoff when possible
++    - net: ena: separate skb allocation to dedicated function
++    - net: ena: use lower_32_bits()/upper_32_bits() to split dma address
++    - net: ena: update driver's rx drop statistics
++    - net: ena: update ena driver to version 1.2.0
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Thu, 20 Jul 2017 09:25:21 +0200
++
++linux (4.4.0-87.110) xenial; urgency=low
++
++  * linux: 4.4.0-87.110 -proposed tracker (LP: #1704982)
++
++  * CVE-2017-1000364
++    - mm/mmap.c: do not blow on PROT_NONE MAP_FIXED holes in the stack
++    - mm/mmap.c: expand_downwards: don't require the gap if !vm_prev
++
++  * CIFS causes oops (LP: #1704857)
++    - CIFS: Fix null pointer deref during read resp processing
++    - CIFS: Fix some return values in case of error in 'crypt_message'
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Tue, 18 Jul 2017 13:58:43 +0200
++
++linux (4.4.0-86.109) xenial; urgency=low
++
++  * linux: 4.4.0-86.109 -proposed tracker (LP: #1703995)
++
++  * sock_recvmsg has dropped size argument (LP: #1701697)
++    - Packaging: Breaks unfixed iscsitarget versions
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 12 Jul 2017 18:23:18 -0300
++
++linux (4.4.0-85.108) xenial; urgency=low
++
++  * linux: 4.4.0-85.108 -proposed tracker (LP: #1702103)
++
++  * [Hyper-V] Implement Hyper-V PTP Source (LP: #1676635)
++    - SAUCE: hv: make clocksource available for PTP device supporting
++    - Drivers: hv: util: Use hv_get_current_tick() to get current tick
++    - hv_util: switch to using timespec64
++    - hv_utils: implement Hyper-V PTP source
++    - Drivers: hv: util: Fix a typo
++    - Drivers: hv: util: don't forget to init host_ts.lock
++    - hv_utils: drop .getcrosststamp() support from PTP driver
++    - hv_utils: fix TimeSync work on pre-TimeSync-v4 hosts
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Mon, 03 Jul 2017 10:50:09 -0300
++
++linux (4.4.0-84.107) xenial; urgency=low
++
++  * linux: 4.4.0-84.107 -proposed tracker (LP: #1701024)
++
++  * Can't disable USB port from BIOS (LP: #1695216)
++    - SAUCE: xhci: AMD Promontory USB disable port support
++
++  * KILLER1435-S[0489:e0a2] BT cannot search BT 4.0 device (LP: #1699651)
++    - Bluetooth: btusb: Add support for 0489:e0a2 QCA_ROME device
++
++  * CIFS: Enable encryption for SMB3 (LP: #1670508)
++    - Revert "Handle mismatched open calls"
++    - Revert "Call echo service immediately after socket reconnect"
++    - cifs: Make echo interval tunable
++    - Prepare for encryption support (first part). Add decryption and encryption
++      key generation. Thanks to Metze for helping with this.
++    - [net] drop 'size' argument of sock_recvmsg()
++    - cifs: merge the hash calculation helpers
++    - cifs: no need to wank with copying and advancing iovec on recvmsg side
++      either
++    - cifs: don't bother with kmap on read_pages side
++    - cifs_readv_receive: use cifs_read_from_socket()
++    - Fix memory leaks in cifs_do_mount()
++    - SMB3: Add mount parameter to allow user to override max credits
++    - SMB2: Separate Kerberos authentication from SMB2_sess_setup
++    - SMB2: Separate RawNTLMSSP authentication from SMB2_sess_setup
++    - SMB3: parsing for new snapshot timestamp mount parm
++    - cifs: Simplify SMB2 and SMB311 dependencies
++    - cifs: Only select the required crypto modules
++    - cifs: Add soft dependencies
++    - CIFS: Separate SMB2 header structure
++    - CIFS: Make SendReceive2() takes resp iov
++    - CIFS: Make send_cancel take rqst as argument
++    - CIFS: Send RFC1001 length in a separate iov
++    - CIFS: Separate SMB2 sync header processing
++    - CIFS: Separate RFC1001 length processing for SMB2 read
++    - CIFS: Add capability to transform requests before sending
++    - CIFS: Enable encryption during session setup phase
++    - CIFS: Encrypt SMB3 requests before sending
++    - CIFS: Add transform header handling callbacks
++    - CIFS: Add mid handle callback
++    - CIFS: Add copy into pages callback for a read operation
++    - CIFS: Decrypt and process small encrypted packets
++    - CIFS: Add capability to decrypt big read responses
++    - CIFS: Allow to switch on encryption with seal mount option
++    - CIFS: Fix possible use after free in demultiplex thread
++    - Call echo service immediately after socket reconnect
++    - Handle mismatched open calls
++
++  * CVE-2017-9150
++    - bpf: don't let ldimm64 leak map addresses on unprivileged
++
++  * CVE-2015-8944
++    - Make file credentials available to the seqfile interfaces
++    - /proc/iomem: only expose physical resource addresses to privileged users
++
++  * Xenial update to 4.4.73 stable release (LP: #1698817)
++    - s390/vmem: fix identity mapping
++    - partitions/msdos: FreeBSD UFS2 file systems are not recognized
++    - ARM: dts: imx6dl: Fix the VDD_ARM_CAP voltage for 396MHz operation
++    - staging: rtl8192e: rtl92e_fill_tx_desc fix write to mapped out memory.
++    - net: xilinx_emaclite: fix freezes due to unordered I/O
++    - net: xilinx_emaclite: fix receive buffer overflow
++    - ipv6: Handle IPv4-mapped src to in6addr_any dst.
++    - ipv6: Inhibit IPv4-mapped src address on the wire.
++    - NET: Fix /proc/net/arp for AX.25
++    - NET: mkiss: Fix panic
++    - net: hns: Fix the device being used for dma mapping during TX
++    - sierra_net: Skip validating irrelevant fields for IDLE LSIs
++    - sierra_net: Add support for IPv6 and Dual-Stack Link Sense Indications
++    - i2c: piix4: Fix request_region size
++    - ipv6: Fix IPv6 packet loss in scenarios involving roaming + snooping
++      switches
++    - PM / runtime: Avoid false-positive warnings from might_sleep_if()
++    - jump label: pass kbuild_cflags when checking for asm goto support
++    - kasan: respect /proc/sys/kernel/traceoff_on_warning
++    - log2: make order_base_2() behave correctly on const input value zero
++    - ethtool: do not vzalloc(0) on registers dump
++    - fscache: Fix dead object requeue
++    - fscache: Clear outstanding writes when disabling a cookie
++    - FS-Cache: Initialise stores_lock in netfs cookie
++    - ipv6: fix flow labels when the traffic class is non-0
++    - drm/nouveau: prevent userspace from deleting client object
++    - drm/nouveau/fence/g84-: protect against concurrent access to semaphore
++      buffers
++    - gianfar: synchronize DMA API usage by free_skb_rx_queue w/ gfar_new_page
++    - pinctrl: berlin-bg4ct: fix the value for "sd1a" of pin SCRD0_CRD_PRES
++    - net: adaptec: starfire: add checks for dma mapping errors
++    - parisc, parport_gsc: Fixes for printk continuation lines
++    - drm/nouveau: Don't enabling polling twice on runtime resume
++    - drm/ast: Fixed system hanged if disable P2A
++    - ravb: unmap descriptors when freeing rings
++    - nfs: Fix "Don't increment lock sequence ID after NFS4ERR_MOVED"
++    - r8152: re-schedule napi for tx
++    - r8152: fix rtl8152_post_reset function
++    - r8152: avoid start_xmit to schedule napi when napi is disabled
++    - sctp: sctp_addr_id2transport should verify the addr before looking up assoc
++    - romfs: use different way to generate fsid for BLOCK or MTD
++    - proc: add a schedule point in proc_pid_readdir()
++    - tipc: ignore requests when the connection state is not CONNECTED
++    - xtensa: don't use linux IRQ #0
++    - s390/kvm: do not rely on the ILC on kvm host protection fauls
++    - sparc64: make string buffers large enough
++    - Linux 4.4.73
++
++  * Xenial update to 4.4.72 stable release (LP: #1698799)
++    - bnx2x: Fix Multi-Cos
++    - ipv6: xfrm: Handle errors reported by xfrm6_find_1stfragopt()
++    - cxgb4: avoid enabling napi twice to the same queue
++    - tcp: disallow cwnd undo when switching congestion control
++    - vxlan: fix use-after-free on deletion
++    - ipv6: Fix leak in ipv6_gso_segment().
++    - net: ping: do not abuse udp_poll()
++    - net: ethoc: enable NAPI before poll may be scheduled
++    - net: bridge: start hello timer only if device is up
++    - sparc64: mm: fix copy_tsb to correctly copy huge page TSBs
++    - sparc: Machine description indices can vary
++    - sparc64: reset mm cpumask after wrap
++    - sparc64: combine activate_mm and switch_mm
++    - sparc64: redefine first version
++    - sparc64: add per-cpu mm of secondary contexts
++    - sparc64: new context wrap
++    - sparc64: delete old wrap code
++    - arch/sparc: support NR_CPUS = 4096
++    - serial: ifx6x60: fix use-after-free on module unload
++    - ptrace: Properly initialize ptracer_cred on fork
++    - KEYS: fix dereferencing NULL payload with nonzero length
++    - KEYS: fix freeing uninitialized memory in key_update()
++    - crypto: gcm - wait for crypto op not signal safe
++    - drm/amdgpu/ci: disable mclk switching for high refresh rates (v2)
++    - nfsd4: fix null dereference on replay
++    - nfsd: Fix up the "supattr_exclcreat" attributes
++    - kvm: async_pf: fix rcu_irq_enter() with irqs enabled
++    - KVM: cpuid: Fix read/write out-of-bounds vulnerability in cpuid emulation
++    - arm: KVM: Allow unaligned accesses at HYP
++    - KVM: async_pf: avoid async pf injection when in guest mode
++    - dmaengine: usb-dmac: Fix DMAOR AE bit definition
++    - dmaengine: ep93xx: Always start from BASE0
++    - xen/privcmd: Support correctly 64KB page granularity when mapping memory
++    - xen-netfront: do not cast grant table reference to signed short
++    - xen-netfront: cast grant table reference first to type int
++    - ext4: fix SEEK_HOLE
++    - ext4: keep existing extra fields when inode expands
++    - ext4: fix fdatasync(2) after extent manipulation operations
++    - usb: gadget: f_mass_storage: Serialize wake and sleep execution
++    - usb: chipidea: udc: fix NULL pointer dereference if udc_start failed
++    - usb: chipidea: debug: check before accessing ci_role
++    - staging/lustre/lov: remove set_fs() call from lov_getstripe()
++    - iio: light: ltr501 Fix interchanged als/ps register field
++    - iio: proximity: as3935: fix AS3935_INT mask
++    - drivers: char: random: add get_random_long()
++    - random: properly align get_random_int_hash
++    - stackprotector: Increase the per-task stack canary's random range from 32
++      bits to 64 bits on 64-bit platforms
++    - cpufreq: cpufreq_register_driver() should return -ENODEV if init fails
++    - target: Re-add check to reject control WRITEs with overflow data
++    - drm/msm: Expose our reservation object when exporting a dmabuf.
++    - Input: elantech - add Fujitsu Lifebook E546/E557 to force crc_enabled
++    - cpuset: consider dying css as offline
++    - fs: add i_blocksize()
++    - ufs: restore proper tail allocation
++    - fix ufs_isblockset()
++    - ufs: restore maintaining ->i_blocks
++    - ufs: set correct ->s_maxsize
++    - ufs_extend_tail(): fix the braino in calling conventions of
++      ufs_new_fragments()
++    - ufs_getfrag_block(): we only grab ->truncate_mutex on block creation path
++    - cxl: Fix error path on bad ioctl
++    - btrfs: use correct types for page indices in btrfs_page_exists_in_range
++    - btrfs: fix memory leak in update_space_info failure path
++    - KVM: arm/arm64: Handle possible NULL stage2 pud when ageing pages
++    - scsi: qla2xxx: don't disable a not previously enabled PCI device
++    - powerpc/eeh: Avoid use after free in eeh_handle_special_event()
++    - powerpc/numa: Fix percpu allocations to be NUMA aware
++    - powerpc/hotplug-mem: Fix missing endian conversion of aa_index
++    - perf/core: Drop kernel samples even though :u is specified
++    - drm/vmwgfx: Handle vmalloc() failure in vmw_local_fifo_reserve()
++    - drm/vmwgfx: Make sure backup_handle is always valid
++    - drm/nouveau/tmr: fully separate alarm execution/pending lists
++    - ALSA: timer: Fix race between read and ioctl
++    - ALSA: timer: Fix missing queue indices reset at SNDRV_TIMER_IOCTL_SELECT
++    - ASoC: Fix use-after-free at card unregistration
++    - drivers: char: mem: Fix wraparound check to allow mappings up to the end
++    - tty: Drop krefs for interrupted tty lock
++    - serial: sh-sci: Fix panic when serial console and DMA are enabled
++    - mm: consider memblock reservations for deferred memory initialization sizing
++    - NFS: Ensure we revalidate attributes before using execute_ok()
++    - NFSv4: Don't perform cached access checks before we've OPENed the file
++    - Make __xfs_xattr_put_listen preperly report errors.
++    - arm64: hw_breakpoint: fix watchpoint matching for tagged pointers
++    - arm64: entry: improve data abort handling of tagged pointers
++    - RDMA/qib,hfi1: Fix MR reference count leak on write with immediate
++    - usercopy: Adjust tests to deal with SMAP/PAN
++    - arm64: armv8_deprecated: ensure extension of addr
++    - arm64: ensure extension of smp_store_release value
++    - Linux 4.4.72
++
++  * Xenial update to 4.4.71 stable release (LP: #1697001)
++    - sparc: Fix -Wstringop-overflow warning
++    - s390/qeth: handle sysfs error during initialization
++    - s390/qeth: unbreak OSM and OSN support
++    - s390/qeth: avoid null pointer dereference on OSN
++    - tcp: avoid fragmenting peculiar skbs in SACK
++    - sctp: fix src address selection if using secondary addresses for ipv6
++    - tcp: eliminate negative reordering in tcp_clean_rtx_queue
++    - net: Improve handling of failures on link and route dumps
++    - bridge: netlink: check vlan_default_pvid range
++    - qmi_wwan: add another Lenovo EM74xx device ID
++    - bridge: start hello_timer when enabling KERNEL_STP in br_stp_start
++    - be2net: Fix offload features for Q-in-Q packets
++    - virtio-net: enable TSO/checksum offloads for Q-in-Q vlans
++    - tcp: avoid fastopen API to be used on AF_UNSPEC
++    - sctp: fix ICMP processing if skb is non-linear
++    - ipv4: add reference counting to metrics
++    - netem: fix skb_orphan_partial()
++    - net: phy: marvell: Limit errata to 88m1101
++    - vlan: Fix tcp checksum offloads in Q-in-Q vlans
++    - i2c: i2c-tiny-usb: fix buffer not being DMA capable
++    - mmc: sdhci-iproc: suppress spurious interrupt with Multiblock read
++    - HID: wacom: Have wacom_tpc_irq guard against possible NULL dereference
++    - scsi: mpt3sas: Force request partial completion alignment
++    - drm/radeon/ci: disable mclk switching for high refresh rates (v2)
++    - drm/radeon: Unbreak HPD handling for r600+
++    - pcmcia: remove left-over %Z format
++    - ALSA: hda - apply STAC_9200_DELL_M22 quirk for Dell Latitude D430
++    - slub/memcg: cure the brainless abuse of sysfs attributes
++    - drm/gma500/psb: Actually use VBT mode when it is found
++    - mm/migrate: fix refcount handling when !hugepage_migration_supported()
++    - mlock: fix mlock count can not decrease in race condition
++    - xfs: Fix missed holes in SEEK_HOLE implementation
++    - xfs: fix off-by-one on max nr_pages in xfs_find_get_desired_pgoff()
++    - xfs: fix over-copying of getbmap parameters from userspace
++    - xfs: handle array index overrun in xfs_dir2_leaf_readbuf()
++    - xfs: prevent multi-fsb dir readahead from reading random blocks
++    - xfs: fix up quotacheck buffer list error handling
++    - xfs: support ability to wait on new inodes
++    - xfs: update ag iterator to support wait on new inodes
++    - xfs: wait on new inodes during quotaoff dquot release
++    - xfs: fix indlen accounting error on partial delalloc conversion
++    - xfs: bad assertion for delalloc an extent that start at i_size
++    - xfs: fix unaligned access in xfs_btree_visit_blocks
++    - xfs: in _attrlist_by_handle, copy the cursor back to userspace
++    - xfs: only return -errno or success from attr ->put_listent
++    - Linux 4.4.71
++
++  * CVE-2017-7346
++    - drm/vmwgfx: limit the number of mip levels in vmw_gb_surface_define_ioctl()
++
++  * Power button does not work on Latitude 7480 (LP: #1697116)
++    - intel-hid: Remove duplicated acpi_remove_notify_handler
++    - platform/x86: intel-hid: Support 5 button array
++
++  * CVE-2017-9074
++    - ipv6: Check ip6_find_1stfragopt() return value properly.
++
++  * CVE-2014-9900
++    - net: Zeroing the structure ethtool_wolinfo in ethtool_get_wol()
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 28 Jun 2017 14:47:02 -0300
++
++linux (4.4.0-83.106) xenial; urgency=low
++
++  * linux: 4.4.0-83.106 -proposed tracker (LP: #1700541)
++
++  * CVE-2017-1000364
++    - Revert "UBUNTU: SAUCE: mm: Only expand stack if guard area is hit"
++    - Revert "mm: do not collapse stack gap into THP"
++    - Revert "mm: enlarge stack guard gap"
++    - mm: vma_adjust: remove superfluous confusing update in remove_next == 1 case
++    - mm: larger stack guard gap, between vmas
++    - mm: fix new crash in unmapped_area_topdown()
++    - Allow stack to grow up to address space limit
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Mon, 26 Jun 2017 12:27:55 -0300
++
++linux (4.4.0-82.105) xenial; urgency=low
++
++  * linux: 4.4.0-82.105 -proposed tracker (LP: #1699064)
++
++  * CVE-2017-1000364
++    - SAUCE: mm: Only expand stack if guard area is hit
++
++  * linux-aws/linux-gke incorrectly producing and using linux-*-tools-
++    common/linux-*-cloud-tools-common (LP: #1688579)
++    - [Config] make linux-tools-common and linux-cloud-tools-common protection
++      consistent
++
++  * CVE-2017-9242
++    - ipv6: fix out of bound writes in __ip6_append_data()
++
++  * CVE-2017-9075
++    - sctp: do not inherit ipv6_{mc|ac|fl}_list from parent
++
++  * CVE-2017-9074
++    - ipv6: Prevent overrun when parsing v6 header options
++
++  * CVE-2017-9076
++    - ipv6/dccp: do not inherit ipv6_mc_list from parent
++
++  * CVE-2017-9077
++    - ipv6/dccp: do not inherit ipv6_mc_list from parent
++
++  * CVE-2017-8890
++    - dccp/tcp: do not inherit mc_list from parent
++
++  * Module signing exclusion for staging drivers does not work properly
++    (LP: #1690908)
++    - SAUCE: Fix module signing exclusion in package builds
++
++  * extend-diff-ignore should use exact matches (LP: #1693504)
++    - [Packaging] exact extend-diff-ignore matches
++
++  * Dell XPS 9360 wifi 5G performance is poor (LP: #1692836)
++    - SAUCE: ath10k: fix the wifi speed issue for kill 1535
++
++  *  Upgrade Redpine WLAN/BT driver to ver. 1.2.RC12 (LP: #1694607)
++    - SAUCE: Redpine: Upgrade to ver. 1.2.RC12
++
++  * [DP MST] No audio output through HDMI/DP/mDP ports in Dell WD15 and TB15
++    docking stations (LP: #1694665)
++    - drm/i915: Store port enum in intel_encoder
++    - drm/i915: Eliminate redundant local variable definition
++    - drm/i915: Switch to using port stored in intel_encoder
++    - drm/i915: Move audio_connector to intel_encoder
++    - drm/i915/dp: DP audio API changes for MST
++    - drm/i915: abstract ddi being audio enabled
++    - drm/i915/audio: extend get_saved_enc() to support more scenarios
++    - drm/i915: enable dp mst audio
++
++  * Xenial update to 4.4.70 stable release (LP: #1694621)
++    - usb: misc: legousbtower: Fix buffers on stack
++    - usb: misc: legousbtower: Fix memory leak
++    - USB: ene_usb6250: fix DMA to the stack
++    - watchdog: pcwd_usb: fix NULL-deref at probe
++    - char: lp: fix possible integer overflow in lp_setup()
++    - USB: core: replace %p with %pK
++    - ARM: tegra: paz00: Mark panel regulator as enabled on boot
++    - tpm_crb: check for bad response size
++    - infiniband: call ipv6 route lookup via the stub interface
++    - dm btree: fix for dm_btree_find_lowest_key()
++    - dm raid: select the Kconfig option CONFIG_MD_RAID0
++    - dm bufio: avoid a possible ABBA deadlock
++    - dm bufio: check new buffer allocation watermark every 30 seconds
++    - dm cache metadata: fail operations if fail_io mode has been established
++    - dm bufio: make the parameter "retain_bytes" unsigned long
++    - dm thin metadata: call precommit before saving the roots
++    - dm space map disk: fix some book keeping in the disk space map
++    - md: update slab_cache before releasing new stripes when stripes resizing
++    - rtlwifi: rtl8821ae: setup 8812ae RFE according to device type
++    - mwifiex: pcie: fix cmd_buf use-after-free in remove/reset
++    - ima: accept previously set IMA_NEW_FILE
++    - KVM: x86: Fix load damaged SSEx MXCSR register
++    - KVM: X86: Fix read out-of-bounds vulnerability in kvm pio emulation
++    - regulator: tps65023: Fix inverted core enable logic.
++    - s390/kdump: Add final note
++    - s390/cputime: fix incorrect system time
++    - ath9k_htc: Add support of AirTies 1eda:2315 AR9271 device
++    - ath9k_htc: fix NULL-deref at probe
++    - drm/amdgpu: Avoid overflows/divide-by-zero in latency_watermark
++      calculations.
++    - drm/amdgpu: Make display watermark calculations more accurate
++    - drm/nouveau/therm: remove ineffective workarounds for alarm bugs
++    - drm/nouveau/tmr: ack interrupt before processing alarms
++    - drm/nouveau/tmr: fix corruption of the pending list when rescheduling an
++      alarm
++    - drm/nouveau/tmr: avoid processing completed alarms when adding a new one
++    - drm/nouveau/tmr: handle races with hw when updating the next alarm time
++    - cdc-acm: fix possible invalid access when processing notification
++    - proc: Fix unbalanced hard link numbers
++    - of: fix sparse warning in of_pci_range_parser_one
++    - iio: dac: ad7303: fix channel description
++    - pid_ns: Sleep in TASK_INTERRUPTIBLE in zap_pid_ns_processes
++    - pid_ns: Fix race between setns'ed fork() and zap_pid_ns_processes()
++    - USB: serial: ftdi_sio: fix setting latency for unprivileged users
++    - USB: serial: ftdi_sio: add Olimex ARM-USB-TINY(H) PIDs
++    - ext4 crypto: don't let data integrity writebacks fail with ENOMEM
++    - ext4 crypto: fix some error handling
++    - net: qmi_wwan: Add SIMCom 7230E
++    - fscrypt: fix context consistency check when key(s) unavailable
++    - f2fs: check entire encrypted bigname when finding a dentry
++    - fscrypt: avoid collisions when presenting long encrypted filenames
++    - usb: host: xhci-plat: propagate return value of platform_get_irq()
++    - xhci: apply PME_STUCK_QUIRK and MISSING_CAS quirk for Denverton
++    - usb: host: xhci-mem: allocate zeroed Scratchpad Buffer
++    - net: irda: irda-usb: fix firmware name on big-endian hosts
++    - usbvision: fix NULL-deref at probe
++    - mceusb: fix NULL-deref at probe
++    - ttusb2: limit messages to buffer size
++    - usb: musb: tusb6010_omap: Do not reset the other direction's packet size
++    - USB: iowarrior: fix info ioctl on big-endian hosts
++    - usb: serial: option: add Telit ME910 support
++    - USB: serial: qcserial: add more Lenovo EM74xx device IDs
++    - USB: serial: mct_u232: fix big-endian baud-rate handling
++    - USB: serial: io_ti: fix div-by-zero in set_termios
++    - USB: hub: fix SS hub-descriptor handling
++    - USB: hub: fix non-SS hub-descriptor handling
++    - ipx: call ipxitf_put() in ioctl error path
++    - iio: proximity: as3935: fix as3935_write
++    - ceph: fix recursion between ceph_set_acl() and __ceph_setattr()
++    - gspca: konica: add missing endpoint sanity check
++    - s5p-mfc: Fix unbalanced call to clock management
++    - dib0700: fix NULL-deref at probe
++    - zr364xx: enforce minimum size when reading header
++    - dvb-frontends/cxd2841er: define symbol_rate_min/max in T/C fe-ops
++    - cx231xx-audio: fix init error path
++    - cx231xx-audio: fix NULL-deref at probe
++    - cx231xx-cards: fix NULL-deref at probe
++    - powerpc/book3s/mce: Move add_taint() later in virtual mode
++    - powerpc/pseries: Fix of_node_put() underflow during DLPAR remove
++    - powerpc/64e: Fix hang when debugging programs with relocated kernel
++    - ARM: dts: at91: sama5d3_xplained: fix ADC vref
++    - ARM: dts: at91: sama5d3_xplained: not all ADC channels are available
++    - arm64: xchg: hazard against entire exchange variable
++    - arm64: uaccess: ensure extension of access_ok() addr
++    - arm64: documentation: document tagged pointer stack constraints
++    - xc2028: Fix use-after-free bug properly
++    - Revert "UBUNTU: SAUCE: mm: Respect FOLL_FORCE/FOLL_COW for thp"
++    - mm/huge_memory.c: respect FOLL_FORCE/FOLL_COW for thp
++    - staging: rtl8192e: fix 2 byte alignment of register BSSIDR.
++    - staging: rtl8192e: rtl92e_get_eeprom_size Fix read size of EPROM_CMD.
++    - iommu/vt-d: Flush the IOTLB to get rid of the initial kdump mappings
++    - metag/uaccess: Fix access_ok()
++    - metag/uaccess: Check access_ok in strncpy_from_user
++    - uwb: fix device quirk on big-endian hosts
++    - genirq: Fix chained interrupt data ordering
++    - osf_wait4(): fix infoleak
++    - tracing/kprobes: Enforce kprobes teardown after testing
++    - PCI: Fix pci_mmap_fits() for HAVE_PCI_RESOURCE_TO_USER platforms
++    - PCI: Freeze PME scan before suspending devices
++    - drm/edid: Add 10 bpc quirk for LGD 764 panel in HP zBook 17 G2
++    - nfsd: encoders mustn't use unitialized values in error cases
++    - drivers: char: mem: Check for address space wraparound with mmap()
++    - Linux 4.4.70
++
++  * Xenial update to 4.4.69 stable release (LP: #1692900)
++    - xen: adjust early dom0 p2m handling to xen hypervisor behavior
++    - target: Fix compare_and_write_callback handling for non GOOD status
++    - target/fileio: Fix zero-length READ and WRITE handling
++    - target: Convert ACL change queue_depth se_session reference usage
++    - iscsi-target: Set session_fall_back_to_erl0 when forcing reinstatement
++    - usb: host: xhci: print correct command ring address
++    - USB: serial: ftdi_sio: add device ID for Microsemi/Arrow SF2PLUS Dev Kit
++    - USB: Proper handling of Race Condition when two USB class drivers try to
++      call init_usb_class simultaneously
++    - staging: vt6656: use off stack for in buffer USB transfers.
++    - staging: vt6656: use off stack for out buffer USB transfers.
++    - staging: gdm724x: gdm_mux: fix use-after-free on module unload
++    - staging: comedi: jr3_pci: fix possible null pointer dereference
++    - staging: comedi: jr3_pci: cope with jiffies wraparound
++    - usb: misc: add missing continue in switch
++    - usb: Make sure usb/phy/of gets built-in
++    - usb: hub: Fix error loop seen after hub communication errors
++    - usb: hub: Do not attempt to autosuspend disconnected devices
++    - x86/boot: Fix BSS corruption/overwrite bug in early x86 kernel startup
++    - selftests/x86/ldt_gdt_32: Work around a glibc sigaction() bug
++    - x86, pmem: Fix cache flushing for iovec write < 8 bytes
++    - um: Fix PTRACE_POKEUSER on x86_64
++    - KVM: x86: fix user triggerable warning in kvm_apic_accept_events()
++    - KVM: arm/arm64: fix races in kvm_psci_vcpu_on
++    - block: fix blk_integrity_register to use template's interval_exp if not 0
++    - crypto: algif_aead - Require setkey before accept(2)
++    - dm era: save spacemap metadata root after the pre-commit
++    - vfio/type1: Remove locked page accounting workqueue
++    - IB/core: Fix sysfs registration error flow
++    - IB/IPoIB: ibX: failed to create mcg debug file
++    - IB/mlx4: Fix ib device initialization error flow
++    - IB/mlx4: Reduce SRIOV multicast cleanup warning message to debug level
++    - ext4: evict inline data when writing to memory map
++    - fs/xattr.c: zero out memory copied to userspace in getxattr
++    - ceph: fix memory leak in __ceph_setxattr()
++    - fs/block_dev: always invalidate cleancache in invalidate_bdev()
++    - Set unicode flag on cifs echo request to avoid Mac error
++    - SMB3: Work around mount failure when using SMB3 dialect to Macs
++    - CIFS: fix mapping of SFM_SPACE and SFM_PERIOD
++    - cifs: fix CIFS_IOC_GET_MNT_INFO oops
++    - CIFS: add misssing SFM mapping for doublequote
++    - padata: free correct variable
++    - arm64: KVM: Fix decoding of Rt/Rt2 when trapping AArch32 CP accesses
++    - serial: samsung: Use right device for DMA-mapping calls
++    - serial: omap: fix runtime-pm handling on unbind
++    - serial: omap: suspend device on probe errors
++    - tty: pty: Fix ldisc flush after userspace become aware of the data already
++    - Bluetooth: Fix user channel for 32bit userspace on 64bit kernel
++    - Bluetooth: hci_bcm: add missing tty-device sanity check
++    - Bluetooth: hci_intel: add missing tty-device sanity check
++    - mac80211: pass RX aggregation window size to driver
++    - mac80211: pass block ack session timeout to to driver
++    - mac80211: RX BA support for sta max_rx_aggregation_subframes
++    - wlcore: Pass win_size taken from ieee80211_sta to FW
++    - wlcore: Add RX_BA_WIN_SIZE_CHANGE_EVENT event
++    - ipmi: Fix kernel panic at ipmi_ssif_thread()
++    - Linux 4.4.69
++
++  * Support IPMI system interface on Cavium ThunderX (LP: #1688132)
++    - i2c: octeon: Cleanup kerneldoc comments
++    - i2c: octeon: Cleanup i2c-octeon driver
++    - i2c: octeon: Cleanup resource allocation code
++    - i2c: octeon: Support I2C_M_RECV_LEN
++    - i2c: octeon: Increase retry default and use fixed timeout value
++    - i2c: octeon: Move set-clock and init-lowlevel upward
++    - i2c: octeon: Rename [read|write]_sw to reg_[read|write]
++    - i2c: octeon: Introduce helper functions for register access
++    - i2c: octeon: Remove superfluous check in octeon_i2c_test_iflg
++    - i2c: octeon: Improve error status checking
++    - i2c: octeon: Use i2c recovery framework
++    - i2c: octeon: Add flush writeq helper function
++    - i2c: octeon: Enable High-Level Controller
++    - i2c: octeon: Add support for cn78xx chips
++    - i2c: octeon: Remove zero-length message support
++    - i2c: octeon: Improve performance if interrupt is early
++    - i2c: octeon: Add workaround for broken irqs on CN3860
++    - i2c: octeon: Missing AAK flag in case of I2C_M_RECV_LEN
++    - i2c: octeon: Avoid printk after too long SMBUS message
++    - i2c: octeon: Rename driver to prepare for split
++    - i2c: octeon: Split the driver into two parts
++    - [Config] CONFIG_I2C_THUNDERX=m
++    - i2c: thunderx: Add i2c driver for ThunderX SOC
++    - i2c: thunderx: Add SMBUS alert support
++    - i2c: octeon,thunderx: Move register offsets to struct
++    - i2c: octeon: Sort include files alphabetically
++    - i2c: octeon: Use booleon values for booleon variables
++    - i2c: octeon: thunderx: Add MAINTAINERS entry
++    - i2c: octeon: Fix set SCL recovery function
++    - i2c: octeon: Avoid sending STOP during recovery
++    - i2c: octeon: Fix high-level controller status check
++    - i2c: octeon: thunderx: TWSI software reset in recovery
++    - i2c: octeon: thunderx: Remove double-check after interrupt
++    - i2c: octeon: thunderx: Limit register access retries
++    - i2c: thunderx: Enable HWMON class probing
++
++  * Xenial update to 4.4.68 stable release (LP: #1691418)
++    - 9p: fix a potential acl leak
++    - ARM: 8452/3: PJ4: make coprocessor access sequences buildable in Thumb2 mode
++    - cpupower: Fix turbo frequency reporting for pre-Sandy Bridge cores
++    - powerpc/powernv: Fix opal_exit tracepoint opcode
++    - power: supply: bq24190_charger: Fix irq trigger to IRQF_TRIGGER_FALLING
++    - power: supply: bq24190_charger: Call set_mode_host() on pm_resume()
++    - power: supply: bq24190_charger: Install irq_handler_thread() at end of
++      probe()
++    - power: supply: bq24190_charger: Call power_supply_changed() for relevant
++      component
++    - power: supply: bq24190_charger: Don't read fault register outside
++      irq_handle_thread()
++    - power: supply: bq24190_charger: Handle fault before status on interrupt
++    - leds: ktd2692: avoid harmless maybe-uninitialized warning
++    - ARM: OMAP5 / DRA7: Fix HYP mode boot for thumb2 build
++    - mwifiex: debugfs: Fix (sometimes) off-by-1 SSID print
++    - mwifiex: remove redundant dma padding in AMSDU
++    - mwifiex: Avoid skipping WEP key deletion for AP
++    - x86/ioapic: Restore IO-APIC irq_chip retrigger callback
++    - x86/pci-calgary: Fix iommu_free() comparison of unsigned expression >= 0
++    - clk: Make x86/ conditional on CONFIG_COMMON_CLK
++    - kprobes/x86: Fix kernel panic when certain exception-handling addresses are
++      probed
++    - x86/platform/intel-mid: Correct MSI IRQ line for watchdog device
++    - Revert "KVM: nested VMX: disable perf cpuid reporting"
++    - KVM: nVMX: initialize PML fields in vmcs02
++    - KVM: nVMX: do not leak PML full vmexit to L1
++    - usb: host: ehci-exynos: Decrese node refcount on exynos_ehci_get_phy() error
++      paths
++    - usb: host: ohci-exynos: Decrese node refcount on exynos_ehci_get_phy() error
++      paths
++    - usb: chipidea: Only read/write OTGSC from one place
++    - usb: chipidea: Handle extcon events properly
++    - USB: serial: keyspan_pda: fix receive sanity checks
++    - USB: serial: digi_acceleport: fix incomplete rx sanity check
++    - USB: serial: ssu100: fix control-message error handling
++    - USB: serial: io_edgeport: fix epic-descriptor handling
++    - USB: serial: ti_usb_3410_5052: fix control-message error handling
++    - USB: serial: ark3116: fix open error handling
++    - USB: serial: ftdi_sio: fix latency-timer error handling
++    - USB: serial: quatech2: fix control-message error handling
++    - USB: serial: mct_u232: fix modem-status error handling
++    - USB: serial: io_edgeport: fix descriptor error handling
++    - phy: qcom-usb-hs: Add depends on EXTCON
++    - serial: 8250_omap: Fix probe and remove for PM runtime
++    - scsi: mac_scsi: Fix MAC_SCSI=m option when SCSI=m
++    - MIPS: R2-on-R6 MULTU/MADDU/MSUBU emulation bugfix
++    - brcmfmac: Ensure pointer correctly set if skb data location changes
++    - brcmfmac: Make skb header writable before use
++    - staging: wlan-ng: add missing byte order conversion
++    - staging: emxx_udc: remove incorrect __init annotations
++    - ALSA: hda - Fix deadlock of controller device lock at unbinding
++    - tcp: do not underestimate skb->truesize in tcp_trim_head()
++    - bpf, arm64: fix jit branch offset related to ldimm64
++    - tcp: fix wraparound issue in tcp_lp
++    - tcp: do not inherit fastopen_req from parent
++    - ipv4, ipv6: ensure raw socket message is big enough to hold an IP header
++    - rtnetlink: NUL-terminate IFLA_PHYS_PORT_NAME string
++    - ipv6: initialize route null entry in addrconf_init()
++    - ipv6: reorder ip6_route_dev_notifier after ipv6_dev_notf
++    - bnxt_en: allocate enough space for ->ntp_fltr_bmap
++    - f2fs: sanity check segment count
++    - drm/ttm: fix use-after-free races in vm fault handling
++    - block: get rid of blk_integrity_revalidate()
++    - Linux 4.4.68
++
++  * Keyboard backlight control does not work on some dell laptops.
++    (LP: #1693126)
++    - platform/x86: dell-laptop: Add Latitude 7480 and others to the DMI whitelist
++    - platform/x86: dell-laptop: Add keyboard backlight timeout AC settings
++
++  * Upgrade Redpine WLAN/BT driver to ver. 1.2.RC9 (LP: #1690498)
++    - SAUCE: Redpine: Upgrade to ver. 1.2.RC9
++
++  * exec'ing a setuid binary from a threaded program sometimes fails to setuid
++    (LP: #1672819)
++    - SAUCE: exec: ensure file system accounting in check_unsafe_exec is correct
++
++  * attempts to rename vlans / vlans have addr_assign_type of 0 on kernel 4.4
++    (LP: #1682871)
++    - vlan: Propagate MAC address to VLANs
++
++  * Exar usb-serial doesn't restore baud rate after resume from S3/S4
++    (LP: #1690362)
++    - SAUCE: xr-usb-serial: re-initialise baudrate after resume from S3/S4
++
++  * st_pressure, st_accel IIO drivers fail to detect sensors after reloading
++    kernel modules (LP: #1690310)
++    - SAUCE: (no-up) iio: st_pressure: st_accel: Initialise sensor platform data
++      properly
++
++  * nvidia-docker on ppc64le-ubuntu16.04  issue due to cross-thread naming if
++    !PR_DUMPABLE (LP: #1690225)
++    - procfs: fix pthread cross-thread naming if !PR_DUMPABLE
++
++  * linux xenial derivatives fail to build (LP: #1691814)
++    - [Packaging] Set do_tools_common in common vars
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Tue, 20 Jun 2017 15:47:03 +0200
++
++linux (4.4.0-81.104) xenial; urgency=low
++
++  * CVE-2017-1000364
++    - mm: enlarge stack guard gap
++    - mm: do not collapse stack gap into THP
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Thu, 08 Jun 2017 15:19:41 +0200
++
++linux (4.4.0-79.100) xenial; urgency=low
++
++  * linux: 4.4.0-79.100 -proposed tracker (LP: #1691180)
++
++  * linux-aws/linux-gke incorrectly producing and using linux-*-tools-
++    common/linux-*-cloud-tools-common (LP: #1688579)
++    - [Config] make linux-tools-common and linux-cloud-tools-common provide linux-
++      gke versions
++    - [Config] make linux-tools-common and linux-cloud-tools-common provide linux-
++      aws versions
++    - [Packaging] prevent linux-*-tools-common from being produced from non linux
++      packages
++
++  * CVE-2017-0605
++    - tracing: Use strlcpy() instead of strcpy() in __trace_find_cmdline()
++
++  * i915-bpo crashes on external hdmi input (LP: #1580272)
++    - SAUCE: i915_bpo: Silence the warning about watermark entries not changing
++
++  * Kernel panics on Xenial when using cgroups and strict CFS limits
++    (LP: #1687512)
++    - sched/fair: Initialize throttle_count for new task-groups lazily
++    - sched/fair: Do not announce throttled next buddy in dequeue_task_fair()
++
++  * bonding - mlx5 - speed changed to 0 after changing ring size  (LP: #1687877)
++    - bonding: allow notifications for bond_set_slave_link_state
++
++  * Xenial update to 4.4.67 stable release (LP: #1689296)
++    - timerfd: Protect the might cancel mechanism proper
++    - Handle mismatched open calls
++    - ASoC: intel: Fix PM and non-atomic crash in bytcr drivers
++    - ALSA: ppc/awacs: shut up maybe-uninitialized warning
++    - drbd: avoid redefinition of BITS_PER_PAGE
++    - mtd: avoid stack overflow in MTD CFI code
++    - net: tg3: avoid uninitialized variable warning
++    - netlink: Allow direct reclaim for fallback allocation
++    - IB/qib: rename BITS_PER_PAGE to RVT_BITS_PER_PAGE
++    - IB/ehca: fix maybe-uninitialized warnings
++    - ext4: require encryption feature for EXT4_IOC_SET_ENCRYPTION_POLICY
++    - ext4 crypto: revalidate dentry after adding or removing the key
++    - ext4 crypto: use dget_parent() in ext4_d_revalidate()
++    - ext4/fscrypto: avoid RCU lookup in d_revalidate
++    - nfsd4: minor NFSv2/v3 write decoding cleanup
++    - nfsd: stricter decoding of write-like NFSv2/v3 ops
++    - dm ioctl: prevent stack leak in dm ioctl call
++    - Linux 4.4.67
++
++  * Precision Rack failed to resume from S4 (LP: #1686061)
++    - x86 / hibernate: Use hlt_play_dead() when resuming from hibernation
++    - x86/boot: Split out kernel_ident_mapping_init()
++    - x86/power/64: Always create temporary identity mapping correctly
++
++  * Xenial update to 4.4.66 stable release (LP: #1688505)
++    - f2fs: do more integrity verification for superblock
++    - xc2028: unlock on error in xc2028_set_config()
++    - ARM: OMAP2+: timer: add probe for clocksources
++    - clk: sunxi: Add apb0 gates for H3
++    - crypto: testmgr - fix out of bound read in __test_aead()
++    - drm/amdgpu: fix array out of bounds
++    - ext4: check if in-inode xattr is corrupted in ext4_expand_extra_isize_ea()
++    - md:raid1: fix a dead loop when read from a WriteMostly disk
++    - MIPS: Fix crash registers on non-crashing CPUs
++    - net: cavium: liquidio: Avoid dma_unmap_single on uninitialized ndata
++    - net_sched: close another race condition in tcf_mirred_release()
++    - RDS: Fix the atomicity for congestion map update
++    - regulator: core: Clear the supply pointer if enabling fails
++    - usb: gadget: f_midi: Fixed a bug when buflen was smaller than wMaxPacketSize
++    - xen/x86: don't lose event interrupts
++    - sparc64: kern_addr_valid regression
++    - sparc64: Fix kernel panic due to erroneous #ifdef surrounding pmd_write()
++    - net: neigh: guard against NULL solicit() method
++    - net: phy: handle state correctly in phy_stop_machine
++    - l2tp: purge socket queues in the .destruct() callback
++    - l2tp: take reference on sessions being dumped
++    - l2tp: fix PPP pseudo-wire auto-loading
++    - net: ipv4: fix multipath RTM_GETROUTE behavior when iif is given
++    - sctp: listen on the sock only when it's state is listening or closed
++    - tcp: clear saved_syn in tcp_disconnect()
++    - dp83640: don't recieve time stamps twice
++    - net: ipv6: RTF_PCPU should not be settable from userspace
++    - netpoll: Check for skb->queue_mapping
++    - ip6mr: fix notification device destruction
++    - macvlan: Fix device ref leak when purging bc_queue
++    - ipv6: check skb->protocol before lookup for nexthop
++    - ipv6: check raw payload size correctly in ioctl
++    - ALSA: firewire-lib: fix inappropriate assignment between signed/unsigned
++      type
++    - ALSA: seq: Don't break snd_use_lock_sync() loop by timeout
++    - MIPS: KGDB: Use kernel context for sleeping threads
++    - MIPS: Avoid BUG warning in arch_check_elf
++    - p9_client_readdir() fix
++    - Input: i8042 - add Clevo P650RS to the i8042 reset list
++    - nfsd: check for oversized NFSv2/v3 arguments
++    - ARCv2: save r30 on kernel entry as gcc uses it for code-gen
++    - ftrace/x86: Fix triple fault with graph tracing and suspend-to-ram
++    - Linux 4.4.66
++
++  * Xenial update to 4.4.65 stable release (LP: #1688483)
++    - tipc: make sure IPv6 header fits in skb headroom
++    - tipc: make dist queue pernet
++    - tipc: re-enable compensation for socket receive buffer double counting
++    - tipc: correct error in node fsm
++    - tty: nozomi: avoid a harmless gcc warning
++    - hostap: avoid uninitialized variable use in hfa384x_get_rid
++    - gfs2: avoid uninitialized variable warning
++    - tipc: fix random link resets while adding a second bearer
++    - tipc: fix socket timer deadlock
++    - xc2028: avoid use after free
++    - netfilter: nfnetlink: correctly validate length of batch messages
++    - tipc: check minimum bearer MTU
++    - vfio/pci: Fix integer overflows, bitmask check
++    - staging/android/ion : fix a race condition in the ion driver
++    - ping: implement proper locking
++    - perf/core: Fix concurrent sys_perf_event_open() vs. 'move_group' race
++    - Linux 4.4.65
++
++  * Xenial update to 4.4.64 stable release (LP: #1687638)
++    - KEYS: Disallow keyrings beginning with '.' to be joined as session keyrings
++    - KEYS: Change the name of the dead type to ".dead" to prevent user access
++    - KEYS: fix keyctl_set_reqkey_keyring() to not leak thread keyrings
++    - tracing: Allocate the snapshot buffer before enabling probe
++    - ring-buffer: Have ring_buffer_iter_empty() return true when empty
++    - cifs: Do not send echoes before Negotiate is complete
++    - CIFS: remove bad_network_name flag
++    - s390/mm: fix CMMA vs KSM vs others
++    - VSOCK: Detach QP check should filter out non matching QPs.
++    - Input: elantech - add Fujitsu Lifebook E547 to force crc_enabled
++    - ACPI / power: Avoid maybe-uninitialized warning
++    - mmc: sdhci-esdhc-imx: increase the pad I/O drive strength for DDR50 card
++    - mac80211: reject ToDS broadcast data frames
++    - ubi/upd: Always flush after prepared for an update
++    - powerpc/kprobe: Fix oops when kprobed on 'stdu' instruction
++    - x86/mce/AMD: Give a name to MCA bank 3 when accessed with legacy MSRs
++    - kvm: arm/arm64: Fix locking for kvm_free_stage2_pgd
++    - x86, pmem: fix broken __copy_user_nocache cache-bypass assumptions
++    - block: fix del_gendisk() vs blkdev_ioctl crash
++    - tipc: fix crash during node removal
++    - Linux 4.4.64
++
++  * Xenial update to 4.4.63 stable release (LP: #1687629)
++    - cgroup, kthread: close race window where new kthreads can be migrated to
++      non-root cgroups
++    - thp: fix MADV_DONTNEED vs clear soft dirty race
++    - drm/nouveau/mpeg: mthd returns true on success now
++    - drm/nouveau/mmu/nv4a: use nv04 mmu rather than the nv44 one
++    - CIFS: store results of cifs_reopen_file to avoid infinite wait
++    - Input: xpad - add support for Razer Wildcat gamepad
++    - perf/x86: Avoid exposing wrong/stale data in intel_pmu_lbr_read_32()
++    - x86/vdso: Ensure vdso32_enabled gets set to valid values only
++    - x86/vdso: Plug race between mapping and ELF header setup
++    - acpi, nfit, libnvdimm: fix interleave set cookie calculation (64-bit
++      comparison)
++    - iscsi-target: Fix TMR reference leak during session shutdown
++    - iscsi-target: Drop work-around for legacy GlobalSAN initiator
++    - scsi: sr: Sanity check returned mode data
++    - scsi: sd: Consider max_xfer_blocks if opt_xfer_blocks is unusable
++    - scsi: sd: Fix capacity calculation with 32-bit sector_t
++    - xen, fbfront: fix connecting to backend
++    - libnvdimm: fix reconfig_mutex, mmap_sem, and jbd2_handle lockdep splat
++    - irqchip/irq-imx-gpcv2: Fix spinlock initialization
++    - ftrace: Fix removing of second function probe
++    - char: Drop bogus dependency of DEVPORT on !M68K
++    - char: lack of bool string made CONFIG_DEVPORT always on
++    - Revert "MIPS: Lantiq: Fix cascaded IRQ setup"
++    - kvm: fix page struct leak in handle_vmon
++    - zram: do not use copy_page with non-page aligned address
++    - powerpc: Disable HFSCR[TM] if TM is not supported
++    - crypto: ahash - Fix EINPROGRESS notification callback
++    - ath9k: fix NULL pointer dereference
++    - dvb-usb-v2: avoid use-after-free
++    - ext4: fix inode checksum calculation problem if i_extra_size is small
++    - platform/x86: acer-wmi: setup accelerometer when machine has appropriate
++      notify event
++    - rtc: tegra: Implement clock handling
++    - mm: Tighten x86 /dev/mem with zeroing reads
++    - dvb-usb: don't use stack for firmware load
++    - dvb-usb-firmware: don't do DMA on stack
++    - virtio-console: avoid DMA from stack
++    - pegasus: Use heap buffers for all register access
++    - rtl8150: Use heap buffers for all register access
++    - catc: Combine failure cleanup code in catc_probe()
++    - catc: Use heap buffer for memory size test
++    - tty/serial: atmel: RS485 half duplex w/DMA: enable RX after TX is done
++    - net: ipv6: check route protocol when deleting routes
++    - MIPS: fix Select HAVE_IRQ_EXIT_ON_IRQ_STACK patch.
++    - Linux 4.4.63
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Wed, 17 May 2017 16:44:58 +0200
++
++linux (4.4.0-78.99) xenial; urgency=low
++
++  * linux: 4.4.0-78.99 -proposed tracker (LP: #1686645)
++
++  * Please backport fix to reference leak in cgroup blkio throttle
++    (LP: #1683976)
++    - block: fix module reference leak on put_disk() call for cgroups throttle
++
++  * UbuntuKVM guest crashed while running I/O stress test with Ubuntu kernel
++    4.4.0-47-generic (LP: #1659111)
++    - block: Unhash block device inodes on gendisk destruction
++    - block: Use pointer to backing_dev_info from request_queue
++    - block: Dynamically allocate and refcount backing_dev_info
++    - block: Make blk_get_backing_dev_info() safe without open bdev
++    - block: Get rid of blk_get_backing_dev_info()
++    - block: Move bdev_unhash_inode() after invalidate_partition()
++    - block: Unhash also block device inode for the whole device
++    - block: Revalidate i_bdev reference in bd_aquire()
++    - block: Initialize bd_bdi on inode initialization
++    - block: Move bdi_unregister() to del_gendisk()
++    - block: Allow bdi re-registration
++    - bdi: Fix use-after-free in wb_congested_put()
++    - block: Make del_gendisk() safer for disks without queues
++    - block: Fix bdi assignment to bdev inode when racing with disk delete
++    - bdi: Mark congested->bdi as internal
++    - bdi: Make wb->bdi a proper reference
++    - bdi: Unify bdi->wb_list handling for root wb_writeback
++    - bdi: Shutdown writeback on all cgwbs in cgwb_bdi_destroy()
++    - bdi: Do not wait for cgwbs release in bdi_unregister()
++    - bdi: Rename cgwb_bdi_destroy() to cgwb_bdi_unregister()
++    - block: Fix oops in locked_inode_to_wb_and_lock_list()
++    - kobject: Export kobject_get_unless_zero()
++    - block: Fix oops scsi_disk_get()
++
++  * Touchpad not working correctly after kernel upgrade (LP: #1662589)
++    - Input: ALPS - fix V8+ protocol handling (73 03 28)
++
++  * Xenial update to v4.4.62 stable release (LP: #1683728)
++    - drm/i915: Avoid tweaking evaluation thresholds on Baytrail v3
++    - drm/i915: Stop using RP_DOWN_EI on Baytrail
++    - usb: dwc3: gadget: delay unmap of bounced requests
++    - mtd: bcm47xxpart: fix parsing first block after aligned TRX
++    - MIPS: Introduce irq_stack
++    - MIPS: Stack unwinding while on IRQ stack
++    - MIPS: Only change $28 to thread_info if coming from user mode
++    - MIPS: Switch to the irq_stack in interrupts
++    - MIPS: Select HAVE_IRQ_EXIT_ON_IRQ_STACK
++    - MIPS: IRQ Stack: Fix erroneous jal to plat_irq_dispatch
++    - crypto: caam - fix RNG deinstantiation error checking
++    - Linux 4.4.62
++
++  * ifup service of network device stay active after driver stop (LP: #1672144)
++    - net: use net->count to check whether a netns is alive or not
++
++  * [Hyper-V] mkfs regression in kernel 4.4+ (LP: #1682215)
++    - block: relax check on sg gap
++
++  * [Feature] KBL: intel_powerclamp driver support (LP: #1591641)
++    - thermal/powerclamp: remove cpu whitelist
++    - thermal/powerclamp: correct cpu support check
++    - thermal/powerclamp: add back module device table
++
++  * sysfs channel reads of lps22hb pressure sensor are stale (LP: #1682103)
++    - iio: st_pressure: initialize lps22hb bootime
++
++  * Backlight control does not work and there are no entries in
++    /sys/class/backlight (LP: #1667323)
++    - Revert "ACPI / video: Add force_native quirk for HP Pavilion dv6"
++
++  * [Feature] KBL: intel_rapl driver support (LP: #1591640)
++    - powercap/intel_rapl: Add support for Kabylake
++
++  * Xenial update to v4.4.61 stable release (LP: #1682140)
++    - drm/vmwgfx: Type-check lookups of fence objects
++    - drm/vmwgfx: NULL pointer dereference in vmw_surface_define_ioctl()
++    - drm/vmwgfx: avoid calling vzalloc with a 0 size in vmw_get_cap_3d_ioctl()
++    - drm/ttm, drm/vmwgfx: Relax permission checking when opening surfaces
++    - drm/vmwgfx: Remove getparam error message
++    - drm/vmwgfx: fix integer overflow in vmw_surface_define_ioctl()
++    - sysfs: be careful of error returns from ops->show()
++    - staging: android: ashmem: lseek failed due to no FMODE_LSEEK.
++    - arm/arm64: KVM: Take mmap_sem in stage2_unmap_vm
++    - arm/arm64: KVM: Take mmap_sem in kvm_arch_prepare_memory_region
++    - iio: bmg160: reset chip when probing
++    - Reset TreeId to zero on SMB2 TREE_CONNECT
++    - ptrace: fix PTRACE_LISTEN race corrupting task->state
++    - ring-buffer: Fix return value check in test_ringbuffer()
++    - metag/usercopy: Drop unused macros
++    - metag/usercopy: Fix alignment error checking
++    - metag/usercopy: Add early abort to copy_to_user
++    - metag/usercopy: Zero rest of buffer from copy_from_user
++    - metag/usercopy: Set flags before ADDZ
++    - metag/usercopy: Fix src fixup in from user rapf loops
++    - metag/usercopy: Add missing fixups
++    - powerpc/mm: Add missing global TLB invalidate if cxl is active
++    - powerpc: Don't try to fix up misaligned load-with-reservation instructions
++    - nios2: reserve boot memory for device tree
++    - s390/decompressor: fix initrd corruption caused by bss clear
++    - s390/uaccess: get_user() should zero on failure (again)
++    - MIPS: Force o32 fp64 support on 32bit MIPS64r6 kernels
++    - MIPS: ralink: Fix typos in rt3883 pinctrl
++    - MIPS: End spinlocks with .insn
++    - MIPS: Lantiq: fix missing xbar kernel panic
++    - MIPS: Flush wrong invalid FTLB entry for huge page
++    - mm/mempolicy.c: fix error handling in set_mempolicy and mbind.
++    - Linux 4.4.61
++
++  * Xenial update to v4.4.60 stable release (LP: #1681862)
++    - libceph: force GFP_NOIO for socket allocations
++    - xen/setup: Don't relocate p2m over existing one
++    - scsi: mpt3sas: fix hang on ata passthrough commands
++    - scsi: sg: check length passed to SG_NEXT_CMD_LEN
++    - scsi: libsas: fix ata xfer length
++    - ALSA: seq: Fix race during FIFO resize
++    - ALSA: hda - fix a problem for lineout on a Dell AIO machine
++    - ASoC: atmel-classd: fix audio clock rate
++    - ACPI: Fix incompatibility with mcount-based function graph tracing
++    - ACPI: Do not create a platform_device for IOAPIC/IOxAPIC
++    - tty/serial: atmel: fix race condition (TX+DMA)
++    - tty/serial: atmel: fix TX path in atmel_console_write()
++    - USB: fix linked-list corruption in rh_call_control()
++    - KVM: x86: clear bus pointer when destroyed
++    - drm/radeon: Override fpfn for all VRAM placements in radeon_evict_flags
++    - mm, hugetlb: use pte_present() instead of pmd_present() in follow_huge_pmd()
++    - MIPS: Lantiq: Fix cascaded IRQ setup
++    - rtc: s35390a: fix reading out alarm
++    - rtc: s35390a: make sure all members in the output are set
++    - rtc: s35390a: implement reset routine as suggested by the reference
++    - rtc: s35390a: improve irq handling
++    - KVM: kvm_io_bus_unregister_dev() should never fail
++    - power: reset: at91-poweroff: timely shutdown LPDDR memories
++    - blk: improve order of bio handling in generic_make_request()
++    - blk: Ensure users for current->bio_list can see the full list.
++    - padata: avoid race in reordering
++    - Linux 4.4.60
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Thu, 27 Apr 2017 10:24:08 -0300
++
++linux (4.4.0-77.98) xenial; urgency=low
++
++  * linux: 4.4.0-77.98 -proposed tracker (LP: #1686040)
++
++  * [Hyper-V][SAUCE] pci-hyperv: Use only 16 bit integer for PCI domain
++    (LP: #1684971)
++    - SAUCE: pci-hyperv: Use only 16 bit integer for PCI domain
++
++  * Upgrade Redpine WLAN/BT driver to ver. 1.2.RC4 (LP: #1669672)
++    - SAUCE: sdhci: use PCI ID to identify Dell IoT gateways
++    - SAUCE: Redpine: Upgrade to ver. 1.2.RC4
++    - [Config] Update CONFIG_VEN_RSI_* configs
++    - SAUCE: Redpine: add copyright to kernel packages
++
++  * Fix RX fail issue on Exar USB serial driver after resume from S3/S4
++    (LP: #1685133)
++    - SAUCE: xr-usb-serial: Update driver for Exar USB serial ports
++
++  * Miscellaneous Ubuntu changes
++    - [Config] updating configs to match redpine driver changes
++
++ -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Tue, 25 Apr 2017 19:32:01 +0200
++
++linux (4.4.0-75.96) xenial; urgency=low
++
++  * linux: 4.4.0-75.96 -proposed tracker (LP: #1684441)
++
++  * [Hyper-V] hv: util: move waiting for release to hv_utils_transport itself
++    (LP: #1682561)
++    - Drivers: hv: util: move waiting for release to hv_utils_transport itself
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Wed, 19 Apr 2017 17:14:23 +0200
++
++linux (4.4.0-74.95) xenial; urgency=low
++
++  * linux: 4.4.0-74.95 -proposed tracker (LP: #1682041)
++
++  * [Hyper-V] hv: vmbus: Raise retry/wait limits in vmbus_post_msg()
++    (LP: #1681893)
++    - Drivers: hv: vmbus: Raise retry/wait limits in vmbus_post_msg()
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Wed, 12 Apr 2017 10:30:01 +0200
++
++linux (4.4.0-73.94) xenial; urgency=low
++
++  * linux: 4.4.0-73.94 -proposed tracker (LP: #1680416)
++
++  * CVE-2017-6353
++    - sctp: deny peeloff operation on asocs with threads sleeping on it
++
++  * vfat: missing iso8859-1 charset (LP: #1677230)
++    - [Config] NLS_ISO8859_1=y
++
++  * Regression: KVM modules should be on main kernel package (LP: #1678099)
++    - [Config] powerpc: Add kvm-hv and kvm-pr to the generic inclusion list
++
++  * linux-lts-xenial 4.4.0-63.84~14.04.2 ADT test failure with linux-lts-xenial
++    4.4.0-63.84~14.04.2 (LP: #1664912)
++    - SAUCE: apparmor: fix link auditing failure due to, uninitialized var
++
++  * regession tests failing after stackprofile test is run (LP: #1661030)
++    - SAUCE: fix regression with domain change in complain mode
++
++  * Permission denied and inconsistent behavior in complain mode with 'ip netns
++    list' command (LP: #1648903)
++    - SAUCE: fix regression with domain change in complain mode
++
++  * unexpected errno=13 and disconnected path when trying to open /proc/1/ns/mnt
++    from a unshared mount namespace (LP: #1656121)
++    - SAUCE: apparmor: null profiles should inherit parent control flags
++
++  * apparmor refcount leak of profile namespace when removing profiles
++    (LP: #1660849)
++    - SAUCE: apparmor: fix ns ref count link when removing profiles from policy
++
++  * tor in lxd: apparmor="DENIED" operation="change_onexec"
++    namespace="root//CONTAINERNAME_<var-lib-lxd>" profile="unconfined"
++    name="system_tor" (LP: #1648143)
++    - SAUCE: apparmor: Fix no_new_privs blocking change_onexec when using stacked
++      namespaces
++
++  * apparmor oops in bind_mnt when dev_path lookup fails (LP: #1660840)
++    - SAUCE: apparmor: fix oops in bind_mnt when dev_path lookup fails
++
++  * apparmor  auditing denied access of special apparmor .null fi\ le
++    (LP: #1660836)
++    - SAUCE: apparmor: Don't audit denied access of special apparmor .null file
++
++  * apparmor label leak when new label is unused (LP: #1660834)
++    - SAUCE: apparmor: fix label leak when new label is unused
++
++  * apparmor reference count bug in label_merge_insert() (LP: #1660833)
++    - SAUCE: apparmor: fix reference count bug in label_merge_insert()
++
++  * apparmor's raw_data file in securityfs is sometimes truncated (LP: #1638996)
++    - SAUCE: apparmor: fix replacement race in reading rawdata
++
++  * unix domain socket cross permission check failing with nested namespaces
++    (LP: #1660832)
++    - SAUCE: apparmor: fix cross ns perm of unix domain sockets
++
++  * Xenial update to v4.4.59 stable release (LP: #1678960)
++    - xfrm: policy: init locks early
++    - virtio_balloon: init 1st buffer in stats vq
++    - pinctrl: qcom: Don't clear status bit on irq_unmask
++    - c6x/ptrace: Remove useless PTRACE_SETREGSET implementation
++    - h8300/ptrace: Fix incorrect register transfer count
++    - mips/ptrace: Preserve previous registers for short regset write
++    - sparc/ptrace: Preserve previous registers for short regset write
++    - metag/ptrace: Preserve previous registers for short regset write
++    - metag/ptrace: Provide default TXSTATUS for short NT_PRSTATUS
++    - metag/ptrace: Reject partial NT_METAG_RPIPE writes
++    - fscrypt: remove broken support for detecting keyring key revocation
++    - sched/rt: Add a missing rescheduling point
++    - Linux 4.4.59
++
++  * Update ENA driver to 1.1.2 from net-next (LP: #1664312)
++    - net: ena: Remove unnecessary pci_set_drvdata()
++    - net: ena: Fix error return code in ena_device_init()
++    - net: ena: change the return type of ena_set_push_mode() to be void.
++    - net: ena: use setup_timer() and mod_timer()
++    - net/ena: remove ntuple filter support from device feature list
++    - net/ena: fix queues number calculation
++    - net/ena: fix ethtool RSS flow configuration
++    - net/ena: fix RSS default hash configuration
++    - net/ena: fix NULL dereference when removing the driver after device reset
++      failed
++    - net/ena: refactor ena_get_stats64 to be atomic context safe
++    - net/ena: fix potential access to freed memory during device reset
++    - net/ena: use READ_ONCE to access completion descriptors
++    - net/ena: reduce the severity of ena printouts
++    - net/ena: change driver's default timeouts
++    - net/ena: change condition for host attribute configuration
++    - net/ena: update driver version to 1.1.2
++
++  * Xenial update to v4.4.58 stable release (LP: #1677600)
++    - net/openvswitch: Set the ipv6 source tunnel key address attribute correctly
++    - net: bcmgenet: Do not suspend PHY if Wake-on-LAN is enabled
++    - net: properly release sk_frag.page
++    - amd-xgbe: Fix jumbo MTU processing on newer hardware
++    - net: unix: properly re-increment inflight counter of GC discarded candidates
++    - net/mlx5: Increase number of max QPs in default profile
++    - net/mlx5e: Count LRO packets correctly
++    - net: bcmgenet: remove bcmgenet_internal_phy_setup()
++    - ipv4: provide stronger user input validation in nl_fib_input()
++    - socket, bpf: fix sk_filter use after free in sk_clone_lock
++    - tcp: initialize icsk_ack.lrcvtime at session start time
++    - Input: elan_i2c - add ASUS EeeBook X205TA special touchpad fw
++    - Input: i8042 - add noloop quirk for Dell Embedded Box PC 3000
++    - Input: iforce - validate number of endpoints before using them
++    - Input: ims-pcu - validate number of endpoints before using them
++    - Input: hanwang - validate number of endpoints before using them
++    - Input: yealink - validate number of endpoints before using them
++    - Input: cm109 - validate number of endpoints before using them
++    - Input: kbtab - validate number of endpoints before using them
++    - Input: sur40 - validate number of endpoints before using them
++    - ALSA: seq: Fix racy cell insertions during snd_seq_pool_done()
++    - ALSA: ctxfi: Fix the incorrect check of dma_set_mask() call
++    - ALSA: hda - Adding a group of pin definition to fix headset problem
++    - USB: serial: option: add Quectel UC15, UC20, EC21, and EC25 modems
++    - USB: serial: qcserial: add Dell DW5811e
++    - ACM gadget: fix endianness in notifications
++    - usb: gadget: f_uvc: Fix SuperSpeed companion descriptor's wBytesPerInterval
++    - usb-core: Add LINEAR_FRAME_INTR_BINTERVAL USB quirk
++    - USB: uss720: fix NULL-deref at probe
++    - USB: lvtest: fix NULL-deref at probe
++    - USB: idmouse: fix NULL-deref at probe
++    - USB: wusbcore: fix NULL-deref at probe
++    - usb: musb: cppi41: don't check early-TX-interrupt for Isoch transfer
++    - usb: hub: Fix crash after failure to read BOS descriptor
++    - uwb: i1480-dfu: fix NULL-deref at probe
++    - uwb: hwa-rc: fix NULL-deref at probe
++    - mmc: ushc: fix NULL-deref at probe
++    - iio: adc: ti_am335x_adc: fix fifo overrun recovery
++    - iio: hid-sensor-trigger: Change get poll value function order to avoid
++      sensor properties losing after resume from S3
++    - parport: fix attempt to write duplicate procfiles
++    - ext4: mark inode dirty after converting inline directory
++    - mmc: sdhci: Do not disable interrupts while waiting for clock
++    - xen/acpi: upload PM state from init-domain to Xen
++    - iommu/vt-d: Fix NULL pointer dereference in device_to_iommu
++    - ARM: at91: pm: cpu_idle: switch DDR to power-down mode
++    - ARM: dts: at91: sama5d2: add dma properties to UART nodes
++    - cpufreq: Restore policy min/max limits on CPU online
++    - raid10: increment write counter after bio is split
++    - libceph: don't set weight to IN when OSD is destroyed
++    - xfs: don't allow di_size with high bit set
++    - xfs: fix up xfs_swap_extent_forks inline extent handling
++    - nl80211: fix dumpit error path RTNL deadlocks
++    - USB: usbtmc: add missing endpoint sanity check
++    - xfs: clear _XBF_PAGES from buffers when readahead page
++    - igb: add i211 to i210 PHY workaround
++    - vfio/spapr: Postpone allocation of userspace version of TCE table
++    - block: allow WRITE_SAME commands with the SG_IO ioctl
++    - fbcon: Fix vc attr at deinit
++    - crypto: algif_hash - avoid zero-sized array
++    - Linux 4.4.58
++
++  * PS/2 mouse does not work on Dell embedded computer (LP: #1591053)
++    - Input: i8042 - add noloop quirk for Dell Embedded Box PC 3000
++
++  * Xenial update to v4.4.57 stable release (LP: #1676424)
++    - give up on gcc ilog2() constant optimizations
++    - perf/core: Fix event inheritance on fork()
++    - cpufreq: Fix and clean up show_cpuinfo_cur_freq()
++    - powerpc/boot: Fix zImage TOC alignment
++    - md/raid1/10: fix potential deadlock
++    - target/pscsi: Fix TYPE_TAPE + TYPE_MEDIMUM_CHANGER export
++    - scsi: lpfc: Add shutdown method for kexec
++    - scsi: libiscsi: add lock around task lists to fix list corruption regression
++    - target: Fix VERIFY_16 handling in sbc_parse_cdb
++    - isdn/gigaset: fix NULL-deref at probe
++    - gfs2: Avoid alignment hole in struct lm_lockname
++    - percpu: acquire pcpu_lock when updating pcpu_nr_empty_pop_pages
++    - ext4: fix fencepost in s_first_meta_bg validation
++    - Linux 4.4.57
++
++  * Xenial update to v4.4.56 stable release (LP: #1675789)
++    - netlink: remove mmapped netlink support
++    - [Config] CONFIG_NETLINK_MMAP disappeared
++    - vxlan: correctly validate VXLAN ID against VXLAN_N_VID
++    - vti6: return GRE_KEY for vti6
++    - ipv4: mask tos for input route
++    - l2tp: avoid use-after-free caused by l2tp_ip_backlog_recv
++    - net: don't call strlen() on the user buffer in packet_bind_spkt()
++    - net: net_enable_timestamp() can be called from irq contexts
++    - dccp: Unlock sock before calling sk_free()
++    - tcp: fix various issues for sockets morphing to listen state
++    - net: fix socket refcounting in skb_complete_wifi_ack()
++    - net: fix socket refcounting in skb_complete_tx_timestamp()
++    - dccp: fix use-after-free in dccp_feat_activate_values
++    - vrf: Fix use-after-free in vrf_xmit
++    - uapi: fix linux/packet_diag.h userspace compilation error
++    - act_connmark: avoid crashing on malformed nlattrs with null parms
++    - mpls: Send route delete notifications when router module is unloaded
++    - ipv6: make ECMP route replacement less greedy
++    - ipv6: avoid write to a possibly cloned skb
++    - dccp/tcp: fix routing redirect race
++    - dccp: fix memory leak during tear-down of unsuccessful connection request
++    - net sched actions: decrement module reference count after table flush.
++    - fscrypt: fix renaming and linking special files
++    - fscrypto: lock inode while setting encryption policy
++    - x86/kasan: Fix boot with KASAN=y and PROFILE_ANNOTATED_BRANCHES=y
++    - x86/perf: Fix CR4.PCE propagation to use active_mm instead of mm
++    - futex: Fix potential use-after-free in FUTEX_REQUEUE_PI
++    - futex: Add missing error handling to FUTEX_REQUEUE_PI
++    - Linux 4.4.56
++
++  * Kernel linux-image-4.4.0-67-generic prevent the boot on Microsoft Hyper-v
++    2012r2 Gen2 VM (LP: #1674635)
++    - scsi: storvsc: Workaround for virtual DVD SCSI version
++
++  * [Hyper-V][Mellanox] net/mlx4_core: Avoid delays during VF driver device
++    shutdown (LP: #1672785)
++    - net/mlx4_core: Avoid delays during VF driver device shutdown
++
++  * Channel data values for IIO based st_sensors (st_accel, st_pressure) are
++    incorrect (LP: #1676356)
++    - iio: core: added support for IIO_VAL_INT
++    - iio: st_sensors: simplify buffer address handling
++    - iio: st_sensors: read each channel individually
++    - iio:st_sensors: emulate SMBus block read if needed
++    - iio:st_sensors: align on storagebits boundaries
++    - iio:st_pressure: temperature triggered buffering
++    - iio:st_pressure: clean useless static channel initializers
++    - iio: st_pressure: Fix data sign
++
++  * Enable lspcon on i915 (LP: #1676747)
++    - drm: Helper for lspcon in drm_dp_dual_mode
++    - drm/i915: Add lspcon support for I915 driver
++    - drm/i915: Parse VBT data for lspcon
++    - drm/i915: Enable lspcon initialization
++    - drm/i915: Add lspcon resume function
++
++  * stress_smoke_test passing and exiting rc=9 (linux 4.9.0-12.13 ADT test
++    failure with linux 4.9.0-12.13) (LP: #1658633)
++    - ext4: lock the xattr block before checksuming it
++
++  * Fix line-out port noise on Baytrail-I with RT5660 based sound card
++    (LP: #1675327)
++    - SAUCE: (no-up): ASoC: Intel: bytcr-rt5660: Fix noise in line-out
++
++  * Kernel 4.4.0-67 Defaults to ACPI-cpufreq rather than P-State - Dell
++    Precision 5520  (LP: #1674390)
++    - cpufreq: intel_pstate: Enable HWP by default
++
++  * ip_rcv_finish() NULL pointer kernel panic (LP: #1672470)
++    - bridge: drop netfilter fake rtable unconditionally
++
++  * dm-queue-length module is not included in installer/initramfs (LP: #1673350)
++    - d-i: Also add dm-queue-length to multipath modules
++
++  * Broadcom bluetooth modules sometimes fail to initialize (LP: #1483101)
++    - Bluetooth: btbcm: Add a delay for module reset
++
++  * Need support of Broadcom bluetooth device [413c:8143] (LP: #1166113)
++    - Bluetooth: btusb: Add support for 413c:8143
++
++  * i40e Intel X710 error during device probe prevents link set up and ip
++    association (LP: #1672550)
++    - i40e: check for and deal with non-contiguous TCs
++
++  * CIFS: Call echo service immediately after socket reconnect (LP: #1669941)
++    - Call echo service immediately after socket reconnect
++
++  * FC Adapter (LPe32000-based) prints "iotag out of range", goes offline, and
++    delays boot a lot (Ubuntu17.04/Emulex/lpfc)) (LP: #1670490)
++    - scsi: lpfc: Add missing memory barrier
++
++  * No C-State Deeper than C3 utilized by Kaby Lake 7820HQ in Precision 5520
++    (LP: #1672439)
++    - intel_idle: Add KBL support
++
++  * [Hyper-V] Missing PCI patches breaking SR-IOV hot remove (LP: #1670518)
++    - PCI: hv: Fix hv_pci_remove() for hot-remove
++    - PCI: hv: Delete the device earlier from hbus->children for hot-remove
++    - PCI: hv: Make unnecessarily global IRQ masking functions static
++    - PCI: hv: Allocate physically contiguous hypercall params buffer
++
++  * Xenial update to v4.4.55 stable release (LP: #1674292)
++    - USB: serial: digi_acceleport: fix OOB data sanity check
++    - USB: serial: digi_acceleport: fix OOB-event processing
++    - crypto: improve gcc optimization flags for serpent and wp512
++    - MIPS: Update defconfigs for NF_CT_PROTO_DCCP/UDPLITE change
++    - MIPS: ip27: Disable qlge driver in defconfig
++    - MIPS: Update ip27_defconfig for SCSI_DH change
++    - MIPS: ip22: Fix ip28 build for modern gcc
++    - MIPS: Update lemote2f_defconfig for CPU_FREQ_STAT change
++    - mtd: pmcmsp: use kstrndup instead of kmalloc+strncpy
++    - MIPS: ralink: Cosmetic change to prom_init().
++    - MIPS: ralink: Remove unused rt*_wdt_reset functions
++    - cpmac: remove hopeless #warning
++    - mm: memcontrol: avoid unused function warning
++    - MIPS: DEC: Avoid la pseudo-instruction in delay slots
++    - MIPS: Netlogic: Fix CP0_EBASE redefinition warnings
++    - tracing: Add #undef to fix compile error
++    - powerpc: Emulation support for load/store instructions on LE
++    - usb: gadget: dummy_hcd: clear usb_gadget region before registration
++    - usb: dwc3: gadget: make Set Endpoint Configuration macros safe
++    - usb: gadget: function: f_fs: pass companion descriptor along
++    - usb: host: xhci-dbg: HCIVERSION should be a binary number
++    - usb: host: xhci-plat: Fix timeout on removal of hot pluggable xhci
++      controllers
++    - USB: serial: safe_serial: fix information leak in completion handler
++    - USB: serial: omninet: fix reference leaks at open
++    - USB: iowarrior: fix NULL-deref at probe
++    - USB: iowarrior: fix NULL-deref in write
++    - USB: serial: io_ti: fix NULL-deref in interrupt callback
++    - USB: serial: io_ti: fix information leak in completion handler
++    - serial: samsung: Continue to work if DMA request fails
++    - mvsas: fix misleading indentation
++    - KVM: s390: Fix guest migration for huge guests resulting in panic
++    - s390/kdump: Use "LINUX" ELF note name instead of "CORE"
++    - nfit, libnvdimm: fix interleave set cookie calculation
++    - dm: flush queued bios when process blocks to avoid deadlock
++    - ext4: don't BUG when truncating encrypted inodes on the orphan list
++    - Linux 4.4.55
++
++  * Xenial update to v4.4.54 stable release (LP: #1673541)
++    - serial: 8250_pci: Add MKS Tenta SCOM-0800 and SCOM-0801 cards
++    - KVM: s390: Disable dirty log retrieval for UCONTROL guests
++    - KVM: VMX: use correct vmcs_read/write for guest segment selector/base
++    - Bluetooth: Add another AR3012 04ca:3018 device
++    - s390/qdio: clear DSCI prior to scanning multiple input queues
++    - s390/dcssblk: fix device size calculation in dcssblk_direct_access()
++    - s390: TASK_SIZE for kernel threads
++    - s390: make setup_randomness work
++    - s390: use correct input data address for setup_randomness
++    - net: mvpp2: fix DMA address calculation in mvpp2_txq_inc_put()
++    - mnt: Tuck mounts under others instead of creating shadow/side mounts.
++    - IB/ipoib: Fix deadlock between rmmod and set_mode
++    - IB/IPoIB: Add destination address when re-queue packet
++    - IB/srp: Avoid that duplicate responses trigger a kernel bug
++    - IB/srp: Fix race conditions related to task management
++    - ktest: Fix child exit code processing
++    - ceph: remove req from unsafe list when unregistering it
++    - target: Fix NULL dereference during LUN lookup + active I/O shutdown
++    - nlm: Ensure callback code also checks that the files match
++    - pwm: pca9685: Fix period change with same duty cycle
++    - xtensa: move parse_tag_fdt out of #ifdef CONFIG_BLK_DEV_INITRD
++    - mac80211: flush delayed work when entering suspend
++    - drm/amdgpu: add more cases to DCE11 possible crtc mask setup
++    - drm/ast: Fix test for VGA enabled
++    - drm/ast: Call open_key before enable_mmio in POST code
++    - drm/ast: Fix AST2400 POST failure without BMC FW or VBIOS
++    - drm/edid: Add EDID_QUIRK_FORCE_8BPC quirk for Rotel RSX-1058
++    - drm/ttm: Make sure BOs being swapped out are cacheable
++    - drm/atomic: fix an error code in mode_fixup()
++    - fakelb: fix schedule while atomic
++    - drm/i915/dsi: Do not clear DPOUNIT_CLOCK_GATE_DISABLE from
++      vlv_init_display_clock_gating
++    - libceph: use BUG() instead of BUG_ON(1)
++    - fat: fix using uninitialized fields of fat_inode/fsinfo_inode
++    - drivers: hv: Turn off write permission on the hypercall page
++    - Linux 4.4.54
++
++  * Xenial update to v4.4.53 stable release (LP: #1673538)
++    - samples: move mic/mpssd example code from Documentation
++    - MIPS: Fix special case in 64 bit IP checksumming.
++    - MIPS: BCM47XX: Fix button inversion for Asus WL-500W
++    - MIPS: OCTEON: Fix copy_from_user fault handling for large buffers
++    - MIPS: Lantiq: Keep ethernet enabled during boot
++    - MIPS: Clear ISA bit correctly in get_frame_info()
++    - MIPS: Prevent unaligned accesses during stack unwinding
++    - MIPS: Fix get_frame_info() handling of microMIPS function size
++    - MIPS: Fix is_jump_ins() handling of 16b microMIPS instructions
++    - MIPS: Calculate microMIPS ra properly when unwinding the stack
++    - MIPS: Handle microMIPS jumps in the same way as MIPS32/MIPS64 jumps
++    - am437x-vpfe: always assign bpp variable
++    - uvcvideo: Fix a wrong macro
++    - media: fix dm1105.c build error
++    - ARM: at91: define LPDDR types
++    - ARM: dts: at91: Enable DMA on sama5d4_xplained console
++    - ARM: dts: at91: Enable DMA on sama5d2_xplained console
++    - ALSA: hda/realtek - Cannot adjust speaker's volume on a Dell AIO
++    - ALSA: hda - fix Lewisburg audio issue
++    - ALSA: timer: Reject user params with too small ticks
++    - ALSA: ctxfi: Fallback DMA mask to 32bit
++    - ALSA: seq: Fix link corruption by event error handling
++    - ALSA: hda - Add subwoofer support for Dell Inspiron 17 7000 Gaming
++    - ALSA: hda - Fix micmute hotkey problem for a lenovo AIO machine
++    - staging: rtl: fix possible NULL pointer dereference
++    - regulator: Fix regulator_summary for deviceless consumers
++    - iommu/vt-d: Fix some macros that are incorrectly specified in intel-iommu
++    - iommu/vt-d: Tylersburg isoch identity map check is done too late.
++    - mm/page_alloc: fix nodes for reclaim in fast path
++    - mm: vmpressure: fix sending wrong events on underflow
++    - mm: do not access page->mapping directly on page_endio
++    - ipc/shm: Fix shmat mmap nil-page protection
++    - dm cache: fix corruption seen when using cache > 2TB
++    - dm stats: fix a leaked s->histogram_boundaries array
++    - Revert "scsi: storvsc: properly set residual data length on errors"
++    - scsi: storvsc: properly set residual data length on errors
++    - scsi: aacraid: Reorder Adapter status check
++    - scsi: use 'scsi_device_from_queue()' for scsi_dh
++    - sd: get disk reference in sd_check_events()
++    - Fix: Disable sys_membarrier when nohz_full is enabled
++    - jbd2: don't leak modified metadata buffers on an aborted journal
++    - block/loop: fix race between I/O and set_status
++    - loop: fix LO_FLAGS_PARTSCAN hang
++    - ext4: Include forgotten start block on fallocate insert range
++    - ext4: do not polute the extents cache while shifting extents
++    - ext4: trim allocation requests to group size
++    - ext4: fix data corruption in data=journal mode
++    - ext4: fix inline data error paths
++    - ext4: preserve the needs_recovery flag when the journal is aborted
++    - ext4: return EROFS if device is r/o and journal replay is needed
++    - samples/seccomp: fix 64-bit comparison macros
++    - target: Obtain se_node_acl->acl_kref during get_initiator_node_acl
++    - target: Fix multi-session dynamic se_node_acl double free OOPs
++    - ath5k: drop bogus warning on drv_set_key with unsupported cipher
++    - ath9k: fix race condition in enabling/disabling IRQs
++    - ath9k: use correct OTP register offsets for the AR9340 and AR9550
++    - crypto: testmgr - Pad aes_ccm_enc_tv_template vector
++    - fuse: add missing FR_FORCE
++    - arm/arm64: KVM: Enforce unconditional flush to PoC when mapping to stage-2
++    - iio: pressure: mpl115: do not rely on structure field ordering
++    - iio: pressure: mpl3115: do not rely on structure field ordering
++    - can: usb_8dev: Fix memory leak of priv->cmd_msg_buffer
++    - w1: don't leak refcount on slave attach failure in w1_attach_slave_device()
++    - w1: ds2490: USB transfer buffers need to be DMAable
++    - usb: musb: da8xx: Remove CPPI 3.0 quirk and methods
++    - usb: host: xhci: plat: check hcc_params after add hcd
++    - usb: gadget: udc: fsl: Add missing complete function.
++    - hv: allocate synic pages for all present CPUs
++    - hv: init percpu_list in hv_synic_alloc()
++    - Drivers: hv: util: kvp: Fix a rescind processing issue
++    - Drivers: hv: util: Fcopy: Fix a rescind processing issue
++    - Drivers: hv: util: Backup: Fix a rescind processing issue
++    - RDMA/core: Fix incorrect structure packing for booleans
++    - rdma_cm: fail iwarp accepts w/o connection params
++    - gfs2: Add missing rcu locking for glock lookup
++    - rtlwifi: Fix alignment issues
++    - rtlwifi: rtl8192c-common: Fix "BUG: KASAN:
++    - nfsd: minor nfsd_setattr cleanup
++    - nfsd: special case truncates some more
++    - NFSv4: Fix memory and state leak in _nfs4_open_and_get_state
++    - NFSv4: fix getacl head length estimation
++    - NFSv4: fix getacl ERANGE for some ACL buffer sizes
++    - rtc: sun6i: Add some locking
++    - rtc: sun6i: Switch to the external oscillator
++    - md linear: fix a race between linear_add() and linear_congested()
++    - bcma: use (get|put)_device when probing/removing device driver
++    - dmaengine: ipu: Make sure the interrupt routine checks all interrupts.
++    - powerpc/xmon: Fix data-breakpoint
++    - MIPS: IP22: Reformat inline assembler code to modern standards.
++    - MIPS: IP22: Fix build error due to binutils 2.25 uselessnes.
++    - scsi: lpfc: Correct WQ creation for pagesize
++    - Linux 4.4.53
++
++  * move aufs.ko from -extra to linux-image package (LP: #1673498)
++    - [config] aufs.ko moved to linux-image package
++
++  * [Xenial] net: better skb->sender_cpu and skb->napi_id cohabitation
++    (LP: #1673303)
++    - net: better skb->sender_cpu and skb->napi_id cohabitation
++
++  * lsattr 32bit does not work on 64bit kernel (Inappropriate ioctl error)
++    (LP: #1619918)
++    - btrfs: fix btrfs_compat_ioctl failures on non-compat ioctls
++
++  * linux-tools-common should Depends: lsb-release (LP: #1667571)
++    - [Config] linux-tools-common depends on lsb-release
++
++  * Add Use-After-Free Patch for Ubuntu16.10 - EEH on BELL3 adapter fails to
++    recover (serial/tty) (LP: #1669153)
++    - 8250_pci: Fix potential use-after-free in error path
++
++  * [Hyper-V] pci-hyperv: Use device serial number as PCI domain (LP: #1667527)
++    - net/mlx4_core: Use cq quota in SRIOV when creating completion EQs
++    - PCI: hv: Use device serial number as PCI domain
++
++  * [Xenial - 16.04 ]Bonding driver - stack corruption when trying to copy 20
++    bytes to a sockaddr (LP: #1668042)
++    - net/bonding: Enforce active-backup policy for IPoIB bonds
++
++  * Request to backport cxlflash patches to Xenial SRU stream (LP: #1623750)
++    - scsi: cxlflash: Scan host only after the port is ready for I/O
++    - scsi: cxlflash: Remove the device cleanly in the system shutdown path
++    - scsi: cxlflash: Fix to avoid EEH and host reset collisions
++    - scsi: cxlflash: Improve EEH recovery time
++
++  * Xenial update to v4.4.52 stable release (LP: #1669016)
++    - net/llc: avoid BUG_ON() in skb_orphan()
++    - packet: fix races in fanout_add()
++    - packet: Do not call fanout_release from atomic contexts
++    - irda: Fix lockdep annotations in hashbin_delete().
++    - ip: fix IP_CHECKSUM handling
++    - net: socket: fix recvmmsg not returning error from sock_error
++    - tty: serial: msm: Fix module autoload
++    - USB: serial: mos7840: fix another NULL-deref at open
++    - USB: serial: cp210x: add new IDs for GE Bx50v3 boards
++    - USB: serial: ftdi_sio: fix modem-status error handling
++    - USB: serial: ftdi_sio: fix extreme low-latency setting
++    - USB: serial: ftdi_sio: fix line-status over-reporting
++    - USB: serial: spcp8x5: fix modem-status handling
++    - USB: serial: opticon: fix CTS retrieval at open
++    - USB: serial: ark3116: fix register-accessor error handling
++    - x86/platform/goldfish: Prevent unconditional loading
++    - goldfish: Sanitize the broken interrupt handler
++    - block: fix double-free in the failure path of cgwb_bdi_init()
++    - rtlwifi: rtl_usb: Fix for URB leaking when doing ifconfig up/down
++    - Revert "usb: chipidea: imx: enable CI_HDRC_SET_NON_ZERO_TTHA"
++    - kvm: vmx: ensure VMCS is current while enabling PML
++    - Linux 4.4.52
++
++  * Xenial update to v4.4.51 stable release (LP: #1669015)
++    - vfs: fix uninitialized flags in splice_to_pipe()
++    - siano: make it work again with CONFIG_VMAP_STACK
++    - fuse: fix use after free issue in fuse_dev_do_read()
++    - scsi: don't BUG_ON() empty DMA transfers
++    - Fix missing sanity check in /dev/sg
++    - Input: elan_i2c - add ELAN0605 to the ACPI table
++    - drm/radeon: Use mode h/vdisplay fields to hide out of bounds HW cursor
++    - drm/dp/mst: fix kernel oops when turning off secondary monitor
++    - futex: Move futex_init() to core_initcall
++    - ARM: 8658/1: uaccess: fix zeroing of 64-bit get_user()
++    - printk: use rcuidle console tracepoint
++    - NTB: ntb_transport: fix debugfs_remove_recursive
++    - ntb_transport: Pick an unused queue
++    - bcache: Make gc wakeup sane, remove set_task_state()
++    - mmc: core: fix multi-bit bus width without high-speed mode
++    - Linux 4.4.51
++
++  * Xenial update to v4.4.50 stable release (LP: #1666324)
++    - can: Fix kernel panic at security_sock_rcv_skb
++    - ipv6: fix ip6_tnl_parse_tlv_enc_lim()
++    - ipv6: pointer math error in ip6_tnl_parse_tlv_enc_lim()
++    - tcp: fix 0 divide in __tcp_select_window()
++    - net: use a work queue to defer net_disable_timestamp() work
++    - ipv4: keep skb->dst around in presence of IP options
++    - netlabel: out of bound access in cipso_v4_validate()
++    - ip6_gre: fix ip6gre_err() invalid reads
++    - ipv6: tcp: add a missing tcp_v6_restore_cb()
++    - tcp: avoid infinite loop in tcp_splice_read()
++    - tun: read vnet_hdr_sz once
++    - macvtap: read vnet_hdr_size once
++    - mlx4: Invoke softirqs after napi_reschedule
++    - sctp: avoid BUG_ON on sctp_wait_for_sndbuf
++    - sit: fix a double free on error path
++    - net: introduce device min_header_len
++    - packet: round up linear to header len
++    - ping: fix a null pointer dereference
++    - l2tp: do not use udp_ioctl()
++    - Linux 4.4.50
++
++  * FlashGT Integration and Setup: fsbmc30: After 17th reboot of soft bootme,
++    HTX & Linux errors seen with 256 virtual LUNs (LP: #1667239)
++    - cxl: Fix coredump generation when cxl_get_fd() is used
++
++  * [Hyper-V] Ubuntu 14.04.2 LTS Generation 2 SCSI Errors on VSS Based Backups
++    (LP: #1470250)
++    - Drivers: hv: vss: Operation timeouts should match host expectation
++    - SAUCE: Tools: hv: vss: Thaw the filesystem and continue after freeze fails
++
++  * kernel 4.4.0-63 with USB WLAN RTL8192CU freezes desktop (LP: #1666421)
++    - rtlwifi: rtl_usb: Fix missing entry in USB driver's private data
++
++  * Export symbol "dev_pm_qos_update_user_latency_tolerance" (LP: #1666401)
++    - PM / QoS: Export dev_pm_qos_update_user_latency_tolerance
++
++  * Linux ZFS port doesn't respect RLIMIT_FSIZE (LP: #1656259)
++    - SAUCE: (noup) Update zfs to 0.6.5.6-0ubuntu16
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Thu, 06 Apr 2017 09:34:27 +0100
++
++linux (4.4.0-72.93) xenial; urgency=low
++
++  * linux: 4.4.0-72.93 -proposed tracker (LP: #1678078)
++
++  * Fix CVE-2017-7308 (LP: #1678009)
++    - net/packet: fix overflow in check for priv area size
++    - net/packet: fix overflow in check for tp_frame_nr
++    - net/packet: fix overflow in check for tp_reserve
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Fri, 31 Mar 2017 09:20:03 +0200
++
++linux (4.4.0-71.92) xenial; urgency=low
++
++  * CVE-2017-7184
++    - xfrm_user: validate XFRM_MSG_NEWAE XFRMA_REPLAY_ESN_VAL replay_window
++    - xfrm_user: validate XFRM_MSG_NEWAE incoming ESN size harder
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Fri, 24 Mar 2017 09:32:49 -0300
++
++linux (4.4.0-70.91) xenial; urgency=low
++
++  * linux: 4.4.0-70.91 -proposed tracker (LP: #1674938)
++
++  * snaps with classic + jailmode confinement started to fail on zesty
++    (LP: #1666897)
++    - Revert "UBUNTU: SAUCE: apparmor: fix link auditing failure due to,
++      uninitialized var"
++    - Revert "UBUNTU: SAUCE: fix regression with domain change in complain mode"
++    - Revert "UBUNTU: SAUCE: apparmor: flock mediation is not being enforced on
++      cache check"
++    - Revert "UBUNTU: SAUCE: apparmor: null profiles should inherit parent control
++      flags"
++    - Revert "UBUNTU: SAUCE: apparmor: fix ns ref count link when removing
++      profiles from policy"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix no_new_privs blocking change_onexec
++      when using stacked namespaces"
++    - Revert "UBUNTU: SAUCE: apparmor: fix oops in bind_mnt when dev_path lookup
++      fails"
++    - Revert "UBUNTU: SAUCE: apparmor: Don't audit denied access of special
++      apparmor .null file"
++    - Revert "UBUNTU: SAUCE: apparmor: fix label leak when new label is unused"
++    - Revert "UBUNTU: SAUCE: apparmor: fix reference count bug in
++      label_merge_insert()"
++    - Revert "UBUNTU: SAUCE: apparmor: fix replacement race in reading rawdata"
++    - Revert "UBUNTU: SAUCE: apparmor: fix cross ns perm of unix domain sockets"
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Wed, 22 Mar 2017 09:28:43 +0100
++
++linux (4.4.0-67.88) xenial; urgency=low
++
++  * linux: 4.4.0-67.88 -proposed tracker (LP: #1667052)
++
++  * Recent KVM RTC cherry-picks break (some) Windows Live-Migrations
++    (LP: #1668594)
++    - kvm: x86: correctly reset dest_map->vector when restoring LAPIC state
++
++  * Regression in 4.4.0-65-generic causes very frequent system crashes
++    (LP: #1669611)
++    - Revert "UBUNTU: SAUCE: apparmor: fix lock ordering for mkdir"
++    - Revert "UBUNTU: SAUCE: apparmor: fix leak on securityfs pin count"
++    - Revert "UBUNTU: SAUCE: apparmor: fix reference count leak when
++      securityfs_setup_d_inode() fails"
++    - Revert "UBUNTU: SAUCE: apparmor: fix not handling error case when
++      securityfs_pin_fs() fails"
++
++  * Upgrade Redpine RS9113 driver to support AP mode (LP: #1665211)
++    - SAUCE: Redpine driver to support Host AP mode
++
++  * NFS client : permission denied when trying to access subshare, since kernel
++    4.4.0-31 (LP: #1649292)
++    - fs: Better permission checking for submounts
++
++  * [Hyper-V] SAUCE: pci-hyperv fixes for SR-IOV on Azure (LP: #1665097)
++    - SAUCE: PCI: hv: Fix wslot_to_devfn() to fix warnings on device removal
++    - SAUCE: pci-hyperv: properly handle pci bus remove
++    - SAUCE: pci-hyperv: lock pci bus on device eject
++
++  * [Hyper-V/Azure] Please include Mellanox OFED drivers in Azure kernel and
++    image (LP: #1650058)
++    - net/mlx4_en: Fix bad WQE issue
++    - net/mlx4_core: Fix racy CQ (Completion Queue) free
++    - net/mlx4_core: Fix when to save some qp context flags for dynamic VST to VGT
++      transitions
++    - net/mlx4_core: Avoid command timeouts during VF driver device shutdown
++
++  * Xenial update to v4.4.49 stable release (LP: #1664960)
++    - ARC: [arcompact] brown paper bag bug in unaligned access delay slot fixup
++    - selinux: fix off-by-one in setprocattr
++    - Revert "x86/ioapic: Restore IO-APIC irq_chip retrigger callback"
++    - cpumask: use nr_cpumask_bits for parsing functions
++    - hns: avoid stack overflow with CONFIG_KASAN
++    - ARM: 8643/3: arm/ptrace: Preserve previous registers for short regset write
++    - target: Don't BUG_ON during NodeACL dynamic -> explicit conversion
++    - target: Use correct SCSI status during EXTENDED_COPY exception
++    - target: Fix early transport_generic_handle_tmr abort scenario
++    - target: Fix COMPARE_AND_WRITE ref leak for non GOOD status
++    - ARM: 8642/1: LPAE: catch pending imprecise abort on unmask
++    - mac80211: Fix adding of mesh vendor IEs
++    - netvsc: Set maximum GSO size in the right place
++    - scsi: zfcp: fix use-after-free by not tracing WKA port open/close on failed
++      send
++    - scsi: aacraid: Fix INTx/MSI-x issue with older controllers
++    - scsi: mpt3sas: disable ASPM for MPI2 controllers
++    - xen-netfront: Delete rx_refill_timer in xennet_disconnect_backend()
++    - ALSA: seq: Fix race at creating a queue
++    - ALSA: seq: Don't handle loop timeout at snd_seq_pool_done()
++    - drm/i915: fix use-after-free in page_flip_completed()
++    - Linux 4.4.49
++
++  * NFS client : kernel 4.4.0-57 crash with nfsv4 enries in /etc/fstab
++    (LP: #1650336)
++    - SUNRPC: fix refcounting problems with auth_gss messages.
++
++  * [0bda:0328] Card reader failed after S3 (LP: #1664809)
++    - usb: hub: Wait for connection to be reestablished after port reset
++
++  * linux-lts-xenial 4.4.0-63.84~14.04.2 ADT test failure with linux-lts-xenial
++    4.4.0-63.84~14.04.2 (LP: #1664912)
++    - SAUCE: apparmor: fix link auditing failure due to, uninitialized var
++
++  * ibmvscsis: Add SGL LIMIT (LP: #1662551)
++    - ibmvscsis: Add SGL limit
++
++  * [Hyper-V] Bug fixes for storvsc (tagged queuing, error conditions)
++    (LP: #1663687)
++    - scsi: storvsc: Enable tracking of queue depth
++    - scsi: storvsc: Remove the restriction on max segment size
++    - scsi: storvsc: Enable multi-queue support
++    - scsi: storvsc: use tagged SRB requests if supported by the device
++    - scsi: storvsc: properly handle SRB_ERROR when sense message is present
++    - scsi: storvsc: properly set residual data length on errors
++
++  * ISST-LTE:pNV: ppc64_cpu command is hung w HDs, SSDs and NVMe (LP: #1662666)
++    - blk-mq: Avoid memory reclaim when remapping queues
++    - blk-mq: Fix failed allocation path when mapping queues
++
++  * Possible missing firmware /lib/firmware/i915/kbl_dmc_ver1.bin for module
++    i915_bpo (LP: #1624164)
++    - SAUCE: i915_bpo: Remove MODULE_FIRMWARE statement for i915/kbl_dmc_ver1.bin
++
++  *  Intel I210 ethernet does not work both after S3 (LP: #1662763)
++    - igb: implement igb_ptp_suspend
++    - igb: call igb_ptp_suspend during suspend/resume cycle
++
++  * [Hyper-V] Fix ring buffer handling to avoid host throttling (LP: #1661430)
++    - Drivers: hv: vmbus: On write cleanup the logic to interrupt the host
++    - Drivers: hv: vmbus: On the read path cleanup the logic to interrupt the host
++    - Drivers: hv: vmbus: finally fix hv_need_to_signal_on_read()
++
++  * brd module compiled as built-in (LP: #1593293)
++    - [Config] CONFIG_BLK_DEV_RAM=m
++
++  * regession tests failing after stackprofile test is run (LP: #1661030)
++    - SAUCE: fix regression with domain change in complain mode
++
++  * Permission denied and inconsistent behavior in complain mode with 'ip netns
++    list' command (LP: #1648903)
++    - SAUCE: fix regression with domain change in complain mode
++
++  * flock not mediated by 'k' (LP: #1658219)
++    - SAUCE: apparmor: flock mediation is not being enforced on cache check
++
++  * unexpected errno=13 and disconnected path when trying to open /proc/1/ns/mnt
++    from a unshared mount namespace (LP: #1656121)
++    - SAUCE: apparmor: null profiles should inherit parent control flags
++
++  * apparmor refcount leak of profile namespace when removing profiles
++    (LP: #1660849)
++    - SAUCE: apparmor: fix ns ref count link when removing profiles from policy
++
++  * tor in lxd: apparmor="DENIED" operation="change_onexec"
++    namespace="root//CONTAINERNAME_<var-lib-lxd>" profile="unconfined"
++    name="system_tor" (LP: #1648143)
++    - SAUCE: apparmor: Fix no_new_privs blocking change_onexec when using stacked
++      namespaces
++
++  * apparmor_parser hangs indefinitely when called by multiple threads
++    (LP: #1645037)
++    - SAUCE: apparmor: fix lock ordering for mkdir
++
++  * apparmor leaking securityfs pin count (LP: #1660846)
++    - SAUCE: apparmor: fix leak on securityfs pin count
++
++  * apparmor reference count leak when securityfs_setup_d_inode\ () fails
++    (LP: #1660845)
++    - SAUCE: apparmor: fix reference count leak when securityfs_setup_d_inode()
++      fails
++
++  * apparmor not checking error if security_pin_fs() fails (LP: #1660842)
++    - SAUCE: apparmor: fix not handling error case when securityfs_pin_fs() fails
++
++  * apparmor oops in bind_mnt when dev_path lookup fails (LP: #1660840)
++    - SAUCE: apparmor: fix oops in bind_mnt when dev_path lookup fails
++
++  * apparmor  auditing denied access of special apparmor .null fi\ le
++    (LP: #1660836)
++    - SAUCE: apparmor: Don't audit denied access of special apparmor .null file
++
++  * apparmor label leak when new label is unused (LP: #1660834)
++    - SAUCE: apparmor: fix label leak when new label is unused
++
++  * apparmor reference count bug in label_merge_insert() (LP: #1660833)
++    - SAUCE: apparmor: fix reference count bug in label_merge_insert()
++
++  * apparmor's raw_data file in securityfs is sometimes truncated (LP: #1638996)
++    - SAUCE: apparmor: fix replacement race in reading rawdata
++
++  * unix domain socket cross permission check failing with nested namespaces
++    (LP: #1660832)
++    - SAUCE: apparmor: fix cross ns perm of unix domain sockets
++
++  * docker permission issues with overlay2 storage driver (LP: #1659417)
++    - SAUCE: overlayfs: Replace ovl_prepare_creds() with ovl_override_creds()
++    - Revert "UBUNTU: SAUCE: cred: Add clone_cred() interface"
++    - ovl: check mounter creds on underlying lookup
++
++  * Enable CONFIG_NET_DROP_MONITOR=m in Ubuntu Kernel (LP: #1660634)
++    - [Config] CONFIG_NET_DROP_MONITOR=m
++
++  * Xenial update to v4.4.48 stable release (LP: #1663657)
++    - PCI/ASPM: Handle PCI-to-PCIe bridges as roots of PCIe hierarchies
++    - ext4: validate s_first_meta_bg at mount time
++    - drm/nouveau/disp/gt215: Fix HDA ELD handling (thus, HDMI audio) on gt215
++    - drm/nouveau/nv1a,nv1f/disp: fix memory clock rate retrieval
++    - crypto: api - Clear CRYPTO_ALG_DEAD bit before registering an alg
++    - crypto: arm64/aes-blk - honour iv_out requirement in CBC and CTR modes
++    - perf/core: Fix PERF_RECORD_MMAP2 prot/flags for anonymous memory
++    - ata: sata_mv:- Handle return value of devm_ioremap.
++    - libata: apply MAX_SEC_1024 to all CX1-JB*-HP devices
++    - powerpc/eeh: Fix wrong flag passed to eeh_unfreeze_pe()
++    - powerpc: Add missing error check to prom_find_boot_cpu()
++    - NFSD: Fix a null reference case in find_or_create_lock_stateid()
++    - svcrpc: fix oops in absence of krb5 module
++    - zswap: disable changing params if init fails
++    - cifs: initialize file_info_lock
++    - mm/memory_hotplug.c: check start_pfn in test_pages_in_a_zone()
++    - mm, fs: check for fatal signals in do_generic_file_read()
++    - can: bcm: fix hrtimer/tasklet termination in bcm op removal
++    - mmc: sdhci: Ignore unexpected CARD_INT interrupts
++    - percpu-refcount: fix reference leak during percpu-atomic transition
++    - HID: wacom: Fix poor prox handling in 'wacom_pl_irq'
++    - KVM: x86: do not save guest-unsupported XSAVE state
++    - USB: serial: qcserial: add Dell DW5570 QDL
++    - USB: serial: pl2303: add ATEN device ID
++    - USB: Add quirk for WORLDE easykey.25 MIDI keyboard
++    - usb: gadget: f_fs: Assorted buffer overflow checks.
++    - USB: serial: option: add device ID for HP lt2523 (Novatel E371)
++    - x86/irq: Make irq activate operations symmetric
++    - base/memory, hotplug: fix a kernel oops in show_valid_zones()
++    - Linux 4.4.48
++
++  * Xenial update to v4.4.47 stable release (LP: #1662507)
++    - r8152: fix the sw rx checksum is unavailable
++    - mlxsw: spectrum: Fix memory leak at skb reallocation
++    - mlxsw: switchx2: Fix memory leak at skb reallocation
++    - mlxsw: pci: Fix EQE structure definition
++    - net: lwtunnel: Handle lwtunnel_fill_encap failure
++    - net: ipv4: fix table id in getroute response
++    - net: systemport: Decouple flow control from __bcm_sysport_tx_reclaim
++    - tcp: fix tcp_fastopen unaligned access complaints on sparc
++    - openvswitch: maintain correct checksum state in conntrack actions
++    - ravb: do not use zero-length alignment DMA descriptor
++    - ax25: Fix segfault after sock connection timeout
++    - net: fix harmonize_features() vs NETIF_F_HIGHDMA
++    - net: phy: bcm63xx: Utilize correct config_intr function
++    - ipv6: addrconf: Avoid addrconf_disable_change() using RCU read-side lock
++    - tcp: initialize max window for a new fastopen socket
++    - bridge: netlink: call br_changelink() during br_dev_newlink()
++    - r8152: don't execute runtime suspend if the tx is not empty
++    - af_unix: move unix_mknod() out of bindlock
++    - qmi_wwan/cdc_ether: add device ID for HP lt2523 (Novatel E371) WWAN card
++    - net: dsa: Bring back device detaching in dsa_slave_suspend()
++    - Linux 4.4.47
++
++  * Xenial update to v4.4.46 stable release (LP: #1660994)
++    - fbdev: color map copying bounds checking
++    - tile/ptrace: Preserve previous registers for short regset write
++    - drm: Fix broken VT switch with video=1366x768 option
++    - mm/mempolicy.c: do not put mempolicy before using its nodemask
++    - sysctl: fix proc_doulongvec_ms_jiffies_minmax()
++    - ISDN: eicon: silence misleading array-bounds warning
++    - RDMA/cma: Fix unknown symbol when CONFIG_IPV6 is not enabled
++    - s390/ptrace: Preserve previous registers for short regset write
++    - can: c_can_pci: fix null-pointer-deref in c_can_start() - set device pointer
++    - can: ti_hecc: add missing prepare and unprepare of the clock
++    - ARC: udelay: fix inline assembler by adding LP_COUNT to clobber list
++    - ARC: [arcompact] handle unaligned access delay slot corner case
++    - parisc: Don't use BITS_PER_LONG in userspace-exported swab.h header
++    - nfs: Don't increment lock sequence ID after NFS4ERR_MOVED
++    - NFSv4.0: always send mode in SETATTR after EXCLUSIVE4
++    - SUNRPC: cleanup ida information when removing sunrpc module
++    - drm/i915: Don't leak edid in intel_crt_detect_ddc()
++    - IB/ipoib: move back IB LL address into the hard header
++    - IB/umem: Release pid in error and ODP flow
++    - s5k4ecgx: select CRC32 helper
++    - pinctrl: broxton: Use correct PADCFGLOCK offset
++    - platform/x86: intel_mid_powerbtn: Set IRQ_ONESHOT
++    - mm, memcg: do not retry precharge charges
++    - Linux 4.4.46
++
++  * Xenial update to v4.4.45 stable release (LP: #1660993)
++    - ftrace/x86: Set ftrace_stub to weak to prevent gcc from using short jumps to
++      it
++    - IB/mlx5: Wait for all async command completions to complete
++    - IB/mlx4: Set traffic class in AH
++    - IB/mlx4: Fix out-of-range array index in destroy qp flow
++    - IB/mlx4: Fix port query for 56Gb Ethernet links
++    - IB/mlx4: When no DMFS for IPoIB, don't allow NET_IF QPs
++    - IB/IPoIB: Remove can't use GFP_NOIO warning
++    - perf scripting: Avoid leaking the scripting_context variable
++    - ARM: dts: imx31: fix clock control module interrupts description
++    - ARM: dts: imx31: move CCM device node to AIPS2 bus devices
++    - ARM: dts: imx31: fix AVIC base address
++    - tmpfs: clear S_ISGID when setting posix ACLs
++    - x86/PCI: Ignore _CRS on Supermicro X8DTH-i/6/iF/6F
++    - svcrpc: don't leak contexts on PROC_DESTROY
++    - fuse: clear FR_PENDING flag when moving requests out of pending queue
++    - PCI: Enumerate switches below PCI-to-PCIe bridges
++    - HID: corsair: fix DMA buffers on stack
++    - HID: corsair: fix control-transfer error handling
++    - mmc: mxs-mmc: Fix additional cycles after transmission stop
++    - ieee802154: atusb: do not use the stack for buffers to make them DMA able
++    - mtd: nand: xway: disable module support
++    - x86/ioapic: Restore IO-APIC irq_chip retrigger callback
++    - qla2xxx: Fix crash due to null pointer access
++    - ubifs: Fix journal replay wrt. xattr nodes
++    - clocksource/exynos_mct: Clear interrupt when cpu is shut down
++    - svcrdma: avoid duplicate dma unmapping during error recovery
++    - ARM: 8634/1: hw_breakpoint: blacklist Scorpion CPUs
++    - ceph: fix bad endianness handling in parse_reply_info_extra
++    - ARM: dts: da850-evm: fix read access to SPI flash
++    - arm64/ptrace: Preserve previous registers for short regset write
++    - arm64/ptrace: Preserve previous registers for short regset write - 2
++    - arm64/ptrace: Preserve previous registers for short regset write - 3
++    - arm64/ptrace: Avoid uninitialised struct padding in fpr_set()
++    - arm64/ptrace: Reject attempts to set incomplete hardware breakpoint fields
++    - ARM: dts: imx6qdl-nitrogen6_max: fix sgtl5000 pinctrl init
++    - ARM: ux500: fix prcmu_is_cpu_in_wfi() calculation
++    - ARM: 8613/1: Fix the uaccess crash on PB11MPCore
++    - blackfin: check devm_pinctrl_get() for errors
++    - ite-cir: initialize use_demodulator before using it
++    - dmaengine: pl330: Fix runtime PM support for terminated transfers
++    - selftest/powerpc: Wrong PMC initialized in pmc56_overflow test
++    - arm64: avoid returning from bad_mode
++    - Linux 4.4.45
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 08 Mar 2017 11:47:26 -0300
++
++linux (4.4.0-66.87) xenial; urgency=low
++
++  * CVE-2017-2636
++    - TTY: n_hdlc, fix lockdep false positive
++    - tty: n_hdlc: get rid of racy n_hdlc.tbuf
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Fri, 03 Mar 2017 12:01:27 +0100
++
++linux (4.4.0-64.85) xenial; urgency=low
++
++  * CVE-2017-6074 (LP: #1665935)
++    - dccp: fix freeing skb too early for IPV6_RECVPKTINFO
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Mon, 20 Feb 2017 11:06:47 +0100
++
++linux (4.4.0-63.84) xenial; urgency=low
++
++  [ Thadeu Lima de Souza Cascardo ]
++
++  * Release Tracking Bug
++    - LP: #1660704
++
++  * Backport Dirty COW patch to prevent wineserver freeze (LP: #1658270)
++    - SAUCE: mm: Respect FOLL_FORCE/FOLL_COW for thp
++
++  * Kdump through NMI SMP and single core not working on Ubuntu16.10
++    (LP: #1630924)
++    - x86/hyperv: Handle unknown NMIs on one CPU when unknown_nmi_panic
++    - SAUCE: hv: don't reset hv_context.tsc_page on crash
++
++  * [regression 4.8.0-14 -> 4.8.0-17] keyboard and touchscreen lost on Acer
++    Chromebook R11 (LP: #1630238)
++    - [Config] CONFIG_PINCTRL_CHERRYVIEW=y
++
++  * Call trace when testing fstat stressor on ppc64el with virtual  keyboard and
++    mouse present (LP: #1652132)
++    - SAUCE: HID: usbhid: Quirk a AMI virtual mouse and keyboard with ALWAYS_POLL
++
++  * VLAN SR-IOV regression for IXGBE driver (LP: #1658491)
++    - ixgbe: Force VLNCTRL.VFE to be set in all VMDq paths
++
++  * "Out of memory" errors after upgrade to 4.4.0-59 (LP: #1655842)
++    - mm, page_alloc: convert alloc_flags to unsigned
++    - mm, compaction: change COMPACT_ constants into enum
++    - mm, compaction: distinguish COMPACT_DEFERRED from COMPACT_SKIPPED
++    - mm, compaction: simplify __alloc_pages_direct_compact feedback interface
++    - mm, compaction: distinguish between full and partial COMPACT_COMPLETE
++    - mm, compaction: abstract compaction feedback to helpers
++    - mm, oom: protect !costly allocations some more
++    - mm: consider compaction feedback also for costly allocation
++    - mm, oom, compaction: prevent from should_compact_retry looping for ever for
++      costly orders
++    - mm, oom: protect !costly allocations some more for !CONFIG_COMPACTION
++    - mm, oom: prevent premature OOM killer invocation for high order request
++
++  * Backport 3 patches to fix bugs with AIX clients using IBMVSCSI Target Driver
++    (LP: #1657194)
++    - SAUCE: ibmvscsis: Fix max transfer length
++    - SAUCE: ibmvscsis: fix sleeping in interrupt context
++    - SAUCE: ibmvscsis: Fix srp_transfer_data fail return code
++
++  * NVMe: adapter is missing after abnormal shutdown followed by quick reboot,
++    quirk needed (LP: #1656913)
++    - nvme: apply DELAY_BEFORE_CHK_RDY quirk at probe time too
++
++  * Ubuntu 16.10 KVM SRIOV: if enable sriov while ping flood is running ping
++    will stop working (LP: #1625318)
++    - PCI: Do any VF BAR updates before enabling the BARs
++    - PCI: Ignore BAR updates on virtual functions
++    - PCI: Update BARs using property bits appropriate for type
++    - PCI: Separate VF BAR updates from standard BAR updates
++    - PCI: Don't update VF BARs while VF memory space is enabled
++    - PCI: Remove pci_resource_bar() and pci_iov_resource_bar()
++    - PCI: Decouple IORESOURCE_ROM_ENABLE and PCI_ROM_ADDRESS_ENABLE
++    - PCI: Add comments about ROM BAR updating
++
++  * Linux rtc self test fails in a VM under xenial (LP: #1649718)
++    - kvm: x86: Convert ioapic->rtc_status.dest_map to a struct
++    - kvm: x86: Track irq vectors in ioapic->rtc_status.dest_map
++    - kvm: x86: Check dest_map->vector to match eoi signals for rtc
++
++  * Xenial update to v4.4.44 stable release (LP: #1658091)
++    - Input: xpad - use correct product id for x360w controllers
++    - Input: i8042 - add Pegatron touchpad to noloop table
++    - selftests: do not require bash to run netsocktests testcase
++    - selftests: do not require bash for the generated test
++    - mm: fix devm_memremap_pages crash, use mem_hotplug_{begin, done}
++    - ocfs2: fix crash caused by stale lvb with fsdlm plugin
++    - mm/hugetlb.c: fix reservation race when freeing surplus pages
++    - KVM: x86: fix emulation of "MOV SS, null selector"
++    - KVM: eventfd: fix NULL deref irqbypass consumer
++    - jump_labels: API for flushing deferred jump label updates
++    - KVM: x86: flush pending lapic jump label updates on module unload
++    - KVM: x86: add Align16 instruction flag
++    - KVM: x86: add asm_safe wrapper
++    - KVM: x86: emulate FXSAVE and FXRSTOR
++    - KVM: x86: Introduce segmented_write_std
++    - nl80211: fix sched scan netlink socket owner destruction
++    - USB: serial: kl5kusb105: fix line-state error handling
++    - USB: serial: ch341: fix initial modem-control state
++    - USB: serial: ch341: fix open error handling
++    - USB: serial: ch341: fix control-message error handling
++    - USB: serial: ch341: fix open and resume after B0
++    - Input: elants_i2c - avoid divide by 0 errors on bad touchscreen data
++    - i2c: print correct device invalid address
++    - i2c: fix kernel memory disclosure in dev interface
++    - xhci: fix deadlock at host remove by running watchdog correctly
++    - vme: Fix wrong pointer utilization in ca91cx42_slave_get
++    - mnt: Protect the mountpoint hashtable with mount_lock
++    - tty/serial: atmel_serial: BUG: stop DMA from transmitting in stop_tx
++    - sysrq: attach sysrq handler correctly for 32-bit kernel
++    - sysctl: Drop reference added by grab_header in proc_sys_readdir
++    - drm/radeon: drop verde dpm quirks
++    - USB: serial: ch341: fix resume after reset
++    - USB: serial: ch341: fix modem-control and B0 handling
++    - x86/cpu: Fix bootup crashes by sanitizing the argument of the 'clearcpuid='
++      command-line option
++    - btrfs: fix locking when we put back a delayed ref that's too new
++    - btrfs: fix error handling when run_delayed_extent_op fails
++    - pinctrl: meson: fix gpio request disabling other modes
++    - pNFS: Fix race in pnfs_wait_on_layoutreturn
++    - NFS: Fix a performance regression in readdir
++    - NFSv4.1: nfs4_fl_prepare_ds must be careful about reporting success.
++    - cpufreq: powernv: Disable preemption while checking CPU throttling state
++    - block: cfq_cpd_alloc() should use @gfp
++    - ACPI / APEI: Fix NMI notification handling
++    - blk-mq: Always schedule hctx->next_cpu
++    - bus: vexpress-config: fix device reference leak
++    - powerpc/ibmebus: Fix further device reference leaks
++    - powerpc/ibmebus: Fix device reference leaks in sysfs interface
++    - pinctrl: sh-pfc: Do not unconditionally support PIN_CONFIG_BIAS_DISABLE
++    - Linux 4.4.44
++
++  * Add support for RT5660 codec based sound cards on Baytrail (LP: #1657674)
++    - ASoC: rt5660: add rt5660 codec driver
++    - ASoC: rt5660: enable MCLK detection
++    - ASoC: Intel: Atom: flip logic for gain Switch
++    - SAUCE: (no-up) ASoC: rt5660: Add ACPI support
++    - SAUCE: (no-up) ASoC: Intel: Support machine driver for RT5660 on Baytrail
++    - [Config] CONFIG_SND_SOC_INTEL_BYTCR_RT5660_MACH=m, CONFIG_SND_SOC_RT5660=m
++
++  * Support latest Redpine WLAN/BT RS9113 driver (LP: #1657682)
++    - SAUCE: Support Redpine RS9113 WLAN/BT
++    - SAUCE: Separate Redpine RS9113 WLAN/BT vendor and kernel drivers
++    - SAUCE: Redpine RS9113 WLAN/BT driver ver. 0.9.7
++    - SAUCE: RS9113: Use vendor driver to support WLAN/BT card on Caracalla HW
++      only
++    - SAUCE: RS9113: Comment out IDs from upstream driver
++    - [Config] Enable CONFIG_VEN_RSI_* configs
++
++  * [Hyper-V] netvsc: add rcu_read locked to netvsc callback (LP: #1657540)
++    - netvsc: add rcu_read locking to netvsc callback
++
++  * [Hyper-V] Rebase Hyper-V in 16.04 and 16.10 to the the upstream 4.9 kernel
++    (LP: #1650059)
++    - memory-hotplug: add automatic onlining policy for the newly added memory
++    - hv_netvsc: Add query for initial physical link speed
++    - hv_netvsc: Add handler for physical link speed change
++    - hv_netvsc: Implement batching of receive completions
++    - PCI: hv: Use list_move_tail() instead of list_del() + list_add_tail()
++    - hv_netvsc: fix rtnl locking in callback
++    - hv_netvsc: make RSS hash key static
++    - hv_netvsc: use kcalloc
++    - hv_netvsc: style cleanups
++    - hv_netvsc: make inline functions static
++    - hv_netvsc: use ARRAY_SIZE() for NDIS versions
++    - hv_netvsc: make device_remove void
++    - hv_netvsc: init completion during alloc
++    - hv_netvsc: rearrange start_xmit
++    - hv_netvsc: refactor completion function
++    - hv_netvsc: make netvsc_destroy_buf void
++    - hv_netvsc: make variable local
++    - hv_netvsc: report vmbus name in ethtool
++    - hv_netvsc: add ethtool statistics for tx packet issues
++    - Drivers: hv: get rid of redundant messagecount in create_gpadl_header()
++    - Drivers: hv: don't leak memory in vmbus_establish_gpadl()
++    - Drivers: hv: get rid of timeout in vmbus_open()
++    - Drivers: hv: utils: fix a race on userspace daemons registration
++    - Drivers: hv: vmbus: fix the race when querying & updating the percpu list
++    - Drivers: hv: vmbus: Enable explicit signaling policy for NIC channels
++    - Drivers: hv: vmbus: Reduce the delay between retries in vmbus_post_msg()
++    - Drivers: hv: vmbus: Implement a mechanism to tag the channel for low latency
++    - Tools: hv: kvp: ensure kvp device fd is closed on exec
++    - Drivers: hv: balloon: keep track of where ha_region starts
++    - Drivers: hv: balloon: account for gaps in hot add regions
++    - Drivers: hv: balloon: don't wait for ol_waitevent when memhp_auto_online is
++      enabled
++    - Drivers: hv: balloon: replace ha_region_mutex with spinlock
++    - Drivers: hv: balloon: Use available memory value in pressure report
++    - Drivers: hv: cleanup vmbus_open() for wrap around mappings
++    - Drivers: hv: ring_buffer: wrap around mappings for ring buffers
++    - Drivers: hv: ring_buffer: use wrap around mappings in hv_copy{from,
++      to}_ringbuffer()
++    - Drivers: hv: ring_buffer: count on wrap around mappings in
++      get_next_pkt_raw()
++    - Drivers: hv: Introduce a policy for controlling channel affinity
++    - Drivers: hv: utils: Continue to poll VSS channel after handling requests.
++    - Drivers: hv: utils: Check VSS daemon is listening before a hot backup
++    - PCI: hv: Use zero-length array in struct pci_packet
++    - PCI: hv: Use pci_function_description[0] in struct definitions
++    - PCI: hv: Remove the unused 'wrk' in struct hv_pcibus_device
++    - PCI: hv: Handle vmbus_sendpacket() failure in hv_compose_msi_msg()
++    - PCI: hv: Handle hv_pci_generic_compl() error case
++    - Revert "Drivers: hv: ring_buffer: count on wrap around mappings in
++      get_next_pkt_raw()"
++    - Driver: hv: vmbus: Make mmio resource local
++    - Drivers: hv: vmbus: suppress some "hv_vmbus: Unknown GUID" warnings
++    - Drivers: hv: utils: Rename version definitions to reflect protocol version.
++    - Drivers: hv: utils: Use TimeSync samples to adjust the clock after boot.
++    - Drivers: hv: utils: Support TimeSync version 4.0 protocol samples.
++    - Drivers: hv: hv_util: Avoid dynamic allocation in time synch
++    - Revert "hv_netvsc: make inline functions static"
++    - hv_netvsc: use consume_skb
++    - hv_netvsc: dev hold/put reference to VF
++    - hv_netvsc: simplify callback event code
++    - hv_netvsc: improve VF device matching
++    - hv_netvsc: use RCU to protect vf_netdev
++    - hv_netvsc: remove VF in flight counters
++    - hv_netvsc: count multicast packets received
++    - hv_netvsc: fix comments
++    - Drivers: hv: make VMBus bus ids persistent
++    - Drivers: hv: get rid of id in struct vmbus_channel
++    - netvsc: fix checksum on UDP IPV6
++    - netvsc: Remove mistaken udp.h inclusion.
++    - net/hyperv: avoid uninitialized variable
++    - Revert "hv_netvsc: report vmbus name in ethtool"
++    - vmbus: make sysfs names consistent with PCI
++    - netvsc: reduce maximum GSO size
++    - Drivers: hv: vmbus: Base host signaling strictly on the ring state
++    - tools: hv: Add a script to help bonding synthetic and VF NICs
++
++  * Ubuntu - ibmveth: abnormally large TCP MSS value caused a TCP session to
++    hang with a zero window (LP: #1655420)
++    - ibmveth: set correct gso_size and gso_type
++    - ibmveth: calculate gso_segs for large packets
++
++  * netfilter regression introducing a performance slowdown in binary
++    arp/ip/ip6tables (LP: #1640786)
++    - netfilter: x_tables: pass xt_counters struct instead of packet counter
++    - netfilter: x_tables: pass xt_counters struct to counter allocator
++    - netfilter: x_tables: pack percpu counter allocations
++
++  * Move some kernel modules to the main kernel package (part 2) (LP: #1655002)
++    - [Config] Add IBM power drivers to the inclusion list
++
++  * Xenial update to v4.4.43 stable release (LP: #1656876)
++    - netvsc: reduce maximum GSO size
++    - ser_gigaset: return -ENOMEM on error instead of success
++    - net: vrf: Drop conntrack data after pass through VRF device on Tx
++    - ipv6: handle -EFAULT from skb_copy_bits
++    - net, sched: fix soft lockup in tc_classify
++    - net: stmmac: Fix race between stmmac_drv_probe and stmmac_open
++    - net/mlx5: Check FW limitations on log_max_qp before setting it
++    - net/mlx5: Avoid shadowing numa_node
++    - drop_monitor: add missing call to genlmsg_end
++    - drop_monitor: consider inserted data in genlmsg_end
++    - igmp: Make igmp group member RFC 3376 compliant
++    - ipv4: Do not allow MAIN to be alias for new LOCAL w/ custom rules
++    - r8152: split rtl8152_suspend function
++    - r8152: fix rx issue for runtime suspend
++    - gro: Enter slow-path if there is no tailroom
++    - gro: use min_t() in skb_gro_reset_offset()
++    - gro: Disable frag0 optimization on IPv6 ext headers
++    - net: ipv4: Fix multipath selection with vrf
++    - net: vrf: do not allow table id 0
++    - HID: hid-cypress: validate length of report
++    - ALSA: firewire-tascam: Fix to handle error from initialization of stream
++      data
++    - powerpc: Fix build warning on 32-bit PPC
++    - ARM: zynq: Reserve correct amount of non-DMA RAM
++    - ARM: OMAP4+: Fix bad fallthrough for cpuidle
++    - spi: mvebu: fix baudrate calculation for armada variant
++    - ALSA: usb-audio: Add a quirk for Plantronics BT600
++    - mm/init: fix zone boundary creation
++    - Linux 4.4.43
++
++  * Xenial update to v4.4.42 stable release (LP: #1655969)
++    - ALSA: hda - Fix up GPIO for ASUS ROG Ranger
++    - ALSA: hda - Apply asus-mode8 fixup to ASUS X71SL
++    - ALSA: usb-audio: Fix irq/process data synchronization
++    - ARM: davinci: da850: don't add emac clock to lookup table twice
++    - mac80211: initialize fast-xmit 'info' later
++    - KVM: x86: reset MMU on KVM_SET_VCPU_EVENTS
++    - KVM: MIPS: Flush KVM entry code from icache globally
++    - usb: musb: core: add clear_ep_rxintr() to musb_platform_ops
++    - usb: musb: dsps: implement clear_ep_rxintr() callback
++    - usb: storage: unusual_uas: Add JMicron JMS56x to unusual device
++    - usb: gadgetfs: restrict upper bound on device configuration size
++    - USB: gadgetfs: fix unbounded memory allocation bug
++    - USB: gadgetfs: fix use-after-free bug
++    - USB: gadgetfs: fix checks of wTotalLength in config descriptors
++    - USB: fix problems with duplicate endpoint addresses
++    - USB: dummy-hcd: fix bug in stop_activity (handle ep0)
++    - usb: gadget: composite: Test get_alt() presence instead of set_alt()
++    - usb: dwc3: core: avoid Overflow events
++    - usb: xhci: fix possible wild pointer
++    - xhci: workaround for hosts missing CAS bit
++    - usb: xhci: apply XHCI_PME_STUCK_QUIRK to Intel Apollo Lake
++    - xhci: free xhci virtual devices with leaf nodes first
++    - usb: xhci: fix return value of xhci_setup_device()
++    - usb: host: xhci: Fix possible wild pointer when handling abort command
++    - xhci: Handle command completion and timeout race
++    - usb: xhci: hold lock over xhci_abort_cmd_ring()
++    - USB: serial: omninet: fix NULL-derefs at open and disconnect
++    - USB: serial: quatech2: fix sleep-while-atomic in close
++    - USB: serial: pl2303: fix NULL-deref at open
++    - USB: serial: keyspan_pda: verify endpoints at probe
++    - USB: serial: spcp8x5: fix NULL-deref at open
++    - USB: serial: io_ti: fix NULL-deref at open
++    - USB: serial: io_ti: fix another NULL-deref at open
++    - USB: serial: io_ti: fix I/O after disconnect
++    - USB: serial: iuu_phoenix: fix NULL-deref at open
++    - USB: serial: garmin_gps: fix memory leak on failed URB submit
++    - USB: serial: ti_usb_3410_5052: fix NULL-deref at open
++    - USB: serial: io_edgeport: fix NULL-deref at open
++    - USB: serial: oti6858: fix NULL-deref at open
++    - USB: serial: cyberjack: fix NULL-deref at open
++    - USB: serial: kobil_sct: fix NULL-deref in write
++    - USB: serial: mos7840: fix NULL-deref at open
++    - USB: serial: mos7720: fix NULL-deref at open
++    - USB: serial: mos7720: fix use-after-free on probe errors
++    - USB: serial: mos7720: fix parport use-after-free on probe errors
++    - USB: serial: mos7720: fix parallel probe
++    - usb: xhci-mem: use passed in GFP flags instead of GFP_KERNEL
++    - xhci: Use delayed_work instead of timer for command timeout
++    - xhci: Fix race related to abort operation
++    - usb: dwc3: pci: add Intel Gemini Lake PCI ID
++    - usb: musb: Fix trying to free already-free IRQ 4
++    - usb: hub: Move hub_port_disable() to fix warning if PM is disabled
++    - usb: musb: blackfin: add bfin_fifo_offset in bfin_ops
++    - ALSA: usb-audio: Fix bogus error return in snd_usb_create_stream()
++    - USB: serial: kl5kusb105: abort on open exception path
++    - ARM: dts: r8a7794: Correct hsusb parent clock
++    - USB: phy: am335x-control: fix device and of_node leaks
++    - USB: serial: io_ti: bind to interface after fw download
++    - mei: bus: fix mei_cldev_enable KDoc
++    - staging: iio: ad7606: fix improper setting of oversampling pins
++    - usb: dwc3: gadget: always unmap EP0 requests
++    - usb: dwc3: ep0: add dwc3_ep0_prepare_one_trb()
++    - usb: dwc3: ep0: explicitly call dwc3_ep0_prepare_one_trb()
++    - stable-fixup: hotplug: fix unused function warning
++    - ath10k: use the right length of "background"
++    - cris: Only build flash rescue image if CONFIG_ETRAX_AXISFLASHMAP is selected
++    - hwmon: (scpi) Fix module autoload
++    - hwmon: (amc6821) sign extension temperature
++    - hwmon: (ds620) Fix overflows seen when writing temperature limits
++    - hwmon: (nct7802) Fix overflows seen when writing into limit attributes
++    - hwmon: (g762) Fix overflows and crash seen when writing limit attributes
++    - clk: clk-wm831x: fix a logic error
++    - clk: imx31: fix rewritten input argument of mx31_clocks_init()
++    - iommu/amd: Missing error code in amd_iommu_init_device()
++    - iommu/amd: Fix the left value check of cmd buffer
++    - iommu/vt-d: Fix pasid table size encoding
++    - iommu/vt-d: Flush old iommu caches for kdump when the device gets context
++      mapped
++    - ASoC: samsung: i2s: Fixup last IRQ unsafe spin lock call
++    - scsi: mvsas: fix command_active typo
++    - target/iscsi: Fix double free in lio_target_tiqn_addtpg()
++    - irqchip/bcm7038-l1: Implement irq_cpu_offline() callback
++    - PM / wakeirq: Fix dedicated wakeirq for drivers not using autosuspend
++    - mmc: mmc_test: Uninitialized return value
++    - s390/crypto: unlock on error in prng_tdes_read()
++    - crypto: arm64/sha2-ce - fix for big endian
++    - crypto: arm64/ghash-ce - fix for big endian
++    - crypto: arm/aes-ce - fix for big endian
++    - crypto: arm64/aes-ccm-ce: fix for big endian
++    - crypto: arm64/aes-neon - fix for big endian
++    - crypto: arm64/sha1-ce - fix for big endian
++    - crypto: arm64/aes-xts-ce: fix for big endian
++    - crypto: arm64/aes-ce - fix for big endian
++    - md: MD_RECOVERY_NEEDED is set for mddev->recovery
++    - powerpc/pci/rpadlpar: Fix device reference leaks
++    - staging: comedi: dt282x: tidy up register bit defines
++    - cred/userns: define current_user_ns() as a function
++    - net: ti: cpmac: Fix compiler warning due to type confusion
++    - net: vxge: avoid unused function warnings
++    - cx23885-dvb: move initialization of a8293_pdata
++    - drm/radeon: Always store CRTC relative radeon_crtc->cursor_x/y values
++    - tick/broadcast: Prevent NULL pointer dereference
++    - Revert "usb: gadget: composite: always set ep->mult to a sensible value"
++    - usb: gadget: composite: always set ep->mult to a sensible value
++    - Linux 4.4.42
++
++  * Xenial update to v4.4.41 stable release (LP: #1655041)
++    - ssb: Fix error routine when fallback SPROM fails
++    - rtlwifi: Fix enter/exit power_save
++    - cfg80211/mac80211: fix BSS leaks when abandoning assoc attempts
++    - ath9k: Really fix LED polarity for some Mini PCI AR9220 MB92 cards.
++    - mmc: sdhci: Fix recovery from tuning timeout
++    - regulator: stw481x-vmmc: fix ages old enable error
++    - timekeeping_Force_unsigned_clocksource_to_nanoseconds_conversion
++    - clk: bcm2835: Avoid overwriting the div info when disabling a pll_div clk
++    - thermal: hwmon: Properly report critical temperature in sysfs
++    - staging: comedi: ni_mio_common: fix M Series ni_ai_insn_read() data mask
++    - staging: comedi: ni_mio_common: fix E series ni_ai_insn_read() data
++    - ACPI / video: Add force_native quirk for Dell XPS 17 L702X
++    - ACPI / video: Add force_native quirk for HP Pavilion dv6
++    - drm/nouveau/kms: lvds panel strap moved again on maxwell
++    - drm/nouveau/bios: require checksum to match for fast acpi shadow method
++    - drm/nouveau/ltc: protect clearing of comptags with mutex
++    - drm/nouveau/fifo/gf100-: protect channel preempt with subdev mutex
++    - drm/nouveau/i2c/gk110b,gm10x: use the correct implementation
++    - drm/radeon: Also call cursor_move_locked when the cursor size changes
++    - drm/radeon: Hide the HW cursor while it's out of bounds
++    - drm/radeon: add additional pci revision to dpm workaround
++    - drm/gma500: Add compat ioctl
++    - drivers/gpu/drm/ast: Fix infinite loop if read fails
++    - mei: request async autosuspend at the end of enumeration
++    - block: protect iterate_bdevs() against concurrent close
++    - vt: fix Scroll Lock LED trigger name
++    - scsi: megaraid_sas: For SRIOV enabled firmware, ensure VF driver waits for
++      30secs before reset
++    - scsi: megaraid_sas: Do not set MPI2_TYPE_CUDA for JBOD FP path for FW which
++      does not support JBOD sequence map
++    - scsi: zfcp: fix use-after-"free" in FC ingress path after TMF
++    - scsi: zfcp: do not trace pure benign residual HBA responses at default level
++    - scsi: zfcp: fix rport unblock race with LUN recovery
++    - scsi: avoid a permanent stop of the scsi device's request queue
++    - ARC: mm: arc700: Don't assume 2 colours for aliasing VIPT dcache
++    - firmware: fix usermode helper fallback loading
++    - s390/vmlogrdr: fix IUCV buffer allocation
++    - sc16is7xx: Drop bogus use of IRQF_ONESHOT
++    - md/raid5: limit request size according to implementation limits
++    - KVM: PPC: Book3S HV: Save/restore XER in checkpointed register state
++    - KVM: PPC: Book3S HV: Don't lose hardware R/C bit updates in H_PROTECT
++    - kvm: nVMX: Allow L1 to intercept software exceptions (#BP and #OF)
++    - platform/x86: asus-nb-wmi.c: Add X45U quirk
++    - fgraph: Handle a case where a tracer ignores set_graph_notrace
++    - IB/mad: Fix an array index check
++    - IPoIB: Avoid reading an uninitialized member variable
++    - IB/multicast: Check ib_find_pkey() return value
++    - IB/cma: Fix a race condition in iboe_addr_get_sgid()
++    - media: solo6x10: fix lockup by avoiding delayed register write
++    - Input: drv260x - fix input device's parent assignment
++    - PCI: Check for PME in targeted sleep state
++    - libceph: verify authorize reply on connect
++    - nfs_write_end(): fix handling of short copies
++    - powerpc/ps3: Fix system hang with GCC 5 builds
++    - powerpc: Convert cmp to cmpd in idle enter sequence
++    - kconfig/nconf: Fix hang when editing symbol with a long prompt
++    - sg_write()/bsg_write() is not fit to be called under KERNEL_DS
++    - net: mvpp2: fix dma unmapping of TX buffers for fragments
++    - Linux 4.4.41
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 01 Feb 2017 14:00:35 -0200
++
++linux (4.4.0-62.83) xenial; urgency=low
++
++  [ Thadeu Lima de Souza Cascardo ]
++
++  * Release Tracking Bug
++    - LP: #1657430
++
++  * Backport DP MST fixes to i915 (LP: #1657353)
++    - SAUCE: i915_bpo: Fix DP link rate math
++    - SAUCE: i915_bpo: Validate mode against max. link data rate for DP MST
++
++  * Ubuntu xenial - 4.4.0-59-generic i3 I/O performance issue (LP: #1657281)
++    - blk-mq: really fix plug list flushing for nomerge queues
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 18 Jan 2017 09:34:07 -0200
++
++linux (4.4.0-61.82) xenial; urgency=low
++
++  [ Thadeu Lima de Souza Cascardo ]
++
++  * Release Tracking Bug
++    - LP: #1656810
++
++  * Xen MSI setup code incorrectly re-uses cached pirq (LP: #1656381)
++    - SAUCE: xen: do not re-use pirq number cached in pci device msi msg data
++
++  * nvme drive probe failure (LP: #1626894)
++    - nvme: revert NVMe: only setup MSIX once
++
++ -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Mon, 16 Jan 2017 10:30:12 -0200
++
++linux (4.4.0-60.81) xenial; urgency=low
++
++  [ John Donnelly ]
++
++  * Release Tracking Bug
++    - LP: #1656084
++
++  * Couldn't emulate instruction 0x7813427c (LP: #1634129)
++    - KVM: PPC: Book3S PR: Fix illegal opcode emulation
++
++  * perf: 24x7: Eliminate domain name suffix in event names (LP: #1560482)
++    - powerpc/perf/hv-24x7: Fix usage with chip events.
++    - powerpc/perf/hv-24x7: Display change in counter values
++    - powerpc/perf/hv-24x7: Display domain indices in sysfs
++    - powerpc/perf/24x7: Eliminate domain suffix in event names
++
++  * i386 ftrace tests hang on ADT testing (LP: #1655040)
++    - ftrace/x86_32: Set ftrace_stub to weak to prevent gcc from using short jumps
++      to it
++
++  * VMX module autoloading if available (LP: #1651322)
++    - powerpc: Add module autoloading based on CPU features
++    - crypto: vmx - Convert to CPU feature based module autoloading
++
++  * ACPI probe support for AD5592/3 configurable multi-channel converter
++    (LP: #1654497)
++    - SAUCE: iio: dac: ad5592r: Add ACPI support
++    - SAUCE: iio: dac: ad5593r: Add ACPI support
++
++  * Xenial update to v4.4.40 stable release (LP: #1654602)
++    - btrfs: limit async_work allocation and worker func duration
++    - Btrfs: fix tree search logic when replaying directory entry deletes
++    - btrfs: store and load values of stripes_min/stripes_max in balance status
++      item
++    - Btrfs: fix qgroup rescan worker initialization
++    - USB: serial: option: add support for Telit LE922A PIDs 0x1040, 0x1041
++    - USB: serial: option: add dlink dwm-158
++    - USB: serial: kl5kusb105: fix open error path
++    - USB: cdc-acm: add device id for GW Instek AFG-125
++    - usb: hub: Fix auto-remount of safely removed or ejected USB-3 devices
++    - usb: gadget: f_uac2: fix error handling at afunc_bind
++    - usb: gadget: composite: correctly initialize ep->maxpacket
++    - USB: UHCI: report non-PME wakeup signalling for Intel hardware
++    - ALSA: usb-audio: Add QuickCam Communicate Deluxe/S7500 to
++      volume_control_quirks
++    - ALSA: hiface: Fix M2Tech hiFace driver sampling rate change
++    - ALSA: hda/ca0132 - Add quirk for Alienware 15 R2 2016
++    - ALSA: hda - ignore the assoc and seq when comparing pin configurations
++    - ALSA: hda - fix headset-mic problem on a Dell laptop
++    - ALSA: hda - Gate the mic jack on HP Z1 Gen3 AiO
++    - ALSA: hda: when comparing pin configurations, ignore assoc in addition to
++      seq
++    - clk: ti: omap36xx: Work around sprz319 advisory 2.1
++    - Btrfs: fix memory leak in reading btree blocks
++    - Btrfs: bail out if block group has different mixed flag
++    - Btrfs: return gracefully from balance if fs tree is corrupted
++    - Btrfs: don't leak reloc root nodes on error
++    - Btrfs: fix memory leak in do_walk_down
++    - Btrfs: don't BUG() during drop snapshot
++    - btrfs: make file clone aware of fatal signals
++    - block_dev: don't test bdev->bd_contains when it is not stable
++    - ptrace: Capture the ptracer's creds not PT_PTRACE_CAP
++    - crypto: caam - fix AEAD givenc descriptors
++    - ext4: fix mballoc breakage with 64k block size
++    - ext4: fix stack memory corruption with 64k block size
++    - ext4: use more strict checks for inodes_per_block on mount
++    - ext4: fix in-superblock mount options processing
++    - ext4: add sanity checking to count_overhead()
++    - ext4: reject inodes with negative size
++    - ext4: return -ENOMEM instead of success
++    - ext4: do not perform data journaling when data is encrypted
++    - f2fs: set ->owner for debugfs status file's file_operations
++    - loop: return proper error from loop_queue_rq()
++    - mm/vmscan.c: set correct defer count for shrinker
++    - fs: exec: apply CLOEXEC before changing dumpable task flags
++    - exec: Ensure mm->user_ns contains the execed files
++    - usb: gadget: composite: always set ep->mult to a sensible value
++    - blk-mq: Do not invoke .queue_rq() for a stopped queue
++    - dm flakey: return -EINVAL on interval bounds error in flakey_ctr()
++    - dm crypt: mark key as invalid until properly loaded
++    - dm space map metadata: fix 'struct sm_metadata' leak on failed create
++    - ASoC: intel: Fix crash at suspend/resume without card registration
++    - CIFS: Fix a possible memory corruption during reconnect
++    - CIFS: Fix missing nls unload in smb2_reconnect()
++    - CIFS: Fix a possible memory corruption in push locks
++    - kernel/watchdog: use nmi registers snapshot in hardlockup handler
++    - kernel/debug/debug_core.c: more properly delay for secondary CPUs
++    - tpm xen: Remove bogus tpm_chip_unregister
++    - xen/gntdev: Use VM_MIXEDMAP instead of VM_IO to avoid NUMA balancing
++    - arm/xen: Use alloc_percpu rather than __alloc_percpu
++    - xfs: set AGI buffer type in xlog_recover_clear_agi_bucket
++    - driver core: fix race between creating/querying glue dir and its cleanup
++    - ppp: defer netns reference release for ppp channel
++    - Linux 4.4.40
++
++  * igb i210 probe of pci device failed with error -2 (LP: #1639810)
++    - SAUCE: igb: Workaround for igb i210 firmware issue.
++    - SAUCE: igb: add i211 to i210 PHY workaround
++
++  * PowerNV: PCI Slot is invalid after fencedPHB Error injection (LP: #1652018)
++    - powerpc/powernv: Call opal_pci_poll() if needed
++
++  * mfd: intel-lpss: Add default I2C device properties for Apollo Lake
++    (LP: #1635177)
++    - mfd: intel-lpss: Add default I2C device properties for Apollo Lake
++
++  * Xenial update to v4.4.39 stable release (LP: #1650609)
++    - powerpc/eeh: Fix deadlock when PE frozen state can't be cleared
++    - parisc: Purge TLB before setting PTE
++    - parisc: Remove unnecessary TLB purges from flush_dcache_page_asm and
++      flush_icache_page_asm
++    - parisc: Fix TLB related boot crash on SMP machines
++    - zram: restrict add/remove attributes to root only
++    - locking/rtmutex: Prevent dequeue vs. unlock race
++    - locking/rtmutex: Use READ_ONCE() in rt_mutex_owner()
++    - perf/x86: Fix full width counter, counter overflow
++    - crypto: mcryptd - Check mcryptd algorithm compatibility
++    - can: raw: raw_setsockopt: limit number of can_filter that can be set
++    - can: peak: fix bad memory access and free sequence
++    - arm64: futex.h: Add missing PAN toggling
++    - m68k: Fix ndelay() macro
++    - batman-adv: Check for alloc errors when preparing TT local data
++    - hotplug: Make register and unregister notifier API symmetric
++    - crypto: rsa - Add Makefile dependencies to fix parallel builds
++    - Linux 4.4.39
++
++  * Xenial update to v4.4.38 stable release (LP: #1650607)
++    - virtio-net: add a missing synchronize_net()
++    - net: check dead netns for peernet2id_alloc()
++    - ip6_tunnel: disable caching when the traffic class is inherited
++    - net: sky2: Fix shutdown crash
++    - af_unix: conditionally use freezable blocking calls in read
++    - rtnetlink: fix FDB size computation
++    - l2tp: fix racy SOCK_ZAPPED flag check in l2tp_ip{,6}_bind()
++    - net: dsa: bcm_sf2: Ensure we re-negotiate EEE during after link change
++    - net, sched: respect rcu grace period on cls destruction
++    - net/sched: pedit: make sure that offset is valid
++    - netlink: Call cb->done from a worker thread
++    - netlink: Do not schedule work from sk_destruct
++    - net/dccp: fix use-after-free in dccp_invalid_packet
++    - net: bcmgenet: Utilize correct struct device for all DMA operations
++    - sh_eth: remove unchecked interrupts for RZ/A1
++    - geneve: avoid use-after-free of skb->data
++    - net: ping: check minimum size on ICMP header length
++    - sparc32: Fix inverted invalid_frame_pointer checks on sigreturns
++    - sparc64: Fix find_node warning if numa node cannot be found
++    - sparc64: fix compile warning section mismatch in find_node()
++    - constify iov_iter_count() and iter_is_iovec()
++    - Don't feed anything but regular iovec's to blk_rq_map_user_iov
++    - ipv6: Set skb->protocol properly for local output
++    - ipv4: Set skb->protocol properly for local output
++    - esp4: Fix integrity verification when ESN are used
++    - esp6: Fix integrity verification when ESN are used
++    - Linux 4.4.38
++
++  * Xenial update to v4.4.37 stable release (LP: #1650604)
++    - ARC: Don't use "+l" inline asm constraint
++    - zram: fix unbalanced idr management at hot removal
++    - kasan: update kasan_global for gcc 7
++    - x86/traps: Ignore high word of regs->cs in early_fixup_exception()
++    - rcu: Fix soft lockup for rcu_nocb_kthread
++    - PCI: Export pcie_find_root_port
++    - PCI: Set Read Completion Boundary to 128 iff Root Port supports it (_HPX)
++    - mwifiex: printk() overflow with 32-byte SSIDs
++    - pwm: Fix device reference leak
++    - arm64: cpufeature: Schedule enable() calls instead of calling them via IPI
++    - arm64: mm: Set PSTATE.PAN from the cpu_enable_pan() call
++    - arm64: suspend: Reconfigure PSTATE after resume from idle
++    - Linux 4.4.37
++
++  * Xenial update to v4.4.36 stable release (LP: #1650601)
++    - iommu/vt-d: Fix PASID table allocation
++    - iommu/vt-d: Fix IOMMU lookup for SR-IOV Virtual Functions
++    - KVM: x86: check for pic and ioapic presence before use
++    - usb: chipidea: move the lock initialization to core file
++    - USB: serial: cp210x: add ID for the Zone DPMX
++    - USB: serial: ftdi_sio: add support for TI CC3200 LaunchPad
++    - Fix USB CB/CBI storage devices with CONFIG_VMAP_STACK=y
++    - scsi: mpt3sas: Fix secure erase premature termination
++    - tile: avoid using clocksource_cyc2ns with absolute cycle count
++    - cfg80211: limit scan results cache size
++    - NFSv4.x: hide array-bounds warning
++    - parisc: Fix races in parisc_setup_cache_timing()
++    - parisc: Fix race in pci-dma.c
++    - parisc: Also flush data TLB in flush_icache_page_asm
++    - mpi: Fix NULL ptr dereference in mpi_powm() [ver #3]
++    - drm/radeon: Ensure vblank interrupt is enabled on DPMS transition to on
++    - mei: me: disable driver on SPT SPS firmware
++    - mei: me: fix place for kaby point device ids.
++    - mei: fix return value on disconnection
++    - scsi: mpt3sas: Unblock device after controller reset
++    - Linux 4.4.36
++
++  * Miscellaneous Ubuntu changes
++    - [Debian] consider renames in gen-auto-reconstruct
++
++ -- John Donnelly <john.donnelly@canonical.com>  Fri, 13 Jan 2017 08:54:11 +0000
++
++linux (4.4.0-59.80) xenial; urgency=low
++
++  [ John Donnelly ]
++
++  * Release Tracking Bug
++    - LP: #1654282
++
++  * [2.1.1] MAAS has nvme0n1 set as boot disk, curtin fails (LP: #1651602)
++    - (fix) nvme: only require 1 interrupt vector, not 2+
++
++ -- John Donnelly <john.donnelly@canonical.com>  Thu, 05 Jan 2017 12:49:16 +0000
++
++linux (4.4.0-58.79) xenial; urgency=low
++
++  [ Luis Henriques ]
++
++  * Release Tracking Bug
++    - LP: #1651402
++
++  * Support ACPI probe for IIO sensor drivers from ST Micro (LP: #1650123)
++    - SAUCE: iio: st_sensors: match sensors using ACPI handle
++    - SAUCE: iio: st_accel: Support sensor i2c probe using acpi
++    - SAUCE: iio: st_pressure: Support i2c probe using acpi
++    - [Config] CONFIG_HTS221=m, CONFIG_HTS221_I2C=m, CONFIG_HTS221_SPI=m
++
++  * Fix channel data parsing in ST Micro sensor IIO drivers (LP: #1650189)
++    - SAUCE: iio: common: st_sensors: fix channel data parsing
++
++  * ST Micro lng2dm 3-axis "femto" accelerometer support (LP: #1650112)
++    - SAUCE: iio: st-accel: add support for lis2dh12
++    - SAUCE: iio: st_sensors: support active-low interrupts
++    - SAUCE: iio: accel: Add support for the h3lis331dl accelerometer
++    - SAUCE: iio: st_sensors: verify interrupt event to status
++    - SAUCE: iio: st_sensors: support open drain mode
++    - SAUCE: iio:st_sensors: fix power regulator usage
++    - SAUCE: iio: st_sensors: switch to a threaded interrupt
++    - SAUCE: iio: accel: st_accel: Add lis3l02dq support
++    - SAUCE: iio: st_sensors: fix scale configuration for h3lis331dl
++    - SAUCE: iio: accel: st_accel: add support to lng2dm
++    - SAUCE: iio: accel: st_accel: inline per-sensor data
++    - SAUCE: Documentation: dt: iio: accel: add lng2dm sensor device binding
++
++  * ST Micro hts221 relative humidity sensor support (LP: #1650116)
++    - SAUCE: iio: humidity: add support to hts221 rh/temp combo device
++    - SAUCE: Documentation: dt: iio: humidity: add hts221 sensor device binding
++    - SAUCE: iio: humidity: remove
++    - SAUCE: iio: humidity: Support acpi probe for hts211
++
++  * crypto : tolerate new crypto hardware for z Systems (LP: #1644557)
++    - s390/zcrypt: Introduce CEX6 toleration
++
++  * Acer, Inc ID 5986:055a is useless after 14.04.2 installed. (LP: #1433906)
++    - uvcvideo: uvc_scan_fallback() for webcams with broken chain
++
++  * vmxnet3 driver could causes kernel panic with v4.4 if LRO enabled.
++    (LP: #1650635)
++    - vmxnet3: segCnt can be 1 for LRO packets
++
++  * system freeze when swapping to encrypted swap partition (LP: #1647400)
++    - mm, oom: rework oom detection
++    - mm: throttle on IO only when there are too many dirty and writeback pages
++
++  * Kernel Fixes to get TCMU File Backed Optical to work (LP: #1646204)
++    - target/user: Use sense_reason_t in tcmu_queue_cmd_ring
++    - target/user: Return an error if cmd data size is too large
++    - target/user: Fix comments to not refer to data ring
++    - SAUCE: (no-up) target/user: Fix use-after-free of tcmu_cmds if they are
++      expired
++
++  * CVE-2016-9756
++    - KVM: x86: drop error recovery in em_jmp_far and em_ret_far
++
++  * Dell Precision 5520 & 3520 freezes at login screent (LP: #1650054)
++    - ACPI / blacklist: add _REV quirks for Dell Precision 5520 and 3520
++
++  * CVE-2016-9794
++    - ALSA: pcm : Call kill_fasync() in stream lock
++
++  * Allow fuse user namespace mounts by default in xenial (LP: #1634964)
++    - (namespace) mnt: Move the FS_USERNS_MOUNT check into sget_userns
++    - (namespace) Revert "UBUNTU: SAUCE: fs: Refuse uid/gid changes which don't
++      map into s_user_ns"
++    - (namespace) fs: Refuse uid/gid changes which don't map into s_user_ns
++    - (namespace) Revert "UBUNTU: SAUCE: fs: Update posix_acl support to handle
++      user namespace mounts"
++    - (namespace) vfs: Verify acls are valid within superblock's s_user_ns.
++    - SAUCE: (namespace) posix_acl: Export posix_acl_fix_xattr_userns() to modules
++    - SAUCE: (namespace) fuse: Translate ids in posix acl xattrs
++    - (namespace) vfs: Don't modify inodes with a uid or gid unknown to the vfs
++    - (namespace) vfs: Don't create inodes with a uid or gid unknown to the vfs
++    - (namespace) Revert "UBUNTU: SAUCE: quota: Require that qids passed to
++      dqget() be valid and map into s_user_ns"
++    - (namespace) Revert "UBUNTU: SAUCE: quota: Convert ids relative to s_user_ns"
++    - (namespace) quota: Ensure qids map to the filesystem
++    - (namespace) quota: Handle quota data stored in s_user_ns in quota_setxquota
++    - (namespace) dquot: For now explicitly don't support filesystems outside of
++      init_user_ns
++    - (namespace) Revert "UBUNTU: SAUCE: ima/evm: Allow root in s_user_ns to set
++      xattrs"
++    - SAUCE: (namespace) security/integrity: Harden against malformed xattrs
++    - (namespace) Revert "UBUNTU: SAUCE: fs: Allow superblock owner to change
++      ownership of inodes with unmappable ids"
++    - SAUCE: (namespace) fs: Allow superblock owner to change ownership of inodes
++    - (namespace) Revert "UBUNTU: SAUCE: fs: Don't remove suid for CAP_FSETID in
++      s_user_ns"
++    - SAUCE: (namespace) fs: Don't remove suid for CAP_FSETID for userns root
++    - SAUCE: (namespace) fuse: Allow user namespace mounts by default
++
++  * Boot crash in xen_send_IPI_one (LP: #1649821)
++    - xen/qspinlock: Don't kick CPU if IRQ is not initialized
++
++  * linux: Staging modules should be unsigned (LP: #1642368)
++    - [Debian] Suppress module signing for staging drivers
++    - SAUCE: Add rtl drivers to signature inclusion list
++
++  * Ethernet not work after upgrade from kernel 3.19 to 4.4 [10ec:8168]
++    (LP: #1648279)
++    - ACPI / blacklist: Make Dell Latitude 3350 ethernet work
++
++  * CVE-2016-9793
++    - net: avoid signed overflows for SO_{SND|RCV}BUFFORCE
++
++  * [Hyper-V] Kernel panic not functional on 32bit Ubuntu 14.10, 15.04, and
++    15.10 (LP: #1400319)
++    - Drivers: hv: avoid vfree() on crash
++
++  * [Hyper-V] netvsc: fix incorrect receive checksum offloading (LP: #1636656)
++    - netvsc: fix incorrect receive checksum offloading
++
++ -- Luis Henriques <luis.henriques@canonical.com>  Tue, 20 Dec 2016 10:54:41 +0000
++
++linux (4.4.0-57.78) xenial; urgency=low
++
++  * Release Tracking Bug
++    - LP: #1648867
++
++  * Miscellaneous Ubuntu changes
++    - SAUCE: Do not build the xr-usb-serial driver for s390
++
++ -- Brad Figg <brad.figg@canonical.com>  Fri, 09 Dec 2016 10:51:16 -0800
++
++linux (4.4.0-56.77) xenial; urgency=low
++
++  * Release Tracking Bug
++    - LP: #1648867
++
++  * Release Tracking Bug
++    - LP: #1648579
++
++  * CONFIG_NR_CPUS=256 is too low (LP: #1579205)
++    - [Config] Increase the NR_CPUS to 512 for amd64 to support systems with a
++      large number of cores.
++
++  * NVMe drives in Amazon AWS instance fail to initialize (LP: #1648449)
++    - SAUCE: (no-up) NVMe: only setup MSIX once
++
++ -- Brad Figg <brad.figg@canonical.com>  Thu, 08 Dec 2016 10:50:49 -0800
++
++linux (4.4.0-55.76) xenial; urgency=low
++
++  [ Luis Henriques ]
++
++  * Release Tracking Bug
++    - LP: #1648503
++
++  * NVMe driver accidentally reverted to use GSI instead of MSIX (LP: #1647887)
++    - (fix) NVMe: restore code to always use MSI/MSI-x interrupts
++
++ -- Luis Henriques <luis.henriques@canonical.com>  Thu, 08 Dec 2016 14:34:40 +0000
++
++linux (4.4.0-54.75) xenial; urgency=low
++
++  [ Luis Henriques ]
++
++  * Release Tracking Bug
++    - LP: #1648017
++
++  * Update hio driver to 2.1.0.28 (LP: #1646643)
++    - SAUCE: hio: update to Huawei ES3000_V2 (2.1.0.28)
++
++  * linux: Enable live patching for all supported architectures (LP: #1633577)
++    - [Config] CONFIG_LIVEPATCH=y for s390x
++
++  * Botched backport breaks level triggered EOIs in QEMU guests with --machine
++    kernel_irqchip=split (LP: #1644394)
++    - kvm/irqchip: kvm_arch_irq_routing_update renaming split
++
++  * Xenial update to v4.4.35 stable release (LP: #1645453)
++    - x86/cpu/AMD: Fix cpu_llc_id for AMD Fam17h systems
++    - KVM: x86: fix missed SRCU usage in kvm_lapic_set_vapic_addr
++    - KVM: Disable irq while unregistering user notifier
++    - fuse: fix fuse_write_end() if zero bytes were copied
++    - mfd: intel-lpss: Do not put device in reset state on suspend
++    - can: bcm: fix warning in bcm_connect/proc_register
++    - i2c: mux: fix up dependencies
++    - kbuild: add -fno-PIE
++    - scripts/has-stack-protector: add -fno-PIE
++    - x86/kexec: add -fno-PIE
++    - kbuild: Steal gcc's pie from the very beginning
++    - ext4: sanity check the block and cluster size at mount time
++    - crypto: caam - do not register AES-XTS mode on LP units
++    - drm/amdgpu: Attach exclusive fence to prime exported bo's. (v5)
++    - clk: mmp: pxa910: fix return value check in pxa910_clk_init()
++    - clk: mmp: pxa168: fix return value check in pxa168_clk_init()
++    - clk: mmp: mmp2: fix return value check in mmp2_clk_init()
++    - rtc: omap: Fix selecting external osc
++    - iwlwifi: pcie: fix SPLC structure parsing
++    - mfd: core: Fix device reference leak in mfd_clone_cell
++    - uwb: fix device reference leaks
++    - PM / sleep: fix device reference leak in test_suspend
++    - PM / sleep: don't suspend parent when async child suspend_{noirq, late}
++      fails
++    - IB/mlx4: Check gid_index return value
++    - IB/mlx4: Fix create CQ error flow
++    - IB/mlx5: Use cache line size to select CQE stride
++    - IB/mlx5: Fix fatal error dispatching
++    - IB/core: Avoid unsigned int overflow in sg_alloc_table
++    - IB/uverbs: Fix leak of XRC target QPs
++    - IB/cm: Mark stale CM id's whenever the mad agent was unregistered
++    - netfilter: nft_dynset: fix element timeout for HZ != 1000
++    - Linux 4.4.35
++
++  * Upstream stable 4.4.34 and 4.8.10 regression (LP: #1645278)
++    - flow_dissect: call init_default_flow_dissectors() earlier
++
++  * AD5593R configurable multi-channel converter support (LP: #1644726)
++    - iio: dac: Add support for the AD5592R/AD5593R ADCs/DACs
++    - iio: dac: ad5592r: Off by one bug in ad5592r_alloc_channels()
++    - [Config] CONFIG_AD5592R/AD5593R=m
++
++  * ST Micro lps22hb pressure sensor support (LP: #1642258)
++    - iio:st_pressure:initial lps22hb sensor support
++    - iio:st_pressure: align storagebits on power of 2
++    - iio:st_pressure: document sampling gains
++    - iio:st_pressure:lps22hb: temperature support
++
++  * Fix Kernel Crashing under IBM Virtual Scsi Driver (LP: #1642299)
++    - SAUCE: ibmvscsis: Rearrange functions for future patches
++    - SAUCE: ibmvscsis: Synchronize cmds at tpg_enable_store time
++    - SAUCE: ibmvscsis: Synchronize cmds at remove time
++    - SAUCE: ibmvscsis: Clean up properly if target_submit_cmd/tmr fails
++    - SAUCE: ibmvscsis: Return correct partition name/# to client
++    - SAUCE: ibmvscsis: Issues from Dan Carpenter/Smatch
++
++  * System stalls when creating device node on booting (LP: #1643797)
++    - sched/fair: Fix new task's load avg removed from source CPU in
++      wake_up_new_task()
++
++  * nvme: improve performance for virtual Google NVMe devices (LP: #1637565)
++    - blk-mq: add blk_mq_alloc_request_hctx
++    - nvme.h: add NVMe over Fabrics definitions
++    - [Config] CONFIG_NVME_VENDOR_EXT_GOOGLE=y
++    - SAUCE: nvme: improve performance for virtual NVMe devices
++
++  * Move some kernel modules to the main kernel package (LP: #1642228)
++    - [Config] Move some powerpc kernel modules to the main kernel package
++
++  * sched: Match-all classifier is missing in xenial (LP: #1642514)
++    - [Config] CONFIG_NET_CLS_MATCHALL=m
++    - net/sched: introduce Match-all classifier
++
++  * Xenial update to 4.4.34 stable release (LP: #1643637)
++    - dctcp: avoid bogus doubling of cwnd after loss
++    - net: clear sk_err_soft in sk_clone_lock()
++    - net: mangle zero checksum in skb_checksum_help()
++    - bgmac: stop clearing DMA receive control register right after it is set
++    - ip6_tunnel: Clear IP6CB in ip6tunnel_xmit()
++    - tcp: fix potential memory corruption
++    - dccp: do not send reset to already closed sockets
++    - dccp: fix out of bound access in dccp_v4_err()
++    - ipv6: dccp: fix out of bound access in dccp_v6_err()
++    - ipv6: dccp: add missing bind_conflict to dccp_ipv6_mapped
++    - sctp: assign assoc_id earlier in __sctp_connect
++    - fib_trie: Correct /proc/net/route off by one error
++    - sock: fix sendmmsg for partial sendmsg
++    - net: __skb_flow_dissect() must cap its return value
++    - ipv4: use new_gw for redirect neigh lookup
++    - tcp: take care of truncations done by sk_filter()
++    - tty: Prevent ldisc drivers from re-using stale tty fields
++    - sparc: Don't leak context bits into thread->fault_address
++    - sparc: serial: sunhv: fix a double lock bug
++    - sparc64 mm: Fix base TSB sizing when hugetlb pages are used
++    - sparc: Handle negative offsets in arch_jump_label_transform
++    - sparc64: Handle extremely large kernel TSB range flushes sanely.
++    - sparc64: Fix illegal relative branches in hypervisor patched TLB code.
++    - sparc64: Fix instruction count in comment for
++      __hypervisor_flush_tlb_pending.
++    - sparc64: Fix illegal relative branches in hypervisor patched TLB cross-call
++      code.
++    - sparc64: Handle extremely large kernel TLB range flushes more gracefully.
++    - sparc64: Delete __ret_efault.
++    - sparc64: Prepare to move to more saner user copy exception handling.
++    - sparc64: Convert copy_in_user to accurate exception reporting.
++    - sparc64: Convert GENcopy_{from,to}_user to accurate exception reporting.
++    - sparc64: Convert U1copy_{from,to}_user to accurate exception reporting.
++    - sparc64: Convert NG4copy_{from,to}_user to accurate exception reporting.
++    - sparc64: Convert NGcopy_{from,to}_user to accurate exception reporting.
++    - sparc64: Convert NG2copy_{from,to}_user to accurate exception reporting.
++    - sparc64: Convert U3copy_{from,to}_user to accurate exception reporting.
++    - sparc64: Delete now unused user copy assembler helpers.
++    - sparc64: Delete now unused user copy fixup functions.
++    - Linux 4.4.34
++
++  * Xenial update to v4.4.33 stable release (LP: #1642968)
++    - ALSA: info: Return error for invalid read/write
++    - ALSA: info: Limit the proc text input size
++    - ASoC: cs4270: fix DAPM stream name mismatch
++    - dib0700: fix nec repeat handling
++    - swapfile: fix memory corruption via malformed swapfile
++    - coredump: fix unfreezable coredumping task
++    - s390/hypfs: Use get_free_page() instead of kmalloc to ensure page alignment
++    - ARC: timer: rtc: implement read loop in "C" vs. inline asm
++    - pinctrl: cherryview: Serialize register access in suspend/resume
++    - pinctrl: cherryview: Prevent possible interrupt storm on resume
++    - staging: iio: ad5933: avoid uninitialized variable in error case
++    - drivers: staging: nvec: remove bogus reset command for PS/2 interface
++    - Revert "staging: nvec: ps2: change serio type to passthrough"
++    - staging: nvec: remove managed resource from PS2 driver
++    - USB: cdc-acm: fix TIOCMIWAIT
++    - usb: gadget: u_ether: remove interrupt throttling
++    - drbd: Fix kernel_sendmsg() usage - potential NULL deref
++    - toshiba-wmi: Fix loading the driver on non Toshiba laptops
++    - clk: qoriq: Don't allow CPU clocks higher than starting value
++    - iio: hid-sensors: Increase the precision of scale to fix wrong reading
++      interpretation.
++    - iio: orientation: hid-sensor-rotation: Add PM function (fix non working
++      driver)
++    - scsi: qla2xxx: Fix scsi scan hang triggered if adapter fails during init
++    - scsi: mpt3sas: Fix for block device of raid exists even after deleting raid
++      disk
++    - KVM: MIPS: Precalculate MMIO load resume PC
++    - drm/i915: Respect alternate_ddc_pin for all DDI ports
++    - dmaengine: at_xdmac: fix spurious flag status for mem2mem transfers
++    - tty/serial: at91: fix hardware handshake on Atmel platforms
++    - iommu/amd: Free domain id when free a domain of struct dma_ops_domain
++    - iommu/vt-d: Fix dead-locks in disable_dmar_iommu() path
++    - mei: bus: fix received data size check in NFC fixup
++    - lib/genalloc.c: start search from start of chunk
++    - hwrng: core - Don't use a stack buffer in add_early_randomness()
++    - i40e: fix call of ndo_dflt_bridge_getlink()
++    - ACPI / APEI: Fix incorrect return value of ghes_proc()
++    - ASoC: sun4i-codec: return error code instead of NULL when create_card fails
++    - mmc: mxs: Initialize the spinlock prior to using it
++    - btrfs: qgroup: Prevent qgroup->reserved from going subzero
++    - netfilter: fix namespace handling in nf_log_proc_dostring
++    - Linux 4.4.33
++
++  * Xenial update to 4.4.32 stable release (LP: #1642573)
++    - tcp: fix overflow in __tcp_retransmit_skb()
++    - net: avoid sk_forward_alloc overflows
++    - tcp: fix wrong checksum calculation on MTU probing
++    - tcp: fix a compile error in DBGUNDO()
++    - ip6_gre: fix flowi6_proto value in ip6gre_xmit_other()
++    - ipmr, ip6mr: fix scheduling while atomic and a deadlock with ipmr_get_route
++    - tg3: Avoid NULL pointer dereference in tg3_io_error_detected()
++    - net: fec: set mac address unconditionally
++    - net: pktgen: fix pkt_size
++    - net/sched: act_vlan: Push skb->data to mac_header prior calling skb_vlan_*()
++      functions
++    - net: Add netdev all_adj_list refcnt propagation to fix panic
++    - packet: call fanout_release, while UNREGISTERING a netdev
++    - netlink: do not enter direct reclaim from netlink_dump()
++    - ipv6: tcp: restore IP6CB for pktoptions skbs
++    - ip6_tunnel: fix ip6_tnl_lookup
++    - net: pktgen: remove rcu locking in pktgen_change_name()
++    - bridge: multicast: restore perm router ports on multicast enable
++    - rtnetlink: Add rtnexthop offload flag to compare mask
++    - net: add recursion limit to GRO
++    - ipv4: disable BH in set_ping_group_range()
++    - ipv4: use the right lock for ping_group_range
++    - net: sctp, forbid negative length
++    - udp: fix IP_CHECKSUM handling
++    - net sched filters: fix notification of filter delete with proper handle
++    - sctp: validate chunk len before actually using it
++    - packet: on direct_xmit, limit tso and csum to supported devices
++    - of: silence warnings due to max() usage
++    - Revert KVM: MIPS: Drop other CPU ASIDs on guest MMU changes
++    - KVM: MIPS: Drop other CPU ASIDs on guest MMU changes
++    - drm/amdgpu/dp: add back special handling for NUTMEG
++    - drm/amdgpu: fix DP mode validation
++    - drm/radeon: fix DP mode validation
++    - scsi: megaraid_sas: fix macro MEGASAS_IS_LOGICAL to avoid regression
++    - Linux 4.4.32
++
++  * Xenial update to 4.4.31 stable release (LP: #1642572)
++    - i2c: xgene: Avoid dma_buffer overrun
++    - i2c: core: fix NULL pointer dereference under race condition
++    - drm/dp/mst: Clear port->pdt when tearing down the i2c adapter
++    - h8300: fix syscall restarting
++    - libxfs: clean up _calc_dquots_per_chunk
++    - mm/list_lru.c: avoid error-path NULL pointer deref
++    - mm: memcontrol: do not recurse in direct reclaim
++    - ALSA: usb-audio: Add quirk for Syntek STK1160
++    - ALSA: hda - Merge RIRB_PRE_DELAY into CTX_WORKAROUND caps
++    - ALSA: hda - Raise AZX_DCAPS_RIRB_DELAY handling into top drivers
++    - ALSA: hda - allow 40 bit DMA mask for NVidia devices
++    - ALSA: hda - Adding a new group of pin cfg into ALC295 pin quirk table
++    - ALSA: hda - Fix headset mic detection problem for two Dell laptops
++    - ANDROID: binder: Add strong ref checks
++    - ANDROID: binder: Clear binder and cookie when setting handle in flat binder
++      struct
++    - btrfs: fix races on root_log_ctx lists
++    - ubifs: Abort readdir upon error
++    - ubifs: Fix regression in ubifs_readdir()
++    - mei: txe: don't clean an unprocessed interrupt cause.
++    - usb: gadget: function: u_ether: don't starve tx request queue
++    - USB: serial: fix potential NULL-dereference at probe
++    - USB: serial: ftdi_sio: add support for Infineon TriBoard TC2X7
++    - xhci: use default USB_RESUME_TIMEOUT when resuming ports.
++    - usb: increase ohci watchdog delay to 275 msec
++    - Fix potential infoleak in older kernels
++    - vt: clear selection before resizing
++    - xhci: add restart quirk for Intel Wildcatpoint PCH
++    - tty: limit terminal size to 4M chars
++    - USB: serial: cp210x: fix tiocmget error handling
++    - dm: free io_barrier after blk_cleanup_queue call
++    - KVM: x86: fix wbinvd_dirty_mask use-after-free
++    - KVM: MIPS: Make ERET handle ERL before EXL
++    - ovl: fsync after copy-up
++    - parisc: Ensure consistent state when switching to kernel stack at syscall
++      entry
++    - virtio_ring: Make interrupt suppression spec compliant
++    - virtio: console: Unlock vqs while freeing buffers
++    - dm mirror: fix read error on recovery after default leg failure
++    - Input: i8042 - add XMG C504 to keyboard reset table
++    - firewire: net: guard against rx buffer overflows
++    - firewire: net: fix fragmented datagram_size off-by-one
++    - mac80211: discard multicast and 4-addr A-MSDUs
++    - scsi: megaraid_sas: Fix data integrity failure for JBOD (passthrough)
++      devices
++    - scsi: scsi_debug: Fix memory leak if LBP enabled and module is unloaded
++    - scsi: arcmsr: Send SYNCHRONIZE_CACHE command to firmware
++    - mmc: dw_mmc-pltfm: fix the potential NULL pointer dereference
++    - Revert "drm/radeon: fix DP link training issue with second 4K monitor"
++    - drm/radeon/si_dpm: Limit clocks on HD86xx part
++    - drm/radeon/si_dpm: workaround for SI kickers
++    - drm/radeon: drop register readback in cayman_cp_int_cntl_setup
++    - drm/dp/mst: Check peer device type before attempting EDID read
++    - perf build: Fix traceevent plugins build race
++    - x86/xen: fix upper bound of pmd loop in xen_cleanhighmap()
++    - powerpc/ptrace: Fix out of bounds array access warning
++    - ARM: 8584/1: floppy: avoid gcc-6 warning
++    - mm/cma: silence warnings due to max() usage
++    - drm/exynos: fix error handling in exynos_drm_subdrv_open
++    - cgroup: avoid false positive gcc-6 warning
++    - smc91x: avoid self-comparison warning
++    - Disable "frame-address" warning
++    - UBI: fastmap: scrub PEB when bitflips are detected in a free PEB EC header
++    - pwm: Unexport children before chip removal
++    - usb: dwc3: Fix size used in dma_free_coherent()
++    - tty: vt, fix bogus division in csi_J
++    - kvm: x86: Check memopp before dereference (CVE-2016-8630)
++    - ubi: fastmap: Fix add_vol() return value test in ubi_attach_fastmap()
++    - HID: usbhid: add ATEN CS962 to list of quirky devices
++    - Linux 4.4.31
++
++  * CVE-2016-6213
++    - mnt: Add a per mount namespace limit on the number of mounts
++
++  * ThinkPad T460 hotkeys stop working in Ubuntu 16.04 (LP: #1642114)
++    - thinkpad_acpi: Add support for HKEY version 0x200
++
++  * CVE-2016-4568
++    - videobuf2-v4l2: Verify planes array in buffer dequeueing
++
++  * [SRU] Add 0cf3:e009 to btusb (LP: #1641562)
++    - Bluetooth: btusb: Add support for 0cf3:e009
++
++  * Fix resource leak in btusb (LP: #1641569)
++    - SAUCE: Bluetooth: decrease refcount after use
++
++  * WiFi LED doesn't work on some Edge Gateway units (LP: #1640418)
++    - SAUCE: mwifiex: Use PCI ID instead of DMI ID to identify Edge Gateways
++
++  * [Hyper-V] do not lose pending heartbeat vmbus packets (LP: #1632786)
++    - hv: do not lose pending heartbeat vmbus packets
++
++  * ipv6: connected routes are missing after a down/up cycle on the loopback
++    (LP: #1634545)
++    - ipv6: correctly add local routes when lo goes up
++
++  * audit: prevent a new auditd to stop an old auditd still alive (LP: #1633404)
++    - audit: stop an old auditd being starved out by a new auditd
++
++  * hv_set_ifconfig script parsing fails for certain configuration
++    (LP: #1640109)
++    - hv_set_ifconfig -- handle DHCP interfaces correctly
++    - hv_set_ifconfig -- ensure we include the last stanza
++
++  * CVE-2016-7039 and CVE-2016-8666 (LP: #1631287)
++    - Revert "UBUNTU: SAUCE: net: add recursion limit to GRO"
++
++ -- Luis Henriques <luis.henriques@canonical.com>  Wed, 07 Dec 2016 10:13:50 +0000
++
++linux (4.4.0-53.74) xenial; urgency=low
++
++  * CVE-2016-8655 (LP: #1646318)
++    - packet: fix race condition in packet_set_ring
++
++ -- Brad Figg <brad.figg@canonical.com>  Thu, 01 Dec 2016 10:54:01 -0800
++
++linux (4.4.0-51.72) xenial; urgency=low
++
++  [ Luis Henriques ]
++
++  * Release Tracking Bug
++    - LP: #1644611
++
++  * 4.4.0-1037-snapdragon #41: kernel panic on boot (LP: #1644596)
++    - Revert "dma-mapping: introduce the DMA_ATTR_NO_WARN attribute"
++    - Revert "powerpc: implement the DMA_ATTR_NO_WARN attribute"
++    - Revert "nvme: use the DMA_ATTR_NO_WARN attribute"
++
++ -- Luis Henriques <luis.henriques@canonical.com>  Thu, 24 Nov 2016 17:56:21 +0000
++
++linux (4.4.0-50.71) xenial; urgency=low
++
++  [ Luis Henriques ]
++
++  * Release Tracking Bug
++    - LP: #1644169
++
++  * xenial 4.4.0-49.70 kernel breaks LXD userspace (LP: #1644165)
++    - Revert "UBUNTU: SAUCE: (namespace) fuse: Allow user namespace mounts by
++      default"
++    - Revert "UBUNTU: SAUCE: (namespace) fs: Don't remove suid for CAP_FSETID for
++      userns root"
++    - Revert "(namespace) Revert "UBUNTU: SAUCE: fs: Don't remove suid for
++      CAP_FSETID in s_user_ns""
++    - Revert "UBUNTU: SAUCE: (namespace) fs: Allow superblock owner to change
++      ownership of inodes"
++    - Revert "(namespace) Revert "UBUNTU: SAUCE: fs: Allow superblock owner to
++      change ownership of inodes with unmappable ids""
++    - Revert "UBUNTU: SAUCE: (namespace) security/integrity: Harden against
++      malformed xattrs"
++    - Revert "(namespace) Revert "UBUNTU: SAUCE: ima/evm: Allow root in s_user_ns
++      to set xattrs""
++    - Revert "(namespace) dquot: For now explicitly don't support filesystems
++      outside of init_user_ns"
++    - Revert "(namespace) quota: Handle quota data stored in s_user_ns in
++      quota_setxquota"
++    - Revert "(namespace) quota: Ensure qids map to the filesystem"
++    - Revert "(namespace) Revert "UBUNTU: SAUCE: quota: Convert ids relative to
++      s_user_ns""
++    - Revert "(namespace) Revert "UBUNTU: SAUCE: quota: Require that qids passed
++      to dqget() be valid and map into s_user_ns""
++    - Revert "(namespace) vfs: Don't create inodes with a uid or gid unknown to
++      the vfs"
++    - Revert "(namespace) vfs: Don't modify inodes with a uid or gid unknown to
++      the vfs"
++    - Revert "UBUNTU: SAUCE: (namespace) fuse: Translate ids in posix acl xattrs"
++    - Revert "UBUNTU: SAUCE: (namespace) posix_acl: Export
++      posix_acl_fix_xattr_userns() to modules"
++    - Revert "(namespace) vfs: Verify acls are valid within superblock's
++      s_user_ns."
++    - Revert "(namespace) Revert "UBUNTU: SAUCE: fs: Update posix_acl support to
++      handle user namespace mounts""
++    - Revert "(namespace) fs: Refuse uid/gid changes which don't map into
++      s_user_ns"
++    - Revert "(namespace) Revert "UBUNTU: SAUCE: fs: Refuse uid/gid changes which
++      don't map into s_user_ns""
++    - Revert "(namespace) mnt: Move the FS_USERNS_MOUNT check into sget_userns"
++
++ -- Luis Henriques <luis.henriques@canonical.com>  Wed, 23 Nov 2016 10:16:31 +0000
++
++linux (4.4.0-49.70) xenial; urgency=low
++
++  [ Luis Henriques ]
++
++  * Release Tracking Bug
++    - LP: #1640921
++
++  * Infiniband driver (kernel module) needed for Azure (LP: #1641139)
++    - SAUCE: RDMA Infiniband for Windows Azure
++    - [Config] CONFIG_HYPERV_INFINIBAND_ND=m
++    - SAUCE: Makefile RDMA infiniband driver for Windows Azure
++    - [Config] Add hv_network_direct.ko to generic inclusion list
++    - SAUCE: RDMA Infiniband for Windows Azure is dependent on amd64
++
++ -- Luis Henriques <luis.henriques@canonical.com>  Fri, 11 Nov 2016 15:36:20 +0000
++
++linux (4.4.0-48.69) xenial; urgency=low
++
++  [ Luis Henriques ]
++
++  * Release Tracking Bug
++    - LP: #1640758
++
++  * lxc-attach to malicious container allows access to host (LP: #1639345)
++    - Revert "UBUNTU: SAUCE: (noup) ptrace: being capable wrt a process requires
++      mapped uids/gids"
++    - (upstream) mm: Add a user_ns owner to mm_struct and fix ptrace permission
++      checks
++
++  * take 'P' command from upstream xmon (LP: #1637978)
++    - powerpc/xmon: Add xmon command to dump process/task similar to ps(1)
++
++  * zfs: importing zpool with vdev on zvol hangs kernel (LP: #1636517)
++    - SAUCE: (noup) Update zfs to 0.6.5.6-0ubuntu15
++
++  * I2C touchpad does not work on AMD platform (LP: #1612006)
++    - pinctrl/amd: Configure GPIO register using BIOS settings
++    - pinctrl/amd: switch to using a bool for level
++
++  * [LTCTest] vfio_pci not loaded on Ubuntu 16.10 by default (LP: #1636733)
++    - [Config] CONFIG_VFIO_PCI=y for ppc64el
++
++  * QEMU throws failure msg while booting guest with SRIOV VF (LP: #1630554)
++    - KVM: PPC: Always select KVM_VFIO, plus Makefile cleanup
++
++  * Allow fuse user namespace mounts by default in xenial (LP: #1634964)
++    - (namespace) mnt: Move the FS_USERNS_MOUNT check into sget_userns
++    - (namespace) Revert "UBUNTU: SAUCE: fs: Refuse uid/gid changes which don't
++      map into s_user_ns"
++    - (namespace) fs: Refuse uid/gid changes which don't map into s_user_ns
++    - (namespace) Revert "UBUNTU: SAUCE: fs: Update posix_acl support to handle
++      user namespace mounts"
++    - (namespace) vfs: Verify acls are valid within superblock's s_user_ns.
++    - SAUCE: (namespace) posix_acl: Export posix_acl_fix_xattr_userns() to modules
++    - SAUCE: (namespace) fuse: Translate ids in posix acl xattrs
++    - (namespace) vfs: Don't modify inodes with a uid or gid unknown to the vfs
++    - (namespace) vfs: Don't create inodes with a uid or gid unknown to the vfs
++    - (namespace) Revert "UBUNTU: SAUCE: quota: Require that qids passed to
++      dqget() be valid and map into s_user_ns"
++    - (namespace) Revert "UBUNTU: SAUCE: quota: Convert ids relative to s_user_ns"
++    - (namespace) quota: Ensure qids map to the filesystem
++    - (namespace) quota: Handle quota data stored in s_user_ns in quota_setxquota
++    - (namespace) dquot: For now explicitly don't support filesystems outside of
++      init_user_ns
++    - (namespace) Revert "UBUNTU: SAUCE: ima/evm: Allow root in s_user_ns to set
++      xattrs"
++    - SAUCE: (namespace) security/integrity: Harden against malformed xattrs
++    - (namespace) Revert "UBUNTU: SAUCE: fs: Allow superblock owner to change
++      ownership of inodes with unmappable ids"
++    - SAUCE: (namespace) fs: Allow superblock owner to change ownership of inodes
++    - (namespace) Revert "UBUNTU: SAUCE: fs: Don't remove suid for CAP_FSETID in
++      s_user_ns"
++    - SAUCE: (namespace) fs: Don't remove suid for CAP_FSETID for userns root
++    - SAUCE: (namespace) fuse: Allow user namespace mounts by default
++
++  * [Feature] KBL - New device ID for Kabypoint(KbP) (LP: #1591618)
++    - SAUCE: mfd: lpss: Fix Intel Kaby Lake PCH-H properties
++
++  * hio: SSD data corruption under stress test (LP: #1638700)
++    - SAUCE: hio: set bi_error field to signal an I/O error on a BIO
++    - SAUCE: hio: splitting bio in the entry of .make_request_fn
++
++  * Module sha1-mb fails to load (LP: #1637165)
++    - crypto: sha-mb - Fix load failure
++    - crypto: mcryptd - Fix load failure
++
++  * please include mlx5_core modules in linux-image-generic package
++    (LP: #1635223)
++    - [Config] Include mlx5 in main package
++
++  * xgene i2c slimpro driver fails to load (LP: #1625232)
++    - mailbox: Add support for APM X-Gene platform mailbox driver
++    - mailbox/xgene-slimpro: Checking for IS_ERR instead of NULL
++    - mailbox: xgene-slimpro: Fix wrong test for devm_kzalloc
++    - [Config] Enabled XGENE_SLIMPRO_MBOX as a module
++
++  * [Dell][XPS]Touchscreen fails to function after resume from s3 by Lid
++    close/open (LP: #1632527)
++    - gpio/pinctrl: sunxi: stop poking around in private vars
++    - pinctrl: intel: Only restore pins that are used by the driver
++
++  * Xenial update to v4.4.30 stable release (LP: #1638272)
++    - Revert "x86/mm: Expand the exception table logic to allow new handling
++      options"
++    - Revert "fix minor infoleak in get_user_ex()"
++    - Linux 4.4.30
++
++  * Xenial update to v4.4.29 stable release (LP: #1638267)
++    - drm/prime: Pass the right module owner through to dma_buf_export()
++    - drm/amdgpu: fix IB alignment for UVD
++    - drm/amdgpu/dce10: disable hpd on local panels
++    - drm/amdgpu/dce8: disable hpd on local panels
++    - drm/amdgpu/dce11: disable hpd on local panels
++    - drm/amdgpu/dce11: add missing drm_mode_config_cleanup call
++    - drm/amdgpu: change vblank_time's calculation method to reduce computational
++      error.
++    - drm/radeon: narrow asic_init for virtualization
++    - drm/radeon/si/dpm: fix phase shedding setup
++    - drm/radeon: change vblank_time's calculation method to reduce computational
++      error.
++    - drm/vmwgfx: Limit the user-space command buffer size
++    - drm/i915/gen9: fix the WaWmMemoryReadLatency implementation
++    - Revert "drm/i915: Check live status before reading edid"
++    - drm/i915: Account for TSEG size when determining 865G stolen base
++    - drm/i915: Unalias obj->phys_handle and obj->userptr
++    - mm/hugetlb: fix memory offline with hugepage size > memory block size
++    - posix_acl: Clear SGID bit when setting file permissions
++    - ipip: Properly mark ipip GRO packets as encapsulated.
++    - powerpc/eeh: Null check uses of eeh_pe_bus_get
++    - perf stat: Fix interval output values
++    - genirq/generic_chip: Add irq_unmap callback
++    - uio: fix dmem_region_start computation
++    - ARM: clk-imx35: fix name for ckil clk
++    - spi: spi-fsl-dspi: Drop extra spi_master_put in device remove function
++    - mwifiex: correct aid value during tdls setup
++    - crypto: gcm - Fix IV buffer size in crypto_gcm_setkey
++    - crypto: arm/ghash-ce - add missing async import/export
++    - hwrng: omap - Only fail if pm_runtime_get_sync returns < 0
++    - ASoC: topology: Fix error return code in soc_tplg_dapm_widget_create()
++    - ASoC: dapm: Fix possible uninitialized variable in snd_soc_dapm_get_volsw()
++    - ASoC: dapm: Fix value setting for _ENUM_DOUBLE MUX's second channel
++    - ASoC: dapm: Fix kcontrol creation for output driver widget
++    - staging: r8188eu: Fix scheduling while atomic splat
++    - power: bq24257: Fix use of uninitialized pointer bq->charger
++    - dmaengine: ipu: remove bogus NO_IRQ reference
++    - x86/mm: Expand the exception table logic to allow new handling options
++    - s390/cio: fix accidental interrupt enabling during resume
++    - s390/con3270: fix use of uninitialised data
++    - s390/con3270: fix insufficient space padding
++    - clk: qoriq: fix a register offset error
++    - clk: divider: Fix clk_divider_round_rate() to use clk_readl()
++    - perf hists browser: Fix event group display
++    - perf symbols: Check symbol_conf.allow_aliases for kallsyms loading too
++    - perf symbols: Fixup symbol sizes before picking best ones
++    - mpt3sas: Don't spam logs if logging level is 0
++    - powerpc/nvram: Fix an incorrect partition merge
++    - ARM: pxa: pxa_cplds: fix interrupt handling
++    - Linux 4.4.29
++
++  * KVM: PPC: Book3S HV: Migrate pinned pages out of CMA (LP: #1632045)
++    - KVM: PPC: Book3S HV: Migrate pinned pages out of CMA
++
++  * Xenial update to v4.4.28 stable release (LP: #1637510)
++    - gpio: mpc8xxx: Correct irq handler function
++    - mei: me: add kaby point device ids
++    - regulator: tps65910: Work around silicon erratum SWCZ010
++    - clk: imx6: initialize GPU clocks
++    - PM / devfreq: event: remove duplicate devfreq_event_get_drvdata()
++    - rtlwifi: Fix missing country code for Great Britain
++    - mmc: block: don't use CMD23 with very old MMC cards
++    - mmc: sdhci: cast unsigned int to unsigned long long to avoid unexpeted error
++    - PCI: Mark Atheros AR9580 to avoid bus reset
++    - platform: don't return 0 from platform_get_irq[_byname]() on error
++    - cpufreq: intel_pstate: Fix unsafe HWP MSR access
++    - parisc: Increase KERNEL_INITIAL_SIZE for 32-bit SMP kernels
++    - parisc: Fix kernel memory layout regarding position of __gp
++    - parisc: Increase initial kernel mapping size
++    - pstore/ramoops: fixup driver removal
++    - pstore/core: drop cmpxchg based updates
++    - pstore/ram: Use memcpy_toio instead of memcpy
++    - pstore/ram: Use memcpy_fromio() to save old buffer
++    - perf intel-pt: Fix snapshot overlap detection decoder errors
++    - perf intel-pt: Fix estimated timestamps for cycle-accurate mode
++    - perf intel-pt: Fix MTC timestamp calculation for large MTC periods
++    - dm: mark request_queue dead before destroying the DM device
++    - dm: return correct error code in dm_resume()'s retry loop
++    - dm mpath: check if path's request_queue is dying in activate_path()
++    - dm crypt: fix crash on exit
++    - powerpc/vdso64: Use double word compare on pointers
++    - powerpc/powernv: Pass CPU-endian PE number to opal_pci_eeh_freeze_clear()
++    - powerpc/powernv: Use CPU-endian hub diag-data type in
++      pnv_eeh_get_and_dump_hub_diag()
++    - powerpc/powernv: Use CPU-endian PEST in pnv_pci_dump_p7ioc_diag_data()
++    - ubi: Deal with interrupted erasures in WL
++    - zfcp: fix fc_host port_type with NPIV
++    - zfcp: fix ELS/GS request&response length for hardware data router
++    - zfcp: close window with unblocked rport during rport gone
++    - zfcp: retain trace level for SCSI and HBA FSF response records
++    - zfcp: restore: Dont use 0 to indicate invalid LUN in rec trace
++    - zfcp: trace on request for open and close of WKA port
++    - zfcp: restore tracing of handle for port and LUN with HBA records
++    - zfcp: fix D_ID field with actual value on tracing SAN responses
++    - zfcp: fix payload trace length for SAN request&response
++    - zfcp: trace full payload of all SAN records (req,resp,iels)
++    - scsi: zfcp: spin_lock_irqsave() is not nestable
++    - fbdev/efifb: Fix 16 color palette entry calculation
++    - ovl: Fix info leak in ovl_lookup_temp()
++    - ovl: copy_up_xattr(): use strnlen
++    - mb86a20s: fix the locking logic
++    - mb86a20s: fix demod settings
++    - cx231xx: don't return error on success
++    - cx231xx: fix GPIOs for Pixelview SBTVD hybrid
++    - ALSA: hda - Fix a failure of micmute led when having multi adcs
++    - MIPS: Fix -mabi=64 build of vdso.lds
++    - MIPS: ptrace: Fix regs_return_value for kernel context
++    - lib: move strtobool() to kstrtobool()
++    - lib: update single-char callers of strtobool()
++    - lib: add "on"/"off" support to kstrtobool
++    - Input: i8042 - skip selftest on ASUS laptops
++    - Input: elantech - force needed quirks on Fujitsu H760
++    - Input: elantech - add Fujitsu Lifebook E556 to force crc_enabled
++    - sunrpc: fix write space race causing stalls
++    - NFSv4: Don't report revoked delegations as valid in nfs_have_delegation()
++    - NFSv4: nfs4_copy_delegation_stateid() must fail if the delegation is invalid
++    - NFSv4: Open state recovery must account for file permission changes
++    - NFSv4.2: Fix a reference leak in nfs42_proc_layoutstats_generic
++    - scsi: Fix use-after-free
++    - metag: Only define atomic_dec_if_positive conditionally
++    - mm: filemap: don't plant shadow entries without radix tree node
++    - ipc/sem.c: fix complex_count vs. simple op race
++    - arc: don't leak bits of kernel stack into coredump
++    - fs/super.c: fix race between freeze_super() and thaw_super()
++    - cifs: Limit the overall credit acquired
++    - fs/cifs: keep guid when assigning fid to fileinfo
++    - Clarify locking of cifs file and tcon structures and make more granular
++    - Display number of credits available
++    - Set previous session id correctly on SMB3 reconnect
++    - SMB3: GUIDs should be constructed as random but valid uuids
++    - Do not send SMB3 SET_INFO request if nothing is changing
++    - Cleanup missing frees on some ioctls
++    - blkcg: Unlock blkcg_pol_mutex only once when cpd == NULL
++    - x86/e820: Don't merge consecutive E820_PRAM ranges
++    - kvm: x86: memset whole irq_eoi
++    - irqchip/gicv3: Handle loop timeout proper
++    - sd: Fix rw_max for devices that report an optimal xfer size
++    - hpsa: correct skipping masked peripherals
++    - PKCS#7: Don't require SpcSpOpusInfo in Authenticode pkcs7 signatures
++    - bnx2x: Prevent false warning for lack of FC NPIV
++    - net/mlx4_core: Allow resetting VF admin mac to zero
++    - acpi, nfit: check for the correct event code in notifications
++    - mm: workingset: fix crash in shadow node shrinker caused by
++      replace_page_cache_page()
++    - mm: filemap: fix mapping->nrpages double accounting in fuse
++    - Using BUG_ON() as an assert() is _never_ acceptable
++    - s390/mm: fix gmap tlb flush issues
++    - irqchip/gic-v3-its: Fix entry size mask for GITS_BASER
++    - isofs: Do not return EACCES for unknown filesystems
++    - memstick: rtsx_usb_ms: Runtime resume the device when polling for cards
++    - memstick: rtsx_usb_ms: Manage runtime PM when accessing the device
++    - arm64: percpu: rewrite ll/sc loops in assembly
++    - arm64: kernel: Init MDCR_EL2 even in the absence of a PMU
++    - ceph: fix error handling in ceph_read_iter
++    - powerpc/mm: Prevent unlikely crash in copro_calculate_slb()
++    - mmc: core: Annotate cmd_hdr as __le32
++    - mmc: rtsx_usb_sdmmc: Avoid keeping the device runtime resumed when unused
++    - mmc: rtsx_usb_sdmmc: Handle runtime PM while changing the led
++    - ext4: do not advertise encryption support when disabled
++    - jbd2: fix incorrect unlock on j_list_lock
++    - ubifs: Fix xattr_names length in exit paths
++    - target: Re-add missing SCF_ACK_KREF assignment in v4.1.y
++    - target: Make EXTENDED_COPY 0xe4 failure return COPY TARGET DEVICE NOT
++      REACHABLE
++    - target: Don't override EXTENDED_COPY xcopy_pt_cmd SCSI status code
++    - Linux 4.4.28
++
++  * Xenial update to v4.4.27 stable release (LP: #1637501)
++    - serial: 8250_dw: Check the data->pclk when get apb_pclk
++    - btrfs: assign error values to the correct bio structs
++    - drivers: base: dma-mapping: page align the size when unmap_kernel_range
++    - fuse: listxattr: verify xattr list
++    - fuse: invalidate dir dentry after chmod
++    - fuse: fix killing s[ug]id in setattr
++    - i40e: avoid NULL pointer dereference and recursive errors on early PCI error
++    - brcmfmac: fix memory leak in brcmf_fill_bss_param
++    - ASoC: Intel: Atom: add a missing star in a memcpy call
++    - reiserfs: Unlock superblock before calling reiserfs_quota_on_mount()
++    - reiserfs: switch to generic_{get,set,remove}xattr()
++    - async_pq_val: fix DMA memory leak
++    - scsi: arcmsr: Simplify user_len checking
++    - ext4: enforce online defrag restriction for encrypted files
++    - ext4: reinforce check of i_dtime when clearing high fields of uid and gid
++    - ext4: fix memory leak in ext4_insert_range()
++    - ext4: allow DAX writeback for hole punch
++    - ext4: release bh in make_indexed_dir
++    - dlm: free workqueues after the connections
++    - vfs: move permission checking into notify_change() for utimes(NULL)
++    - cfq: fix starvation of asynchronous writes
++    - Linux 4.4.27
++
++  * Xenial update to v4.4.26 stable release (LP: #1637500)
++    - x86/build: Build compressed x86 kernels as PIE
++    - Linux 4.4.26
++
++  * ISST-LTE:pVM nvme 0000:a0:00.0: iommu_alloc failed on NVMe card
++    (LP: #1633128)
++    - dma-mapping: introduce the DMA_ATTR_NO_WARN attribute
++    - powerpc: implement the DMA_ATTR_NO_WARN attribute
++    - nvme: use the DMA_ATTR_NO_WARN attribute
++
++  * CVE-2016-8658
++    - brcmfmac: avoid potential stack overflow in brcmf_cfg80211_start_ap()
++
++  * Hotkey doesn't work on HP x360 (LP: #1620979)
++    - gpiolib: Make it possible to exclude GPIOs from IRQ domain
++    - pinctrl: cherryview: Do not mask all interrupts in probe
++    - pinctrl: cherryview: Do not add all southwest and north GPIOs to IRQ domain
++
++  * Bad page state in process genwqe_gunzip pfn:3c275 in the genwqe device
++    driver (LP: #1559194)
++    - SAUCE: (noup) Bad page state in process genwqe_gunzip pfn:3c275 in the
++      genwqe device driver
++
++  * CVE-2016-7425
++    - scsi: arcmsr: Buffer overflow in arcmsr_iop_message_xfer()
++
++  * Add ipvlan module to 16.04 kernel (LP: #1634705)
++    - [Config] Add ipvlan to the generic inclusion list
++
++  * kernel generates ACPI Exception: AE_NOT_FOUND, Evaluating _DOD incorrectly
++    (LP: #1634607)
++    - ACPI / video: skip evaluating _DOD when it does not exist
++
++  * BT still shows off after resume by wireless hotkey (LP: #1634380)
++    - Bluetooth: btusb: Fix atheros firmware download error
++
++  * ghash-clmulni-intel module fails to load (LP: #1633058)
++    - crypto: ghash-clmulni - Fix load failure
++    - crypto: cryptd - Assign statesize properly
++
++  * Xenial update to v4.4.25 stable release (LP: #1634153)
++    - timekeeping: Fix __ktime_get_fast_ns() regression
++    - ALSA: ali5451: Fix out-of-bound position reporting
++    - ALSA: usb-audio: Extend DragonFly dB scale quirk to cover other variants
++    - ALSA: usb-line6: use the same declaration as definition in header for MIDI
++      manufacturer ID
++    - mfd: rtsx_usb: Avoid setting ucr->current_sg.status
++    - mfd: atmel-hlcdc: Do not sleep in atomic context
++    - mfd: 88pm80x: Double shifting bug in suspend/resume
++    - mfd: wm8350-i2c: Make sure the i2c regmap functions are compiled
++    - KVM: PPC: Book3s PR: Allow access to unprivileged MMCR2 register
++    - KVM: MIPS: Drop other CPU ASIDs on guest MMU changes
++    - KVM: PPC: BookE: Fix a sanity check
++    - x86/boot: Fix kdump, cleanup aborted E820_PRAM max_pfn manipulation
++    - x86/irq: Prevent force migration of irqs which are not in the vector domain
++    - x86/dumpstack: Fix x86_32 kernel_stack_pointer() previous stack access
++    - ARM: dts: mvebu: armada-390: add missing compatibility string and bracket
++    - ARM: dts: MSM8064 remove flags from SPMI/MPP IRQs
++    - ARM: cpuidle: Fix error return code
++    - ima: use file_dentry()
++    - tpm: fix a race condition in tpm2_unseal_trusted()
++    - tpm_crb: fix crb_req_canceled behavior
++    - Linux 4.4.25
++
++  * backport fwts UEFI test driver to Xenial (LP: #1633506)
++    - efi: Add efi_test driver for exporting UEFI runtime service interfaces
++    - [Config] CONFIG_EFI_TEST=m
++
++  * Fix alps driver for multitouch function. (LP: #1633321)
++    - HID: alps: fix multitouch cursor issue
++
++  * xgene merlin crashes when running as iperf server (LP: #1632739)
++    - drivers: net: xgene: optimizing the code
++    - xgene: get_phy_device() doesn't return NULL anymore
++    - drivers: net: xgene: Get channel number from device binding
++    - drivers: net: xgene: constify xgene_cle_ops structure
++    - drivers: net: xgene: Fix error handling
++    - drivers: net: xgene: fix IPv4 forward crash
++    - drivers: net: xgene: fix sharing of irqs
++    - drivers: net: xgene: fix ununiform latency across queues
++    - drivers: net: xgene: fix statistics counters race condition
++    - drivers: net: xgene: fix register offset
++    - drivers: net: xgene: Separate set_speed from mac_init
++    - drivers: net: xgene: Fix module unload crash - hw resource cleanup
++    - drivers: net: xgene: Fix module unload crash - change sw sequence
++    - drivers: net: xgene: Fix module unload crash - clkrst sequence
++    - drivers: net: phy: xgene: Add MDIO driver
++    - drivers: net: xgene: Add backward compatibility
++    - drivers: net: xgene: Enable MDIO driver
++    - drivers: net: xgene: Use exported functions
++    - drivers: net: xgene: ethtool: Use phy_ethtool_gset and sset
++    - dtb: xgene: Add MDIO node
++    - MAINTAINERS: xgene: Add driver and documentation path
++    - [Config] Enable MDIO_XGENE as a modules
++
++  * Add support for KabeLake i219-LOM chips (LP: #1632578)
++    - e1000e: Initial support for KabeLake
++
++ -- Luis Henriques <luis.henriques@canonical.com>  Thu, 10 Nov 2016 11:08:11 +0000
++
++linux (4.4.0-47.68) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1636941
++
++  * Add a driver for Amazon Elastic Network Adapters (ENA) (LP: #1635721)
++    - lib/bitmap.c: conversion routines to/from u32 array
++    - net: ethtool: add new ETHTOOL_xLINKSETTINGS API
++    - net: ena: Add a driver for Amazon Elastic Network Adapters (ENA)
++    - [config] enable CONFIG_ENA_ETHERNET=m (Amazon ENA driver)
++
++  * unexpectedly large memory usage of mounted snaps (LP: #1636847)
++    - [Config] switch squashfs to single threaded decode
++
++ -- Kamal Mostafa <kamal@canonical.com>  Wed, 26 Oct 2016 10:47:55 -0700
++
++linux (4.4.0-46.67) xenial; urgency=low
++
++  [ Seth Forshee ]
++
++  * Release Tracking Bug
++    - LP: #1635242
++
++  * proc_keys_show crash when reading /proc/keys (LP: #1634496)
++    - SAUCE: KEYS: ensure xbuf is large enough to fix buffer overflow in
++      proc_keys_show (LP: #1634496)
++
++  * [Trusty->Yakkety] powerpc/64: Fix incorrect return value from
++    __copy_tofrom_user (LP: #1632462)
++    - SAUCE: (no-up) powerpc/64: Fix incorrect return value from
++      __copy_tofrom_user
++
++  * Ubuntu 16.10: Oops panic in move_page_tables/page_remove_rmap after running
++    memory_stress_ng. (LP: #1628976)
++    - SAUCE: (no-up) powerpc/pseries: Fix stack corruption in htpe code
++
++  * Paths not failed properly when unmapping virtual FC ports in VIOS (using
++    ibmvfc) (LP: #1632116)
++    - scsi: ibmvfc: Fix I/O hang when port is not mapped
++
++  * PSL data cache should be flushed before resetting CAPI adapter
++    (LP: #1632049)
++    - cxl: Flush PSL cache before resetting the adapter
++
++  * thunder nic: avoid link delays due to RX_PACKET_DIS (LP: #1630038)
++    - net: thunderx: Don't set RX_PACKET_DIS while initializing
++
++  * Support snaps inside of lxd containers (LP: #1611078)
++    - Revert "UBUNTU: SAUCE: apparmor: fix sleep in critical section"
++    - SAUCE: (no-up) apparmor: sync of apparmor 3.6 (from Ubuntu 16.10)
++
++  * crypto/vmx/p8_ghash memory corruption (LP: #1630970)
++    - crypto: ghash-generic - move common definitions to a new header file
++    - crypto: vmx - Fix memory corruption caused by p8_ghash
++    - crypto: vmx - Ensure ghash-generic is enabled
++
++  * Xenial update to v4.4.24 stable release (LP: #1631468)
++    - cpuset: handle race between CPU hotplug and cpuset_hotplug_work
++    - mtd: nand: davinci: Reinitialize the HW ECC engine in 4bit hwctl
++    - mm,ksm: fix endless looping in allocating memory when ksm enable
++    - can: dev: fix deadlock reported after bus-off
++    - x86/init: Fix cr4_init_shadow() on CR4-less machines
++    - x86/boot: Initialize FPU and X86_FEATURE_ALWAYS even if we don't have CPUID
++    - drm/nouveau/fifo/nv04: avoid ramht race against cookie insertion
++    - drm/radeon/si/dpm: add workaround for for Jet parts
++    - ARM: 8616/1: dt: Respect property size when parsing CPUs
++    - ARM: 8617/1: dma: fix dma_max_pfn()
++    - usb: musb: Fix DMA desired mode for Mentor DMA engine
++    - usb: musb: fix DMA for host mode
++    - iwlwifi: mvm: fix a few firmware capability checks
++    - perf/core: Fix pmu::filter_match for SW-led groups
++    - i40e: avoid null pointer dereference
++    - pinctrl: uniphier: fix .pin_dbg_show() callback
++    - pinctrl: Flag strict is a field in struct pinmux_ops
++    - drivers/perf: arm_pmu: Fix leak in error path
++    - mmc: pxamci: fix potential oops
++    - tools/vm/slabinfo: fix an unintentional printf
++    - ipvs: fix bind to link-local mcast IPv6 address in backup
++    - nvmem: Declare nvmem_cell_read() consistently
++    - hwmon: (adt7411) set bit 3 in CFG1 register
++    - spi: sh-msiof: Avoid invalid clock generator parameters
++    - iwlwifi: pcie: fix access to scratch buffer
++    - iwlwifi: mvm: don't use ret when not initialised
++    - ceph: fix race during filling readdir cache
++    - usb: gadget: fsl_qe_udc: signedness bug in qe_get_frame()
++    - gpio: sa1100: fix irq probing for ucb1x00
++    - irqchip/gicv3: Silence noisy DEBUG_PER_CPU_MAPS warning
++    - ARM: 8618/1: decompressor: reset ttbcr fields to use TTBR0 on ARMv7
++    - arm64: debug: avoid resetting stepping state machine when TIF_SINGLESTEP
++    - MIPS: uprobes: remove incorrect set_orig_insn
++    - MIPS: fix uretprobe implementation
++    - MIPS: Malta: Fix IOCU disable switch read for MIPS64
++    - MIPS: uprobes: fix use of uninitialised variable
++    - printk: fix parsing of "brl=" option
++    - tpm: fix byte-order for the value read by tpm2_get_tpm_pt
++    - regulator: qcom_spmi: Add support for S4 supply on pm8941
++    - regulator: qcom_spmi: Add support for get_mode/set_mode on switches
++    - regulator: qcom_spmi: Update mvs1/mvs2 switches on pm8941
++    - regulator: qcom_smd: Fix voltage ranges for pm8x41
++    - ARM: sun5i: Fix typo in trip point temperature
++    - ARM: sa1100: register clocks early
++    - ARM: sa1100: fix 3.6864MHz clock
++    - ARM: sa1100: clear reset status prior to reboot
++    - ARM: shmobile: fix regulator quirk for Gen2
++    - ARM: sa1111: fix pcmcia suspend/resume
++    - hwrng: omap - Fix assumption that runtime_get_sync will always succeed
++    - blk-mq: actually hook up defer list when running requests
++    - pstore: drop file opened reference count
++    - tile: Define AT_VECTOR_SIZE_ARCH for ARCH_DLINFO
++    - iwlmvm: mvm: set correct state in smart-fifo configuration
++    - NFC: fdp: Detect errors from fdp_nci_create_conn()
++    - em28xx-i2c: rt_mutex_trylock() returns zero on failure
++    - gspca: avoid unused variable warnings
++    - ath9k: Fix programming of minCCA power threshold
++    - avr32: off by one in at32_init_pio()
++    - fnic: pci_dma_mapping_error() doesn't return an error code
++    - dmaengine: at_xdmac: fix debug string
++    - svc: Avoid garbage replies when pc_func() returns rpc_drop_reply
++    - NFS: Don't drop CB requests with invalid principals
++    - pNFS/files: Fix layoutcommit after a commit to DS
++    - pNFS/flexfiles: Fix layoutcommit after a commit to DS
++    - ASoC: Intel: Skylake: Fix error return code in skl_probe()
++    - brcmfmac: Fix glob_skb leak in brcmf_sdiod_recv_chain
++    - brcmsmac: Free packet if dma_mapping_error() fails in dma_rxfill
++    - brcmsmac: Initialize power in brcms_c_stf_ss_algo_channel_get()
++    - powerpc/prom: Fix sub-processor option passed to ibm, client-architecture-
++      support
++    - sysctl: handle error writing UINT_MAX to u32 fields
++    - ASoC: omap-mcpdm: Fix irq resource handling
++    - kernel/fork: fix CLONE_CHILD_CLEARTID regression in nscd
++    - dmaengine: at_xdmac: fix to pass correct device identity to free_irq()
++    - KVM: nVMX: postpone VMCS changes on MSR_IA32_APICBASE write
++    - IB/ipoib: Fix memory corruption in ipoib cm mode connect flow
++    - IB/core: Fix use after free in send_leave function
++    - IB/ipoib: Don't allow MC joins during light MC flush
++    - IB/mlx4: Fix incorrect MC join state bit-masking on SR-IOV
++    - IB/mlx4: Fix code indentation in QP1 MAD flow
++    - IB/mlx4: Use correct subnet-prefix in QP1 mads under SR-IOV
++    - batman-adv: remove unused callback from batadv_algo_ops struct
++    - aio: mark AIO pseudo-fs noexec
++    - clk: xgene: Add missing parenthesis when clearing divider value
++    - dm log writes: fix bug with too large bios
++    - USB: serial: cp210x: fix hardware flow-control disable
++    - usb: misc: legousbtower: Fix NULL pointer deference
++    - Staging: fbtft: Fix bug in fbtft-core
++    - USB: serial: cp210x: Add ID for a Juniper console
++    - Revert "usbtmc: convert to devm_kzalloc"
++    - ALSA: hda - Adding one more ALC255 pin definition for headset problem
++    - ACPICA: acpi_get_sleep_type_data: Reduce warnings
++    - ALSA: hda - Fix headset mic detection problem for several Dell laptops
++    - ALSA: hda - Add the top speaker pin config for HP Spectre x360
++    - Linux 4.4.24
++
++  * sha1-powerpc returning wrong results (LP: #1629977)
++    - crypto: sha1-powerpc - little-endian support
++
++  *  Dell Precision Trackpoint not working after suspend (LP: #1630857)
++    - HID: alps: fix stick device not working after resume
++
++  * OOPS on beaglebone on boot of 4.4.0-36-generic under snappy ubuntu core
++    xenial (LP: #1625177)
++    - net: ethernet: ti: cpdma: fix lockup in cpdma_ctlr_destroy()
++    - drivers: net: cpsw: fix wrong regs access in cpsw_remove
++    - drivers: net: cpsw: use of_platform_depopulate()
++    - ARM: OMAP2+: omap_device: fix crash on omap_device removal
++    - ARM: OMAP2+: Fix omap_device for module reload on PM runtime forbid
++    - ARM: OMAP2+: Fix typo in omap_device.c
++    - drivers: net: cpsw: fix suspend when all ethX devices are down
++    - drivers: net: cpsw: fix wrong regs access in cpsw_ndo_open
++    - drivers: net: cpsw: check return code from pm runtime calls
++    - drivers: net: cpsw: remove pm runtime calls from suspend callbacks
++    - drivers: net: cpsw: ethtool: fix accessing to suspended device
++    - drivers: net: cpsw: ndev: fix accessing to suspended device
++    - drivers: net: cpsw: fix kmemleak false-positive reports for sk buffers
++
++  * Autofs parameter substitution broken in kernel 4.4.0-38 and 4.4.0-40
++    (LP: #1629204)
++    - SAUCE: (namespace) autofs4: Use real_cred for requestor's ids
++
++  * Xenial update to v4.4.23 stable release (LP: #1629386)
++    - include/linux/kernel.h: change abs() macro so it uses consistent return type
++    - Fix build warning in kernel/cpuset.c
++    - reiserfs: fix "new_insert_key may be used uninitialized ..."
++    - ipv4: panic in leaf_walk_rcu due to stale node pointer
++    - ipv6: release dst in ping_v6_sendmsg
++    - tcp: cwnd does not increase in TCP YeAH
++    - tcp: properly scale window in tcp_v[46]_reqsk_send_ack()
++    - crypto: arm64/aes-ctr - fix NULL dereference in tail processing
++    - crypto: arm/aes-ctr - fix NULL dereference in tail processing
++    - crypto: skcipher - Fix blkcipher walk OOM crash
++    - crypto: echainiv - Replace chaining with multiplication
++    - ocfs2/dlm: fix race between convert and migration
++    - ocfs2: fix start offset to ocfs2_zero_range_for_truncate()
++    - kbuild: Do not run modules_install and install in paralel
++    - Makefile: revert "Makefile: Document ability to make file.lst and file.S"
++      partially
++    - tools: Support relative directory path for 'O='
++    - kbuild: forbid kernel directory to contain spaces and colons
++    - Kbuild: disable 'maybe-uninitialized' warning for
++      CONFIG_PROFILE_ALL_BRANCHES
++    - gcov: disable -Wmaybe-uninitialized warning
++    - Disable "maybe-uninitialized" warning globally
++    - Disable "frame-address" warning
++    - Makefile: Mute warning for __builtin_return_address(>0) for tracing only
++    - net: caif: fix misleading indentation
++    - Add braces to avoid "ambiguous ‘else’" compiler warnings
++    - am437x-vfpe: fix typo in vpfe_get_app_input_index
++    - ath9k: fix misleading indentation
++    - iwlegacy: avoid warning about missing braces
++    - Staging: iio: adc: fix indent on break statement
++    - nouveau: fix nv40_perfctr_next() cleanup regression
++    - bonding: Fix bonding crash
++    - Revert "af_unix: Fix splice-bind deadlock"
++    - af_unix: split 'u->readlock' into two: 'iolock' and 'bindlock'
++    - vti: flush x-netns xfrm cache when vti interface is removed
++    - net/irda: handle iriap_register_lsap() allocation failure
++    - tipc: fix NULL pointer dereference in shutdown()
++    - net/mlx5: Added missing check of msg length in verifying its signature
++    - net: dsa: bcm_sf2: Fix race condition while unmasking interrupts
++    - Revert "phy: IRQ cannot be shared"
++    - net: smc91x: fix SMC accesses
++    - bridge: re-introduce 'fix parsing of MLDv2 reports'
++    - autofs races
++    - autofs: use dentry flags to block walks during expire
++    - xfs: prevent dropping ioend completions during buftarg wait
++    - fsnotify: add a way to stop queueing events on group shutdown
++    - fanotify: fix list corruption in fanotify_get_response()
++    - fix fault_in_multipages_...() on architectures with no-op access_ok()
++    - mtd: maps: sa1100-flash: potential NULL dereference
++    - mtd: pmcmsp-flash: Allocating too much in init_msp_flash()
++    - power: reset: hisi-reboot: Unmap region obtained by of_iomap
++    - fix memory leaks in tracing_buffers_splice_read()
++    - tracing: Move mutex to protect against resetting of seq data
++    - mm: delete unnecessary and unsafe init_tlb_ubc()
++    - can: flexcan: fix resume function
++    - nl80211: validate number of probe response CSA counters
++    - btrfs: ensure that file descriptor used with subvol ioctls is a dir
++    - i2c-eg20t: fix race between i2c init and interrupt enable
++    - i2c: qup: skip qup_i2c_suspend if the device is already runtime suspended
++    - MIPS: Fix pre-r6 emulation FPU initialisation
++    - MIPS: SMP: Fix possibility of deadlock when bringing CPUs online
++    - MIPS: vDSO: Fix Malta EVA mapping to vDSO page structs
++    - MIPS: Remove compact branch policy Kconfig entries
++    - MIPS: Avoid a BUG warning during prctl(PR_SET_FP_MODE, ...)
++    - MIPS: Add a missing ".set pop" in an early commit
++    - MIPS: paravirt: Fix undefined reference to smp_bootstrap
++    - PM / hibernate: Restore processor state before using per-CPU variables
++    - PM / hibernate: Fix rtree_next_node() to avoid walking off list ends
++    - power_supply: tps65217-charger: fix missing platform_set_drvdata()
++    - power: supply: max17042_battery: fix model download bug.
++    - qxl: check for kmap failures
++    - hostfs: Freeing an ERR_PTR in hostfs_fill_sb_common()
++    - Linux 4.4.23
++
++  * Xenial update to v4.4.22 stable release (LP: #1627730)
++    - ext4: use __GFP_NOFAIL in ext4_free_blocks()
++    - fscrypto: add authorization check for setting encryption policy
++    - clocksource/drivers/sun4i: Clear interrupts after stopping timer in probe
++      function
++    - MIPS: KVM: Check for pfn noslot case
++    - fscrypto: require write access to mount to set encryption policy
++    - lightnvm: put bio before return
++    - powerpc/tm: do not use r13 for tabort_syscall
++    - powerpc/mm: Don't alias user region to other regions below PAGE_OFFSET
++    - kernfs: don't depend on d_find_any_alias() when generating notifications
++    - pNFS: The client must not do I/O to the DS if it's lease has expired
++    - NFSv4.x: Fix a refcount leak in nfs_callback_up_net
++    - nfsd: Close race between nfsd4_release_lockowner and nfsd4_lock
++    - pNFS: Ensure LAYOUTGET and LAYOUTRETURN are properly serialised
++    - NFSv4.1: Fix the CREATE_SESSION slot number accounting
++    - kexec: fix double-free when failing to relocate the purgatory
++    - mm: introduce get_task_exe_file
++    - audit: fix exe_file access in audit_exe_compare
++    - dm flakey: fix reads to be issued if drop_writes configured
++    - IB/uverbs: Fix race between uverbs_close and remove_one
++    - ARC: mm: fix build breakage with STRICT_MM_TYPECHECKS
++    - x86/paravirt: Do not trace _paravirt_ident_*() functions
++    - x86/AMD: Apply erratum 665 on machines without a BIOS fix
++    - kvm-arm: Unmap shadow pagetables properly
++    - iio: accel: kxsd9: Fix raw read return
++    - iio: proximity: as3935: set up buffer timestamps for non-zero values
++    - iio: adc: rockchip_saradc: reset saradc controller before programming it
++    - iio: adc: ti_am335x_adc: Protect FIFO1 from concurrent access
++    - iio: adc: ti_am335x_adc: Increase timeout value waiting for ADC sample
++    - iio: ad799x: Fix buffered capture for ad7991/ad7995/ad7999
++    - iio: adc: at91: unbreak channel adc channel 3
++    - iio: accel: bmc150: reset chip at init time
++    - iio: fix pressure data output unit in hid-sensor-attributes
++    - iio: accel: kxsd9: Fix scaling bug
++    - iio:core: fix IIO_VAL_FRACTIONAL sign handling
++    - iio: ensure ret is initialized to zero before entering do loop
++    - serial: 8250_mid: fix divide error bug if baud rate is 0
++    - serial: 8250: added acces i/o products quad and octal serial cards
++    - USB: serial: simple: add support for another Infineon flashloader
++    - usb: renesas_usbhs: fix clearing the {BRDY,BEMP}STS condition
++    - usb: chipidea: udc: fix NULL ptr dereference in isr_setup_status_phase
++    - ARM: dts: STiH410: Handle interconnect clock required by EHCI/OHCI (USB)
++    - USB: change bInterval default to 10 ms
++    - net: thunderx: Fix OOPs with ethtool --register-dump
++    - cpuset: make sure new tasks conform to the current config of the cpuset
++    - ARM: AM43XX: hwmod: Fix RSTST register offset for pruss
++    - ARM: imx6: add missing BM_CLPCR_BYP_MMDC_CH0_LPM_HS setting for imx6ul
++    - ARM: imx6: add missing BM_CLPCR_BYPASS_PMIC_READY setting for imx6sx
++    - ARM: kirkwood: ib62x0: fix size of u-boot environment partition
++    - ARM: OMAP3: hwmod data: Add sysc information for DSI
++    - ARM: dts: imx6qdl: Fix SPDIF regression
++    - ARM: dts: overo: fix gpmc nand cs0 range
++    - ARM: dts: overo: fix gpmc nand on boards with ethernet
++    - ARM: dts: STiH407-family: Provide interconnect clock for consumption in ST
++      SDHCI
++    - bus: arm-ccn: Fix PMU handling of MN
++    - bus: arm-ccn: Do not attempt to configure XPs for cycle counter
++    - bus: arm-ccn: Fix XP watchpoint settings bitmask
++    - dm log writes: fix check of kthread_run() return value
++    - dm log writes: move IO accounting earlier to fix error path
++    - dm crypt: fix error with too large bios
++    - pinctrl: pistachio: fix mfio pll_lock pinmux
++    - pinctrl: sunxi: fix uart1 CTS/RTS pins at PG on A23/A33
++    - arm64: spinlocks: implement smp_mb__before_spinlock() as smp_mb()
++    - crypto: cryptd - initialize child shash_desc on import
++    - Btrfs: remove root_log_ctx from ctx list before btrfs_sync_log returns
++    - fuse: direct-io: don't dirty ITER_BVEC pages
++    - xhci: fix null pointer dereference in stop command timeout function
++    - md-cluster: make md-cluster also can work when compiled into kernel
++    - ath9k: fix using sta->drv_priv before initializing it
++    - Revert "wext: Fix 32 bit iwpriv compatibility issue with 64 bit Kernel"
++    - sched/core: Fix a race between try_to_wake_up() and a woken up task
++    - ipv6: addrconf: fix dev refcont leak when DAD failed
++    - gma500: remove annoying deprecation warning
++    - mpssd: fix buffer overflow warning
++    - drm/i915: Avoid pointer arithmetic in calculating plane surface offset
++    - mmc: dw_mmc: use resource_size_t to store physical address
++    - pinctrl: at91-pio4: use %pr format string for resource
++    - soc: qcom/spm: shut up uninitialized variable warning
++    - kconfig: tinyconfig: provide whole choice blocks to avoid warnings
++    - net: simplify napi_synchronize() to avoid warnings
++    - drm: atmel-hlcdc: Fix vertical scaling
++    - drm: Only use compat ioctl for addfb2 on X86/IA64
++    - genirq: Provide irq_gc_{lock_irqsave,unlock_irqrestore}() helpers
++    - irqchip/atmel-aic: Fix potential deadlock in ->xlate()
++    - fix iov_iter_fault_in_readable()
++    - microblaze: fix __get_user()
++    - avr32: fix copy_from_user()
++    - microblaze: fix copy_from_user()
++    - fix minor infoleak in get_user_ex()
++    - mn10300: failing __get_user() and get_user() should zero
++    - m32r: fix __get_user()
++    - sh64: failing __get_user() should zero
++    - nios2: fix __get_user()
++    - score: fix __get_user/get_user
++    - s390: get_user() should zero on failure
++    - ARC: uaccess: get_user to zero out dest in cause of fault
++    - asm-generic: make get_user() clear the destination on errors
++    - frv: fix clear_user()
++    - cris: buggered copy_from_user/copy_to_user/clear_user
++    - blackfin: fix copy_from_user()
++    - score: fix copy_from_user() and friends
++    - sh: fix copy_from_user()
++    - hexagon: fix strncpy_from_user() error return
++    - mips: copy_from_user() must zero the destination on access_ok() failure
++    - asm-generic: make copy_from_user() zero the destination properly
++    - alpha: fix copy_from_user()
++    - metag: copy_from_user() should zero the destination on access_ok() failure
++    - parisc: fix copy_from_user()
++    - openrisc: fix copy_from_user()
++    - nios2: copy_from_user() should zero the tail of destination
++    - mn10300: copy_from_user() should zero on access_ok() failure...
++    - sparc32: fix copy_from_user()
++    - ppc32: fix copy_from_user()
++    - genirq/msi: Fix broken debug output
++    - ia64: copy_from_user() should zero the destination on access_ok() failure
++    - avr32: fix 'undefined reference to `___copy_from_user'
++    - openrisc: fix the fix of copy_from_user()
++    - Linux 4.4.22
++
++  * AES-XTS poor performance in Ubuntu 16.04 (LP: #1613295)
++    - crypto: vmx - fix null dereference in p8_aes_xts_crypt
++
++  * i40e/setting some ethtool features and remove module right after (modprobe
++    -r) lead to crash in systems with more than 127 CPUs (LP: #1626782)
++    - i40e: Fix errors resulted while turning off TSO
++
++  * STC860:alpine-pdq:alpdq5p03: kernel panic when adding vnic (LP: #1626222)
++    - ibmvnic: fix to use list_for_each_safe() when delete items
++
++  * Stratton: ISST-LTE:UbuntuKVM: Failed to hotplug virtual devices to guest
++    running Ubuntu 16.04.1 on UbuntuKVM16.04.1 #179 (LP: #1625986)
++    - PCI: rpaphp: Fix slot registration for multiple slots under a PHB
++
++  * nvme: Missing patch in Ubuntu-4.4.0-41.61 (LP: #1628520)
++    - nvme: Call pci_disable_device on the error path.
++
++ -- Seth Forshee <seth.forshee@canonical.com>  Thu, 20 Oct 2016 08:09:34 -0500
++
++linux (4.4.0-45.66) xenial; urgency=low
++
++  * CVE-2016-5195
++    - SAUCE: mm: remove gup_flags FOLL_WRITE games from __get_user_pages()
++
++  * srcname from mount rule corrupted under load (LP: #1634753)
++    - SAUCE: apparmor: fix sleep in critical section
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Wed, 19 Oct 2016 11:24:20 +0200
++
++linux (4.4.0-43.63) xenial; urgency=low
++
++  [ Seth Forshee ]
++
++  * Release Tracking Bug
++    - LP: #1632375
++
++  * kswapd0 100% CPU usage (LP: #1518457)
++    - SAUCE: (no-up) If zone is so small that watermarks are the same, stop zone
++      balance.
++
++ -- Seth Forshee <seth.forshee@canonical.com>  Tue, 11 Oct 2016 07:54:56 -0500
++
++linux (4.4.0-42.62) xenial; urgency=low
++
++  * Fix GRO recursion overflow for tunneling protocols (LP: #1631287)
++    - tunnels: Don't apply GRO to multiple layers of encapsulation.
++    - gro: Allow tunnel stacking in the case of FOU/GUE
++
++  * CVE-2016-7039
++    - SAUCE: net: add recursion limit to GRO
++
++ -- Seth Forshee <seth.forshee@canonical.com>  Fri, 07 Oct 2016 12:03:55 -0500
++
++linux (4.4.0-41.61) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1628204
++
++  * nvme drive probe failure (LP: #1626894)
++    - (fix) NVMe: Don't unmap controller registers on reset
++
++ -- Kamal Mostafa <kamal@canonical.com>  Tue, 27 Sep 2016 09:40:42 -0700
++
++linux (4.4.0-40.60) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1627074
++
++  * Permission denied in CIFS with kernel 4.4.0-38 (LP: #1626112)
++    - Fix memory leaks in cifs_do_mount()
++    - Compare prepaths when comparing superblocks
++    - SAUCE: Fix regression which breaks DFS mounting
++
++  * Backlight does not change when adjust it higher than 50% after S3
++    (LP: #1625932)
++    - SAUCE: i915_bpo: drm/i915/backlight: setup and cache pwm alternate
++      increment value
++    - SAUCE: i915_bpo: drm/i915/backlight: setup backlight pwm alternate
++      increment on backlight enable
++
++ -- Kamal Mostafa <kamal@canonical.com>  Fri, 23 Sep 2016 08:53:31 -0700
++
++linux (4.4.0-39.59) xenial; urgency=low
++
++  [ Joseph Salisbury ]
++
++  * Release Tracking Bug
++    - LP: #1625303
++
++  * thunder: chip errata w/ multiple CQEs for a TSO packet (LP: #1624569)
++    - net: thunderx: Fix for issues with multiple CQEs posted for a TSO packet
++
++  * thunder: faulty TSO padding (LP: #1623627)
++    - net: thunderx: Fix for HW issue while padding TSO packet
++
++  * CVE-2016-6828
++    - tcp: fix use after free in tcp_xmit_retransmit_queue()
++
++  * Sennheiser Officerunner - cannot get freq at ep 0x83 (LP: #1622763)
++    - SAUCE: (no-up) ALSA: usb-audio: Add quirk for sennheiser officerunner
++
++  * Backport E3 Skylake Support in ie31200_edac to Xenial (LP: #1619766)
++    - EDAC, ie31200_edac: Add Skylake support
++
++  * Ubuntu 16.04 - Full EEH Recovery Support for NVMe devices (LP: #1602724)
++    - SAUCE: nvme: Don't suspend admin queue that wasn't created
++
++  * ISST-LTE:pNV: system ben is hung during ST (nvme) (LP: #1620317)
++    - blk-mq: Allow timeouts to run while queue is freezing
++    - blk-mq: improve warning for running a queue on the wrong CPU
++    - blk-mq: don't overwrite rq->mq_ctx
++
++  * lsattr 32bit does not work on 64bit kernel (Inappropriate ioctl error)
++    (LP: #1619918)
++    - btrfs: bugfix: handle FS_IOC32_{GETFLAGS, SETFLAGS, GETVERSION} in
++      btrfs_ioctl
++
++  * radeon: monitor connected to onboard VGA doesn't work with Xenial
++    (LP: #1600092)
++    - drm/radeon/dp: add back special handling for NUTMEG
++
++  * initramfs includes qle driver, but not firmware (LP: #1623187)
++    - qed: add MODULE_FIRMWARE()
++
++  * [Hyper-V] Rebase Hyper-V to 4.7.2 (stable) (LP: #1616677)
++    - hv_netvsc: Implement support for VF drivers on Hyper-V
++    - hv_netvsc: Fix the list processing for network change event
++    - Drivers: hv: vmbus: Introduce functions for estimating room in the ring
++      buffer
++    - Drivers: hv: vmbus: Use READ_ONCE() to read variables that are volatile
++    - Drivers: hv: vmbus: Export the vmbus_set_event() API
++    - lcoking/barriers, arch: Use smp barriers in smp_store_release()
++    - asm-generic: guard smp_store_release/load_acquire
++    - x86: reuse asm-generic/barrier.h
++    - asm-generic: add __smp_xxx wrappers
++    - x86: define __smp_xxx
++    - asm-generic: implement virt_xxx memory barriers
++    - Drivers: hv: vmbus: Move some ring buffer functions to hyperv.h
++    - Drivers: hv: vmbus: Implement APIs to support "in place" consumption of
++      vmbus packets
++    - drivers:hv: Lock access to hyperv_mmio resource tree
++    - drivers:hv: Make a function to free mmio regions through vmbus
++    - drivers:hv: Track allocations of children of hv_vmbus in private resource
++      tree
++    - drivers:hv: Separate out frame buffer logic when picking MMIO range
++    - Drivers: hv: vmbus: handle various crash scenarios
++    - Drivers: hv: balloon: don't crash when memory is added in non-sorted order
++    - Drivers: hv: balloon: reset host_specified_ha_region
++    - tools: hv: lsvmbus: add pci pass-through UUID
++    - hv_netvsc: move start_remove flag to net_device_context
++    - hv_netvsc: use start_remove flag to protect netvsc_link_change()
++    - hv_netvsc: untangle the pointer mess
++    - hv_netvsc: get rid of struct net_device pointer in struct netvsc_device
++    - hv_netvsc: synchronize netvsc_change_mtu()/netvsc_set_channels() with
++      netvsc_remove()
++    - hv_netvsc: set nvdev link after populating chn_table
++    - hv_netvsc: Fix VF register on vlan devices
++    - hv_netvsc: remove redundant assignment in netvsc_recv_callback()
++    - hv_netvsc: introduce {net, hv}_device_to_netvsc_device() helpers
++    - hv_netvsc: pass struct netvsc_device to rndis_filter_{open, close}()
++    - hv_netvsc: pass struct net_device to rndis_filter_set_device_mac()
++    - hv_netvsc: pass struct net_device to rndis_filter_set_offload_params()
++    - netvsc: get rid of completion timeouts
++    - PCI: hv: Don't leak buffer in hv_pci_onchannelcallback()
++    - PCI: hv: Handle all pending messages in hv_pci_onchannelcallback()
++    - netvsc: Use the new in-place consumption APIs in the rx path
++    - x86/kernel: Audit and remove any unnecessary uses of module.h
++    - PCI: hv: Fix interrupt cleanup path
++    - hv_netvsc: Fix VF register on bonding devices
++    - hv_netvsc: don't lose VF information
++    - hv_netvsc: avoid deadlocks between rtnl lock and vf_use_cnt wait
++    - hv_netvsc: reset vf_inject on VF removal
++    - hv_netvsc: protect module refcount by checking net_device_ctx->vf_netdev
++    - hv_netvsc: fix bonding devices check in netvsc_netdev_event()
++    - Drivers: hv: vmbus: Use the new virt_xx barrier code
++    - ixgbevf: call ndo_stop() instead of dev_close() when running offline
++      selftest
++    - ixgbevf: fix error code path when setting MAC address
++    - ixgbevf: use bit operations for setting and checking resets
++    - ixgbevf: Add support for generic Tx checksums
++    - ixgbe/ixgbevf: Add support for bulk free in Tx cleanup & cleanup boolean
++      logic
++    - ixgbevf: refactor ethtool stats handling
++    - ixgbevf: add support for per-queue ethtool stats
++    - ixgbevf: make use of BIT() macro to avoid shift of signed values
++    - ixgbevf: Move API negotiation function into mac_ops
++    - ixgbevf: Add the device ID's presented while running on Hyper-V
++    - ixgbevf: Support Windows hosts (Hyper-V)
++    - ixgbevf: Change the relaxed order settings in VF driver for sparc
++    - ixgbevf: Use mac_ops instead of trying to identify NIC type
++
++  * New device ID for Kabypoint (LP: #1622469)
++    - mfd: lpss: Add Intel Kaby Lake PCH-H PCI IDs
++    - SAUCE: i2c: i801: Add support for Kaby Lake PCH-H
++
++  * Xenial update to v4.4.21 stable release (LP: #1624037)
++    - Revert "i40e: fix: do not sleep in netdev_ops"
++    - fs: Check for invalid i_uid in may_follow_link()
++    - netfilter: x_tables: check for size overflow
++    - ext4: validate that metadata blocks do not overlap superblock
++    - ext4: fix xattr shifting when expanding inodes
++    - ext4: fix xattr shifting when expanding inodes part 2
++    - ext4: properly align shifted xattrs when expanding inodes
++    - ext4: avoid deadlock when expanding inode size
++    - ext4: avoid modifying checksum fields directly during checksum verification
++    - block: Fix race triggered by blk_set_queue_dying()
++    - block: make sure a big bio is split into at most 256 bvecs
++    - cgroup: reduce read locked section of cgroup_threadgroup_rwsem during fork
++    - s390/sclp_ctl: fix potential information leak with /dev/sclp
++    - drm/radeon: fix radeon_move_blit on 32bit systems
++    - drm: Reject page_flip for !DRIVER_MODESET
++    - drm/msm: fix use of copy_from_user() while holding spinlock
++    - ASoC: atmel_ssc_dai: Don't unconditionally reset SSC on stream startup
++    - xfs: fix superblock inprogress check
++    - timekeeping: Cap array access in timekeeping_debug
++    - timekeeping: Avoid taking lock in NMI path with CONFIG_DEBUG_TIMEKEEPING
++    - lustre: remove unused declaration
++    - wrappers for ->i_mutex access
++    - ovl: don't copy up opaqueness
++    - ovl: remove posix_acl_default from workdir
++    - ovl: listxattr: use strnlen()
++    - ovl: fix workdir creation
++    - ubifs: Fix assertion in layout_in_gaps()
++    - bcache: RESERVE_PRIO is too small by one when prio_buckets() is a power of
++      two.
++    - vhost/scsi: fix reuse of &vq->iov[out] in response
++    - x86/apic: Do not init irq remapping if ioapic is disabled
++    - uprobes: Fix the memcg accounting
++    - crypto: caam - fix IV loading for authenc (giv)decryption
++    - ALSA: usb-audio: Add sample rate inquiry quirk for B850V3 CP2114
++    - ALSA: firewire-tascam: accessing to user space outside spinlock
++    - ALSA: fireworks: accessing to user space outside spinlock
++    - ALSA: rawmidi: Fix possible deadlock with virmidi registration
++    - ALSA: hda - Add headset mic quirk for Dell Inspiron 5468
++    - ALSA: hda - Enable subwoofer on Dell Inspiron 7559
++    - ALSA: timer: fix NULL pointer dereference in read()/ioctl() race
++    - ALSA: timer: fix division by zero after SNDRV_TIMER_IOCTL_CONTINUE
++    - ALSA: timer: fix NULL pointer dereference on memory allocation failure
++    - scsi: fix upper bounds check of sense key in scsi_sense_key_string()
++    - metag: Fix atomic_*_return inline asm constraints
++    - cpufreq: Fix GOV_LIMITS handling for the userspace governor
++    - hwrng: exynos - Disable runtime PM on probe failure
++    - regulator: anatop: allow regulator to be in bypass mode
++    - lib/mpi: mpi_write_sgl(): fix skipping of leading zero limbs
++    - Linux 4.4.21
++
++  * Headset mic detection on some variants of Dell Inspiron 5468 (LP: #1617900)
++    - ALSA: hda - Add headset mic quirk for Dell Inspiron 5468
++
++  * Xenial update to v4.4.20 stable release (LP: #1621113)
++    - hugetlb: fix nr_pmds accounting with shared page tables
++    - x86/mm: Disable preemption during CR3 read+write
++    - uprobes/x86: Fix RIP-relative handling of EVEX-encoded instructions
++    - tools/testing/nvdimm: fix SIGTERM vs hotplug crash
++    - SUNRPC: Handle EADDRNOTAVAIL on connection failures
++    - SUNRPC: allow for upcalls for same uid but different gss service
++    - powerpc/eeh: eeh_pci_enable(): fix checking of post-request state
++    - ALSA: usb-audio: Add a sample rate quirk for Creative Live! Cam Socialize HD
++      (VF0610)
++    - ALSA: usb-audio: Add quirk for ELP HD USB Camera
++    - arm64: Define AT_VECTOR_SIZE_ARCH for ARCH_DLINFO
++    - parisc: Fix order of EREFUSED define in errno.h
++    - virtio: fix memory leak in virtqueue_add()
++    - vfio/pci: Fix NULL pointer oops in error interrupt setup handling
++    - perf intel-pt: Fix occasional decoding errors when tracing system-wide
++    - libnvdimm, nd_blk: mask off reserved status bits
++    - ALSA: hda - Manage power well properly for resume
++    - NVMe: Don't unmap controller registers on reset
++    - PCI: Support PCIe devices with short cfg_size
++    - PCI: Add Netronome vendor and device IDs
++    - PCI: Limit config space size for Netronome NFP6000 family
++    - PCI: Add Netronome NFP4000 PF device ID
++    - PCI: Limit config space size for Netronome NFP4000
++    - mmc: sdhci-acpi: Reduce Baytrail eMMC/SD/SDIO hangs
++    - ACPI: CPPC: Return error if _CPC is invalid on a CPU
++    - ACPI / CPPC: Prevent cpc_desc_ptr points to the invalid data
++    - um: Don't discard .text.exit section
++    - genirq/msi: Remove unused MSI_FLAG_IDENTITY_MAP
++    - genirq/msi: Make sure PCI MSIs are activated early
++    - crypto: caam - fix non-hmac hashes
++    - crypto: caam - fix echainiv(authenc) encrypt shared descriptor
++    - crypto: caam - defer aead_set_sh_desc in case of zero authsize
++    - usb: ehci: change order of register cleanup during shutdown
++    - usb: misc: usbtest: add fix for driver hang
++    - usb: dwc3: pci: add Intel Kabylake PCI ID
++    - usb: dwc3: gadget: increment request->actual once
++    - usb: hub: Fix unbalanced reference count/memory leak/deadlocks
++    - USB: hub: fix up early-exit pathway in hub_activate
++    - USB: hub: change the locking in hub_activate
++    - usb: renesas_usbhs: clear the BRDYSTS in usbhsg_ep_enable()
++    - usb: renesas_usbhs: Use dmac only if the pipe type is bulk
++    - USB: validate wMaxPacketValue entries in endpoint descriptors
++    - usb: gadget: fsl_qe_udc: off by one in setup_received_handle()
++    - usb/gadget: fix gadgetfs aio support.
++    - xhci: always handle "Command Ring Stopped" events
++    - usb: xhci: Fix panic if disconnect
++    - xhci: don't dereference a xhci member after removing xhci
++    - USB: serial: fix memleak in driver-registration error path
++    - USB: serial: option: add D-Link DWM-156/A3
++    - USB: serial: option: add support for Telit LE920A4
++    - USB: serial: ftdi_sio: add device ID for WICED USB UART dev board
++    - USB: serial: ftdi_sio: add PIDs for Ivium Technologies devices
++    - iommu/dma: Don't put uninitialised IOVA domains
++    - iommu/arm-smmu: Fix CMDQ error handling
++    - iommu/arm-smmu: Don't BUG() if we find aborting STEs with disable_bypass
++    - pinctrl/amd: Remove the default de-bounce time
++    - EDAC: Increment correct counter in edac_inc_ue_error()
++    - s390/dasd: fix hanging device after clear subchannel
++    - mac80211: fix purging multicast PS buffer queue
++    - arm64: dts: rockchip: add reset saradc node for rk3368 SoCs
++    - of: fix reference counting in of_graph_get_endpoint_by_regs
++    - sched/cputime: Fix NO_HZ_FULL getrusage() monotonicity regression
++    - sched/nohz: Fix affine unpinned timers mess
++    - iio: fix sched WARNING "do not call blocking ops when !TASK_RUNNING"
++    - drm/amdgpu: Change GART offset to 64-bit
++    - drm/amdgpu: fix amdgpu_move_blit on 32bit systems
++    - drm/amdgpu: avoid a possible array overflow
++    - drm/amdgpu: skip TV/CV in display parsing
++    - drm/amd/amdgpu: sdma resume fail during S4 on CI
++    - drm/amdgpu: record error code when ring test failed
++    - drm/i915: fix aliasing_ppgtt leak
++    - ARC: build: Better way to detect ISA compatible toolchain
++    - ARC: use correct offset in pt_regs for saving/restoring user mode r25
++    - ARC: Call trace_hardirqs_on() before enabling irqs
++    - ARC: Elide redundant setup of DMA callbacks
++    - aacraid: Check size values after double-fetch from user
++    - mfd: cros_ec: Add cros_ec_cmd_xfer_status() helper
++    - i2c: cros-ec-tunnel: Fix usage of cros_ec_cmd_xfer()
++    - cdc-acm: fix wrong pipe type on rx interrupt xfers
++    - mpt3sas: Fix resume on WarpDrive flash cards
++    - megaraid_sas: Fix probing cards without io port
++    - usb: renesas_usbhs: gadget: fix return value check in
++      usbhs_mod_gadget_probe()
++    - gpio: Fix OF build problem on UM
++    - fs/seq_file: fix out-of-bounds read
++    - btrfs: waiting on qgroup rescan should not always be interruptible
++    - btrfs: properly track when rescan worker is running
++    - Input: tegra-kbc - fix inverted reset logic
++    - Input: i8042 - break load dependency between atkbd/psmouse and i8042
++    - Input: i8042 - set up shared ps2_cmd_mutex for AUX ports
++    - crypto: nx - off by one bug in nx_of_update_msc()
++    - crypto: qat - fix aes-xts key sizes
++    - dmaengine: usb-dmac: check CHCR.DE bit in usb_dmac_isr_channel()
++    - USB: avoid left shift by -1
++    - usb: chipidea: udc: don't touch DP when controller is in host mode
++    - USB: fix typo in wMaxPacketSize validation
++    - USB: serial: mos7720: fix non-atomic allocation in write path
++    - USB: serial: mos7840: fix non-atomic allocation in write path
++    - USB: serial: option: add WeTelecom WM-D200
++    - USB: serial: option: add WeTelecom 0x6802 and 0x6803 products
++    - staging: comedi: daqboard2000: bug fix board type matching code
++    - staging: comedi: comedi_test: fix timer race conditions
++    - staging: comedi: ni_mio_common: fix AO inttrig backwards compatibility
++    - staging: comedi: ni_mio_common: fix wrong insn_write handler
++    - ACPI / drivers: fix typo in ACPI_DECLARE_PROBE_ENTRY macro
++    - ACPI / drivers: replace acpi_probe_lock spinlock with mutex
++    - ACPI / sysfs: fix error code in get_status()
++    - ACPI / SRAT: fix SRAT parsing order with both LAPIC and X2APIC present
++    - ALSA: line6: Remove double line6_pcm_release() after failed acquire.
++    - ALSA: line6: Give up on the lock while URBs are released.
++    - ALSA: line6: Fix POD sysfs attributes segfault
++    - hwmon: (iio_hwmon) fix memory leak in name attribute
++    - sysfs: correctly handle read offset on PREALLOC attrs
++    - Linux 4.4.20
++
++  * Failed to acknowledge elog: /sys/firmware/opal/elog/0x5018d709/acknowledge
++    (2:No such file or directory) (LP: #1619552)
++    - powerpc/powernv : Drop reference added by kset_find_obj()
++
++  * backport support for userspace access of DP aux devices (LP: #1619756)
++    - drm/dp: Add a drm_aux-dev module for reading/writing dpcd registers.
++    - drm/dp: Allow signals to interrupt drm_aux-dev reads/writes
++    - [Config] CONFIG_DRM_DP_AUX_CHARDEV=y
++
++  * Enable virtual scsi server driver for Power (LP: #1615665)
++    - SAUCE: Ibmvscsis: Properly deregister target sessions
++    - SAUCE: Return TCMU-generated sense data to fabric module
++    - SAUCE: Ibmvscsis: Code cleanup of print statements
++    - SAUCE: Ibmvscsis: Fixed a bug reported by Dan Carpenter
++
++  * ISST-LTE: system dropped into xmon at pcibios_release_device+0x5c/0x80
++    during running dlpar test on monklp3 (LP: #1618151)
++    - powerpc/pseries: use pci_host_bridge.release_fn() to kfree(phb)
++
++  * Kernel Build Fails for Fuse Module (LP: #1617550)
++    - SAUCE: (namespace) userns: Export current_in_userns to modules
++
++  * boot-time kernel panic introduced in 4.4.0-18, not present in 4.4.0-15
++    (LP: #1572630)
++    - blk-mq: Reuse hardware context cpumask for tags
++    - blk-mq: Use proper cpumask iterator
++
++ -- Joseph Salisbury <joseph.salisbury@canonical.com>  Mon, 19 Sep 2016 14:23:10 -0400
++
++linux (4.4.0-38.57) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1620658
++
++  * CIFS client: access problems after updating to kernel 4.4.0-29-generic
++    (LP: #1612135)
++    - Revert "UBUNTU: SAUCE: (namespace) Bypass sget() capability check for nfs"
++    - fs: Call d_automount with the filesystems creds
++
++  * apt-key add fails in overlayfs (LP: #1618572)
++    - SAUCE: overlayfs: fix regression in whiteout detection
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 30 Aug 2016 12:24:30 -0600
++
++linux (4.4.0-37.56) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1618040
++
++  * [Feature] Instruction decoder support for new SKX instructions- AVX512
++    (LP: #1591655)
++    - x86/insn: perf tools: Fix vcvtph2ps instruction decoding
++    - x86/insn: Add AVX-512 support to the instruction decoder
++    - perf tools: Add AVX-512 support to the instruction decoder used by Intel PT
++    - perf tools: Add AVX-512 instructions to the new instructions test
++
++  * [Ubuntu 16.04] FCoE Lun not visible in OS with inbox driver - Issue with
++    ioremap() call on 32bit kernel (LP: #1608652)
++    - lpfc: Correct issue with ioremap() call on 32bit kernel
++
++  * [Feature] turbostat support for Skylake-SP server (LP: #1591802)
++    - tools/power turbostat: decode more CPUID fields
++    - tools/power turbostat: CPUID(0x16) leaf shows base, max, and bus frequency
++    - tools/power turbostat: decode HWP registers
++    - tools/power turbostat: Decode MSR_MISC_PWR_MGMT
++    - tools/power turbostat: allow sub-sec intervals
++    - tools/power turbostat: Intel Xeon x200: fix erroneous bclk value
++    - tools/power turbostat: Intel Xeon x200: fix turbo-ratio decoding
++    - tools/power turbostat: re-name "%Busy" field to "Busy%"
++    - tools/power turbostat: add --out option for saving output in a file
++    - tools/power turbostat: fix compiler warnings
++    - tools/power turbostat: make fewer systems calls
++    - tools/power turbostat: show IRQs per CPU
++    - tools/power turbostat: show GFXMHz
++    - tools/power turbostat: show GFX%rc6
++    - tools/power turbostat: detect and work around syscall jitter
++    - tools/power turbostat: indicate SMX and SGX support
++    - tools/power turbostat: call __cpuid() instead of __get_cpuid()
++    - tools/power turbostat: correct output for MSR_NHM_SNB_PKG_CST_CFG_CTL dump
++    - tools/power turbostat: bugfix: TDP MSRs print bits fixing
++    - tools/power turbostat: SGX state should print only if --debug
++    - tools/power turbostat: print IRTL MSRs
++    - tools/power turbostat: initial BXT support
++    - tools/power turbostat: decode BXT TSC frequency via CPUID
++    - tools/power turbostat: initial SKX support
++
++  * [BYT] display hotplug doesn't work on console (LP: #1616894)
++    - drm/i915/vlv: Make intel_crt_reset() per-encoder
++    - drm/i915/vlv: Reset the ADPA in vlv_display_power_well_init()
++    - drm/i915/vlv: Disable HPD in valleyview_crt_detect_hotplug()
++    - drm/i915: Enable polling when we don't have hpd
++
++  * [Feature]intel_idle enabling on Broxton-P (LP: #1520446)
++    - intel_idle: add BXT support
++
++  * [Feature] EDAC: Update driver for SKX-SP (LP: #1591815)
++    - [Config] CONFIG_EDAC_SKX=m
++    - EDAC, skx_edac: Add EDAC driver for Skylake
++
++  * [Feature] KBL: Sandy Peak(3168) WiFi/BT support (LP: #1591648)
++    - Bluetooth: Add support for Intel Bluetooth device 3168 [8087:0aa7]
++
++  * MacBookPro11,4 fails to poweroff or suspend (LP: #1587714)
++    - SAUCE: PCI: Workaround to enable poweroff on Mac Pro 11
++
++  * Support Edge Gateway's Bluetooth LED (LP: #1512999)
++    - SAUCE: Bluetooth: Support for LED on Edge Gateways
++    - SAUCE: Bluetooth: Use host bridge subsystem IDs to identify Edge Gateways
++
++  * Please add support for alps touchpad. (LP: #1616813)
++    - [Config] CONFIG_HID_ALPS=m
++    - HID: add Alps I2C HID Touchpad-Stick support
++    - HID: alps: struct u1_dev *priv is internal to the driver
++    - HID: alps: pass correct sizes to hid_hw_raw_request()
++    - HID: alps: match alps devices in core
++    - HID: alps: a few cleanups
++
++  * DINO2M - System hangs with a black screen during s4 stress test
++    (LP: #1616781)
++    - x86/power/64: Fix kernel text mapping corruption during image restoration
++
++  * Xenial update to v4.4.17 stable release (LP: #1611833)
++    - USB: OHCI: Don't mark EDs as ED_OPER if scheduling fails
++    - x86/quirks: Apply nvidia_bugs quirk only on root bus
++    - x86/quirks: Reintroduce scanning of secondary buses
++    - x86/quirks: Add early quirk to reset Apple AirPort card
++    - dmaengine: at_xdmac: align descriptors on 64 bits
++    - dmaengine: at_xdmac: fix residue corruption
++    - dmaengine: at_xdmac: double FIFO flush needed to compute residue
++    - mm, sl[au]b: add __GFP_ATOMIC to the GFP reclaim mask
++    - mm, compaction: abort free scanner if split fails
++    - fs/nilfs2: fix potential underflow in call to crc32_le
++    - mm, compaction: prevent VM_BUG_ON when terminating freeing scanner
++    - mm, meminit: always return a valid node from early_pfn_to_nid
++    - mm, meminit: ensure node is online before checking whether pages are
++      uninitialised
++    - vmlinux.lds: account for destructor sections
++    - pps: do not crash when failed to register
++    - kernel/sysrq, watchdog, sched/core: Reset watchdog on all CPUs while
++      processing sysrq-w
++    - arc: unwind: warn only once if DW2_UNWIND is disabled
++    - ARC: unwind: ensure that .debug_frame is generated (vs. .eh_frame)
++    - xen/pciback: Fix conf_space read/write overlap check.
++    - xenbus: don't BUG() on user mode induced condition
++    - xenbus: don't bail early from xenbus_dev_request_and_reply()
++    - Input: vmmouse - remove port reservation
++    - Input: elantech - add more IC body types to the list
++    - Input: xpad - fix oops when attaching an unknown Xbox One gamepad
++    - Input: wacom_w8001 - w8001_MAX_LENGTH should be 13
++    - Input: xpad - validate USB endpoint count during probe
++    - Input: tsc200x - report proper input_dev name
++    - pvclock: Add CPU barriers to get correct version value
++    - pinctrl: single: Fix missing flush of posted write for a wakeirq
++    - pinctrl: imx: Do not treat a PIN without MUX register as an error
++    - cgroup: set css->id to -1 during init
++    - power_supply: power_supply_read_temp only if use_cnt > 0
++    - locks: use file_inode()
++    - Revert "ecryptfs: forbid opening files without mmap handler"
++    - ecryptfs: don't allow mmap when the lower fs doesn't support it
++    - ext4: verify extent header depth
++    - 9p: use file_dentry()
++    - namespace: update event counter when umounting a deleted dentry
++    - spi: sunxi: fix transfer timeout
++    - spi: sun4i: fix FIFO limit
++    - clk: rockchip: initialize flags of clk_init_data in mmc-phase clock
++    - platform/chrome: cros_ec_dev - double fetch bug in ioctl
++    - block: fix use-after-free in sys_ioprio_get()
++    - mmc: block: fix packed command header endianness
++    - sched/fair: Fix effective_load() to consistently use smoothed load
++    - ovl: handle ATTR_KILL*
++    - perf/x86: fix PEBS issues on Intel Atom/Core2
++    - can: at91_can: RX queue could get stuck at high bus load
++    - can: c_can: Update D_CAN TX and RX functions to 32 bit - fix Altera Cyclone
++      access
++    - can: fix handling of unmodifiable configuration options fix
++    - can: fix oops caused by wrong rtnl dellink usage
++    - RDS: fix rds_tcp_init() error path
++    - SCSI: fix new bug in scsi_dev_info_list string matching
++    - ipr: Clear interrupt on croc/crocodile when running with LSI
++    - posix_cpu_timer: Exit early when process has been reaped
++    - i2c: mux: reg: wrong condition checked for of_address_to_resource return
++      value
++    - libata: LITE-ON CX1-JB256-HP needs lower max_sectors
++    - libceph: apply new_state before new_up_client on incrementals
++    - net: mvneta: set real interrupt per packet for tx_done
++    - intel_th: pci: Add Kaby Lake PCH-H support
++    - intel_th: Fix a deadlock in modprobing
++    - vfs: fix deadlock in file_remove_privs() on overlayfs
++    - Linux 4.4.17
++    - xenbus: don't look up transaction IDs for ordinary writes
++
++  * Enable virtual scsi server driver for Power (LP: #1615665)
++    - [Config] CONFIG_SCSI_IBMVSCSIS=m
++    - target: Add target_alloc_session() helper function
++    - ibmvscsis: Initial commit of IBM VSCSI Tgt Driver
++
++  * AES-XTS poor performance in Ubuntu 16.04 (LP: #1613295)
++    - crypto: vmx: Only call enable_kernel_vsx()
++    - powerpc: Create disable_kernel_{fp,altivec,vsx,spe}()
++    - crypto: vmx - Adding asm subroutines for XTS
++    - crypto: xts - consolidate sanity check for keys
++    - crypto: vmx - Adding support for XTS
++    - crypto: vmx - Fix aes_p8_xts_decrypt build failure
++    - crypto: xts - fix compile errors
++
++  *  System hang when plug/pull USB 3.1 key via thunderbolt port over 5 times
++    (LP: #1616318)
++    - USB: don't free bandwidth_mutex too early
++
++  * Ubuntu 16.04 - Full EEH Recovery Support for NVMe devices (LP: #1602724)
++    - nvme: Suspend all queues before deletion
++
++  * change_hat is logging failures during expected hat probing (LP: #1615893)
++    - SAUCE: apparmor: Fix auditing behavior for change_hat probing
++
++  * deleted files outside of the namespace are not being treated as disconnected
++    (LP: #1615892)
++    - SAUCE: apparmor: deleted dentries can be disconnected
++
++  * stacking to unconfined in a child namespace confuses mediation
++    (LP: #1615890)
++    - SAUCE: apparmor: special case unconfined when determining the mode
++
++  * apparmor module parameters can be changed after the policy is locked
++    (LP: #1615895)
++    - SAUCE: apparmor: fix: parameters can be changed after policy is locked
++
++  * AppArmor profile reloading causes an intermittent kernel BUG (LP: #1579135)
++    - SAUCE: apparmor: fix vec_unique for vectors larger than 8
++
++  * label vec reductions can result in reference labels instead of direct access
++    to labels (LP: #1615889)
++    - SAUCE: apparmor: reduction of vec to single entry is just that entry
++
++  * profiles from different namespaces can block other namespaces from being
++    able to load a profile (LP: #1615887)
++    - SAUCE: apparmor: profiles in one ns can affect mediation in another ns
++
++  * vmalloc failure leads to null ptr dereference in aa_dfa_next (LP: #1592547)
++    - SAUCE: apparmor: oops in profile_unpack() when policy_db is not present
++
++  * vmalloc_addr is being checked on the failed return address of kvzalloc()
++    (LP: #1615885)
++    - SAUCE: apparmor: fix: don't check for vmalloc_addr if kvzalloc() failed
++
++  * dfa is missing a bounds check which can cause an oops (LP: #1615882)
++    - SAUCE: apparmor: Add missing id bounds check on dfa verification
++
++  * The label build for onexec when stacking is wrong (LP: #1615881)
++    - SAUCE: apparmor: Fix label build for onexec stacking.
++
++  * The inherit check for new to old label comparison for domain transitions is
++    wrong (LP: #1615880)
++    - SAUCE: apparmor: Fix new to old label comparison for domain transitions
++
++  * warning stack trace while playing with apparmor namespaces (LP: #1593874)
++    - SAUCE: apparmor: fix stack trace when removing namespace with profiles
++
++  * __label_update proxy comparison test is wrong (LP: #1615878)
++    - SAUCE: apparmor: Fix __label_update proxy comparison test
++
++  * Xenial update to v4.4.19 stable release (LP: #1615620)
++    - usb: gadget: avoid exposing kernel stack
++    - usb: f_fs: off by one bug in _ffs_func_bind()
++    - usb: renesas_usbhs: protect the CFIFOSEL setting in usbhsg_ep_enable()
++    - usb: dwc3: fix for the isoc transfer EP_BUSY flag
++    - USB: serial: option: add support for Telit LE910 PID 0x1206
++    - usb: renesas_usbhs: fix NULL pointer dereference in xfer_work()
++    - arm64: kernel: Save and restore UAO and addr_limit on exception entry
++    - arm64: debug: unmask PSTATE.D earlier
++    - arm64: Fix incorrect per-cpu usage for boot CPU
++    - tty: serial: msm: Don't read off end of tx fifo
++    - serial: samsung: Fix ERR pointer dereference on deferred probe
++    - tty/serial: atmel: fix RS485 half duplex with DMA
++    - gpio: pca953x: Fix NBANK calculation for PCA9536
++    - gpio: intel-mid: Remove potentially harmful code
++    - Bluetooth: hci_intel: Fix null gpio desc pointer dereference
++    - pinctrl: cherryview: prevent concurrent access to GPIO controllers
++    - arm64: dts: rockchip: fixes the gic400 2nd region size for rk3368
++    - arm64: mm: avoid fdt_check_header() before the FDT is fully mapped
++    - KVM: PPC: Book3S HV: Pull out TM state save/restore into separate procedures
++    - KVM: PPC: Book3S HV: Save/restore TM state in H_CEDE
++    - KVM: MTRR: fix kvm_mtrr_check_gfn_range_consistency page fault
++    - KVM: VMX: handle PML full VMEXIT that occurs during event delivery
++    - KVM: nVMX: Fix memory corruption when using VMCS shadowing
++    - intel_pstate: Fix MSR_CONFIG_TDP_x addressing in core_get_max_pstate()
++    - mfd: qcom_rpm: Fix offset error for msm8660
++    - mfd: qcom_rpm: Parametrize also ack selector size
++    - media: usbtv: prevent access to free'd resources
++    - media: dvb_ringbuffer: Add memory barriers
++    - vb2: core: Skip planes array verification if pb is NULL
++    - Fix RC5 decoding with Fintek CIR chipset
++    - sur40: lower poll interval to fix occasional FPS drops to ~56 FPS
++    - sur40: fix occasional oopses on device close
++    - dm: set DMF_SUSPENDED* _before_ clearing DMF_NOFLUSH_SUSPENDING
++    - hp-wmi: Fix wifi cannot be hard-unblocked
++    - s5p-mfc: Set device name for reserved memory region devs
++    - s5p-mfc: Add release callback for memory region devs
++    - i2c: efm32: fix a failure path in efm32_i2c_probe()
++    - spi: pxa2xx: Clear all RFT bits in reset_sccr1() on Intel Quark
++    - Bluetooth: Fix l2cap_sock_setsockopt() with optname BT_RCVMTU
++    - EDAC: Correct channel count limit
++    - HID: uhid: fix timeout when probe races with IO
++    - ovl: disallow overlayfs as upperdir
++    - remoteproc: Fix potential race condition in rproc_add
++    - ARC: mm: don't loose PTE_SPECIAL in pte_modify()
++    - jbd2: make journal y2038 safe
++    - fs/cifs: make share unaccessible at root level mountable
++    - cifs: Check for existing directory when opening file with O_CREAT
++    - cifs: fix crash due to race in hmac(md5) handling
++    - CIFS: Fix a possible invalid memory access in smb2_query_symlink()
++    - random: initialize the non-blocking pool via add_hwgenerator_randomness()
++    - random: print a warning for the first ten uninitialized random users
++    - random: add interrupt callback to VMBus IRQ handler
++    - MIPS: KVM: Fix mapped fault broken commpage handling
++    - MIPS: KVM: Add missing gfn range check
++    - MIPS: KVM: Fix gfn range check in kseg0 tlb faults
++    - MIPS: KVM: Propagate kseg0/mapped tlb fault errors
++    - nfs: don't create zero-length requests
++    - nfsd: Fix race between FREE_STATEID and LOCK
++    - nfsd: don't return an unhashed lock stateid after taking mutex
++    - drm/i915: Don't complain about lack of ACPI video bios
++    - iommu/exynos: Suppress unbinding to prevent system failure
++    - iommu/vt-d: Return error code in domain_context_mapping_one()
++    - iommu/amd: Handle IOMMU_DOMAIN_DMA in ops->domain_free call-back
++    - iommu/amd: Init unity mappings only for dma_ops domains
++    - iommu/amd: Update Alias-DTE in update_device_table()
++    - audit: fix a double fetch in audit_log_single_execve_arg()
++    - ARM: dts: sunxi: Add a startup delay for fixed regulator enabled phys
++    - netlabel: add address family checks to netlbl_{sock,req}_delattr()
++    - w1:omap_hdq: fix regression
++    - drm/amdgpu: add a delay after ATPX dGPU power off
++    - drm/amdgpu: Poll for both connect/disconnect on analog connectors
++    - drm/amdgpu: support backlight control for UNIPHY3
++    - drm/amdgpu: Disable RPM helpers while reprobing connectors on resume
++    - drm/amdgpu: fix firmware info version checks
++    - drm/amdgpu/gmc7: add missing mullins case
++    - drm/radeon: add a delay after ATPX dGPU power off
++    - drm/radeon: Poll for both connect/disconnect on analog connectors
++    - drm/radeon: fix firmware info version checks
++    - drm/radeon: support backlight control for UNIPHY3
++    - drm/nouveau/gr/nv3x: fix instobj write offsets in gr setup
++    - drm/nouveau/fbcon: fix font width not divisible by 8
++    - drm: Restore double clflush on the last partial cacheline
++    - drm/edid: Add 6 bpc quirk for display AEO model 0.
++    - drm/i915: Never fully mask the the EI up rps interrupt on SNB/IVB
++    - drm/i915/dp: Revert "drm/i915/dp: fall back to 18 bpp when sink capability
++      is unknown"
++    - balloon: check the number of available pages in leak balloon
++    - ftrace/recordmcount: Work around for addition of metag magic but not
++      relocations
++    - metag: Fix __cmpxchg_u32 asm constraint for CMP
++    - block: add missing group association in bio-cloning functions
++    - block: fix bdi vs gendisk lifetime mismatch
++    - mtd: nand: fix bug writing 1 byte less than page size
++    - mm/hugetlb: avoid soft lockup in set_max_huge_pages()
++    - ALSA: hda: Fix krealloc() with __GFP_ZERO usage
++    - ALSA: hda/realtek - Can't adjust speaker's volume on a Dell AIO
++    - ALSA: hda: add AMD Bonaire AZ PCI ID with proper driver caps
++    - ALSA: hda - Fix headset mic detection problem for two dell machines
++    - IB/mlx5: Fix MODIFY_QP command input structure
++    - IB/mlx5: Fix entries checks in mlx5_ib_create_cq
++    - IB/mlx5: Fix returned values of query QP
++    - IB/mlx5: Fix entries check in mlx5_ib_resize_cq
++    - IB/mlx5: Fix post send fence logic
++    - IB/mlx5: Return PORT_ERR in Active to Initializing tranisition
++    - IB/SA: Use correct free function
++    - IB/IPoIB: Don't update neigh validity for unresolved entries
++    - IB/IWPM: Fix a potential skb leak
++    - IB/mlx4: Fix the SQ size of an RC QP
++    - IB/mlx4: Fix error flow when sending mads under SRIOV
++    - IB/mlx4: Fix memory leak if QP creation failed
++    - of: fix memory leak related to safe_name()
++    - ubi: Make volume resize power cut aware
++    - ubi: Fix early logging
++    - ubi: Fix race condition between ubi device creation and udev
++    - iscsi-target: Fix panic when adding second TCP connection to iSCSI session
++    - target: Fix ordered task target_setup_cmd_from_cdb exception hang
++    - target: Fix missing complete during ABORT_TASK + CMD_T_FABRIC_STOP
++    - target: Fix race between iscsi-target connection shutdown + ABORT_TASK
++    - target: Fix max_unmap_lba_count calc overflow
++    - target: Fix ordered task CHECK_CONDITION early exception handling
++    - Input: elan_i2c - properly wake up touchpad on ASUS laptops
++    - SUNRPC: Don't allocate a full sockaddr_storage for tracing
++    - MIPS: mm: Fix definition of R6 cache instruction
++    - MIPS: Don't register r4k sched clock when CPUFREQ enabled
++    - MIPS: hpet: Increase HPET_MIN_PROG_DELTA and decrease HPET_MIN_CYCLES
++    - PCI: Mark Atheros AR9485 and QCA9882 to avoid bus reset
++    - x86/platform/intel_mid_pci: Rework IRQ0 workaround
++    - ACPI / EC: Work around method reentrancy limit in ACPICA for _Qxx
++    - rtc: s3c: Add s3c_rtc_{enable/disable}_clk in s3c_rtc_setfreq()
++    - dm flakey: error READ bios during the down_interval
++    - module: Invalidate signatures on force-loaded modules
++    - Documentation/module-signing.txt: Note need for version info if reusing a
++      key
++    - Linux 4.4.19
++
++  * xfrm: ipsec crash when updating spd thresholds (LP: #1613787)
++    - xfrm: Ignore socket policies when rebuilding hash tables
++
++  * ISST-LTE:pKVM311:lotg5:Ubutu16041:lotg5 crashed @
++    writeback_sb_inodes+0x30c/0x590 (LP: #1614565)
++    - writeback: Write dirty times for WB_SYNC_ALL writeback
++
++  * IBM Power 720 Ethernet Not Seen (LP: #1612725)
++    - [Config] CONFIG_IBMEBUS=y for powerpc
++
++  * CAPI: Update default setting for the psl_fir_cntl register (LP: #1612431)
++    - cxl: Set psl_fir_cntl to production environment value
++
++  * Xenial update to v4.4.18 stable release (LP: #1614560)
++    - tcp: enable per-socket rate limiting of all 'challenge acks'
++    - ipv4: reject RTNH_F_DEAD and RTNH_F_LINKDOWN from user space
++    - bonding: set carrier off for devices created through netlink
++    - net: bgmac: Fix infinite loop in bgmac_dma_tx_add()
++    - net/irda: fix NULL pointer dereference on memory allocation failure
++    - qed: Fix setting/clearing bit in completion bitmap
++    - tcp: consider recv buf for the initial window scale
++    - ipath: Restrict use of the write() interface
++    - scsi: ignore errors from scsi_dh_add_device()
++    - HID: sony: do not bail out when the sixaxis refuses the output report
++    - i2c: i801: Allow ACPI SystemIO OpRegion to conflict with PCI BAR
++    - arm: oabi compat: add missing access checks
++    - KEYS: 64-bit MIPS needs to use compat_sys_keyctl for 32-bit userspace
++    - Revert "s390/kdump: Clear subchannel ID to signal non-CCW/SCSI IPL"
++    - random: strengthen input validation for RNDADDTOENTCNT
++    - devpts: clean up interface to pty drivers
++    - x86/mm/pat: Add support of non-default PAT MSR setting
++    - x86/mm/pat: Add pat_disable() interface
++    - x86/mm/pat: Replace cpu_has_pat with boot_cpu_has()
++    - x86/mtrr: Fix Xorg crashes in Qemu sessions
++    - x86/mtrr: Fix PAT init handling when MTRR is disabled
++    - x86/xen, pat: Remove PAT table init code from Xen
++    - x86/pat: Document the PAT initialization sequence
++    - x86/mm/pat: Fix BUG_ON() in mmap_mem() on QEMU/i386
++    - drm/i915: Pretend cursor is always on for ILK-style WM calculations (v2)
++    - x86/syscalls/64: Add compat_sys_keyctl for 32-bit userspace
++    - block: fix use-after-free in seq file
++    - sysv, ipc: fix security-layer leaking
++    - fuse: fsync() did not return IO errors
++    - fuse: fuse_flush must check mapping->flags for errors
++    - fuse: fix wrong assignment of ->flags in fuse_send_init()
++    - fs/dcache.c: avoid soft-lockup in dput()
++    - crypto: gcm - Filter out async ghash if necessary
++    - crypto: scatterwalk - Fix test in scatterwalk_done
++    - ext4: check for extents that wrap around
++    - ext4: fix deadlock during page writeback
++    - ext4: don't call ext4_should_journal_data() on the journal inode
++    - ext4: validate s_reserved_gdt_blocks on mount
++    - ext4: short-cut orphan cleanup on error
++    - ext4: fix reference counting bug on block allocation error
++    - mm: memcontrol: fix cgroup creation failure after many small jobs
++    - mm: memcontrol: fix swap counter leak on swapout from offline cgroup
++    - mm: memcontrol: fix memcg id ref counter on swap charge move
++    - Linux 4.4.18
++
++  * Ubuntu16.10:installation fails on Brazos system (31TB and 192 cores) No
++    memory for flatten_device_tree (no room) (LP: #1614309)
++    - SAUCE: powerpc/pseries: Increase RMA size to 512MB.
++
++  * [SRU] xgene_enet: 10g performance only hits ~75% on multi-client tests
++    (LP: #1613157)
++    - drivers: net: xgene: Add support for Classifier engine
++    - drivers: net: xgene: Add support for RSS
++    - drivers: net: xgene: Add support for multiple queues
++
++  * [SRU] xgene_enet: an extra interrupt may be pending for an interrupt
++    controller that doesn't support irq_disable and hardware with level
++    interrupt (LP: #1611399)
++    - drivers: net: xgene: fix extra IRQ issue
++
++  * Mic mute hotkey does not work on usb keyboard [03f0:2f4a] (LP: #1609606)
++    - HID: input: add mic mute key on HP slim keyboard
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Fri, 12 Aug 2016 09:05:59 +0200
++
++linux (4.4.0-36.55) xenial; urgency=low
++
++  [ Stefan Bader ]
++
++  * Release Tracking Bug
++    - LP: #1612305
++
++  * I2C touchpad does not work on AMD platform (LP: #1612006)
++    - SAUCE: pinctrl/amd: Remove the default de-bounce time
++
++  * CVE-2016-5696
++    - tcp: make challenge acks less predictable
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Thu, 11 Aug 2016 17:34:14 +0200
++
++linux (4.4.0-35.54) xenial; urgency=low
++
++  [ Stefan Bader ]
++
++  * Release Tracking Bug
++    - LP: #1611215
++
++  * [i915_bpo] Sync with v4.7 (LP: #1609742)
++    - SAUCE: i915_bpo: Sync with v4.7
++
++  * s390/cio: fix reset of channel measurement block (LP: #1609415)
++    - s390/cio: allow to reset channel measurement block
++
++  * in Ubuntu16.10: Hit on Call traces  and system goes down when transactional
++    memory  tests are running in 32TB Brazos system (LP: #1606786)
++    - powerpc/tm: Avoid SLB faults in treclaim/trecheckpoint when RI=0
++    - powerpc/tm: Fix stack pointer corruption in __tm_recheckpoint()
++
++  *  Power Menu does not display after press the Power Button (LP: #1609204)
++    - intel-vbtn: new driver for Intel Virtual Button
++    - [config] enable CONFIG_INTEL_VBTN=m
++
++  * OptiPlex 7450 AIO hangs when rebooting (LP: #1608762)
++    - x86/reboot: Add Dell Optiplex 7450 AIO reboot quirk
++
++  * virtualbox+usb 3.0 breaks boot, -28 kernel works (LP: #1604058)
++    - SAUCE: xhci: Fix soft lockup in xhci_pci_probe path when XHCI_STATE_HALTED
++
++  * linux-kernel: Freeing IRQ from IRQ context (LP: #1597908)
++    - block: defer timeouts to a workqueue
++
++  * Tunnel offload indications not stripped from encapsulated packets, causing
++    performance overhead (LP: #1602755)
++    - tunnels: Remove encapsulation offloads on decap.
++
++  * lm-sensors is throwing "ERROR: Can't get value of subfeature temp1_input:
++    I/O error" for be2net driver (LP: #1607387)
++    - be2net: perform temperature query in adapter regardless of its interface
++      state
++
++  * Dell dock MAC Address pass through doesn't work in Ubuntu (LP: #1579984)
++    - r8152: Add support for setting pass through MAC address on RTL8153-AD
++
++  * vmxnet3 LRO IPv6 performance issues (stalling TCP) (LP: #1605494)
++    - Driver: Vmxnet3: set CHECKSUM_UNNECESSARY for IPv6 packets
++
++  * ISST-LTE:pVM:monklp5:Ubuntu16.04.1:system crashed at
++    lpfc_sli4_scmd_to_wqidx_distr (LP: #1597974)
++    - SAUCE: lpfc: fix oops in lpfc_sli4_scmd_to_wqidx_distr() from
++      lpfc_send_taskmgmt()
++
++  * Backport cxlflash shutdown patch to Xenial SRU (LP: #1605405)
++    - SAUCE: cxlflash: Verify problem state area is mapped before notifying
++      shutdown
++
++  * Xenial update to v4.4.16 stable release (LP: #1607404)
++    - mac80211: fix fast_tx header alignment
++    - mac80211: mesh: flush mesh paths unconditionally
++    - mac80211_hwsim: Add missing check for HWSIM_ATTR_SIGNAL
++    - mac80211: Fix mesh estab_plinks counting in STA removal case
++    - EDAC, sb_edac: Fix rank lookup on Broadwell
++    - IB/cm: Fix a recently introduced locking bug
++    - IB/mlx4: Properly initialize GRH TClass and FlowLabel in AHs
++    - powerpc/pseries: Fix IBM_ARCH_VEC_NRCORES_OFFSET since POWER8NVL was added
++    - powerpc/tm: Always reclaim in start_thread() for exec() class syscalls
++    - usb: dwc2: fix regression on big-endian PowerPC/ARM systems
++    - USB: EHCI: declare hostpc register as zero-length array
++    - usb: common: otg-fsm: add license to usb-otg-fsm
++    - mnt: fs_fully_visible test the proper mount for MNT_LOCKED
++    - mnt: Account for MS_RDONLY in fs_fully_visible
++    - mnt: If fs_fully_visible fails call put_filesystem.
++    - of: fix autoloading due to broken modalias with no 'compatible'
++    - of: irq: fix of_irq_get[_byname]() kernel-doc
++    - locking/ww_mutex: Report recursive ww_mutex locking early
++    - locking/qspinlock: Fix spin_unlock_wait() some more
++    - locking/static_key: Fix concurrent static_key_slow_inc()
++    - x86, build: copy ldlinux.c32 to image.iso
++    - kprobes/x86: Clear TF bit in fault on single-stepping
++    - x86/amd_nb: Fix boot crash on non-AMD systems
++    - Revert "gpiolib: Split GPIO flags parsing and GPIO configuration"
++    - uvc: Forward compat ioctls to their handlers directly
++    - thermal: cpu_cooling: fix improper order during initialization
++    - writeback: use higher precision calculation in domain_dirty_limits()
++    - nfsd4/rpc: move backchannel create logic into rpc code
++    - nfsd: Always lock state exclusively.
++    - nfsd: Extend the mutex holding region around in nfsd4_process_open2()
++    - posix_acl: Add set_posix_acl
++    - nfsd: check permissions when setting ACLs
++    - make nfs_atomic_open() call d_drop() on all ->open_context() errors.
++    - NFS: Fix another OPEN_DOWNGRADE bug
++    - ARM: imx6ul: Fix Micrel PHY mask
++    - ARM: 8578/1: mm: ensure pmd_present only checks the valid bit
++    - ARM: 8579/1: mm: Fix definition of pmd_mknotpresent
++    - MIPS: KVM: Fix modular KVM under QEMU
++    - mm: Export migrate_page_move_mapping and migrate_page_copy
++    - UBIFS: Implement ->migratepage()
++    - sched/fair: Fix cfs_rq avg tracking underflow
++    - packet: Use symmetric hash for PACKET_FANOUT_HASH.
++    - net_sched: fix mirrored packets checksum
++    - cdc_ncm: workaround for EM7455 "silent" data interface
++    - ipv6: Fix mem leak in rt6i_pcpu
++    - ARCv2: Check for LL-SC livelock only if LLSC is enabled
++    - ARCv2: LLSC: software backoff is NOT needed starting HS2.1c
++    - kvm: Fix irq route entries exceeding KVM_MAX_IRQ_ROUTES
++    - KVM: nVMX: VMX instructions: fix segment checks when L1 is in long mode.
++    - HID: elo: kill not flush the work
++    - HID: hiddev: validate num_values for HIDIOCGUSAGES, HIDIOCSUSAGES commands
++    - tracing: Handle NULL formats in hold_module_trace_bprintk_format()
++    - base: make module_create_drivers_dir race-free
++    - iommu/arm-smmu: Wire up map_sg for arm-smmu-v3
++    - iommu/vt-d: Enable QI on all IOMMUs before setting root entry
++    - iommu/amd: Fix unity mapping initialization race
++    - drm/mgag200: Black screen fix for G200e rev 4
++    - ipmi: Remove smi_msg from waiting_rcv_msgs list before handle_one_recv_msg()
++    - arm64: Rework valid_user_regs
++    - vfs: add d_real_inode() helper
++    - af_unix: fix hard linked sockets on overlay
++    - btrfs: account for non-CoW'd blocks in btrfs_abort_transaction
++    - drm/radeon: fix asic initialization for virtualized environments
++    - drm/amdgpu/gfx7: fix broken condition check
++    - ubi: Make recover_peb power cut aware
++    - drm/amdkfd: unbind only existing processes
++    - drm/amdkfd: destroy dbgmgr in notifier release
++    - drm/dp/mst: Always clear proposed vcpi table for port.
++    - drm/nouveau/disp/sor/gf119: both links use the same training register
++    - drm/nouveau/gr/gf100-: update sm error decoding from gk20a nvgpu headers
++    - drm/nouveau/fbcon: fix out-of-bounds memory accesses
++    - drm/nouveau: fix for disabled fbdev emulation
++    - drm/nouveau/disp/sor/gf119: select correct sor when poking training pattern
++    - drm/i915/ilk: Don't disable SSC source if it's in use
++    - drm/i915: Refresh cached DP port register value on resume
++    - drm/i915: Update ifdeffery for mutex->owner
++    - drm/i915: Update CDCLK_FREQ register on BDW after changing cdclk frequency
++    - drm: add missing drm_mode_set_crtcinfo call
++    - drm: make drm_atomic_set_mode_prop_for_crtc() more reliable
++    - drm: atmel-hlcdc: actually disable scaling when no scaling is required
++    - drm/ttm: Make ttm_bo_mem_compat available
++    - drm/vmwgfx: Add an option to change assumed FB bpp
++    - drm/vmwgfx: Work around mode set failure in 2D VMs
++    - drm/vmwgfx: Check pin count before attempting to move a buffer
++    - drm/vmwgfx: Delay pinning fbdev framebuffer until after mode set
++    - drm/vmwgfx: Fix error paths when mapping framebuffer
++    - memory: omap-gpmc: Fix omap gpmc EXTRADELAY timing
++    - perf/x86: Fix undefined shift on 32-bit kernels
++    - xen/balloon: Fix declared-but-not-defined warning
++    - iio: Fix error handling in iio_trigger_attach_poll_func
++    - iio:st_pressure: fix sampling gains (bring inline with ABI)
++    - iio: light apds9960: Add the missing dev.parent
++    - iio: proximity: as3935: correct IIO_CHAN_INFO_RAW output
++    - iio: proximity: as3935: remove triggered buffer processing
++    - iio: proximity: as3935: fix buffer stack trashing
++    - iio: humidity: hdc100x: correct humidity integration time mask
++    - iio: humidity: hdc100x: fix IIO_TEMP channel reporting
++    - iio: hudmidity: hdc100x: fix incorrect shifting and scaling
++    - staging: iio: accel: fix error check
++    - iio: accel: kxsd9: fix the usage of spi_w8r8()
++    - iio:ad7266: Fix broken regulator error handling
++    - iio:ad7266: Fix support for optional regulators
++    - iio:ad7266: Fix probe deferral for vref
++    - tty/vt/keyboard: fix OOB access in do_compute_shiftstate()
++    - hwmon: (dell-smm) Restrict fan control and serial number to CAP_SYS_ADMIN by
++      default
++    - hwmon: (dell-smm) Disallow fan_type() calls on broken machines
++    - hwmon: (dell-smm) Cache fan_type() calls and change fan detection
++    - ALSA: dummy: Fix a use-after-free at closing
++    - ALSA: hda - Fix the headset mic jack detection on Dell machine
++    - ALSA: hda / realtek - add two more Thinkpad IDs (5050,5053) for tpt460 fixup
++    - ALSA: au88x0: Fix calculation in vortex_wtdma_bufshift()
++    - ALSA: echoaudio: Fix memory allocation
++    - ALSA: timer: Fix negative queue usage by racy accesses
++    - ALSA: hda/realtek: Add Lenovo L460 to docking unit fixup
++    - ALSA: hda - Add PCI ID for Kabylake-H
++    - ALSA: hda - fix read before array start
++    - ALSA: hda/realtek - add new pin definition in alc225 pin quirk table
++    - ALSA: pcm: Free chmap at PCM free callback, too
++    - ALSA: ctl: Stop notification after disconnection
++    - ALSA: hda - fix use-after-free after module unload
++    - ALSA: hda: add AMD Stoney PCI ID with proper driver caps
++    - ARM: sunxi/dt: make the CHIP inherit from allwinner,sun5i-a13
++    - ARM: dts: armada-38x: fix MBUS_ID for crypto SRAM on Armada 385 Linksys
++    - ARM: mvebu: fix HW I/O coherency related deadlocks
++    - ovl: Copy up underlying inode's ->i_mode to overlay inode
++    - ovl: verify upper dentry in ovl_remove_and_whiteout()
++    - scsi: fix race between simultaneous decrements of ->host_failed
++    - 53c700: fix BUG on untagged commands
++    - Fix reconnect to not defer smb3 session reconnect long after socket
++      reconnect
++    - cifs: dynamic allocation of ntlmssp blob
++    - File names with trailing period or space need special case conversion
++    - xen/acpi: allow xen-acpi-processor driver to load on Xen 4.7
++    - crypto: qat - make qat_asym_algs.o depend on asn1 headers
++    - tmpfs: don't undo fallocate past its last page
++    - tmpfs: fix regression hang in fallocate undo
++    - drm/i915: Revert DisplayPort fast link training feature
++    - ovl: verify upper dentry before unlink and rename
++    - Linux 4.4.16
++
++  * Regression caused by `fuse: Add support for pid namespaces` in 4.4.0-6.21
++    (LP: #1605344)
++    - SAUCE: (namespace) fuse: Permit requests from other pid namespaces
++
++  * CVE-2016-5400
++    - media: fix airspy usb probe error path
++
++  * Cannot mount proc in unprivileged containers if /proc/xen is mounted
++    (LP: #1607374)
++    - SAUCE: xenbus: Use proc_create_mount_point() to create /proc/xen
++
++  * Mic mute key does not work for Ideapad laptops (LP: #1607153)
++    - ideapad_laptop: Add an event for mic mute hotkey
++
++  * NVMe stress test fails after 12 hours on Ubuntu 16.04 (LP: #1604995)
++    - block: atari: Return early for unsupported sector size
++
++  * Console extremely slow with 4.4 kernels for servers with Matrox G200er2 or
++    similar (LP: #1605662)
++    - SAUCE: vesafb: Set mtrr:3 (write-combining) as default
++
++  * Ubuntu 16.04 - Full EEH Recovery Support for NVMe devices (LP: #1602724)
++    - nvme: use a work item to submit async event requests
++    - nvme: don't poll the CQ from the kthread
++    - nvme: replace the kthread with a per-device watchdog timer
++    - NVMe: Fix reset/remove race
++    - nvme: Avoid reset work on watchdog timer function during error recovery
++    - NVMe: Always use MSI/MSI-x interrupts
++
++  * [LTC-Test] - NMI watchdog Bug and call traces when trinity is executed.
++    (LP: #1602524)
++    - ext4: factor out determining of hole size
++    - ext4: return hole from ext4_map_blocks()
++    - ext4: more efficient SEEK_DATA implementation
++
++  * changelog: add CVEs as first class citizens (LP: #1604344)
++    - avoid duplicate CVE numbers in changelog
++
++  * [LTCTest][Opal][OP820] Machine crashed with Oops: Kernel access of bad area,
++    sig: 11 [#1] while executing Froze PE Error injection (LP: #1603449)
++    - powerpc/eeh: Fix invalid cached PE primary bus
++
++  * Hotplug remove and re-add adds PCI adapter to next PCI domain (PCI)
++    (LP: #1603574)
++    - powerpc/pci: Assign fixed PHB number based on device-tree properties
++
++  * nvme - reset_controller is not working after adapter's firmware upgrade
++    (adapter quirk is needed) (LP: #1602726)
++    - NVMe: Create discard zero quirk white list
++    - nvme/quirk: Add a delay before checking for adapter readiness
++
++  * ovs nat: conntrack netlink event are missing (LP: #1603468)
++    - openvswitch: fix conntrack netlink event delivery
++
++  * FlashGT - In Tuleta 8284-22A with card in card slot P1-C9, system Fails to
++    boot operating system (LP: #1602785)
++    - cxl: Ignore CAPI adapters misplaced in switched slots
++
++  * CVE-2016-5728
++    - misc: mic: Fix for double fetch security bug in VOP driver
++
++  * CVE-2016-5244 (LP: #1589041)
++    - rds: fix an infoleak in rds_inc_info_copy
++
++  * Miscellaneous Ubuntu changes
++    - Added Snapcraft files
++    - SAUCE: snapcraft: cleanup and remove unnecessary elements
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Tue, 09 Aug 2016 15:11:33 +0200
++
++linux (4.4.0-34.53) xenial; urgency=low
++
++  [ Seth Forshee ]
++
++  * Release Tracking Bug
++    - LP: #1606960
++
++  * [APL][SAUCE] Slow system response time due to a monitor bug (LP: #1606147)
++    - x86/cpu/intel: Introduce macros for Intel family numbers
++    - SAUCE: x86/cpu: Add workaround for MONITOR instruction erratum on Goldmont
++      based CPUs
++
++ -- Seth Forshee <seth.forshee@canonical.com>  Wed, 27 Jul 2016 10:01:20 -0500
++
++linux (4.4.0-33.52) xenial; urgency=low
++
++  [ Seth Forshee ]
++
++  * Release Tracking Bug
++    - LP: #1605709
++
++  * [regression] NFS client: access problems after updating to kernel
++    4.4.0-31-generic (LP: #1603719)
++    - SAUCE: (namespace) Bypass sget() capability check for nfs
++
++ -- Seth Forshee <seth.forshee@canonical.com>  Fri, 22 Jul 2016 13:10:08 -0500
++
++linux (4.4.0-32.51) xenial; urgency=low
++
++  [ Seth Forshee ]
++
++  * Release Tracking Bug
++    - LP: #1604443
++
++  * thinkpad yoga 260 wacom touchscreen not working (LP: #1603975)
++    - HID: wacom: break out parsing of device and registering of input
++    - HID: wacom: Initialize hid_data.inputmode to -1
++    - HID: wacom: Support switching from vendor-defined device mode on G9 and G11
++
++  * changelog: add CVEs as first class citizens (LP: #1604344)
++    - use CVE numbers in changelog
++
++  * [Xenial] Include Huawei PCIe SSD hio kernel driver (LP: #1603483)
++    - SAUCE: import Huawei ES3000_V2 (2.1.0.23)
++    - SAUCE: hio: bio_endio() no longer takes errors arg
++    - SAUCE: hio: blk_queue make_request_fn now returns a blk_qc_t
++    - SAUCE: hio: use alloc_cpumask_var to avoid -Wframe-larger-than
++    - SAUCE: hio: fix mask maybe-uninitialized warning
++    - [config] enable CONFIG_HIO (Huawei ES3000_V2 PCIe SSD driver)
++    - SAUCE: hio: Makefile and Kconfig
++
++  * CVE-2016-5243 (LP: #1589036)
++    - tipc: fix an infoleak in tipc_nl_compat_link_dump
++    - tipc: fix nl compat regression for link statistics
++
++  * CVE-2016-4470
++    - KEYS: potential uninitialized variable
++
++  * integer overflow in xt_alloc_table_info (LP: #1555353)
++    - netfilter: x_tables: check for size overflow
++
++  * CVE-2016-3135:
++    - Revert "UBUNTU: SAUCE: (noup) netfilter: x_tables: check for size overflow"
++
++  * CVE-2016-4440 (LP: #1584192)
++    - kvm:vmx: more complete state update on APICv on/off
++
++  * the system hangs in the dma driver when reboot or shutdown on a baytrail-m
++    laptop (LP: #1602579)
++    - dmaengine: dw: platform: power on device on shutdown
++    - ACPI / LPSS: override power state for LPSS DMA device
++
++  * Add proper  palm detection support for MS Precision Touchpad (LP: #1593124)
++    - Revert "HID: multitouch: enable palm rejection if device implements
++      confidence usage"
++    - HID: multitouch: enable palm rejection for Windows Precision Touchpad
++
++  * Add support for Intel 8265 Bluetooth ([8087:0A2B]) (LP: #1599068)
++    - Bluetooth: Add support for Intel Bluetooth device 8265 [8087:0a2b]
++
++  * CVE-2016-4794 (LP: #1581871)
++    - percpu: fix synchronization between chunk->map_extend_work and chunk
++      destruction
++    - percpu: fix synchronization between synchronous map extension and chunk
++      destruction
++
++  * Xenial update to v4.4.15 stable release (LP: #1601952)
++    - net_sched: fix pfifo_head_drop behavior vs backlog
++    - net: Don't forget pr_fmt on net_dbg_ratelimited for CONFIG_DYNAMIC_DEBUG
++    - sit: correct IP protocol used in ipip6_err
++    - esp: Fix ESN generation under UDP encapsulation
++    - netem: fix a use after free
++    - ipmr/ip6mr: Initialize the last assert time of mfc entries.
++    - Bridge: Fix ipv6 mc snooping if bridge has no ipv6 address
++    - sock_diag: do not broadcast raw socket destruction
++    - bpf, perf: delay release of BPF prog after grace period
++    - neigh: Explicitly declare RCU-bh read side critical section in neigh_xmit()
++    - net: macb: fix default configuration for GMAC on AT91
++    - net: alx: Work around the DMA RX overflow issue
++    - bpf: try harder on clones when writing into skb
++    - AX.25: Close socket connection on session completion
++    - crypto: ux500 - memmove the right size
++    - crypto: user - re-add size check for CRYPTO_MSG_GETALG
++    - USB: uas: Fix slave queue_depth not being set
++    - usb: quirks: Fix sorting
++    - usb: quirks: Add no-lpm quirk for Acer C120 LED Projector
++    - usb: musb: only restore devctl when session was set in backup
++    - usb: musb: Stop bulk endpoint while queue is rotated
++    - usb: musb: Ensure rx reinit occurs for shared_fifo endpoints
++    - usb: musb: host: correct cppi dma channel for isoch transfer
++    - usb: xhci-plat: properly handle probe deferral for devm_clk_get()
++    - USB: xhci: Add broken streams quirk for Frescologic device id 1009
++    - xhci: Fix handling timeouted commands on hosts in weird states.
++    - USB: mos7720: delete parport
++    - usb: gadget: fix spinlock dead lock in gadgetfs
++    - usb: host: ehci-tegra: Grab the correct UTMI pads reset
++    - usb: dwc3: exynos: Fix deferred probing storm.
++    - Linux 4.4.15
++
++  * qeth: delete napi struct when removing a qeth device (LP: #1601831)
++    - qeth: delete napi struct when removing a qeth device
++
++  * Adjust KBL PCI-ID's (LP: #1600124)
++    - drm/i915: Add more Kabylake PCI IDs.
++    - drm/i915: Removing PCI IDs that are no longer listed as Kabylake.
++
++  * [i915_bpo] Rebase driver to v4.7-rc6 + gen9 workarounds + KBP PCH support
++    (LP: #1599109)
++    - drm/kms_helper: Add a common place to call init and exit functions.
++    - drm: Add helper for DP++ adaptors
++    - GPU-DRM: Delete unnecessary checks before drm_property_unreference_blob()
++    - drm: introduce pipe color correction properties
++    - drm: fix blob pointer check
++    - drm: atomic helper: do not unreference error pointer
++    - drm: fix lut value extraction function
++    - drm/dsi: Add a helper to get bits per pixel of MIPI DSI pixel format
++    - SAUCE: drm: Introduce drm_malloc_gfp()
++    - SAUCE: i915_bpo: Rebase to v4.7-rc6
++    - SAUCE: i915_bpo: Add backported workarounds for gen9
++    - SAUCE: i915_bpo: Revert "drm/i915: Get panel_type from OpRegion panel
++      details"
++    - SAUCE: i915_bpo: Introduce Kabypoint PCH for Kabylake H/DT.
++
++  * Baytrail-I got black screen with HDMI output (LP: #1599379)
++    - drm/i915: Only ignore eDP ports that are connected
++    - drm/i915: Check VBT for port presence in addition to the strap on VLV/CHV
++
++  * [Hyper-V] storvsc messages for CD-ROM medium not present tray closed
++    (LP: #1590655)
++    - SAUCE: (no-up) scsi: storvsc: Filter out storvsc messages CD-ROM medium not
++      present
++
++  * Hotplug device addition issue - missing patches on Xenial kernel
++    (LP: #1599250)
++    - Revert "UBUNTU: SAUCE: powerpc/eeh: Validate arch in eeh_add_device_early()"
++    - Revert "powerpc/eeh: Fix crash in eeh_add_device_early() on Cell"
++    - powerpc/iommu: Remove the dependency on EEH struct in DDW mechanism
++    - powerpc/pseries: Fix PCI config address for DDW
++
++  * kernel: signal return with invalid floating-point control (LP: #1597971)
++    - s390: fix test_fp_ctl inline assembly contraints
++
++  * [Toshiba P50W-B00F] Touchscreen no longer working (LP: #1498667)
++    - SAUCE: (no-up) usb: quirks: Add no-lpm quirk for Elan Microelectronics
++      Touchpad
++
++  * [yakkety] d-i does not support (ehci_msm) Qualcomm  On-Chip EHCI Host
++    Controller (LP: #1599347)
++    - d-i: Add ehci_msm to usb-modules
++
++  * [Bug] Legacy audio couldn't work after S3 resume on Kabylake (LP: #1596871)
++    - ALSA: hda - Skip ELD notification during PM process
++    - ALSA: hda - hdmi add wmb barrier for audio component
++    - ALSA: hda - hdmi defer to register acomp eld notifier
++
++  * sync spl  0.6.5.6-0ubuntu4 changes into Xenial kernel source (LP: #1599257)
++    - SAUCE: (noup) Update spl to 0.6.5.6-0ubuntu4
++
++  * Config: missing AMD Seattle platform support (LP: #1597574)
++    - [Config] Enable the AMD Seattle platform
++
++  * Network installer fails to detect network on AMD Overdrive (ARM64)
++    (LP: #1597573)
++    - [Config] Add amd-xgbe to nic-modules udeb
++
++  * exercising ptys causes a kernel oops (LP: #1586418)
++    - devpts: fix null pointer dereference on failed memory allocation
++
++  * Regression (constant vibration of device) in xpad driver in Ubuntu 16.04
++    (LP: #1574102)
++    - Input: xpad - move pending clear to the correct location
++
++  * thunderx nics fail to establish link (LP: #1597867)
++    - net: thunderx: Fix link status reporting
++
++  * Xenial update to v4.4.14 stable release (LP: #1596575)
++    - scsi_lib: correctly retry failed zero length REQ_TYPE_FS commands
++    - scsi: Add QEMU CD-ROM to VPD Inquiry Blacklist
++    - netlink: Fix dump skb leak/double free
++    - tipc: fix nametable publication field in nl compat
++    - switchdev: pass pointer to fib_info instead of copy
++    - tuntap: correctly wake up process during uninit
++    - udp: prevent skbs lingering in tunnel socket queues
++    - uapi glibc compat: fix compilation when !__USE_MISC in glibc
++    - sfc: on MC reset, clear PIO buffer linkage in TXQs
++    - team: don't call netdev_change_features under team->lock
++    - vxlan: Accept user specified MTU value when create new vxlan link
++    - tcp: record TLP and ER timer stats in v6 stats
++    - bridge: Don't insert unnecessary local fdb entry on changing mac address
++    - l2tp: fix configuration passed to setup_udp_tunnel_sock()
++    - ipv6: Skip XFRM lookup if dst_entry in socket cache is valid
++    - vxlan: Relax MTU constraints
++    - geneve: Relax MTU constraints
++    - vxlan, gre, geneve: Set a large MTU on ovs-created tunnel devices
++    - KVM: x86: fix OOPS after invalid KVM_SET_DEBUGREGS
++    - KVM: irqfd: fix NULL pointer dereference in kvm_irq_map_gsi
++    - ALSA: hda - Add PCI ID for Kabylake
++    - ALSA: hda - Fix headset mic detection problem for Dell machine
++    - ALSA: hda/realtek - ALC256 speaker noise issue
++    - ALSA: hda/realtek - Add support for new codecs ALC700/ALC701/ALC703
++    - ALSA: hda/realtek: Add T560 docking unit fixup
++    - ARM: fix PTRACE_SETVFPREGS on SMP systems
++    - gpio: bcm-kona: fix bcm_kona_gpio_reset() warnings
++    - s390/bpf: fix recache skb->data/hlen for skb_vlan_push/pop
++    - s390/bpf: reduce maximum program size to 64 KB
++    - irqchip/gic-v3: Fix ICC_SGI1R_EL1.INTID decoding mask
++    - crypto: public_key: select CRYPTO_AKCIPHER
++    - crypto: ccp - Fix AES XTS error for request sizes above 4096
++    - arm64: Provide "model name" in /proc/cpuinfo for PER_LINUX32 tasks
++    - arm64: mm: always take dirty state from new pte in ptep_set_access_flags
++    - powerpc/pseries/eeh: Handle RTAS delay requests in configure_bridge
++    - powerpc: Fix definition of SIAR and SDAR registers
++    - powerpc: Use privileged SPR number for MMCR2
++    - powerpc/pseries: Add POWER8NVL support to ibm,client-architecture-support
++      call
++    - pinctrl: mediatek: fix dual-edge code defect
++    - parisc: Fix pagefault crash in unaligned __get_user() call
++    - memcg: add RCU locking around css_for_each_descendant_pre() in
++      memcg_offline_kmem()
++    - wext: Fix 32 bit iwpriv compatibility issue with 64 bit Kernel
++    - x86/entry/traps: Don't force in_interrupt() to return true in IST handlers
++    - fix d_walk()/non-delayed __d_free() race
++    - sparc: Fix system call tracing register handling.
++    - sparc64: Fix bootup regressions on some Kconfig combinations.
++    - sparc64: Fix numa node distance initialization
++    - sparc64: Fix sparc64_set_context stack handling.
++    - sparc/PCI: Fix for panic while enabling SR-IOV
++    - sparc64: Reduce TLB flushes during hugepte changes
++    - sparc64: Take ctx_alloc_lock properly in hugetlb_setup().
++    - sparc: Harden signal return frame checks.
++    - sparc64: Fix return from trap window fill crashes.
++    - MIPS: Fix 64k page support for 32 bit kernels.
++    - crypto: qat - fix adf_ctl_drv.c:undefined reference to adf_init_pf_wq
++    - drm/core: Do not preserve framebuffer on rmfb, v4.
++    - Linux 4.4.14
++
++  * [Hyper-V] Rebase Hyper-V to 4.6 kernel (LP: #1583357)
++    - hv_netvsc: rework link status change handling
++    - hv_netvsc: Resize some of the variables in hv_netvsc_packet
++    - hv_netvsc: Rearrange the hv_negtvsc_packet to be space efficient
++    - hv_netvsc: Eliminate the channel field in hv_netvsc_packet structure
++    - hv_netvsc: Eliminate rndis_msg pointer from hv_netvsc_packet structure
++    - hv_netvsc: Eliminatte the data field from struct hv_netvsc_packet
++    - hv_netvsc: Eliminate send_completion from struct hv_netvsc_packet
++    - hv_netvsc: Eliminate send_completion_ctx from struct hv_netvsc_packet
++    - hv_netvsc: Don't ask for additional head room in the skb
++    - hv_netvsc: move subchannel existence check to netvsc_select_queue()
++    - hv_netvsc: remove locking in netvsc_send()
++    - hv_netvsc: Eliminate page_buf from struct hv_netvsc_packet
++    - hv_netvsc: Eliminate send_completion_tid from struct hv_netvsc_packet
++    - hv_netvsc: Eliminate is_data_pkt from struct hv_netvsc_packet
++    - hv_netvsc: Eliminate completion_func from struct hv_netvsc_packet
++    - hv_netvsc: Eliminate xmit_more from struct hv_netvsc_packet
++    - hv_netvsc: Eliminate status from struct hv_netvsc_packet
++    - hv_netvsc: Eliminate vlan_tci from struct hv_netvsc_packet
++    - storvsc: add logging for error/warning messages
++    - hv_netvsc: Fix race condition on Multi-Send Data field
++    - kvm/x86: split ioapic-handled and EOI exit bitmaps
++    - kvm/x86: per-vcpu apicv deactivation support
++    - kvm/x86: Hyper-V synthetic interrupt controller
++    - kvm/x86: Hyper-V kvm exit
++    - kvm/x86: Rearrange func's declarations inside Hyper-V header
++    - kvm/x86: Added Hyper-V vcpu_to_hv_vcpu()/hv_vcpu_to_vcpu() helpers
++    - kvm/x86: Hyper-V internal helper to read MSR HV_X64_MSR_TIME_REF_COUNT
++    - kvm/x86: Hyper-V SynIC message slot pending clearing at SINT ack
++    - kvm/x86: Hyper-V SynIC timers
++    - storvsc: Fix a bug in the layout of the hv_fc_wwn_packet
++    - storvsc: Properly support Fibre Channel devices
++    - storvsc: Refactor the code in storvsc_channel_init()
++    - storvsc: Tighten up the interrupt path
++    - storvsc: Fix typo in MODULE_PARM_DESC
++    - Revert "hv_netvsc: use skb_get_hash() instead of a homegrown implementation"
++    - hv_netvsc: use skb_get_hash() instead of a homegrown implementation
++    - hv_netvsc: Fix book keeping of skb during batching process
++    - storvsc: Install the storvsc specific timeout handler for FC devices
++    - storvsc: Use the specified target ID in device lookup
++    - Revert "Drivers: hv: vmbus: Cleanup vmbus_set_event()"
++    - Drivers: hv: vmbus: Cleanup vmbus_set_event()
++    - Revert "Drivers: hv: vmbus: Eliminate the spin lock on the read path"
++    - Drivers: hv: vmbus: Eliminate the spin lock on the read path
++    - Revert "hv_netvsc: cleanup netdev feature flags for netvsc"
++    - hv_netvsc: cleanup netdev feature flags for netvsc
++    - hv_netvsc: Restore needed_headroom request
++    - kvm/x86: Rename Hyper-V long spin wait hypercall
++    - hv_netvsc: add software transmit timestamp support
++    - hv_netvsc: add ethtool support for set and get of settings
++    - hv_netvsc: Fix accessing freed memory in netvsc_change_mtu()
++    - hv_netvsc: Fix the array sizes to be max supported channels
++    - hv_netvsc: Fix the order of num_sc_offered decrement
++    - x86/hyperv: Avoid reporting bogus NMI status for Gen2 instances
++    - Drivers: hv: vmbus: Fix signaling logic in hv_need_to_signal_on_read()
++    - Drivers: hv: kvp: fix IP Failover
++
++ -- Seth Forshee <seth.forshee@canonical.com>  Tue, 19 Jul 2016 11:18:32 -0500
++
++linux (4.4.0-31.50) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1602449
++
++  * nouveau: boot hangs at blank screen with unsupported graphics cards
++    (LP: #1602340)
++    - SAUCE: drm: check for supported chipset before booting fbdev off the hw
++
++ -- Kamal Mostafa <kamal@canonical.com>  Tue, 12 Jul 2016 16:28:12 -0700
++
++linux (4.4.0-30.49) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1597897
++
++  * FCP devices are not detected correctly nor deterministically (LP: #1567602)
++    - scsi_dh_alua: Disable ALUA handling for non-disk devices
++    - scsi_dh_alua: Use vpd_pg83 information
++    - scsi_dh_alua: improved logging
++    - scsi_dh_alua: sanitze sense code handling
++    - scsi_dh_alua: use standard logging functions
++    - scsi_dh_alua: return standard SCSI return codes in submit_rtpg
++    - scsi_dh_alua: fixup description of stpg_endio()
++    - scsi_dh_alua: use flag for RTPG extended header
++    - scsi_dh_alua: use unaligned access macros
++    - scsi_dh_alua: rework alua_check_tpgs() to return the tpgs mode
++    - scsi_dh_alua: simplify sense code handling
++    - scsi: Add scsi_vpd_lun_id()
++    - scsi: Add scsi_vpd_tpg_id()
++    - scsi_dh_alua: use scsi_vpd_tpg_id()
++    - scsi_dh_alua: Remove stale variables
++    - scsi_dh_alua: Pass buffer as function argument
++    - scsi_dh_alua: separate out alua_stpg()
++    - scsi_dh_alua: Make stpg synchronous
++    - scsi_dh_alua: call alua_rtpg() if stpg fails
++    - scsi_dh_alua: switch to scsi_execute_req_flags()
++    - scsi_dh_alua: allocate RTPG buffer separately
++    - scsi_dh_alua: Use separate alua_port_group structure
++    - scsi_dh_alua: use unique device id
++    - scsi_dh_alua: simplify alua_initialize()
++    - revert commit a8e5a2d593cb ("[SCSI] scsi_dh_alua: ALUA handler attach should
++      succeed while TPG is transitioning")
++    - scsi_dh_alua: move optimize_stpg evaluation
++    - scsi_dh_alua: remove 'rel_port' from alua_dh_data structure
++    - scsi_dh_alua: Use workqueue for RTPG
++    - scsi_dh_alua: Allow workqueue to run synchronously
++    - scsi_dh_alua: Add new blacklist flag 'BLIST_SYNC_ALUA'
++    - scsi_dh_alua: Recheck state on unit attention
++    - scsi_dh_alua: update all port states
++    - scsi_dh_alua: Send TEST UNIT READY to poll for transitioning
++    - scsi_dh_alua: do not fail for unknown VPD identification
++
++ -- Kamal Mostafa <kamal@canonical.com>  Thu, 30 Jun 2016 12:52:15 -0700
++
++linux (4.4.0-29.48) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1597015
++
++  * Wireless hotkey fails on Dell XPS 15 9550 (LP: #1589886)
++    - intel-hid: new hid event driver for hotkeys
++    - intel-hid: fix incorrect entries in intel_hid_keymap
++    - intel-hid: allocate correct amount of memory for private struct
++    - intel-hid: add a workaround to ignore an event after waking up from S4.
++    - [Config] CONFIG_INTEL_HID_EVENT=m
++
++  * cgroupfs mounts can hang (LP: #1588056)
++    - Revert "UBUNTU: SAUCE: (namespace) mqueue: Super blocks must be owned by the
++      user ns which owns the ipc ns"
++    - Revert "UBUNTU: SAUCE: kernfs: Do not match superblock in another user
++      namespace when mounting"
++    - Revert "UBUNTU: SAUCE: cgroup: Use a new super block when mounting in a
++      cgroup namespace"
++    - (namespace) bpf: Use mount_nodev not mount_ns to mount the bpf filesystem
++    - (namespace) bpf, inode: disallow userns mounts
++    - (namespace) ipc: Initialize ipc_namespace->user_ns early.
++    - (namespace) vfs: Pass data, ns, and ns->userns to mount_ns
++    - SAUCE: (namespace) Sync with upstream s_user_ns patches
++    - (namespace) kernfs: The cgroup filesystem also benefits from SB_I_NOEXEC
++    - (namespace) ipc/mqueue: The mqueue filesystem should never contain
++      executables
++
++  * KVM system crashes after starting guest (LP: #1596635)
++    - xhci: Cleanup only when releasing primary hcd
++
++  * Upstream patch "crypto: vmx - IV size failing on skcipher API" for Ubuntu
++    16.04 (LP: #1596557)
++    - crypto: vmx - IV size failing on skcipher API
++
++  * [Bug]tpm initialization fails on x86 (LP: #1596469)
++    - tpm_crb: drop struct resource res from struct crb_priv
++    - tpm_crb: fix mapping of the buffers
++
++  * Device shutdown notification for CAPI Flash cards (LP: #1592114)
++    - cxlflash: Fix regression issue with re-ordering patch
++    - cxlflash: Fix to drain operations from previous reset
++    - cxlflash: Add device dependent flags
++    - cxlflash: Shutdown notify support for CXL Flash cards
++
++  * scsi-modules udeb should include pm80xx (LP: #1595628)
++    - [Config] Add pm80xx scsi driver to d-i
++
++  * Sync up latest relevant upstream bug fixes (LP: #1594871)
++    - SAUCE: (noup) Update zfs to 0.6.5.6-0ubuntu10
++
++  * Cannot compile module tda10071 (LP: #1592531)
++    - [media] tda10071: Fix dependency to REGMAP_I2C
++
++  * lsvpd doesn't show correct location code for devices attached to a CAPI card
++    (LP: #1594847)
++    - cxl: Make vPHB device node match adapter's
++
++  * enable CRC32 and AES ARM64 by default or as module (LP: #1594455)
++    - [Config] Enable arm64 AES and CRC32 crypto
++
++  * VMX kernel crypto module exhibits poor performance in Ubuntu 16.04
++    (LP: #1592481)
++    - crypto: vmx - comply with ABIs that specify vrsave as reserved.
++    - crypto: vmx - Fix ABI detection
++    - crypto: vmx - Increase priority of aes-cbc cipher
++
++  * build squashfs into xenial kernels by default (LP: #1593134)
++    - [Config] CONFIG_SQUASHFS=y
++
++  * Restore irqfd fast path for PPC (LP: #1592809)
++    - KVM: PPC: Book3S HV: Re-enable XICS fast path for irqfd-generated interrupts
++
++  * Unable to start guests with memballoon default. (LP: #1592042)
++    - virtio_balloon: fix PFN format for virtio-1
++
++  * Key 5 automatically pressed on some Logitech wireless keyboards
++    (LP: #1579190)
++    - HID: core: prevent out-of-bound readings
++
++  * ZFS: Running ztest repeatedly for long periods of time eventually results in
++    "zdb: can't open 'ztest': No such file or directory" (LP: #1587686)
++    - Fix ztest truncated cache file
++
++  * STC840.20:Alpine:alp7fp1:Ubuntu 16.04, BlueFin (SAN) EEH 6 times during boot
++    then disabled SRC BA188002:b0314a_1612.840 (LP: #1587316)
++    - lpfc: Fix DMA faults observed upon plugging loopback connector
++
++ -- Kamal Mostafa <kamal@canonical.com>  Tue, 28 Jun 2016 10:17:41 -0700
++
++linux (4.4.0-28.47) xenial; urgency=low
++
++  [ Luis Henriques ]
++
++  * Release Tracking Bug
++    - LP: #1595874
++
++  * Linux netfilter local privilege escalation issues (LP: #1595350)
++    - netfilter: x_tables: don't move to non-existent next rule
++    - netfilter: x_tables: validate targets of jumps
++    - netfilter: x_tables: add and use xt_check_entry_offsets
++    - netfilter: x_tables: kill check_entry helper
++    - netfilter: x_tables: assert minimum target size
++    - netfilter: x_tables: add compat version of xt_check_entry_offsets
++    - netfilter: x_tables: check standard target size too
++    - netfilter: x_tables: check for bogus target offset
++    - netfilter: x_tables: validate all offsets and sizes in a rule
++    - netfilter: x_tables: don't reject valid target size on some architectures
++    - netfilter: arp_tables: simplify translate_compat_table args
++    - netfilter: ip_tables: simplify translate_compat_table args
++    - netfilter: ip6_tables: simplify translate_compat_table args
++    - netfilter: x_tables: xt_compat_match_from_user doesn't need a retval
++    - netfilter: x_tables: do compat validation via translate_table
++    - netfilter: x_tables: introduce and use xt_copy_counters_from_user
++
++  * Linux netfilter IPT_SO_SET_REPLACE memory corruption (LP: #1555338)
++    - netfilter: x_tables: validate e->target_offset early
++    - netfilter: x_tables: make sure e->next_offset covers remaining blob size
++    - netfilter: x_tables: fix unconditional helper
++
++ -- Luis Henriques <luis.henriques@canonical.com>  Fri, 24 Jun 2016 09:57:21 +0100
++
++linux (4.4.0-27.46) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1594906
++
++  * Support Edge Gateway's Bluetooth LED (LP: #1512999)
++    - Revert "UBUNTU: SAUCE: Bluetooth: Support for LED on Marvell modules"
++
++ -- Kamal Mostafa <kamal@canonical.com>  Tue, 21 Jun 2016 10:17:00 -0700
++
++linux (4.4.0-26.45) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1594442
++
++  * linux: Implement secure boot state variables (LP: #1593075)
++    - SAUCE: UEFI: Add secure boot and MOK SB State disabled sysctl
++
++  * failures building userspace packages that include ethtool.h (LP: #1592930)
++    - ethtool.h: define INT_MAX for userland
++
++ -- Kamal Mostafa <kamal@canonical.com>  Mon, 20 Jun 2016 09:43:47 -0700
++
++linux (4.4.0-25.44) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1591289
++
++  * Xenial update to v4.4.13 stable release (LP: #1590455)
++    - MIPS64: R6: R2 emulation bugfix
++    - MIPS: math-emu: Fix jalr emulation when rd == $0
++    - MIPS: MSA: Fix a link error on `_init_msa_upper' with older GCC
++    - MIPS: Don't unwind to user mode with EVA
++    - MIPS: Avoid using unwind_stack() with usermode
++    - MIPS: Fix siginfo.h to use strict posix types
++    - MIPS: Fix uapi include in exported asm/siginfo.h
++    - MIPS: Fix watchpoint restoration
++    - MIPS: Flush highmem pages in __flush_dcache_page
++    - MIPS: Handle highmem pages in __update_cache
++    - MIPS: Sync icache & dcache in set_pte_at
++    - MIPS: ath79: make bootconsole wait for both THRE and TEMT
++    - MIPS: Reserve nosave data for hibernation
++    - MIPS: Loongson-3: Reserve 32MB for RS780E integrated GPU
++    - MIPS: Use copy_s.fmt rather than copy_u.fmt
++    - MIPS: Fix MSA ld_*/st_* asm macros to use PTR_ADDU
++    - MIPS: Prevent "restoration" of MSA context in non-MSA kernels
++    - MIPS: Disable preemption during prctl(PR_SET_FP_MODE, ...)
++    - MIPS: ptrace: Fix FP context restoration FCSR regression
++    - MIPS: ptrace: Prevent writes to read-only FCSR bits
++    - MIPS: Fix sigreturn via VDSO on microMIPS kernel
++    - MIPS: Build microMIPS VDSO for microMIPS kernels
++    - MIPS: lib: Mark intrinsics notrace
++    - MIPS: VDSO: Build with `-fno-strict-aliasing'
++    - affs: fix remount failure when there are no options changed
++    - ASoC: ak4642: Enable cache usage to fix crashes on resume
++    - Input: uinput - handle compat ioctl for UI_SET_PHYS
++    - ARM: mvebu: fix GPIO config on the Linksys boards
++    - ARM: dts: at91: fix typo in sama5d2 PIN_PD24 description
++    - ARM: dts: exynos: Add interrupt line to MAX8997 PMIC on exynos4210-trats
++    - ARM: dts: imx35: restore existing used clock enumeration
++    - ath9k: Add a module parameter to invert LED polarity.
++    - ath9k: Fix LED polarity for some Mini PCI AR9220 MB92 cards.
++    - ath10k: fix debugfs pktlog_filter write
++    - ath10k: fix firmware assert in monitor mode
++    - ath10k: fix rx_channel during hw reconfigure
++    - ath10k: fix kernel panic, move arvifs list head init before htt init
++    - ath5k: Change led pin configuration for compaq c700 laptop
++    - hwrng: exynos - Fix unbalanced PM runtime put on timeout error path
++    - rtlwifi: rtl8723be: Add antenna select module parameter
++    - rtlwifi: btcoexist: Implement antenna selection
++    - rtlwifi: Fix logic error in enter/exit power-save mode
++    - rtlwifi: pci: use dev_kfree_skb_irq instead of kfree_skb in
++      rtl_pci_reset_trx_ring
++    - aacraid: Relinquish CPU during timeout wait
++    - aacraid: Fix for aac_command_thread hang
++    - aacraid: Fix for KDUMP driver hang
++    - hwmon: (ads7828) Enable internal reference
++    - mfd: intel-lpss: Save register context on suspend
++    - mfd: intel_soc_pmic_core: Terminate panel control GPIO lookup table
++      correctly
++    - PM / Runtime: Fix error path in pm_runtime_force_resume()
++    - cpuidle: Indicate when a device has been unregistered
++    - cpuidle: Fix cpuidle_state_is_coupled() argument in cpuidle_enter()
++    - clk: bcm2835: Fix PLL poweron
++    - clk: at91: fix check of clk_register() returned value
++    - clk: bcm2835: pll_off should only update CM_PLL_ANARST
++    - clk: bcm2835: divider value has to be 1 or more
++    - pinctrl: exynos5440: Use off-stack memory for pinctrl_gpio_range
++    - PCI: Disable all BAR sizing for devices with non-compliant BARs
++    - media: v4l2-compat-ioctl32: fix missing reserved field copy in
++      put_v4l2_create32
++    - mm: use phys_addr_t for reserve_bootmem_region() arguments
++    - wait/ptrace: assume __WALL if the child is traced
++    - QE-UART: add "fsl,t1040-ucc-uart" to of_device_id
++    - powerpc/book3s64: Fix branching to OOL handlers in relocatable kernel
++    - powerpc/eeh: Don't report error in eeh_pe_reset_and_recover()
++    - powerpc/eeh: Restore initial state in eeh_pe_reset_and_recover()
++    - xen/events: Don't move disabled irqs
++    - xen: use same main loop for counting and remapping pages
++    - sunrpc: fix stripping of padded MIC tokens
++    - drm/gma500: Fix possible out of bounds read
++    - drm/vmwgfx: Enable SVGA_3D_CMD_DX_SET_PREDICATION
++    - drm/vmwgfx: use vmw_cmd_dx_cid_check for query commands.
++    - drm/vmwgfx: Fix order of operation
++    - drm/amdgpu: use drm_mode_vrefresh() rather than mode->vrefresh
++    - drm/amdgpu: Fix hdmi deep color support.
++    - drm/i915/fbdev: Fix num_connector references in intel_fb_initial_config()
++    - drm/fb_helper: Fix references to dev->mode_config.num_connector
++    - drm/atomic: Verify connector->funcs != NULL when clearing states
++    - drm/i915: Don't leave old junk in ilk active watermarks on readout
++    - drm/imx: Match imx-ipuv3-crtc components using device node in platform data
++    - ext4: fix hang when processing corrupted orphaned inode list
++    - ext4: clean up error handling when orphan list is corrupted
++    - ext4: fix oops on corrupted filesystem
++    - ext4: address UBSAN warning in mb_find_order_for_block()
++    - ext4: silence UBSAN in ext4_mb_init()
++    - PM / sleep: Handle failures in device_suspend_late() consistently
++    - dma-debug: avoid spinlock recursion when disabling dma-debug
++    - scripts/package/Makefile: rpmbuild add support of RPMOPTS
++    - gcov: disable tree-loop-im to reduce stack usage
++    - xfs: disallow rw remount on fs with unknown ro-compat features
++    - xfs: Don't wrap growfs AGFL indexes
++    - xfs: xfs_iflush_cluster fails to abort on error
++    - xfs: fix inode validity check in xfs_iflush_cluster
++    - xfs: skip stale inodes in xfs_iflush_cluster
++    - xfs: print name of verifier if it fails
++    - xfs: handle dquot buffer readahead in log recovery correctly
++    - Linux 4.4.13
++
++  * 168c:001c [HP Compaq Presario C700 Notebook PC] Wireless led button doesn't
++    switch colors (LP: #972604)
++    - ath5k: Change led pin configuration for compaq c700 laptop
++
++  * Extended statistics from balloon for proper memory management (LP: #1587091)
++    - mm/page_alloc.c: calculate 'available' memory in a separate function
++    - virtio_balloon: export 'available' memory to balloon statistics
++
++  * CAPI: CGZIP AFU contexts do not receive interrupts after heavy afu
++    open/close (LP: #1588468)
++    - misc: cxl: use kobj_to_dev()
++    - cxl: Move common code away from bare-metal-specific files
++    - cxl: Move bare-metal specific code to specialized files
++    - cxl: Define process problem state area at attach time only
++    - cxl: Introduce implementation-specific API
++    - cxl: Rename some bare-metal specific functions
++    - cxl: Isolate a few bare-metal-specific calls
++    - cxl: Update cxl_irq() prototype
++    - cxl: IRQ allocation for guests
++    - powerpc: New possible return value from hcall
++    - cxl: New hcalls to support cxl adapters
++    - cxl: Separate bare-metal fields in adapter and AFU data structures
++    - cxlflash: Simplify PCI registration
++    - cxlflash: Unmap problem state area before detaching master context
++    - cxlflash: Split out context initialization
++    - cxlflash: Simplify attach path error cleanup
++    - cxlflash: Reorder user context initialization
++    - cxl: Add guest-specific code
++    - cxl: sysfs support for guests
++    - cxl: Support to flash a new image on the adapter from a guest
++    - cxl: Parse device tree and create cxl device(s) at boot
++    - cxl: Support the cxl kernel API from a guest
++    - cxl: Adapter failure handling
++    - cxl: Add tracepoints around the cxl hcall
++    - cxlflash: Use new cxl_pci_read_adapter_vpd() API
++    - cxl: Remove cxl_get_phys_dev() kernel API
++    - cxl: Ignore probes for virtual afu pci devices
++    - cxl: Poll for outstanding IRQs when detaching a context
++
++  * NVMe max_segments queue parameter gets set to 1 (LP: #1588449)
++    - nvme: set queue limits for the admin queue
++    - nvme: fix max_segments integer truncation
++    - block: fix blk_rq_get_max_sectors for driver private requests
++
++  * workaround cavium thunderx silicon erratum 23144 (LP: #1589704)
++    - irqchip/gicv3-its: numa: Enable workaround for Cavium thunderx erratum 23144
++
++  * Xenial update to v4.4.12 stable release (LP: #1588945)
++    - Btrfs: don't use src fd for printk
++    - perf/x86/intel/pt: Generate PMI in the STOP region as well
++    - perf/core: Fix perf_event_open() vs. execve() race
++    - perf test: Fix build of BPF and LLVM on older glibc libraries
++    - ext4: iterate over buffer heads correctly in move_extent_per_page()
++    - arm64: Fix typo in the pmdp_huge_get_and_clear() definition
++    - arm64: Ensure pmd_present() returns false after pmd_mknotpresent()
++    - arm64: Implement ptep_set_access_flags() for hardware AF/DBM
++    - arm64: Implement pmdp_set_access_flags() for hardware AF/DBM
++    - arm64: cpuinfo: Missing NULL terminator in compat_hwcap_str
++    - arm/arm64: KVM: Enforce Break-Before-Make on Stage-2 page tables
++    - kvm: arm64: Fix EC field in inject_abt64
++    - remove directory incorrectly tries to set delete on close on non-empty
++      directories
++    - fs/cifs: correctly to anonymous authentication via NTLMSSP
++    - fs/cifs: correctly to anonymous authentication for the LANMAN authentication
++    - fs/cifs: correctly to anonymous authentication for the NTLM(v1)
++      authentication
++    - fs/cifs: correctly to anonymous authentication for the NTLM(v2)
++      authentication
++    - asix: Fix offset calculation in asix_rx_fixup() causing slow transmissions
++    - ring-buffer: Use long for nr_pages to avoid overflow failures
++    - ring-buffer: Prevent overflow of size in ring_buffer_resize()
++    - crypto: caam - fix caam_jr_alloc() ret code
++    - crypto: talitos - fix ahash algorithms registration
++    - crypto: sun4i-ss - Replace spinlock_bh by spin_lock_irq{save|restore}
++    - clk: qcom: msm8916: Fix crypto clock flags
++    - sched/loadavg: Fix loadavg artifacts on fully idle and on fully loaded
++      systems
++    - mfd: omap-usb-tll: Fix scheduling while atomic BUG
++    - Input: pwm-beeper - fix - scheduling while atomic
++    - irqchip/gic: Ensure ordering between read of INTACK and shared data
++    - irqchip/gic-v3: Configure all interrupts as non-secure Group-1
++    - can: fix handling of unmodifiable configuration options
++    - mmc: mmc: Fix partition switch timeout for some eMMCs
++    - mmc: sdhci-acpi: Remove MMC_CAP_BUS_WIDTH_TEST for Intel controllers
++    - ACPI / osi: Fix an issue that acpi_osi=!* cannot disable ACPICA internal
++      strings
++    - dell-rbtn: Ignore ACPI notifications if device is suspended
++    - mmc: longer timeout for long read time quirk
++    - mmc: sdhci-pci: Remove MMC_CAP_BUS_WIDTH_TEST for Intel controllers
++    - Bluetooth: vhci: fix open_timeout vs. hdev race
++    - Bluetooth: vhci: purge unhandled skbs
++    - Bluetooth: vhci: Fix race at creating hci device
++    - mei: fix NULL dereferencing during FW initiated disconnection
++    - mei: amthif: discard not read messages
++    - mei: bus: call mei_cl_read_start under device lock
++    - USB: serial: mxuport: fix use-after-free in probe error path
++    - USB: serial: keyspan: fix use-after-free in probe error path
++    - USB: serial: quatech2: fix use-after-free in probe error path
++    - USB: serial: io_edgeport: fix memory leaks in attach error path
++    - USB: serial: io_edgeport: fix memory leaks in probe error path
++    - USB: serial: option: add support for Cinterion PH8 and AHxx
++    - USB: serial: option: add more ZTE device ids
++    - USB: serial: option: add even more ZTE device ids
++    - usb: gadget: f_fs: Fix EFAULT generation for async read operations
++    - usb: f_mass_storage: test whether thread is running before starting another
++    - usb: misc: usbtest: fix pattern tests for scatterlists.
++    - usb: gadget: udc: core: Fix argument of dev_err() in
++      usb_gadget_map_request()
++    - staging: comedi: das1800: fix possible NULL dereference
++    - KVM: x86: fix ordering of cr0 initialization code in vmx_cpu_reset
++    - MIPS: KVM: Fix timer IRQ race when freezing timer
++    - MIPS: KVM: Fix timer IRQ race when writing CP0_Compare
++    - KVM: x86: mask CPUID(0xD,0x1).EAX against host value
++    - xen/x86: actually allocate legacy interrupts on PV guests
++    - tty: vt, return error when con_startup fails
++    - TTY: n_gsm, fix false positive WARN_ON
++    - tty/serial: atmel: fix hardware handshake selection
++    - Fix OpenSSH pty regression on close
++    - serial: 8250_pci: fix divide error bug if baud rate is 0
++    - serial: 8250_mid: use proper bar for DNV platform
++    - serial: 8250_mid: recognize interrupt source in handler
++    - serial: samsung: Reorder the sequence of clock control when call
++      s3c24xx_serial_set_termios()
++    - locking,qspinlock: Fix spin_is_locked() and spin_unlock_wait()
++    - clk: bcm2835: add locking to pll*_on/off methods
++    - mcb: Fixed bar number assignment for the gdd
++    - ALSA: hda/realtek - New codecs support for ALC234/ALC274/ALC294
++    - ALSA: hda - Fix headphone noise on Dell XPS 13 9360
++    - ALSA: hda/realtek - Add support for ALC295/ALC3254
++    - ALSA: hda - Fix headset mic detection problem for one Dell machine
++    - IB/srp: Fix a debug kernel crash
++    - thunderbolt: Fix double free of drom buffer
++    - SIGNAL: Move generic copy_siginfo() to signal.h
++    - UBI: Fix static volume checks when Fastmap is used
++    - hpfs: fix remount failure when there are no options changed
++    - hpfs: implement the show_options method
++    - scsi: Add intermediate STARGET_REMOVE state to scsi_target_state
++    - Revert "scsi: fix soft lockup in scsi_remove_target() on module removal"
++    - kbuild: move -Wunused-const-variable to W=1 warning level
++    - Linux 4.4.12
++
++  * [Hyper-V] fixes for kdump when running on a VM (LP: #1588965)
++    - clocksource: Allow unregistering the watchdog
++
++  * net_admin apparmor denial when using Go (LP: #1465724)
++    - SAUCE: kernel: Add noaudit variant of ns_capable()
++    - SAUCE: net: Use ns_capable_noaudit() when determining net sysctl permissions
++
++  * [Hyper-V] Put tools/hv/lsvmbus in /usr/sbin (LP: #1585311)
++    - [Debian] Install lsvmbus in cloud tools
++    - SAUCE: tools/hv/lsvmbus -- convert to python3
++    - SAUCE: tools/hv/lsvmbus -- add manual page
++
++  * btrfs: file write crashes with false ENOSPC during snapshot creation since
++    kernel 4.4 - fix available (LP: #1584052)
++    - btrfs: Continue write in case of can_not_nocow
++
++  * boot stalls on USB detection errors (LP: #1437492)
++    - usb: core: hub: hub_port_init lock controller instead of bus
++
++  * [Bug]KNL:Spread MWAIT cache lines over all nodes (LP: #1585850)
++    - kernek/fork.c: allocate idle task for a CPU always on its local node
++
++  * [Hyper-V] PCI Passthrough kernel hang and explicit barriers (LP: #1581243)
++    - PCI: hv: Report resources release after stopping the bus
++    - PCI: hv: Add explicit barriers to config space access
++
++  * Kernel 4.2.X and 4.4.X - Fix USB3.0 link power management (LPM)
++    claim/release logic in USBFS (LP: #1577024)
++    - USB: leave LPM alone if possible when binding/unbinding interface drivers
++
++  * STC840.20:tuleta:tul516p01 panic after injecting Leaf EEH (LP: #1581034)
++    - NVMe: Fix namespace removal deadlock
++    - NVMe: Requeue requests on suspended queues
++    - NVMe: Move error handling to failed reset handler
++    - blk-mq: End unstarted requests on dying queue
++
++  * conflicting modules in udebs - arc4.ko (LP: #1582991)
++    - [Config] Remove arc4 from nic-modules
++
++  * CVE-2016-4482 (LP: #1578493)
++    - USB: usbfs: fix potential infoleak in devio
++
++  * mlx5_core kexec fail  (LP: #1585978)
++    - net/mlx5: Add pci shutdown callback
++
++  * backport fix for /proc/net issues with containers (LP: #1584953)
++    - netfilter: Set /proc/net entries owner to root in namespace
++
++  * CVE-2016-4951 (LP: #1585365)
++    - tipc: check nl sock before parsing nested attributes
++
++  * CVE-2016-4578 (LP: #1581866)
++    - ALSA: timer: Fix leak in events via snd_timer_user_ccallback
++    - ALSA: timer: Fix leak in events via snd_timer_user_tinterrupt
++
++  * CVE-2016-4569 (LP: #1580379)
++    - ALSA: timer: Fix leak in SNDRV_TIMER_IOCTL_PARAMS
++
++  * s390/pci: fix use after free in dma_init (LP: #1584828)
++    - s390/pci: fix use after free in dma_init
++
++  * s390/mm: fix asce_bits handling with dynamic pagetable levels (LP: #1584827)
++    - s390/mm: fix asce_bits handling with dynamic pagetable levels
++
++  * CAPI: CGZIP Wrong CAPI MMIO timeout (256usec desired but 1usec default
++    setting in cxl.ko driver) (LP: #1584066)
++    - powerpc: Define PVR value for POWER8NVL processor
++    - cxl: Configure the PSL for two CAPI ports on POWER8NVL
++    - cxl: Increase timeout for detection of AFU mmio hang
++
++  * ThunderX: soft lockup in cursor_timer_handler() (LP: #1574814)
++    - SAUCE: tty: vt: Fix soft lockup in fbcon cursor blink timer.
++
++  * debian.master/.../getabis bogus warnings "inconsistant compiler versions"
++    and "not a git repository" (LP: #1584890)
++    - [debian] getabis: Only git add $abidir if running in local repo
++    - [debian] getabis: Fix inconsistent compiler versions check
++
++  * Backport cxlflash patch related to EEH recovery into Xenial SRU stream
++    (LP: #1584935)
++    - cxlflash: Fix to resolve dead-lock during EEH recovery
++
++  * Xenial update to 4.4.11 stable release (LP: #1584912)
++    - decnet: Do not build routes to devices without decnet private data.
++    - route: do not cache fib route info on local routes with oif
++    - packet: fix heap info leak in PACKET_DIAG_MCLIST sock_diag interface
++    - net: sched: do not requeue a NULL skb
++    - bpf/verifier: reject invalid LD_ABS | BPF_DW instruction
++    - cdc_mbim: apply "NDP to end" quirk to all Huawei devices
++    - net: use skb_postpush_rcsum instead of own implementations
++    - vlan: pull on __vlan_insert_tag error path and fix csum correction
++    - openvswitch: use flow protocol when recalculating ipv6 checksums
++    - ipv4/fib: don't warn when primary address is missing if in_dev is dead
++    - net/mlx4_en: fix spurious timestamping callbacks
++    - bpf: fix check_map_func_compatibility logic
++    - samples/bpf: fix trace_output example
++    - net: Implement net_dbg_ratelimited() for CONFIG_DYNAMIC_DEBUG case
++    - gre: do not pull header in ICMP error processing
++    - net_sched: introduce qdisc_replace() helper
++    - net_sched: update hierarchical backlog too
++    - sch_htb: update backlog as well
++    - sch_dsmark: update backlog as well
++    - netem: Segment GSO packets on enqueue
++    - net: fec: only clear a queue's work bit if the queue was emptied
++    - VSOCK: do not disconnect socket when peer has shutdown SEND only
++    - net: bridge: fix old ioctl unlocked net device walk
++    - bridge: fix igmp / mld query parsing
++    - uapi glibc compat: fix compile errors when glibc net/if.h included before
++      linux/if.h MIME-Version: 1.0
++    - net: fix a kernel infoleak in x25 module
++    - net: thunderx: avoid exposing kernel stack
++    - tcp: refresh skb timestamp at retransmit time
++    - net/route: enforce hoplimit max value
++    - ocfs2: revert using ocfs2_acl_chmod to avoid inode cluster lock hang
++    - ocfs2: fix posix_acl_create deadlock
++    - zsmalloc: fix zs_can_compact() integer overflow
++    - crypto: qat - fix invalid pf2vf_resp_wq logic
++    - crypto: hash - Fix page length clamping in hash walk
++    - crypto: testmgr - Use kmalloc memory for RSA input
++    - ALSA: usb-audio: Quirk for yet another Phoenix Audio devices (v2)
++    - ALSA: usb-audio: Yet another Phoneix Audio device quirk
++    - ALSA: hda - Fix subwoofer pin on ASUS N751 and N551
++    - ALSA: hda - Fix white noise on Asus UX501VW headset
++    - ALSA: hda - Fix broken reconfig
++    - spi: pxa2xx: Do not detect number of enabled chip selects on Intel SPT
++    - spi: spi-ti-qspi: Fix FLEN and WLEN settings if bits_per_word is overridden
++    - spi: spi-ti-qspi: Handle truncated frames properly
++    - pinctrl: at91-pio4: fix pull-up/down logic
++    - regmap: spmi: Fix regmap_spmi_ext_read in multi-byte case
++    - perf/core: Disable the event on a truncated AUX record
++    - vfs: add vfs_select_inode() helper
++    - vfs: rename: check backing inode being equal
++    - ARM: dts: at91: sam9x5: Fix the memory range assigned to the PMC
++    - workqueue: fix rebind bound workers warning
++    - regulator: s2mps11: Fix invalid selector mask and voltages for buck9
++    - regulator: axp20x: Fix axp22x ldo_io voltage ranges
++    - atomic_open(): fix the handling of create_error
++    - qla1280: Don't allocate 512kb of host tags
++    - tools lib traceevent: Do not reassign parg after collapse_tree()
++    - get_rock_ridge_filename(): handle malformed NM entries
++    - Input: max8997-haptic - fix NULL pointer dereference
++    - Revert "[media] videobuf2-v4l2: Verify planes array in buffer dequeueing"
++    - drm/radeon: fix PLL sharing on DCE6.1 (v2)
++    - drm/i915: Bail out of pipe config compute loop on LPT
++    - drm/i915/bdw: Add missing delay during L3 SQC credit programming
++    - drm/radeon: fix DP link training issue with second 4K monitor
++    - nf_conntrack: avoid kernel pointer value leak in slab name
++    - Linux 4.4.11
++
++  * Support Edge Gateway's Bluetooth LED (LP: #1512999)
++    - SAUCE: Bluetooth: Support for LED on Marvell modules
++
++  * Support Edge Gateway's WIFI LED (LP: #1512997)
++    - SAUCE: mwifiex: Switch WiFi LED state according to the device status
++
++  * Marvell wireless driver update for FCC regulation (LP: #1528910)
++    - mwifiex: parse adhoc start/join result
++    - mwifiex: handle start AP error paths correctly
++    - mwifiex: set regulatory info from EEPROM
++    - mwifiex: don't follow AP if country code received from EEPROM
++    - mwifiex: correction in region code to country mapping
++    - mwifiex: update region_code_index array
++    - mwifiex: use world for unidentified region code
++    - SAUCE: mwifiex: add iw vendor command support
++
++  * Kernel can be oopsed using remap_file_pages (LP: #1558120)
++    - Revert "UBUNTU: SAUCE: mm/mmap: fix oopsing on remap_file_pages"
++    - SAUCE: AUFS: mm/mmap: fix oopsing on remap_file_pages aufs mmap: bugfix,
++      mainly for linux-4.5-rc5, remap_file_pages(2) emulation
++
++  * cgroup namespace update (LP: #1584163)
++    - Revert "UBUNTU: SAUCE: cgroup mount: ignore nsroot="
++    - Revert "UBUNTU: SAUCE: (noup) cgroup namespaces: add a 'nsroot=' mountinfo
++      field"
++    - cgroup, kernfs: make mountinfo show properly scoped path for cgroup
++      namespaces
++    - kernfs: kernfs_sop_show_path: don't return 0 after seq_dentry call
++    - cgroup: fix compile warning
++
++  * Missing libunwind support in perf (LP: #1248289)
++    - [Config] add binutils-dev to the Build-Depends: to fix perf unwinding
++
++  * e1000 Tx Unit Hang  (LP: #1582328)
++    - e1000: Double Tx descriptors needed check for 82544
++    - e1000: Do not overestimate descriptor counts in Tx pre-check
++
++  * Unsharing user and ipc namespaces simultaneously makes mqueue unmountable
++    (LP: #1582378)
++    - SAUCE: (namespace) mqueue: Super blocks must be owned by the user ns which
++      owns the ipc ns
++
++  * Pull in the amdgpu/radeon code from Linux 4.5.3 (LP: #1580526)
++    - drm/radeon: rework fbdev handling on chips with no connectors
++    - drm/radeon/mst: fix regression in lane/link handling.
++    - drm/amd/powerplay: add uvd/vce dpm enabling flag to fix the performance
++      issue for CZ
++    - drm/amd/powerplay: fix segment fault issue in multi-display case.
++    - drm/ttm: fix kref count mess in ttm_bo_move_to_lru_tail
++
++  * aufs CONFIG_AUFS_EXPORT build option should be enabled (LP: #1121699)
++    - [Config] enable CONFIG_AUFS_EXPORT
++
++  * promote *_diag modules from linux-image-extra to linux-image (LP: #1580355)
++    - [Config] Update inclusion list for CRIU
++
++  * [Xenial] net: updates to ethtool and virtio_net for speed/duplex support
++    (LP: #1581132)
++    - ethtool: add speed/duplex validation functions
++    - ethtool: make validate_speed accept all speeds between 0 and INT_MAX
++    - virtio_net: add ethtool support for set and get of settings
++    - virtio_net: validate ethtool port setting and explain the user validation
++
++  * perf tool: Display event codes for Generic HW (PMU) events (LP: #1578211)
++    - powerpc/perf: Remove PME_ prefix for power7 events
++    - powerpc/perf: Export Power8 generic and cache events to sysfs
++
++  * Mellanox ConnectX4 MTU limits: max and min (LP: #1528466)
++    - net/mlx5: Introduce a new header file for physical port functions
++    - net/mlx5e: Device's mtu field is u16 and not int
++    - net/mlx5e: Fix minimum MTU
++
++  * Miscellaneous Ubuntu changes
++    - [Config] CONFIG_CAVIUM_ERRATUM_23144=y
++
++ -- Kamal Mostafa <kamal@canonical.com>  Fri, 10 Jun 2016 10:07:13 -0700
++
++linux (4.4.0-24.43) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * CVE-2016-1583 (LP: #1588871)
++    - ecryptfs: fix handling of directory opening
++    - SAUCE: proc: prevent stacking filesystems on top
++    - SAUCE: ecryptfs: forbid opening files without mmap handler
++    - SAUCE: sched: panic on corrupted stack end
++
++  * arm64: statically link rtc-efi (LP: #1583738)
++    - [Config] Link rtc-efi statically on arm64
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 08 Jun 2016 20:01:12 +0100
++
++linux (4.4.0-23.41) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1582431
++
++  * zfs: disable module checks for zfs when cross-compiling (LP: #1581127)
++    - [Packaging] disable zfs module checks when cross-compiling
++
++  * Xenial update to v4.4.10 stable release (LP: #1580754)
++    - Revert "UBUNTU: SAUCE: (no-up) ACPICA: Dispatcher: Update thread ID for
++      recursive method calls"
++    - Revert "UBUNTU: SAUCE: nbd: ratelimit error msgs after socket close"
++    - Revert: "powerpc/tm: Check for already reclaimed tasks"
++    - RDMA/iw_cxgb4: Fix bar2 virt addr calculation for T4 chips
++    - ipvs: handle ip_vs_fill_iph_skb_off failure
++    - ipvs: correct initial offset of Call-ID header search in SIP persistence
++      engine
++    - ipvs: drop first packet to redirect conntrack
++    - mfd: intel-lpss: Remove clock tree on error path
++    - nbd: ratelimit error msgs after socket close
++    - ata: ahci_xgene: dereferencing uninitialized pointer in probe
++    - mwifiex: fix corner case association failure
++    - CNS3xxx: Fix PCI cns3xxx_write_config()
++    - clk-divider: make sure read-only dividers do not write to their register
++    - soc: rockchip: power-domain: fix err handle while probing
++    - clk: rockchip: free memory in error cases when registering clock branches
++    - clk: meson: Fix meson_clk_register_clks() signature type mismatch
++    - clk: qcom: msm8960: fix ce3_core clk enable register
++    - clk: versatile: sp810: support reentrance
++    - clk: qcom: msm8960: Fix ce3_src register offset
++    - lpfc: fix misleading indentation
++    - ath9k: ar5008_hw_cmn_spur_mitigate: add missing mask_m & mask_p
++      initialisation
++    - mac80211: fix statistics leak if dev_alloc_name() fails
++    - tracing: Don't display trigger file for events that can't be enabled
++    - MD: make bio mergeable
++    - Minimal fix-up of bad hashing behavior of hash_64()
++    - mm, cma: prevent nr_isolated_* counters from going negative
++    - mm/zswap: provide unique zpool name
++    - ARM: EXYNOS: Properly skip unitialized parent clock in power domain on
++    - ARM: SoCFPGA: Fix secondary CPU startup in thumb2 kernel
++    - xen: Fix page <-> pfn conversion on 32 bit systems
++    - xen/balloon: Fix crash when ballooning on x86 32 bit PAE
++    - xen/evtchn: fix ring resize when binding new events
++    - HID: wacom: Add support for DTK-1651
++    - HID: Fix boot delay for Creative SB Omni Surround 5.1 with quirk
++    - Input: zforce_ts - fix dual touch recognition
++    - proc: prevent accessing /proc/<PID>/environ until it's ready
++    - mm: update min_free_kbytes from khugepaged after core initialization
++    - batman-adv: fix DAT candidate selection (must use vid)
++    - batman-adv: Check skb size before using encapsulated ETH+VLAN header
++    - batman-adv: Fix broadcast/ogm queue limit on a removed interface
++    - batman-adv: Reduce refcnt of removed router when updating route
++    - writeback: Fix performance regression in wb_over_bg_thresh()
++    - MAINTAINERS: Remove asterisk from EFI directory names
++    - x86/tsc: Read all ratio bits from MSR_PLATFORM_INFO
++    - ARM: cpuidle: Pass on arm_cpuidle_suspend()'s return value
++    - ARC: Add missing io barriers to io{read,write}{16,32}be()
++    - x86/sysfb_efi: Fix valid BAR address range check
++    - ACPICA: Dispatcher: Update thread ID for recursive method calls
++    - powerpc: Fix bad inline asm constraint in create_zero_mask()
++    - libahci: save port map for forced port map
++    - ata: ahci-platform: Add ports-implemented DT bindings.
++    - USB: serial: cp210x: add ID for Link ECU
++    - USB: serial: cp210x: add Straizona Focusers device ids
++    - nvmem: mxs-ocotp: fix buffer overflow in read
++    - gpu: ipu-v3: Fix imx-ipuv3-crtc module autoloading
++    - drm/amdgpu: make sure vertical front porch is at least 1
++    - drm/amdgpu: set metadata pointer to NULL after freeing.
++    - iio: ak8975: Fix NULL pointer exception on early interrupt
++    - iio: ak8975: fix maybe-uninitialized warning
++    - drm/radeon: make sure vertical front porch is at least 1
++    - drm/i915/ddi: Fix eDP VDD handling during booting and suspend/resume
++    - drm/i915: Fix eDP low vswing for Broadwell
++    - drm/i915: Make RPS EI/thresholds multiple of 25 on SNB-BDW
++    - drm/i915: Fake HDMI live status
++    - lib/test-string_helpers.c: fix and improve string_get_size() tests
++    - drm/i915/skl: Fix DMC load on Skylake J0 and K0
++    - Linux 4.4.10
++
++  * HDMI audio playback noise  observed on AMD Polaris 10/11 GPU (LP: #1577288)
++    - ALSA: hda: add AMD Polaris-10/11 AZ PCI IDs with proper driver caps
++
++  * [i915_bpo] Update i915 backport driver (LP: #1580114)
++    - SAUCE: i915_bpo: Drop is_preliminary from BXT/KBL.
++    - SAUCE: i915_bpo: Sync with v4.6-rc7
++
++  * CVE-2016-4486 (LP: #1578497)
++    - net: fix infoleak in rtnetlink
++
++  * CVE-2016-4485 (LP: #1578496)
++    - net: fix infoleak in llc
++
++  * drm.ko < kernel version 4.5 has a dead lock bug (LP: #1579610)
++    - drm: Balance error path for GEM handle allocation
++
++  * Cannot use CONFIG_CC_STACKPROTECTOR_STRONG: -fstack-protector-strong not
++    supported by compiler (LP: #1574982)
++    - SAUCE: (no-up) disable -pie when gcc has it enabled by default
++
++  * system freeze after vt switching (LP: #1542939)
++    - drm/atomic: Add __drm_atomic_helper_connector_reset, v2.
++    - drm/atomic: Remove drm_atomic_connectors_for_crtc.
++
++  * CVE-2016-4558 (LP: #1579140)
++    - bpf: fix refcnt overflow
++
++  * Kernel Panic on EC2 After Upgrading from 14.04 to 16.04 via do-release-
++    upgrade -d (LP: #1573231)
++    - SAUCE: (no-up) x86/topology: Handle CPUID bogosity gracefully
++
++  * PCI Call Traces  hw csum failure in dmesg with  4.4.0-2-generic
++    (LP: #1544978)
++    - net/mlx4_en: Fix endianness bug in IPV6 csum calculation
++
++  * Missing libunwind support in perf (LP: #1248289)
++    - [Config] Add liblzma-dev to enable libunwind support in perf
++
++  * thunderbolt hotplug is broken (LP: #1577898)
++    - SAUCE: (no-up) ACPICA: Dispatcher: Update thread ID for recursive method
++      calls
++
++  * Kernel can be oopsed using remap_file_pages (LP: #1558120)
++    - SAUCE: mm/mmap: fix oopsing on remap_file_pages
++
++  * ZFS is confused by user namespaces (uid/gid mapping) when used with
++    acltype=posixac (LP: #1567558)
++    - zfs: Fix user namespaces uid/gid mapping
++
++  * oops when propagating mounts into containers - RIP:
++    0010:[<ffffffff8123cb3e>] [<ffffffff8123cb3e>] propagate_one+0xbe/0x1c0
++    (LP: #1572316)
++    - fs/pnode.c: treat zero mnt_group_id-s as unequal
++    - propogate_mnt: Handle the first propogated copy being a slave
++
++  * OOPS on wily+ for Haswell-ULT and Broadwell (LP: #1577748)
++    - PNP: Add Broadwell to Intel MCH size workaround
++    - PNP: Add Haswell-ULT to Intel MCH size workaround
++
++  * Xenial update to v4.4.9 stable release (LP: #1578798)
++    - block: loop: fix filesystem corruption in case of aio/dio
++    - x86/mce: Avoid using object after free in genpool
++    - kvm: x86: do not leak guest xcr0 into host interrupt handlers
++    - ARM: dts: AM43x-epos: Fix clk parent for synctimer
++    - ARM: mvebu: Correct unit address for linksys
++    - ARM: OMAP2: Fix up interconnect barrier initialization for DRA7
++    - ARM: OMAP2+: hwmod: Fix updating of sysconfig register
++    - assoc_array: don't call compare_object() on a node
++    - usb: xhci: applying XHCI_PME_STUCK_QUIRK to Intel BXT B0 host
++    - xhci: resume USB 3 roothub first
++    - usb: xhci: fix wild pointers in xhci_mem_cleanup
++    - xhci: fix 10 second timeout on removal of PCI hotpluggable xhci controllers
++    - usb: hcd: out of bounds access in for_each_companion
++    - usb: gadget: f_fs: Fix use-after-free
++    - dm cache metadata: fix READ_LOCK macros and cleanup WRITE_LOCK macros
++    - dm cache metadata: fix cmd_read_lock() acquiring write lock
++    - lib: lz4: fixed zram with lz4 on big endian machines
++    - debugfs: Make automount point inodes permanently empty
++    - dmaengine: dw: fix master selection
++    - dmaengine: hsu: correct use of channel status register
++    - dmaengine: pxa_dma: fix the maximum requestor line
++    - sched/cgroup: Fix/cleanup cgroup teardown/init
++    - x86/mm/xen: Suppress hugetlbfs in PV guests
++    - x86 EDAC, sb_edac.c: Repair damage introduced when "fixing" channel address
++    - ALSA: hda - Don't trust the reported actual power state
++    - ALSA: hda/realtek - Add ALC3234 headset mode for Optiplex 9020m
++    - ALSA: hda - Keep powering up ADCs on Cirrus codecs
++    - ALSA: hda - add PCI ID for Intel Broxton-T
++    - ALSA: pcxhr: Fix missing mutex unlock
++    - ALSA: hda - Add dock support for ThinkPad X260
++    - asm-generic/futex: Re-enable preemption in futex_atomic_cmpxchg_inatomic()
++    - futex: Handle unlock_pi race gracefully
++    - futex: Acknowledge a new waiter in counter before plist
++    - drm/nouveau/core: use vzalloc for allocating ramht
++    - drm/qxl: fix cursor position with non-zero hotspot
++    - drm/i915: Fix race condition in intel_dp_destroy_mst_connector()
++    - Revert "drm/radeon: disable runtime pm on PX laptops without dGPU power
++      control"
++    - Revert "drm/amdgpu: disable runtime pm on PX laptops without dGPU power
++      control"
++    - cpufreq: intel_pstate: Fix processing for turbo activation ratio
++    - iwlwifi: pcie: lower the debug level for RSA semaphore access
++    - iwlwifi: mvm: fix memory leak in paging
++    - crypto: ccp - Prevent information leakage on export
++    - crypto: sha1-mb - use corrcet pointer while completing jobs
++    - crypto: talitos - fix crash in talitos_cra_init()
++    - crypto: talitos - fix AEAD tcrypt tests
++    - powerpc: scan_features() updates incorrect bits for REAL_LE
++    - powerpc: Update cpu_user_features2 in scan_features()
++    - powerpc: Update TM user feature bits in scan_features()
++    - nl80211: check netlink protocol in socket release notification
++    - netlink: don't send NETLINK_URELEASE for unbound sockets
++    - Input: pmic8xxx-pwrkey - fix algorithm for converting trigger delay
++    - xen kconfig: don't "select INPUT_XEN_KBDDEV_FRONTEND"
++    - pinctrl: mediatek: correct debounce time unit in mtk_gpio_set_debounce
++    - pinctrl: single: Fix pcs_parse_bits_in_pinctrl_entry to use __ffs than ffs
++    - iommu/amd: Fix checking of pci dma aliases
++    - iommu/dma: Restore scatterlist offsets correctly
++    - drm/amdgpu: when suspending, if uvd/vce was running. need to cancel delay
++      work.
++    - drm/amdgpu: use defines for CRTCs and AMFT blocks
++    - drm/amdgpu: bump the afmt limit for CZ, ST, Polaris
++    - amdgpu/uvd: add uvd fw version for amdgpu
++    - drm/amdgpu: fix regression on CIK (v2)
++    - drm/radeon: add a quirk for a XFX R9 270X
++    - drm/radeon: fix initial connector audio value
++    - drm/radeon: forbid mapping of userptr bo through radeon device file
++    - drm/radeon: fix vertical bars appear on monitor (v2)
++    - drm: Loongson-3 doesn't fully support wc memory
++    - drm/nouveau/gr/gf100: select a stream master to fixup tfb offset queries
++    - drm/dp/mst: Validate port in drm_dp_payload_send_msg()
++    - drm/dp/mst: Restore primary hub guid on resume
++    - drm/dp/mst: Get validated port ref in drm_dp_update_payload_part1()
++    - pwm: brcmstb: Fix check of devm_ioremap_resource() return code
++    - drm/i915: Cleanup phys status page too
++    - drm/i915: skl_update_scaler() wants a rotation bitmask instead of bit number
++    - drm/amdkfd: uninitialized variable in dbgdev_wave_control_set_registers()
++    - drm/i915: Fixup the free space logic in ring_prepare
++    - drm/i915: Use fw_domains_put_with_fifo() on HSW
++    - perf intel-pt: Fix segfault tracing transactions
++    - i2c: cpm: Fix build break due to incompatible pointer types
++    - i2c: exynos5: Fix possible ABBA deadlock by keeping I2C clock prepared
++    - toshiba_acpi: Fix regression caused by hotkey enabling value
++    - EDAC: i7core, sb_edac: Don't return NOTIFY_BAD from mce_decoder callback
++    - ASoC: s3c24xx: use const snd_soc_component_driver pointer
++    - ASoC: ssm4567: Reset device before regcache_sync()
++    - ASoC: dapm: Make sure we have a card when displaying component widgets
++    - ASoC: rt5640: Correct the digital interface data select
++    - vb2-memops: Fix over allocation of frame vectors
++    - v4l2-dv-timings.h: fix polarity for 4k formats
++    - cxl: Keep IRQ mappings on context teardown
++    - IB/mlx5: Expose correct max_sge_rd limit
++    - IB/security: Restrict use of the write() interface
++    - efi: Fix out-of-bounds read in variable_matches()
++    - efi: Expose non-blocking set_variable() wrapper to efivars
++    - x86/apic: Handle zero vector gracefully in clear_vector_irq()
++    - workqueue: fix ghost PENDING flag while doing MQ IO
++    - slub: clean up code for kmem cgroup support to kmem_cache_free_bulk
++    - cgroup, cpuset: replace cpuset_post_attach_flush() with
++      cgroup_subsys->post_attach callback
++    - memcg: relocate charge moving from ->attach to ->post_attach
++    - mm/huge_memory: replace VM_NO_THP VM_BUG_ON with actual VMA check
++    - numa: fix /proc/<pid>/numa_maps for THP
++    - mm: vmscan: reclaim highmem zone if buffer_heads is over limit
++    - mm/hwpoison: fix wrong num_poisoned_pages accounting
++    - cgroup: make sure a parent css isn't freed before its children
++    - videobuf2-core: Check user space planes array in dqbuf
++    - videobuf2-v4l2: Verify planes array in buffer dequeueing
++    - Revert "regulator: core: Fix nested locking of supplies"
++    - regulator: core: fix regulator_lock_supply regression
++    - regulator: core: Ensure we lock all regulators
++    - regulator: core: Fix nested locking of supplies
++    - locking/mcs: Fix mcs_spin_lock() ordering
++    - spi/rockchip: Make sure spi clk is on in rockchip_spi_set_cs
++    - irqchip/sunxi-nmi: Fix error check of of_io_request_and_map()
++    - irqchip/mxs: Fix error check of of_io_request_and_map()
++    - regulator: s5m8767: fix get_register() error handling
++    - paride: make 'verbose' parameter an 'int' again
++    - scsi_dh: force modular build if SCSI is a module
++    - fbdev: da8xx-fb: fix videomodes of lcd panels
++    - misc/bmp085: Enable building as a module
++    - misc: mic/scif: fix wrap around tests
++    - PM / OPP: Initialize u_volt_min/max to a valid value
++    - PM / Domains: Fix removal of a subdomain
++    - rtc: hym8563: fix invalid year calculation
++    - rtc: vr41xx: Wire up alarm_irq_enable
++    - rtc: ds1685: passing bogus values to irq_restore
++    - rtc: rx8025: remove rv8803 id
++    - rtc: max77686: Properly handle regmap_irq_get_virq() error code
++    - drivers/misc/ad525x_dpot: AD5274 fix RDAC read back errors
++    - perf evlist: Reference count the cpu and thread maps at set_maps()
++    - x86/mm/kmmio: Fix mmiotrace for hugepages
++    - ext4: fix NULL pointer dereference in ext4_mark_inode_dirty()
++    - serial: sh-sci: Remove cpufreq notifier to fix crash/deadlock
++    - mtd: spi-nor: remove micron_quad_enable()
++    - mtd: brcmnand: Fix v7.1 register offsets
++    - mtd: nand: Drop mtd.owner requirement in nand_scan
++    - perf hists browser: Only offer symbol scripting when a symbol is under the
++      cursor
++    - perf tools: handle spaces in file names obtained from /proc/pid/maps
++    - perf stat: Document --detailed option
++    - ext4: fix races between page faults and hole punching
++    - ext4: move unlocked dio protection from ext4_alloc_file_blocks()
++    - ext4: fix races between buffered IO and collapse / insert range
++    - ext4: fix races of writeback with punch hole and zero range
++    - ARM: OMAP3: Add cpuidle parameters table for omap3430
++    - ARM: prima2: always enable reset controller
++    - ARM: EXYNOS: select THERMAL_OF
++    - ARM: dts: armada-375: use armada-370-sata for SATA
++    - ARM: dts: pxa: fix dma engine node to pxa3xx-nand
++    - bus: imx-weim: Take the 'status' property value into account
++    - jme: Do not enable NIC WoL functions on S0
++    - jme: Fix device PM wakeup API usage
++    - unbreak allmodconfig KCONFIG_ALLCONFIG=...
++    - thermal: rockchip: fix a impossible condition caused by the warning
++    - sunrpc/cache: drop reference when sunrpc_cache_pipe_upcall() detects a race
++    - megaraid_sas: add missing curly braces in ioctl handler
++    - stm class: Select CONFIG_SRCU
++    - extcon: max77843: Use correct size for reading the interrupt register
++    - Linux 4.4.9
++
++  * Stoney powerplay support (LP: #1578305)
++    - amdgpu/powerplay: Add Stoney to list of early init cases
++
++  * CVE-2016-2117 (LP: #1561403)
++    - atl2: Disable unimplemented scatter/gather feature
++
++  * CVE-2016-2187 (LP: #1575706)
++    - Input: gtco - fix crash on detecting device without endpoints
++
++  * zfs posix default permissions lost on reboot or unmount (LP: #1574801)
++    - Fix ZPL miswrite of default POSIX ACL
++
++  * WARNING: at /build/linux-aWXT0l/linux-4.4.0/drivers/pci/pci.c:1595
++    [travis3EN] (LP: #1574697)
++    - net/mlx4_core: Implement pci_resume callback
++    - net/mlx4_core: Avoid repeated calls to pci enable/disable
++
++  * Add support to thinkpad keyboard backlight (LP: #1574498)
++    - thinkpad_acpi: Add support for keyboard backlight
++
++  * Please enable kconfig X86_LEGACY_VM86 for i386 (LP: #1499089)
++    - [Config] CONFIG_VM86=y, CONFIG_X86_LEGACY_VM86=y
++
++  * Miscellaneous Ubuntu changes
++    - updateconfigs for Linux v4.4.9
++
++ -- Kamal Mostafa <kamal@canonical.com>  Mon, 16 May 2016 15:16:29 -0700
++
++linux (4.4.0-22.40) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * CVE-2016-3713 (LP: #1581201)
++    - SAUCE: KVM: MTRR: remove MSR 0x2f8
++
++  * CVE-2016-0758 (LP: #1581202)
++    - SAUCE: KEYS: Fix ASN.1 indefinite length object parsing
++
++ -- Kamal Mostafa <kamal@canonical.com>  Thu, 12 May 2016 13:38:45 -0700
++
++linux (4.4.0-22.39) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1578721
++
++  * LP: #1578705
++    - bpf: fix double-fdput in replace_map_fd_with_map_ptr()
++
++ -- Kamal Mostafa <kamal@canonical.com>  Thu, 05 May 2016 09:30:58 -0700
++
++linux (4.4.0-22.38) xenial; urgency=low
++
++  [ Kamal Mostafa ]
++
++  * Release Tracking Bug
++    - LP: #1573817
++
++  * autoreconstruct: need to also generate extend-diff-ignore options for links
++    (LP: #1574362)
++    - [Packaging] autoreconstruct -- generate extend-diff-ignore for links
++
++  * tipc: missing linearization of sk_buff (LP: #1567064)
++    - tipc: move linearization of buffers to generic code
++
++  * [Hyper-V] In-flight PCI Passthrough Patches (LP: #1570124)
++    - SAUCE:(noup) drivers:hv: Lock access to hyperv_mmio resource tree
++    - SAUCE:(noup) drivers:hv: Call vmbus_mmio_free() to reverse
++      vmbus_mmio_allocate()
++    - SAUCE:(noup) drivers:hv: Reverse order of resources in hyperv_mmio
++    - SAUCE:(noup) drivers:hv: Track allocations of children of hv_vmbus in
++      private resource tree
++    - SAUCE:(noup) drivers:hv: Record MMIO range in use by frame buffer
++    - SAUCE:(noup) drivers:hv: Separate out frame buffer logic when picking MMIO
++      range
++
++  * vbox: resync with 5.0.18-dfsg-2build1 (LP: #1571156)
++    - ubuntu: vbox -- update to 5.0.18-dfsg-2build1
++
++  * CONFIG_AUFS_XATTR is not set (LP: #1557776)
++    - [Config] CONFIG_AUFS_XATTR=y
++
++  * CVE-2016-3672 (LP: #1568523)
++    - x86/mm/32: Enable full randomization on i386 and X86_32
++
++  * CVE-2016-3955 (LP: #1572666)
++    - USB: usbip: fix potential out-of-bounds write
++
++  * Xenial update to v4.4.8 stable release (LP: #1573034)
++    - hwmon: (max1111) Return -ENODEV from max1111_read_channel if not
++      instantiated
++    - PKCS#7: pkcs7_validate_trust(): initialize the _trusted output argument
++    - parisc: Avoid function pointers for kernel exception routines
++    - parisc: Fix kernel crash with reversed copy_from_user()
++    - parisc: Unbreak handling exceptions from kernel modules
++    - ALSA: timer: Use mod_timer() for rearming the system timer
++    - ALSA: hda - Asus N750JV external subwoofer fixup
++    - ALSA: hda - Fix white noise on Asus N750JV headphone
++    - ALSA: hda - Apply fix for white noise on Asus N550JV, too
++    - mm: fix invalid node in alloc_migrate_target()
++    - powerpc/mm: Fixup preempt underflow with huge pages
++    - libnvdimm: fix smart data retrieval
++    - libnvdimm, pfn: fix uuid validation
++    - compiler-gcc: disable -ftracer for __noclone functions
++    - arm64: opcodes.h: Add arm big-endian config options before including arm
++      header
++    - drm/dp: move hw_mutex up the call stack
++    - drm/udl: Use unlocked gem unreferencing
++    - drm/radeon: add a dpm quirk for sapphire Dual-X R7 370 2G D5
++    - drm/radeon: add another R7 370 quirk
++    - drm/radeon: add a dpm quirk for all R7 370 parts
++    - drm/amdgpu/gmc: move vram type fetching into sw_init
++    - drm/amdgpu/gmc: use proper register for vram type on Fiji
++    - xen/events: Mask a moving irq
++    - tcp: convert cached rtt from usec to jiffies when feeding initial rto
++    - tunnel: Clear IPCB(skb)->opt before dst_link_failure called
++    - net: jme: fix suspend/resume on JMC260
++    - net: vrf: Remove direct access to skb->data
++    - net: qca_spi: Don't clear IFF_BROADCAST
++    - net: qca_spi: clear IFF_TX_SKB_SHARING
++    - net: fix bridge multicast packet checksum validation
++    - sctp: lack the check for ports in sctp_v6_cmp_addr
++    - mld, igmp: Fix reserved tailroom calculation
++    - tipc: Revert "tipc: use existing sk_write_queue for outgoing packet chain"
++    - qmi_wwan: add Sierra Wireless EM74xx device ID
++    - ipv6: re-enable fragment header matching in ipv6_find_hdr
++    - vxlan: fix missing options_len update on RX with collect metadata
++    - cdc_ncm: toggle altsetting to force reset before setup
++    - udp6: fix UDP/IPv6 encap resubmit path
++    - tcp: fix tcpi_segs_in after connection establishment
++    - ppp: release rtnl mutex when interface creation fails
++    - net: validate variable length ll headers
++    - ax25: add link layer header validation function
++    - packet: validate variable length ll headers
++    - bpf: avoid copying junk bytes in bpf_get_current_comm()
++    - sh_eth: fix NULL pointer dereference in sh_eth_ring_format()
++    - sh_eth: advance 'rxdesc' later in sh_eth_ring_format()
++    - qlcnic: Remove unnecessary usage of atomic_t
++    - qlcnic: Fix mailbox completion handling during spurious interrupt
++    - macvtap: always pass ethernet header in linear
++    - mlxsw: spectrum: Check requested ageing time is valid
++    - rocker: set FDB cleanup timer according to lowest ageing time
++    - bridge: allow zero ageing time
++    - ipv4: Don't do expensive useless work during inetdev destroy.
++    - net: Fix use after free in the recvmmsg exit path
++    - mlx4: add missing braces in verify_qp_parameters
++    - farsync: fix off-by-one bug in fst_add_one
++    - ath9k: fix buffer overrun for ar9287
++    - ppp: ensure file->private_data can't be overridden
++    - tcp/dccp: remove obsolete WARN_ON() in icmp handlers
++    - qlge: Fix receive packets drop.
++    - net: bcmgenet: fix dma api length mismatch
++    - bonding: fix bond_get_stats()
++    - ipv4: fix broadcast packets reception
++    - ipv4: initialize flowi4_flags before calling fib_lookup()
++    - ppp: take reference on channels netns
++    - xfrm: Fix crash observed during device unregistration and decryption
++    - qmi_wwan: add "D-Link DWM-221 B1" device id
++    - ipv6: udp: fix UDP_MIB_IGNOREDMULTI updates
++    - bridge: Allow set bridge ageing time when switchdev disabled
++    - rtnl: fix msg size calculation in if_nlmsg_size()
++    - tun, bpf: fix suspicious RCU usage in tun_{attach, detach}_filter
++    - tuntap: restore default qdisc
++    - ipv4: l2tp: fix a potential issue in l2tp_ip_recv
++    - ipv6: l2tp: fix a potential issue in l2tp_ip6_recv
++    - ip6_tunnel: set rtnl_link_ops before calling register_netdevice
++    - ipv6: Count in extension headers in skb->network_header
++    - mpls: find_outdev: check for err ptr in addition to NULL check
++    - USB: uas: Limit qdepth at the scsi-host level
++    - USB: uas: Add a new NO_REPORT_LUNS quirk
++    - cdc-acm: fix NULL pointer reference
++    - KVM: x86: Inject pending interrupt even if pending nmi exist
++    - KVM: x86: reduce default value of halt_poll_ns parameter
++    - MIPS: Fix MSA ld unaligned failure cases
++    - pinctrl: pistachio: fix mfio84-89 function description and pinmux.
++    - pinctrl: sh-pfc: only use dummy states for non-DT platforms
++    - pinctrl: sunxi: Fix A33 external interrupts not working
++    - pinctrl: nomadik: fix pull debug print inversion
++    - pinctrl: freescale: imx: fix bogus check of of_iomap() return value
++    - au0828: fix au0828_v4l2_close() dev_state race condition
++    - au0828: Fix dev_state handling
++    - coda: fix error path in case of missing pdata on non-DT platform
++    - v4l: vsp1: Set the SRU CTRL0 register when starting the stream
++    - pcmcia: db1xxx_ss: fix last irq_to_gpio user
++    - rbd: use GFP_NOIO consistently for request allocations
++    - virtio: virtio 1.0 cs04 spec compliance for reset
++    - mac80211: properly deal with station hashtable insert errors
++    - mac80211: avoid excessive stack usage in sta_info
++    - mac80211: fix ibss scan parameters
++    - mac80211: fix unnecessary frame drops in mesh fwding
++    - mac80211: fix txq queue related crashes
++    - usb: renesas_usbhs: avoid NULL pointer derefernce in usbhsf_pkt_handler()
++    - usb: renesas_usbhs: disable TX IRQ before starting TX DMAC transfer
++    - usb: renesas_usbhs: fix to avoid using a disabled ep in usbhsg_queue_done()
++    - iio: st_magn: always define ST_MAGN_TRIGGER_SET_STATE
++    - iio: accel: bmc150: fix endianness when reading axes
++    - iio: gyro: bmg160: fix buffer read values
++    - iio: gyro: bmg160: fix endianness when reading axes
++    - sd: Fix excessive capacity printing on devices with blocks bigger than 512
++      bytes
++    - fs: add file_dentry()
++    - nfs: use file_dentry()
++    - btrfs: fix crash/invalid memory access on fsync when using overlayfs
++    - ext4: add lockdep annotations for i_data_sem
++    - ext4: ignore quota mount options if the quota feature is enabled
++    - iommu: Don't overwrite domain pointer when there is no default_domain
++    - Btrfs: fix file/data loss caused by fsync after rename and new inode
++    - arm64: replace read_lock to rcu lock in call_step_hook
++    - perf: Do not double free
++    - perf: Cure event->pending_disable race
++    - mmc: sdhci-pci: Add support and PCI IDs for more Broxton host controllers
++    - ALSA: hda - Fixup speaker pass-through control for nid 0x14 on ALC225
++    - ALSA: hda - Fix headset support and noise on HP EliteBook 755 G2
++    - ALSA: hda/realtek - Enable the ALC292 dock fixup on the Thinkpad T460s
++    - ALSA: usb-audio: Add a sample rate quirk for Phoenix Audio TMX320
++    - ALSA: usb-audio: Add a quirk for Plantronics BT300
++    - ALSA: usb-audio: Skip volume controls triggers hangup on Dell USB Dock
++    - HID: wacom: fix Bamboo ONE oops
++    - HID: usbhid: fix inconsistent reset/resume/reset-resume behavior
++    - Revert "x86/PCI: Don't alloc pcibios-irq when MSI is enabled"
++    - Revert "PCI: Add helpers to manage pci_dev->irq and pci_dev->irq_managed"
++    - Revert "PCI, x86: Implement pcibios_alloc_irq() and pcibios_free_irq()"
++    - staging: android: ion: Set the length of the DMA sg entries in buffer
++    - usbvision: fix crash on detecting device with invalid configuration
++    - Revert "usb: hub: do not clear BOS field during reset device"
++    - Linux 4.4.8
++
++  * Fix speaker volume on a Dell machine (LP: #1549660)
++    - ALSA: hda - Fixup speaker pass-through control for nid 0x14 on ALC225
++
++  * Xenial update to v4.4.7 stable release (LP: #1572722)
++    - regulator: core: avoid unused variable warning
++    - regulator: core: Fix nested locking of supplies
++    - ASoC: samsung: pass DMA channels as pointers
++    - mmc: sh_mmcif: rework dma channel handling
++    - mmc: sh_mmcif: Correct TX DMA channel allocation
++    - x86/microcode/intel: Make early loader look for builtin microcode too
++    - x86/microcode: Untangle from BLK_DEV_INITRD
++    - x86/entry/compat: Keep TS_COMPAT set during signal delivery
++    - perf/x86/intel: Add definition for PT PMI bit
++    - x86/PCI: Mark Broadwell-EP Home Agent & PCU as having non-compliant BARs
++    - KVM: i8254: change PIT discard tick policy
++    - KVM: fix spin_lock_init order on x86
++    - KVM: VMX: avoid guest hang on invalid invept instruction
++    - KVM: VMX: avoid guest hang on invalid invvpid instruction
++    - KVM: VMX: fix nested vpid for old KVM guests
++    - perf/core: Fix perf_sched_count derailment
++    - perf tools: Dont stop PMU parsing on alias parse error
++    - perf tools: Fix checking asprintf return value
++    - perf tools: Fix python extension build
++    - sched/cputime: Fix steal_account_process_tick() to always return jiffies
++    - sched/preempt, sh: kmap_coherent relies on disabled preemption
++    - EDAC, amd64_edac: Shift wrapping issue in f1x_get_norm_dct_addr()
++    - s390: fix floating pointer register corruption (again)
++    - s390/cpumf: add missing lpp magic initialization
++    - pinctrl-bcm2835: Fix cut-and-paste error in "pull" parsing
++    - PCI: Disable IO/MEM decoding for devices with non-compliant BARs
++    - PCI: ACPI: IA64: fix IO port generic range check
++    - x86/irq: Cure live lock in fixup_irqs()
++    - x86/apic: Fix suspicious RCU usage in smp_trace_call_function_interrupt()
++    - x86/iopl/64: Properly context-switch IOPL on Xen PV
++    - x86/iopl: Fix iopl capability check on Xen PV
++    - x86/mm: TLB_REMOTE_SEND_IPI should count pages
++    - sg: fix dxferp in from_to case
++    - aacraid: Fix RRQ overload
++    - aacraid: Fix memory leak in aac_fib_map_free
++    - aacraid: Set correct msix count for EEH recovery
++    - sd: Fix discard granularity when LBPRZ=1
++    - scsi: storvsc: fix SRB_STATUS_ABORTED handling
++    - be2iscsi: set the boot_kset pointer to NULL in case of failure
++    - aic7xxx: Fix queue depth handling
++    - libnvdimm: Fix security issue with DSM IOCTL.
++    - dm snapshot: disallow the COW and origin devices from being identical
++    - dm: fix excessive dm-mq context switching
++    - dm thin metadata: don't issue prefetches if a transaction abort has failed
++    - dm cache: make sure every metadata function checks fail_io
++    - dm: fix rq_end_stats() NULL pointer in dm_requeue_original_request()
++    - usb: retry reset if a device times out
++    - usb: hub: fix a typo in hub_port_init() leading to wrong logic
++    - USB: uas: Reduce can_queue to MAX_CMNDS
++    - USB: cdc-acm: more sanity checking
++    - USB: iowarrior: fix oops with malicious USB descriptors
++    - USB: usb_driver_claim_interface: add sanity checking
++    - USB: mct_u232: add sanity checking in probe
++    - USB: digi_acceleport: do sanity checking for the number of ports
++    - USB: cypress_m8: add endpoint sanity check
++    - USB: serial: cp210x: Adding GE Healthcare Device ID
++    - USB: serial: ftdi_sio: Add support for ICP DAS I-756xU devices
++    - USB: option: add "D-Link DWM-221 B1" device id
++    - pwc: Add USB id for Philips Spc880nc webcam
++    - Input: powermate - fix oops with malicious USB descriptors
++    - ALSA: usb-audio: Fix NULL dereference in create_fixed_stream_quirk()
++    - ALSA: usb-audio: Add sanity checks for endpoint accesses
++    - ALSA: usb-audio: add Microsoft HD-5001 to quirks
++    - ALSA: usb-audio: Minor code cleanup in create_fixed_stream_quirk()
++    - ALSA: usb-audio: Fix double-free in error paths after
++      snd_usb_add_audio_stream() call
++    - Bluetooth: btusb: Add new AR3012 ID 13d3:3395
++    - Bluetooth: btusb: Add a new AR3012 ID 04ca:3014
++    - Bluetooth: btusb: Add a new AR3012 ID 13d3:3472
++    - crypto: ccp - Add hash state import and export support
++    - crypto: ccp - Limit the amount of information exported
++    - crypto: ccp - Don't assume export/import areas are aligned
++    - crypto: ccp - memset request context to zero during import
++    - crypto: keywrap - memzero the correct memory
++    - crypto: atmel - fix checks of error code returned by devm_ioremap_resource()
++    - crypto: ux500 - fix checks of error code returned by devm_ioremap_resource()
++    - crypto: marvell/cesa - forward devm_ioremap_resource() error code
++    - X.509: Fix leap year handling again
++    - mei: bus: check if the device is enabled before data transfer
++    - HID: logitech: fix Dual Action gamepad support
++    - HID: i2c-hid: fix OOB write in i2c_hid_set_or_send_report()
++    - HID: multitouch: force retrieving of Win8 signature blob
++    - HID: fix hid_ignore_special_drivers module parameter
++    - staging: comedi: ni_tiocmd: change mistaken use of start_src for start_arg
++    - staging: android: ion_test: fix check of platform_device_register_simple()
++      error code
++    - staging: comedi: ni_mio_common: fix the ni_write[blw]() functions
++    - tty: Fix GPF in flush_to_ldisc(), part 2
++    - net: irda: Fix use-after-free in irtty_open()
++    - 8250: use callbacks to access UART_DLL/UART_DLM
++    - saa7134: Fix bytesperline not being set correctly for planar formats
++    - adv7511: TX_EDID_PRESENT is still 1 after a disconnect
++    - bttv: Width must be a multiple of 16 when capturing planar formats
++    - coda: fix first encoded frame payload
++    - media: v4l2-compat-ioctl32: fix missing length copy in put_v4l2_buffer32
++    - mtip32xx: Avoid issuing standby immediate cmd during FTL rebuild
++    - mtip32xx: Fix broken service thread handling
++    - mtip32xx: Remove unwanted code from taskfile error handler
++    - mtip32xx: Print exact time when an internal command is interrupted
++    - mtip32xx: Fix for rmmod crash when drive is in FTL rebuild
++    - mtip32xx: Handle safe removal during IO
++    - mtip32xx: Handle FTL rebuild failure state during device initialization
++    - mtip32xx: Implement timeout handler
++    - mtip32xx: Cleanup queued requests after surprise removal
++    - ALSA: pcm: Avoid "BUG:" string for warnings again
++    - ALSA: intel8x0: Add clock quirk entry for AD1981B on IBM ThinkPad X41.
++    - ALSA: hda - Don't handle ELD notify from invalid port
++    - ALSA: hda - fix the mic mute button and led problem for a Lenovo AIO
++    - ALSA: hda - Fix unconditional GPIO toggle via automute
++    - tools/hv: Use include/uapi with __EXPORTED_HEADERS__
++    - jbd2: fix FS corruption possibility in jbd2_journal_destroy() on umount path
++    - brd: Fix discard request processing
++    - IB/srpt: Simplify srpt_handle_tsk_mgmt()
++    - bcache: cleaned up error handling around register_cache()
++    - bcache: fix race of writeback thread starting before complete initialization
++    - bcache: fix cache_set_flush() NULL pointer dereference on OOM
++    - mm: memcontrol: reclaim when shrinking memory.high below usage
++    - mm: memcontrol: reclaim and OOM kill when shrinking memory.max below usage
++    - ia64: define ioremap_uc()
++    - watchdog: don't run proc_watchdog_update if new value is same as old
++    - watchdog: rc32434_wdt: fix ioctl error handling
++    - Bluetooth: Add new AR3012 ID 0489:e095
++    - Bluetooth: Fix potential buffer overflow with Add Advertising
++    - cgroup: ignore css_sets associated with dead cgroups during migration
++    - net: mvneta: enable change MAC address when interface is up
++    - of: alloc anywhere from memblock if range not specified
++    - vfs: show_vfsstat: do not ignore errors from show_devname method
++    - splice: handle zero nr_pages in splice_to_pipe()
++    - xtensa: ISS: don't hang if stdin EOF is reached
++    - xtensa: fix preemption in {clear,copy}_user_highpage
++    - xtensa: clear all DBREAKC registers on start
++    - ARC: [BE] readl()/writel() to work in Big Endian CPU configuration
++    - ARC: bitops: Remove non relevant comments
++    - quota: Fix possible GPF due to uninitialised pointers
++    - xfs: fix two memory leaks in xfs_attr_list.c error paths
++    - raid1: include bio_end_io_list in nr_queued to prevent freeze_array hang
++    - md/raid5: Compare apples to apples (or sectors to sectors)
++    - RAID5: check_reshape() shouldn't call mddev_suspend
++    - RAID5: revert e9e4c377e2f563 to fix a livelock
++    - raid10: include bio_end_io_list in nr_queued to prevent freeze_array hang
++    - md/raid5: preserve STRIPE_PREREAD_ACTIVE in break_stripe_batch_list
++    - md: multipath: don't hardcopy bio in .make_request path
++    - Revert "UBUNTU: SAUCE: (noup) fuse: Add reference counting for fuse_io_priv"
++    - Revert "UBUNTU: SAUCE: (noup) fuse: do not use iocb after it may have been
++      freed"
++    - fuse: do not use iocb after it may have been freed
++    - fuse: Add reference counting for fuse_io_priv
++    - fs/coredump: prevent fsuid=0 dumps into user-controlled directories
++    - rapidio/rionet: fix deadlock on SMP
++    - ipr: Fix out-of-bounds null overwrite
++    - ipr: Fix regression when loading firmware
++    - iwlwifi: mvm: Fix paging memory leak
++    - drm/radeon: disable runtime pm on PX laptops without dGPU power control
++    - drm/radeon: Don't drop DP 2.7 Ghz link setup on some cards.
++    - drm/amdgpu: disable runtime pm on PX laptops without dGPU power control
++    - drm/amdgpu: include the right version of gmc header files for iceland
++    - IB/ipoib: fix for rare multicast join race condition
++    - tracing: Have preempt(irqs)off trace preempt disabled functions
++    - tracing: Fix crash from reading trace_pipe with sendfile
++    - tracing: Fix trace_printk() to print when not using bprintk()
++    - bitops: Do not default to __clear_bit() for __clear_bit_unlock()
++    - scripts/coccinelle: modernize &
++    - scripts/kconfig: allow building with make 3.80 again
++    - kbuild/mkspec: fix grub2 installkernel issue
++    - MAINTAINERS: Update mailing list and web page for hwmon subsystem
++    - ideapad-laptop: Add ideapad Y700 (15) to the no_hw_rfkill DMI list
++    - mmc: block: fix ABI regression of mmc_blk_ioctl
++    - mmc: mmc_spi: Add Card Detect comments and fix CD GPIO case
++    - mmc: sdhci: fix data timeout (part 1)
++    - mmc: sdhci: fix data timeout (part 2)
++    - mmc: sdhci: Fix override of timeout clk wrt max_busy_timeout
++    - clk: rockchip: rk3368: fix cpuclk mux bit of big cpu-cluster
++    - clk: rockchip: rk3368: fix cpuclk core dividers
++    - clk: rockchip: rk3368: fix parents of video encoder/decoder
++    - clk: rockchip: rk3368: fix hdmi_cec gate-register
++    - clk: rockchip: add hclk_cpubus to the list of rk3188 critical clocks
++    - clk: bcm2835: Fix setting of PLL divider clock rates
++    - target: Fix target_release_cmd_kref shutdown comp leak
++    - iser-target: Fix identification of login rx descriptor type
++    - iser-target: Add new state ISER_CONN_BOUND to isert_conn
++    - iser-target: Separate flows for np listeners and connections cma events
++    - iser-target: Rework connection termination
++    - nfsd4: fix bad bounds checking
++    - nfsd: fix deadlock secinfo+readdir compound
++    - ARM: dts: at91: sama5d3 Xplained: don't disable hsmci regulator
++    - ARM: dts: at91: sama5d4 Xplained: don't disable hsmci regulator
++    - ACPI / PM: Runtime resume devices when waking from hibernate
++    - writeback, cgroup: fix premature wb_put() in
++      locked_inode_to_wb_and_lock_list()
++    - writeback, cgroup: fix use of the wrong bdi_writeback which mismatches the
++      inode
++    - Revert "UBUNTU: SAUCE: (noup) Input: synaptics - handle spurious release of
++      trackstick buttons, again"
++    - Input: synaptics - handle spurious release of trackstick buttons, again
++    - Input: ims-pcu - sanity check against missing interfaces
++    - Input: ati_remote2 - fix crashes on detecting device with invalid descriptor
++    - ocfs2/dlm: fix race between convert and recovery
++    - ocfs2/dlm: fix BUG in dlm_move_lockres_to_recovery_list
++    - mm/page_alloc: prevent merging between isolated and other pageblocks
++    - mtd: onenand: fix deadlock in onenand_block_markbad
++    - PM / sleep: Clear pm_suspend_global_flags upon hibernate
++    - scsi_common: do not clobber fixed sense information
++    - sched/cputime: Fix steal time accounting vs. CPU hotplug
++    - perf/x86/pebs: Add workaround for broken OVFL status on HSW+
++    - perf/x86/intel: Fix PEBS warning by only restoring active PMU in pmi
++    - perf/x86/intel: Fix PEBS data source interpretation on Nehalem/Westmere
++    - Linux 4.4.7
++
++  * QCA9565 / AR9565 bluetooth not work (LP: #1542944)
++    - Bluetooth: Add new AR3012 ID 0489:e095
++
++  * The mic mute key and led can't work on a Lenovo AIO machine (LP: #1555912)
++    - ALSA: hda - fix the mic mute button and led problem for a Lenovo AIO
++
++  * 13d3:3472 bluetooth not working, 4.2 low latency kernel 14.04.1 on asus ROG
++    gl552jx (LP: #1552925)
++    - Bluetooth: btusb: Add a new AR3012 ID 13d3:3472
++
++  * Bluetooth cannot detect other devices (Lite-on 3014 + Atheros AR9565)
++    (LP: #1546694)
++    - Bluetooth: btusb: Add a new AR3012 ID 04ca:3014
++
++  * Atheros AR9462 Bluetooth cannot detect other devices  (LP: #1542564)
++    - Bluetooth: btusb: Add new AR3012 ID 13d3:3395
++
++  * s390/pci: add extra padding to function measurement block (LP: #1572291)
++    - s390/pci: add extra padding to function measurement block
++
++  * CVE-2016-3951 (LP: #1567191)
++    - cdc_ncm: do not call usbnet_link_change from cdc_ncm_bind
++    - usbnet: cleanup after bind() in probe()
++
++  * linux: Add UEFI keyring for externally signed modules (LP: #1569924)
++    - efi: Remove redundant efi_set_variable_nonblocking() prototype
++    - efi/runtime-wrappers: Add a nonblocking version of QueryVariableInfo()
++    - efi: Add nonblocking option to efi_query_variable_store()
++    - efi: Add NV memory attribute
++    - efi: Reformat GUID tables to follow the format in UEFI spec
++    - efi: stub: implement efi_get_random_bytes() based on EFI_RNG_PROTOCOL
++    - SAUCE: (noup) Add EFI signature data types
++    - crypto: KEYS: convert public key and digsig asym to the akcipher api
++    - [Config] CONFIG_EFI_SIGNATURE_LIST_PARSER=y
++    - SAUCE: (noup) Add an EFI signature blob parser and key loader.
++    - [Config] CONFIG_IMA_MOK_KEYRING=y
++    - IMA: create machine owner and blacklist keyrings
++    - KEYS: Add an alloc flag to convey the builtinness of a key
++    - [Config] CONFIG_MODULE_SIG_UEFI=y, CONFIG_SYSTEM_BLACKLIST_KEYRING=y
++    - SAUCE: (noup) KEYS: Add a system blacklist keyring
++    - SAUCE: (noup) MODSIGN: Support not importing certs from db
++
++  * Miscellaneous Ubuntu changes
++    - [Config] CONFIG_PUBLIC_KEY_ALGO_RSA=y
++
++ -- Kamal Mostafa <kamal@canonical.com>  Sun, 24 Apr 2016 12:12:13 -0700
++
++linux (4.4.0-21.37) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1571791
++
++  * linux: MokSBState is ignored (LP: #1571691)
++    - SAUCE: (noup) MODSIGN: Import certificates from UEFI Secure Boot
++    - SAUCE: (noup) efi: Disable secure boot if shim is in insecure mode
++    - SAUCE: (noup) Display MOKSBState when disabled
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 18 Apr 2016 07:00:22 -0600
++
++linux (4.4.0-20.36) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1571069
++
++  * sysfs mount failure during stateful lxd snapshots (LP: #1570906)
++    - SAUCE: kernfs: Do not match superblock in another user namespace when
++      mounting
++
++  * Kernel Panic in Ubuntu 16.04 netboot installer (LP: #1570441)
++    - x86/topology: Fix logical package mapping
++    - x86/topology: Fix Intel HT disable
++    - x86/topology: Use total_cpus not nr_cpu_ids for logical packages
++    - xen/apic: Provide Xen-specific version of cpu_present_to_apicid APIC op
++    - x86/topology: Fix AMD core count
++
++  * [regression]: Failed to call clock_adjtime(): Invalid argument
++    (LP: #1566465)
++    - ntp: Fix ADJ_SETOFFSET being used w/ ADJ_NANO
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 14 Apr 2016 06:31:56 -0600
++
++linux (4.4.0-19.35) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1570348
++
++  * CVE-2016-2847 (LP: #1554260)
++    - pipe: limit the per-user amount of pages allocated in pipes
++
++  * xenial kernel crash on HP BL460c G7 (qla24xx problem?) (LP: #1554003)
++    - SAUCE: (noup) qla2xxx: Add irq affinity notification V2
++
++  * arm64: guest hangs when ntpd is running (LP: #1549494)
++    - SAUCE: (noup) KVM: arm/arm64: Handle forward time correction gracefully
++
++  * linux: Enforce signed module loading when UEFI secure boot (LP: #1566221)
++    - [Config] CONFIG_EFI_SECURE_BOOT_SIG_ENFORCE=y
++
++  * s390/cpumf: Fix lpp detection (LP: #1555344)
++    - s390/facilities: use stfl mnemonic instead of insn magic
++    - s390/facilities: always use lowcore's stfle field for storing facility bits
++    - s390/cpumf: Fix lpp detection
++
++  * s390x kernel image needs weightwatchers (LP: #1536245)
++    - [Config] s390x: Use compressed kernel bzImage
++
++  * Surelock GA2 SP1: surelock02p05: Not seeing sgX devices for LUNs after
++    upgrading to Ubuntu 16.04 (LP: #1567581)
++    - Revert "UBUNTU: SAUCE: (noup) powerpc/pci: Assign fixed PHB number based on
++      device-tree properties"
++
++  * Backport upstream bugfixes to ubuntu-16.04 (LP: #1555765)
++    - cpufreq: powernv: Define per_cpu chip pointer to optimize hot-path
++    - Revert "cpufreq: postfix policy directory with the first CPU in related_cpus"
++    - cpufreq: powernv: Add sysfs attributes to show throttle stats
++
++  * systemd-modules-load.service: Failing due to missing module 'ib_iser' (LP: #1566468)
++    - [Config] Add ib_iser to generic inclusion list
++
++  * thunderx nic performance improvements (LP: #1567093)
++    - net: thunderx: Set recevie buffer page usage count in bulk
++    - net: thunderx: Adjust nicvf structure to reduce cache misses
++
++  * fixes for thunderx nic in multiqueue mode (LP: #1567091)
++    - net: thunderx: Fix for multiqset not configured upon interface toggle
++    - net: thunderx: Fix for HW TSO not enabled for secondary qsets
++    - net: thunderx: Fix receive packet stats
++
++  * Miscellaneous Ubuntu changes
++    - [Config] updateconfigs after CONFIG_DRM_I915_BPO_PRELIMINARY_HW_SUPPORT=n
++
++  * Miscellaneous upstream changes (LP: #1564901)
++    - Input: xpad - correctly handle concurrent LED and FF requests
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 07 Apr 2016 07:32:16 +0100
++
++linux (4.4.0-18.34) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1566868
++
++  * [i915_bpo] Fix RC6 on SKL GT3 & GT4 (LP: #1564759)
++    - SAUCE: i915_bpo: drm/i915/skl: Fix rc6 based gpu/system hang
++    - SAUCE: i915_bpo: drm/i915/skl: Fix spurious gpu hang with gt3/gt4 revs
++
++  * CONFIG_ARCH_ROCKCHIP not enabled in armhf generic kernel (LP: #1566283)
++    - [Config] CONFIG_ARCH_ROCKCHIP=y
++
++  * [Feature] Memory Bandwidth Monitoring (LP: #1397880)
++    - perf/x86/cqm: Fix CQM handling of grouping events into a cache_group
++    - perf/x86/cqm: Fix CQM memory leak and notifier leak
++    - x86/cpufeature: Carve out X86_FEATURE_*
++    - Merge branch 'timers-core-for-linus' of git://git.kernel.org/pub/scm/linux/kernel/git/tip/tip
++    - x86/topology: Create logical package id
++    - perf/x86/mbm: Add Intel Memory B/W Monitoring enumeration and init
++    - perf/x86/mbm: Add memory bandwidth monitoring event management
++    - perf/x86/mbm: Implement RMID recycling
++    - perf/x86/mbm: Add support for MBM counter overflow handling
++
++  * User namespace mount updates (LP: #1566505)
++    - SAUCE: quota: Require that qids passed to dqget() be valid and map into s_user_ns
++    - SAUCE: fs: Allow superblock owner to change ownership of inodes with unmappable ids
++    - SAUCE: fuse: Don't initialize user_id or group_id in mount options
++    - SAUCE: cgroup: Use a new super block when mounting in a cgroup namespace
++    - SAUCE: fs: fix a posible leak of allocated superblock
++
++  * [arm64] kernel BUG at /build/linux-StrpB2/linux-4.4.0/fs/ext4/inode.c:2394!
++    (LP: #1566518)
++    - arm64: Honour !PTE_WRITE in set_pte_at() for kernel mappings
++    - arm64: Update PTE_RDONLY in set_pte_at() for PROT_NONE permission
++
++  * [Feature]USB core and xHCI tasks for USB 3.1 SuperSpeedPlus (SSP) support
++    for Alpine Ridge on SKL (LP: #1519623)
++    - usb: define USB_SPEED_SUPER_PLUS speed for SuperSpeedPlus USB3.1 devices
++    - usb: set USB 3.1 roothub device speed to USB_SPEED_SUPER_PLUS
++    - usb: show speed "10000" in sysfs for USB 3.1 SuperSpeedPlus devices
++    - usb: add device descriptor for usb 3.1 root hub
++    - usb: Support USB 3.1 extended port status request
++    - xhci: Make sure xhci handles USB_SPEED_SUPER_PLUS devices.
++    - xhci: set roothub speed to USB_SPEED_SUPER_PLUS for USB3.1 capable controllers
++    - xhci: USB 3.1 add default Speed Attributes to SuperSpeedPlus device capability
++    - xhci: set slot context speed field to SuperSpeedPlus for USB 3.1 SSP devices
++    - usb: Add USB3.1 SuperSpeedPlus Isoc Endpoint Companion descriptor
++    - usb: Parse the new USB 3.1 SuperSpeedPlus Isoc endpoint companion descriptor
++    - usb: Add USB 3.1 Precision time measurement capability descriptor support
++    - xhci: refactor and cleanup endpoint initialization.
++    - xhci: Add SuperSpeedPlus high bandwidth isoc support to xhci endpoints
++    - xhci: cleanup isoc tranfers queuing code
++    - xhci: Support extended burst isoc TRB structure used by xhci 1.1 for USB 3.1
++    - SAUCE: (noup) usb: fix regression in SuperSpeed endpoint descriptor parsing
++
++  * wrong/missing permissions for device file /dev/prandom (prng.ko)
++    (LP: #1558275)
++    - s390/crypto: provide correct file mode at device register.
++
++  * The Front MIC jack can't work on a HP desktop machine (LP: #1564712)
++    - ALSA: hda - fix front mic problem for a HP desktop
++
++  * HP Notebook Probook 440 G3  HDA Intel PCH horrible sounds while booting
++    (LP: #1556228)
++    - ALSA: hda - Apply reboot D3 fix for CX20724 codec, too
++
++  * please provide mmc-modules udeb (LP: #1565765)
++    - [Config] Add mmc block drivers to d-i
++
++  * linux: Enforce signed module loading when UEFI secure boot (LP: #1566221)
++    - Add secure_modules() call
++    - PCI: Lock down BAR access when module security is enabled
++    - x86: Lock down IO port access when module security is enabled
++    - ACPI: Limit access to custom_method
++    - asus-wmi: Restrict debugfs interface when module loading is restricted
++    - Restrict /dev/mem and /dev/kmem when module loading is restricted
++    - acpi: Ignore acpi_rsdp kernel parameter when module loading is restricted
++    - kexec: Disable at runtime if the kernel enforces module loading restrictions
++    - x86: Restrict MSR access when module loading is restricted
++    - [Config] CONFIG_EFI_SECURE_BOOT_SIG_ENFORCE=n
++    - Add option to automatically enforce module signatures when in Secure Boot mode
++    - efi: Make EFI_SECURE_BOOT_SIG_ENFORCE depend on EFI
++    - efi: Add EFI_SECURE_BOOT bit
++    - hibernate: Disable in a signed modules environment
++
++  * [Hyper-V] Additional PCI passthrough commits (LP: #1565967)
++    - PCI: Add fwnode_handle to x86 pci_sysdata
++    - PCI: Look up IRQ domain by fwnode_handle
++    - [Config] CONFIG_PCI_HYPERV=m
++    - PCI: hv: Add paravirtual PCI front-end for Microsoft Hyper-V VMs
++
++  * [Bug]Lenovo Yoga 260 and Carbon X1 4th gen freeze on HWP enable
++    (LP: #1559923)
++    - ACPI / processor: Request native thermal interrupt handling via _OSC
++
++  * Sync kernel zfs 0.6.5.6 - align with zfsutils-linux and spl packages
++    (LP: #1564591)
++    - SAUCE: (noup) Update spl to 0.6.5.6-0ubuntu1, zfs to 0.6.5.6-0ubuntu3
++
++  * [Ubuntu 16.04.1] RELEASE and ACQUIRE atomics on Power (LP: #1556096)
++    - atomics: Allow architectures to define their own __atomic_op_* helpers
++    - powerpc: atomic: Implement atomic{, 64}_*_return_* variants
++    - powerpc: atomic: Implement acquire/release/relaxed variants for xchg
++    - powerpc: atomic: Implement acquire/release/relaxed variants for cmpxchg
++
++  * fix for do_tools_cpupower when cross-compiling (LP: #1564206)
++    - [Debian] cpupower uses non-standard CROSS
++
++  * ISST:LTE: Regression: roselp2 Oops in kernel during setup io (LP: #1546439)
++    - SAUCE: block: partition: initialize percpuref before sending out KOBJ_ADD
++
++  * Unable to migrate container (LP: #1563921)
++    - SAUCE: cgroup mount: ignore nsroot=
++
++  * [Hyper-V] patch inclusion in 16.04 for NIC hot add/remove (LP: #1563688)
++    - hv_netvsc: Move subchannel waiting to rndis_filter_device_remove()
++
++  * /proc/$pid/maps performance regression (LP: #1547231)
++    - proc: revert /proc/<pid>/maps [stack:TID] annotation
++
++  * TPM2.0 trusted keys fixes (LP: #1398274)
++    - tpm: remove unneeded include of actbl2.h
++    - tpm: fix checks for policy digest existence in tpm2_seal_trusted()
++    - tpm_crb: Use the common ACPI definition of struct acpi_tpm2
++    - tpm_tis: Disable interrupt auto probing on a per-device basis
++    - tpm_tis: Do not fall back to a hardcoded address for TPM2
++    - tpm_tis: Use devm_ioremap_resource
++    - tpm_tis: Clean up the force=1 module parameter
++    - tpm_crb: Drop le32_to_cpu(ioread32(..))
++    - tpm_crb: Use devm_ioremap_resource
++    - tpm: fix the rollback in tpm_chip_register()
++    - tpm: fix the cleanup of struct tpm_chip
++    - tpm: fix: set continueSession attribute for the unseal operation
++    - tpm: fix: return rc when devm_add_action() fails
++    - tpm_eventlog.c: fix binary_bios_measurements
++    - tpm_crb/tis: fix: use dev_name() for /proc/iomem
++    - tpm_crb: tpm2_shutdown() must be called before tpm_chip_unregister()
++    - tpm_tis: fix build warning with tpm_tis_resume
++
++  * [Feature]intel_idle driver support for Knights Landing (LP: #1461365)
++    - intel_idle: Support for Intel Xeon Phi Processor x200 Product Family
++
++  * cxlflash: Backport upstream cxlflash commits and submitting a noup patch to
++    Xenial (LP: #1563485)
++    - cxlflash: Fix to avoid unnecessary scan with internal LUNs
++    - cxlflash: Increase cmd_per_lun for better throughput
++    - SAUCE: (noup) cxlflash: Move to exponential back-off when cmd_room is not available
++
++  * Miscellaneous Ubuntu changes
++    - [Config] do_zfs_powerpc64-smp  = true
++    - [Debian] fix linux_tools when cross-compiling
++    - [Config] do_zfs_powerpc64-smp use default value
++    - SAUCE: apparmor: Fix FTBFS due to bad include path
++    - SAUCE: i915_bpo: Disable preliminary hw support
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 29 Mar 2016 15:31:33 -0600
++
++linux (4.4.0-17.33) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1563441
++
++  * ISST-LTE: pVM:high cpus number need a high crashkernel value in kdump
++    (LP: #1560552)
++    - SAUCE: (noup) ppc64 boot: Wait for boot cpu to show up if nr_cpus limit is
++      about to hit.
++
++  * Predictable naming mechanism is leading to issues in DLPAR operations of
++    NICs (LP: #1560514)
++    - SAUCE: (noup) powerpc/pci: Assign fixed PHB number based on device-tree
++      properties
++
++  * ThunderX: support alternative phy implementations (LP: #1562968)
++    - net: thunderx: Cleanup PHY probing code.
++    - [Config] CONFIG_MDIO_CAVIUM=m
++    - phy: mdio-octeon: Refactor into two files/modules
++    - [Config] CONFIG_MDIO_THUNDER=m
++    - phy: mdio-thunder: Add driver for Cavium Thunder SoC MDIO buses.
++    - phy: mdio-cavium: Add missing MODULE_* annotations.
++    - net: cavium: For Kconfig THUNDER_NIC_BGX, select MDIO_THUNDER.
++    - phy: mdio-thunder: Fix some Kconfig typos
++    - [d-i] Add phy drivers for Cavium ThunderX to nic-modules udeb
++
++  * linux: exclude ZONE_DEVICE from GFP_ZONE_TABLE (LP: #1563293)
++    - Revert "mm: CONFIG_NR_ZONES_EXTENDED"
++    - mm: exclude ZONE_DEVICE from GFP_ZONE_TABLE
++
++  * lots of printk to serial console can hang system for long time
++    (LP: #1534216)
++    - printk: set may_schedule for some of console_trylock() callers
++
++  * [i915_bpo] Update i915 backport driver (LP: #1560395)
++    - SAUCE: i915_bpo: Update to drm-intel-next-fixes-2016-03-16
++    - PM / runtime: Add new helper for conditional usage count incrementation
++    - drm/core: Add drm_for_each_encoder_mask, v2.
++    - drm/atomic-helper: Implement subsystem-level suspend/resume
++
++  * [Hyper-V] VM Sockets (LP: #1541585)
++    - Drivers: hv: vmbus: Cleanup vmbus_set_event()
++    - Drivers: hv: vmbus: Add vendor and device atttributes
++    - Drivers: hv: vmbus: avoid infinite loop in init_vp_index()
++    - Drivers: hv: vmbus: avoid scheduling in interrupt context in vmbus_initiate_unload()
++    - Drivers: hv: vmbus: don't manipulate with clocksources on crash
++    - Drivers: hv: vmbus: add a helper function to set a channel's pending send size
++    - Drivers: hv: vmbus: define the new offer type for Hyper-V socket (hvsock)
++    - Drivers: hv: vmbus: vmbus_sendpacket_ctl: hvsock: avoid unnecessary signaling
++    - Drivers: hv: vmbus: define a new VMBus message type for hvsock
++    - Drivers: hv: vmbus: add a hvsock flag in struct hv_driver
++    - Drivers: hv: vmbus: add a per-channel rescind callback
++    - Drivers: hv: vmbus: add an API vmbus_hvsock_device_unregister()
++    - Drivers: hv: vmbus: Eliminate the spin lock on the read path
++    - Drivers: hv: vmbus: Give control over how the ring access is serialized
++    - drivers/hv: Move VMBus hypercall codes into Hyper-V UAPI header
++    - Drivers: hv: vmbus: don't loose HVMSG_TIMER_EXPIRED messages
++    - Drivers: hv: vmbus: avoid wait_for_completion() on crash
++    - Drivers: hv: vmbus: remove code duplication in message handling
++    - Drivers: hv: vmbus: avoid unneeded compiler optimizations in vmbus_wait_for_unload()
++    - Drivers: hv: util: Pass the channel information during the init call
++    - Drivers: hv: utils: Remove util transport handler from list if registration fails
++    - Revert "Drivers: hv: vmbus: Support handling messages on multiple CPUs"
++    - Drivers: hv: vmbus: Support handling messages on multiple CPUs
++
++  * [Bug]SKL-H boot hang when c8+c9+c10 enabled by intel_idle driver
++    (LP: #1559918)
++    - intel_idle: prevent SKL-H boot failure when C8+C9+C10 enabled
++
++  * ixgbe: Update to Fortville SW5 release (LP: #1562326)
++    - net: add tc offload feature flag
++    - net: tc: helper functions to query action types
++    - sctp: Rename NETIF_F_SCTP_CSUM to NETIF_F_SCTP_CRC
++    - net: rework ndo tc op to consume additional qdisc handle parameter
++    - net: rework setup_tc ndo op to consume general tc operand
++    - net: sched: add cls_u32 offload hooks for netdevs
++    - net: ixgbe: add support for tc_u32 offload
++    - net: ixgbe: abort with cls u32 divisor groups greater than 1
++
++  * Bring fm10k up to Fortville SW5 (LP: #1562310)
++    - net: add netif_is_team_master helper
++    - net: add netif_is_team_port helper
++    - net: add netif_is_lag_master helper
++    - net: add netif_is_lag_port helper
++    - ethtool: correctly ensure {GS}CHANNELS doesn't conflict with GS{RXFH}
++    - fm10k: don't reinitialize RSS flow table when RXFH configured
++
++  * [Feature]Always Running Timer (ART) to System Time translation
++    (LP: #1519625)
++    - time: Verify time values in adjtimex ADJ_SETOFFSET to avoid overflow
++    - timekeeping: Provide internal function __ktime_get_real_seconds
++    - timekeeping: Cap adjustments so they don't exceed the maxadj value
++    - clocksource: Make clocksource validation work for all clocksources
++    - time: Add cycles to nanoseconds translation
++    - time: Add timekeeping snapshot code capturing system time and counter
++    - time: Remove duplicated code in ktime_get_raw_and_real()
++    - time: Add driver cross timestamp interface for higher precision time synchronization
++    - time: Add history to cross timestamp interface supporting slower devices
++    - time/timekeeping: Work around false positive GCC warning
++    - x86/tsc: Always Running Timer (ART) correlated clocksource
++    - ptp: Add PTP_SYS_OFFSET_PRECISE for driver crosstimestamping
++    - [Config] CONFIG_E1000E_HWTS=y
++    - e1000e: Adds hardware supported cross timestamp on e1000e nic
++
++  * x-gene2: add SoC v2 support to clock (LP: #1561604)
++    - clk: xgene: Add SoC and PMD PLL clocks with v2 hardware
++
++  * [Bug]Disable multi-record PEBS on Merom (LP: #1559914)
++    - perf/x86: Move perf_event.c ............... => x86/events/core.c
++    - perf/x86: Move perf_event_amd.c ........... => x86/events/amd/core.c
++    - perf/x86: Move perf_event_amd_ibs.c ....... => x86/events/amd/ibs.c
++    - perf/x86: Move perf_event_amd_iommu.[ch] .. => x86/events/amd/iommu.[ch]
++    - perf/x86: Move perf_event_amd_uncore.c .... => x86/events/amd/uncore.c
++    - perf/x86: Move perf_event_intel_bts.c ........ => x86/events/intel/bts.c
++    - perf/x86: Move perf_event_intel.c ............ => x86/events/intel/core.c
++    - perf/x86: Move perf_event_intel_cqm.c ........ => x86/events/intel/cqm.c
++    - perf/x86: Move perf_event_intel_cstate.c ..... => x86/events/intel/cstate.c
++    - perf/x86: Move perf_event_intel_ds.c ......... => x86/events/intel/ds.c
++    - perf/x86: Move perf_event_intel_lbr.c ........ => x86/events/intel/lbr.c
++    - perf/x86: Move perf_event_intel_pt.[ch] ...... => x86/events/intel/pt.[ch]
++    - perf/x86: Move perf_event_intel_rapl.c ....... => x86/events/intel/rapl.c
++    - perf/x86: Move perf_event_intel_uncore.[ch] .. =>
++      x86/events/intel/uncore.[ch]
++    - perf/x86: Move perf_event_intel_uncore_nhmex.c =>
++      x86/events/intel/uncore_nmhex.c
++    - perf/x86: Move perf_event_intel_uncore_snb.c =>
++      x86/events/intel/uncore_snb.c
++    - perf/x86: Move perf_event_intel_uncore_snbep.c =>
++      x86/events/intel/uncore_snbep.c
++    - perf/x86: Move perf_event_knc.c .............. => x86/events/intel/knc.c
++    - perf/x86: Move perf_event_p4.c ............... => x86/events/intel/p4.c
++    - perf/x86: Move perf_event_p6.c ............... => x86/events/intel/p6.c
++    - perf/x86: Move perf_event_msr.c .............. => x86/events/msr.c
++    - perf/x86: Move perf_event.h to its new home
++    - perf/x86/intel: Use PAGE_SIZE for PEBS buffer size on Core2
++
++  * [Feature] Enable I2C on Broxton-P (LP: #1520139)
++    - mfd: intel-lpss: Pass I2C configuration via properties on BXT
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 24 Mar 2016 20:40:27 -0600
++
++linux (4.4.0-16.32) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1561727
++
++  * fix thermal throttling due to commit "Thermal: initialize thermal zone
++    device correctly"  (LP: #1561676)
++    - Thermal: Ignore invalid trip points
++
++  * Thinkpad T460: Trackpoint mouse buttons instantly generate "release" event
++    on press (LP: #1553811)
++    - SAUCE: (noup) Input: synaptics - handle spurious release of trackstick
++      buttons, again
++
++  * reading /sys/kernel/security/apparmor/profiles requires CAP_MAC_ADMIN
++    (LP: #1560583)
++    - SAUCE: apparmor: Allow ns_root processes to open profiles file
++    - SAUCE: apparmor: Consult sysctl when reading profiles in a user ns
++
++  * linux: sync virtualbox drivers to 5.0.16-dfsg-2 (LP: #1561492)
++    - ubuntu: vbox -- update to 5.0.16-dfsg-2
++
++  * s390/kconfig: CONFIG_NUMA without CONFIG_NUMA_EMU does not make any sense on
++    s390x (LP: #1557690)
++    - [Config] CONFIG_NUMA_BALANCING_DEFAULT_ENABLED=n for s390x
++
++  * spl/zfs fails to build on s390x (LP: #1519814)
++    - [Config] s390x -- re-enable zfs
++    - [Config] zfs -- disable powerpc until the test failures can be resolved
++
++  * linux: sync to ZFS 0.6.5.6 stable release (LP: #1561483)
++    - SAUCE: (noup) Update spl to 0.6.5.6-0ubuntu1, zfs to 0.6.5.6-0ubuntu1
++
++  * zfs: enable zfs for 64bit powerpc kernels (LP: #1558871)
++    - [Packaging] zfs -- handle rprovides via dpkg-gencontrol
++    - [Config] powerpc -- convert zfs configuration to custom_override
++
++  * Memory arena corruption with FUSE (was Memory allocation failure crashes
++    kernel hard, presumably related to FUSE) (LP: #1505948)
++    - SAUCE: (noup) fuse: do not use iocb after it may have been freed
++    - SAUCE: (noup) fuse: Add reference counting for fuse_io_priv
++
++  * cgroup namespaces: add a 'nsroot=' mountinfo field (LP: #1560489)
++    - SAUCE: (noup) cgroup namespaces: add a 'nsroot=' mountinfo field
++
++  * linux packaging: clear remaining redundant delta (LP: #1560445)
++    - [Debian] Remove generated intermediate files on clean
++
++  * arm64: guest hangs when ntpd is running (LP: #1549494)
++    - Revert "hrtimer: Add support for CLOCK_MONOTONIC_RAW"
++    - Revert "hrtimer: Catch illegal clockids"
++    - Revert "KVM: arm/arm64: timer: Switch to CLOCK_MONOTONIC_RAW"
++
++  * Need enough contiguous memory to support GICv3 ITS table (LP: #1558828)
++    - [Config] CONFIG_FORCE_MAX_ZONEORDER=13 on arm64
++    - SAUCE: (no-up) arm64: gicv3: its: Increase FORCE_MAX_ZONEORDER for Cavium
++      ThunderX
++
++  * update arcmsr to version v1.30.00.22-20151126 to fix card timeouts
++    (LP: #1559609)
++    - arcmsr: fixed getting wrong configuration data
++    - arcmsr: fixes not release allocated resource
++    - arcmsr: make code more readable
++    - arcmsr: adds code to support new Areca adapter ARC1203
++    - arcmsr: changes driver version number
++    - arcmsr: more readability improvements
++    - arcmsr: Split dma resource allocation to a new function
++    - arcmsr: change driver version to v1.30.00.22-20151126
++
++  * server image has no keyboard, desktop image works (LP: #1559692)
++    - [Config] Rework input-modules (d-i) list
++
++  * PMU support for Cavium ThunderX (LP: #1559349)
++    - arm64: perf: Rename Cortex A57 events
++    - arm64/perf: Add Cavium ThunderX PMU support
++    - arm64: perf: Enable PMCR long cycle counter bit
++    - arm64: perf: Extend event mask for ARMv8.1
++    - arm64: dts: Add Cavium ThunderX specific PMU
++
++  * Show ARM PMU events in perf stat (LP: #1559350)
++    - drivers/perf: kill armpmu_register
++    - arm: perf: Convert event enums to #defines
++    - arm: perf: Add event descriptions
++    - arm64: perf: Convert event enums to #defines
++    - arm64: perf: Add event descriptions
++    - ARM: perf: add format entry to describe event -> config mapping
++    - arm64: perf: add format entry to describe event -> config mapping
++
++  * [Bug]HSW/BDW EDAC driver reports wrong DIMM (LP: #1559904)
++    - EDAC/sb_edac: Fix computation of channel address
++
++  * 5-10 second delay in kernel boot with kernel command line ip= (LP: #1259861)
++    - [Config] disable CONFIG_IP_PNP
++
++  * Miscellaneous Ubuntu changes
++    - [Debian] Silence the reconstruct script
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 21 Mar 2016 10:15:31 -0600
++
++linux (4.4.0-15.31) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1559252
++
++  * Xilinx KU3 Capi card does not show up in Ubuntu  16.04 (LP: #1557001)
++    - SAUCE: (noup) cxl: Allow initialization on timebase sync failures
++
++  * policy namespace stacking (LP: #1379535)
++    - Revert "UBUNTU: SAUCE: Move replacedby allocation into label_alloc"
++    - Revert "UBUNTU: SAUCE: Fixup: __label_update() still doesn't handle some cases correctly."
++    - Revert "UBUNTU: SAUCE: fix: audit "no_new_privs" case for exec failure"
++    - Revert "UBUNTU: SAUCE: fixup: warning about aa_label_vec_find_or_create not being static"
++    - Revert "UBUNTU: SAUCE: apparmor: fix refcount race when finding a child profile"
++    - Revert "UBUNTU: SAUCE: fixup: cast poison values to remove warnings"
++    - Revert "UBUNTU: SAUCE: fixup: get rid of unused var build warning"
++    - Revert "UBUNTU: SAUCE: fixup: 20/23 locking issue around in __label_update"
++    - Revert "UBUNTU: SAUCE: fixup: make __share_replacedby private to get rid of build warning"
++    - Revert "UBUNTU: SAUCE: fix: replacedby forwarding is not being properly update when ns is destroyed"
++    - Revert "UBUNTU: SAUCE: apparmor: fix log of apparmor audit message when kern_path() fails"
++    - Revert "UBUNTU: SAUCE: fixup: cleanup return handling of labels"
++    - Revert "UBUNTU: SAUCE: apparmor: fix: ref count leak when profile sha1 hash is read"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: query label file permission"
++    - Revert "UBUNTU: SAUCE: apparmor: Don't remove label on rcu callback if the label has already been removed"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: break circular refcount for label that is directly freed."
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: refcount bug when inserting label update that transitions ns"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: now that insert can force replacement use it instead of remove_and_insert"
++    - Revert "UBUNTU: SAUCE: apparmor Fix: refcount bug in pivotroot mediation"
++    - Revert "UBUNTU: SAUCE: apparmor: ensure that repacedby sharing is done correctly"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: update replacedby allocation to take a gfp parameter"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: convert replacedby update to be protected by the labelset lock"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: add required locking of __aa_update_replacedby on merge path"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: deadlock in aa_put_label() call chain"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: label_vec_merge insertion"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: ensure new labels resulting from merge have a replacedby"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: refcount leak in aa_label_merge"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: refcount race between locating in labelset and get"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: label merge handling of marking unconfined and stale"
++    - Revert "UBUNTU: SAUCE: apparmor: add underscores to indicate aa_label_next_not_in_set() use needs locking"
++    - Revert "UBUNTU: SAUCE: apparmor: debug: POISON label and replaceby pointer on free"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: ensure aa_get_newest will trip debugging if the replacedby is not setup"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: insert race between label_update and label_merge"
++    - Revert "UBUNTU: SAUCE: apparmor: rework retrieval of the current label in the profile update case"
++    - Revert "UBUNTU: SAUCE: apparmor: Disallow update of cred when then subjective != the objective cred"
++    - Revert "UBUNTU: SAUCE: apparmor: Fix: oops do to invalid null ptr deref in label print fns"
++    - Revert "UBUNTU: SAUCE: fix-up: kern_mount fail path should not be doing put_buffers()"
++    - Revert "UBUNTU: SAUCE: apparmor: fix sleep from invalid context"
++    - Revert "UBUNTU: SAUCE: (no-up): apparmor: fix for failed mediation of socket that is being shutdown"
++    - Revert "UBUNTU: SAUCE: (no-up) apparmor: Fix incompatible pointer type warnings"
++    - Revert "UBUNTU: SAUCE: (no-up) apparmor: fix mount not handling disconnected paths"
++    - Revert "UBUNTU: SAUCE: (no-up): apparmor: fix mediation of fs unix sockets"
++    - Revert "UBUNTU: apparmor -- follow change to this_cpu_ptr"
++    - Revert "UBUNTU: SAUCE: (no-up) fix: bad unix_addr_fs macro"
++    - Revert "UBUNTU: SAUCE: Revert: fix: only allow a single threaded process to ..."
++    - Revert "UBUNTU: SAUCE: (no-up) apparmor: Sync to apparmor3 - RC1 snapshot"
++    - Revert "UBUNTU: SAUCE: (no-up) apparmor: add parameter to control whether policy hashing is used"
++    - SAUCE: (no-up) apparmor: sync of apparmor3.5-beta1 snapshot
++    - SAUCE: add a sysctl to enable unprivileged user ns AppArmor policy loading
++
++  * Add arm64 NUMA support (LP: #1558765)
++    - SAUCE: (noup) efi: ARM/arm64: ignore DT memory nodes instead of removing them
++    - SAUCE: (noup) Documentation, dt, numa: dt bindings for NUMA.
++    - [Config] CONFIG_OF_NUMA=y
++    - SAUCE: (noup) of, numa: Add NUMA of binding implementation.
++    - SAUCE: (noup) arm64: Move unflatten_device_tree() call earlier.
++    - [Config] CONFIG_NUMA=y and CONFIG_NODES_SHIFT=2 on arm64
++    - SAUCE: (noup) arm64, numa: Add NUMA support for arm64 platforms.
++    - SAUCE: (noup) arm64, mm, numa: Add NUMA balancing support for arm64.
++
++  * vivid/linux: total ADT test failures (LP: #1558447)
++    - Revert "Revert "af_unix: Revert 'lock_interruptible' in stream receive code""
++
++  * [Hyper-V] patches to allow kdump crash through NMI (LP: #1558720)
++    - Drivers: hv: vmbus: Support handling messages on multiple CPUs
++    - Drivers: hv: vmbus: Support kexec on ws2012 r2 and above
++
++  * s390/pci: enforce fmb page boundary rule (LP: #1558625)
++    - s390/pci: enforce fmb page boundary rule
++
++  * s390/pci: backport upstream commits since v4.4 (LP: #1558624)
++    - s390/pci_dma: fix DMA table corruption with > 4 TB main memory
++    - page_to_phys() always returns a multiple of PAGE_SIZE
++    - s390/pci: provide ZPCI_ADDR macro
++    - s390/pci: improve ZPCI_* macros
++    - s390/pci: resize iomap
++    - s390/pci: fix bar check
++    - s390/pci: set error state for unusable functions
++    - s390/pci: remove iomap sanity checks
++    - s390/pci: remove pdev pointer from arch data
++    - s390/pci: add ioctl interface for CLP
++
++  * IMA-appraisal is unusable in Ubuntu 16.04 (LP: #1558553)
++    - [Config] CONFIG_SYSTEM_EXTRA_CERTIFICATE=y, CONFIG_SYSTEM_EXTRA_CERTIFICATE_SIZE=4096
++    - KEYS: Use the symbol value for list size, updated by scripts/insert-sys-cert
++    - KEYS: Reserve an extra certificate symbol for inserting without recompiling
++    - SAUCE: (noup) KEYS: Support for inserting a certificate into x86 bzImage
++
++  * skb_warn_bad_offload Crash (LP: #1558025)
++    - ipv4: only create late gso-skb if skb is already set up with CHECKSUM_PARTIAL
++
++  * Add PCIe root complex to Cavium arm64 (LP: #1558342)
++    - [Config] CONFIG_PCI_HOST_COMMON=y
++    - [Config] CONFIG_PCI_HOST_THUNDER_PEM=y
++    - [Config] CONFIG_PCI_HOST_THUNDER_ECAM=y
++    - PCI: generic: Move structure definitions to separate header file
++    - PCI: generic: Add pci_host_common_probe(), based on gen_pci_probe()
++    - PCI: generic: Expose pci_host_common_probe() for use by other drivers
++    - PCI: thunder: Add PCIe host driver for ThunderX processors
++    - PCI: thunder: Add driver for ThunderX-pass{1,2} on-chip devices
++
++  * [Hyper-V] vmbus: Fix a bug in hv_need_to_signal_on_read() (LP: #1556264)
++    - SAUCE: (noup) Drivers: hv: vmbus: Fix a bug in hv_need_to_signal_on_read()
++
++  * Xenial update to v4.4.6 stable release (LP: #1558330)
++    - arm64: account for sparsemem section alignment when choosing vmemmap offset
++    - ARM: mvebu: fix overlap of Crypto SRAM with PCIe memory window
++    - ARM: dts: dra7: do not gate cpsw clock due to errata i877
++    - ARM: OMAP2+: hwmod: Introduce ti,no-idle dt property
++    - PCI: Allow a NULL "parent" pointer in pci_bus_assign_domain_nr()
++    - kvm: cap halt polling at exactly halt_poll_ns
++    - KVM: VMX: disable PEBS before a guest entry
++    - KVM: s390: correct fprs on SIGP (STOP AND) STORE STATUS
++    - KVM: PPC: Book3S HV: Sanitize special-purpose register values on guest exit
++    - KVM: MMU: fix ept=0/pte.u=1/pte.w=0/CR0.WP=0/CR4.SMEP=1/EFER.NX=0 combo
++    - KVM: MMU: fix reserved bit check for ept=0/CR0.WP=0/CR4.SMEP=1/EFER.NX=0
++    - s390/dasd: fix diag 0x250 inline assembly
++    - tracing: Fix check for cpu online when event is disabled
++    - dmaengine: at_xdmac: fix residue computation
++    - jffs2: reduce the breakage on recovery from halfway failed rename()
++    - ncpfs: fix a braino in OOM handling in ncp_fill_cache()
++    - ASoC: dapm: Fix ctl value accesses in a wrong type
++    - ASoC: samsung: Use IRQ safe spin lock calls
++    - ASoC: wm8994: Fix enum ctl accesses in a wrong type
++    - ASoC: wm8958: Fix enum ctl accesses in a wrong type
++    - ovl: ignore lower entries when checking purity of non-directory entries
++    - ovl: fix working on distributed fs as lower layer
++    - wext: fix message delay/ordering
++    - cfg80211/wext: fix message ordering
++    - can: gs_usb: fixed disconnect bug by removing erroneous use of kfree()
++    - iwlwifi: mvm: inc pending frames counter also when txing non-sta
++    - mac80211: minstrel: Change expected throughput unit back to Kbps
++    - mac80211: fix use of uninitialised values in RX aggregation
++    - mac80211: minstrel_ht: set default tx aggregation timeout to 0
++    - mac80211: minstrel_ht: fix a logic error in RTS/CTS handling
++    - mac80211: check PN correctly for GCMP-encrypted fragmented MPDUs
++    - mac80211: Fix Public Action frame RX in AP mode
++    - gpu: ipu-v3: Do not bail out on missing optional port nodes
++    - drm/amdgpu: Fix error handling in amdgpu_flip_work_func.
++    - drm/radeon: Fix error handling in radeon_flip_work_func.
++    - Revert "drm/radeon/pm: adjust display configuration after powerstate"
++    - userfaultfd: don't block on the last VM updates at exit time
++    - ovl: fix getcwd() failure after unsuccessful rmdir
++    - MIPS: Fix build error when SMP is used without GIC
++    - MIPS: smp.c: Fix uninitialised temp_foreign_map
++    - block: don't optimize for non-cloned bio in bio_get_last_bvec()
++    - target: Drop incorrect ABORT_TASK put for completed commands
++    - ld-version: Fix awk regex compile failure
++    - Linux 4.4.6
++
++  * linux fails to load x.509 built-in certificate (LP: #1557250)
++    - lib/mpi: Endianness fix
++
++  * s390/kconfig: setting for CONFIG...9P.... (LP: #1557994)
++    - [Config] CONFIG_NET_9P=m for s390x
++
++  * mlx5_core kernel trace after "ethtool -C eth1 adaptive-rx on" flow
++    (LP: #1557950)
++    - net/mlx5e: Don't try to modify CQ moderation if it is not supported
++    - net/mlx5e: Don't modify CQ before it was created
++
++  * [Feature]SD/SDIO/eMMC support for Broxton-P (LP: #1520454)
++    - mmc: sdhci: Do not BUG on invalid vdd
++    - mmc: enable MMC/SD/SDIO device to suspend/resume asynchronously
++    - mmc: It is not an error for the card to be removed while suspended
++
++  * s390/kconfig: disable CONFIG_VIRTIO_MMIO (LP: #1557689)
++    - [Config] CONFIG_VIRTIO_MMIO=n for s390x
++
++  * s390/kconfig: CONFIG_NUMA without CONFIG_NUMA_EMU does not make any sense on s390x (LP: #1557690)
++    - [Config] CONFIG_NUMA_EMU=y for s390x
++
++  * Miscellaneous Ubuntu changes
++    - [Debian] git-ubuntu-log -- prevent bug references being split
++    - [Debian] git-ubuntu-log -- git log output is UTF-8
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Mar 2016 13:18:58 -0600
++
++linux (4.4.0-14.30) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1557508
++
++  * Current 4.4 kernel won't boot on powerpc (LP: #1557130)
++    - powerpc: Fix dedotify for binutils >= 2.26
++
++  * ZFS: send fails to transmit some holes [corruption] (LP: #1557151)
++    - Illumos 6370 - ZFS send fails to transmit some holes
++
++  * Request to cherry-pick uvcvideo patch for Xenial kernel support of RealSense
++    camera (LP: #1557138)
++    - UVC: Add support for ds4 depth camera
++
++  * use after free of task_struct->numa_faults in task_numa_find_cpu (LP: #1527643)
++    - sched/numa: Fix use-after-free bug in the task_numa_compare
++
++  * overlay fs regression: chmod fails with "Operation not permitted" on chowned
++    files (LP: #1555997)
++    - ovl: copy new uid/gid into overlayfs runtime inode
++
++  * Miscellaneous Ubuntu changes
++    - SAUCE: Dump stack when X.509 certificates cannot be loaded
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 14 Mar 2016 07:16:19 -0600
++
++linux (4.4.0-13.29) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1556247
++
++  * s390/mm: four page table levels vs. fork (LP: #1556141)
++    - s390/mm: four page table levels vs. fork
++
++  * [Hyper-V] network performance patches for Xenial 16.04 (LP: #1556037)
++    - hv_netvsc: use skb_get_hash() instead of a homegrown implementation
++    - hv_netvsc: cleanup netdev feature flags for netvsc
++
++  * fails to boot on megaraid (LP: #1552903)
++    - SAUCE: (noup) megaraid_sas: Don't issue kill adapter for MFI controllers in
++      case of PD list DCMD failure
++
++  * ALSA: hda - add codec support for Kabylake display audio codec (LP: #1556002)
++    - ALSA: hda - add codec support for Kabylake display audio codec
++
++  * Backport upstream bugfixes to ubuntu-16.04 (LP: #1555765)
++    - cpufreq: powernv: Free 'chips' on module exit
++    - cpufreq: powernv: Hot-plug safe the kworker thread
++    - cpufreq: powernv: Remove cpu_to_chip_id() from hot-path
++    - cpufreq: powernv/tracing: Add powernv_throttle tracepoint
++    - cpufreq: powernv: Replace pr_info with trace print for throttle event
++    - SAUCE: (noup) cpufreq: powernv: Fix bugs in powernv_cpufreq_{init/exit}
++
++  * Linux netfilter IPT_SO_SET_REPLACE memory corruption (LP: #1555338)
++    - SAUCE: [nf,v2] netfilter: x_tables: don't rely on well-behaving userspace
++
++  * integer overflow in xt_alloc_table_info (LP: #1555353)
++    - SAUCE: (noup) netfilter: x_tables: check for size overflow
++
++  * linux: auto-generate the reconstruct information from the git tag (LP: #1555543)
++    - [Packaging] reconstruct -- automatically reconstruct against base tag
++    - [Config] reconstruct -- update to autoreconstruct output
++    - [Packaging] reconstruct -- update when inserting final changes
++
++  * Xenial update to v4.4.5 stable release (LP: #1555640)
++    - use ->d_seq to get coherency between ->d_inode and ->d_flags
++    - drivers: sh: Restore legacy clock domain on SuperH platforms
++    - Btrfs: fix deadlock running delayed iputs at transaction commit time
++    - btrfs: Fix no_space in write and rm loop
++    - btrfs: async-thread: Fix a use-after-free error for trace
++    - block: Initialize max_dev_sectors to 0
++    - PCI: keystone: Fix MSI code that retrieves struct pcie_port pointer
++    - parisc: Fix ptrace syscall number and return value modification
++    - mips/kvm: fix ioctl error handling
++    - kvm: x86: Update tsc multiplier on change.
++    - fbcon: set a default value to blink interval
++    - cifs: fix out-of-bounds access in lease parsing
++    - CIFS: Fix SMB2+ interim response processing for read requests
++    - Fix cifs_uniqueid_to_ino_t() function for s390x
++    - vfio: fix ioctl error handling
++    - KVM: x86: fix root cause for missed hardware breakpoints
++    - arm/arm64: KVM: Fix ioctl error handling
++    - iommu/amd: Apply workaround for ATS write permission check
++    - iommu/amd: Fix boot warning when device 00:00.0 is not iommu covered
++    - iommu/vt-d: Use BUS_NOTIFY_REMOVED_DEVICE in hotplug path
++    - target: Fix WRITE_SAME/DISCARD conversion to linux 512b sectors
++    - drm/ast: Fix incorrect register check for DRAM width
++    - drm/radeon/pm: update current crtc info after setting the powerstate
++    - drm/amdgpu/pm: update current crtc info after setting the powerstate
++    - drm/amdgpu: apply gfx_v8 fixes to gfx_v7 as well
++    - drm/amdgpu/gfx8: specify which engine to wait before vm flush
++    - drm/amdgpu: return from atombios_dp_get_dpcd only when error
++    - libata: fix HDIO_GET_32BIT ioctl
++    - libata: Align ata_device's id on a cacheline
++    - block: bio: introduce helpers to get the 1st and last bvec
++    - writeback: flush inode cgroup wb switches instead of pinning super_block
++    - Adding Intel Lewisburg device IDs for SATA
++    - arm64: vmemmap: use virtual projection of linear region
++    - PM / sleep / x86: Fix crash on graph trace through x86 suspend
++    - ata: ahci: don't mark HotPlugCapable Ports as external/removable
++    - tracing: Do not have 'comm' filter override event 'comm' field
++    - pata-rb532-cf: get rid of the irq_to_gpio() call
++    - Btrfs: fix loading of orphan roots leading to BUG_ON
++    - Revert "jffs2: Fix lock acquisition order bug in jffs2_write_begin"
++    - jffs2: Fix page lock / f->sem deadlock
++    - Fix directory hardlinks from deleted directories
++    - dmaengine: pxa_dma: fix cyclic transfers
++    - adv7604: fix tx 5v detect regression
++    - ALSA: usb-audio: Add a quirk for Plantronics DA45
++    - ALSA: ctl: Fix ioctls for X32 ABI
++    - ALSA: hda - Fix mic issues on Acer Aspire E1-472
++    - ALSA: rawmidi: Fix ioctls X32 ABI
++    - ALSA: timer: Fix ioctls for X32 ABI
++    - ALSA: pcm: Fix ioctls for X32 ABI
++    - ALSA: seq: oss: Don't drain at closing a client
++    - ALSA: hdspm: Fix wrong boolean ctl value accesses
++    - ALSA: hdsp: Fix wrong boolean ctl value accesses
++    - ALSA: hdspm: Fix zero-division
++    - ALSA: timer: Fix broken compat timer user status ioctl
++    - usb: chipidea: otg: change workqueue ci_otg as freezable
++    - USB: cp210x: Add ID for Parrot NMEA GPS Flight Recorder
++    - USB: qcserial: add Dell Wireless 5809e Gobi 4G HSPA+ (rev3)
++    - USB: qcserial: add Sierra Wireless EM74xx device ID
++    - USB: serial: option: add support for Telit LE922 PID 0x1045
++    - USB: serial: option: add support for Quectel UC20
++    - MIPS: scache: Fix scache init with invalid line size.
++    - MIPS: traps: Fix SIGFPE information leak from `do_ov' and `do_trap_or_bp'
++    - ubi: Fix out of bounds write in volume update code
++    - i2c: brcmstb: allocate correct amount of memory for regmap
++    - thermal: cpu_cooling: fix out of bounds access in time_in_idle
++    - block: check virt boundary in bio_will_gap()
++    - block: get the 1st and last bvec via helpers
++    - drm/i915: more virtual south bridge detection
++    - drm/i915: refine qemu south bridge detection
++    - modules: fix longstanding /proc/kallsyms vs module insertion race.
++    - drm/amdgpu: fix topaz/tonga gmc assignment in 4.4 stable
++    - Linux 4.4.5
++
++  * QEMU: causes vCPU steal time overflow on live migration (LP: #1494350)
++    - x86/mm: Fix slow_virt_to_phys() for X86_PAE again
++
++  * TPM2.0 trusted keys fixes (LP: #1398274)
++    - tpm_tis: further simplify calculation of ordinal duration
++    - tpm_tis: Use devm_free_irq not free_irq
++    - tpm_tis: Ensure interrupts are disabled when the driver starts
++    - tpm: rework tpm_get_timeouts()
++    - tpm_tis: Get rid of the duplicate IRQ probing code
++    - tpm_tis: Refactor the interrupt setup
++    - tpm_tis: Tighten IRQ auto-probing
++    - tpm_ibmvtpm: properly handle interrupted packet receptions
++
++  * linux: review all versioned depends/conflicts/replaces/breaks for validility (LP: #1555033)
++    - [Config] control.stub.in -- review versioned Build-Depends:
++    - [Config] control.stub.in -- review versioned
++      Depends/Breaks/Conflicts/Replaces
++    - [Config] flavour-control.stub -- review versioned Breaks/Conflicts/Replaces
++    - [Config] x86 vars.* -- review versioned Breaks/Conflicts/Replaces
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 09 Mar 2016 05:11:51 -0700
++
++linux (4.4.0-12.28) xenial; urgency=low
++
++  * Miscellaneous Ubuntu changes
++    - reconstruct: Work around orig tarball packaging limitiations
++      Fixes FTBS
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 08 Mar 2016 13:26:08 -0700
++
++linux (4.4.0-12.27) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1554704
++
++  * Fails to detect (second) display (LP: #1543683)
++    - drm/i915: Fix hpd live status bits for g4x
++
++  * s390x -- various configuration changes (LP: #1543165)
++    - [Config] s390x -- enable CONFIG_NUMA
++    - [Config] s390x -- disable CONFIG_NET_VENDOR_EMULEX
++    - [Config] s390x -- disable CONFIG_NET_VENDOR_SYNOPSYS
++    - [Config] s390x -- disable CONFIG_NVMEM
++    - [Config] s390x -- switch preempt mode to none
++
++  * Radeon hybrid graphics problem on resume (LP: #1554608)
++    - Revert "drm/radeon: call hpd_irq_event on resume"
++
++  * Pull in upstream AMD code (amdgpu) in Xenial (LP: #1546572)
++    - [Config] CONFIG_DRM_AMD_POWERPLAY=y
++    - drm/amdgpu: use $(src) in Makefile (v2)
++    - drm/radeon: constify radeon_asic_ring structures
++    - drm/amdgpu: add a callback for reading the bios from the rom directly
++    - drm/amdgpu: add read_bios_from_rom callback for CI parts
++    - drm/amdgpu: add read_bios_from_rom callback for VI parts
++    - drm/amdgpu: Use new read bios from rom callback
++    - drm/amdgpu: Use unlocked gem unreferencing
++    - drm/radeon: Use unlocked gem unreferencing
++    - drm/amd: add new gfx8 register definitions for EDC
++    - drm/amdgpu: add EDC support for CZ (v3)
++    - drm/amd: abstract kernel rq and normal rq to priority of run queue
++    - drm/amdgpu/gfx8: Enable interrupt on ME1_PIPE3
++    - drm/amdgpu/gfx8: update PA_SC_RASTER_CONFIG:PKR_MAP only
++    - drm/amdgpu: update rev id register for VI
++    - drm/amdgpu: add more debugging output for driver failures
++    - drm/amdgpu: add entity only when first job come
++    - drm/amdgpu: handle error case for ctx
++    - drm/amdgpu: unify AMDGPU_CTX_MAX_CS_PENDING and amdgpu_sched_jobs
++    - drm/amdgpu: change default sched jobs to 32
++    - drm/amdgpu: limit visible vram if it's smaller than the BAR
++    - drm/amdgpu: restrict the sched jobs number to power of two
++    - drm/amdgpu: put VM page tables directly into duplicates list
++    - drm/amdgpu: split VM PD and PT handling during CS
++    - drm/amdgpu: keep the PTs validation list in the VM v2
++    - drm/radeon: Update radeon_get_vblank_counter_kms()
++    - drm/radeon: only increment sync_seq when a fence is really emitted
++    - drm/fb-helper: Use proper plane mask for fb cleanup
++    - drm/amdgpu: fix dp link rate selection (v2)
++    - drm/radeon: fix dp link rate selection (v2)
++    - drm/amdgpu: share struct amdgpu_pm_state_type with powerplay module
++    - drm/amdgpu: mv some definition from amdgpu_acpi.c to amdgpu_acpi.h
++    - drm/amdgpu: mv amdgpu_acpi.h to amd/include/amd_acpi.h
++    - drm/amdgpu: implement new cgs interface for acpi function
++    - drm/amdgpu: implement cgs interface to query system info
++    - drm/amdgpu: add new cgs interface to get display info (v2)
++    - drm/amd/powerplay: add basic powerplay framework
++    - drm/amdgpu: disable legacy path of firmware check if powerplay is enabled
++    - drm/amdgpu: export amd_powerplay_func to amdgpu and other ip block
++    - drm/amd/powerplay: add SMU manager sub-component
++    - drm/amd/powerplay: add hardware manager sub-component
++    - SAUCE: amd: Include errno.h
++    - drm/amd/powerplay: add Carrizo smu support
++    - drm/amd/powerplay: add Carrizo dpm support
++    - drm/amd/powerplay: add CG and PG support for carrizo
++    - drm/amd/powerplay: add event manager sub-component
++    - drm/amd/powerplay: implement functions of amd_powerplay_func
++    - drm/amd/powerplay: Add ixSWRST_COMMAND_1 in bif_5_0_d.h
++    - drm/amd/powerplay: Move smu7*.h from amdgpu to powerplay.
++    - drm/amd/powerplay: add header file for tonga smu and dpm
++    - drm/amd/powerplay: Add Tonga SMU support
++    - drm/amd/powerplay: add Tonga dpm support (v3)
++    - drm/amd/powerplay: add/update headers for Fiji SMU and DPM
++    - drm/amd/powerplay: update atomctrl for fiji
++    - drm/amd/powerplay: add Fiji SMU support.
++    - drm/amd/powerplay: add Fiji DPM support.
++    - drm/amdgpu: add amdgpu.powerplay module option
++    - drm/amd/amdgpu: enable powerplay and smc firmware loading for Fiji.
++    - drm/amdgpu/powerplay: add function point in hwmgr_funcs for program display gap
++    - drm/amdgpu/poweprlay: export program display gap function to eventmgr
++    - drm/amdgpu/powerplay: implement pem_task for display_configuration_change
++    - drm/amdgpu/powerplay: program display gap for tonga.
++    - drm/amdgpu: enable powerplay module by default for tonga.
++    - drm/amdgpu: enable powerplay module by default for fiji.
++    - drm/amdgpu/powerplay: add some definition for other ip block to update cg pg.
++    - drm/amd/powerplay: add new function point in hwmgr_func for CG/PG.
++    - drm/amd/powerplay: Add CG and PG support for tonga
++    - drm/amdgpu/powerplay: add new function point in hwmgr_funcs for thermal control
++    - drm/amdgpu/powerplay: mv ppinterrupt.h to inc folder to share with other submodule.
++    - drm/amdgpu/powerplay: add thermal control interface in hwmgr.
++    - drm/amdgpu/powerplay: enable thermal interrupt task in eventmgr.
++    - drm/amdgpu/powerplay: implement thermal control for tonga.
++    - drm/amdgpu/powerplay: implement fan control interface in amd_powerplay_funcs
++    - drm/amdgpu: export fan control functions to amdgpu
++    - drm/amdgpu: enable sysfs interface for powerplay
++    - drm/amdgpu: support per device powerplay enablement (v2)
++    - drm/amd/powerplay: add and export hwmgr interface to eventmgr to check hw states.
++    - drm/amd/powerplay: implement new funcs to check current states for tonga.
++    - drm/amd/powerplay: refine the logic of whether need to update power state.
++    - drm/amd/powerplay/tonga: enable pcie and mclk forcing for low
++    - drm/amd/powerplay/fiji: enable pcie and mclk forcing for low
++    - drm/amdgpu: extract pcie helpers to common header
++    - drm: add drm_pcie_get_max_link_width helper (v2)
++    - drm/amdgpu: store pcie gen mask and link width
++    - drm/amdgpu/cgs: add sys info query for pcie gen and link width
++    - drm/amdgpu/powerplay/tonga: query supported pcie info from cgs (v2)
++    - drm/amdgpu/powerplay/fiji: query supported pcie info from cgs (v2)
++    - drm/amd/powerplay: fix boolreturn.cocci warnings
++    - drm/amd/powerplay/tonga: Add UVD DPM init
++    - drm/amd/amdgpu: add gfx clock gating support for Fiji.
++    - drm/amd/amdgpu: add gmc clock gating support for Fiji.
++    - drm/amdgpu: add sdma clock gating support for Fiji.
++    - drm/amd/powerplay: add parts of system clock gating support for Fiji. (v2)
++    - drm/amd/powerplay: enable clock gating for Fiji.
++    - drm/amd/powerplay: add atomctrl function to calculate CZ sclk dividers
++    - drm/amd/powerplay: implement smc state upload for CZ
++    - drm/amd/powerplay: fix warning of cast to pointer from integer of different size.
++    - drm/amd/powerplay: fix warning of cast to pointer from integer of different size.
++    - drm/amd/powerplay: add new function point in hwmgr.
++    - drm/amd/powerplay: add smc msg for NB P-State switch
++    - drm/amd/powerplay: export interface to DAL to init/change display configuration.
++    - drm/amd/powerplay: enable set_cpu_power_state task. (v2)
++    - drm/amd/powerplay: enable/disable NB pstate feature for Carrizo.
++    - drm/amd/powerplay: Add PPLib debug print macro.
++    - drm/amdgpu: rename tonga_smumgr.h to tonga_smum.h
++    - drm/amdgpu: rename fiji_smumgr.h to fiji_smum.h
++    - drm/amd/powerplay: add multimedia power gating support for Fiji.
++    - drm/amd/amdgpu: add uvd6.0 clock gating support. (v2)
++    - drm/amd/amdgpu: add vce3.0 clock gating support. (v2)
++    - drm/amd/amdgpu: enable uvd&vce clock gating for Fiji.
++    - drm/amdgpu: Prepare DKMS build for powerplay module.
++    - drm/amd/powerplay: add display configeration changed function in hwmgr for Fiji.
++    - drm/amd/powerplay: Add thermal protection support for Fiji.
++    - drm/amd/powerplay: Fix a bug in fan control setting default mode for Tonga and Fiji.
++    - drm/amd/powerplay: add functions set/get_fan_control_mode in hwmgr for Tonga.
++    - drm/amd/powerplay: add functions set/get_fan_control_mode in hwmgr for Fiji.
++    - drm/amd/powerplay: fix boolreturn.cocci warnings
++    - drm/amd/powerplay: fix bug that dpm funcs in debugfs/sysfs missing.
++    - drm/amd/powerplay: check whether enable dpm in powerplay.
++    - drm/amd/powerplay: move shared function of vi to hwmgr. (v2)
++    - drm/amdgpu/powerplay: enable sysfs and debugfs interfaces late
++    - drm/amd/powerplay: display gpu load when print performance for tonga.
++    - drm/powerplay: add debugging output to tonga_processpptables.c
++    - drm/powerplay: add debugging output to processpptables.c
++    - drm/powerplay/hwmgr: log errors in tonga_hwmgr_backend_init
++    - drm/amd/powerplay: Don't return an error if fan table is missing
++    - amd\powerplay Implement get dal power level
++    - amd/powerplay: Fix get dal power level
++    - amd/powerplay: Add structures required to report configuration change
++    - drm/amdgpu/powerplay: Program a calculated value as Deep Sleep clock.
++    - drm/amd/powerplay: add point check to avoid NULL point hang.
++    - drm/amd/powerplay: check whether need to enable thermal control. (v2)
++    - drm/amd/powerplay: show gpu load when print gpu performance for Cz. (v2)
++    - drm: powerplay: use div64_s64 instead of do_div
++    - drm/amd/powerplay: fix a reversed condition
++    - drm/amdgpu/cgs: cleanup some indenting
++    - drm/amd/powerplay: precedence bug in init_non_clock_fields()
++    - drm/amdgpu: fix NULL in vm_grab_id while S3 back
++    - drm/amd/powerplay: fix bug that NULL checks are reversed.
++    - drm/amd/powerplay: fix Smatch static checker warnings with indenting (v2)
++    - drm/amd/powerplay: fix Smatch static checker warnings
++    - drm/amd/powerplay: add powerplay valid check to avoid null point. (v2)
++    - drm/amd/powerplay: Reload and initialize the smc firmware on powerplay resume.
++    - drm/amdgpu: Show gpu load when display gpu performance for Ci.
++    - drm/amdgpu: Show gpu load when display gpu performance for Fiji of VI.
++    - drm/amdgpu: fix hex/decimal bug when show gpu load.
++    - drm/amd/powerplay: add thermal control task when resume.
++    - drm/amd/powerplay: enable set boot state task
++    - drm/amd/powerplay: enable power down asic task. (v2)
++    - drm/amd/powerplay: implement power down asic task for CZ
++    - drm/amdgpu: add warning to amdgpu_bo_gpu_offset() v2
++    - drm/amdgpu/cgs: add an interface to access PCI resources
++    - drm/amdgpu: add irq domain support
++    - drm/amdgpu/powerplay: include asm/div64.h for do_div()
++    - drm/sysfs: use kobj_to_dev()
++    - drm/amd/powerplay: fix static checker warning for return meaningless value.
++    - drm/amdgpu/cz: add code to enable forcing UVD clocks
++    - drm/amdgpu/cz: add code to enable forcing VCE clocks
++    - drm/amdgpu/cz: force uvd clocks when sclks are forced
++    - drm/amdgpu/cz: force vce clocks when sclks are forced
++    - drm/amdgpu: use kobj_to_dev()
++    - drm/radeon: use kobj_to_dev()
++    - drm/ttm: fix adding foreign BOs to the LRU during init v2
++    - drm/ttm: fix adding foreign BOs to the swap LRU
++    - drm/ttm: add ttm_bo_move_to_lru_tail function v2
++    - drm/amdgpu: move VM page tables to the LRU end on CS v2
++    - drm/amdgpu: validate duplicates first
++    - drm/amdgpu: add missing irq.h include
++    - drm/fb_cma_helper: Remove implicit call to disable_unused_functions
++    - drm/amdgpu: Add some tweaks to gfx 8 soft reset
++    - amdkfd: don't open-code memdup_user()
++    - amdkfd: Copy from the proper user command pointer
++    - drm/amdgpu: Use drm_calloc_large for VM page_tables array
++    - amd/powerplay: disable powerplay by default initially
++    - drm/amdgpu: Allow the driver to load if amdgpu.powerplay=1 on asics without powerplay support
++    - drm/atomic-helper: Export framebuffer_changed()
++    - drm/amd/amdgpu: Improve amdgpu_dpm* macros to avoid unexpected result (v2)
++    - drm/amdgpu: add a message to indicate when powerplay is enabled (v2)
++    - drm/amdgpu: fix next_rptr handling for debugfs
++    - drm/radeon: Ensure radeon bo is unreserved in radeon_gem_va_ioctl
++    - drm/radeon: only init fbdev if we have connectors
++    - drm/amdgpu: don't init fbdev if we don't have any connectors
++    - drm/amd/powerplay: Update SMU firmware loading for Stoney
++    - drm/amdgpu: fix non-ANSI declaration of amdgpu_amdkfd_gfx_*_get_functions()
++    - drm/amdkfd: Remove unnecessary cast in kfree
++    - drm/amdgpu: only move pt bos in LRU list on success
++    - drm/amdgpu: mask out WC from BO on unsupported arches
++    - drm/amdgpu/gfx8: enable cp inst/reg error interrupts
++    - drm/amdgpu/gfx7: enable cp inst/reg error interrupts
++    - drm/amdgpu: load MEC ucode manually on iceland
++    - drm/amdgpu: disable uvd and vce clockgating on Fiji
++    - drm/amdgpu: add pcie cap module parameters (v2)
++    - drm/amdgpu/cik: don't mess with aspm if gpu is root bus
++    - drm/amdgpu/dpm/ci: switch over to the common pcie caps interface
++    - drm/amdgpu: handle uvd pg flags properly
++    - drm/amdgpu: handle vce pg flags properly
++    - drm/amdgpu: clean up vce pg flags for cz/st
++    - drm/amdgpu: be consistent with uvd cg flags
++    - drm/amd/powerplay/cz: disable uvd pg
++    - drm/amd/powerplay/cz: disable vce pg
++    - drm/amd/powerplay/tonga: disable uvd pg
++    - drm/amd/powerplay/tonga: disable vce pg
++    - drm/amdgpu: add a cgs interface to fetch cg and pg flags
++    - drm/amdgpu: remove unused cg defines
++    - drma/dmgpu: move cg and pg flags into shared headers
++    - drm/amdgpu/tonga: plumb pg flags through to powerplay
++    - drm/amdgpu/cz: plumb pg flags through to powerplay
++    - SAUCE: drm/amdgpu/cz: enable/disable vce dpm even if vce pg is disabled
++
++  * mlx4_core Set UAR page size to 4KB regardless of system page size (LP:
++    #1552632)
++    - net/mlx4_core: Set UAR page size to 4KB regardless of system page size
++
++  * Miscellaneous Ubuntu changes
++    - [Config] CONFIG_CAVIUM_ERRATUM_27456=y
++
++  * Miscellaneous upstream changes
++    - net: thunderx: Fix for Qset error due to CQ full
++    - ahci: Workaround for ThunderX Errata#22536
++    - arm64: Add workaround for Cavium erratum 27456
++    - tipc: fix nullptr crash during subscription cancel
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 07 Mar 2016 05:04:22 -0700
++
++linux (4.4.0-11.26) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1553391
++
++  * Xenial update to v4.4.4 stable release (LP: #1553179)
++    - af_iucv: Validate socket address length in iucv_sock_bind()
++    - gro: Make GRO aware of lightweight tunnels.
++    - net: dp83640: Fix tx timestamp overflow handling.
++    - tunnels: Allow IPv6 UDP checksums to be correctly controlled.
++    - lwt: fix rx checksum setting for lwt devices tunneling over ipv6
++    - tcp: fix NULL deref in tcp_v4_send_ack()
++    - af_unix: fix struct pid memory leak
++    - pptp: fix illegal memory access caused by multiple bind()s
++    - sctp: allow setting SCTP_SACK_IMMEDIATELY by the application
++    - net: dsa: fix mv88e6xxx switches
++    - tipc: fix connection abort during subscription cancel
++    - inet: frag: Always orphan skbs inside ip_defrag()
++    - switchdev: Require RTNL mutex to be held when sending FDB notifications
++    - tcp: beware of alignments in tcp_get_info()
++    - ipv6: enforce flowi6_oif usage in ip6_dst_lookup_tail()
++    - ipv6/udp: use sticky pktinfo egress ifindex on connect()
++    - ipv6: addrconf: Fix recursive spin lock call
++    - ipv6: fix a lockdep splat
++    - unix: correctly track in-flight fds in sending process user_struct
++    - tcp: do not drop syn_recv on all icmp reports
++    - net:Add sysctl_max_skb_frags
++    - tg3: Fix for tg3 transmit queue 0 timed out when too many gso_segs
++    - enic: increment devcmd2 result ring in case of timeout
++    - sctp: translate network order to host order when users get a hmacid
++    - net: Copy inner L3 and L4 headers as unaligned on GRE TEB
++    - flow_dissector: Fix unaligned access in __skb_flow_dissector when used by
++      eth_get_headlen
++    - bpf: fix branch offset adjustment on backjumps after patching ctx expansion
++    - bonding: Fix ARP monitor validation
++    - ipv4: fix memory leaks in ip_cmsg_send() callers
++    - af_unix: Don't set err in unix_stream_read_generic unless there was an error
++    - af_unix: Guard against other == sk in unix_dgram_sendmsg
++    - tipc: fix premature addition of node to lookup table
++    - tcp: md5: release request socket instead of listener
++    - qmi_wwan: add "4G LTE usb-modem U901"
++    - net/mlx4_en: Count HW buffer overrun only once
++    - net/mlx4_en: Avoid changing dev->features directly in run-time
++    - l2tp: Fix error creating L2TP tunnels
++    - pppoe: fix reference counting in PPPoE proxy
++    - net_sched fix: reclassification needs to consider ether protocol changes
++    - route: check and remove route cache when we get route
++    - tcp/dccp: fix another race at listener dismantle
++    - IFF_NO_QUEUE: Fix for drivers not calling ether_setup()
++    - rtnl: RTM_GETNETCONF: fix wrong return value
++    - tipc: unlock in error path
++    - unix_diag: fix incorrect sign extension in unix_lookup_by_ino
++    - sctp: Fix port hash table size computation
++    - ext4: fix bh->b_state corruption
++    - ARM: debug-ll: fix BCM63xx entry for multiplatform
++    - arm64: errata: Add -mpc-relative-literal-loads to build flags
++    - KVM: s390: fix guest fprs memory leak
++    - devm_memremap: Fix error value when memremap failed
++    - drm/gma500: Use correct unref in the gem bo create function
++    - ARM: 8457/1: psci-smp is built only for SMP
++    - lib/ucs2_string: Add ucs2 -> utf8 helper functions
++    - efi: Use ucs2_as_utf8 in efivarfs instead of open coding a bad version
++    - efi: Do variable name validation tests in utf8
++    - efi: Make our variable validation list include the guid
++    - efi: Make efivarfs entries immutable by default
++    - efi: Add pstore variables to the deletion whitelist
++    - lib/ucs2_string: Correct ucs2 -> utf8 conversion
++    - bcache: fix a livelock when we cause a huge number of cache misses
++    - bcache: Add a cond_resched() call to gc
++    - bcache: clear BCACHE_DEV_UNLINK_DONE flag when attaching a backing device
++    - bcache: fix a leak in bch_cached_dev_run()
++    - bcache: unregister reboot notifier if bcache fails to unregister device
++    - bcache: allows use of register in udev to avoid "device_busy" error.
++    - bcache: Change refill_dirty() to always scan entire disk if necessary
++    - dm thin: fix race condition when destroying thin pool workqueue
++    - can: ems_usb: Fix possible tx overflow
++    - usb: dwc3: Fix assignment of EP transfer resources
++    - USB: cp210x: add IDs for GE B650V3 and B850V3 boards
++    - USB: option: add support for SIM7100E
++    - USB: option: add "4G LTE usb-modem U901"
++    - drivers: android: correct the size of struct binder_uintptr_t for
++      BC_DEAD_BINDER_DONE
++    - spi: omap2-mcspi: Prevent duplicate gpio_request
++    - iw_cxgb3: Fix incorrectly returning error on success
++    - drm/i915: shut up gen8+ SDE irq dmesg noise
++    - ocfs2: unlock inode if deleting inode from orphan fails
++    - mm: thp: fix SMP race condition between THP page fault and MADV_DONTNEED
++    - mm: numa: quickly fail allocations for NUMA balancing on full nodes
++    - genirq: Validate action before dereferencing it in handle_irq_event_percpu()
++    - clocksource/drivers/vt8500: Increase the minimum delta
++    - s390/kvm: remove dependency on struct save_area definition
++    - KVM: s390: fix memory overwrites when vx is disabled
++    - Btrfs: add missing brelse when superblock checksum fails
++    - Btrfs: igrab inode in writepage
++    - btrfs: statfs: report zero available if metadata are exhausted
++    - Btrfs: send, don't BUG_ON() when an empty symlink is found
++    - Btrfs: fix number of transaction units required to create symlink
++    - Btrfs: fix transaction handle leak on failure to create hard link
++    - Btrfs: Initialize btrfs_root->highest_objectid when loading tree root and
++      subvolume roots
++    - btrfs: initialize the seq counter in struct btrfs_device
++    - s390: fix normalization bug in exception table sorting
++    - s390/dasd: prevent incorrect length error under z/VM after PAV changes
++    - s390/dasd: fix refcount for PAV reassignment
++    - s390/dasd: fix performance drop
++    - uml: flush stdout before forking
++    - uml: fix hostfs mknod()
++    - um: link with -lpthread
++    - locks: fix unlock when fcntl_setlk races with a close
++    - rtlwifi: rtl_pci: Fix kernel panic
++    - rtlwifi: rtl8192cu: Add missing parameter setup
++    - rtlwifi: rtl8192ce: Fix handling of module parameters
++    - rtlwifi: rtl8192de: Fix incorrect module parameter descriptions
++    - rtlwifi: rtl8723ae: Fix initialization of module parameters
++    - rtlwifi: rtl8192se: Fix module parameter initialization
++    - rtlwifi: rtl8188ee: Fix module parameter initialization
++    - rtlwifi: rtl8723be: Fix module parameter initialization
++    - mei: fix fasync return value on error
++    - mei: validate request value in client notify request ioctl
++    - namei: ->d_inode of a pinned dentry is stable only for positives
++    - rc: sunxi-cir: Initialize the spinlock properly
++    - media: dvb-core: Don't force CAN_INVERSION_AUTO in oneshot mode
++    - si2157: return -EINVAL if firmware blob is too big
++    - gspca: ov534/topro: prevent a division by 0
++    - vb2: fix a regression in poll() behavior for output,streams
++    - tda1004x: only update the frontend properties if locked
++    - dm space map metadata: remove unused variable in brb_pop()
++    - dm snapshot: fix hung bios when copy error occurs
++    - dm: fix dm_rq_target_io leak on faults with .request_fn DM w/ blk-mq paths
++    - coresight: checking for NULL string in coresight_name_match()
++    - irqchip/omap-intc: Add support for spurious irq handling
++    - irqchip/mxs: Add missing set_handle_irq()
++    - irqchip/atmel-aic: Fix wrong bit operation for IRQ priority
++    - irqchip/gic-v3-its: Fix double ICC_EOIR write for LPI in EOImode==1
++    - posix-clock: Fix return code on the poll method's error path
++    - clockevents/tcb_clksrc: Prevent disabling an already disabled clock
++    - mmc: usdhi6rol0: handle NULL data in timeout
++    - mmc: sdhci-pci: Do not default to 33 Ohm driver strength for Intel SPT
++    - mmc: sdio: Fix invalid vdd in voltage switch power cycle
++    - mmc: mmc: Fix incorrect use of driver strength switching HS200 and HS400
++    - mmc: sdhci: Fix sdhci_runtime_pm_bus_on/off()
++    - mmc: core: Enable tuning according to the actual timing
++    - mmc: mmci: fix an ages old detection error
++    - mmc: sdhci-acpi: Fix card detect race for Intel BXT/APL
++    - mmc: pxamci: fix again read-only gpio detection polarity
++    - mmc: sdhci-pci: Fix card detect race for Intel BXT/APL
++    - mmc: sdhci: Allow override of mmc host operations
++    - mmc: sdhci: Allow override of get_cd() called from sdhci_request()
++    - Bluetooth: Use continuous scanning when creating LE connections
++    - Bluetooth: Add support of Toshiba Broadcom based devices
++    - Bluetooth: Fix incorrect removing of IRKs
++    - Bluetooth: 6lowpan: Fix kernel NULL pointer dereferences
++    - Bluetooth: 6lowpan: Fix handling of uncompressed IPv6 packets
++    - time: Avoid signed overflow in timekeeping_get_ns()
++    - cputime: Prevent 32bit overflow in time[val|spec]_to_cputime()
++    - Revert "MIPS: Fix PAGE_MASK definition"
++    - MIPS: Loongson-3: Fix SMP_ASK_C0COUNT IPI handler
++    - MIPS: hpet: Choose a safe value for the ETIME check
++    - MIPS: Fix some missing CONFIG_CPU_MIPSR6 #ifdefs
++    - MIPS: Fix buffer overflow in syscall_get_arguments()
++    - EDAC: Robustify workqueues destruction
++    - EDAC, mc_sysfs: Fix freeing bus' name
++    - sparc64: fix incorrect sign extension in sys_sparc64_personality
++    - clk: exynos: use irqsave version of spin_lock to avoid deadlock with irqs
++    - regulator: axp20x: Fix GPIO LDO enable value for AXP22x
++    - regulator: mt6311: MT6311_REGULATOR needs to select REGMAP_I2C
++    - virtio_balloon: fix race by fill and leak
++    - virtio_balloon: fix race between migration and ballooning
++    - virtio_pci: fix use after free on release
++    - drm/vmwgfx: Fix an incorrect lock check
++    - drm/vmwgfx: Fix a width / pitch mismatch on framebuffer updates
++    - drm/vmwgfx: respect 'nomodeset'
++    - drm/amdgpu: Fix off-by-one errors in amdgpu_vm_bo_map
++    - drm/amdgpu: call hpd_irq_event on resume
++    - drm/amdgpu: fix lost sync_to if scheduler is enabled.
++    - drm/amdgpu: fix tonga smu resume
++    - drm/amdgpu: fix amdgpu_bo_pin_restricted VRAM placing v2
++    - drm/amdgpu: no need to load MC firmware on fiji
++    - drm/amdgpu: move gmc7 support out of CIK dependency
++    - drm/amdgpu: iceland use CI based MC IP
++    - drm/amdgpu: The VI specific EXE bit should only apply to GMC v8.0 above
++    - drm/amdgpu: pull topaz gmc bits into gmc_v7
++    - drm/amdgpu: drop topaz support from gmc8 module
++    - drm/amdgpu: don't load MEC2 on topaz
++    - drm/amdgpu: remove exp hardware support from iceland
++    - drm/amdgpu: fix s4 resume
++    - drm/amdgpu: remove unnecessary forward declaration
++    - drm/amdgpu: hold reference to fences in amdgpu_sa_bo_new (v2)
++    - drm/amdgpu: fix issue with overlapping userptrs
++    - drm/amdgpu: use post-decrement in error handling
++    - drm/amdgpu: Don't hang in amdgpu_flip_work_func on disabled crtc.
++    - drm/amdgpu/pm: adjust display configuration after powerstate
++    - drm/nouveau/kms: take mode_config mutex in connector hotplug path
++    - drm/nouveau/display: Enable vblank irqs after display engine is on again.
++    - drm/nouveau/disp/dp: ensure sink is powered up before attempting link
++      training
++    - drm/nouveau: platform: Fix deferred probe
++    - drm/dp/mst: process broadcast messages correctly
++    - drm/dp/mst: always send reply for UP request
++    - drm/dp/mst: fix in MSTB RAD initialization
++    - drm/dp/mst: fix in RAD element access
++    - drm: Add drm_fixp_from_fraction and drm_fixp2int_ceil
++    - drm/dp/mst: Calculate MST PBN with 31.32 fixed point
++    - drm/dp/mst: move GUID storage from mgr, port to only mst branch
++    - drm/dp/mst: Reverse order of MST enable and clearing VC payload table.
++    - drm/dp/mst: deallocate payload on port destruction
++    - drm/radeon: Fix off-by-one errors in radeon_vm_bo_set_addr
++    - drm/radeon: call hpd_irq_event on resume
++    - drm/radeon: Fix "slow" audio over DP on DCE8+
++    - drm/radeon: clean up fujitsu quirks
++    - drm/radeon: properly byte swap vce firmware setup
++    - drm/radeon: cleaned up VCO output settings for DP audio
++    - drm/radeon: Add a common function for DFS handling
++    - drm/radeon: fix DP audio support for APU with DCE4.1 display engine
++    - drm: add helper to check for wc memory support
++    - drm/radeon: mask out WC from BO on unsupported arches
++    - drm/radeon: hold reference to fences in radeon_sa_bo_new
++    - drm: fix missing reference counting decrease
++    - drm/i915: Restore inhibiting the load of the default context
++    - drm/i915: intel_hpd_init(): Fix suspend/resume reprobing
++    - drm/i915: Init power domains early in driver load
++    - drm/i915: Make sure DC writes are coherent on flush.
++    - drm/i915/dp: fall back to 18 bpp when sink capability is unknown
++    - drm/i915: Don't reject primary plane windowing with color keying enabled on
++      SKL+
++    - drm/i915/skl: Don't skip mst encoders in skl_ddi_pll_select()
++    - drm/i915/dsi: defend gpio table against out of bounds access
++    - drm/i915/dsi: don't pass arbitrary data to sideband
++    - drm/i915: fix error path in intel_setup_gmbus()
++    - drm/qxl: use kmalloc_array to alloc reloc_info in qxl_process_single_command
++    - drm/radeon: use post-decrement in error handling
++    - drm: No-Op redundant calls to drm_vblank_off() (v2)
++    - drm: Prevent vblank counter bumps > 1 with active vblank clients. (v2)
++    - drm: Fix drm_vblank_pre/post_modeset regression from Linux 4.4
++    - drm: Fix treatment of drm_vblank_offdelay in drm_vblank_on() (v2)
++    - drm/radeon: Don't hang in radeon_flip_work_func on disabled crtc. (v2)
++    - drm/radeon/pm: adjust display configuration after powerstate
++    - make sure that freeing shmem fast symlinks is RCU-delayed
++    - toshiba_acpi: Fix blank screen at boot if transflective backlight is
++      supported
++    - ideapad-laptop: Add Lenovo ideapad Y700-17ISK to no_hw_rfkill dmi list
++    - ideapad-laptop: Add Lenovo Yoga 700 to no_hw_rfkill dmi list
++    - uapi: update install list after nvme.h rename
++    - lib: sw842: select crc32
++    - ACPI / video: Add disable_backlight_sysfs_if quirk for the Toshiba Portege
++      R700
++    - ACPI / video: Add disable_backlight_sysfs_if quirk for the Toshiba Satellite
++      R830
++    - ACPI: Revert "ACPI / video: Add Dell Inspiron 5737 to the blacklist"
++    - ACPI / PCI / hotplug: unlock in error path in acpiphp_enable_slot()
++    - nfit: fix multi-interface dimm handling, acpi6.1 compatibility
++    - dmaengine: dw: fix cyclic transfer setup
++    - dmaengine: dw: fix cyclic transfer callbacks
++    - dmaengine: at_xdmac: fix resume for cyclic transfers
++    - dmaengine: dw: disable BLOCK IRQs for non-cyclic xfer
++    - IB/cm: Fix a recently introduced deadlock
++    - IB/qib: fix mcast detach when qp not attached
++    - IB/qib: Support creating qps with GFP_NOIO flag
++    - IB/mlx5: Expose correct maximum number of CQE capacity
++    - Thermal: initialize thermal zone device correctly
++    - Thermal: handle thermal zone device properly during system sleep
++    - Thermal: do thermal zone update after a cooling device registered
++    - hwmon: (dell-smm) Blacklist Dell Studio XPS 8000
++    - hwmon: (gpio-fan) Remove un-necessary speed_index lookup for thermal hook
++    - hwmon: (ads1015) Handle negative conversion values correctly
++    - cpufreq: pxa2xx: fix pxa_cpufreq_change_voltage prototype
++    - cpufreq: Fix NULL reference crash while accessing policy->governor_data
++    - seccomp: always propagate NO_NEW_PRIVS on tsync
++    - libceph: fix ceph_msg_revoke()
++    - libceph: don't bail early from try_read() when skipping a message
++    - libceph: use the right footer size when skipping a message
++    - libceph: don't spam dmesg with stray reply warnings
++    - sd: Optimal I/O size is in bytes, not sectors
++    - Staging: speakup: Fix getting port information
++    - Revert "Staging: panel: usleep_range is preferred over udelay"
++    - cdc-acm:exclude Samsung phone 04e8:685d
++    - perf stat: Do not clean event's private stats
++    - tick/nohz: Set the correct expiry when switching to nohz/lowres mode
++    - rfkill: fix rfkill_fop_read wait_event usage
++    - mac80211: Requeue work after scan complete for all VIF types.
++    - workqueue: handle NUMA_NO_NODE for unbound pool_workqueue lookup
++    - Revert "workqueue: make sure delayed work run in local cpu"
++    - ALSA: hda - Apply clock gate workaround to Skylake, too
++    - ALSA: hda - Fixing background noise on Dell Inspiron 3162
++    - target: Fix LUN_RESET active I/O handling for ACK_KREF
++    - target: Fix LUN_RESET active TMR descriptor handling
++    - target: Fix TAS handling for multi-session se_node_acls
++    - target: Fix remote-port TMR ABORT + se_cmd fabric stop
++    - target: Fix race with SCF_SEND_DELAYED_TAS handling
++    - spi: atmel: fix gpio chip-select in case of non-DT platform
++    - libata: fix sff host state machine locking while polling
++    - ARCv2: STAR 9000950267: Handle return from intr to Delay Slot #2
++    - ARCv2: SMP: Emulate IPI to self using software triggered interrupt
++    - PCI/AER: Flush workqueue on device remove to avoid use-after-free
++    - cpuset: make mm migration asynchronous
++    - cgroup: make sure a parent css isn't offlined before its children
++    - writeback: keep superblock pinned during cgroup writeback association
++      switches
++    - phy: core: fix wrong err handle for phy_power_on
++    - i2c: i801: Adding Intel Lewisburg support for iTCO
++    - bio: return EINTR if copying to user space got interrupted
++    - block: fix use-after-free in dio_bio_complete
++    - nfs: fix nfs_size_to_loff_t
++    - NFSv4: Fix a dentry leak on alias use
++    - of/irq: Fix msi-map calculation for nonzero rid-base
++    - KVM: async_pf: do not warn on page allocation failures
++    - KVM: arm/arm64: vgic: Ensure bitmaps are long enough
++    - KVM: x86: fix missed hardware breakpoints
++    - KVM: x86: MMU: fix ubsan index-out-of-range warning
++    - powerpc/eeh: Fix partial hotplug criterion
++    - tracing: Fix showing function event in available_events
++    - sunrpc/cache: fix off-by-one in qword_get()
++    - kernel/resource.c: fix muxed resource handling in __request_region()
++    - do_last(): don't let a bogus return value from ->open() et.al. to confuse us
++    - ARM: OMAP2+: Fix onenand initialization to avoid filesystem corruption
++    - ARM: at91/dt: fix typo in sama5d2 pinmux descriptions
++    - xen/arm: correctly handle DMA mapping of compound pages
++    - xen/scsiback: correct frontend counting
++    - xen/pciback: Check PF instead of VF for PCI_COMMAND_MEMORY
++    - xen/pciback: Save the number of MSI-X entries to be copied later.
++    - xen/pcifront: Fix mysterious crashes when NUMA locality information was
++      extracted.
++    - should_follow_link(): validate ->d_seq after having decided to follow
++    - do_last(): ELOOP failure exit should be done after leaving RCU mode
++    - hpfs: don't truncate the file when delete fails
++    - x86/irq: Call chip->irq_set_affinity in proper context
++    - x86/irq: Fix a race in x86_vector_free_irqs()
++    - x86/irq: Validate that irq descriptor is still active
++    - x86/irq: Do not use apic_chip_data.old_domain as temporary buffer
++    - x86/irq: Reorganize the return path in assign_irq_vector
++    - x86/irq: Reorganize the search in assign_irq_vector
++    - x86/irq: Check vector allocation early
++    - x86/irq: Copy vectormask instead of an AND operation
++    - x86/irq: Get rid of code duplication
++    - x86/irq: Remove offline cpus from vector cleanup
++    - x86/irq: Clear move_in_progress before sending cleanup IPI
++    - x86/irq: Remove the cpumask allocation from send_cleanup_vector()
++    - x86/irq: Remove outgoing CPU from vector cleanup mask
++    - x86/irq: Call irq_force_move_complete with irq descriptor
++    - x86/irq: Plug vector cleanup race
++    - IB/cma: Fix RDMA port validation for iWarp
++    - iwlwifi: dvm: fix WoWLAN
++    - iwlwifi: pcie: properly configure the debug buffer size for 8000
++    - iwlwifi: update and fix 7265 series PCI IDs
++    - iwlwifi: mvm: don't allow sched scans without matches to be started
++    - Revert "UBUNTU: SAUCE: bcache: prevent crash on changing writeback_running"
++    - bcache: prevent crash on changing writeback_running
++    - Linux 4.4.4
++
++  * mlx4_en didn't choose time-stamping shift value according to HW frequency
++    (LP: #1552627)
++    - net/mlx4_en: Choose time-stamping shift value according to HW frequency
++
++  * [Ubuntu 16.04] Help to flush kernel panics to console (LP: #1552332)
++    - target/transport: add flag to indicate CPU Affinity is observed
++    - powerpc/powernv: Add a kmsg_dumper that flushes console output on panic
++    - powerpc/powernv: Fix OPAL_CONSOLE_FLUSH prototype and usages
++
++  * [Ubuntu 16.04] Update qla2xxx driver for POWER (QLogic) (LP: #1541456)
++    - qla2xxx: Fix warning reported by static checker
++    - qla2xxx: Fix TMR ABORT interaction issue between qla2xxx and TCM
++    - qla2xxx: Fix stale pointer access.
++    - qla2xxx: Use ATIO type to send correct tmr response
++    - qla2xxx: use TARGET_SCF_USE_CPUID flag to indiate CPU Affinity
++
++  * [s390x] zfcp.ko missing from scsi-modules udeb (LP: #1552314)
++    - [Config] Add s390x zfcp to scsi-modules udeb
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 02 Mar 2016 08:08:16 -0700
++
++linux (4.4.0-10.25) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1552247
++
++  * linux:  4.4.0-9.X fails yama ptrace restrictions tests (LP: #1551894)
++    - security: let security modules use PTRACE_MODE_* with bitmasks
++
++  * [wily][regression] systemtap script compilation broken by new kernels (LP: #1545330)
++    - SAUCE: (noup) locking/qspinlock: Move __ARCH_SPIN_LOCK_UNLOCKED to qspinlock_types.h
++
++  * [Feature]SD/SDIO/eMMC support for Broxton-P (LP: #1520454)
++    - mmc: sdhci: 64-bit DMA actually has 4-byte alignment
++    - mmc: sdhci: Fix DMA descriptor with zero data length
++
++  * Miscellaneous Ubuntu changes
++    - SAUCE: (noup) cgroup: fix and restructure error handling in copy_cgroup_ns()
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Feb 2016 13:04:14 -0700
++
++linux (4.4.0-9.24) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1551319
++
++  * AppArmor logs denial for when the device path is ENOENT (LP: #1482943)
++    - SAUCE: apparmor: fix log of apparmor audit message when kern_path() fails
++
++  * BUG: unable to handle kernel NULL pointer dereference (aa_label_merge) (LP:
++    #1448912)
++    - SAUCE: apparmor: Fix: insert race between label_update and label_merge
++    - SAUCE: apparmor: Fix: ensure aa_get_newest will trip debugging if the
++      replacedby is not setup
++    - SAUCE: apparmor: Fix: label merge handling of marking unconfined and stale
++    - SAUCE: apparmor: Fix: refcount race between locating in labelset and get
++    - SAUCE: apparmor: Fix: ensure new labels resulting from merge have a
++      replacedby
++    - SAUCE: apparmor: Fix: label_vec_merge insertion
++    - SAUCE: apparmor: Fix: deadlock in aa_put_label() call chain
++    - SAUCE: apparmor: Fix: add required locking of __aa_update_replacedby on
++      merge path
++    - SAUCE: apparmor: Fix: convert replacedby update to be protected by the
++      labelset lock
++    - SAUCE: apparmor: Fix: update replacedby allocation to take a gfp parameter
++
++  * apparmor kernel BUG kills firefox (LP: #1430546)
++    - SAUCE: apparmor: Disallow update of cred when then subjective != the
++      objective cred
++    - SAUCE: apparmor: rework retrieval of the current label in the profile update
++      case
++
++  * sleep from invalid context in aa_move_mount (LP: #1539349)
++    - SAUCE: apparmor: fix sleep from invalid context
++
++  * s390x: correct restore of high gprs on signal return (LP: #1550468)
++    - s390/compat: correct restore of high gprs on signal return
++
++  * missing SMAP support (LP: #1550517)
++    - x86/entry/compat: Add missing CLAC to entry_INT80_32
++
++  * Floating-point exception handler receives empty Data-Exception Code in
++    Floating Point Control register (LP: #1548414)
++    - s390/fpu: signals vs. floating point control register
++
++  * kvm fails to boot GNU Hurd kernels with 4.4 Xenial kernel (LP: #1550596)
++    - KVM: x86: fix conversion of addresses to linear in 32-bit protected mode
++
++  * Surelock GA2 SP1: capiredp01: cxl_init_adapter fails for CAPI devices
++    0000:01:00.0 and 0005:01:00.0 after upgrading to 840.10 Platform firmware
++    build fips840/b1208b_1604.840 (LP: #1532914)
++    - cxl: Fix PSL timebase synchronization detection
++
++  * [Feature]EDAC support for Knights Landing (LP: #1519631)
++    - EDAC, sb_edac: Set fixed DIMM width on Xeon Knights Landing
++
++  * Various failures of kernel_security suite on Xenial kernel on s390x arch
++    (LP: #1531327)
++    - [config] s390x -- CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
++
++  * Unable to install VirtualBox Guest Service in 15.04 (LP: #1434579)
++    - [Config] Provides: virtualbox-guest-modules when appropriate
++
++  * linux is missing provides for virtualbox-guest-modules [i386 amd64 x32] (LP:
++    #1507588)
++    - [Config] Provides: virtualbox-guest-modules when appropriate
++
++  * Backport more recent driver for SKL, KBL and BXT graphics (LP: #1540390)
++    - SAUCE: i915_bpo: Provide a backport driver for SKL, KBL & BXT graphics
++    - SAUCE: i915_bpo: Update intel_ips.h file location
++    - SAUCE: i915_bpo: Rename the backport driver to i915_bpo
++    - SAUCE: i915_bpo: Add i915_bpo_*() calls for ubuntu/i915
++    - drm/i915: remove an extra level of indirection in PCI ID list
++    - drm/i915/kbl: Add Kabylake PCI ID
++    - drm/i915/kbl: Add Kabylake GT4 PCI ID
++    - mm: Export nr_swap_pages
++    - async: export current_is_async()
++    - drm: fix potential dangling else problems in for_each_ macros
++    - dp/mst: add SDP stream support
++    - drm: Implement drm_modeset_lock_all_ctx()
++    - drm: Add "prefix" parameter to drm_rect_debug_print()
++    - drm/i915: Set connector_state->connector using the helper.
++    - drm/atomic: add connector mask to drm_crtc_state.
++    - drm/i915: Report context GTT size
++    - drm/i915: Add get_eld audio component
++    - SAUCE: Backport I915_PARAM_HAS_EXEC_SOFTPIN and EXEC_OBJECT_PINNED
++    - SAUCE: i915_bpo: Revert passing plane/encoder name
++    - SAUCE: sound/hda: Load i915_bpo from the hda driver on SKL/KBL/BXT
++    - SAUCE: i915_bpo: Support only SKL, KBL and BXT with the backport driver
++    - drm/i915/bxt: update list of PCIIDs
++    - drm/i915/skl: Add missing SKL ids
++    - SAUCE: i915_bpo: Revert "drm/i915: Defer probe if gmux is present but its
++      driver isn't"
++    - SAUCE: uapi/drm/i915: Backport I915_EXEC_BSD_MASK
++    - drm/atomic: Do not unset crtc when an encoder is stolen
++    - drm/i915: Update connector_mask during readout, v2.
++    - drm/atomic: Add encoder_mask to crtc_state, v3.
++    - SAUCE: drm/core: Add drm_encoder_index.
++    - SAUCE: i915_bpo: Revert "drm/i915: Switch DDC when reading the EDID"
++    - i915_bpo: [Config] Enable CONFIG_DRM_I915_BPO=m
++
++  * arm64: guest hangs when ntpd is running (LP: #1549494)
++    - hrtimer: Add support for CLOCK_MONOTONIC_RAW
++    - hrtimer: Catch illegal clockids
++    - KVM: arm/arm64: timer: Switch to CLOCK_MONOTONIC_RAW
++
++  * Miscellaneous Ubuntu changes
++    - [Debian] git-ubuntu-log -- wrap long bug and commit titles
++    - [Config] CONFIG_ARM_SMMU=y on arm64
++    - rebase to v4.4.3
++    - [Debian] git-ubuntu-log -- ensure we get the last commit
++    - [Config] fix up spelling of probably again
++    - [Debian] perf -- build in the context of the full generated local headers
++    - SAUCE: tools: lib/bpf -- add generated headers to search path
++    - SAUCE: proc: Always set super block owner to init_user_ns
++    - SAUCE: fix-up: kern_mount fail path should not be doing put_buffers()
++    - SAUCE: apparmor: Fix: oops do to invalid null ptr deref in label print fns
++    - SAUCE: apparmor: debug: POISON label and replaceby pointer on free
++    - SAUCE: apparmor: add underscores to indicate aa_label_next_not_in_set() use
++      needs locking
++    - SAUCE: apparmor: Fix: refcount leak in aa_label_merge
++    - SAUCE: apparmor: ensure that repacedby sharing is done correctly
++    - SAUCE: apparmor Fix: refcount bug in pivotroot mediation
++    - SAUCE: apparmor: Fix: now that insert can force replacement use it instead
++      of remove_and_insert
++    - SAUCE: apparmor: Fix: refcount bug when inserting label update that
++      transitions ns
++    - SAUCE: apparmor: Fix: break circular refcount for label that is directly
++      freed.
++    - SAUCE: apparmor: Don't remove label on rcu callback if the label has already
++      been removed
++    - SAUCE: apparmor: Fix: query label file permission
++    - SAUCE: apparmor: fix: ref count leak when profile sha1 hash is read
++    - SAUCE: fixup: cleanup return handling of labels
++    - SAUCE: fix: replacedby forwarding is not being properly update when ns is
++      destroyed
++    - SAUCE: fixup: make __share_replacedby private to get rid of build warning
++    - SAUCE: fixup: 20/23 locking issue around in __label_update
++    - SAUCE: fixup: get rid of unused var build warning
++    - SAUCE: fixup: cast poison values to remove warnings
++    - SAUCE: apparmor: fix refcount race when finding a child profile
++    - SAUCE: fixup: warning about aa_label_vec_find_or_create not being static
++    - SAUCE: fix: audit "no_new_privs" case for exec failure
++    - SAUCE: Fixup: __label_update() still doesn't handle some cases correctly.
++    - SAUCE: Move replacedby allocation into label_alloc
++    - [Debian] supply zfs dkms Provides: based on do_zfs
++    - [Config] supply zfs dkms Provides: based on do_zfs
++    - [Config] drop linux-image-3.0 provides
++
++  * Miscellaneous upstream changes
++    - x86/mpx: Fix off-by-one comparison with nr_registers
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.4.3
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 25 Feb 2016 19:47:55 -0700
++
++linux (4.4.0-8.23) xenial; urgency=low
++
++  * cgroup namespace mounts broken in containers (LP: #1549398)
++    - SAUCE: kernfs: Always set super block owner to init_user_ns
++
++  * 4.4.0-7.22 no longer boots on arm64 (LP: #1547718)
++    - arm64: mm: avoid calling apply_to_page_range on empty range
++    - UBUNTU SAUCE: arm: mm: avoid calling apply_to_page_range on empty range
++
++  * kernel install failed /bin/cp: cannot stat ‘/boot/initrd.img-4.3.0-7-generic’: No such file or directory (LP: #1536810)
++    - [Config] postinst -- handle recreating symlinks when a real file is present
++
++  * insecure overlayfs xattrs handling in copy_up (LP: #1534961)
++    - SAUCE: cred: Add clone_cred() interface
++    - SAUCE: overlayfs: Use mounter's credentials instead of selectively raising caps
++    - SAUCE: overlayfs: Skip permission checking for trusted.overlayfs.* xattrs
++    - SAUCE: overlayfs: Be more careful about copying up sxid files
++    - SAUCE: overlayfs: Propogate nosuid from lower and upper mounts
++
++  * overlayfs over fuse should refuse copy_up of files if uid/gid not mapped (LP: #1535150)
++    - SAUCE: cred: Add clone_cred() interface
++    - SAUCE: overlayfs: Use mounter's credentials instead of selectively raising caps
++    - SAUCE: overlayfs: Skip permission checking for trusted.overlayfs.* xattrs
++    - SAUCE: overlayfs: Be more careful about copying up sxid files
++    - SAUCE: overlayfs: Propogate nosuid from lower and upper mounts
++
++  * overlay: mkdir fails if directory exists in lowerdir in a user namespace (LP: #1531747)
++    - SAUCE: cred: Add clone_cred() interface
++    - SAUCE: overlayfs: Use mounter's credentials instead of selectively raising caps
++    - SAUCE: overlayfs: Skip permission checking for trusted.overlayfs.* xattrs
++
++  * Update Intel ethernet drivers to Fortville SW5 (LP: #1547674)
++    - net: bulk free infrastructure for NAPI context, use napi_consume_skb
++    - net: Add eth_platform_get_mac_address() helper.
++    - i40e: Add mac_filter_element at the end of the list instead of HEAD
++    - i40e/i40evf: Fix RSS rx-flow-hash configuration through ethtool
++    - i40e: Replace X722 mac check in ethtool get_settings
++    - i40evf: allow channel bonding of VFs
++    - i40e: define function capabilities in only one place
++    - i40evf: null out ring pointers on free
++    - i40e: Cleanup the code with respect to restarting autoneg
++    - i40e: update features with right offload
++    - i40e: bump version to 1.4.10
++    - i40e: add new device IDs for X722
++    - i40e: Extend ethtool RSS hooks for X722
++    - i40e/i40evf: Fix for UDP/TCP RSS for X722
++    - i40evf: add new write-back mode
++    - i40e/i40evf: Use private workqueue
++    - i40e: add new proxy-wol bit for X722
++    - i40e: Limit DCB FW version checks to X710/XL710 devices
++    - i40e: AQ Add Run PHY Activity struct
++    - i40e: AQ Geneve cloud tunnel type
++    - i40e: AQ Add external power class to get link status
++    - i40e: add 100Mb ethtool reporting
++    - ixgbe: bulk free SKBs during TX completion cleanup cycle
++    - igb: Remove unnecessary flag setting in igb_set_flag_queue_pairs()
++    - igb: Unpair the queues when changing the number of queues
++    - igb/igbvf: don't give up
++    - igb: clean up code for setting MAC address
++    - igb: Refactor VFTA configuration
++    - igb: Allow asymmetric configuration of MTU versus Rx frame size
++    - igb: Do not factor VLANs into RLPML calculation
++    - igb: Always enable VLAN 0 even if 8021q is not loaded
++    - igb: Merge VLVF configuration into igb_vfta_set
++    - igb: Clean-up configuration of VF port VLANs
++    - igb: Add support for VLAN promiscuous with SR-IOV and NTUPLE
++    - igb: Drop unnecessary checks in transmit path
++    - igb: Enable use of "bridge fdb add" to set unicast table entries
++    - igb: Add workaround for VLAN tag stripping on 82576
++    - i40e: AQ Shared resource flags
++    - i40e: AQ Add set_switch_config
++    - i40e: AQ Add VXLAN-GPE tunnel type
++    - i40e: AQ thermal sensor control struct
++    - i40e: Bump AQ minor version to 1.5 for new FW features
++    - i40e: Store lan_vsi_idx and lan_vsi_id in the right size
++    - i40e: fix write-back-on-itr to work with legacy itr
++    - i40e: add counter for arq overflows
++    - i40e: add 20G speed for Tx bandwidth calculations
++    - i40e: refactor DCB function
++    - i40e: add a little more to an NVM update debug message
++    - i40evf: enable bus master after reset
++    - i40e: add netdev info to VSI dump
++    - i40e: remove VF device IDs from PF
++    - i40e: trivial: remove unnecessary local var
++    - i40e/i40evf: Bump i40e to 1.4.11 and i40evf to 1.4.7
++    - net: ixgbe: add minimal parser details for ixgbe
++    - i40e: trivial: drop duplicate definition
++    - i40e: trivial: fix missing space
++    - i40e: fix bug in dma sync
++    - i40e: do TSO only if CHECKSUM_PARTIAL is set
++    - i40e: allocate memory safer
++    - i40e: fix: do not sleep in netdev_ops
++    - i40e: APIs to Add/remove port mirroring rules
++    - i40e: negate PHY int mask bits
++    - i40e: drop unused function
++    - i40e: count allocation errors
++    - i40e: avoid large memcpy by assigning struct
++    - i40e/i40evf: bump version to 1.4.12/1.4.8
++    - i40e: Enable Geneve offload for FW API ver > 1.4 for XL710/X710 devices
++    - i40e: add priv flag for automatic rule eviction
++    - i40e: use eth_platform_get_mac_address()
++    - i40e: move sync_vsi_filters up in service_task
++    - i40e: Make the DCB firmware checks for X710/XL710 only
++    - i40e: set shared bit for multicast filters
++    - i40e: add VEB stat control and remove L2 cloud filter
++    - i40e: use new add_veb calling with VEB stats control
++    - i40e: Refactor force_wb and WB_ON_ITR functionality code
++    - i40evf: Change vf driver string to reflect all products i40evf supports
++    - i40e/i40evf: don't lose interrupts
++    - i40e/i40evf: try again after failure
++    - i40e: dump descriptor indexes in hex
++    - i40e/i40evf: use __GFP_NOWARN
++    - i40e/i40evf: use pages correctly in Rx
++    - i40e/i40evf: use logical operators, not bitwise
++    - i40e: properly show packet split status in debugfs
++    - i40e/i40evf: Bump version
++    - ixgbe: use u32 instead of __u32 in model header
++    - ixgbe: fix dates on header of ixgbe_model.h
++    - i40e: get rid of magic number
++    - i40e: drop unused debugfs file "dump"
++    - i40evf: support packet split receive
++    - i40e: trivial: cleanup use of pf->hw
++    - i40e: Add a SW workaround for lost interrupts
++    - i40e: Fix PROMISC mode for Multi-function per port (MFP) devices
++    - i40e: Removal of code which relies on BASE VEB SEID
++    - i40e/i40evf: avoid atomics
++    - i40e: Do not disable queues in the Legacy/MSI Interrupt handler
++    - i40e: expand comment
++    - i40e: better error reporting for nvmupdate
++    - i40evf: set adapter state on reset failure
++    - i40e: clean event descriptor before use
++    - i40e: When in promisc mode apply promisc mode to Tx Traffic as well
++    - i40e/i40evf: Bump i40e to 1.4.15 and i40evf to 1.4.11.
++    - i40e/i40evf: Drop outer checksum offload that was not requested
++    - i40e/i40evf: Use u64 values instead of casting them in TSO function
++    - i40e/i40evf: Factor out L4 header and checksum from L3 bits in TSO path
++    - i40e/i40evf: Consolidate all header changes into TSO function
++    - i40e/i40evf: Replace header pointers with unions of pointers in Tx checksum path
++    - i40e/i40evf: Add support for IPv4 encapsulated in IPv6
++    - i40e/i40evf: Handle IPv6 extension headers in checksum offload
++    - i40e/i40evf: Do not write to descriptor unless we complete
++    - i40e/i40evf: Add exception handling for Tx checksum
++    - i40e/i40evf: Clean-up Rx packet checksum handling
++    - i40e/i40evf: Enable support for SKB_GSO_UDP_TUNNEL_CSUM
++    - i40e: Fix ATR in relation to tunnels
++    - i40e: Do not drop support for IPv6 VXLAN or GENEVE tunnels
++    - i40e: Update feature flags to reflect newly enabled features
++    - i40evf: Update feature flags to reflect newly enabled features
++    - i40e: Add support for ATR w/ IPv6 extension headers
++    - i40e/i40evf: Break up xmit_descriptor_count from maybe_stop_tx
++    - i40e/i40evf: Rewrite logic for 8 descriptor per packet check
++    - i40e/i40evf: Move Tx checksum closer to TSO
++    - i40e: Add functions to blink led on 10GBaseT PHY
++    - i40e: Fix led blink capability for 10GBaseT PHY
++    - i40e: Increase timeout when checking GLGEN_RSTAT_DEVSTATE bit
++    - i40e: Do not wait for Rx queue disable in DCB reconfig
++    - i40e: Fix for unexpected messaging
++    - i40e: Expose some registers to program parser, FD and RSS logic
++    - i40e: add check for null VSI
++    - i40e: add adminq commands for Rx CTL registers
++    - i40e: implement and use Rx CTL helper functions
++    - i40e: Use the new rx ctl register helpers. Don't use AQ calls from clear_hw.
++    - i40e: suspend scheduling during driver unload
++    - i40e: let go of the past
++    - i40e/i40evf: Bump i40e to 1.4.25 and i40evf to 1.4.15
++
++  * MPT3SAS Driver update for next kernel release (LP: #1512221)
++    - mpt3sas: A correction in unmap_resources
++    - mpt3sas: Added support for high port count HBA variants.
++    - mpt3sas: Used IEEE SGL instead of MPI SGL while framing a SMP Passthrough request message.
++    - mpt3sas: Fix static analyzer(coverity) tool identified defects
++    - mpt3sas: Never block the Enclosure device
++    - mpt3sas: Make use of additional HighPriority credit message frames for sending SCSI IO's
++    - mpt3sas: Added smp_affinity_enable module parameter.
++    - mpt3sas: Add support for configurable Chain Frame Size
++    - mpt3sas: Updated MPI Header to 2.00.42
++    - mpt3sas: Fix for Asynchronous completion of timedout IO and task abort of timedout IO.
++    - mpt3sas: Updating mpt3sas driver version to 12.100.00.00
++    - mpt3sas: Remove cpumask_clear for zalloc_cpumask_var and don't free free_cpu_mask_var before reply_q
++
++  * /sys/class/scsi_host/hostN/partition_number and .../mad_version showing up BE on LE Ubuntu. (ibmvscsi) (LP: #1547153)
++    - ibmvscsi: Add endian conversions to sysfs attribute show functions
++
++  * Miscellaneous Ubuntu changes
++    - [Packaging] git-ubuntu-log -- output should be utf-8
++    - [Packaging] git-ubuntu-log -- handle invalid or private bugs
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 24 Feb 2016 20:34:49 +0000
++
++linux (4.4.0-7.22) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1547205
++
++  * need arm64 acpi parking protocol support in xenial (LP: #1547047)
++    - [Config] Enabled ARM64_ACPI_PARKING_PROTOCOL
++    - arm64: kernel: implement ACPI parking protocol
++
++  * Please pull cgroup namespaces (LP: #1546775)
++    - SAUCE: (noup) kernfs: Add API to generate relative kernfs path
++    - SAUCE: (noup) sched: new clone flag CLONE_NEWCGROUP for cgroup namespace
++    - SAUCE: (noup) cgroup: introduce cgroup namespaces
++    - SAUCE: (noup) cgroup: cgroup namespace setns support
++    - SAUCE: (noup) kernfs: define kernfs_node_dentry
++    - SAUCE: (noup) cgroup: mount cgroupns-root when inside non-init cgroupns
++    - SAUCE: (noup) Add FS_USERNS_FLAG to cgroup fs
++    - SAUCE: (noup) cgroup: Add documentation for cgroup namespaces
++
++  * [Feature]Pulse-Width Modulation enabling on Broxton-P (LP: #1520436)
++    - [Config] CONFIG_PWM_OMAP_DMTIMER=m
++    - pwm: lpss: Remove ->free() callback
++    - pwm: bcm2835: Calculate scaler in ->config()
++    - pwm: bcm2835: Prevent division by zero
++    - pwm: bcm2835: Fix email address specification
++    - pwm: lpss: Update PWM setting for Broxton
++    - pwm: lpss: Select core part automatically
++    - pwm: lpss: Rework the sequence of programming PWM_SW_UPDATE
++    - pwm: fsl-ftm: Fix clock enable/disable when using PM
++    - pwm: lpc32xx: correct number of PWM channels from 2 to 1
++    - pwm: lpc32xx: make device usable with common clock framework
++    - pwm: lpc32xx: fix and simplify duty cycle and period calculations
++    - pwm: lpc32xx: return ERANGE, if requested period is not supported
++    - pwm: rcar: Improve accuracy of frequency division setting
++    - pwm: Add PWM driver for OMAP using dual-mode timers
++    - pwm: add HAS_IOMEM dependency to PWM_FSL_FTM
++    - pwm: omap-dmtimer: Potential NULL dereference on error
++    - pwm: Mark all devices as "might sleep"
++
++  * [Hyper-V] Netmask value is not parsed by hv_set_ifconfig - IP injection (LP: #1540586)
++    - [Debian] hv: hv_set_ifconfig -- switch to approved indentation
++    - [Debian] hv: hv_set_ifconfig -- fix numerous parameter handling issues
++
++  * Update megaraid driver to MR6.10 (LP: #1544679)
++    - megaraid_sas: Do not allow PCI access during OCR
++    - megaraid_sas: MFI IO timeout handling
++    - megaraid_sas: Syncing request flags macro names with firmware
++    - megaraid_sas: Task management support
++    - megaraid_sas: Update device queue depth based on interface type
++    - megaraid_sas: Fastpath region lock bypass
++    - megaraid_sas: Reply Descriptor Post Queue (RDPQ) support
++    - megaraid_sas: Code optimization build_and_issue_cmd return-type
++    - megaraid_sas: Dual queue depth support
++    - megaraid_sas: IO throttling support
++    - megaraid_sas: Make adprecovery variable atomic
++    - megaraid_sas: MFI adapter OCR changes
++    - megaraid_sas: Introduce module parameter for SCSI command timeout
++    - megaraid_sas: SPERC OCR changes
++    - megaraid_sas: driver version upgrade
++    - megaraid: fix null pointer check in megasas_detach_one().
++    - megaraid_sas: Fix for IO failing post OCR in SRIOV environment
++    - megaraid_sas: Fix SMAP issue
++    - megaraid_sas: Add an i/o barrier
++
++  * Surelock-GA2:kernel panic @ cxl_configure_adapter+0x418/0x8b0 (LP: #1546145)
++    - powerpc/powernv: Fix stale PE primary bus
++
++  * In A Single Power VM LPAR : Network Configuration Fails in Ubuntu16.04 while installation (LP: #1544321)
++    - [Config] Update bnx2x d-i firmware to 7.12.30
++
++  * Miscellaneous Ubuntu changes
++    - rebase to v4.4.2
++
++  * Miscellaneous upstream changes
++    - openvswitch: allow management from inside user namespaces
++    - net: thunderx: nicvf_queues: nivc_*_intr: remove duplication
++    - net, thunderx: Remove unnecessary rcv buffer start address management
++    - net: thunderx: HW TSO support for pass-2 hardware
++    - net: thunderx: Enable CQE count threshold interrupt
++    - net: cavium: liquidio: use helpers ns_to_timespec64()
++    - irqchip/gic-v3: Make sure read from ICC_IAR1_EL1 is visible on redestributor
++    - arm64: KVM: Configure TCR_EL2.PS at runtime
++    - arm64: prefetch: don't provide spin_lock_prefetch with LSE
++    - arm64: prefetch: add alternative pattern for CPUs without a prefetcher
++    - arm64: lib: improve copy_page to deal with 128 bytes at a time
++    - arm64: lib: patch in prfm for copy_page if requested
++    - arm64: prefetch: add missing #include for spin_lock_prefetch
++    - net, thunderx: Add TX timeout and RX buffer alloc failure stats.
++    - net: thunderx: Use napi_schedule_irqoff()
++    - net: thunderx: Assign affinity hints to vf's interrupts
++    - net: thunderx: bgx: Use standard firmware node infrastructure.
++    - net: thunderx: bgx: Add log message when setting mac address
++    - net: thunderx: Alloc higher order pages when pagesize is small
++    - net: cavium: liquidio: Return correct error code
++    - net: cavium: liquidio: fix check for in progress flag
++    - livepatch: add old_sympos as disambiguator field to klp_func
++    - livepatch: add sympos as disambiguator field to klp_reloc
++    - livepatch: function,sympos scheme in livepatch sysfs directory
++    - module: Use the same logic for setting and unsetting RO/NX
++    - gcov: use within_module() helper.
++    - module: use a structure to encapsulate layout.
++    - module: clean up RO/NX handling.
++    - module: keep percpu symbols in module's symtab
++    - livepatch: Cleanup module page permission changes
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.4.2
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 16 Feb 2016 14:24:45 -0700
++
++linux (4.4.0-6.21) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1546283
++
++  *  Naples/Zen, NTB Driver  (LP: #1542071)
++    - [Config] CONFIG_NTB_AMD=m
++    - NTB: Add support for AMD PCI-Express Non-Transparent Bridge
++
++  * [Hyper-V] kernel panic occurs when installing Ubuntu Server x32 (LP: #1495983)
++    - SAUCE: storvsc: use small sg_tablesize on x86
++
++  * Enable arm64 emulation of removed ARMv7 instructions (LP: #1545542)
++    - [Config] CONFIG_ARMV8_DEPRECATED=y
++
++  * Surelock-GA2:kernel panic/ exception @ pcibios_set_pcie_reset_state+0x118/0x280 + cxl_reset+0x5c/0xc0 (LP: #1545037)
++    - powerpc/eeh: Fix stale cached primary bus
++
++  * Miscellaneous Ubuntu changes
++    - SAUCE: fs: Add user namesapace member to struct super_block
++    - SAUCE: fs: Limit file caps to the user namespace of the super block
++    - SAUCE: Smack: Add support for unprivileged mounts from user namespaces
++    - SAUCE: block_dev: Support checking inode permissions in lookup_bdev()
++    - SAUCE: block_dev: Check permissions towards block device inode when mounting
++    - SAUCE: fs: Treat foreign mounts as nosuid
++    - SAUCE: selinux: Add support for unprivileged mounts from user namespaces
++    - SAUCE: userns: Replace in_userns with current_in_userns
++    - SAUCE: Smack: Handle labels consistently in untrusted mounts
++    - SAUCE: fs: Check for invalid i_uid in may_follow_link()
++    - SAUCE: cred: Reject inodes with invalid ids in set_create_file_as()
++    - SAUCE: fs: Refuse uid/gid changes which don't map into s_user_ns
++    - SAUCE: fs: Update posix_acl support to handle user namespace mounts
++    - SAUCE: fs: Ensure the mounter of a filesystem is privileged towards its inodes
++    - SAUCE: fs: Don't remove suid for CAP_FSETID in s_user_ns
++    - SAUCE: fs: Allow superblock owner to access do_remount_sb()
++    - SAUCE: capabilities: Allow privileged user in s_user_ns to set security.* xattrs
++    - SAUCE: fuse: Add support for pid namespaces
++    - SAUCE: fuse: Support fuse filesystems outside of init_user_ns
++    - SAUCE: fuse: Restrict allow_other to the superblock's namespace or a descendant
++    - SAUCE: fuse: Allow user namespace mounts
++    - SAUCE: mtd: Check permissions towards mtd block device inode when mounting
++    - SAUCE: fs: Update i_[ug]id_(read|write) to translate relative to s_user_ns
++    - SAUCE: quota: Convert ids relative to s_user_ns
++    - SAUCE: evm: Translate user/group ids relative to s_user_ns when computing HMAC
++    - SAUCE: fs: Allow CAP_SYS_ADMIN in s_user_ns to freeze and thaw filesystems
++    - SAUCE: quota: Treat superblock owner as privilged
++    - SAUCE: ima/evm: Allow root in s_user_ns to set xattrs
++    - SAUCE: block_dev: Forbid unprivileged mounting when device is opened for writing
++    - SAUCE: ext4: Add support for unprivileged mounts from user namespaces
++    - SAUCE: ext4: Add module parameter to enable user namespace mounts
++    - SAUCE: fuse: Add module parameter to enable user namespace mounts
++
++  * Miscellaneous upstream changes
++    - megaraid: Fix possible NULL pointer deference in mraid_mm_ioctl
++    - libahci: Implement the capability to override the generic ahci interrupt handler.
++    - ata: Remove the AHCI_HFLAG_EDGE_IRQ support from libahci.
++    - ahci_xgene: Implement the workaround to fix the missing of the edge interrupt for the HOST_IRQ_STAT.
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 12 Feb 2016 09:49:05 -0700
++
++linux (4.4.0-5.20) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1544637
++
++  * s390/cio: update measurement characteristics (LP: #1541534)
++    - s390/cio: fix measurement characteristics memleak
++    - s390/cio: ensure consistent measurement state
++    - s390/cio: update measurement characteristics
++
++  * qeth: layer2 reports unknown state to network tools. (LP: #1541907)
++    - qeth: initialize net_device with carrier off
++
++  * Collateral damage due to kernel configuration change enabling CONFIG_ZONE_DEVICE (Kernel 4.4 amd64) (LP: #1534647)
++    - [Config] CONFIG_ZONE_DMA=y
++    - mm: CONFIG_NR_ZONES_EXTENDED
++
++  * perf enahancements for ppc64 (LP: #1521678)
++    - perf kvm/{x86,s390}: Remove dependency on uapi/kvm_perf.h
++    - perf kvm/{x86,s390}: Remove const from kvm_events_tp
++    - perf kvm/powerpc: Port perf kvm stat to powerpc
++    - perf kvm/powerpc: Add support for HCALL reasons
++
++  * Soft lockup with "block nbdX: Attempted send on closed socket" spam (LP: #1505564)
++    - SAUCE: nbd: ratelimit error msgs after socket close
++
++  * sleep from invalid context in aa_move_mount (LP: #1539349)
++    - SAUCE: apparmor: fix sleep from invalid context
++
++  * Introducing ConnectX-4 Ethernet SRIOV (LP: #1540435)
++    - net/mlx5_core: Modify enable/disable hca functions
++    - net/mlx5_core: Add base sriov support
++    - net/mlx5: Add HW capabilities and structs for SR-IOV E-Switch
++    - net/mlx5: Update access functions to Query/Modify vport MAC address
++    - net/mlx5: Introduce access functions to modify/query vport mac lists
++    - net/mlx5: Introduce access functions to modify/query vport state
++    - net/mlx5: Introduce access functions to modify/query vport promisc mode
++    - net/mlx5: Introduce access functions to modify/query vport vlans
++    - net/mlx5e: Write UC/MC list and promisc mode into vport context
++    - net/mlx5e: Write vlan list into vport context
++    - net/mlx5: Introducing E-Switch and l2 table
++    - net/mlx5: E-Switch, Introduce FDB hardware capabilities
++    - net/mlx5: E-Switch, Add SR-IOV (FDB) support
++    - net/mlx5: E-Switch, Introduce Vport administration functions
++    - net/mlx5: E-Switch, Introduce HCA cap and E-Switch vport context
++    - net/mlx5: E-Switch, Introduce set vport vlan (VST mode)
++    - net/mlx5: E-Switch, Introduce get vf statistics
++    - net/mlx5e: Add support for SR-IOV ndos
++    - net/mlx5: Fix query E-Switch capabilities
++    - net/mlx5e: Assign random MAC address if needed
++
++  * make wacom_w8001 work well in xenial (LP: #1542771)
++    - Input: wacom_w8001 - use __set_bit for evbits
++    - Input: wacom_w8001 - set BTN_TOOL_DOUBLETAP if we have 2fg support
++    - Input: wacom_w8001 - handle touch error case correctly
++    - Input: wacom_w8001 - split pen and touch initialization up
++    - Input: wacom_w8001 - split the touch and pen devices into two devices
++    - Input: wacom_w8001 - drop use of ABS_MT_TOOL_TYPE
++
++  * virtualbox: update to 5.0.14-dfsg-2 (LP: #1542728)
++    - ubuntu: vbox -- update to 5.0.14-dfsg-2
++
++  * Miscellaneous Ubuntu changes
++    - [Packaging] git-ubuntu-log -- fix empty section formatting
++    - SAUCE: (noup) Update spl to 0.6.5.4-0ubuntu2, zfs to 0.6.5.4-0ubuntu2
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 06 Feb 2016 22:32:10 +0000
++
++linux (4.4.0-4.19) xenial; urgency=low
++
++  * update ZFS and SPL to 0.6.5.4 (LP: #1542296)
++    - [Config] update spl/zfs version
++    - SAUCE: (noup) Update spl to 0.6.5.4-0ubuntu2, zfs to 0.6.5.4-0ubuntu1
++    - [Config] reconstruct -- drop links for zfs userspace components
++    - [Config] reconstruct -- drop links for zfs userspace components -- restore spec links
++
++  * recvmsg() fails SCM_CREDENTIALS request with EOPNOTSUPP. (LP: #1540731)
++    - Revert "af_unix: Revert 'lock_interruptible' in stream receive code"
++
++  * lxc: ADT exercise test failing with linux-4.4.0-3.17  (LP: #1542049)
++    - Revert "UBUNTU: SAUCE: apparmor: fix sleep from invalid context"
++
++  * WARNING: at /build/linux-lts-wily-W0lTWH/linux-lts-wily-4.2.0/net/core/skbuff.c:4174 (Travis IB) (LP: #1541326)
++    - SAUCE: IB/IPoIB: Do not set skb truesize since using one linearskb
++
++  * backport Microsoft Precision Touchpad palm rejection patch (LP: #1541671)
++    - HID: multitouch: enable palm rejection if device implements confidence usage
++
++  * [Ubuntu 16.04] Update qla2xxx driver for POWER (QLogic) (LP: #1541456)
++    - qla2xxx: Remove unavailable firmware files
++    - qla2xxx: Enable Extended Logins support
++    - qla2xxx: Enable Exchange offload support.
++    - qla2xxx: Enable Target counters in DebugFS.
++    - qla2xxx: Add FW resource count in DebugFS.
++    - qla2xxx: Added interface to send explicit LOGO.
++    - qla2xxx: Delete session if initiator is gone from FW
++    - qla2xxx: Wait for all conflicts before ack'ing PLOGI
++    - qla2xxx: Replace QLA_TGT_STATE_ABORTED with a bit.
++    - qla2xxx: Remove dependency on hardware_lock to reduce lock contention.
++    - qla2xxx: Add irq affinity notification
++    - qla2xxx: Add selective command queuing
++    - qla2xxx: Move atioq to a different lock to reduce lock contention
++    - qla2xxx: Disable ZIO at start time.
++    - qla2xxx: Set all queues to 4k
++    - qla2xxx: Check for online flag instead of active reset when transmitting responses
++    - scsi: qla2xxxx: avoid type mismatch in comparison
++
++  * [Hyper-V] PCI Passthrough (LP: #1541120)
++    - x86/irq: Export functions to allow MSI domains in modules
++    - genirq/msi: Export functions to allow MSI domains in modules
++
++  * Update lpfc driver to 11.0.0.10 (LP: #1541592)
++    - lpfc: Fix FCF Infinite loop in lpfc_sli4_fcf_rr_next_index_get.
++    - lpfc: Fix the FLOGI discovery logic to comply with T11 standards
++    - lpfc: Fix RegLogin failed error seen on Lancer FC during port bounce
++    - lpfc: Fix driver crash when module parameter lpfc_fcp_io_channel set to 16
++    - lpfc: Fix crash in fcp command completion path.
++    - lpfc: Modularize and cleanup FDMI code in driver
++    - lpfc: Fix RDP Speed reporting.
++    - lpfc: Fix RDP ACC being too long.
++    - lpfc: Make write check error processing more resilient
++    - lpfc: Use new FDMI speed definitions for 10G, 25G and 40G FCoE.
++    - lpfc: Fix mbox reuse in PLOGI completion
++    - lpfc: Fix external loopback failure.
++    - lpfc: Add logging for misconfigured optics.
++    - lpfc: Delete unnecessary checks before the function call "mempool_destroy"
++    - lpfc: Use kzalloc instead of kmalloc
++    - lpfc: Update version to 11.0.0.10 for upstream patch set
++
++  * Miscellaneous Ubuntu changes
++    - [Config] CONFIG_ARM64_VA_BITS=48
++    - [Config] Fixed Vcs-Git
++
++  * Miscellaneous upstream changes
++    - cxl: Fix possible idr warning when contexts are released
++    - cxl: use correct operator when writing pcie config space values
++    - cxlflash: drop unlikely before IS_ERR_OR_NULL
++    - cxl: Fix DSI misses when the context owning task exits
++    - cxlflash: Removed driver date print
++    - cxlflash: Fix to resolve cmd leak after host reset
++    - cxlflash: Resolve oops in wait_port_offline
++    - cxlflash: Enable device id for future IBM CXL adapter
++    - cxl: fix build for GCC 4.6.x
++    - cxl: use -Werror only with CONFIG_PPC_WERROR
++    - cxl: Enable PCI device ID for future IBM CXL adapter
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Feb 2016 14:58:51 +0000
++
++linux (4.4.0-3.17) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1541058
++  * [Config] CONFIG_BLK_DEV_NVME_SCSI=y
++    - LP: #1531539
++  * SAUCE: nvme merge cleanup
++    - LP: #1531539
++  * rebase to v4.4.1
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: dm: introduce a target_ioctl op to allow target specific
++    ioctls"
++    - LP: #1538618
++  * postinst -- detect symlinks correctly
++    - LP: #1536810
++
++  [ John Johansen ]
++
++  * SAUCE: apparmor: fix sleep from invalid context
++    - LP: #1539349
++
++  [ Upstream Kernel Changes ]
++
++  * powerpc/eeh: Fix PE location code
++    - LP: #1538909
++  * powerpc/pseries: Limit EPOW reset event warnings
++    - LP: #1539102
++  * lightnvm: fix bio submission issue
++    - LP: #1531539
++  * lightnvm: fix incorrect nr_free_blocks stat
++    - LP: #1531539
++  * lightnvm: add check after mempool allocation
++    - LP: #1531539
++  * lightnvm: unlock rq and free ppa_list on submission fail
++    - LP: #1531539
++  * lightnvm: move ppa erase logic to core
++    - LP: #1531539
++  * lightnvm: refactor rqd ppa list into set/free
++    - LP: #1531539
++  * lightnvm: refactor end_io functions for sync
++    - LP: #1531539
++  * lightnvm: return the get_bb_tbl return value
++    - LP: #1531539
++  * lightnvm: check bi_error in gc
++    - LP: #1531539
++  * lightnvm: put block back to gc list on its reclaim fail
++    - LP: #1531539
++  * lightnvm: fix locking and mempool in rrpc_lun_gc
++    - LP: #1531539
++  * lightnvm: sectors first in ppa list
++    - LP: #1531539
++  * lightnvm: move the pages per block check out of the loop
++    - LP: #1531539
++  * lightnvm: support multiple ppas in nvm_erase_ppa
++    - LP: #1531539
++  * lightnvm: move rq->error to nvm_rq->error
++    - LP: #1531539
++  * lightnvm: introduce nvm_submit_ppa
++    - LP: #1531539
++  * lightnvm: reference rrpc lun in rrpc block
++    - LP: #1531539
++  * lightnvm: fix missing grown bad block type
++    - LP: #1531539
++  * lightnvm: manage open and closed blocks separately
++    - LP: #1531539
++  * lightnvm: add mccap support
++    - LP: #1531539
++  * lightnvm: introduce mlc lower page table mappings
++    - LP: #1531539
++  * lightnvm: core on-disk initialization
++    - LP: #1531539
++  * lightnvm: introduce ioctl to initialize device
++    - LP: #1531539
++  * lightnvm: use system block for mm initialization
++    - LP: #1531539
++  * lightnvm: introduce factory reset
++    - LP: #1531539
++  * lightnvm: ensure that nvm_dev_ops can be used without CONFIG_NVM
++    - LP: #1531539
++  * blk-mq: add a flags parameter to blk_mq_alloc_request
++    - LP: #1531539
++  * nvme: move struct nvme_iod to pci.c
++    - LP: #1531539
++  * nvme: split command submission helpers out of pci.c
++    - LP: #1531539
++  * nvme: use offset instead of a struct for registers
++    - LP: #1531539
++  * nvme: split nvme_trans_device_id_page
++    - LP: #1531539
++  * nvme: use vendor it from identify
++    - LP: #1531539
++  * nvme: split a new struct nvme_ctrl out of struct nvme_dev
++    - LP: #1531539
++  * nvme: simplify nvme_setup_prps calling convention
++    - LP: #1531539
++  * nvme: refactor nvme_queue_rq
++    - LP: #1531539
++  * nvme: factor out a nvme_unmap_data helper
++    - LP: #1531539
++  * nvme: move nvme_error_status to common code
++    - LP: #1531539
++  * nvme: move nvme_setup_flush and nvme_setup_rw to common code
++    - LP: #1531539
++  * nvme: split __nvme_submit_sync_cmd
++    - LP: #1531539
++  * nvme: use the block layer for userspace passthrough metadata
++    - LP: #1531539
++  * nvme: move block_device_operations and ns/ctrl freeing to common code
++    - LP: #1531539
++  * nvme: add explicit quirk handling
++    - LP: #1531539
++  * nvme: move remaining CC setup into nvme_enable_ctrl
++    - LP: #1531539
++  * nvme: move nvme_{enable,disable,shutdown}_ctrl to common code
++    - LP: #1531539
++  * nvme: add a common helper to read Identify Controller data
++    - LP: #1531539
++  * nvme: move the call to nvme_init_identify earlier
++    - LP: #1531539
++  * nvme: move namespace scanning to common code
++    - LP: #1531539
++  * nvme: move chardev and sysfs interface to common code
++    - LP: #1531539
++  * nvme: refactor set_queue_count
++    - LP: #1531539
++  * blk-integrity: empty implementation when disabled
++    - LP: #1531539
++  * NVMe: fix build with CONFIG_NVM enabled
++    - LP: #1531539
++  * nvme: fix another 32-bit build warning
++    - LP: #1531539
++  * nvme: precedence bug in nvme_pr_clear()
++    - LP: #1531539
++  * nvme: only ignore hardware errors in nvme_create_io_queues
++    - LP: #1531539
++  * nvme: only add a controller to dev_list after it's been fully
++    initialized
++    - LP: #1531539
++  * nvme: protect against simultaneous shutdown invocations
++    - LP: #1531539
++  * nvme: don't take the I/O queue q_lock in nvme_timeout
++    - LP: #1531539
++  * nvme: merge nvme_abort_req and nvme_timeout
++    - LP: #1531539
++  * nvme: add NVME_SC_CANCELLED
++    - LP: #1531539
++  * nvme: simplify resets
++    - LP: #1531539
++  * nvme: do not restart the request timeout if we're resetting the
++    controller
++    - LP: #1531539
++  * nvme: merge probe_work and reset_work
++    - LP: #1531539
++  * nvme: remove dead controllers from a work item
++    - LP: #1531539
++  * nvme: switch abort_limit to an atomic_t
++    - LP: #1531539
++  * NVMe: Implement namespace list scanning
++    - LP: #1531539
++  * NVMe: Use unbounded work queue for all work
++    - LP: #1531539
++  * NVMe: Remove device management handles on remove
++    - LP: #1531539
++  * NVMe: Simplify metadata setup
++    - LP: #1531539
++  * nvme: fix admin queue depth
++    - LP: #1531539
++  * nvme: factor out a few helpers from req_completion
++    - LP: #1531539
++  * nvme: switch delete SQ/CQ to blk_execute_rq_nowait
++    - LP: #1531539
++  * nvme: switch abort to blk_execute_rq_nowait
++    - LP: #1531539
++  * nvme: special case AEN requests
++    - LP: #1531539
++  * nvme: simplify completion handling
++    - LP: #1531539
++  * nvme: properly free resources for cancelled command
++    - LP: #1531539
++  * nvme: meta_sg doesn't have to be an array
++    - LP: #1531539
++  * nvme: merge iod and cmd_info
++    - LP: #1531539
++  * NVMe: Add pci error handlers
++    - LP: #1531539
++  * NVMe: Export namespace attributes to sysfs
++    - LP: #1531539
++  * nvme: Move nvme_freeze/unfreeze_queues to nvme core
++    - LP: #1531539
++  * nvme: synchronize access to ctrl->namespaces
++    - LP: #1531539
++  * nvme: fixes for NVME_IOCTL_IO_CMD on the char device
++    - LP: #1531539
++  * nvme: make SG_IO support optional
++    - LP: #1531539
++  * NVMe: Fix admin queue ring wrap
++    - LP: #1531539
++  * NVMe: Use a retryable error code on reset
++    - LP: #1531539
++  * NVMe: Remove queue freezing on resets
++    - LP: #1531539
++  * NVMe: IO queue deletion re-write
++    - LP: #1531539
++  * NVMe: Shutdown controller only for power-off
++    - LP: #1531539
++  * NVMe: Export NVMe attributes to sysfs group
++    - LP: #1531539
++  * i40e: fix build warnings
++  * net: i40e: shut up uninitialized variable warnings
++  * Drivers: hv: vmbus: fix build warning
++  * Drivers: hv: util: Increase the timeout for util services
++  * Drivers: hv: utils: run polling callback always in interrupt context
++  * tools: hv: report ENOSPC errors in hv_fcopy_daemon
++  * tools: hv: remove repeated HV_FCOPY string
++  * Drivers: hv: util: catch allocation errors
++  * Drivers: hv: utils: use memdup_user in hvt_op_write
++  * drivers/hv: cleanup synic msrs if vmbus connect failed
++  * drivers:hv: Export a function that maps Linux CPU num onto Hyper-V proc
++    num
++  * drivers:hv: Export the API to invoke a hypercall on Hyper-V
++  * drivers:hv: Define the channel type for Hyper-V PCI Express
++    pass-through
++  * Drivers: hv: vss: run only on supported host versions
++  * Drivers: hv: vmbus: Use uuid_le type consistently
++  * Drivers: hv: vmbus: Use uuid_le_cmp() for comparing GUIDs
++  * Drivers: hv: vmbus: Get rid of the unused macro
++  * Drivers: hv: vmbus: Get rid of the unused irq variable
++  * Drivers: hv: vmbus: serialize process_chn_event() and
++    vmbus_close_internal()
++  * Drivers: hv: vmbus: do sanity check of channel state in
++    vmbus_close_internal()
++  * Drivers: hv: vmbus: fix rescind-offer handling for device without a
++    driver
++  * Drivers: hv: vmbus: release relid on error in vmbus_process_offer()
++  * Drivers: hv: vmbus: channge vmbus_connection.channel_lock to mutex
++  * drivers:hv: Allow for MMIO claims that span ACPI _CRS records
++  * Drivers: hv: vmbus: Fix a Host signaling bug
++  * drivers/hv: correct tsc page sequence invalid value
++  * Drivers: hv: vmbus: Force all channel messages to be delivered on CPU 0
++  * Drivers: hv: utils: Invoke the poll function after handshake
++  * tools: hv: vss: fix the write()'s argument: error -> vss_msg
++  * Drivers: hv: utils: fix memory leak on on_msg() failure
++  * Drivers: hv: utils: rename outmsg_lock
++  * Drivers: hv: utils: introduce HVUTIL_TRANSPORT_DESTROY mode
++  * Drivers: hv: utils: fix crash when device is removed from host side
++  * Drivers: hv: ring_buffer.c: fix comment style
++  * Drivers: hv: ring_buffer: remove stray smp_read_barrier_depends()
++  * Drivers: hv: ring_buffer: remove code duplication from
++    hv_ringbuffer_peek/read()
++  * Drivers: hv: remove code duplication between
++    vmbus_recvpacket()/vmbus_recvpacket_raw()
++  * Drivers: hv: ring_buffer: eliminate hv_ringbuffer_peek()
++  * drivers/hv: replace enum hv_message_type by u32
++  * drivers/hv: Move HV_SYNIC_STIMER_COUNT into Hyper-V UAPI x86 header
++  * drivers/hv: Move struct hv_message into UAPI Hyper-V x86 header
++  * drivers/hv: Move struct hv_timer_message_payload into UAPI Hyper-V x86
++    header
++  * Drivers: hv: vmbus: fix the building warning with hyperv-keyboard
++  * Drivers: hv: utils: fix hvt_op_poll() return value on transport destroy
++  * Drivers: hv: vmbus: Treat Fibre Channel devices as performance critical
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.4.1
++    - LP: #1533461
++    - LP: #1529624
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 29 Jan 2016 08:06:37 -0700
++
++linux (4.4.0-2.16) xenial; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Release Tracking Bug
++    - LP: #1539090
++  * SAUCE: hv: hv_set_ifconfig -- convert to python3
++    - LP: #1506521
++  * SAUCE: dm: introduce a target_ioctl op to allow target specific ioctls
++    - LP: #1538618
++
++  [ Colin Ian King ]
++
++  * SAUCE: ACPI / tables: Add acpi_force_32bit_fadt_addr option to force 32
++    bit FADT addresses (LP: #1529381)
++    - LP: #1529381
++
++  [ John Johansen ]
++
++  * SAUCE: (no-up): apparmor: fix for failed mediation of socket that is
++    being shutdown
++    - LP: #1446906
++
++  [ Mahesh Salgaonkar ]
++
++  * SAUCE: Powernv: Remove the usage of PACAR1 from opal wrappers
++    - LP: #1537881
++  * SAUCE: powerpc/book3s: Fix TB corruption in guest exit path on HMI
++    interrupt.
++    - LP: #1537881
++  * SAUCE: KVM: PPC: Book3S HV: Fix soft lockups in KVM on HMI for time
++    base errors
++    - LP: #1537881
++
++  [ Paolo Pisati ]
++
++  * SAUCE: arm64: errata: Add -mpc-relative-literal-loads to erratum
++    #843419 build flags
++    - LP: #1533009
++  * [Config] MFD_TPS65217=y && REGULATOR_TPS65217=y
++  * [Config] disable ARCH_ZX (ZTE ZX Soc)
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: (noup) cxlflash: a couple off by one bugs"
++  * SAUCE: (no-up) Update bnx2x firmware to 7.12.30.0
++    - LP: #1536719
++  * SAUCE: drop obsolete bnx2x firmware
++  * SAUCE: i40e: Silence 'may be used uninitialized' warnings
++    - LP: #1536474
++  * [Config] CONFIG_ZONE_DMA=y for amd64 lowlatency
++    - LP: #1534647
++  * [Config] Add pvpanic to virtual flavour
++    - LP: #1537923
++  * [Config] CONFIG_INTEL_PUNIT_IPC=m, CONFIG_INTEL_TELEMETRY=m
++    - LP: #1520457
++
++  [ Upstream Kernel Changes ]
++
++  * i40evf: fix compiler warning of unused variable
++    - LP: #1536474
++  * intel: i40e: fix confused code
++    - LP: #1536474
++  * i40e/i40evf: remove unused tunnel parameter
++    - LP: #1536474
++  * i40e: Change BUG_ON to WARN_ON in service event complete
++    - LP: #1536474
++  * i40e: remove BUG_ON from feature string building
++    - LP: #1536474
++  * i40e: remove BUG_ON from FCoE setup
++    - LP: #1536474
++  * i40e: Workaround fix for mss < 256 issue
++    - LP: #1536474
++  * i40e/i40evf: Add a stat to track how many times we have to do a force
++    WB
++    - LP: #1536474
++  * i40e: Move the saving of old link info from handle_link_event to
++    link_event
++    - LP: #1536474
++  * i40e/i40evf: Add comment to #endif
++    - LP: #1536474
++  * i40e/i40evf: clean up error messages
++    - LP: #1536474
++  * i40evf: handle many MAC filters correctly
++    - LP: #1536474
++  * i40e: return the number of enabled queues for ETHTOOL_GRXRINGS
++    - LP: #1536474
++  * i40e: rework the functions to configure RSS with similar parameters
++    - LP: #1536474
++  * i40e: create a generic configure rss function
++    - LP: #1536474
++  * i40e: Bump version to 1.4.2
++    - LP: #1536474
++  * i40e: add new fields to store user configuration
++    - LP: #1536474
++  * i40e: rename rss_size to alloc_rss_size in i40e_pf
++    - LP: #1536474
++  * i40e/i40evf: Fix RS bit update in Tx path and disable force WB
++    workaround
++    - LP: #1536474
++  * i40e/i40evf: prefetch skb data on transmit
++    - LP: #1536474
++  * i40evf: rename VF adapter specific RSS function
++    - LP: #1536474
++  * i40evf: create a generic config RSS function
++    - LP: #1536474
++  * i40evf: create a generic get RSS function
++    - LP: #1536474
++  * i40evf: add new fields to store user configuration of RSS
++    - LP: #1536474
++  * i40e: Update error messaging
++    - LP: #1536474
++  * i40e: fix confusing message
++    - LP: #1536474
++  * i40e: make error message more useful
++    - LP: #1536474
++  * i40evf: quoth the VF driver, Nevermore
++    - LP: #1536474
++  * i40evf: allocate queue vectors dynamically
++    - LP: #1536474
++  * i40evf: allocate ring structs dynamically
++    - LP: #1536474
++  * i40e/i40evf: Bump i40e version to 1.4.4 and i40evf to 1.4.1
++    - LP: #1536474
++  * i40e: fix: do not sleep in netdev_ops
++    - LP: #1536474
++  * i40e: remove unused argument
++    - LP: #1536474
++  * i40evf: increase max number of queues
++    - LP: #1536474
++  * i40evf: set real num queues
++    - LP: #1536474
++  * i40evf: remove duplicate string
++    - LP: #1536474
++  * i40e: Detection and recovery of TX queue hung logic moved to
++    service_task from tx_timeout
++    - LP: #1536474
++  * i40e: Fix memory leaks, sideband filter programming
++    - LP: #1536474
++  * i40evf: don't use atomic allocation
++    - LP: #1536474
++  * i40e: propagate properly
++    - LP: #1536474
++  * i40evf: use correct types
++    - LP: #1536474
++  * i40e: use priv flags to control packet split
++    - LP: #1536474
++  * i40e: Remove separate functions gathering XOFF Rx stats
++    - LP: #1536474
++  * i40e: fix whitespace
++    - LP: #1536474
++  * i40e/i40evf: use logical operator
++    - LP: #1536474
++  * i40e/i40evf: Bump version to 1.4.7 for i40e and 1.4.3 for i40evf
++    - LP: #1536474
++  * i40e: trivial fixes
++    - LP: #1536474
++  * i40e: Fix i40e_print_features() VEB mode output
++    - LP: #1536474
++  * i40e: chomp the BIT(_ULL)
++    - LP: #1536474
++  * i40e: properly delete VF MAC filters
++    - LP: #1536474
++  * i40e: don't add zero MAC filter
++    - LP: #1536474
++  * i40evf: check rings before freeing resources
++    - LP: #1536474
++  * i40e: use explicit cast from u16 to u8
++    - LP: #1536474
++  * i40e: Opcode and structures required by OEM Post Update AQ command and
++    add new NVM arq message
++    - LP: #1536474
++  * i40e: hush little warnings
++    - LP: #1536474
++  * i40e/i40evf: Add a new offload for RSS PCTYPE V2 for X722
++    - LP: #1536474
++  * i40e: clean whole mac filter list
++    - LP: #1536474
++  * i40evf: change version string generation
++    - LP: #1536474
++  * i40e/i40evf: Bump i40e to 1.4.8 and i40evf to 1.4.4
++    - LP: #1536474
++  * geneve: UDP checksum configuration via netlink
++    - LP: #1536474
++  * geneve: Add geneve udp port offload for ethernet devices
++    - LP: #1536474
++  * i40e: geneve tunnel offload support
++    - LP: #1536474
++  * geneve: Add geneve_get_rx_port support
++    - LP: #1536474
++  * i40e: Call geneve_get_rx_port to get the existing Geneve ports
++    - LP: #1536474
++  * i40e: change log messages and error returns
++    - LP: #1536474
++  * i40e: allow zero MAC address for VFs
++    - LP: #1536474
++  * i40e: Look up MAC address in Open Firmware or IDPROM
++    - LP: #1536474
++  * i40e: Fix Rx hash reported to the stack by our driver
++    - LP: #1536474
++  * i40e: remove forever unused ID
++    - LP: #1536474
++  * igb: add 88E1543 initialization code
++  * igb: don't unmap NULL hw_addr
++  * igb: use the correct i210 register for EEMNGCTL
++  * igb: fix NULL derefs due to skipped SR-IOV enabling
++  * igb: improve handling of disconnected adapters
++  * igb: Remove GS40G specific defines/functions
++  * igb: Don't add PHY address to PCDL address
++  * igb: Improve cable length function for I210, etc.
++  * igb: Explicitly label self-test result indices
++  * ixgbe: drop null test before destroy functions
++    - LP: #1536473
++  * ixgbe: Delete redundant include file
++    - LP: #1536473
++  * ixgbe: fix multiple kernel-doc errors
++    - LP: #1536473
++  * ixgbe: Fix handling of NAPI budget when multiple queues are enabled per
++    vector
++    - LP: #1536473
++  * ixgbe: Add KR mode support for CS4227 chip
++    - LP: #1536473
++  * ixgbevf: Limit lowest interrupt rate for adaptive interrupt moderation
++    to 12K
++    - LP: #1536473
++  * ixgbe/ixgbevf: use napi_schedule_irqoff()
++    - LP: #1536473
++  * ixgbe: Remove CS4227 diagnostic code
++    - LP: #1536473
++  * ixgbevf: use ether_addr_copy instead of memcpy
++    - LP: #1536473
++  * ixgbevf: fix spoofed packets with random MAC
++    - LP: #1536473
++  * ixgbe: Prevent KR PHY reset in ixgbe_init_phy_ops_x550em
++    - LP: #1536473
++  * ixgbe: Add support for newer thermal alarm
++    - LP: #1536473
++  * ixgbe: Use private workqueue to avoid certain possible hangs
++    - LP: #1536473
++  * ixgbevf: Use a private workqueue to avoid certain possible hangs
++    - LP: #1536473
++  * ixgbevf: Minor cleanups
++    - LP: #1536473
++  * ixgbe: Refactor MAC address configuration code
++    - LP: #1536473
++  * ixgbe: Use __dev_uc_sync and __dev_uc_unsync for unicast addresses
++    - LP: #1536473
++  * ixgbe: Allow FDB entries access to more RAR filters
++    - LP: #1536473
++  * ixgbe: Update PTP to support X550EM_x devices
++    - LP: #1536473
++  * ixgbe: Correct spec violations by waiting after reset
++    - LP: #1536473
++  * ixgbe: Wait for master disable to be set
++    - LP: #1536473
++  * ixgbe: Save VF info and take references
++    - LP: #1536473
++  * ixgbe: Handle extended IPv6 headers in Tx path
++    - LP: #1536473
++  * ixgbe: Always turn PHY power on when requested
++    - LP: #1536473
++  * ixgbevf: Handle extended IPv6 headers in Tx path
++    - LP: #1536473
++  * ixgbe: Return error on failure to allocate mac_table
++    - LP: #1536473
++  * ixgbe: Fix SR-IOV VLAN pool configuration
++    - LP: #1536473
++  * ixgbe: Simplify definitions for regidx and bit in set_vfta
++    - LP: #1536473
++  * ixgbe: Reduce VT code indent in set_vfta by introducing jump label
++    - LP: #1536473
++  * ixgbe: Simplify configuration of setting VLVF and VLVFB
++    - LP: #1536473
++  * ixgbe: Add support for adding/removing VLAN on PF bypassing the VLVF
++    - LP: #1536473
++  * ixgbe: Reorder search to work from the top down instead of bottom up
++    - LP: #1536473
++  * ixgbe: Add support for VLAN promiscuous with SR-IOV
++    - LP: #1536473
++  * ixgbe: Fix VLAN promisc in relation to SR-IOV
++    - LP: #1536473
++  * ixgbe: Clear stale pool mappings
++    - LP: #1536473
++  * ixgbe: Clean stale VLANs when changing port VLAN or resetting
++    - LP: #1536473
++  * ixgbe: do not report 2.5 Gbps as supported
++    - LP: #1536473
++  * ixgbevf: Fix handling of NAPI budget when multiple queues are enabled
++    per vector
++    - LP: #1536473
++  * ixgbevf: minor cleanups for ixgbevf_set_itr()
++    - LP: #1536473
++  * ixgbe: add support for QSFP PHY types in ixgbe_get_settings()
++    - LP: #1536473
++  * ixgbe: report correct media type for KR, KX and KX4 interfaces
++    - LP: #1536473
++  * ixgbe: Clean up redundancy in hw_enc_features
++    - LP: #1536473
++  * ixgbe: fix RSS limit for X550
++    - LP: #1536473
++  * ixgbe: Correct X550EM_x revision check
++    - LP: #1536473
++  * ixgbe: Fix bugs in ixgbe_clear_vf_vlans()
++    - LP: #1536473
++  * ixgbe: Fill at least min credits to a TC credit refills
++    - LP: #1536473
++  * ixgbe: use correct FCoE DDP max check
++    - LP: #1536473
++  * ixgbe: fix broken PFC with X550
++    - LP: #1536473
++  * ixgbe: do not call check_link for ethtool in ixgbe_get_settings()
++    - LP: #1536473
++  * ixgbe: Correct handling of any outer UDP checksum setting
++    - LP: #1536473
++  * ixgbe: Fix to get FDMI HBA attributes information with X550
++    - LP: #1536473
++  * ixgbe: Fix MDD events generated when FCoE+SRIOV are enabled
++    - LP: #1536473
++  * ixgbe: Make ATR recognize IPv6 extended headers
++    - LP: #1536473
++  * e1000: make eeprom read/write scheduler friendly
++  * e1000: fix data race between tx_ring->next_to_clean
++  * e1000: Remove checkpatch coding style errors
++  * e1000: clean up the checking logic
++  * e1000: fix a typo in the comment
++  * e1000e: clean up the local variable
++  * e1000: fix kernel-doc argument being missing
++  * e1000: get rid of duplicate exit path
++  * e1000: Elementary checkpatch warnings and checks removed
++  * e1000e: fix division by zero on jumbo MTUs
++  * e1000e: Increase timeout of polling bit RSPCIPHY
++  * e1000e: initial support for i219-LM (3)
++  * e1000e: Switch e1000e_up to void, drop code checking for error result
++  * e1000e: Remove unreachable code
++  * e1000e: Do not read ICR in Other interrupt
++  * e1000e: Do not write lsc to ics in msi-x mode
++  * e1000e: Fix msi-x interrupt automask
++  * acpi: pci: Setup MSI domain for ACPI based pci devices
++  * irqdomain: Introduce is_fwnode_irqchip helper
++  * irqchip/gic-v2m: Refactor to prepare for ACPI support
++  * irqchip/gic-v2m: acpi: Introducing GICv2m ACPI support
++  * clk: xgene: Fix divider with non-zero shift value
++  * i2c: designware: Do not require clock when SSCN and FFCN are provided
++  * fm10k: do not assume VF always has 1 queue
++    - LP: #1536475
++  * fm10k: Correct MTU for jumbo frames
++    - LP: #1536475
++  * fm10k: Fix handling of NAPI budget when multiple queues are enabled per
++    vector
++    - LP: #1536475
++  * fm10k: use napi_schedule_irqoff()
++    - LP: #1536475
++  * fm10k: set netdev features in one location
++    - LP: #1536475
++  * fm10k: reset max_queues on init_hw_vf failure
++    - LP: #1536475
++  * fm10k: always check init_hw for errors
++    - LP: #1536475
++  * fm10k: reinitialize queuing scheme after calling init_hw
++    - LP: #1536475
++  * fm10k: Correct typecast in fm10k_update_xc_addr_pf
++    - LP: #1536475
++  * fm10k: explicitly typecast vlan values to u16
++    - LP: #1536475
++  * fm10k: add statistics for actual DWORD count of mbmem mailbox
++    - LP: #1536475
++  * fm10k: rename mbx_tx_oversized statistic to mbx_tx_dropped
++    - LP: #1536475
++  * fm10k: Add support for ITR scaling based on PCIe link speed
++    - LP: #1536475
++  * fm10k: introduce ITR_IS_ADAPTIVE macro
++    - LP: #1536475
++  * fm10k: Update adaptive ITR algorithm
++    - LP: #1536475
++  * fm10k: use macro for default Tx and Rx ITR values
++    - LP: #1536475
++  * fm10k: change default Tx ITR to 25usec
++    - LP: #1536475
++  * fm10k: TRIVIAL fix typo of hardware
++    - LP: #1536475
++  * fm10k: TRIVIAL cleanup order at top of fm10k_xmit_frame
++    - LP: #1536475
++  * fm10k: use ether_addr_copy to copy MAC address
++    - LP: #1536475
++  * fm10k: do not use CamelCase
++    - LP: #1536475
++  * fm10k: remove unnecessary else block from if statements with return
++    - LP: #1536475
++  * fm10k: remove namespace pollution of fm10k_iov_msg_data_pf
++    - LP: #1536475
++  * fm10k: consistently refer to VLANs and VLAN IDs
++    - LP: #1536475
++  * fm10k: bump driver version
++    - LP: #1536475
++  * fm10k: conditionally compile DCB and DebugFS support
++    - LP: #1536475
++  * fm10k: Cleanup MSI-X interrupts in case of failure
++    - LP: #1536475
++  * fm10k: Cleanup exception handling for mailbox interrupt
++    - LP: #1536475
++  * fm10k: do not inline fm10k_iov_select_vid()
++    - LP: #1536475
++  * fm10k: whitespace cleanups
++    - LP: #1536475
++  * fm10k: use BIT() macro instead of open-coded bit-shifting
++    - LP: #1536475
++  * fm10k: cleanup namespace pollution
++    - LP: #1536475
++  * fm10k: cleanup overly long lines
++    - LP: #1536475
++  * fm10k: initialize xps at driver load
++    - LP: #1536475
++  * fm10k: don't initialize fm10k_workqueue at global level
++    - LP: #1536475
++  * fm10k: correctly pack TLV structures and explain reasoning
++    - LP: #1536475
++  * fm10k: Cleanup exception handling for changing queues
++    - LP: #1536475
++  * fm10k: use ether_addr_equal instead of memcmp
++    - LP: #1536475
++  * fm10k: address operator not needed when declaring function pointers
++    - LP: #1536475
++  * fm10k: constify fm10k_mac_ops, fm10k_iov_ops and fm10k_info structures
++    - LP: #1536475
++  * fm10k: remove unused struct element
++    - LP: #1536475
++  * fm10k: use true/false for boolean get_host_state
++    - LP: #1536475
++  * fm10k: cleanup mailbox code comments etc
++    - LP: #1536475
++  * fm10k: IS_ENABLED() is not appropriate for boolean kconfig option
++    - LP: #1536475
++  * device property: always check for fwnode type
++    - LP: #1533035
++  * device property: rename helper functions
++    - LP: #1533035
++  * device property: refactor built-in properties support
++    - LP: #1533035
++  * device property: keep single value inplace
++    - LP: #1533035
++  * device property: helper macros for property entry creation
++    - LP: #1533035
++  * device property: improve readability of macros
++    - LP: #1533035
++  * device property: return -EINVAL when property isn't found in ACPI
++    - LP: #1533035
++  * device property: Fallback to secondary fwnode if primary misses the
++    property
++    - LP: #1533035
++  * device property: Take a copy of the property set
++    - LP: #1533035
++  * driver core: platform: Add support for built-in device properties
++    - LP: #1533035
++  * driver core: Do not overwrite secondary fwnode with NULL if it is set
++    - LP: #1533035
++  * mfd: core: propagate device properties to sub devices drivers
++    - LP: #1533035
++  * mfd: intel-lpss: Add support for passing device properties
++    - LP: #1533035
++  * mfd: intel-lpss: Pass SDA hold time to I2C host controller driver
++    - LP: #1533035
++  * mfd: intel-lpss: Pass HSUART configuration via properties
++    - LP: #1533035
++  * i2c: designware: Convert to use unified device property API
++    - LP: #1533035
++  * keys, trusted: fix: *do not* allow duplicate key options
++    - LP: #1398274
++  * keys, trusted: select hash algorithm for TPM2 chips
++    - LP: #1398274
++  * keys, trusted: seal with a TPM2 authorization policy
++    - LP: #1398274
++  * perf/x86/intel: Add perf core PMU support for Intel Knights Landing
++    - LP: #1461360
++  * perf/x86/intel/uncore: Add Knights Landing uncore PMU support
++    - LP: #1461360
++  * perf/x86/intel/uncore: Remove hard coding of PMON box control MSR
++    offset
++    - LP: #1461360
++  * drm/i915: WaRsDisableCoarsePowerGating
++    - LP: #1527462
++  * drm/i915/skl: Add SKL GT4 PCI IDs
++    - LP: #1527462
++  * drm/i915/skl: Disable coarse power gating up until F0
++    - LP: #1527462
++  * platform:x86: add Intel P-Unit mailbox IPC driver
++    - LP: #1520457
++  * intel_punit_ipc: add NULL check for input parameters
++    - LP: #1520457
++  * platform/x86: Add Intel Telemetry Core Driver
++    - LP: #1520457
++  * intel_pmc_ipc: update acpi resource structure for Punit
++    - LP: #1520457
++  * platform:x86: Add Intel telemetry platform device
++    - LP: #1520457
++  * platform:x86: Add Intel telemetry platform driver
++    - LP: #1520457
++  * platform:x86: Add Intel Telemetry Debugfs interfaces
++    - LP: #1520457
++  * cxlflash: a couple off by one bugs
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 28 Jan 2016 13:56:00 +0000
++
++linux (4.4.0-1.15) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1536803
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[SCSI] libiscsi: Reduce locking contention in fast path"
++    - LP: #1517142
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 20 Jan 2016 07:41:40 -0700
++
++linux (4.4.0-0.14) xenial; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "powerpc/pci: Remove unused struct pci_dn.pcidev field"
++    - LP: #1522415
++  * powerpc: Add __raw_rm_writeq() function
++    - LP: #1522415
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 19 Jan 2016 11:24:26 -0700
++
++linux (4.4.0-0.13) xenial; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] s390x -- the kernel provides ppp-modules such as there are
++  * SAUCE: (no-up) add compat_uts_machine= kernel command line override
++
++  [ Tim Gardner ]
++
++  * [Config] Update annotations for VIRTIO_{NET,BLK}
++    - LP: #1533382
++
++  [ Upstream Kernel Changes ]
++
++  * powerpc/powernv: Add support for Nvlink NPUs
++    - LP: #1522415
++  * powerpc/powernv: Fix update of NVLink DMA mask
++    - LP: #1522415
++  * powerpc/powernv: Change NPU PE# assignment
++    - LP: #1522415
++  * powerpc/powernv: Reserve PE#0 on NPU
++    - LP: #1522415
++  * KEYS: Fix keyring ref leak in join_session_keyring()
++    - LP: #1534887
++    - CVE-2016-0728
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 19 Jan 2016 05:49:09 -0700
++
++linux (4.4.0-0.12) xenial; urgency=low
++
++  [ Eric Dumazet ]
++
++  * SAUCE: (no-up) udp: properly support MSG_PEEK with truncated buffers
++    - LP: #1527902
++
++  [ Guilherme G. Piccoli ]
++
++  * SAUCE: powerpc/eeh: Validate arch in eeh_add_device_early()
++    - LP: #1486180
++
++  [ Tim Gardner ]
++
++  * SAUCE: AUFS - update to aufs4.x-rcN 20160111
++  * [Config] CONFIG_VIRTIO_BLK=y, CONFIG_VIRTIO_NET=y for s390
++    - LP: #1532886
++  * [Config] nvme.ko moved to drivers/nvme/host
++  * [Config] scsi_dh morphed into 4 modules
++  * [Config] CONFIG_IBMVNIC=m
++  * [Config] Add DRM ast driver to udeb installer image
++    - LP: #1514711
++  * [Config] CONFIG_KVM=y for s390x
++    - LP: #1532886
++  * [Config] Install spl/zfs under the kernel modules directory
++    Fixes some errors in generic.inclusion-list.log
++
++  [ Upstream Kernel Changes ]
++
++  * perf/x86/intel/uncore: Add Broadwell-EP uncore support
++    - LP: #1524574
++  * EDAC: Add DDR4 flag
++    - LP: #1519631
++  * EDAC, sb_edac: Virtualize several hard-coded functions
++    - LP: #1519631
++  * EDAC, sb_edac: Add support for duplicate device IDs
++    - LP: #1519631
++  * EDAC, sb_edac: Add Knights Landing (Xeon Phi gen 2) support
++    - LP: #1519631
++  * Driver for IBM System i/p VNIC protocol
++    - LP: #1532303
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 11 Jan 2016 09:57:16 -0700
++
++linux (4.4.0-0.11) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Fix bogus reconstruct script
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 11 Jan 2016 07:29:17 -0700
++
++linux (4.4.0-0.10) xenial; urgency=low
++
++  [ Haren Myneni ]
++
++  * SAUCE: crypto: nx-842 - Mask XERS0 bit in return value
++    - LP: #1529666
++
++  [ Serge Hallyn ]
++
++  * SAUCE: add a sysctl to disable unprivileged user namespace unsharing
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_ZONE_DEVICE=y for amd64
++  * [Config] CONFIG_BLK_DEV_LOOP=y for s390x
++    - LP: #1526869
++  * SAUCE: (no-up) apparmor: Fix incompatible pointer type warnings
++  * SAUCE: radeon: r100: Silence 'may be used uninitialized' warnings
++  * SAUCE: dmaengine: ioatdma: Squelch framesize warnings
++  * rebase to v4.4
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.4
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 04 Jan 2016 17:43:51 -0700
++
++linux (4.4.0-0.9) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * rebase to v4.4-rc8
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.4-rc8
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Sun, 03 Jan 2016 18:50:33 -0700
++
++linux (4.4.0-0.8) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * rebase to v4.4-rc7
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.4-rc7
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 28 Dec 2015 16:13:11 -0700
++
++linux (4.4.0-0.7) xenial; urgency=low
++
++  [ Hui Wang ]
++
++  * [Config] CONFIG_I2C_DESIGNWARE_BAYTRAIL=y, CONFIG_IOSF_MBI=y
++    - LP: #1527096
++
++  [ Jann Horn ]
++
++  * SAUCE: (noup) ptrace: being capable wrt a process requires mapped
++    uids/gids
++    - LP: #1527374
++
++  [ Tim Gardner ]
++
++  * rebase to v4.4-rc6
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.4-rc6
++    - LP: #1526330
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 17 Dec 2015 05:28:27 -0700
++
++linux (4.4.0-0.6) xenial; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] disable CONFIG_ARM64_LSE_ATOMICS to avoid issues with ARMv8.1
++    support in latest compilers
++  * [Config] disable CONFIG_CRYPTO_AES_ARM64_CE* to avoid issues with
++    ARMv8.1 support in latest compilers
++
++  [ Tim Gardner ]
++
++  * [Config] s390 -> s390x
++  * SAUCE: include/linux/mmdebug.h: #include <linux/bug.h>
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Dec 2015 06:46:26 -0700
++
++linux (4.4.0-0.5) xenial; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] s390x -- enable tools
++    - LP: #1524319
++  * [Config] s390x -- add architecture to getabis
++  * [Config] s390x -- add s390x ABI information
++  * [Config] s390x -- enable ABI checks
++
++  [ Tim Gardner ]
++
++  * [Debian] config-check and prepare using ${DEBIAN}/config/annotations
++  * [Config] Add s390 modules to nic-modules udeb
++    - LP: #1525297
++  * rebase to v4.4-rc5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.4-rc5
++    - LP: #1523517
++    - LP: #1523232
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 14 Dec 2015 05:28:05 -0700
++
++linux (4.4.0-0.4) xenial; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * cgroup: make css_set pin its css's to avoid use-afer-free
++  * cgroup_freezer: simplify propagation of CGROUP_FROZEN clearing in
++    freezer_attach()
++  * cgroup: fix handling of multi-destination migration from
++    subtree_control enabling
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 08 Dec 2015 11:20:41 -0700
++
++linux (4.4.0-0.3) xenial; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.4-rc4
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Sun, 06 Dec 2015 16:50:15 -0700
++
++linux (4.4.0-0.2) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Add spl/zfs provides to generic and powerpc64-smp
++  * [Config] Add zfs to d-i fs-core-modules
++  * [Config] Include all s390 specific drivers in linux-image
++    - LP: #1522210
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 03 Dec 2015 07:05:56 -0700
++
++linux (4.4.0-0.1) xenial; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Tests] gcc-multilib does not exist on ppc64el redux
++    - LP: #1515541
++  * [Config] libunwind8-dev is not available on s390x
++  * [Debian] Disable SPL/ZFS for cross compiling -- redux
++  * [Config] s390x -- add dasd udebs
++    - LP: #1519833
++  * [Config] s390x -- include dasd modules in linux-image
++    - LP: #1519833
++  * [Config] s390x -- disable ZFS temporarily
++    - LP: #1519820
++  * [Config] s390s -- disable ABI/module checks
++  * [Config] make IBMVETH consistent on powerpc/ppc64el
++    - LP: #1521712
++  * [Config] follow ibmvscsi name change
++    - LP: #1521712
++  * [Config] move ibm disk and ethernet drivers to linux-image
++    - LP: #1521712
++  * [Config] include ibmveth in nic-modules for ppc64el
++    - LP: #1521712
++  * [Config] s390x -- disable abi/module checks for s390x
++
++  [ Joseph Salisbury ]
++
++  * SAUCE: scsi_sysfs: protect against double execution of
++    __scsi_remove_device()
++    - LP: #1509029
++
++  [ Seth Forshee ]
++
++  * [Config] CONFIG_DRM_AMDGPU_CIK=n
++    - LP: #1510405
++
++  [ Tim Gardner ]
++
++  * [Debian] Disable SPL/ZFS for cross compiling
++  * [Config] CONFIG_SCSI_IBMVSCSI=m
++    - LP: #1515872
++  * rebase to v4.4-rc2
++  * [Config] updateconfigs
++  * [Config] CONFIG_WILC1000_DRIVER=n for FTBS
++  * SAUCE: do_zfs=false temporarily
++  * [Config] CONFIG_LUSTRE_FS=n
++  * [Debian] Disable udebs when cross compiling
++  * rebase to v4.4-rc3
++  * [Config] CONFIG_AUFS_FS=m
++  * SAUCE: AUFS
++
++  [ Upstream Kernel Changes ]
++
++  * ZFS: Update with 4.4 support
++  * SPL: Update with 4.4 support
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.4-rc3
++    - LP: #1519168
++  * rebase to v4.4-rc2
++    - LP: #1506615
++    - LP: #1502781
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 23 Nov 2015 13:22:37 -0700
++
++linux (4.3.0-0.8) xenial; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] re-enable OSS support and blacklist
++    - LP: #1434842
++  * [Config] enable CONFIG_CC_STACKPROTECTOR_STRONG=y
++  * [Packaging] config-check -- improve syntax diagnostics
++  * [Packaging] module-inclusion -- add dependency inclusion for a list
++  * [Packaging] config-check -- accumulate multi-line annotations correctly
++  * [Packaging] config-check -- handle V2 annotations format
++  * [Packaging] s390x -- add architecture to kernelconfig
++    - LP: #1488653
++  * [Config] s390x -- initial configuration
++  * [Config] s390x -- add initial binary image
++  * [Config] s390x -- initial configuration update
++  * [Config] s390x -- produce linux-image
++  * [Config] s390x -- d-i module exclusions
++  * [Config] apply Device Drivers >> LED Support >> LED Class Support
++  * [Config] apply File systems >> Miscellaneous filesystems >> SquashFS 4.0 - Squashed file system support
++  * [Config] apply Device Drivers >> Generic Driver Options >> Userspace firmware loading support
++  * SAUCE: leds: lp55xx -- do not force use of the fallback loader
++  * [Config] -- s390x -- configuration review updates
++  * [Config] annotations -- add review marks
++  * [Config] annotations -- config review 4.3 updates
++  * [Config] annotations -- expose reviews
++  * [Config] updateconfigs following incoporation of s390x configs
++  * [Tests] gcc-multilib does not exist on ppc64el
++    - LP: #1515541
++
++  [ Dan Carpenter ]
++
++  * SAUCE: (noup) cxlflash: a couple off by one bugs
++    - LP: #1499849
++
++  [ Haren Myneni ]
++
++  * Revert "SAUCE: (noup) crypto: 842 - Add CRC and validation support"
++
++  [ Jay Vosburgh ]
++
++  * SAUCE: fan: add VXLAN implementation
++
++  [ Manoj Kumar ]
++
++  * SAUCE: (noup) cxlflash: Fix to escalate LINK_RESET also on port 1
++    - LP: #1513583
++
++  [ Matthew R. Ochs ]
++
++  * SAUCE: (noup) cxlflash: Fix to avoid virtual LUN failover failure
++    - LP: #1513583
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_AUFS_EXPORT=y
++    - LP: #1121699
++
++  [ Upstream Kernel Changes ]
++
++  * misc/genwqe: get rid of atomic allocations
++  * crypto: 842 - Add CRC and validation support
++    - LP: #1497878
++  * cxlflash: Fix to avoid invalid port_sel value
++  * cxlflash: Replace magic numbers with literals
++  * cxlflash: Fix read capacity timeout
++  * cxlflash: Fix potential oops following LUN removal
++  * cxlflash: Fix data corruption when vLUN used over multiple cards
++  * cxlflash: Fix to avoid sizeof(bool)
++  * cxlflash: Fix context encode mask width
++  * cxlflash: Fix to avoid CXL services during EEH
++  * cxlflash: Correct naming of limbo state and waitq
++  * cxlflash: Make functions static
++  * cxlflash: Refine host/device attributes
++  * cxlflash: Fix to avoid spamming the kernel log
++  * cxlflash: Fix to avoid stall while waiting on TMF
++  * cxlflash: Fix location of setting resid
++  * cxlflash: Fix host link up event handling
++  * cxlflash: Fix async interrupt bypass logic
++  * cxlflash: Remove dual port online dependency
++  * cxlflash: Fix AFU version access/storage and add check
++  * cxlflash: Correct usage of scsi_host_put()
++  * cxlflash: Fix to prevent workq from accessing freed memory
++  * cxlflash: Correct behavior in device reset handler following EEH
++  * cxlflash: Remove unnecessary scsi_block_requests
++  * cxlflash: Fix function prolog parameters and return codes
++  * cxlflash: Fix MMIO and endianness errors
++  * cxlflash: Fix to prevent EEH recovery failure
++  * cxlflash: Correct spelling, grammar, and alignment mistakes
++  * cxlflash: Fix to prevent stale AFU RRQ
++  * cxlflash: Fix to double the delay each time
++  * cxlflash: Fix to avoid corrupting adapter fops
++  * cxlflash: Correct trace string
++  * cxlflash: Fix to avoid potential deadlock on EEH
++  * cxlflash: Fix to avoid leaving dangling interrupt resources
++  * cxlflash: Fix to escalate to LINK_RESET on login timeout
++  * cxlflash: Fix to avoid corrupting port selection mask
++  * cxlflash: Fix to avoid lock instrumentation rejection
++  * cxlflash: Fix to avoid bypassing context cleanup
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 06 Nov 2015 10:15:07 -0600
++
++linux (4.3.0-0.7) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Revert "Bypass spl/zfs config"
++    Causes unresolved symbols on load.
++  * [Config] Enable ZFS for powerpc64-smp
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 05 Nov 2015 11:42:37 -0600
++
++linux (4.3.0-0.6) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1512704
++  * UBUNTU: SAUCE: AUFS aufs4.x-rcN 20151102
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] add feature interlock with mainline builds
++  * apparmor -- follow change to this_cpu_ptr
++
++  [ John Johansen ]
++
++  * SAUCE: (no-up) apparmor: add parameter to control whether policy hashing is used
++    - LP: #1383886
++  * SAUCE: (no-up) apparmor: Sync to apparmor3 - RC1 snapshot
++    - LP: #1362199
++  * SAUCE: Revert: fix: only allow a single threaded process to ...
++    - LP: #1371310
++  * SAUCE: (no-up) fix: bad unix_addr_fs macro
++    - LP: #1390223
++  * SAUCE: (no-up): apparmor: fix mediation of fs unix sockets
++    - LP: #1408833
++  * SAUCE: (no-up) apparmor: fix mount not handling disconnected paths
++    - LP: #1496430
++
++  [ Tim Gardner ]
++
++  * [Config] Add iscsi_ibft and iscsi_boot_sysfs to generic inclusion list
++    - LP: #1511006
++  * rebase to v4.3
++  * Bypass spl/zfs config
++  * SPL/ZFS: Add Makefiles in order to avoid the lengthy config
++  * [Config] Default AppArmor settings
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.3
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 29 Oct 2015 09:16:26 -0600
++
++linux (4.3.0-0.5) xenial; urgency=low
++
++  * Update spl to 0.6.5.3-0ubuntu1, zfs to 0.6.5.3-0ubuntu1
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.3-rc7
++    - LP: #1504778
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 23 Oct 2015 13:59:52 -0600
++
++linux (4.3.0-0.4) xenial; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Debian] Update to new signing key type and location
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 21 Oct 2015 13:07:30 -0600
++
++linux (4.3.0-0.3) wily; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Debian] sign-file is now compiled
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 21 Oct 2015 09:26:34 -0600
++
++linux (4.3.0-0.2) wily; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Added libssl-dev to Build-Depends
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 20 Oct 2015 14:01:55 -0600
++
++linux (4.3.0-0.1) wily; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.3-rc6
++  * rebase to v4.3-rc5
++  * rebase to v4.3-rc4
++  * rebase to v4.3-rc3
++  * rebase to v4.3-rc2
++  * rebase to v4.3-rc1
++    - LP: #1492132
++    - LP: #1481575
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 14 Sep 2015 07:30:36 -0600
++
++linux (4.2.0-10.11) wily; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Release Tracking Bug
++    - LP: #1495208
++  * No change rebuild to avoid issues with leading zero bytes on
++    internal module signing key.  (see launchpad bug 1494943)
++
++  [ Ming Lei ]
++
++  * [Config] SERIAL_8250_DW=y for arm64
++
++  [ Upstream Kernel Changes ]
++
++  * drm/i915: Move WaBarrierPerformanceFixDisable:skl to skl code from chv
++    code
++    - LP: #1484486
++  * drm/i915/gen8: Add infrastructure to initialize WA batch buffers
++    - LP: #1484486
++  * drm/i915/gen8: Re-order init pipe_control in lrc mode
++    - LP: #1484486
++  * drm/i915/gen8: Add WaDisableCtxRestoreArbitration workaround
++    - LP: #1484486
++  * drm/i915/gen8: Add WaFlushCoherentL3CacheLinesAtContextSwitch
++    workaround
++    - LP: #1484486
++  * drm/i915: Bail out early if WA batch is not available for given Gen
++    - LP: #1484486
++  * drm/i915/gen8: Add WaClearSlmSpaceAtContextSwitch workaround
++    - LP: #1484486
++  * drm/i915: Update WaFlushCoherentL3CacheLinesAtContextSwitch
++    - LP: #1484486
++  * drm/i915/gen9: Implement WaDisableKillLogic for gen 9
++    - LP: #1484486
++  * drm/i915: Enable WA batch buffers for Gen9
++    - LP: #1484486
++  * drm/i915/gen9: Add WaDisableCtxRestoreArbitration workaround
++    - LP: #1484486
++  * drm/i915: Update wa_ctx_emit() macro as per kernel coding guidelines
++    - LP: #1484486
++  * drm/i915/gen9: Add WaFlushCoherentL3CacheLinesAtContextSwitch
++    workaround
++    - LP: #1484486
++  * drm/i915/gen9: Add
++    WaSetDisablePixMaskCammingAndRhwoInCommonSliceChicken
++    - LP: #1484486
++  * drm/i915:skl: Add WaEnableGapsTsvCreditFix
++    - LP: #1484486
++  * drm/i915/skl: revert duplicated WaBarrierPerformanceFixDisable:skl
++    - LP: #1484486
++  * drm/i915/skl: Don't expose the top most plane on gen9 display
++    - LP: #1484486
++  * drm/i915/skl WaDisableSbeCacheDispatchPortSharing
++    - LP: #1484486
++  * drm/i915/skl: WaIgnoreDDIAStrap is forever, always init DDI A
++    - LP: #1484486
++  * drm/i915: reduce indent in i9xx_hpd_irq_handler
++    - LP: #1484531
++  * drm/i915: reduce duplicate conditions in i9xx_hpd_irq_handler
++    - LP: #1484531
++  * drm/i915: reduce indent in intel_hpd_irq_handler
++    - LP: #1484531
++  * drm/i915: group all hotplug related fields into a new struct in
++    dev_priv
++    - LP: #1484531
++  * drm/i915: add for_each_hpd_pin to iterate over hotplug pins
++    - LP: #1484531
++  * drm/i915: simplify conditions for skipping the 2nd hpd loop iterations
++    - LP: #1484531
++  * drm/i915: put back the indent in intel_hpd_irq_handler
++    - LP: #1484531
++  * drm/i915: merge the two hpd loops in intel_hpd_irq_handler to one
++    - LP: #1484531
++  * drm/i915: simplify condition for digital port
++    - LP: #1484531
++  * drm/i915: abstract away platform specific parts from hpd handling
++    - LP: #1484531
++  * drm/i915: Handle HPD when it has actually occurred
++    - LP: #1484531
++  * drm/i915: Set power domain for DDI-E
++    - LP: #1484531
++  * drm/i915: Set alternate aux for DDI-E
++    - LP: #1484531
++  * drm/i915/skl: enable DDI-E hotplug
++    - LP: #1484531
++  * drm/i915/bxt: fix DDI PHY vswing scale value setting
++    - LP: #1494163
++  * drm/i915/skl: Buffer translation improvements
++    - LP: #1494163
++  * drm/i915: Per-DDI I_boost override
++    - LP: #1494163
++  * drm/i915: fix VBT parsing for SDVO child device mapping
++    - LP: #1494163
++  * drm/i915/bxt: edp1.4 Intermediate Freq support
++    - LP: #1494163
++  * drm/i915: fix link rates reported for SKL
++    - LP: #1494163
++  * drm/i915: Allow parsing of variable size child device entries from VBT
++    - LP: #1494163
++  * drm/i915/skl: Update DDI buffer translation programming.
++    - LP: #1494163
++  * drm/i915: Enable HDMI on DDI-E
++    - LP: #1484531
++  * drm/i915/skl: Enable DDI-E
++    - LP: #1484531
++  * drm/i915: eDP can be present on DDI-E
++    - LP: #1484531
++  * drm/i915/skl: Adding DDI_E power well domain
++    - LP: #1484531
++  * drm/i915: set CDCLK if DPLL0 enabled during resuming from S3
++    - LP: #1490035
++  * drm/i915: Split atomic wm update to pre and post variants
++    - LP: #1493746
++  * drm/i915/skl: Drop the preliminary_hw_support flag
++    - LP: #1486868
++  * drm/i915: set FDI translations to NULL on SKL
++    - LP: #1494163
++
++ -- Andy Whitcroft <apw@canonical.com>  Sun, 13 Sep 2015 11:32:02 +0100
++
++linux (4.2.0-9.9) wily; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1493970
++  * [Config] CONFIG_MFD_INTEL_LPSS=m
++    - LP: #1397876
++
++  [ dann frazier ]
++
++  * [Config] Disable CONFIG_IPMI_SI_PROBE_DEFAULTS on armhf and arm64
++    - LP: #1388952
++
++  [ Michael Ellerman ]
++
++  * SAUCE: crypto: vmx - VMX crypto should depend on CONFIG_VSX
++    Fixes FTBS on 32 bit powerpc, patch sent upstream.
++
++  [ Upstream Kernel Changes ]
++
++  * thermal/powerclamp: add cpu id for skylake h/s
++    - LP: #1398269
++  * perf/x86/intel/uncore: Add Broadwell-DE uncore support
++    - LP: #1397852
++  * mfd: watchdog: iTCO_wdt: Expose watchdog properties using platform data
++    - LP: #1460905
++  * i2c: i801: Create iTCO device on newer Intel PCHs
++    - LP: #1460905
++  * watchdog: iTCO_wdt: Add support for TCO on Intel Sunrisepoint
++    - LP: #1460905
++  * perf/x86: Add a native_perf_sched_clock_from_tsc()
++    - LP: #1397867
++  * perf/x86/intel: Add support for PEBSv3 profiling
++    - LP: #1397867
++  * perf/x86/intel/lbr: Allow time stamp for free running PEBSv3
++    - LP: #1397867
++  * x86: Add new MSRs and MSR bits used for Intel Skylake PMU support
++    - LP: #1397867
++  * perf: Add cycles to branch_info
++    - LP: #1397867
++  * perf/x86/intel/lbr: Add support for LBRv5
++    - LP: #1397867
++  * perf/x86/intel: Handle new arch perfmon v4 status bits
++    - LP: #1397867
++  * perf/x86/intel: Move PMU ACK to after LBR read
++    - LP: #1397867
++  * perf/x86/intel/lbr: Optimize v4 LBR unfreezing
++    - LP: #1397867
++  * perf/x86/intel: Add Intel Skylake PMU support
++    - LP: #1397867
++  * perf/x86/intel/lbr: Use correct index to save/restore LBR_INFO with
++    call stack
++    - LP: #1397867
++  * perf/x86/intel/lbr: Limit LBR accesses to TOS in callstack mode
++    - LP: #1397867
++  * perf/x86: Make merge_attr() global to use from perf_event_intel
++    - LP: #1397867
++  * perf/x86/intel: Use 0x11 as extra reg test value
++    - LP: #1397867
++  * perf tools: Add support for cycles, weight branch_info field
++    - LP: #1397867
++  * perf report: Add flag for non ANY branch mode
++    - LP: #1397867
++  * perf report: Add infrastructure for a cycles histogram
++    - LP: #1397867
++  * perf report: Add processing for cycle histograms
++    - LP: #1397867
++  * perf annotate: Compute IPC and basic block cycles
++    - LP: #1397867
++  * perf annotate: Finally display IPC and cycle accounting
++    - LP: #1397867
++  * perf top: Add branch annotation code to top
++    - LP: #1397867
++  * perf report: Display cycles in branch sort mode
++    - LP: #1397867
++  * perf annotate: Fix 32-bit compilation error in util/annotate.c
++    - LP: #1397867
++  * PM / QoS: Make it possible to expose device latency tolerance to
++    userspace
++    - LP: #1460908
++  * ACPI / PM: Attach ACPI power domain only once
++    - LP: #1460908
++  * Driver core: wakeup the parent device before trying probe
++    - LP: #1460908
++  * klist: implement klist_prev()
++    - LP: #1460908
++  * driver core: implement device_for_each_child_reverse()
++    - LP: #1460908
++  * mfd: make mfd_remove_devices() iterate in reverse order
++    - LP: #1460908
++  * dmaengine: add a driver for Intel integrated DMA 64-bit
++    - LP: #1460908
++  * mfd: Add support for Intel Sunrisepoint LPSS devices
++    - LP: #1460908
++  * spi: pxa2xx: Add support for Intel Sunrisepoint
++    - LP: #1397876
++  * spi: spi-pxa2xx: Remove unused legacy PXA DMA API channel numbers
++    - LP: #1397876
++  * spi: pxa2xx: Add terminating entry for pxa2xx_spi_pci_compound_match
++    - LP: #1397876
++  * spi: spi-pxa2xx: Remove unused legacy null dma buffer and allocation
++    for it
++    - LP: #1397876
++  * intel_idle: Skylake Client Support
++    - LP: #1397877
++  * powerpc/kernel: Switch to using MAX_ERRNO
++    - LP: #1458876
++  * powerpc/kernel: Change the do_syscall_trace_enter() API
++    - LP: #1458876
++  * powerpc: Drop unused syscall_get_error()
++    - LP: #1458876
++  * powerpc: Don't negate error in syscall_set_return_value()
++    - LP: #1458876
++  * powerpc: Rework syscall_get_arguments() so there is only one loop
++    - LP: #1458876
++  * powerpc: Use orig_gpr3 in syscall_get_arguments()
++    - LP: #1458876
++  * powerpc: Change syscall_get_nr() to return int
++    - LP: #1458876
++  * powerpc/kernel: Add SIG_SYS support for compat tasks
++    - LP: #1458876
++  * powerpc/kernel: Enable seccomp filter
++    - LP: #1458876
++  * selftests/seccomp: Make seccomp tests work on big endian
++    - LP: #1458876
++  * selftests/seccomp: Add powerpc support
++    - LP: #1458876
++  * eCryptfs: Invalidate dcache entries when lower i_nlink is zero
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 08 Sep 2015 19:17:57 -0600
++
++linux (4.2.0-8.8) wily; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1493357
++  * [Config] CONFIG_CRYPTO_DEV_NX_COMPRESS_CRYPTO obsolete
++    - LP: #1488495
++  * [Config] CONFIG_CXLFLASH=m
++  * [Config] CONFIG_CXL_EEH=y for ppc64el, powerpc64-smp
++
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] standardise on stage1 for the bootstrap stage in line with debian
++  * [Packaging] mark up control for stage1
++  * [Config] kernel-versions -- clean up deps field
++  * [Config] s390x -- build linux-libc-dev
++    - LP: #1488653
++  * [Packaging] control -- prepare for new kernel-wedge semantics
++
++  [ Upstream Kernel Changes ]
++
++  * crypto: vmx - Fixing AES-CTR counter bug
++    - LP: #1484519
++  * crypto: vmx - Fixing GHASH Key issue on little endian
++    - LP: #1484519
++  * powerpc: Uncomment and make enable_kernel_vsx() routine available
++    - LP: #1484519
++  * crypto: vmx - Adding enable_kernel_vsx() to access VSX instructions
++    - LP: #1484519
++  * crypto: nx - nx842_OF_upd_status should return ENODEV if device is not
++    'okay'
++    - LP: #1488495
++  * crypto: nx - rename nx842_{init, exit} to nx842_pseries_{init, exit}
++    - LP: #1488495
++  * crypto: nx - do not emit extra output if status is disabled
++    - LP: #1488495
++  * crypto: nx - reduce chattiness of platform drivers
++    - LP: #1488495
++  * crypto: nx/842 - Fix context corruption
++    - LP: #1488495
++  * crypto: nx - remove __init/__exit from VIO functions
++    - LP: #1488495
++  * crypto: nx - remove pSeries NX 'status' field
++    - LP: #1488495
++  * crypto: nx - move kzalloc() out of spinlock
++    - LP: #1488495
++  * crypto: nx - don't register pSeries driver if ENODEV
++    - LP: #1488495
++  * crypto: nx - use common code for both NX decompress success cases
++    - LP: #1488495
++  * crypto: nx - merge nx-compress and nx-compress-crypto
++    - LP: #1488495
++  * crypto: nx - rename nx-842-crypto.c to nx-842.c
++    - LP: #1488495
++  * crypto: nx - make platform drivers directly register with crypto
++    - LP: #1488495
++  * cxlflash: Base support for IBM CXL Flash Adapter
++    - LP: #1449121
++  * cxlflash: Base error recovery support
++    - LP: #1449121
++  * cxlflash: Superpipe support
++    - LP: #1449121
++  * cxlflash: Virtual LUN support
++    - LP: #1449121
++  * cxlflash: off by one bug in cxlflash_show_port_status()
++    - LP: #1449121
++  * cxlflash: shift wrapping bug in afu_link_reset()
++    - LP: #1449121
++  * cxlflash: Remove unused variable from queuecommand
++    - LP: #1449121
++  * powerpc/powernv: move dma_get_required_mask from pnv_phb to
++    pci_controller_ops
++  * powerpc/eeh: Probe after unbalanced kref check
++  * misc: cxl: clean up afu_read_config()
++  * cxl: Add explicit precision specifiers
++  * cxl: use more common format specifier
++  * cxl: Destroy cxl_adapter_idr on module_exit
++  * cxl: Destroy afu->contexts_idr on release of an afu
++  * cxl: Don't ignore add_process_element() result when attaching context
++  * cxl: Compile with -Werror
++  * cxl: sparse: Make declarations static
++  * cxl: sparse: Silence iomem warning in debugfs file creation
++  * cxl: Convert MMIO read/write macros to inline functions
++  * cxl: Drop commands if the PCI channel is not in normal state
++  * cxl: Allocate and release the SPA with the AFU
++  * cxl: Make IRQ release idempotent
++  * cxl: Clean up adapter MMIO unmap path.
++  * cxl: Refactor adaptor init/teardown
++  * cxl: Refactor AFU init/teardown
++  * cxl: Don't remove AFUs/vPHBs in cxl_reset
++  * cxl: Allow the kernel to trust that an image won't change on PERST.
++  * cxl: EEH support
++  * cxl: Add CONFIG_CXL_EEH symbol
++  * cxl: Plug irq_bitmap getting leaked in cxl_context
++  * cxl: Add alternate MMIO error handling
++  * cxl: Allow release of contexts which have been OPENED but not STARTED
++  * cxl: Remove use of macro DEFINE_PCI_DEVICE_TABLE
++  * cxl: Release irqs if memory allocation fails
++  * cxl: Remove racy attempt to force EEH invocation in reset
++  * cxl: Fix + cleanup error paths in cxl_dev_context_init
++  * cxl: Fix force unmapping mmaps of contexts allocated through the kernel api
++  * cxl: Set up and enable PSL Timebase
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 01 Sep 2015 07:38:43 -0600
++
++linux (4.2.0-7.7) wily; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1490564
++  * rebase to v4.2
++
++  [ Wen Xiong ]
++
++  * SAUCE: ipr: Byte swapping for device_id attribute in sysfs
++    - LP: #1453892
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.2
++    - LP: #1487345
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 26 Aug 2015 07:06:10 -0600
++
++linux (4.2.0-6.6) wily; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1488138
++
++  [ Andy Whitcroft ]
++
++  * rebase to v4.2-rc8
++
++  [ Shilpasri G Bhat ]
++
++  * SAUCE: cpufreq: powernv: Handle throttling due to Pmax capping at chip
++    level
++    - LP: #1480894
++  * SAUCE: powerpc/powernv: Add definition of OPAL_MSG_OCC message type
++    - LP: #1480894
++  * SAUCE: cpufreq: powernv: Register for OCC related opal_message
++    notification
++    - LP: #1480894
++  * SAUCE: cpufreq: powernv: Call throttle_check() on receiving
++    OCC_THROTTLE
++    - LP: #1480894
++  * SAUCE: cpufreq: powernv: Report Psafe only if PMSR.psafe_mode_active
++    bit is set
++    - LP: #1480894
++  * SAUCE: cpufreq: powernv: Restore cpu frequency to policy->cur on
++    unthrottling
++    - LP: #1480894
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.2-rc8
++    - LP: #1483440
++    - LP: #1484334
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 21 Aug 2015 07:12:11 -0600
++
++linux (4.2.0-5.5) wily; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1487173
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] correct spelling of probabaly on the tools packages
++    - LP: #1256822
++  * rebase to v4.2-rc7
++
++  [ dann frazier ]
++
++  * d-i: Add nicpf and nicvf to nic-modules
++  * d-i: Enable usb modules on arm64
++
++  [ Mahesh Salgaonkar ]
++
++  * SAUCE: powerpc/powernv: display reason for Malfunction Alert HMI.
++    - LP: #1482343
++  * SAUCE: powerpc/powernv: Pull all HMI events before panic.
++    - LP: #1482343
++  * SAUCE: powerpc/powernv: Invoke opal_cec_reboot2() on unrecoverable
++    machine check errors.
++    - LP: #1482343
++  * SAUCE: powerpc/powernv: Invoke opal_cec_reboot2() on unrecoverable HMI.
++    - LP: #1482343
++
++  [ Vipin K Parashar ]
++
++  * SAUCE: powerpc/powernv: Add poweroff (EPOW, DPO) events support for
++    PowerNV platform
++    - LP: #1469771
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.2-rc7
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 11 Aug 2015 09:48:40 -0600
++
++linux (4.2.0-4.4) wily; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1483677
++
++  [ Achiad Shochat ]
++
++  * SAUCE: net/mlx5e: Support TX packet copy into WQE
++  * SAUCE: net/mlx5e: TX latency optimization to save DMA reads
++  * SAUCE: net/mlx5e: Cosmetics: use BIT() instead of "1 <<", and others
++  * SAUCE: net/mlx5e: Input IPSEC.SPI into the RX RSS hash function
++
++  [ Adam Lee ]
++
++  * SAUCE: serial: 8250_pci: Add support for Pericom PI7C9X795[1248]
++    - LP: #1480142
++
++  [ dann frazier ]
++
++  * [Config] CONFIG_NR_CPUS=128 on arm64
++
++  [ Leann Ogasawara ]
++
++  * [Config] d-i -- Add sfc to nic-modules udeb
++    - LP: #1481490
++
++  [ Saeed Mahameed ]
++
++  * SAUCE: net/mlx5e: Support ETH_RSS_HASH_XOR
++  * SAUCE: net/mlx5e: Allocate DMA coherent memory on reader NUMA node
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_X86_INTEL_MPX=y
++    - LP: #1460902
++  * [Debian] change dependency on module-init-tools to kmod
++    - LP: #1481986
++  * rebase to v4.2-rc6
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.2-rc6
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 04 Aug 2015 16:59:45 -0600
++
++linux (4.2.0-3.3) wily; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1481462
++  * SAUCE: workqueue: Make flush_workqueue() available again to non GPL modules
++    Fixes an FTBS for at least one DKMS package.
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 04 Aug 2015 11:26:53 -0600
++
++linux (4.2.0-2.2) wily; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1481067
++  * rebase to v4.2-rc5
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] module-inclusion -- commonise copy code and simplify
++  * [Packaging] module-inclusion -- add manual command entries
++  * [Packaging] module blacklists -- add support for manual blacklists
++  * [Packaging] do_common_tools should always be on
++  * [Packaging] initscripts need installing when making the package
++  * [Packaging] initscripts work around bug in debhelper systemd support
++  * [Config] exclude oss modules from linux-image
++    - LP: #1434842
++  * hyper-v -- add hid and fb drivers to linux-virtual
++    - LP: #1444179
++  * ubuntu: (no-squash) vbox -- infrastructure and updater
++  * ubuntu: vbox -- elide the new symlinks and reconstruct on clean:
++    - LP: #1426113
++  * ubuntu: vbox -- update to 5.0.0-dfsg-1
++    - LP: #1480879
++  * SAUCE: vbox: follow v4.2 updates to follow_link()/put_link() API
++  * [Config] move vbox modules into linux-image
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.2-rc5
++    - LP: #1478497
++    - LP: #1477900
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 03 Aug 2015 12:20:10 +0100
++
++linux (4.2.0-1.1~rc1) wily; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Release Tracking Bug
++    - LP: #1479903
++  * Initial upload of v4.2 based kernel (currently v4.-rc4)
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.2-rc4
++    - LP: #1476987
++    - LP: #1476888
++  * rebase to v4.2-rc3
++  * rebase to v4.2-rc2
++  * rebase to v4.2-rc1
++    - LP: #1394368
++    - LP: #1427680
++    - LP: #1462614
++    - LP: #1397021
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 30 Jul 2015 18:42:46 +0100
++
++linux (4.1.0-3.3) wily; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Release Tracking Bug
++    - LP: #1478897
++
++  [ Colin Ian King ]
++
++  * SAUCE: KEYS: ensure we free the assoc array edit if edit is valid
++    - CVE-2015-1333
++
++  [ Seth Forshee ]
++
++  * SAUCE: overlayfs: Enable user namespace mounts for the "overlay" fstype
++    - LP: #1478578
++
++  [ Upstream Kernel Changes ]
++
++  * sched/stop_machine: Fix deadlock between multiple stop_two_cpus()
++    - LP: #1461620
++  * x86/nmi: Enable nested do_nmi() handling for 64-bit kernels
++  * x86/nmi/64: Remove asm code that saves cr2
++  * x86/nmi/64: Switch stacks on userspace NMI entry
++  * x86/nmi/64: Reorder nested NMI checks
++  * x86/nmi/64: Use DF to avoid userspace RSP confusing nested NMI
++    detection
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 28 Jul 2015 11:59:03 +0100
++
++linux (4.1.0-2.4) wily; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: overlayfs: when copying up and reading directories ensure
++    mounter had permissions V2
++    - CVE-2015-1328
++
++  [ Leann Ogasawara ]
++
++  * Release Tracking Bug
++    - LP: #1465419
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 15 Jun 2015 14:09:22 -0700
++
++linux (4.1.0-2.2) wily; urgency=low
++
++  [ Tim Gardner ]
++
++  * rebase to v4.1.3
++  * [Config] Add i40e[vf] to d-i
++    - LP: #1476393
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.1.3
++    - LP: #1427680
++    - LP: #1462614
++    - LP: #1394368
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 22 Jul 2015 09:13:02 -0600
++
++linux (4.1.0-1.1) wily; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: overlay: add backwards compatible overlayfs format support V3
++    - LP: #1395877, #1410480
++  * SAUCE: overlayfs: when copying up and reading directories ensure
++    mounter had permissions V2
++    - CVE-2015-1328
++  * [Packaging] fix up Vcs-Git: to point to launchpad
++  * [Config] correct linux-initramfs-tool virtual linkage
++    - LP: #1474810
++
++  [ Chris J Arges ]
++
++  * [Config] Add dm-service-time to multipath-modules
++    - LP: #1469240
++  * [Config] Add MTD_POWERNV_FLASH and OPAL_PRD
++    - LP: #1464560
++
++  [ Jay Vosburgh ]
++
++  * SAUCE: fan: Proof of concept implementation (v2)
++    - LP: #1439706
++  * SAUCE: fan: tunnel multiple mapping mode (v3)
++    - LP: #1470091
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: ext4: disable ext4_punch_hole for indirect filesystems"
++  * Revert "SAUCE: intel_pstate: inform user that thermald is worth
++    considering"
++  * Revert "SAUCE: Work around broken ACPI backlight on Dell Inspiron 5537"
++  * Revert "SAUCE: dm-crypt: never use write same"
++  * Release Tracking Bug
++    - LP: #1476333
++
++  [ Tim Gardner ]
++
++  * Rebase to v4.1
++    - LP: #1443371
++  * [Config] Enable Apparmor
++  * [Config] CONFIG_OVERLAY_FS_V1=y
++  * [Config] DEFAULT_IOSCHED="deadline" for ppc64el
++    - LP: #1469829
++  * [Config] CONFIG_VM86=n
++    - LP: #1473447
++  * [Config] ACORN_PARTITION=n
++    - LP: #1453117
++
++  [ Timo Aaltonen ]
++
++  * [Config] Disable CONFIG_DRM_I915_PRELIMINARY_HW_SUPPORT
++    - LP: #1473319
++
++  [ Upstream Kernel Changes ]
++
++  * efi: efivar_create_sysfs_entry() should return negative error codes
++  * efi: Add esrt support
++  * x86, doc: Remove cmdline_size from list of fields to be filled in for
++    EFI handover
++  * efi/esrt: Fix some compiler warnings
++  * efi: dmi: List SMBIOS3 table before SMBIOS table
++  * efi: Add 'systab' information to Documentation/ABI
++  * ALSA: hda - restore the MIC FIXUP for some Dell machines
++    - LP: #1473560
++  * mtd: powernv: Add powernv flash MTD abstraction driver
++    - LP: #1464560
++  * powerpc/powernv: Expose OPAL APIs required by PRD interface
++    - LP: #1464560
++  * powerpc/powernv: Add opal-prd channel
++    - LP: #1464560
++  * powerpc/powernv: fix construction of opal PRD messages
++    - LP: #1464560
++  * powerpc/include: Add opal-prd to installed uapi headers
++    - LP: #1464560
++  * powerpc/powernv: Fix vma page prot flags in opal-prd driver
++    - LP: #1464560
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 20 Jul 2015 10:16:06 -0700
++
++linux (4.0.0-2.4) wily; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: overlayfs: when copying up and reading directories ensure
++    mounter had permissions V2
++    - CVE-2015-1328
++
++  [ Leann Ogasawara ]
++
++  * Release Tracking Bug
++    - LP: #1465419
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 15 Jun 2015 14:09:22 -0700
++
++linux (4.0.0-1.2) wily; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: overlay: add backwards compatible overlayfs format support V3
++    - LP: #1395877, #1410480
++  * [Config] enable CONFIG_OVERLAY_FS_V1
++
++  [ Tai Nguyen ]
++
++  * SAUCE: power: reset: Add syscon reboot device node for APM X-Gene platform
++    - LP: #1463211
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_HIBERNATION=n for ppc64el
++    - LP: #1463836
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 12 Jun 2015 06:11:53 -0600
++
++linux (4.0.0-1.1) wily; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Revert "md/raid0: fix bug with chunksize not a power of 2."
++    - LP: #1457510
++  * powerpc/powernv: Check image loaded or not before calling flash
++    - LP: #1461553
++
++  [ Tim Gardner ]
++
++  * [Config] armhf: CPUFREQ_DT=y
++    - LP: #1457781
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v4.0.5
++    - LP: #1429756
++    - LP: #1452175
++    - LP: #1454656
++    - LP: #1447909
++    - LP: #1446517
++    - LP: #1428947
++    - LP: #1410704
++    - LP: #1412800
++    - LP: #1400215
++    - LP: #1411193
++    - LP: #1412800
++    - LP: #1408295
++    - LP: #1436745
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 09 Jun 2015 05:58:46 -0700
++
++linux (3.19.0-10.10) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] control -- make element ordering deterministic
++  * [Config] allow dracult to support initramfs as well
++    - LP: #1109029
++  * [Packaging] generate live watchdog blacklists
++    - LP: #1432837
++
++  [ Leann Ogasawara ]
++
++  * [Config] CONFIG_KVM_GENERIC_DIRTYLOG_READ_PROTECT=y
++    - LP: #1397860
++  * rebase to v3.19.2
++
++  [ Upstream Kernel Changes ]
++
++  * thinkpad_acpi: support new BIOS version string pattern
++    - LP: #1417915
++  * arm64: Invalidate the TLB corresponding to intermediate page table
++    levels
++    - LP: #1432546
++  * perf tools: Support parsing parameterized events
++    - LP: #1430341
++  * perf tools: Extend format_alias() to include event parameters
++    - LP: #1430341
++  * perf Documentation: Add event parameters
++    - LP: #1430341
++  * perf tools: Document parameterized and symbolic events
++    - LP: #1430341
++  * perf: provide sysfs_show for struct perf_pmu_events_attr
++    - LP: #1430341
++  * perf: add PMU_EVENT_ATTR_STRING() helper
++    - LP: #1430341
++  * perf: define EVENT_DEFINE_RANGE_FORMAT_LITE helper
++    - LP: #1430341
++  * powerpc/perf/hv-24x7: parse catalog and populate sysfs with events
++    - LP: #1430341
++  * powerpc/perf/{hv-gpci, hv-common}: generate requests with counters
++    annotated
++    - LP: #1430341
++  * powerpc/perf/hv-gpci: add the remaining gpci requests
++    - LP: #1430341
++  * powerpc/perf/hv-24x7: Document sysfs event description entries
++    - LP: #1430341
++  * powerpc/iommu: Remove IOMMU device references via bus notifier
++    - LP: #1425202
++  * powerpc/pseries: Fix endian problems with LE migration
++    - LP: #1428351
++  * intel_idle: support additional Broadwell model
++    - LP: #1400970
++  * tools/power turbostat: support additional Broadwell model
++    - LP: #1400970
++  * KVM: x86: flush TLB when D bit is manually changed.
++    - LP: #1397860
++  * Optimize TLB flush in kvm_mmu_slot_remove_write_access.
++    - LP: #1397860
++  * KVM: Add generic support for dirty page logging
++    - LP: #1397860
++  * KVM: x86: switch to kvm_get_dirty_log_protect
++    - LP: #1397860
++  * KVM: Rename kvm_arch_mmu_write_protect_pt_masked to be more generic for
++    log dirty
++    - LP: #1397860
++  * KVM: MMU: Add mmu help functions to support PML
++    - LP: #1397860
++  * KVM: MMU: Explicitly set D-bit for writable spte.
++    - LP: #1397860
++  * KVM: x86: Change parameter of kvm_mmu_slot_remove_write_access
++    - LP: #1397860
++  * KVM: x86: Add new dirty logging kvm_x86_ops for PML
++    - LP: #1397860
++  * KVM: VMX: Add PML support in VMX
++    - LP: #1397860
++  * HID: multitouch: add support of clickpads
++  * HID: multitouch: Add support for button type usage
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.19.2
++    - LP: #1428947
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 23 Mar 2015 15:28:16 +0000
++
++linux (3.19.0-9.9) vivid; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Release Tracking Bug
++    - LP: #1430930
++
++  [ Shachar Raindel ]
++
++  * SAUCE: IB/core: Prevent integer overflow in ib_umem_get address
++    arithmetic
++    - LP: #1413741
++    - CVE-2014-8159
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 11 Mar 2015 10:29:17 -0700
++
++linux (3.19.0-8.8) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: vbox -- elide the new symlinks and reconstruct on clean:
++    - LP: #1426113
++  * rebase to stable v3.19.1
++
++  [ John Johansen ]
++
++  * SAUCE: (no-up): apparmor: fix mediation of fs unix sockets
++    - LP: #1408833
++
++  [ Leann Ogasawara ]
++
++  * Release Tracking Bug
++    - LP: #1429940
++
++  [ Upstream Kernel Changes ]
++
++  * xen: correct bug in p2m list initialization
++  * net/mlx5_core: Fix configuration of log_uar_page_sz
++    - LP: #1419938
++  * tpm/ibmvtpm: Additional LE support for tpm_ibmvtpm_send
++    - LP: #1420575
++  * net/mlx4_core: Maintain a persistent memory for mlx4 device
++    - LP: #1422481
++  * net/mlx4_core: Set device configuration data to be persistent across
++    reset
++    - LP: #1422481
++  * net/mlx4_core: Refactor the catas flow to work per device
++    - LP: #1422481
++  * net/mlx4_core: Enhance the catas flow to support device reset
++    - LP: #1422481
++  * net/mlx4_core: Activate reset flow upon fatal command cases
++    - LP: #1422481
++  * net/mlx4_core: Manage interface state for Reset flow cases
++    - LP: #1422481
++  * net/mlx4_core: Handle AER flow properly
++    - LP: #1422481
++  * net/mlx4_core: Enable device recovery flow with SRIOV
++    - LP: #1422481
++  * net/mlx4_core: Reset flow activation upon SRIOV fatal command cases
++    - LP: #1422481
++  * tg3: Hold tp->lock before calling tg3_halt() from tg3_init_one()
++    - LP: #1428111
++  * rebase to v3.19.1
++    - LP: #1410704
++    - LP: #1411193
++    - LP: #1400215
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 09 Mar 2015 10:08:29 -0700
++
++linux (3.19.0-7.7) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Release Tracking Bug
++    - LP: #1426013
++
++  [ Upstream Kernel Changes ]
++
++  * x86/irq: Fix regression caused by commit b568b8601f05
++  * cxl: Fix leaking interrupts if attach process fails
++    - LP: #1415102
++  * cxl: Early return from cxl_handle_fault for a shut down context
++    - LP: #1415102
++  * cxl: Disable AFU debug flag
++    - LP: #1415102
++  * cxl: Disable SPAP register when freeing SPA
++    - LP: #1415102
++  * cxl: remove redundant increment of hwirq
++    - LP: #1415102
++  * cxl: Add tracepoints
++    - LP: #1415102
++  * cxl: Update CXL ABI documentation
++    - LP: #1415102
++  * cxl: Use image state defaults for reloading FPGA
++    - LP: #1415102
++  * cxl: Add image control to sysfs
++    - LP: #1415102
++  * cxl: Enable CAPP recovery
++    - LP: #1415102
++  * cxl: Add ability to reset the card
++    - LP: #1415102
++  * cxl: Fix device_node reference counting
++    - LP: #1415102
++  * cxl: Export optional AFU configuration record in sysfs
++    - LP: #1415102
++  * cxl: Fail AFU initialisation if an invalid configuration record is
++    found
++    - LP: #1415102
++  * cxl: Add missing return statement after handling AFU errror
++    - LP: #1415102
++  * powerpc/eeh: Introduce flag EEH_PE_REMOVED
++    - LP: #1415102
++  * powerpc/eeh: Allow to set maximal frozen times
++    - LP: #1415102
++  * HID: i2c-hid: Limit reads to wMaxInputLength bytes for input events
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 26 Feb 2015 16:00:18 +0000
++
++linux (3.19.0-6.6) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * systemd -- fix hyper-v units to be non-forking
++    - LP: #1401525
++  * [Config] move vbox modules into linux-image
++  * ubuntu: vbox -- update to 4.3.22-dfsg-1
++
++  [ Brad Figg ]
++
++  * SAUCE: DEP8 test to run our regression tests
++
++  [ Paolo Pisati ]
++
++  * [Config] I2C_CHARDEV=y
++    - LP: #1417032
++
++  [ Upstream Kernel Changes ]
++
++  * PCI: Fix infinite loop with ROM image of size 0
++  * tpm: Fix NULL return in tpm_ibmvtpm_get_desired_dma
++  * Bluetooth: ath3k: workaround the compatibility issue with xHCI
++    controller
++    - LP: #1400215
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 19 Feb 2015 12:44:43 +0000
++
++linux (3.19.0-5.5) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_FA_DUMP=y
++    - LP: #1415562
++  * ubuntu: (no-squash) vbox -- infrastructure and updater
++  * ubuntu: vbox -- update to 4.3.20-dfsg-1ubuntu1
++  * rebase to v3.19 final
++
++  [ Chris J Arges ]
++
++  * [Config] Add ibmvfc to d-i
++    - LP: #1416001
++  * SAUCE: ext4: disable ext4_punch_hole for indirect filesystems
++    - LP: #1292234
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.19
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 09 Feb 2015 10:41:11 +0000
++
++linux (3.19.0-4.4) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] apply Kernel hacking >> Tracers config defaults
++  * hyper-v -- fix comment handing in /etc/network/interfaces
++    - LP: #1413020
++  * rebase to v3.19-rc7
++  * updateconfigs following rebase to v3.19-rc7
++
++  [ Ben Hutchings ]
++
++  * SAUCE: rtsx_usb_ms: Use msleep_interruptible() in polling loop
++    - LP: #1413149
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.19-rc7
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 02 Feb 2015 17:03:07 +0200
++
++linux (3.19.0-3.3) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Debian] arm64 -- build ubuntu drivers
++    - LP: #1411284
++  * [Packaging] config-check -- add support for enforced annotations
++  * [Config] annotations -- switch to ENFORCED annotations
++  * [Packaging] config-check -- drop support for enforce file
++  * [Packaging] enforce -- drop empty enforce file
++  * rebase to v3.19-rc5
++  * [Config] add modules removed due to tighter dependencies
++  * [Config] updateconfigs following rebase to v3.19-rc5
++  * [Config] enforce CONFIG_FHANDLE=y
++    - LP: #1412543
++  * [Packaging] hyper-v -- daemons now require -n for non-forking startup
++    - LP: #1408355
++  * [Config] CONFIG_DEBUG_INFO_SPLIT=n
++    - LP: #1413646
++  * [Config] apply Device Drivers >> Character devices >> IPMI top-level
++    message handler config defaults
++  * [Config] apply Device Drivers >> Character devices >> Serial drivers
++    config defaults
++  * [Config] apply Device Drivers >> GPIO Support config defaults
++  * [Config] apply Device Drivers >> Graphics support >> Direct Rendering
++    Manager >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI
++    support) config defaults
++  * [Config] apply Device Drivers >> Graphics support >> Frame buffer
++    Devices >> Support for frame buffer devices config defaults
++  * [Config] apply Device Drivers >> HID support >> HID bus support >>
++    Special HID drivers config defaults
++  * [Config] apply Device Drivers >> Hardware Monitoring support config
++    defaults
++  * [Config] apply Device Drivers >> I2C support >> I2C support >> I2C
++    Hardware Bus support config defaults
++  * [Config] apply Device Drivers >> Industrial I/O support >> Analog to
++    digital converters config defaults
++  * [Config] apply Device Drivers >> Industrial I/O support >> Humidity
++    sensors config defaults
++  * [Config] apply Device Drivers >> Industrial I/O support >> Pressure
++    sensors config defaults
++  * [Config] apply Device Drivers >> Input device support >> Generic input
++    layer (needed for keyboard, mouse, ...) >> Mice config defaults
++  * [Config] apply Device Drivers >> Input device support >> Generic input
++    layer (needed for keyboard, mouse, ...) >> Touchscreens config defaults
++  * [Config] apply Device Drivers >> LED Support >> LED Class Support
++    config defaults
++  * [Config] apply Device Drivers >> MMC/SD/SDIO card support config
++    defaults
++  * [Config] apply Device Drivers >> Multifunction device drivers config
++    defaults
++  * [Config] apply Device Drivers >> Multimedia support >> Cameras/video
++    grabbers support >> Media test drivers config defaults
++  * [Config] apply Device Drivers >> Multimedia support >> Media PCI
++    Adapters config defaults
++  * [Config] apply Device Drivers >> Multimedia support >> Remote
++    Controller devices config defaults
++  * [Config] apply Device Drivers >> Network device support >> Distributed
++    Switch Architecture drivers config defaults
++  * [Config] apply Device Drivers >> Network device support >> Network core
++    driver support config defaults
++  * [Config] apply Device Drivers >> Network device support >> Wireless LAN
++    >> Hermes chipset 802.11b support (Orinoco/Prism2/Symbol) config
++    defaults
++  * [Config] apply Device Drivers >> Network device support >> Wireless LAN
++    >> Intel PRO/Wireless 2200BG and 2915ABG Network Connection config
++    defaults
++  * [Config] apply Device Drivers >> PHY Subsystem config defaults
++  * [Config] apply Device Drivers >> Pin controllers config defaults
++  * [Config] apply Device Drivers >> SPI support config defaults
++  * [Config] apply Device Drivers >> Sound card support >> Advanced Linux
++    Sound Architecture >> ALSA for SoC audio support config defaults
++  * [Config] apply Device Drivers >> Sound card support >> Advanced Linux
++    Sound Architecture >> FireWire sound devices config defaults
++  * [Config] apply Device Drivers >> Sound card support >> Advanced Linux
++    Sound Architecture >> HD-Audio config defaults
++  * [Config] apply Device Drivers >> Staging drivers >> Lustre file system
++    client support config defaults
++  * [Config] apply Device Drivers >> Staging drivers >> Media staging
++    drivers config defaults
++  * [Config] apply Device Drivers >> USB support >> USB Gadget Support >>
++    USB Gadget Drivers >> USB functions configurable through configfs
++    config defaults
++  * [Config] apply Device Drivers >> USB support >> USB Gadget Support >>
++    USB Peripheral Controller config defaults
++  * [Config] apply Networking support >> NFC subsystem support >> Near
++    Field Communication (NFC) devices config defaults
++  * [Config] apply Networking support >> Networking options >> Network
++    packet filtering framework (Netfilter) >> Core Netfilter Configuration
++    >> Netfilter nf_tables support config defaults
++  * [Config] apply Networking support >> Networking options >> QoS and/or
++    fair queueing >> Actions config defaults
++  * [Config] apply Networking support >> Networking options >> TCP/IP
++    networking config defaults
++  * [Config] apply Networking support >> Wireless >> Generic IEEE 802.11
++    Networking Stack (mac80211) config defaults
++  * [Config] apply Device Drivers >> Input device support >> Generic input
++    layer (needed for keyboard, mouse, ...) >> Keyboards config defaults
++  * [Config] apply Device Drivers >> Input device support >> Generic input
++    layer (needed for keyboard, mouse, ...) >> Mice config defaults
++  * [Config] apply Device Drivers >> Pulse-Width Modulation (PWM) Support
++    config defaults
++  * [Config] apply Networking support >> Networking options >> Network
++    packet filtering framework (Netfilter) >> IP: Netfilter Configuration
++    >> IPv4 NAT config defaults
++  * [Config] apply Networking support >> Networking options >> Network
++    packet filtering framework (Netfilter) >> IPv6: Netfilter Configuration
++    >> IPv6 NAT config defaults
++  * [Config] apply Kernel hacking >> Kernel debugging config defaults
++  * [Config] apply General setup >> Timers subsystem >> Timer tick handling
++    config defaults
++  * SAUCE: arm64 -- psci tell the compiler which registers we are needing
++    values in
++    - LP: #1414002
++  * [Config] apply Device Drivers >> Network device support >> Wireless LAN
++    >> Intel Wireless WiFi Next Gen AGN - Wireless-N/Advanced-N/Ultimate-N
++    (iwlwifi) config defaults
++  * [Config] apply Device Drivers >> Real Time Clock config defaults
++  * [Config] apply Device Drivers >> SCSI device support >> SCSI device
++    support >> SCSI low-level drivers config defaults
++  * [Config] apply General setup >> CPU/Task time and stats accounting >>
++    Cputime accounting config defaults
++  * [Config] apply Device Drivers >> Mailbox Hardware Support config
++    defaults
++  * rebase to v3.19-rc6
++  * [Config] updateconfigs following rebase to v3.19-rc6
++
++  [ Kamal Mostafa ]
++
++  * [Packaging] force "dpkg-source -I -i" behavior
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable CONFIG_USB_OTG
++    - LP: #1411295
++
++  [ Upstream Kernel Changes ]
++
++  * overlay: add backwards compatible overlayfs format support (fixes)
++    - LP: #1410480
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.19-rc5
++  * rebase to v3.19-rc6
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 26 Jan 2015 11:37:39 +0000
++
++linux (3.19.0-2.2) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.19-rc4
++  * [Config] updateconfigs following rebase to v3.19-rc4
++  * [Packaging] install all dtb files
++    - LP: #1408002
++  * [Config] switch on "all" dtbs
++    - LP: #1408002
++
++  [ Colin Ian King ]
++
++  * SAUCE: drivers/rtc/interface.c: ignore exprired times when enqueing new
++    timers
++    - LP: #1333569
++
++  [ Joseph Salisbury ]
++
++  * [Config] Enable CONFIG_N_GSM as module.
++    - LP: #1404670
++
++  [ K. Y. Srinivasan ]
++
++  * SAUCE: storvsc: force SPC-3 compliance on win8 and win8 r2 hosts
++    - LP: #1406867
++
++  [ Steve McIntyre ]
++
++  * SAUCE: efi: Expose underlying UEFI firmware platform size to userland
++    - LP: #1409750
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.19-rc4
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 13 Jan 2015 12:35:58 +0000
++
++linux (3.19.0-1.1) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: AUFS -- aufs3-standalone.patch"
++  * Revert "SAUCE: AUFS -- aufs3-mmap.patch"
++  * Revert "SAUCE: AUFS -- aufs3-base.patch"
++  * ubuntu: AUFS3 -- follow switch to vfs_fallocate
++  * rebase to v3.19-rc1
++  * rebase to v3.19-rc2
++  * [Config] defaultconfigs following rebase to v3.19-rc2
++  * ubuntu: aufs3 -- follow rename of d_child
++  * ubuntu: aufs3 -- follow switch to d_splice_alias
++  * ubuntu: aufs3 -- follow switch to get_unused_fd_flags()
++  * ubuntu: aufs3 -- follow rename for d_alias
++  * apparmor -- follow change to this_cpu_ptr
++  * disable module checks for rebase
++  * ubuntu: AUFS -- substrate: aufs3-base.patch
++  * ubuntu: AUFS -- substrate: aufs3-mmap.patch
++  * ubuntu: AUFS -- substrate: aufs3-standalone.patch
++  * ubuntu: AUFS -- update to 92ad9cc8bd289bf8e59b6bd8d83137d8e1a58c1c
++  * [Configs] updateconfigs following aufs update
++  * v3.19 series start
++  * rebase to v3.19-rc3
++  * [Configs] updateconfigs following rebase to v3.19-rc3
++  * [Packaging] uploadnum should be the remainder of the version
++    - LP: #1407755
++  * [Packaging] handle dts directories
++    - LP: #1408004
++  * [Config] follow move of arm64 dts' into vendor directories
++
++  [ Upstream Kernel Changes ]
++
++  * arm64: optimized copy_to_user and copy_from_user assembly code
++    - LP: #1400349
++  * iommu/ipmmu-vmsa: follow flag switch to IOMMU_NOEXEC
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.19-rc1
++    - LP: #1173681
++  * rebase to v3.19-rc2
++  * rebase to v3.19-rc3
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 06 Jan 2015 14:30:02 +0000
++
++linux (3.18.0-7.8) vivid; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Release Tracking Bug
++    - LP: #1401590
++
++  [ John Johansen ]
++
++  * SAUCE: (no-up) apparmor: Sync to apparmor3 - RC1 snapshot
++    - LP: #1362199
++  * SAUCE: Revert: fix: only allow a single threaded process to ...
++    - LP: #1371310
++  * SAUCE: (no-up) fix: bad unix_addr_fs macro
++    - LP: #1390223
++  * SAUCE: (no-up) apparmor: add parameter to control whether policy
++    hashing is used
++    - LP: #1383886
++  * [config] set apparmor config options
++
++  [ Seth Forshee ]
++
++  * [Config] CONFIG_FW_LOADER_USER_HELPER_FALLBACK=n
++    - LP: #1398458
++
++  [ Upstream Kernel Changes ]
++
++  * mfd: rtsx: Fix PM suspend for 5227 & 5249
++    - LP: #1359052
++  * mmc: sdhci-pci-o2micro: Fix Dell E5440 issue
++    - LP: #1346067
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 11 Dec 2014 08:36:36 -0800
++
++linux (3.18.0-6.7) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: (no-up) arm64: optimized copy_to_user and copy_from_user
++    assembly code"
++    - LP: #1398596
++  * rebase to v3.18
++
++  [ Chris J Arges ]
++
++  * [Config] CONFIG_PCIEASPM_DEBUG=y
++    - LP: #1398544
++
++  [ Paolo Pisati ]
++
++  * [Config] armhf: VIRTIO_[BALLOON|MMIO]=y
++    - LP: #1396470
++
++  [ Upstream Kernel Changes ]
++
++  * drivers:scsi:storvsc: Fix a bug in handling ring buffer failures that
++    may result in I/O freeze
++    - LP: #1400289
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.18
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 08 Dec 2014 09:15:17 -0800
++
++linux (3.18.0-5.6) vivid; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Release Tracking Bug
++    - LP: #1398109
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_SCSI_MQ_DEFAULT=n
++    - LP: #1397061
++  * rebase to v3.18-rc7
++
++  [ Chris J Arges ]
++
++  * [Config] CONFIG_SCOM_DEBUGFS=y for powerpc/powerpc64-smp
++    ppc64el/generic
++    - LP: #1395855
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.18-rc7
++    - LP: #1389497
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 01 Dec 2014 10:09:09 -0800
++
++linux (3.18.0-4.5) vivid; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Release Tracking Bug
++    - LP: #1395891
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.18-rc6
++  * [Config] update configs following rebase to v3.18-rc6
++  * [Config] enable overlayfs v1 support
++
++  [ Tim Gardner ]
++
++  * rebase to v3.18-rc5
++
++  [ Upstream Kernel Changes ]
++
++  * overlay: add backwards compatible overlayfs format support
++    - LP: #1395877
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.18-rc5
++  * rebase to v3.18-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 24 Nov 2014 13:12:48 -0800
++
++linux (3.18.0-3.4) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Config] CONFIG_AUFS_FS=n for FTBS"
++  * Revert "SAUCE: AUFS -- update to
++    dcf336a754c86d5ee1c3d50699fd75c586d037cb"
++  * Revert "SAUCE: aufs3 -- (no-up) aufs3-standalone.patch"
++  * Revert "SAUCE: aufs3 -- (no-up) aufs3-base.patch"
++  * [Config] amd64 is now the indep architecture
++  * [Debian] basic hook support
++  * SAUCE: AUFS -- aufs3-base.patch
++  * SAUCE: AUFS -- aufs3-mmap.patch
++  * SAUCE: AUFS -- aufs3-standalone.patch
++  * ubuntu: AUFS -- update to 9d5c349d5c452170b8e813d86956f896a0aef170
++  * [Config] updateconfigs following aufs3 update
++  * SAUCE: AUFS (no-squash): basic framework and update machinary -- part 2
++
++  [ dann frazier ]
++
++  * [Config] Disable CONFIG_IPMI_SI_PROBE_DEFAULTS on armhf and arm64
++    - LP: #1388952
++  * [Config] disable CONFIG_ARM64_RANDOMIZE_TEXT_OFFSET
++  * [Config] Disable CONFIG_RCU_USER_QS on arm64
++
++  [ Tim Gardner ]
++
++  * rebase to v3.18-rc4
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.18-rc4
++    - LP: #1389497
++    - LP: #1387128
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 11 Nov 2014 17:16:13 +0000
++
++linux (3.18.0-2.2) vivid; urgency=low
++
++  [ Tim Gardner ]
++
++  * SAUCE: nft_reject_bridge.c: Include net/ip6_checksum.h
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.18-rc3
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 03 Nov 2014 06:09:06 -0700
++
++linux (3.18.0-1.1) vivid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Config] Switch kernel to vmlinuz (from vmlinux) on ppc64el"
++  * [Config] tools -- only build common tools when enabled
++  * [Config] follow rename of DEB_BUILD_PROFILES
++  * [Config] linux-image-extra is additive to linux-image
++    - LP: #1375310
++  * [Config] linux-image-extra postrm is not needed on purge
++  * [Config] enable cloud tools on i386
++    - LP: #1367399
++
++  [ Marc Dietrich ]
++
++  * [Config] arm/tegra/d-i: framebuffer and usb support for Tegra SoCs
++
++  [ Paolo Pisati ]
++
++  * [Config] armhf: REGULATOR_TWL4030=y
++  * [Config] armhf: disable JUMP_LABEL
++    - LP: #1378856
++
++  [ Tim Gardner ]
++
++  * rebase to v3.17-rc2
++  * updateconfigs
++  * [Config] CONFIG_NFC_ST21NFCB=n
++  * [Config] Added net/6lowpan/* to generic inclusion list
++  * [Config] Add arm64 to enforcer CONFIG_CC_STACKPROTECTOR
++  * rebase to v3.17-rc3
++  * rebase to v3.17-rc4
++  * rebase to v3.17-rc5
++  * [Config] armhf: USB_[E|O]HCI_EXYNOS=y
++  * [Config] CONFIG_XMON=y
++    - LP: #1365655
++  * [Config] CONFIG_KVM_BOOK3S_64=m for ppc64el
++    - LP: #1362514
++  * [Config] CONFIG_KVM_BOOK3S_64_HV=m
++    - LP: #1362514
++  * [Config] CONFIG_DMA_CMA=n
++    - LP: #1362261
++  * [Config] Add mpt3sas to d-i
++    - LP: #1368907
++  * [Debian] set do_*_tools after stage1 or bootstrap is determined
++    - LP: #1370211
++  * [Config] CONFIG_USB_OHCI_HCD_PCI=y
++    - LP: #1244176
++  * rebase to v3.17-rc6
++  * SAUCE: usbip: Update include path
++  * [Debian] usbip tools packaging
++    - LP: #898003
++  * [Config] Enable usbip tools
++    - LP: #898003
++  * [Config] CONFIG_CRASH_DUMP=n for powerpc-smp
++    - LP: #1363180
++  * [Config] Correct annotation regarding CONFIG_DMA_CMA
++    - LP: #1362261
++  * [Config] CONFIG_SND_HDA_INTEL=n for ppc64el
++    - LP: #1374438
++  * [Config] CONFIG_HOTPLUG_PCI_SHPC=n for ppc64el
++    - LP: #1374440
++  * [Debian] Don't fail if a symlink already exists
++  * rebase to v3.17-rc7
++  * [Config] CONFIG_HOTPLUG_PCI_PCIE=n for ppc64el
++    - LP: #1374440
++  * rebase to v3.17
++  * rebase to v3.18-rc1
++  * [Config] CONFIG_AUFS_FS=n for FTBS
++  * Enable vivid
++  * [Config] CONFIG_SOUND_OSS_CORE_PRECLAIM=n
++    - LP: #1385510
++  * rebase to v3.18-rc2
++  * [Debian] Fix linux-doc dangling symlinks
++    - LP: #661306
++  * CONFIG_MODULE_COMPRESS=n
++  * [Config] dropped scsi_tgt from generic inclusion list
++  * [Config] Added drivers/uio to generic inclusion list
++  * [Config] CONFIG_PATA_MACIO=y
++    - LP: #1378894
++  * [Config] CONFIG_DRM_BOCHS=n
++  * [Debian] install usbipd
++    - LP: #898003
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.18-rc2
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.18-rc1
++    - LP: #1316518
++    - LP: #1371591
++    - LP: #1357928
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.17
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.17-rc7
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.17-rc6
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.17-rc5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.17-rc4
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.17-rc3
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.17-rc2
++    - LP: #1358116
++    - LP: #1350148
++    - LP: #1334950
++    - LP: #1329580
++    - LP: #1329580
++    - LP: #1329580
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.17-rc2
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 26 Aug 2014 10:36:19 -0600
++
++linux (3.17.0-0.0) utopic; urgency=medium
++
++  * Empty entry
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 26 Aug 2014 10:34:44 -0600
++
++linux (3.16.0-11.16) utopic; urgency=low
++
++  [ Mauricio Faria de Oliveira ]
++
++  * [Config] Switch kernel to vmlinuz (from vmlinux) on ppc64el
++    - LP: #1358920
++
++  [ Peter Zijlstra ]
++
++  * SAUCE: (no-up) mmu_notifier: add call_srcu and sync function for listener to delay call and sync
++    - LP: #1361300
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_ZPOOL=y
++    - LP: #1360428
++  * Release Tracking Bug
++    - LP: #1361308
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "net/mlx4_en: Fix bad use of dev_id"
++    - LP: #1347012
++  * net/mlx4_en: Reduce memory consumption on kdump kernel
++    - LP: #1347012
++  * net/mlx4_en: Fix mac_hash database inconsistency
++    - LP: #1347012
++  * net/mlx4_en: Disable blueflame using ethtool private flags
++    - LP: #1347012
++  * net/mlx4_en: current_mac isn't updated in port up
++    - LP: #1347012
++  * net/mlx4_core: Use low memory profile on kdump kernel
++    - LP: #1347012
++  * Drivers: scsi: storvsc: Change the limits to reflect the values on the host
++    - LP: #1347169
++  * Drivers: scsi: storvsc: Set cmd_per_lun to reflect value supported by the Host
++    - LP: #1347169
++  * Drivers: scsi: storvsc: Filter commands based on the storage protocol version
++    - LP: #1347169
++  * Drivers: scsi: storvsc: Fix a bug in handling VMBUS protocol version
++    - LP: #1347169
++  * Drivers: scsi: storvsc: Implement a eh_timed_out handler
++    - LP: #1347169
++  * drivers: scsi: storvsc: Set srb_flags in all cases
++    - LP: #1347169
++  * drivers: scsi: storvsc: Correctly handle TEST_UNIT_READY failure
++    - LP: #1347169
++  * namespaces: Use task_lock and not rcu to protect nsproxy
++    - LP: #1328088
++  * net: xgene: Check negative return value of xgene_enet_get_ring_size()
++  * mm/zbud: change zbud_alloc size type to size_t
++    - LP: #1360428
++  * mm/zpool: implement common zpool api to zbud/zsmalloc
++    - LP: #1360428
++  * mm/zpool: zbud/zsmalloc implement zpool
++    - LP: #1360428
++  * mm/zpool: update zswap to use zpool
++    - LP: #1360428
++  * ideapad-laptop: Change Lenovo Yoga 2 series rfkill handling
++    - LP: #1341296
++  * iommu/amd: Fix for pasid initialization
++    - LP: #1361300
++  * iommu/amd: Moving PPR fault flags macros definitions
++    - LP: #1361300
++  * iommu/amd: Drop oprofile dependency
++    - LP: #1361300
++  * iommu/amd: Fix typo in amd_iommu_v2 driver
++    - LP: #1361300
++  * iommu/amd: Don't call mmu_notifer_unregister in __unbind_pasid
++    - LP: #1361300
++  * iommu/amd: Don't free pasid_state in mn_release path
++    - LP: #1361300
++  * iommu/amd: Get rid of __unbind_pasid
++    - LP: #1361300
++  * iommu/amd: Drop pasid_state reference in ppr_notifer error path
++    - LP: #1361300
++  * iommu/amd: Add pasid_state->invalid flag
++    - LP: #1361300
++  * iommu/amd: Don't hold a reference to mm_struct
++    - LP: #1361300
++  * iommu/amd: Don't hold a reference to task_struct
++    - LP: #1361300
++  * iommu/amd: Don't call the inv_ctx_cb when pasid is not set up
++    - LP: #1361300
++  * iommu/amd: Don't set pasid_state->mm to NULL in unbind_pasid
++    - LP: #1361300
++  * iommu/amd: Remove change_pte mmu_notifier call-back
++    - LP: #1361300
++  * iommu/amd: Fix device_state reference counting
++    - LP: #1361300
++  * iommu/amd: Fix 2 typos in comments
++    - LP: #1361300
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 22 Aug 2014 08:45:54 -0400
++
++linux (3.16.0-10.15) utopic; urgency=low
++
++  [ dann frazier ]
++
++  * [debian] Fix regression with ABI subversions and backport
++
++  [ Feng Kan ]
++
++  * SAUCE: (no-up) irqchip:gic: change access of gicc_ctrl register to read
++    modify write.
++    - LP: #1357527
++  * SAUCE: (no-up) arm64: optimized copy_to_user and copy_from_user
++    assembly code
++    - LP: #1358949
++
++  [ Stefan Bader ]
++
++  * SAUCE: bcache: prevent crash on changing writeback_running
++    - LP: #1357295
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_XFRM_STATISTICS=y
++  * [Config] CONFIG_SECURITY_NETWORK_XFRM=y
++  * [Config] CONFIG_SENSORS_IBMPOWERNV=m
++    - LP: #1353005
++  * Release Tracking Bug
++    - LP: #1359783
++
++  [ Upstream Kernel Changes ]
++
++  * intel_idle: Broadwell support
++    - LP: #1256170
++  * powerpc/book3s: Add basic infrastructure to handle HMI in Linux.
++    - LP: #1357108
++  * powerpc/powernv: Invoke opal call to handle hmi.
++    - LP: #1357108
++  * powerpc/book3s: handle HMIs for cpus in nap mode.
++    - LP: #1357108
++  * powerpc/book3s: Fix endianess issue for HMI handling on napping cpus.
++    - LP: #1357108
++  * powerpc: Add smp_mb() to arch_spin_is_locked()
++    - LP: #1358569
++  * powerpc: Add smp_mb()s to arch_spin_unlock_wait()
++    - LP: #1358569
++  * hwmon: (powerpc/powernv) hwmon driver for power, fan rpm, voltage and
++    temperature
++    - LP: #1353005
++  * tools/testing/selftests/ptrace/peeksiginfo.c: add PAGE_SIZE definition
++    - LP: #1358855
++  * printk: Add function to return log buffer address and size
++    - LP: #1359423
++  * powerpc/powernv: Interface to register/unregister opal dump region
++    - LP: #1359423
++  * bcache: fix crash on shutdown in passthrough mode
++    - LP: #1357295
++  * bcache: fix uninterruptible sleep in writeback thread
++    - LP: #1357295
++
++  [ Vinayak Kale ]
++
++  * SAUCE: (no-up) dt-bindings: Add Potenza PMU binding
++    - LP: #1357527
++  * SAUCE: (no-up) arm64: dts: Add PMU node for APM X-Gene Storm SOC
++    - LP: #1357527
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 15 Aug 2014 12:34:33 -0600
++
++linux (3.16.0-9.14) utopic; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1357370
++
++  [ Serge Hallyn ]
++
++  * SAUCE: Overlayfs: allow unprivileged mounts
++    - LP: #1357025
++
++  [ Upstream Kernel Changes ]
++
++  * MAINTAINERS: Add entry for APM X-Gene SoC ethernet driver
++  * Documentation: dts: Add bindings for APM X-Gene SoC ethernet driver
++  * dts: Add bindings for APM X-Gene SoC ethernet driver
++  * drivers: net: Add APM X-Gene SoC ethernet driver support.
++  * powerpc/thp: Add write barrier after updating the valid bit
++    - LP: #1357014
++  * powerpc/thp: Don't recompute vsid and ssize in loop on invalidate
++    - LP: #1357014
++  * powerpc/thp: Invalidate old 64K based hash page mapping before insert
++    of 4k pte
++    - LP: #1357014
++  * powerpc/thp: Handle combo pages in invalidate
++    - LP: #1357014
++  * powerpc/thp: Invalidate with vpn in loop
++    - LP: #1357014
++  * powerpc/thp: Use ACCESS_ONCE when loading pmdp
++    - LP: #1357014
++  * powerpc/mm: Use read barrier when creating real_pte
++    - LP: #1357014
++  * powerpc/thp: Add tracepoints to track hugepage invalidate
++    - LP: #1357014
++  * rebase to v3.16.1
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 14 Aug 2014 08:18:02 -0400
++
++linux (3.16.0-8.13) utopic; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1356403
++
++  [ dann frazier ]
++
++  * [debian] Allow for package revisions condusive for branching
++
++  [ Upstream Kernel Changes ]
++
++  * ahci_xgene: Fix the watermark threshold for the APM X-Gene SATA host controller driver.
++    - LP: #1350087
++  * ahci_xgene: Use correct OOB tunning parameters for APM X-Gene SoC AHCI SATA Host controller driver.
++    - LP: #1350087
++  * powerpc/powernv: Enable M64 aperatus for PHB3
++    - LP: #1355469
++  * powerpc: Fail remap_4k_pfn() if PFN doesn't fit inside PTE
++    - LP: #1352994
++  * powerpc: Add machine_early_initcall()
++    - LP: #1352640
++  * powerpc/powernv: Switch powernv drivers to use machine_xxx_initcall()
++    - LP: #1352640
++  * powerpc/eeh: Avoid event on passed PE
++    - LP: #1352640
++  * powerpc/eeh: EEH support for VFIO PCI device
++    - LP: #1352640
++  * powerpc/eeh: sysfs entries lost
++    - LP: #1352640
++  * powerpc/powernv: Fix IOMMU table for VFIO dev
++    - LP: #1352640
++  * powerpc/eeh: Fetch IOMMU table in reliable way
++    - LP: #1352640
++  * powerpc/eeh: Refactor EEH flag accessors
++    - LP: #1352640
++  * powerpc/eeh: Selectively enable IO for error log
++    - LP: #1352640
++  * powerpc/eeh: Reduce lines of log dump
++    - LP: #1352640
++  * powerpc/eeh: Replace pr_warning() with pr_warn()
++    - LP: #1352640
++  * powerpc/eeh: Make diag-data not endian dependent
++    - LP: #1352640
++  * powerpc/eeh: Aux PE data for error log
++    - LP: #1352640
++  * PCI: Support BAR sizes up to 128GB
++    - LP: #1352640
++  * powerpc/powernv: Allow to freeze PE
++    - LP: #1352640
++  * powerpc/powernv: Split ioda_eeh_get_state()
++    - LP: #1352640
++  * powerpc/powernv: Handle compound PE
++    - LP: #1352640
++  * powerpc/powernv: Handle compound PE for EEH
++    - LP: #1352640
++  * powerpc/powernv: Handle compound PE in config accessors
++    - LP: #1352640
++  * mnt: Only change user settable mount flags in remount
++    - LP: #1356318
++    - CVE-2014-5206
++  * mnt: Move the test for MNT_LOCK_READONLY from change_mount_flags into do_remount
++    - LP: #1356318
++    - CVE-2014-5206
++  * mnt: Correct permission checks in do_remount
++    - LP: #1356323
++    - CVE-2014-5207
++  * mnt: Change the default remount atime from relatime to the existing value
++    - LP: #1356323
++    - CVE-2014-5207
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Sun, 10 Aug 2014 09:10:51 -0600
++
++linux (3.16.0-7.12) utopic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.16 final
++  * [Config] d-i -- add virtio_scsi to virtio-modules
++    - LP: #1342000
++
++  [ dann frazier ]
++
++  * [Packaging] Fix 'printchanges' to work with versions containing '+'
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_MICROCODE=y
++    - LP: #1084373
++  * [Config] CONFIG_CONTEXT_TRACKING_FORCE=n
++    - LP: #1349028
++  * [Config] Add hv_balloon to d-i virtio-modules
++    - LP: #1292216
++  * Release Tracking Bug
++    - LP: #1354530
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.16
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 29 Jul 2014 09:55:15 -0400
++
++linux (3.16.0-6.11) utopic; urgency=low
++
++  [ Paolo Pisati ]
++
++  * [Config] armhf: MXS_DMA=y && MTD_NAND_GPMI_NAND=m
++  * [Config] armhf: KEYBOARD_IMX=m
++  * [Config] armhf: build cubox & imx6 DTBs
++  * [Config] armhf: RTC_DRV_PCF8523=y
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_KEYS_DEBUG_PROC_KEYS=y
++    - LP: #1344405
++  * [Config] CONFIG_SCSI_IPR_TRACE=y, CONFIG_SCSI_IPR_DUMP=y
++    - LP: #1343109
++  * Release Tracking Bug
++    - LP: #1349196
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.16-rc7
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 24 Jul 2014 09:08:55 -0400
++
++linux (3.16.0-5.10) utopic; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1346298
++  * [Config] CONFIG_GPIO_SYSFS=y
++    - LP: #1342153
++  * rebase to v3.16-rc6
++
++  [ Paolo Pisati ]
++
++  * [Config] enable ARCH_MVEBU*
++  * [Config] AHCI_MVEBU=m
++  * [Config] ARMADA_THERMAL=y
++  * [Config] ARM_ARMADA_370_XP_CPUIDLE=y
++  * [Config] CRYPTO_DEV_MV_CESA=m
++  * [Config] I2C_MV64XXX=m
++  * [Config] MMC_MVSDIO=m
++  * [Config] MMC_SDHCI_DOVE=m
++  * [Config] MTD_NAND_ORION=m
++  * [Config] MTD_NAND_PXA3xx=m
++  * [Config] MVNETA=m
++  * [Config] MV_XOR=y
++  * [Config] ORION_WATCHDOG=m
++  * [Config] PCI_MVEBU=y
++  * [Config] RTC_DRV_MV=y
++  * [Config] SND_KIRKWOOD_SOC*=m
++  * [Config] SPI_ORION=m
++  * [Config] USB_XHCI_MVEBU=m
++  * [Config] armhf: build all Armada and Dove DTBs
++  * [Config] armhf: SERIAL_8250_DW=y
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.16-rc6
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Jul 2014 07:49:42 -0400
++
++linux (3.16.0-4.9) utopic; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1341543
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.16-rc5
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Sun, 13 Jul 2014 21:30:27 -0400
++
++linux (3.16.0-3.8) utopic; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1340091
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 10 Jul 2014 10:06:47 +0100
++
++linux (3.16.0-2.7) utopic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: aufs3 -- avoid aufs3-mmap.patch include hell for arm64
++    ubuntu: aufs3 -- (no-up) aufs3-mmap.patch
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 09 Jul 2014 16:16:28 +0100
++
++linux (3.16.0-2.6) utopic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: aufs3 -- (no-up) aufs3-mmap.patch"
++    Fixes FTBS.
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 08 Jul 2014 17:29:26 +0100
++
++linux (3.16.0-2.5) utopic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu -- fix basic format for ubuntu/Makefile
++  * ubuntu: AUFS (no-squash): basic framework and update machinary
++  * ubuntu: aufs3 -- update update scripting
++  * ubuntu: aufs3 -- (no-up) aufs3-base.patch
++  * ubuntu: aufs3 -- (no-up) aufs3-mmap.patch
++  * ubuntu: aufs3 -- (no-up) aufs3-standalone.patch
++  * ubuntu: AUFS -- update to dcf336a754c86d5ee1c3d50699fd75c586d037cb
++  * [Configs] AUFS configs
++  * ubuntu: aufs3 -- reenable
++
++  [ Tim Gardner ]
++
++  * CONFIG_LATENCYTOP=n
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 08 Jul 2014 15:27:35 +0100
++
++linux (3.16.0-2.4) utopic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] flip VIRTIO*=y
++  * [Config] commonise CONFIG_SWIOTLB=y
++  * [Config] apply Bus options (PCI etc.) >> PCI support config defaults
++  * [Config] apply Device Drivers >> ATA/ATAPI/MFM/RLL support (DEPRECATED)
++    config defaults
++  * [Config] apply Device Drivers >> Block devices config defaults
++  * [Config] apply Device Drivers >> Character devices config defaults
++  * [Config] apply Device Drivers >> DMA Engine support config defaults
++  * [Config] apply Device Drivers >> EDAC (Error Detection And Correction)
++    reporting config defaults
++  * [Config] apply Device Drivers >> Graphics support >> Direct Rendering
++    Manager >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI
++    support) config defaults
++  * [Config] apply Device Drivers >> GPIO Support config defaults
++  * [Config] apply Device Drivers >> Graphics support >> Console display
++    driver support config defaults
++  * [Config] apply Device Drivers >> IIO staging drivers >> Accelerometers
++    config defaults
++  * [Config] apply Device Drivers >> IOMMU Hardware Support config defaults
++  * [Config] apply Device Drivers >> Input device support >> Generic input
++    layer (needed for keyboard, mouse, ...) >> Miscellaneous devices config
++    defaults
++  * [Config] apply Device Drivers >> Input device support >> Hardware I/O
++    ports config defaults
++  * [Config] apply Device Drivers >> LED Support >> LED Class Support
++    config defaults
++  * [Config] apply Device Drivers >> Hardware Spinlock drivers config
++    defaults
++  * [Config] apply Device Drivers >> Multimedia support >> Cameras/video
++    grabbers support config defaults
++  * [Config] apply Security options config defaults
++  * [Config] apply Networking options >> Network packet filtering framework
++    (Netfilter) >> Core Netfilter Configuration config defaults
++  * [Config] apply Device Drivers >> MMC/SD/SDIO card support config
++    defaults
++  * [Config] apply Device Drivers >> Graphics support >> Frame buffer
++    Devices >> Support for frame buffer devices config defaults
++  * [Config] apply Power management and ACPI options >> CPU Frequency
++    scaling config defaults
++  * [Config] apply Processor type and features config defaults
++  * [Config] apply Partition Types config defaults
++  * [Config] apply Power management and ACPI options config defaults
++  * [Config] apply Device Drivers >> InfiniBand support config defaults
++  * [Config] apply Device Drivers >> Misc devices config defaults
++  * [Config] apply Device Drivers >> Multifunction device drivers config
++    defaults
++  * [Config] apply Device Drivers >> SCSI device support >> SCSI device
++    support >> SCSI low-level drivers config defaults
++  * [Config] apply Device Drivers >> Network device support >> Ethernet
++    driver support config defaults
++  * [Config] apply Device Drivers >> Network device support >> Network core
++    driver support config defaults
++  * [Config] apply Device Drivers >> Network device support >> PHY Device
++    support and infrastructure config defaults
++  * [Config] apply File systems >> Network File Systems config defaults
++  * [Config] apply Device Drivers >> Input device support >> Generic input
++    layer (needed for keyboard, mouse, ...) >> Touchscreens config defaults
++  * [Config] apply Device Drivers >> Memory Technology Device (MTD) support
++    >> NAND Device Support config defaults
++  * [Config] apply Device Drivers >> Network device support >> Wireless LAN
++    >> Ralink driver support config defaults
++  * [Config] apply Device Drivers >> Staging drivers config defaults
++  * [Config] apply Cryptographic API >> Hardware crypto devices config
++    defaults
++  * [Config] apply Device Drivers >> Macintosh device drivers config
++    defaults
++  * [Config] apply Device Drivers >> Network device support >> Wireless LAN
++    config defaults
++  * [Config] apply Device Drivers >> PPS support config defaults
++  * [Config] apply Device Drivers >> Sound card support config defaults
++  * [Config] apply Networking support >> RF switch subsystem support config
++    defaults
++  * [Config] apply Library routines config defaults
++  * [Config] apply Device Drivers >> CODEC drivers config defaults
++  * [Config] apply Device Drivers >> PHY Subsystem config defaults
++  * [Config] apply Device Drivers >> Pulse-Width Modulation (PWM) Support
++    config defaults
++  * [Config] apply Kernel hacking >> Tracers config defaults
++  * [Config] apply Kernel hacking >> Runtime Testing config defaults
++  * [Config] apply Kernel hacking >> Architecture: powerpc config defaults
++  * [Config] apply Device Drivers >> USB support config defaults
++  * [Config] apply Device Drivers >> Power supply class support config
++    defaults
++  * [Config] apply Device Drivers >> USB Network Adapters config defaults
++  * [Config] apply General setup >> IRQ subsystem config defaults
++  * [Config] apply General setup config defaults
++  * [Config] apply File systems >> Miscellaneous filesystems config
++    defaults
++  * [Config] apply File systems config defaults
++  * [Config] apply Device Drivers >> Userspace I/O drivers config defaults
++  * [Config] apply Device Drivers >> Virtio drivers config defaults
++  * [Config] apply Device Drivers >> USB Peripheral Controller config
++    defaults
++  * [Config] apply Device Drivers >> SCSI device support >> SCSI device
++    support >> SCSI Transports config defaults
++  * [Config] apply Device Drivers >> Real Time Clock config defaults
++  * [Config] apply Device Drivers >> Serial ATA and Parallel ATA drivers
++    (libata) config defaults
++  * [Config] apply Device Drivers >> SoC Audio for Freescale CPUs config
++    defaults
++  * [Config] apply Device Drivers >> Voltage and Current Regulator Support
++    config defaults
++  * [Config] apply Device Drivers >> USB Physical Layer drivers config
++    defaults
++  * [Config] apply Device Drivers >> Watchdog Timer Support config defaults
++  * [Config] powerpc-powerpc-e500mc FTBFS -- CONFIG_CRASH_DUMP=n
++  * [Config] powerpc-powerpc64-emb FTBFS -- CONFIG_IMA=n
++  * [Config] powerpc-powerpc64-emb FTBFS -- CONFIG_HIBERNATION=n
++    CONFIG_HOTPLUG_CPU=n
++  * [Config] ppc64el-generic FTBFS -- CONFIG_LUSTRE_FS=n
++  * [Config] drivers/message/fusion needs scsi_transport_spi in virtual
++  * [Config] drivers/acpi/acpi_ipmi.ko needs
++    drivers/char/ipmi/ipmi_msghandler.ko in virtual
++  * [Config] armhf-* FTBFS -- CONFIG_STACK_TRACER=n
++    CONFIG_FUNCTION_TRACER=n
++  * [Config] ignore modules changing following major config changes
++
++  [ Tim Gardner ]
++
++  * rebase to v3.16-rc4
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.16-rc4
++    - LP: #1297581
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 03 Jul 2014 11:00:43 +0100
++
++linux (3.16.0-1.3) utopic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "Disable do_tools_perf for FTBS"
++  * SAUCE: fix perf_regs definitions for arm64
++
++  [ Paolo Pisati ]
++
++  * [Config] armhf: ARCH_EXYNOS5* support
++  * [Config] armhf: CPU_IDLE=y and ARM_EXYNOS_CPUIDLE=y
++  * [Config] armhf: EXYNOS_THERMAL=y
++  * [Config] armhf: EXYNOS_IOMMU=y
++  * [Config] armhf: EXYNOS_ADC=m
++  * [Config] armhf: EXYNOS_I2C_EXYNOS5=m
++  * [Config] armhf: MMC_SDHCI_S3C=m
++  * [Config] armhf: PCI_EXYNOS=y
++  * [Config] armhf: PHY_EXYNOS5250_SATA=y
++  * [Config] armhf: USB_[E|O]HCI_EXYNOS=y && SAMSUNG_USBPHY=y
++  * [Config] armhf: PWM_SAMSUNG=m
++  * [Config] armhf: RTC_DRV_S3C=y
++  * [Config] armhf: S3C2410_WATCHDOG=m
++  * [Config] armhf: MMC_DW_EXYNOS=m
++  * [Config] armhf: SERIAL_SAMSUNG=y
++  * [Config] armhf: SND_SOC_SAMSUNG=m
++  * [Config] armhf: SPI_S3C64XX=m
++  * [Config] armhf: EXYNOS_VIDEO=y and VIDEO_SAMSUNG*=m
++  * [Config] armhf: FB_S3C=m
++  * [Config] armhf: build all Exynos 5 DTBs
++  * [Config] armhf: disable CPUFREQ_EXYNOS
++
++  [ Tim Gardner ]
++
++  * rebase to v3.16-rc3
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.16-rc3
++    - LP: #1331915
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 24 Jun 2014 08:58:09 -0600
++
++linux (3.16.0-0.2) utopic; urgency=low
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: intel_pstate -- toggle default to disable"
++    - LP: #1333322
++  * CONFIG_BOOKE_WDT=y
++  * Disable do_tools_perf for FTBS (just until I can figure it out)
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 23 Jun 2014 13:37:53 -0600
++
++linux (3.16.0-0.1) utopic; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1333265
++
++  [ Andy Whitcroft ]
++
++  * [Config] cloud-tools -- add systemd units
++    - LP: #1329027
++
++  [ dann frazier ]
++
++  * [Config] CONFIG_RTC_DRV_XGENE=y for arm64
++  * [Config] CONFIG_NET_XGENE=m for arm64
++  * [Config] Restrict CONFIG_POWER_RESET_SYSCON to arm64 only
++
++  [ Feng Kan ]
++
++  * SAUCE: (no-up) arm64: dts: Add X-Gene reboot driver dts node
++  * SAUCE: (no-up) Add documentation for generic SYSCON reboot driver.
++  * SAUCE: (no-up) Select reboot driver for X-Gene platform.
++
++  [ Iyappan Subramanian ]
++
++  * SAUCE: (no-up) MAINTAINERS: Add entry for APM X-Gene SoC ethernet driver
++  * SAUCE: (no-up) Documentation: dts: Add bindings for APM X-Gene SoC ethernet driver
++  * SAUCE: (no-up) dts: Add bindings for APM X-Gene SoC ethernet driver
++  * SAUCE: (no-up) drivers: net: Add APM X-Gene SoC ethernet driver support.
++
++  [ Tim Gardner ]
++
++  * updateconfigs
++  * Fix arm64 crypto Makefile
++  * [Config] CONFIG_BOOKE_WDT=n for FTBS
++  * [Debian] Add UTS_UBUNTU_RELEASE_ABI to utsrelease.h
++    - LP: #1327619
++  * Disabled powerpc64-emb for FTBS
++  * [Config] CONFIG_DRM_TEGRA=m
++  * [Config] CONFIG_CMA_SIZE_MBYTES=64
++  * rebase to v3.16-rc2
++  * Clean up generic.inclusion-list warnings
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.16-rc2
++    - LP: #1328587
++    - LP: #1319291
++    - LP: #1310512
++    - LP: #1310512
++    - LP: #1305480
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 12 Jun 2014 12:26:09 +0000
++
++linux (3.15.0-6.11) utopic; urgency=low
++
++  [ Adam Conrad ]
++
++  * Enable building the sata-modules udeb on ppc64el.
++    - LP: #1323980
++  * [Packaging] Set bootloader and loader on ppc64el to grub
++
++  [ Adam Lee ]
++
++  * SAUCE: (no-up) rtlwifi: rtl8723be: disable MSI interrupts mode
++    - LP: #1310512, #1320070
++
++  [ Alex Hung ]
++
++  * SAUCE: (no-up) dell-led: add mic mute led interface
++    - LP: #1308297
++
++  [ Andy Whitcroft ]
++
++  * [Config] d-i -- add hyperv_keyboard to serial-modules udeb
++    - LP: #1285434
++  * [Config] tools -- enable cpupower on ppc64el
++  * [Config] ppc64el -- enable perf tools
++  * [Config] powerpc -- enable perf tools
++  * [Config] ppc64el -- reduce MAX_ORDER with 64k pages
++  * [Config] arm64 -- enable tools
++    - LP: #1326050
++  * [Config] switch hyper-keyboard to virtual
++    - LP: #1325306
++  * [Config] fix up Breaks/Replaces on linux-cloud-tools-common to fix
++    upgrades
++  * SAUCE: kvm: BIOS disabled kvm support should be a warning
++    - LP: #1300247
++  * SAUCE: nouveau: missing outputs should be warnings
++    - LP: #1300244
++  * [Config] d-i -- add nvme devices to block-modules udeb
++    - LP: #1303710
++
++  [ Anton Blanchard ]
++
++  * SAUCE: (no-up) powerpc: 64bit sendfile is capped at 2GB
++    - LP: #1328230
++
++  [ Colin Ian King ]
++
++  * SAUCE: intel_pstate: inform user that thermald is worth considering
++
++  [ Dave Chiluk ]
++
++  * [Config] Enable CONFIG_IP_VS_IPV6=y
++    - LP: #1300739
++
++  [ Paolo Pisati ]
++
++  * [Config] build vexpress a9 dtb
++    - LP: #1303657
++
++  [ Tetsuo Handa ]
++
++  * SAUCE: kthread: Do not leave kthread_create() immediately upon SIGKILL.
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1329045
++  * [Debian] Treat vdso install as an environment variable
++    - LP: #1325713
++  * [Config] Treat vdso install as an environment variable
++    - LP: #1325713
++  * [config] Set IPMI suppoort default to "y"
++  * [Config] powerpc -- CONFIG_SCSI_IBMVSCSI=y
++  * [Config] CONFIG_RT_GROUP_SCHED=n
++    - LP: #1284731
++  * [Config] ppc64el -- switch to 64K system pages
++  * [Config] CONFIG_MICROCODE_EARLY=y
++  * [Config] SND_DAVINCI_SOC && SND_AM33XX_SOC_EVM =m
++  * [Config] armhf: DRM_TILCDC=m
++  * SAUCE: (no-up) mei_me: Add module parameter to disable MSI
++  * [Config] arm64: KVM=y
++  * [Config] armhf: LEDS_TRIGGER_HEARTBEAT=y
++  * [Config] armhf: generic: disable CPU_IDLE
++  * [Config] armhf: CPU_FREQ=y
++  * [Config] Add new mlx modules to d-i
++  * [Config] Added Muti-Arch support for linux-headers-PKGVER-ABINUM, linux-tools-common, and linux-cloud-tools-common
++    - LP: #1295112
++  * [Config] CONFIG_EXYNOS_ADC=n, CONFIG_HW_RANDOM_EXYNOS=n, CONFIG_MMC_DW_EXYNOS=n, CONFIG_USB_DWC3_EXYNOS=n
++    - LP: #1294353
++  * [Config] CONFIG_ABX500_CORE=y for ppc64el
++  * [Config] CONFIG_ALX=m for powerpc
++  * [Config] CONFIG_ACENIC_OMIT_TIGON_I=n for ppc64el
++  * [Config] CONFIG_ACORN_PARTITION_*=n for ppc64el
++  * [Config] CONFIG_ANDROID=n for powerpc
++  * [Config] CONFIG_ASYNC_RAID6_TEST=m for ppc64el
++  * [Config] CONFIG_BIG_KEYS=y for ppc64el
++  * [Config] CONFIG_BSD_PROCESS_ACCT=y for ppc64el
++  * rebase to v3.15
++  * [Config] CONFIG_PHY_XGENE=y
++  * [Config] CONFIG_MLX4_DEBUG=y
++    - LP: #1328256
++  * [Config] CONFIG_POWERNV_CPUFREQ=y for powerpc, ppc64el
++    - LP: #1324571
++  * [Config] CONFIG_BLK_DEV_SR_VENDOR=n for ppc64el
++  * [Config] CONFIG_CFG80211=m for ppc64el
++  * [Config] CONFIG_CHARGER_BQ24190=m for powerpc
++  * [Config] CONFIG_CHARGER_BQ24735=m for powerpc
++  * [Config] CONFIG_EXPERT=y for ppc64el
++  * [Config] CONFIG_ATA_SFF=y on ppc64el
++  * [Config] CONFIG_ATA_GENERIC=y for ppc64el, powerpc
++  * [Config] CONFIG_CHR_DEV_ST=m for ppc64el
++  * [Config] CONFIG_CHECKPOINT_RESTORE=y for ppc64el
++  * [Config] CONFIG_CHELSIO_T1_1G=y for ppc64el
++  * [Config] CONFIG_CHR_DEV_OSST=m for ppc64el
++  * [Config] CONFIG_CHR_DEV_SCH=m for ppc64el
++  * [Config] CONFIG_CPU_FREQ_STAT=y for powerpc
++  * [Config] CONFIG_DDR=y for ppc64el
++  * [Config] CONFIG_DEBUG_BUGVERBOSE=y for powerpc
++  * [Config] CONFIG_E100=m, CONFIG_E1000=m, CONFIG_E1000E=m for ppc64el
++  * [Config] CONFIG_EZX_PCAP=n for all arches
++  * [Config] CONFIG_DYNAMIC_DEBUG=y for powerpc
++  * [Config] CONFIG_ENABLE_MUST_CHECK=n for ppc64el
++  * [Config] CONFIG_ENABLE_WARN_DEPRECATED=n for ppc64el
++  * [Config] CONFIG_FB_3DFX=m for all arches
++  * [Config] CONFIG_FB_MATROX=m for ppc64el
++  * [Config] CONFIG_FB_RADEON=m for ppc64el
++  * [Config] CONFIG_FB_SAVAGE_I2C=y for all arches
++  * [Config] CONFIG_FIREWIRE=m for ppc64el
++  * [Config] CONFIG_FTR_FIXUP_SELFTEST=n for ppc64el
++  * [Config] CONFIG_HAMRADIO=y for ppc64el
++  * [Config] CONFIG_I2C_CHARDEV=m for ppc64el
++  * [Config] CONFIG_I2C_MUX=m for ppc64el
++  * [Config] CONFIG_I2C_STUB=m for ppc64el
++  * [Config] CONFIG_I2O=m for ppc64el
++  * [Config] CONFIG_INET_XFRM_MODE_BEET=m, CONFIG_INET_XFRM_MODE_TRANSPORT=m, CONFIG_INET_XFRM_MODE_TUNNEL=m for ppc64el
++  * [Config] CONFIG_INFINIBAND_IPOIB_DEBUG=n, CONFIG_INFINIBAND_MTHCA_DEBUG=n for ppc64el
++  * [Config] CONFIG_INFINIBAND_NES=m, CONFIG_INFINIBAND_OCRDMA=m, CONFIG_INFINIBAND_QIB=m for ppc64el
++  * [Config] CONFIG_INPUT_FF_MEMLESS=m for ppc64el
++  * [Config] CONFIG_INTERVAL_TREE_TEST=m for ppc64el
++  * [Config] CONFIG_IPACK_BUS=m for ppc64el
++  * [Config] CONFIG_ISDN=y for ppc64el
++  * [Config] CONFIG_ISO9660_FS=m for ppc64el
++  * [Config] CONFIG_KGDB=y for ppc64el
++  * [Config] CONFIG_KVM_GUEST=y for ppc64el
++  * [Config] CONFIG_L2TP_V3=y for powerpc
++  * [Config] CONFIG_MAILBOX=y for ppc64el
++  * [Config] CONFIG_MD_LINEAR=m, CONFIG_MD_RAID0=m, CONFIG_MD_RAID1=m for ppc64el
++  * [Config] CONFIG_MEDIA_SUPPORT=m for ppc64el
++  * [Config] CONFIG_MEMORY=y for ppc64el
++  * [Config] CONFIG_MEMSTICK=m for ppc64el
++  * [Config] CONFIG_MFD_SM501_GPIO=n for ppc64el
++  * [Config] CONFIG_MMC_BLOCK=m for ppc64el
++  * [Config] CONFIG_MOUSE_PS2=m for ppc64el
++  * [Config] CONFIG_NET_9P=m for ppc64el
++  * [Config] CONFIG_MSDOS_FS=m for ppc64el
++  * [Config] CONFIG_MSI_BITMAP_SELFTEST=n for ppc64el
++  * [Config] CONFIG_MTD=m for arm64
++  * [Config] CONFIG_NETCONSOLE=m for ppc64el
++  * [Config] CONFIG_NETFILTER_XT_TARGET_NOTRACK=m for ppc64el
++  * [Config] CONFIG_NET_IPIP=m for ppc64el
++  * [Config] CONFIG_NET_TEAM=m for all arches
++  * [Config] CONFIG_NFC=m for ppc64el
++  * [Config] CONFIG_NL80211_TESTMODE=n for all arches
++  * [Config] CONFIG_NLS_CODEPAGE_437=y for powerpc
++  * [Config] CONFIG_NLS_ASCII=m, CONFIG_NLS_ISO8859_1=m, CONFIG_NLS_UTF8=m for ppc64el
++  * [Config] CONFIG_NOP_USB_XCEIV=m for ppc64el
++  * [Config] CONFIG_NOTIFIER_ERROR_INJECTION=m for ppc64el
++  * [Config] CONFIG_OPROFILE=m for ppc64el
++  * [Config] CONFIG_PARPORT_1284=y for ppc64el
++  * [Config] CONFIG_PARPORT_AX88796=m, CONFIG_PARPORT_PC_FIFO=y, CONFIG_PARPORT_SERIAL=m for ppc64el
++  * [Config] CONFIG_8723AU_P2P=n
++  * [Config] CONFIG_PCI_IOV=y, CONFIG_PCI_PASID=y, CONFIG_PCI_PRI=y, CONFIG_PCI_REALLOC_ENABLE_AUTO=y, CONFIG_PCI_STUB=m for ppc64el
++  * [Config] CONFIG_PCNET32=m for ppc64el
++  * [Config] CONFIG_SCSI_DH_EMC=m for ppc64el
++  * [Config] CONFIG_SCSI_DH_HP_SW=m for ppc64el
++  * [Config] CONFIG_SCSI_FC_ATTRS=m for ppc64el
++  * [Config] CONFIG_SCSI_IPR=m for ppc64el
++  * [Config] CONFIG_SCSI_LOGGING=y for ppc64el
++  * [Config] CONFIG_SCSI_OSD_INITIATOR=m for ppc64el
++  * [Config] CONFIG_SCSI_SCAN_ASYNC=y for ppc64el
++  * [Config] CONFIG_SCSI_SYM53C8XX_2=m for ppc64el
++  * [Config] CONFIG_XILINX_LL_TEMAC=m for powerpc
++  * [Config] CONFIG_WQ_POWER_EFFICIENT_DEFAULT=y for ppc64el
++  * [Config] CONFIG_WLAN=y for arm64
++  * [Config] CONFIG_VORTEX=m for ppc64el
++  * [Config] CONFIG_WIMAX=m for ppc64el
++  * [Config] CONFIG_WATCHDOG=y for ppc64el
++  * [Config] CONFIG_VIRT_DRIVERS=y for ppc64el
++  * [Config] CONFIG_VERSION_SIGNATURE="" for powerpc64-emb
++  * [Config] CONFIG_UWB=m for ppc64el
++  * [Config] CONFIG_USB_STORAGE=y
++  * [Config] CONFIG_SATA_AHCI_PLATFORM=y for armhf
++  * [Config] CONFIG_HID_RMI=m
++  * [Config] CONFIG_HVC_DCC=n
++    - LP: #1303657
++
++  [ Upstream Kernel Changes ]
++
++  * mm/numa: Remove BUG_ON() in __handle_mm_fault()
++    - LP: #1323165
++  * powerpc/powernv: Add calls to support little endian host
++    - LP: #1327400
++  * HID: rmi: introduce RMI driver for Synaptics touchpads
++  * HID: rmi: do not stop the device at the end of probe
++  * HID: rmi: check for the existence of some optional queries before reading query 12
++  * HID: rmi: do not fetch more than 16 bytes in a query
++  * HID: rmi: fix wrong struct field name
++  * HID: rmi: fix masks for x and w_x data
++  * HID: rmi: do not handle touchscreens through hid-rmi
++  * ALSA: pcm: 'BUG:' message unnecessarily triggers kerneloops
++    - LP: #1305480
++  * rebase to v3.15
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 03 Jun 2014 17:02:49 +0000
++
++linux (3.15.0-5.10) utopic; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1325596
++  * [Config] CONFIG_POWERNV_CPUFREQ=y for ppc64el
++  * rebase to v3.15-rc8
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.15-rc8
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 02 Jun 2014 12:59:34 +0000
++
++linux (3.15.0-4.9) utopic; urgency=low
++
++  * no change rebuild to fix embeded debhelper.
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 29 May 2014 12:41:58 +0100
++
++linux (3.15.0-4.8) utopic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Release Tracking Bug
++    - LP: #1324107
++  * [Config] enable SECURITY_APPARMOR_UNCONFINED_INIT
++
++  [ Javier Martinez Canillas ]
++
++  * SAUCE: (no-up) apparmor: fix bug that constantly spam the console
++    - LP: #1323526
++
++  [ John Johansen ]
++
++  * SAUCE: (no-up) apparmor: Sync to apparmor3 - alpha6 snapshot
++    - LP: #1323528
++  * SAUCE: (no-up) apparmor: fix apparmor spams log with warning message
++    - LP: #1308761
++  * SAUCE: (no-up) apparmor: fix refcount bug in apparmor pivotroot
++    - LP: #1308765
++  * SAUCE: (no-up): apparmor: fix apparmor refcount bug in apparmor_kill
++    - LP: #1308764
++  * SAUCE: (no-up): apparmor: use custom write_is_locked macro
++    - LP: #1323530
++
++  [ Kamal Mostafa ]
++
++  * [Config] add debian/gbp.conf
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_SATA_AHCI=m for ppc64el
++    - LP: #1323980
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 28 May 2014 12:47:17 +0100
++
++linux (3.15.0-3.7) utopic; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1323189
++
++  [ Andy Whitcroft ]
++
++  * [Config] autopkgtest -- need fakeroot for tests
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.15-rc7
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 26 May 2014 08:12:50 +0200
++
++linux (3.15.0-2.6) utopic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] remove the kernel-image firmware list on clean
++
++  [ Martin Pitt ]
++
++  * [Config] autopkgtest -- switch to significantly faster rebuild
++
++  [ Stefan Bader ]
++
++  * [Config]: Add missing modules to inclusion list
++
++  [ Tim Gardner ]
++
++  * [debian] Dynamically generate the kernel-image udebs firmware list
++  * [d-i] firmware/kernel-image is generated
++  * rebase to v3.15-rc6
++  * Release Tracking Bug
++    - LP: #1322251
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.15-rc6
++    - LP: #1297581
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 21 May 2014 10:51:29 -0700
++
++linux (3.15.0-1.5) utopic; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Add apm-mustang.dtb to kernel-image udeb
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 19 May 2014 14:47:42 -0700
++
++linux (3.15.0-1.4) utopic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: (no-up) hv -- bodge hv_vss_daemon so it can use the
++    local linux/hyperv.h"
++  * Revert "SAUCE: (no-up) hv -- bodge hv_kvp_daemon so it can use the
++    local linux/hyperv.h"
++  * [Packaging] tools -- hv tools build correctly against the built headers
++  * [Packaging] cloud-tools -- add the hv_fcopy_daemon to the package
++  * cloud-tools -- pull in init scripts for Hyper-V daemons
++  * cloud-tools -- detect Hyper-V VM to avoid starting
++  * cloud-tools -- update IF_NAME to DEVICE in hv_* scripts
++    - LP: #1295401
++  * [Config] cloud-tools: reenable cloud-tools
++
++ -- Andy Whitcroft <apw@canonical.com>  Sun, 18 May 2014 19:21:04 +0100
++
++linux (3.15.0-1.3) utopic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] ppc64el is a powerpc kernel arch and needs its quirks
++    - LP: #1318848
++
++  [ Ben Collins ]
++
++  * [Config] Switch to grub-ieee1275 as recommended on book3e systems
++    - LP: #1318629
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_FSL_PAMU=n
++    - LP: #1311738
++  * Release Tracking Bug
++    - LP: #1320239
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 16 May 2014 07:37:07 -0600
++
++linux (3.15.0-1.2) utopic; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1318171
++  * Add rpcsec_gss_krb5 to generic inclusion list
++    - LP: #769527
++  * rebase to v3.15-rc5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.15-rc5
++    - LP: #1297581
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 06 May 2014 15:20:10 -0500
++
++linux (3.15.0-0.1) utopic; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.15-rc4
++    - LP: #1297581
++    - LP: #1297581
++    - LP: #1305133
++    - LP: #1297581
++    - LP: #1297581
++    - LP: #871808
++    - LP: #1260303
++    - LP: #1268468
++    - LP: #1248116
++    - LP: #1211920
++    - LP: #1259790
++    - LP: #1259437
++    - LP: #1259435
++    - LP: #1268468
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 07 Feb 2014 09:35:13 -0700
++
++linux (3.15.0-0.0) utopic; urgency=low
++
++  * Initial version for 3.15.
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 02 May 2014 15:06:39 +0100
++
++linux (3.13.0-8.27) trusty; urgency=low
++
++  [ John Johansen ]
++
++  * SAUCE: Add config option to disable new apparmor 3 semantics
++    -LP: #1270215
++
++  [ Tim Gardner ]
++
++  * [debian] Fix indep_hdrs_pkg_name
++    - LP: #1134441
++  * Update lttng to 00808267d3ba7cdcddfed7bec7e62a40463c1307 Version 2.4.0-rc3
++  * Enabled lttng build
++  * Don't build lttng for armhf
++    lttng hates gcc-4.8 for armhf
++  * Release Tracking Bug
++    - LP: #1277309
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.13.2
++    - LP: #1260303
++    - LP: #1260303
++    - LP: #1268468
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 06 Feb 2014 09:25:51 -0700
++
++linux (3.13.0-7.26) trusty; urgency=low
++
++  [ John Johansen ]
++
++  * SAUCE: apparmor: fix uninitialized lsm_audit membe
++    - LP: #1268727
++  * Add config option to optionally enable new apparmor 3 semantics
++
++  [ Tim Gardner ]
++
++  * [Config] Add lowlatency to getabis
++  * [Config] CONFIG_SECURITY_APPARMOR_AA3_SEMANTICS=y
++    - LP: #1270215
++  * Release Tracking Bug
++    - LP: #1276810
++
++  [ Upstream Kernel Changes ]
++
++  * x86, x32: Correct invalid use of user timespec in the kernel
++    - LP: #1274349
++    - CVE-2014-0038
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 05 Feb 2014 15:49:44 -0500
++
++linux (3.13.0-7.25) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: fix fmd headers"
++  * SAUCE: fix fmd headers
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 04 Feb 2014 09:36:09 +0000
++
++linux (3.13.0-7.24) trusty; urgency=low
++
++  [ Stefan Bader ]
++
++  * [Config] Make vmwgfx driver enable the framebuffer device
++
++  [ Tim Gardner ]
++
++  * rebase to v3.13.1
++  * [Config] CONFIG_NFS_FS=m for ppc64el
++  * [Config] CONFIG_X86_SYSFB=n
++    https://lists.ubuntu.com/archives/kernel-team/2014-February/038166.html
++  * Release Tracking Bug
++    - LP: #1275898
++
++  [ Upstream Kernel Changes ]
++
++  * i2c: piix4: Add support for AMD ML and CZ SMBus changes
++    - LP: #1272525
++  * i2c: piix4: Use different message for AMD Auxiliary SMBus Controller
++    - LP: #1272525
++  * mm: ignore VM_SOFTDIRTY on VMA merging
++    - LP: #1274917
++  * drm/radeon: disable dpm on BTC
++    - LP: #1266984
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.13.1
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 30 Jan 2014 15:24:48 +0000
++
++linux (3.13.0-6.23) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] fix up architecture for linux-tools
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 30 Jan 2014 09:00:41 +0000
++
++linux (3.13.0-6.22) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] limit linux-udebs-<flavour> to matching arch
++  * [Config] powerpc -- disable perf to fix FTBFS
++  * [Config] ppc64el -- fix up missing udebs
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 29 Jan 2014 16:00:28 +0000
++
++linux (3.13.0-6.21) trusty; urgency=low
++
++  [ Andy Fleming ]
++
++  * SAUCE: net: Add support for handling queueing in hardware
++  * SAUCE: of_mdio: Add of_phy_attach function
++  * SAUCE: phylib: Add generic 10G driver
++  * SAUCE: phylib: Support attaching to gen10g_driver
++  * SAUCE: phylib: Add Clause 45 read/write functions
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: fix fmd headers
++  * [Packaging] lowlatency -- merge out of tree flavours
++  * SAUCE: allow IRQs to be irq-threaded by default via config
++  * [Config]: enable CONFIG_IRQ_FORCED_THREADING_DEFAULT for lowlatency
++  * [Config] powerpc -- fix up Build-depends:
++  * Release Tracking Bug
++    - LP: #1273747
++
++  [ Ben Collins ]
++
++  * SAUCE: PPC: PCI: Fix pcibios_io_space_offset() so it works for 32-bit
++    ptr/64-bit rsrcs
++  * SAUCE: Revert "phy: vitesse make vsc824x_add_skew static"
++  * SAUCE: Fixup freescale usb phy driver to work on ppc64
++  * SAUCE: xgmac_mdio: Silence read errors
++  * SAUCE: Provide booke stub for kvmppc_is_bigendian()
++  * SAUCE: Fix stack overflow on ppc32
++  * SAUCE: Use resource_size_t instead of long for PCI resource address
++  * SAUCE: net/phy: Export function for use by dpaa_eth
++  * [Packaging] powerpc -- merge out of tree powerpc arch
++
++  [ Bjorn Helgaas ]
++
++  * SAUCE: Revert "EISA: Log device resources in dmesg"
++    - LP: #1251816
++  * SAUCE: Revert "EISA: Initialize device before its resources"
++    - LP: #1251816
++
++  [ Emil Medve ]
++
++  * SAUCE: phylib: Minimum hack to get the generic 10G PHY driver to work
++    with 10G "fixed-link"s
++
++  [ Kumar Gala ]
++
++  * SAUCE: fsl_qbman: Add drivers for Freescale DPAA Qman & Bman
++  * SAUCE: fsl_pme2: Add support for DPAA PME
++  * SAUCE: fmd: FMD14 integration
++  * SAUCE: dpaa_eth: Ethernet driver for Freescale QorIQ DPA Architecture
++  * SAUCE: powerpc/85xx: Add DPAA/networking support for CoreNet
++
++  [ Madalin Bucur ]
++
++  * SAUCE: net/flow: remove sleeping and deferral mechanism from
++    flow_cache_flush
++  * SAUCE: net/phy: abort genphy_read_status when link changes during speed
++    and duplex reading
++
++  [ Stefan Bader ]
++
++  * [Config] move some VMWare related modules into main package
++    - LP: #1271669
++
++  [ Tim Gardner ]
++
++  * [Config] Add r815x to nic-modules
++    - LP: #1273735
++  * [Config] CONFIG_FRAMEBUFFER_CONSOLE_ROTATION=y
++    - LP: #239479
++
++  [ Upstream Kernel Changes ]
++
++  * mmc: sdhci-pci: break out definitions to header file
++    - LP: #1239938
++  * mmc: sdhci-pci: add support of O2Micro/BayHubTech SD hosts
++    - LP: #1239938
++  * powerpc/book3e: rename interrupt_end_book3e with __end_interrupts
++  * powerpc/book3e: support CONFIG_RELOCATABLE
++  * book3e/kexec/kdump: enable kexec for kernel
++  * book3e/kexec/kdump: create a 1:1 TLB mapping
++  * book3e/kexec/kdump: introduce a kexec kernel flag
++  * book3e/kexec/kdump: implement ppc64 kexec specfic
++  * book3e/kexec/kdump: redefine VIRT_PHYS_OFFSET
++  * book3e/kexec/kdump: recover "r4 = 0" to create the initial TLB
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 28 Jan 2014 22:59:46 +0000
++
++linux (3.13.0-5.20) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] tools -- do not make symlinks when not making packages
++  * [Packaging] tools -- tidy up control.stub.in ordering
++  * [Packaging] tools -- tools-common is shared and not conditional
++  * rebase to v3.13
++
++  [ Dirk Brandewie ]
++
++  * SAUCE: intel_pstate: Add setting voltage value for baytrail P states.
++
++  [ KY Srinivasan ]
++
++  * SAUCE: Drivers: hv: vmbus: Specify the target CPU that should receive
++    notification
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.13
++   - LP: #1270603
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 17 Jan 2014 15:45:31 +0000
++
++linux (3.13.0-4.19) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] libunwind8-dev is now available for ppc64el
++  * [Packaging] tools -- make cpupower optional
++  * [Packaging] tools -- enable correctly for x86
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1269872
++
++  [ Upstream Kernel Changes ]
++
++  * SAUCE: ARM: OMAP: hwmod: Add SYSC offsets for AES IP
++  * SAUCE: ARM: OMAP4: hwmod: Add hwmod data for AES IP
++  * SAUCE: OMAP: AM33xx: hwmod: Correct AES module SYSC type
++  * SAUCE: crypto: omap-aes: add error check for pm_runtime_get_sync
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to 85ce70fdf48aa290b4845311c2dd815d7f8d1fa5
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 15 Jan 2014 13:23:05 +0000
++
++linux (3.13.0-3.18) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.13-rc8
++  * [Packaging] efi -- allow EFI signatures on any arch
++
++  [ Tim Gardner ]
++
++  * [Config] Fix vcs-git path
++  * Release Tracking Bug
++    - LP: #1268683
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.13-rc8
++
++ -- Andy Whitcroft <apw@canonical.com>  Sun, 12 Jan 2014 11:58:01 +0000
++
++linux (3.13.0-2.17) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Release Tracking Bug
++    - LP: #1267809
++  * [Config] apply Platform support>>CPUIdle driver>>CPU Idle config
++    defaults
++  * [Config] apply Platform support>>CPU Frequency scaling config defaults
++  * [Config] CONFIG_PARIDE_EPATC8=y
++  * [Config] apply Device Drivers >> Broadcom specific AMBA config defaults
++  * [Config] apply Bus options >> PCI support >> RapidIO support >> RapidIO
++    Switch drivers config defaults
++  * [Config] apply Cryptographic API config defaults
++  * [Config] apply Device Drivers >> Common Clock Framework config defaults
++  * [Config] apply Device Drivers >> Distributed Switch Architecture
++    drivers config defaults
++  * [Config] apply Device Drivers >> Graphics support >> Backlight & LCD
++    device support config defaults
++  * [Config] apply Device Drivers >> Graphics support >> Support for frame
++    buffer devices >> Bootup logo config defaults
++  * annotations -- update in tree annotations
++  * [Config] apply Bus options >> PCI support >> RapidIO support config
++    defaults
++  * [Config] CONFIG_POWER_AVS=y CONFIG_RESET_CONTROLLER=y
++  * [Config] apply Device Drivers >> 1-wire Bus Masters config defaults
++  * [Config] apply CAN Device Drivers >> Platform CAN drivers with Netlink
++    support config defaults
++  * [Config] apply Device Drivers >> Character devices >> Serial drivers
++    config defaults
++  * [Config] apply Device Drivers >> Generic Thermal sysfs driver config
++    defaults
++  * [Config] apply Device Drivers >> Character devices >> TPM Hardware
++    Support config defaults
++  * [Config] apply Device Drivers >> Character devices config defaults
++  * [Config] apply Device Drivers >> HID support >> USB HID support >> USB
++    HID transport layer config defaults
++  * [Config] apply Device Drivers >> HID support >> HID bus support config
++    defaults
++  * [Config] apply Device Drivers >> HID support >> USB HID support config
++    defaults
++  * annotations -- update in tree annotations
++  * [Config] apply Device Drivers >> GPIO Support config defaults
++  * [Config] update configs for apparmour update
++
++  [ John Johansen ]
++
++  * SAUCE: (no-up) apparmor: Sync to apparmor 3 - alpha 4 snapshot
++  * SAUCE: apparmor: fix unix domain sockets to be mediated on connection
++    - LP: #1208988
++  * SAUCE: apparmor: allocate path lookup buffers during init
++    - LP: #1208988
++  * SAUCE: (no-up) apparmor: Fix tasks not subject to, reloaded policy
++    - LP: #1236455
++
++  [ Tim Gardner ]
++
++  * Revert "[Debian] getabis: Preface module with package name"
++  * [Config] Added ppc64el to getabis
++  * [packaging] Bump ABI for every new release
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 10 Jan 2014 11:48:39 +0000
++
++linux (3.13.0-1.16) trusty; urgency=low
++
++  * First 3.13 upload.
++  * Release tracker
++    - LP: #1266852
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 07 Jan 2014 09:21:26 -0700
++
++linux (3.13.0-0.15) trusty; urgency=low
++
++  [ Tim Gardner ]
++
++  * rebase to v3.13-rc7
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.13-rc7
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Sun, 05 Jan 2014 06:13:33 -0700
++
++linux (3.13.0-0.14) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to 7a262d2ed9fa42fad8c4f243f8025580b58cf2f6
++
++  [ Tim Gardner ]
++
++  * Remove ubuntu/dm-raid4-5 in favor of CONFIG_MD_RAID456
++  * Update lttng to Version 2.4.0-rc2
++  * lttng: Disabled trace_kvm_async_pf_completed
++  * [Config] CONFIG_IMA=y
++    - LP: #1244627
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to 7a262d2ed9fa42fad8c4f243f8025580b58cf2f6
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 02 Jan 2014 12:57:13 -0700
++
++linux (3.13.0-0.13) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: aufs3 -- (no-up) aufs3-base.patch
++  * ubuntu: aufs3 -- (no-up) aufs3-mmap.patch
++  * ubuntu: aufs3 -- (no-up) aufs3-standalone.patch
++  * ubuntu: AUFS (no-squash): basic framework and update machinary
++  * ubuntu: AUFS -- update to 7b136a27b021da9010d8b6c101939dd298e46be7
++  * ubuntu: aufs3 -- enable
++  * ubuntu: aufs3 -- update configs
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 02 Jan 2014 09:41:02 +0000
++
++linux (3.13.0-0.12) trusty; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.13-rc6
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 31 Dec 2013 06:16:03 -0700
++
++linux (3.13.0-0.11) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: suspicious unlocked ->status reading and writing in ipc/sem.c
++  * [Config] ppc64el -- initial defconfig based -generic flavour
++  * [Config] initial defconfig for ppc64el
++  * [Config] ubuntuise ppc64el config
++  * [Config] ubuntuise ppc64el config part 2
++  * [Config] d-i -- update empty udebs list
++  * [Config] ppc64el -- split extras package
++
++  [ Anton Blanchard ]
++
++  * SAUCE: KVM: PPC: Book3S HV: Add little-endian guest support
++
++  [ Benjamin Herrenschmidt ]
++
++  * SAUCE: powerpc/powernv: Add calls to support little endian
++
++  [ Cédric Le Goater ]
++
++  * SAUCE: KVM: PPC: Book3S: add helper routine to load guest instructions
++  * SAUCE: KVM: PPC: Book3S: add helper routines to detect endian order
++  * SAUCE: KVM: PPC: Book3S: MMIO emulation support for little endian
++    guests
++
++  [ Paul E. McKenney ]
++
++  * SAUCE: powerpc: Make 64-bit non-VMX copy_tofrom_user() bi-endian
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 27 Dec 2013 16:48:55 +0000
++
++linux (3.13.0-0.10) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.13-rc5
++  * [Config] updateconfigs following rebase to v3.13-rc5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.13-rc5
++    - LP: #1260303
++    - LP: #1260303
++    - LP: #1260225
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 23 Dec 2013 12:48:28 +0000
++
++linux (3.13.0-0.9) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] d-i -- allow missing firmware
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 20 Dec 2013 17:57:06 +0000
++
++linux (3.13.0-0.8) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] annotations -- first pass over entire config
++  * [Config] drop libunwind8-dev from Build-Depends for ppc64el
++
++  [ Tim Gardner ]
++
++  * [Config] Add arm64 device tree files
++    - LP: #1262901
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 19 Dec 2013 18:36:43 +0000
++
++linux (3.13.0-0.7) trusty; urgency=low
++
++  [ Rajesh B Prathipati ]
++
++  * SAUCE: powerpc: Make unaligned accesses endian-safe for powerpc
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_REGULATOR_S2MPS11=n for FTBS
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.13-rc4
++    - LP: #1259790
++    - LP: #1259437
++    - LP: #1259435
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 13 Dec 2013 07:56:34 -0700
++
++linux (3.13.0-0.6) trusty; urgency=low
++
++  [ Paolo Pisati ]
++
++  * [Config] armhf: arm64: VIRTIO_[BLK|MMIO|NET|CONSOLE|BALLOON]=y
++  * [Config] i386: amd64: VIRTIO_CONSOLE=y
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS=y
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Sun, 08 Dec 2013 09:22:01 -0700
++
++linux (3.13.0-0.5) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * correct bug listing for v3.13-rc2 rebase
++  * [Config] ppc64el -- create linux-libc-dev
++  * [Debian] Improve tools version message
++    - LP: #1257715
++
++  [ Serge Hallyn ]
++
++  * SAUCE: fork: Allow CLONE_PARENT after setns(CLONE_NEWPID)]
++    - LP: #1248590
++  * SAUCE: vfs: Fix a regression in mounting proc
++
++  [ Tim Gardner ]
++
++  * [Config] Build-in ohci-pci
++    - LP: #1244176
++  * Rebase to v3.13-rc3
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "Revert "fork: unify and tighten up CLONE_NEWUSER/CLONE_NEWPID
++    checks""
++    - LP: #1248590
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.13-rc3
++    - LP: #1256840
++    - LP: #1256212
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Sat, 07 Dec 2013 07:55:39 -0700
++
++linux (3.13.0-0.4) trusty; urgency=low
++
++  [ Tim Gardner ]
++
++  * Rebase to v3.13-rc2
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.13-rc2
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 29 Nov 2013 23:54:05 -0500
++
++linux (3.13.0-0.3) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: Fix DocBook FTBS"
++
++  [ Tim Gardner ]
++
++  * [Debian] Re-sign modules after debug objcopy
++    - LP: #1253155
++  * [Config] CONFIG_EXT4_USE_FOR_EXT23=y
++
++  [ Upstream Kernel Changes ]
++
++  * doc: fix generation of device-drivers
++  * rebase to b975dc3689fc6a3718ad288ce080924f9cb7e176
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 26 Nov 2013 12:24:42 -0700
++
++linux (3.13.0-0.2) trusty; urgency=low
++
++  [ Tim Gardner ]
++
++  * SAUCE: Fix DocBook FTBS
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 25 Nov 2013 13:24:15 -0700
++
++linux (3.13.0-0.1) trusty; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to 7e3528c3660a2e8602abc7858b0994d611f74bc3
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 12 Nov 2013 07:28:53 -0700
++
++linux (3.13.0-0.0) trusty; urgency=low
++
++  * Major release bump.
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 12 Nov 2013 21:37:52 +0000
++
++linux (3.12.0-2.7) trusty; urgency=low
++
++  * Fixed armhf ABI build failure.
++  * Release tracker
++    - LP: #1249477
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 08 Nov 2013 16:22:45 -0700
++
++linux (3.12.0-2.6) trusty; urgency=low
++
++  [ Joseph Salisbury ]
++
++  * SAUCE: tg3: Add support for new 57786 device id.
++    - LP: #1242610
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_OABI_COMPAT=n
++  * [Config] add the wandboard to shipped dtb
++    - LP: #1249421
++  * Release tracker
++    - LP: #1249477
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 08 Nov 2013 12:23:18 -0700
++
++linux (3.12.0-2.5) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to mainline v3.12
++  * [Config] updateconfigs following rebase to v3.12
++  * postinst -- improve relative symlink detection with missing files
++    - LP: #1248053
++  * postinst -- fix unchanged link detection
++  * [Config] update configs following addition of apparmor fixes
++
++  [ Anthony Wong ]
++
++  * SAUCE: Work around broken ACPI backlight on Dell Inspiron 5537
++    - LP: #1231305
++
++  [ John Johansen ]
++
++  * SAUCE: (no-up) apparmor: Sync to apparmor 3 - alpha 4 snapshot
++  * SAUCE: apparmor: fix unix domain sockets to be mediated on connection
++    - LP: #1208988
++  * SAUCE: apparmor: allocate path lookup buffers during init
++    - LP: #1208988
++
++  [ Tim Gardner ]
++
++  * [Config] Remove superfluous ubuntu/lttng-modules
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "fork: unify and tighten up CLONE_NEWUSER/CLONE_NEWPID checks"
++    - LP: #1248590
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.12
++    - LP: #1222850
++
++  [ Adam Conrad ]
++  * etc/getabis: Fetch arm64/generic abis as well
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 06 Nov 2013 21:00:21 +0000
++
++linux (3.12.0-1.3) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] arm64 -- add arch to the configuration handlers
++  * [Config] arm64 -- add generic flavour
++  * [Config] arm64 -- default config
++  * [Config] arm64 -- fix up various FTBFS config options
++  * SAUCE: arm64: export __copy_in_user to modules
++  * [Config] arm64 -- disable ABI/module checks
++  * [Config] arm64 -- enforcer -- add arm64 to the enforcer
++  * [Config] arm64 -- enable udebs for arm64
++
++  [ Colin Watson ]
++
++  * [Config] Clean up various udeb Provides
++
++  [ Paolo Pisati ]
++
++  * [Config] AHCI_IMX=y
++  * [Config] build imx*-wandboard dtbs
++
++  [ Serge Hallyn ]
++
++  * SAUCE: device_cgroup: remove can_attach
++
++  [ Tim Gardner ]
++
++  * rebase to v3.12-rc7
++  * SAUCE: KVM: Fix modprobe failure for kvm_intel/kvm_amd
++  * Release tracker
++    - LP: #1245932
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.12-rc7
++    - LP: #1180881
++    - LP: #1180881
++    - LP: #1217957
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Sun, 27 Oct 2013 22:08:55 -0600
++
++linux (3.12.0-0.2) trusty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: (no-up) scsi: hyper-v storage -- mark as preferring READ
++    CAPACITY (16) at SPC-2"
++  * Revert "SAUCE: (no-up) scsi: hyper-v storage -- mark as VPD capable at
++    SPC-2"
++  * Revert "SAUCE: (no-up) scsi: add scsi device flag to request READ
++    CAPACITY (16) be preferred"
++  * Revert "SAUCE: (no-up) scsi: add scsi device flag to request VPD pages
++    be used at SPC-2"
++  * Revert "overlayfs: Update to v19"
++  * Revert "ubuntu: overlayfs v18 -- -- overlayfs: implement show_options"
++  * Revert "ubuntu: overlayfs v18 -- -- overlayfs: add statfs support"
++  * Revert "ubuntu: overlayfs v18 -- -- overlay filesystem"
++  * Revert "ubuntu: overlayfs v18 -- -- vfs: introduce
++    clone_private_mount()"
++  * Revert "ubuntu: overlayfs v18 -- -- vfs: export do_splice_direct() to
++    modules"
++  * Revert "ubuntu: overlayfs v18 -- -- overlay: overlay filesystem
++    documentation"
++  * ubuntu: overlayfs v20 -- overlayfs: add statfs support
++  * [Config] fix linux-libc-dev generation for arm64
++  * [Config] fix linux-libc-dev generation for x32
++  * [Config] add linux-libc-dev generation for ppc64el
++
++  [ Erez Zadok ]
++
++  * ubuntu: overlayfs v20 -- overlayfs: implement show_options
++
++  [ Miklos Szeredi ]
++
++  * ubuntu: overlayfs v20 -- vfs: add i_op->dentry_open()
++  * ubuntu: overlayfs v20 -- vfs: export do_splice_direct() to modules
++  * ubuntu: overlayfs v20 -- vfs: export __inode_permission() to modules
++  * ubuntu: overlayfs v20 -- vfs: introduce clone_private_mount()
++  * ubuntu: overlayfs v20 -- overlay filesystem
++  * ubuntu: overlayfs v20 -- fs: limit filesystem stacking depth
++
++  [ Neil Brown ]
++
++  * ubuntu: overlayfs v20 -- overlay: overlay filesystem documentation
++
++  [ Paolo Pisati ]
++
++  * [Config] arm: VIRTIO_[BLK|NET|MMIO]=y
++
++  [ Seth Forshee ]
++
++  * SAUCE: (no-up) ACPI: Disable Windows 8 compatibility for some Lenovo
++    ThinkPads
++    - LP: #1183856
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_CRYPTO_CRCT10DIF=y, CONFIG_CRYPTO_CRCT10DIF_PCLMUL=m
++  * rebase to v3.12-rc2
++  * updateconfigs
++  * [Config] disable CONFIG_FB_VESA enforcer check
++  * [Config] Disable lttng for FTBS
++  * rebase to v3.12-rc3
++  * rebase to v3.12-rc4
++  * [Config] CONFIG_ANDROID=n
++    - LP: #1235161
++  * [Config] CONFIG_L2TP_V3=y
++    - LP: #1235914
++  * [Config] CONFIG_USB_OTG=n for all arches
++  * Release tracker
++    - LP: #1242811
++
++  [ Upstream Kernel Changes ]
++
++  * scsi: hyper-v storsvc switch up to SPC-3
++
++  * rebase to v3.12-rc6
++    - LP: #1235977
++    - LP: #1235523
++    - LP: #1239392
++    - LP: #1227491
++
++  * rebase to v3.12-rc3
++    - LP: #1231931
++
++  * rebase to v3.12-rc2
++    - LP: #1213820
++    - LP: #1213055
++    - LP: #1198030
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 23 Sep 2013 07:41:07 -0600
++
++linux (3.11.0-8.15) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release tracker
++    - LP: #1227969
++
++  * Update lttng
++    Updated to git://git.lttng.org/lttng-modules.git 9998f5216f4641a79e158135
++    Version 2.3.0+
++
++  [ Upstream Kernel Changes ]
++
++  * igb: Add additional get_phy_id call for i354 devices
++    - LP: #1219619
++  * igb: Read flow control for i350 from correct EEPROM section
++    - LP: #1219619
++  * timekeeping: Fix HRTICK related deadlock from ntp lock changes
++    Required for lttng update.
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 19 Sep 2013 07:41:49 -0600
++
++linux (3.11.0-7.14) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] sort out linux-tools naming
++    - LP: #1205284
++  * [Packaging] linux-tools: switch to common generic version helper
++
++  [ Paolo Pisati ]
++
++  * [Config] highbank: ecx1000: CPU_IDLE causes instabilities, disable it
++
++  [ Tim Gardner ]
++
++  * Release tracker
++    - LP: #1226160
++
++  [ Tony Lindgren ]
++
++  * SAUCE: ARM: dts: Fix muxing and regulator for wl12xx on the SDIO bus
++    for pandaboard
++
++  [ Upstream Kernel Changes ]
++
++  * USB: handle LPM errors during device suspend correctly
++    - LP: #1011415
++  * usb: don't check pm qos NO_POWER_OFF flag in usb_port_suspend()
++    - LP: #1011415
++  * usb: Don't fail port power resume on device disconnect.
++    - LP: #1011415
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.11.1
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 11 Sep 2013 07:30:17 -0600
++
++linux (3.11.0-7.13) saucy; urgency=low
++
++  * Release tracker
++    - LP: #1223545
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: (no-up) scsi: add scsi device flag to request VPD pages be used at SPC-2
++    - LP: #1223499
++  * SAUCE: (no-up) scsi: add scsi device flag to request READ CAPACITY (16) be preferred
++    - LP: #1223499
++  * SAUCE: (no-up) scsi: hyper-v storage -- mark as VPD capable at SPC-2
++    - LP: #1223499
++  * SAUCE: (no-up) scsi: hyper-v storage -- mark as preferring READ CAPACITY (16) at SPC-2
++    - LP: #1223499
++
++  [ Maximiliano Curia ]
++
++  * SAUCE: (no-up) Only let characters through when there are active readers.
++    - LP: #1208740
++
++  [ Tim Gardner ]
++
++  * [Debian] getabis: Commit new ABI directory, remove the old
++  * [Config] CONFIG_EFIVAR_FS=y
++    - LP: #1223195
++  * [Config] CONFIG_EFI_VARS_PSTORE=m,
++    CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE=n
++  * SAUCE: (no-up) USB: input: cm109.c: Convert high volume dev_err() to dev_err_ratelimited()
++    - LP: #1222850
++
++  [ Upstream Kernel Changes ]
++
++  * Intel xhci: refactor EHCI/xHCI port switching
++    - LP: #1210858
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 10 Sep 2013 09:00:19 -0600
++
++linux (3.11.0-6.12) saucy; urgency=low
++
++  * Release tracker
++    - LP: #1222893
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch"
++  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-base.patch"
++  * ubuntu: (no-squash) AUFS3 -- aufs3-base.patch
++  * ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch
++    - LP: #1222407
++
++  [ Paolo Pisati ]
++
++  * [Config] restore mmc boot on panda
++
++  [ Tyler Hicks ]
++
++  * SAUCE: apparmor: Use shash crypto API interface for profile hashes
++    - LP: #1216294
++
++  [ Upstream Kernel Changes ]
++
++  * net: calxedaxgmac: remove NETIF_F_FRAGLIST setting
++  * net: calxedaxgmac: read correct field in xgmac_desc_get_buf_len
++  * net: calxedaxgmac: fix race between xgmac_tx_complete and xgmac_tx_err
++  * net: calxedaxgmac: fix possible skb free before tx complete
++  * net: calxedaxgmac: update ring buffer tx_head after barriers
++  * net: calxedaxgmac: fix race with tx queue stop/wake
++  * net: calxedaxgmac: enable interrupts after napi_enable
++  * net: calxedaxgmac: fix various errors in xgmac_set_rx_mode
++  * net: calxedaxgmac: remove some unused statistic counters
++  * net: calxedaxgmac: fix rx DMA mapping API size mismatches
++  * net: calxedaxgmac: fix xgmac_xmit DMA mapping error handling
++  * mfd: rtsx: Read vendor setting from config space
++    - LP: #1201698
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 09 Sep 2013 07:21:06 -0600
++
++linux (3.11.0-5.11) saucy; urgency=low
++
++  * Release tracker
++    - LP: #1221886
++
++  [ Adam Lee ]
++
++  * SAUCE: Bluetooth: Add support for 04ca:2007
++    - LP: #1153448
++  * SAUCE: Bluetooth: Add support for 105b:e065
++    - LP: #1161261
++
++  [ Gavin Guo ]
++
++  * SAUCE: Bluetooth: Add support for Broadcom 413c:8143
++    - LP: #1166113
++
++  [ Upstream Kernel Changes ]
++
++  * igb: Reset the link when EEE setting changed
++    - LP: #1219619
++  * igb: Read register for latch_on without return value
++    - LP: #1219619
++  * igb: Added rcu_lock to avoid race
++    - LP: #1219619
++  * igb: don't allow SR-IOV without MSI-X
++    - LP: #1219619
++  * igb: Update MTU so that it is always at least a standard frame size
++    - LP: #1219619
++  * igb: Refactor of init_nvm_params
++    - LP: #1219619
++  * igb: Refactor NVM read functions to accommodate devices with no flash
++    - LP: #1219619
++  * igb: Add device support for flashless SKU of i210 device
++    - LP: #1219619
++  * igb: Fix get_fw_version function for all parts
++    - LP: #1219619
++  * igb: Add macro for size of RETA indirection table
++    - LP: #1219619
++  * igb: Expose RSS indirection table for ethtool
++    - LP: #1219619
++  * igb: Don't look for a PBA in the iNVM when flashless
++    - LP: #1219619
++  * igb: Implementation of 1-sec delay for i210 devices
++    - LP: #1219619
++  * igb: New PHY_ID for i354 device
++    - LP: #1219619
++  * igb: M88E1543 PHY downshift implementation
++    - LP: #1219619
++  * igb: No PHPM support in i354 devices
++    - LP: #1219619
++  * igb: Support to get 2_5G link status for appropriate media type
++    - LP: #1219619
++  * igb: Get speed and duplex for 1G non_copper devices
++    - LP: #1219619
++  * igb: Implementation to report advertised/supported link on i354 devices
++    - LP: #1219619
++  * igb: Update version number
++    - LP: #1219619
++  * Bluetooth: Take proper tty_struct references
++    - LP: #1189998
++  * Bluetooth: Remove the device from the list in the destructor
++    - LP: #1189998
++  * Bluetooth: Move the tty initialization and cleanup out of open/close
++    - LP: #1189998
++  * Bluetooth: Implement .activate, .shutdown and .carrier_raised methods
++    - LP: #1189998
++  * Bluetooth: Fix the reference counting of tty_port
++    - LP: #1189998
++  * Bluetooth: Purge the dlc->tx_queue to avoid circular dependency
++    - LP: #1189998
++
++  [ Wen-chien Jesse Sung ]
++
++  * SAUCE: Bluetooth: Support for loading broadcom patchram firmware
++    - LP: #1065400
++  * SAUCE: Bluetooth: Add support for 13d3:3388 and 13d3:3389
++    - LP: #1065400
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 05 Sep 2013 08:06:17 -0600
++
++linux (3.11.0-5.10) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Release tracker
++    - LP: #1220222
++  * Revert "[Config] Fix ubuntu directoy Kbuilds"
++  * Revert "aufs update dropped some Kbuild files"
++  * Revert "ubuntu: AUFS -- follow rename of loop.h into drivers/block"
++  * Revert "ubuntu: AUFS -- update to
++    8e503d4142c189ed6c47a2177ad2cd058e8d340e"
++  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch"
++  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-base.patch"
++  * rebase to v3.11 final
++  * [Config] clean up ubuntu/Kconfig and ubuntu/Makefile
++  * ubuntu: AUFS (no-squash): basic framework and update machinary
++  * ubuntu: (no-squash) AUFS3 -- aufs3-base.patch
++  * ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch
++  * ubuntu: AUFS -- update to 5ac5fe26a90a818218310e208d17688fddb07622
++  * ubuntu: (no-squash) AUFS -- enable aufs
++  * ubuntu: AUFS -- fix remaining d_count references to use accessor
++  * ubuntu: lttng -- follow rename of pid_ns
++  * SAUCE: disable stack-protector for ARM compressed bootloader
++
++  [ Paolo Pisati ]
++
++  * [Config] ARM_ATAG_DTB_COMPAT=y
++
++  [ Rob Herring ]
++
++  * [Config] Enable KVM and virtio for armhf generic-lpae
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_ARPD=y
++  * [Config] CONFIG_ZSWAP=y
++    - LP: #1215379
++
++  [ Upstream Kernel Changes ]
++
++  * uvcvideo: quirk PROBE_DEF for Dell SP2008WFP monitor.
++    - LP: #1217957
++  * ARM: use phys_addr_t for DMA zone sizes
++  * ARM: highbank: enable DMA zone for LPAE
++  * ARM: highbank: select ARCH_HAS_HOLES_MEMORYMODEL
++  * ARM: highbank: select required errata work-arounds
++  * DMA: fix AMBA PL08x compilation issue with 64bit DMA address type
++  * DMA: fix printk warning in AMBA PL08x DMA driver
++  * ARM: highbank: select ARCH_DMA_ADDR_T_64BIT for LPAE
++  * ARM: move outer_cache declaration out of ifdef
++  * ARM: highbank: avoid L2 cache smc calls when PL310 is not present
++  * ARM: highbank: clean-up some unused includes
++  * ARM: xen: only set pm function ptrs for Xen guests
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.11
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 03 Sep 2013 17:08:06 +0100
++
++linux (3.11.0-4.9) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * rebase to v3.11-rc7
++  * Release tracker
++    - LP: #1216962
++
++  [ Upstream Kernel Changes ]
++
++  * mwifiex: do not create AP and P2P interfaces upon driver loading
++    - LP: #1212720
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 26 Aug 2013 06:25:35 -0600
++
++linux (3.11.0-3.8) saucy; urgency=low
++
++  [ Johannes Berg ]
++
++  * SAUCE: mac80211: ignore (E)CSA in probe response frames
++    - LP: #1201470
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 23 Aug 2013 09:47:36 -0600
++
++linux (3.11.0-3.7) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * SAUCE: (no-up) hv_vss_daemon -- prevent self-daemonising to allow
++    upstart to track
++  * SAUCE: (no-up) hv -- bodge hv_vss_daemon so it can use the local
++    linux/hyperv.h
++  * SAUCE: hv: Add vss daemon to Makefile
++  * [Debian] Add hv_vss_daemon to tools package
++    - LP: #1213282
++  * [Config] Fix ubuntu directoy Kbuilds
++    - LP: #1181755
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 20 Aug 2013 08:34:05 -0600
++
++linux (3.11.0-3.6) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] tools: conditionalise x86 and hyper-v tools sensibly
++  * [Config] tools: enable x86 and hyper-v
++
++  [ John Johansen ]
++
++  * Revert "SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable
++    snapshot"
++  * Revert "SAUCE: (no-up) apparmor: fix apparmor module status for none
++    root users"
++  * SAUCE: (no-up) apparmor: Sync to apparmor 3 - alpha 4 snapshot
++
++  [ Joseph Salisbury ]
++
++  * SAUCE: (no-up) intel_ips: blacklist ASUSTek G60JX laptops
++    - LP: #1210848
++
++  [ Kamal Mostafa ]
++
++  * [debian] tools: ship 'cpupower' in linux-tools
++    - LP: #1158668
++  * [Config] Build-dep on libpci-dev for cpu tools
++    - LP: #1158668
++
++  [ Tim Gardner ]
++
++  * rebase to v3.11-rc6
++  * Release tracker
++    - LP: #1213941
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 16 Aug 2013 07:02:07 -0600
++
++linux (3.11.0-2.5) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_PM_DEBUG=y
++    - LP: #1210539
++  * rebase to v3.11-rc5
++  * Release tracker
++    - LP: #1211378
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 12 Aug 2013 06:10:39 -0600
++
++linux (3.11.0-1.4) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * Bump ABI when making changes to the inclusion list lest
++    you cause conflicts with existing installed kernel
++    packages.
++    - LP: #1210331
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 09 Aug 2013 03:03:51 +0100
++
++linux (3.11.0-0.3) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Include rbd and kvm in the virtual inclusion list
++    - LP: #1206961
++  * [Config] Removed obsolete inclusion list entries
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 06 Aug 2013 08:52:14 +0100
++
++linux (3.11.0-0.2) saucy; urgency=low
++
++  [ Bruce Allan ]
++
++  * SAUCE: (no-up) e1000e: fix I217/I218 PHY initialization flow
++    - LP: #1206757
++  * SAUCE: (no-up) e1000e: enable support for new device IDs
++    - LP: #1206757
++
++  [ John Johansen ]
++
++  * SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable snapshot
++
++  [ Paolo Pisati ]
++
++  * build vexpress a15 dtb
++  * [Config] disable Broadcom bcm support (ARCH_BCM)
++  * [Config] disable Allwinner a1x support (ARCH_SUNXI)
++  * [Config] disable WonderMedia WM8850 support (ARCH_WM8850)
++  * [Config] disable Rockchip support (ARCH_ROCKCHIP)
++  * [Config] disable STMicroelectronics STiH41x SOCs (ARCH_STI)
++  * [Config] disable TI Keystone, AM43xx and OMAP5 support
++  * [Config] ARM_APPENDED_DTB=y
++
++  [ Tim Gardner ]
++
++  * rebase to v3.11-rc4
++  * overlayfs: Update to v19
++  * [Config] Enable overlayfs
++  * SAUCE: Fix lttng compile errors
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.11-rc4
++    - LP: #1163720
++    - LP: #1162026
++    - LP: #1195636
++    - LP: #1195597
++    - LP: #1180409
++    - LP: #1168430
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Sun, 04 Aug 2013 03:45:31 -0600
++
++linux (3.11.0-0.1) saucy; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to 64ccccf8525fee499625b517c0faadf784c79e93
++    - LP: #1163720
++    - LP: #1162026
++    - LP: #1195636
++    - LP: #1195597
++    - LP: #1180409
++    - LP: #1168430
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 08 Jul 2013 08:50:46 -0600
++
++linux (3.10.0-2.10) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_INTEL_MEI*=m
++    - LP: #1196155
++  * [Config] CONFIG_DEBUG_INFO=y
++
++  [ Stephen Warren ]
++
++  * [Config] fix Calxeda xgmac module filename
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "serial: 8250_pci: add support for another kind of NetMos
++    Technology PCI 9835 Multi-I/O Controller"
++    - LP: #1190967
++  * mfd: lpc_ich: Add support for Intel Avoton SoC
++    - LP: #1196658
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Jul 2013 18:08:02 +0100
++
++linux (3.10.0-2.9) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.10
++
++  [ John Johansen ]
++
++  * Revert "SAUCE: (no-up) apparmor: Fix quieting of audit messages for
++    network mediation"
++  * Revert "SAUCE: (no-up) apparmor: Fix compile warnings"
++  * Revert "SAUCE: (no-up) AppArmor: basic networking rules"
++  * Revert "SAUCE: (no-up) apparmor: Add the ability to mediate mount"
++  * Revert "SAUCE: (no-up) AppArmor: Add profile introspection file to
++    interface"
++  * Revert "SAUCE: (no-up) AppArmor: Disable Add PR_{GET,SET}_NO_NEW_PRIVS
++    to prevent execve from granting privs"
++  * SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable snapshot
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 01 Jul 2013 17:42:29 +0100
++
++linux (3.10.0-1.8) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Release Tracking Bug
++    - LP: #1195717
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: overlayfs -- follow change to do_splice_direct
++    interface"
++  * Revert "ubuntu: overlayfs -- expose do_splice_direct prototype"
++  * Revert "SAUCE: ubuntu: overlayfs -- ovl_path_open should not take path
++    reference"
++  * Revert "ubuntu: overlayfs -- add FS_ALIAS"
++  * Revert "ubuntu: overlayfs --
++    overlayfs-copy-up-i_uid-i_gid-from-the-underlying-inode"
++  * Revert "ubuntu: overlayfs -- ovl-switch-to-inode_permission"
++  * Revert "ubuntu: overlayfs -- vfs-export-inode_permission-to-modules"
++  * Revert "ubuntu: overlayfs -- overlayfs-create-new-inode-in-ovl_link"
++  * Revert "ubuntu: overlayfs --
++    overlayfs-fix-possible-leak-in-ovl_new_inode"
++  * Revert "ubuntu: overlayfs -- fs-limit-filesystem-stacking-depth"
++  * Revert "ubuntu: overlayfs -- overlay-overlay-filesystem-documentation"
++  * Revert "ubuntu: overlayfs -- overlayfs-implement-show_options"
++  * Revert "ubuntu: overlayfs -- overlayfs-add-statfs-support"
++  * Revert "ubuntu: overlayfs -- overlay filesystem"
++  * Revert "ubuntu: overlayfs -- vfs-introduce-clone_private_mount"
++  * Revert "ubuntu: overlayfs -- vfs-export-do_splice_direct-to-modules"
++  * Revert "ubuntu: overlayfs -- vfs-add-i_op-dentry_open"
++  * ubuntu: overlayfs v18 -- -- overlayfs: add statfs support
++
++  [ Erez Zadok ]
++
++  * ubuntu: overlayfs v18 -- -- overlayfs: implement show_options
++
++  [ Miklos Szeredi ]
++
++  * ubuntu: overlayfs v18 -- -- vfs: add i_op->dentry_open()
++  * ubuntu: overlayfs v18 -- -- vfs: export do_splice_direct() to modules
++  * ubuntu: overlayfs v18 -- -- vfs: export __inode_permission() to modules
++  * ubuntu: overlayfs v18 -- -- vfs: introduce clone_private_mount()
++  * ubuntu: overlayfs v18 -- -- overlay filesystem
++  * ubuntu: overlayfs v18 -- -- fs: limit filesystem stacking depth
++
++  [ Neil Brown ]
++
++  * ubuntu: overlayfs v18 -- -- overlay: overlay filesystem documentation
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_SUNRPC_DEBUG=y
++    - LP: #1127319
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jun 2013 10:26:52 +0100
++
++linux (3.10.0-0.7) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * autopkgtest: switch Depends: to build-essential
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 25 Jun 2013 08:40:55 +0100
++
++linux (3.10.0-0.6) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_ARCH_TEGRA to fix FTBFS on armhf
++  * SAUCE: ubuntu: overlayfs -- ovl_path_open should not take path reference
++    - LP: #1098378
++  * ubuntu: AUFS -- update to 4f14cef47eb7c23eda7198931fbab1040866b6ee
++  * ubuntu: overlayfs -- expose do_splice_direct prototype
++  * ubuntu: overlayfs -- follow change to do_splice_direct interface
++  * [Config] flip CONFIG_NO_HZ_FULL_ALL off as it is overheating machines
++    - LP: #1192691
++
++  [ Stefan Bader ]
++
++  * (d-i) Add dm-snapshot to md-modules
++    - LP: #1191726
++
++  [ Tim Gardner ]
++
++  * Release tracker
++    - LP: #1194149
++  * [Config] CONFIG_WIL6210=n for armhf
++  * [Config] d-i: Add calxedaxgmac to nic-modules
++    - LP: #1192358
++  * [debian] Use dh_strip
++    - LP: #1192759
++  * [Config] Enable perf for armhf
++  * do_tools=false when cross compiling
++  * [Config] CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS=y
++    - LP: #1108082
++
++  [ Upstream Kernel Changes ]
++
++  * nsp32: switch reset delay to msleep() as it is tooo long
++  * alx: add a simple AR816x/AR817x device driver
++    Plucked from linux-next. replaces ubuntu/alx in favor of
++    'to be merged' version in 3.11.
++  * rebase to v3.10-rc7
++    - LP: #1189363
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sat, 22 Jun 2013 18:10:31 -0600
++
++linux (3.10.0-0.5) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.10-rc6
++  * [Config] updateconfigs following rebase to v3.10-rc6
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10-rc6
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 17 Jun 2013 11:12:39 +0100
++
++linux (3.10.0-0.4) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] updateconfigs following rebase to v3.10-rc4
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 10 Jun 2013 11:42:28 +0100
++
++linux (3.10.0-0.3) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.10-rc5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10-rc5
++    - LP: #1186170
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 10 Jun 2013 09:23:31 +0100
++
++linux (3.10.0-0.2) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.10-rc4
++  * [Config] CONFIG_BINFMT_SCRIPT=y to fix booting initramfs scripts
++  * [Config] enable SND_PCM_DEBUG SND_PCM_XRUN_DEBUG
++    - LP: #1187744
++  * [Config] enforce CONFIG_BINFMT_SCRIPT=y
++
++  [ Dave Chiluk ]
++
++  * SAUCE: ncpfs: fix rmdir returns Device or resource busy
++    - LP: #1035226
++
++  [ Tim Gardner ]
++
++  * rebase to v3.10-rc3
++  * [Config] sparc be gone
++  * [Config] ia64 be gone
++  * d-i: block-modules provides nbd-modules
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10-rc4
++  * rebase to v3.10-rc3
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 28 May 2013 06:16:46 -0600
++
++linux (3.10.0-0.1) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * UBUNTU: Disabled lttng
++  * UBUNTU: Disable aufs for FTBS
++  * UBUNTU: Disabled alx
++  * UBUNTU: alx: rename NETIF_F_HW_VLAN_* feature flags to NETIF_F_HW_VLAN_CTAG_*
++  * UBUNTU: rebase to v3.10-rc2
++  * UBUNTU: SAUCE: uvcvideo: quirk PROBE_DEF for Alienware X51 OmniVision webcam
++
++  [ Andy Whitcroft ]
++
++  * UBUNTU: [Config] update standards version to 3.9.4.0
++  * UBUNTU: [Config] squash duplicate package description (long and short)
++  * UBUNTU: [Config] fix up Vcs-git: to point to saucy
++  * UBUNTU: [Config] drop depenancy on util-linux as is Essential
++  * UBUNTU: [Config] drop redundant Build-Conficts:
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10-rc2
++    - LP: #1180351
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10-rc1
++    - LP: #1172151
++    - LP: #1089795
++    - LP: #1167270
++    - LP: #1128840
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 14 May 2013 13:41:07 -0600
++
++linux (3.10.0-0.0) saucy; urgency=low
++
++  * Dummy
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 09 May 2013 20:30:40 +0100
++
++linux (3.9.0-2.6) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * rebase to v3.9.2
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 09 May 2013 20:30:40 +0100
++
++linux (3.9.0-1.5) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * rebase to v3.9.1
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 08 May 2013 12:49:45 -0400
++
++linux (3.9.0-0.4) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: overlayfs -- add FS_ALIAS
++
++  [ Tim Gardner ]
++
++  * Added lttng
++    - LP: #1175784
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 02 May 2013 17:17:13 -0400
++
++linux (3.9.0-0.3) saucy; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Apr 2013 18:20:00 -0400
++
++linux (3.9.0-0.2) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * Enable extras packaging for amd64/i386.
++    Fixes build depenencies with brittany and linux-meta.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Apr 2013 05:37:01 -0600
++
++linux (3.9.0-0.1) saucy; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc8
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc7
++    - LP: #1128840
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc6
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc4
++    - LP: #1095315
++    - LP: #886975
++    - LP: #1086921
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc3
++    - LP: #1155016
++    - LP: #1103594
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc2
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc1
++    - LP: #901105
++    - LP: #961286
++    - LP: #1011792
++    - LP: #1128934
++    - LP: #886975
++    - LP: #978807
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 20 Feb 2013 09:12:39 -0700
++
++linux (3.8.0-7.14) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_RCU_USER_QS=n
++  * [Config] CONFIG_MTD_ONENAND_SIM=n
++  * annotations: add annotations for CONFIG_CC_STACKPROTECTOR
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8
++
++  [Tim Gardner]
++
++  * Release Tracking Bug
++    - LP: #1130111
++  * UBUNTU: SAUCE: rt2x00: rt2x00pci_regbusy_read() - only print register access failure once
++    - LP: #1128840
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 18 Feb 2013 09:25:56 -0700
++
++linux (3.8.0-6.13) raring; urgency=low
++
++  [Tim Gardner]
++
++  * Release Tracking Bug
++    - LP: #1125364
++  * Add ahci modules to d-i
++    - LP: #1124415
++
++
++  [ Chris Wilson ]
++
++  * SAUCE: drm/i915: Wait for pending flips to complete before tearing down
++    the encoders
++    - LP: #1097315
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 13 Feb 2013 12:16:48 -0700
++
++linux (3.8.0-6.12) raring; urgency=low
++
++  [Tim Gardner]
++
++  * perf: NO_LIBPERL=1
++  * Fix linux-headers dependency
++  * Release Tracking Bug
++    - LP: #1124362
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_AUFS_EXPORT to allow nfs exports
++    - LP: #1121699
++
++  [ Daniel Vetter ]
++
++  * SAUCE: drm/i915: write backlight harder
++    - LP: #954661
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 13 Feb 2013 10:25:11 -0700
++
++linux (3.8.0-6.11) raring; urgency=low
++
++  [Tim Gardner]
++
++  * Release Tracking Bug
++    - LP: #1122071
++  * rebase to v3.8-rc7
++  * Add libaudit-dev as a build dependency
++  * Build perf with NO_LIBPYTHON=1 to avoid a python build dependency.
++
++  [ Leann Ogasawara ]
++
++  * [Config] Remove CONFIG_SATA_AHCI annotation
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 08 Feb 2013 07:41:13 -0500
++
++linux (3.8.0-5.10) raring; urgency=low
++
++  [Tim Gardner]
++
++  * Release Tracking Bug
++    - LP: #1118568
++
++  * Bump ABI to fix install issue with 3.8.0-4.8.
++    Moving drivers/ata/*ahci* to linux-image caused an
++    install conflict with linux-image-extras without an
++    ABI bump.
++
++  [ Jan Beulich ]
++
++  * SAUCE: xen-pciback: rate limit error messages from
++    xen_pcibk_enable_msi{, x}()
++    - LP: #1117336
++    - CVE-2013-0231
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 07 Feb 2013 05:38:12 -0700
++
++linux (3.8.0-4.9) raring; urgency=low
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * d-i: Add mellanox ethernet drivers to nic-modules
++    - LP: #1015339
++
++  [ Joseph Salisbury ]
++
++  * SAUCE: ACPI: Add DMI entry for Sony VGN-FW41E_H
++    - LP: #1113547
++
++  [ Kamal Mostafa ]
++
++  * SAUCE: alx driver import script
++
++  [ Qualcomm Atheros, Inc ]
++
++  * SAUCE: alx: Update to heads/master
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1117673
++
++  * [debian] Remove dangling symlink from headers package
++    - LP: #1112442
++  * [config] CONFIG_ALX=m
++  * [Config] Add alx to d-i nic-modules
++  * [Config] CONFIG_SATA_AHCI=m
++    - LP: #1056563
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 05 Feb 2013 05:54:32 -0800
++
++linux (3.8.0-4.8) raring; urgency=low
++
++  [ Allen Ibara ]
++
++  * SAUCE: imx6: dts: Add IMX6Q AHCI support
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.8-rc6
++  * updateconfigs following rebase to v3.8-rc6
++
++  [Leann Ogasawara]
++
++  * Release Tracking Bug
++    - LP: #1112573
++
++  [ Paolo Pisati ]
++
++  * SAUCE: imx6: enable sata clk if SATA_AHCI_PLATFORM
++  * [Config] SERIAL_AMBA_PL011=y (vexpress serial console)
++  * [Config] MMC_ARMMMCI=y (vexpress mmc)
++  * [Config] FB_ARMCLCD=y (vexpress framebuffer)
++
++  [ Seth Forshee ]
++
++  * [Config] CONFIG_MAC80211_MESSAGE_TRACING=y
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc6
++    - LP: #1107477
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 01 Feb 2013 07:20:59 -0800
++
++linux (3.8.0-3.7) raring; urgency=low
++
++  [ Andy Green ]
++
++  * SAUCE: ARM: OMAP2+: add cpu id register to MAC address helper
++  * SAUCE: ARM: omap2 add mac address allocation register api
++  * SAUCE: ARM: omap2 panda register ethernet and wlan for automatic mac
++    allocation
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.8-rc5
++  * Release Tracking Bug
++    - LP: #1111486
++
++  [ Paolo Pisati ]
++
++  * SAUCE: davinci: vpss: compilation fix
++  * [Config] enable TI OMAP4 support (Pandaboard/ES)
++  * [Config] OMAP_USB2=y (since TWL6030_USB depends on it)
++  * [Config] enable Freescale IMX6 support (SabreLite)
++  * [Config] SERIAL_IMX_CONSOLE=y
++  * [Config] MMC_*_IMX=y
++  * [Config] disable USB_SUSPEND
++  * [Config] USB_MXS_PHY=y
++  * [Config] USB_CHIPIDEA=y
++  * SAUCE: DTB: add support for multiple DTBs
++  * SAUCE: DTB: build imx6q-sabrelite
++  * SAUCE: DTB: build beaglexm
++  * SAUCE: DTB: build panda/panda es
++  * [Config] disable CPU_FREQ
++  * [Config] PANEL_TFP410=y (video DVI output)
++  * [Config] SND_OMAP_SOC*=y
++  * [Config] SND_IMX_SOC*=y
++  * [Config] I2C_IMX=y
++  * [Config] SPI_IMX=m
++
++  [ Stefan Bader ]
++
++  * [Config] Move 9p modules into generic package
++    - LP: #1107658
++
++  [ Tony Lindgren ]
++
++  * SAUCE: ARM: OMAP2+: Limit omap initcalls to omap only on multiplatform
++    kernels
++  * SAUCE: ARM: OMAP2+: Use omap initcalls
++  * SAUCE: ARM: OMAP: Fix i2c cmdline initcall for multiplatform
++  * SAUCE: ARM: OMAP: Fix dmaengine init for multiplatform
++  * SAUCE: ARM: OMAP2+: Add multiplatform debug_ll support
++  * SAUCE: ARM: OMAP2+: Disable code that currently does not work with
++    multiplaform
++  * SAUCE: ARM: OMAP2+: Enable ARCH_MULTIPLATFORM support
++  * SAUCE: ARM: OMAP2+: Add minimal support for booting vexpress
++  * SAUCE: ARM: OMAP2+: Remove now obsolete uncompress.h and debug-macro.S
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc5
++    - LP: #1096789
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Jan 2013 06:44:52 -0800
++
++linux (3.8.0-2.6) raring; urgency=low
++
++  [ Adam Conrad ]
++
++  * Fix up linux-tools -> SRCPKGNAME-tools rename
++
++  [ Andy Whitcroft ]
++
++  * [Config] re-disable CONFIG_SOUND_OSS
++    - LP: #1105230
++
++  [ Arend van Spriel ]
++
++  * SAUCE: brcmsmac: fix tx status processing
++
++  [Leann Ogasawara]
++
++  * Release Tracking Bug
++    - LP: #1105104
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 25 Jan 2013 11:56:30 -0800
++
++linux (3.8.0-1.5) raring; urgency=low
++
++  [Tim Gardner]
++
++  * Release Tracking Bug
++    - LP: #1101235
++
++  [ Dudley Du ]
++
++  * SAUCE: Input: add support for Cypress PS/2 Trackpads
++    - LP: #978807
++
++  [ Kamal Mostafa ]
++
++  * SAUCE: Input: increase struct ps2dev cmdbuf[] to 8 bytes
++  * SAUCE: Input: Cypress PS/2 Trackpad simulated multitouch
++  * [Config] Add CONFIG_PS2_CYPRESS
++
++  [ Tim Gardner ]
++
++  * rebase to v3.8-rc4
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc4
++    - LP: #1095315
++    - LP: #886975
++    - LP: #1086921
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 17 Jan 2013 10:50:22 -0800
++
++linux (3.8.0-0.4) raring; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] Update CONFIG_TOUCHSCREEN_EGALAX build annotation
++  * [Config] Update CONFIG_IIO build annotation
++  * [Config] Update CONFIG_TOUCHSCREEN_EETI annotation
++  * [Config] Remove CONFIG_SPI_DW_MMIO annotation
++  * [Config] Remove CONFIG_SPI_PL022 annotation
++  * [Config] Update CONFIG_EZX_PCAP annotation
++  * [Config] Update CONFIG_SENSORS_AK8975 annotation
++  * [Config] Disable CONFIG_DRM_MGAG200
++    - LP: #1042903
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 14 Jan 2013 10:01:50 -0800
++
++linux (3.8.0-0.3) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: (no-up) trace: add trace events for open(), exec() and
++    uselib()"
++
++  [ Scott James Remnant ]
++
++  * SAUCE: (no-up) trace: add trace events for open(), exec() and uselib()
++    (for v3.7+)
++    - LP: #1085766, #462111
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Jan 2013 16:57:27 +0000
++
++linux (3.8.0-0.2) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * [packaging] Add macro to selectively disable building perf
++  * [packaging] Cannot depend on universe package libaudit-dev
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 10 Jan 2013 12:43:24 -0700
++
++linux (3.8.0-0.1) raring; urgency=low
++
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc3
++    - LP: #1096789
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc2
++    - LP: #1082357
++    - LP: #1075882
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 17 Dec 2012 10:35:09 +0000
++
++linux (3.7.0-7.15) raring; urgency=low
++
++  [ Chris J Arges ]
++
++  * SAUCE: add eeprom_bad_csum_allow module parameter
++    - LP: #1070182
++
++  [ Leann Ogasawara ]
++
++  * Add ceph to linux-image for virtual instances
++    - LP: #1063784
++
++  [ Serge Hallyn ]
++
++  * SAUCE: net: dev_change_net_namespace: send a KOBJ_REMOVED/KOBJ_ADD
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_SLUB_DEBUG=y
++    - LP: #1090308
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[SCSI] sd: Implement support for WRITE SAME"
++    - LP: #1089818
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 12 Dec 2012 06:50:20 -0800
++
++linux (3.7.0-6.14) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] annotations: all new annotations scheme including defaults
++  * [Configs] apply annotation updates to main configs (top section)
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: include <linux/printk.h> and <stdarg.h> for mmc_core arm
++    build"
++  * Revert "SAUCE: [arm] fixup __aeabi_uldivmod undefined build error"
++  * Temporarily disable module check for build
++
++  [ Stefan Bader ]
++
++  * ubuntu: dm-raid45: Adapt to upstream interface changes
++  * Re-enable build of dm-raid45
++
++  [ Tim Gardner ]
++
++  * SAUCE: Moved scripts/fw-to-ihex.sh to debian/scripts/misc
++  * SAUCE: ACPICA: Fix ACPI mutex object allocation memory leak on error
++  * SAUCE: drm: Fix possible EDID memory allocation oops
++  * SAUCE: ttm: Fix possible _manager memory allocation oops
++  * SAUCE: iwlwifi: iwlagn_request_scan: Fix check for priv->scan_request
++  * SAUCE: i915: intel_set_mode: Reduce stack allocation from 500 bytes to
++    2 pointers
++
++  [ Tomas Hozza ]
++
++  * SAUCE: tools: hv: Netlink source address validation allows DoS
++    - LP: #1084777
++    - CVE-2012-5532
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 05 Dec 2012 14:11:12 -0800
++
++linux (3.7.0-5.13) raring; urgency=low
++
++  [ Lino Sanfilippo ]
++
++  * SAUCE: inotify, fanotify: replace fsnotify_put_group() with
++    fsnotify_destroy_group()
++    - LP: #922906
++  * SAUCE: fsnotify: introduce fsnotify_get_group()
++    - LP: #922906
++  * SAUCE: fsnotify: use reference counting for groups
++    - LP: #922906
++  * SAUCE: fsnotify: take groups mark_lock before mark lock
++    - LP: #922906
++  * SAUCE: fanotify: add an extra flag to mark_remove_from_mask that
++    indicates wheather a mark should be destroyed
++    - LP: #922906
++  * SAUCE: fsnotify: use a mutex instead of a spinlock to protect a groups
++    mark list
++    - LP: #922906
++  * SAUCE: fsnotify: pass group to fsnotify_destroy_mark()
++    - LP: #922906
++  * SAUCE: fsnotify: introduce locked versions of fsnotify_add_mark() and
++    fsnotify_remove_mark()
++    - LP: #922906
++  * SAUCE: fsnotify: dont put marks on temporary list when clearing marks
++    by group
++    - LP: #922906
++  * SAUCE: fsnotify: change locking order
++    - LP: #922906
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_NFC_LLCP=y
++  * [Config] get-firmware: Filter new files through fwinfo
++  * [Config] CONFIG_MTD_NAND_DOCG4=m for all arches
++  * [Config] CONFIG_DRM_EXYNOS_HDMI=y
++  * [Config] CONFIG_XEN=y for all arches
++  * [Config] CONFIG_SND_OMAP_SOC_ZOOM2=m
++  * [Config] CONFIG_MMC_DW_EXYNOS=m
++  * [Config] CONFIG_GPIO_ADNP=m
++  * [Config] find-obsolete-firmware: Use correct path
++  * rebase to v3.7-rc8
++    - LP: #1084640
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "VFS: don't do protected {sym,hard}links by default"
++    - LP: #1084192
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 28 Nov 2012 16:07:08 +0000
++
++linux (3.7.0-4.12) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * Revert "[Config] Use -j1 for headers_install"
++  * Revert "[Config] install-arch-headers needs a valid config"
++    Strayed into the weeds in search of the root cause of the periodic
++    build failure.
++    Fixes powerpc FTBS introduced in -4.11.
++  * [Config] hmake -j1
++    The kernel makefile appears to have parallel dependency
++    problems for the install_headers target. This appears to be root
++    cause for a periodic build failure on N-way machines.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 27 Nov 2012 12:33:06 -0800
++
++linux (3.7.0-4.11) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Use -j1 for headers_install
++    Also fixes a powerpc FTBS introduced by
++    "[Config] install-arch-headers needs a valid config".
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 27 Nov 2012 10:19:30 -0700
++
++linux (3.7.0-4.10) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] add rebuild-test support for autopkgtest
++    - LP: #1081500
++  * [tests] move build tests out of the way
++    - LP: #1081500
++  * [tests] add an autopkgtest rebuild test
++    - LP: #1081500
++
++  [ Tim Gardner ]
++
++  * rebase to v3.7-rc7
++  * SAUCE: Remove emi62 files duplicated in linux-firmware
++  * SAUCE: Remove sb16 files duplicated in linux-firmware
++  * SAUCE: Remove whiteheat files duplicated in linux-firmware
++  * SAUCE: Remove yamaha files duplicated in linux-firmware
++  * SAUCE: Remove dsp56k files used only by m68k
++  * SAUCE: firmware: Remove last vestiges of dabusb
++  * SAUCE: Remove vicam files duplicated in linux-firmware
++  * [Config] install-arch-headers needs a valid config
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7-rc7
++    - LP: #1076840
++    - LP: #1081466
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 21 Nov 2012 06:07:23 -0800
++
++linux (3.7.0-3.9) raring; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_X86_CPUFREQ_NFORCE2=y
++    - LP: #1079900
++  * Add nfsv3 to nfs-modules udeb
++
++  [ Paolo Pisati ]
++
++  * [Config] SND_OMAP_SOC*=y
++    - LP: #1019321
++
++  [ Stefan Bader ]
++
++  * SAUCE: (no-up) xen/netfront: handle compound page fragments on transmit
++    - LP: #1078926
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: SECCOMP: audit: always report seccomp violations"
++    - LP: #1079469
++  * Revert "SAUCE: omap3 clocks .dev_id = NULL"
++  * rebase to v3.7-rc6
++  * SAUCE: script to detect obsolete firmware
++  * SAUCE: Remove yam files duplicated in linux-firmware
++  * SAUCE: Remove tehuti files duplicated in linux-firmware
++  * SAUCE: Remove matrox files duplicated in linux-firmware
++  * SAUCE: Remove cxgb3 files duplicated in linux-firmware
++  * SAUCE: Remove r128 files duplicated in linux-firmware
++  * SAUCE: Remove acenic files duplicated in linux-firmware
++  * SAUCE: Remove keyspan files duplicated in linux-firmware
++  * SAUCE: Remove sun files duplicated in linux-firmware
++  * SAUCE: Remove radeon files duplicated in linux-firmware
++  * SAUCE: Update bnx2x firmware to 7.8.2.0
++  * [Config] generic.inclusion-list: econet has disappeared
++
++  [ Upstream Kernel Changes ]
++
++  * seccomp: forcing auditing of kill condition
++    - LP: #1079469
++  * rebase to v3.7-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 20 Nov 2012 12:28:55 -0800
++
++linux (3.7.0-2.8) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "overlayfs: disable until FTBS is fixed"
++  * Revert "ubuntu: overlayfs"
++  * Revert "ubuntu: AUFS"
++  * ubuntu: overlayfs -- overlayfs: add statfs support
++  * ubuntu: overlayfs -- ovl: switch to __inode_permission()
++  * ubuntu: overlayfs -- overlayfs: copy up i_uid/i_gid from the underlying
++    inode
++    - LP: #944386
++  * ubuntu: AUFS (no-squash): basic framework and update machinary
++  * ubuntu: AUFS (no-squash) -- aufs3-base.patch
++  * ubuntu: AUFS (no-squash) -- aufs3-standalone.patch
++  * ubuntu: AUFS: aufs-update -- follow the uapi header changes
++  * ubuntu: AUFS -- update to f2873474324d0a31af4340554b9715f51331bc7f
++  * ubuntu: AUFS (no-squash) -- reenable
++    - LP: #1079193
++
++  [ Erez Zadok ]
++
++  * ubuntu: overlayfs -- overlayfs: implement show_options
++
++  [ Miklos Szeredi ]
++
++  * ubuntu: overlayfs -- vfs: add i_op->dentry_open()
++  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
++  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
++  * ubuntu: overlayfs -- overlay filesystem
++  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
++  * ubuntu: overlayfs -- vfs: export __inode_permission() to modules
++
++  [ Neil Brown ]
++
++  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
++
++  [ Robin Dong ]
++
++  * ubuntu: overlayfs -- overlayfs: fix possible leak in ovl_new_inode
++  * ubuntu: overlayfs -- overlayfs: create new inode in ovl_link
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 15 Nov 2012 13:35:12 +0000
++
++linux (3.7.0-1.7) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Drop dependency on libaudit-dev
++    Its a universe package which causes an FTBS on the builders.
++    libaudit-dev is not strictly required for the perf tools build.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 14 Nov 2012 10:08:13 -0700
++
++linux (3.7.0-1.6) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enforce -- switch CONFIG_NVRAM to more readable form
++  * [Config] better encode the CONFIG_NVRAM constaint
++  * enforcer -- fix debugging output
++
++  [ Ben Collins ]
++
++  * [Config] Add custom_override rule to allow for alternate kernel
++    file/install
++  * [Config] Use SRCPKGNAME as prefix for indep linux headers package
++
++  [ Tim Gardner ]
++
++  * [Config] Dropped armel
++  * Drop highbank from ABI fetch list
++  * [Config] Use dh_prep instead of 'dh_clean -k'
++  * [Config] Build depend on libaudit-dev, libunwind8-dev for tools
++  * [Config] Document binary-indep dependency chain
++  * rebase to v3.7-rc5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7-rc5
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 13 Nov 2012 07:13:37 -0500
++
++linux (3.7.0-0.5) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_AMD_IOMMU_V2=m
++    - LP: #1071520
++  * [Config] CONFIG_MTD_ONENAND_SIM=n for armel
++    Fixes FTBS
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Nov 2012 15:45:39 -0500
++
++linux (3.7.0-0.4) raring; urgency=low
++
++  [ Ben Collins ]
++
++  * [Config] Update enforce rule for CONFIG_NVRAM to better suit flavours
++
++  [ Tim Gardner ]
++
++  * [Config] do_tools=false for arm
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Nov 2012 05:39:51 -0700
++
++linux (3.7.0-0.3) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_DRM_EXYNOS_HDMI=n for armhf
++  * [Config] CONFIG_MTD_NAND_DOCG4=n for armel/armhf
++  * [Config] Drop highbank harder
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 07 Nov 2012 18:11:45 +0000
++
++linux (3.7.0-0.2) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] add fs/udf to linux-image to support DVD/CD formats in virtual
++    instances
++    - LP: #1066921
++  * [Config] drop highbank builds
++
++  [ Jeremy Kerr ]
++
++  * SAUCE: efivarfs: Implement exclusive access for {get, set}_variable
++    - LP: #1063061
++
++  [ Leann Ogasawara ]
++
++  * Reinstate dropped.txt from Ubuntu-3.7.0-0.1-rc1
++
++  [ Tim Gardner ]
++
++  * [Config] Dropped powerpc/ppc64 in favour of the community kernel
++  * [Config] CONFIG_MODULE_SIG=y for amd64,i386, and highbank
++  * rebase to v3.7-rc4
++  * SAUCE: MODSIGN: Emit error for incorrectly signed module
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7-rc4
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 05 Nov 2012 05:35:41 -0700
++
++linux (3.7.0-0.1) raring; urgency=low
++
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7-rc3
++    - LP: #1056078
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7-rc2
++    - LP: #1060729
++    - LP: #1059523
++    - LP: #1006690
++    - LP: #1049623
++    - LP: #1046512
++    - LP: #1052499
++    - LP: #1037642
++    - LP: #559939
++    - LP: #1052460
++    - LP: #939161
++    - LP: #1046734
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 02 Oct 2012 08:13:07 -0600
++
++linux (3.6.0-0.1) UNRELEASED; urgency=low
++
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6-rc7
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6-rc6
++    - LP: #1000424
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6-rc5
++    - LP: #1040077
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6-rc4
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6-rc3
++    - LP: #1038651
++    - LP: #1034779
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 24 Jul 2012 06:37:09 -0700
++
++linux (3.5.0-6.6) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_INET6_XFRM_MODE_ROUTEOPTIMIZATION enable IPv6
++    experimental features
++  * SAUCE: highbank -- export clock functions for modules
++  * [Config] highbank -- reenable CONFIG_TOUCHSCREEN_W90X900
++  * [Config] highbank -- renenable CONFIG_SERIO_AMBAKMI
++  * [Config] highbank -- reenable CONFIG_RFKILL_GPIO
++  * [Config] highbank -- reenable CONFIG_MMC_SDHCI_PXAV3
++  * [Config] highbank -- reenable CONFIG_MMC_SDHCI_PXAV3
++  * [Config] highbank -- reenable CONFIG_KEYBOARD_SAMSUNG
++  * [Config] highbank -- reenable CONFIG_FB_ARMCLCD
++  * [Config] highbank -- reenable CONFIG_DW_DMAC
++  * [Config] highbank -- reenable CONFIG_USB_R8A66597_HCD
++  * [Config] highbank -- reenable CONFIG_USB_MV_UDC
++  * [Config] highbank -- reenable CONFIG_USB_DWC3
++  * [Config] highbank -- reenable CONFIG_SATA_MV
++  * [Config] highbank -- reenable CONFIG_PATA_ARASAN_CF
++  * [Config] highbank -- CONFIG_CAN_C_CAN_PLATFORM
++  * [Config] highbank -- reenable CONFIG_MMC_ARMMMCI
++  * [Config] highbank -- reenable CONFIG_SERIAL_AMBA_PL010
++  * [Config] highbank -- reenable CONFIG_ATMEL_PWM
++  * [Config] highbank -- enable CONFIG_CHECKPOINT_RESTORE
++  * [Config] highbank -- enable CONFIG_EXPERT
++  * [Config] highbank -- enable CONFIG_CHECKPOINT_RESTORE
++  * [Config] enable CONFIG_USB_DYNAMIC_MINORS
++  * [Config] enable CONFIG_USB_EHCI_TT_NEWSCHED
++  * [Config] enable CONFIG_USB_ETH_EEM
++  * [Config] enable CONFIG_USB_HCD_BCMA/CONFIG_USB_HCD_SSB
++  * [Config] disable CONFIG_USB_M66592
++  * [Config] enable CONFIG_USB_NET2272
++  * [Config] enable CONFIG_USB_R8A66597
++  * [Config] annotate: CONFIG_USB_OMAP not required for our h/w
++  * [Config] set CONFIG_USB_MUSB_HDRC=m for omap
++  * [Config] annotate: CONFIG_USB_G_MULTI fix rule
++  * [Config] CONFIG_USB_GPIO_VBUS=m for OMAP
++  * [Config] Enable CONFIG_DRM_AST/_CIRRUS_QEMU/_MGAG200
++  * [Config] sync configuration armhf omap -> armel omap
++  * [Config] annotate: CONFIG_IIO triggers build failures on OMAP4
++  * [Config] disable CONFIG_OMAP_IOVMM is deprecated
++
++  [ Bryan Wu ]
++
++  * [Config] change default IO scheduler from CFQ to Deadline
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Config] Temporarily disable CONFIG_MV643XX_ETH on powerpc"
++  * [Config] Disable CONFIG_MOUSE_INPORT
++
++  [ Tim Gardner ]
++
++  * SAUCE: firmware: Update bnx2x to current firmware version 7.2.51
++  * [Config] Add bnx2x firmware to nic-modules udeb
++  * SAUCE: Add script to convert firmware to ihex format
++  * SAUCE: firmware: Upgrade bnx2 to current versions
++  * [Config] Add tigon firmware to nic-modules udeb
++  * [Config] CONFIG_EARLY_PRINTK_DBGP=y
++    - LP: #1026761
++  * SAUCE: Remove redundant cis firmware
++  * SAUCE: Remove redundant emi26 firmware
++  * SAUCE: Remove redundant ttusb-budget firmware
++  * SAUCE: Remove redundant sun/cassini firmware
++  * SAUCE: Remove redundant ositech/Xilinx7OD firmware
++  * SAUCE: Remove redundant 3com/typhoon.bin firmware
++  * SAUCE: Remove redundant yamaha/ds1 firmware
++  * SAUCE: Remove redundant keyspan_pda firmware
++  * rebase to v3.5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5
++    - LP: #1027828
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 Jul 2012 05:57:04 -0700
++
++linux (3.5.0-5.5) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] annotations: initial import of configuration annotations
++
++  [ Bryan Wu ]
++
++  * [Config] enforcer -- add CONFIG_I2C_DESIGNWARE_PLATFORM enforce checker
++
++  [ Leann Ogasawara ]
++
++  * Rebase to v3.5-rc7
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Bluetooth: btusb: Add vendor specific ID (0a5c:21f4) BCM20702A0
++    - LP: #1010281
++
++  [ Tim Gardner ]
++
++  * [Config] enable CONFIG_I2C_HELPER_AUTO for all flavours as policy
++    expects
++  * [Config] CONFIG_I2O_CONFIG_OLD_IOCTL=n
++  * [Config] CONFIG_BRIDGE_EBT_ULOG=n
++  * [Config] CONFIG_IP_NF_QUEUE=n
++  * [Config] CONFIG_MTD_DOC2000=n
++  * [Config] CONFIG_PRINT_QUOTA_WARNING=n
++  * [Config] CONFIG_PRISM54=n
++  * [Config] CONFIG_SCx200_I2C=n
++  * [Config] CONFIG_USB_ANNOUNCE_NEW_DEVICES=y
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5-rc7
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 Jul 2012 15:38:41 -0700
++
++linux (3.5.0-4.4) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] getabis should be extracting all packages
++    - LP: #1021174
++  * [Config] getabis -- series uses linux-image-extra
++    - LP: #1021174
++  * rebase to v3.5-rc6
++
++  [ Bryan Wu ]
++
++  * [Config] built-in CONFIG_MICREL_PHY as other PHY drivers for all
++    flavours
++  * [Config] sync CONFIG_MOUSE_PS2_ config for all flavours
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_RT2800USB_RT35XX and CONFIG_RT2800USB_RT53XX
++    - LP: #1019561
++
++  [ Paolo Pisati ]
++
++  * [Config] SND_OMAP_SOC, SND_OMAP_SOC_MCBSP and SND_OMAP_SOC_OMAP3_BEAGLE =y
++    - LP: #1019321
++
++  [ Stefan Bader ]
++
++  * SAUCE: (pre-up) net: dont use __netdev_alloc_skb for bounce buffer
++    - LP: #1018456
++  * (config) Disable ACPI_PROCFS_POWER
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_ACPI_BGRT=y
++  * Extract firmware module info during getabi
++    - LP: #1021174
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 09 Jul 2012 08:50:20 -0700
++
++linux (3.5.0-3.3) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_MEMTEST=y
++    - LP: #1004535
++  * [Config] config-check: add support for a cut operation
++  * [Config] enforcer -- switch to cut where appropriate
++
++  [ Leann Ogasawara ]
++
++  * Rebase to v3.5-rc5
++  * [Config] Updateconfigs after rebase to v3.5-rc5
++
++  [ Luis Henriques ]
++
++  * SAUCE: ocfs2: Fix NULL pointer dereferrence in
++    __ocfs2_change_file_space
++    - LP: #1006012
++
++  [ Seth Forshee ]
++
++  * SAUCE: (drop after 3.5) drm/i915: ignore pipe select bit when checking
++    for LVDS register initialization
++    - LP: #1012800
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5-rc5
++    - LP: #1013183
++    - LP: #1017017
++    - LP: #884652
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 02 Jul 2012 06:41:58 -0700
++
++linux (3.5.0-2.2) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.5-rc4
++
++  [ Arend van Spriel ]
++
++  * SAUCE: (drop after 3.5) brcmsmac: fix NULL pointer crash in
++    brcms_c_regd_init()
++    - LP: #950320
++
++  [ Bryan Wu ]
++
++  * [Config] Sync CONFIG_CGROUP_MEM_RES_CTLR_SWAP for ARM
++
++  [ Chris J Arges ]
++
++  * PACKAGING: add .gnu_debuglink sections to .ko files
++    - LP: #669641
++
++  [ Leann Ogasawara ]
++
++  * d-i: Add hid-generic to input-modules
++    - LP: #1017879
++
++  [ Ming Lei ]
++
++  * SAUCE: Revert "mmc: omap_hsmmc: Enable Auto CMD12"
++    - LP: #1017717, #225
++
++  [ Paolo Pisati ]
++
++  * SAUCE: Revert "Fix OMAP EHCI suspend/resume failure (i693)"
++    - LP: #1017718
++  * [Config] Disable generic USB_EHCI_HCD_PLATFORM on omap3
++
++  [ Seth Forshee ]
++
++  * SAUCE: (drop after 3.5) brcm80211: smac: don't set up tx power limits
++    during initialization
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: always set channel specified
++    by mac80211
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: remove unused code for 40MHz
++    channels
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: clean up channel.c
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: inform mac80211 of the X2
++    regulatory domain
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: enable/disable radio on
++    regulatory updates
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: use mac80211 channel data for
++    tx power limits
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: don't validate channels
++    against internal regulatory data
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: use current regulatory domain
++    when checking whether OFDM is allowed
++    - LP: #950320
++
++  [ Tim Gardner ]
++
++  * [Config] Enable CONFIG_CGROUPS for highbank
++    - LP: #1014692
++  * [Config] FB_OMAP*=y and PANEL_TFP410=y
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 26 Jun 2012 06:21:05 -0700
++
++linux (3.5.0-1.1) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] highbank -- enable CONFIG_RFKILL=y and CONFIG_CAN=m
++
++  [ Leann Ogasawara ]
++
++  * Rebase to v3.5-rc1
++  * [Config] Remove USB_DEVICEFS from the config enforcer
++  * [Config] Updateconfigs after rebase to v3.5-rc1
++  * [Config] Temporarily disable CONFIG_MACH_NOKIA_RX51 on arm
++  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EETI on arm
++  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EGALAX on arm
++  * [Config] Temporarily disable CONFIG_EZX_PCAP on arm
++  * [Config] Temporarily disable CONFIG_LIS3L02DQ on arm
++  * [Config] Temporarily disable CONFIG_TI_CPSW on arm
++  * [Config] Temporarily disable CONFIG_GPIO_EM on arm
++  * [Config] Temporarily disable CONFIG_SERIAL_8250_EM on armhf
++  * [Config] Temporarily disable CONFIG_STMMAC_ETH on armhf
++  * [Config] Temporarily disable CONFIG_HW_RANDOM_ATMEL on armhf
++  * Rebase to v3.5-rc2
++  * [Config] Updateconfigs after rebase to v3.5-rc2
++  * [Config] Temporarily disable CONFIG_MV643XX_ETH on powerpc
++  * Rebase to v3.5-rc3
++  * [Config] Updateconfigs after rebase to v3.5-rc3
++
++  [ Paul Mundt ]
++
++  * SAUCE: fix bug.h's inclusion of kernel.h
++
++  [ Stefan Bader ]
++
++  * SAUCE: Fix compile failures of dm-raid45
++  * [Config] Enable dm-raid45
++  * Move dependency on crda to extra package
++    - LP: #657901
++  * SAUCE: Mask CR4 writes on older Xen hypervisors
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5-rc3
++    - LP: #993162
++    - LP: #925577
++  * rebase to v3.5-rc2
++  * rebase to v3.5-rc1
++    - LP: #955892
++    - LP: #978038
++    - LP: #987371
++    - LP: #929545
++    - LP: #942316
++    - LP: #903853
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 08 Jun 2012 14:28:46 -0700
++
++linux (3.4.0-5.11) quantal-proposed; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable CONFIG_ARM_LPAE
++    - LP: #1009061
++
++  [ Oleksij Rempel ]
++
++  * SAUCE: b43: do not call ieee80211_unregister_hw if we are not registred
++    - LP: #1008905
++
++  [ Paolo Pisati ]
++
++  * [Config] omap3: MFD_OMAP_USB_HOST is usb host in omap2+.
++    - LP: #1009061
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 05 Jun 2012 08:06:28 -0700
++
++linux (3.4.0-4.10) quantal; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Temporarily disable ABI and module check
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 04 Jun 2012 20:27:31 -0700
++
++linux (3.4.0-4.9) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] fix config split to avoid the shared config
++  * [Config] updateconfigs following split config fix
++  * [Config] linux-image-extras needs full postinst
++  * [Config] CONFIG_BLK_DEV_NVME commonise across architectures
++  * [Config] CONFIG_HP_WATCHDOG enable as module
++  * [Config] CONFIG_PDC_ADMA is not boot essential
++  * [Config] CONFIG_XEN_ACPI_PROCESSOR should be enabled on x86
++  * [Config] CONFIG_VT6655/CONFIG_VT6656=m
++  * [Config] CONFIG_TRANZPORT=m commonise
++  * [Config] CONFIG_R3964=m commonise
++  * [Config] CONFIG_SCSI_DH=m commonise
++  * [Config] CONFIG_SCSI_IBMVSCSIS=m commonise
++  * [Config] CONFIG_AMD_PHY=y phys are not autoloadable
++  * [Config] CONFIG_SCSI_QLA_ISCSI=m commonise
++  * [Config] CONFIG_SCSI_SPI_ATTR=m commonise
++  * [Config] CONFIG_USB_SN9C102 is deprecated disable
++  * [Config] CONFIG_USB_SI470X=m commonise
++  * [Config] CONFIG_USB_ET61X251=m commonise
++  * [Config] CONFIG_RTS_PSTOR=m commonise
++  * [Config] CONFIG_SCANLOG=m commonise
++  * [Config] CONFIG_SCSI_SYM53C8XX_2=m commonise
++  * [Config] CONFIG_SM_FTL=m commonise
++  * [Config] CONFIG_SOLO6X10=m commonise
++  * [Config] CONFIG_SND_PCM_OSS=n using pulseaudio emulation instead
++  * [Config] CONFIG_SPI_DESIGNWARE=m commonise
++  * [Config] CONFIG_SPI_SPIDEV=m commonise
++  * [Config] CONFIG_TABLET_USB_WACOM=m commonise
++  * [Config] CONFIG_TPS65010=m commonise
++  * [Config] CONFIG_STE10XP=y commonise
++  * [Config] CONFIG_X25_ASY=m commonise
++  * [Config] CONFIG_USB_MON=m commonise
++  * [Config] CONFIG_VME_BUS=m commonise
++  * [Config] CONFIG_W35UND=m commonise
++  * [Config] -CONFIG_TCG_TPM=y commonise
++  * [Config] highbank -- commonise filesystems
++  * [Config] highbank -- commonise subsystems
++  * [Config] highbank -- commonise network protocols
++  * [Config] highbank -- commonise input drivers
++  * [Config] highbank -- commonise CRYPTO options
++  * [Config] highbank -- commonise HID options
++  * [Config] highbank -- commonise sensors options
++  * [Config] highbank -- commonise EXPORTFS/FHANDLE
++  * [Config] highbank -- commonise CONFIG_CRYPTO_LZO
++  * [Config] highbank -- commonise ENCRYPTED_KEYS
++  * [Config] highbank -- commonise CONFIG_ATALK
++  * [Config] highbank -- commonise INET/INET6
++  * [Config] highbank -- commonise NLS
++  * [Config] highbank -- commonise BLK/CHR
++  * [Config] highbank -- CONFIG_EXT2_FS=y boot essential on highbank
++  * [Config] highbank -- commonise INET/INET6 part 2
++  * [Config] highbank -- commonise PHY settings
++  * [Config] highbank -- commonise CRC settings
++  * [Config] highbank -- commonise BINFMT settings
++  * [Config] highbank -- commonise DM settings
++  * [Config] highbank -- commonise RTC_DRV settings
++  * [Config] highbank -- commonise KEYBOARD/MOUSE settings
++  * [Config] highbank -- commonise USB settings
++  * [Config] highbank -- commonise GPIO settings
++  * [Config] highbank -- commonise I2C settings
++  * [Config] highbank -- commonise numerous subsystem selectors
++  * [Config] highbank -- commonise A-C modules missmatches
++  * [Config] highbank -- commonise D-F modules missmatches
++  * [Config] CONFIG_AUDIT_LOGINUID_IMMUTABLE incompatible with upstart
++  * [Config] highbank -- commonise G-I modules missmatches
++  * [Config] highbank -- commonise J-L modules missmatches
++  * [Config] highbank -- commonise M modules missmatches
++  * [Config] highbank -- commonise N-P modules missmatches
++  * [Config] highbank -- commonise Q-R modules missmatches
++  * [Config] highbank -- commonise S modules missmatches -- part 1
++  * [Config] highbank -- commonise S modules missmatches -- part 2
++  * [Config] highbank -- commonise T modules missmatches
++  * [Config] highbank -- commonise U-Z modules missmatches
++
++  [ Ike Panhc ]
++
++  * [Config] add highbank flavour
++    - LP: #1000831
++
++  [ Mark Langsdorf ]
++
++  * SAUCE: arm highbank: add support for pl320-ipc driver
++    - LP: #1000831
++
++  [ Rob Herring ]
++
++  * SAUCE: input: add a key driver for highbank
++    - LP: #1000831
++  * SAUCE: ARM: highbank: Add smc calls to enable/disable the L2
++    - LP: #1000831
++  * SAUCE: force DMA buffers to non-bufferable on highbank
++    - LP: #1000831
++  * SAUCE: net: calxedaxgmac: fix net timeout recovery
++    - LP: #1000831
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_IWLWIFI_EXPERIMENTAL_MFP=n
++  * [Config] CONFIG_PCI_REALLOC_ENABLE_AUTO=y
++  * [Config] CONFIG_CIFS_EXPERIMENTAL has disappeared
++  * [Config] Homogenize CIFS configs across all arches
++  * [Config] armhf should not be skipabi or skipmodules
++    - LP: #1006913
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 04 Jun 2012 05:52:49 -0700
++
++linux (3.4.0-3.8) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] include include/generated/compile.h
++    - LP: #942569
++  * [Config] fix up postinst to ensure we know which error is which
++    - LP: #1002388
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * SAUCE: async_populate_rootfs: fix build warnings
++    - LP: #1003417
++
++  [ John Johansen ]
++
++  * Revert "SAUCE: AppArmor: Add the ability to mediate mount"
++  * SAUCE: apparmor: Add the ability to mediate mount
++  * SAUCE: AppArmor: basic networking rules
++  * SAUCE: apparmor: fix profile lookup for unconfined
++    - LP: #978038, #987371
++  * SAUCE: apparmor: fix long path failure due to disconnected path
++    - LP: #955892
++
++  [ Mario Limonciello ]
++
++  * SAUCE: dell-laptop: rfkill blacklist Dell XPS 13z, 15
++    - LP: #901410
++
++  [ Stefan Bader ]
++
++  * (config) Built-in xen-acpi-processor
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_NET_DSA=m
++    - LP: #1004148
++  * [Config] Ensure CONFIG_XEN_ACPI_PROCESSOR=y for amd64
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 25 May 2012 11:38:33 -0700
++
++linux (3.4.0-3.7) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] drop the virtual flavour in favour of a split generic et al
++  * [Config] enforcer -- drop IDLE enforcement
++  * [Config] enable CONFIG_SCSI_VIRTIO=m for amd64
++  * [Config] updateconfigs following removal of -virtual
++
++  [ Leann Ogasawara ]
++
++  * Rebase to v3.4
++
++  [ Seth Forshee ]
++
++  * [Config] disable CONFIG_B43_BCMA_EXTRA
++
++  [ Tim Gardner ]
++
++  * [Config] Check for extras when building udebs
++  * [Config] Collapsed generic-pae into generic [i386]
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 May 2012 07:23:47 -0700
++
++linux (3.4.0-2.6) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: overlayfs -- overlayfs: update touch_atime() usage"
++  * Revert "ubuntu: overlayfs -- overlayfs: switch from d_alloc_root() to
++    d_make_root()"
++  * Revert "ubuntu: overlayfs -- overlayfs: follow header cleanup"
++  * Revert "ubuntu: overlayfs -- overlayfs: apply device cgroup and
++    security permissions to overlay files"
++  * Revert "ubuntu: overlayfs -- fs: limit filesystem stacking depth"
++  * Revert "ubuntu: overlayfs -- overlay: overlay filesystem documentation"
++  * Revert "ubuntu: overlayfs -- overlayfs: implement show_options"
++  * Revert "ubuntu: overlayfs -- overlayfs: add statfs support"
++  * Revert "ubuntu: overlayfs -- overlay filesystem"
++  * Revert "ubuntu: overlayfs -- vfs: introduce clone_private_mount()"
++  * Revert "ubuntu: overlayfs -- vfs: export do_splice_direct() to modules"
++  * Revert "ubuntu: overlayfs -- vfs: add i_op->open()"
++  * Revert "ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()"
++  * ubuntu: overlayfs -- overlayfs: add statfs support
++  * ubuntu: overlayfs -- inode_only_permission: export inode level
++    permissions checks
++  * ubuntu: overlayfs -- overlayfs: switch to use inode_only_permissions
++
++  [ Erez Zadok ]
++
++  * ubuntu: overlayfs -- overlayfs: implement show_options
++
++  [ Miklos Szeredi ]
++
++  * ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()
++  * ubuntu: overlayfs -- vfs: add i_op->open()
++  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
++  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
++  * ubuntu: overlayfs -- overlay filesystem
++  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
++
++  [ Neil Brown ]
++
++  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
++
++  [ Robin Dong ]
++
++  * ubuntu: overlayfs -- overlayfs: fix possible leak in ovl_new_inode
++  * ubuntu: overlayfs -- overlayfs: create new inode in ovl_link
++
++  [ Tim Gardner ]
++
++  * [Config] perarch and indep tools builds need separate build directories
++  * Prevent upgrading a non-PAE CPU
++  * perf is not parallel build safe
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 16 May 2012 08:43:18 -0700
++
++linux (3.4.0-2.5) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] perarch and indep tools builds need separate build directories
++
++  [ Tim Gardner ]
++
++  * Prevent upgrading a non-PAE CPU
++  * [Config] build debug
++  * [Config] perf tools are not parallel build safe
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 15 May 2012 11:37:53 -0700
++
++linux (3.4.0-2.4) quantal; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: fsam7400: use UMH_WAIT_PROC consistently"
++  * Revert "ubuntu: fsam7400 select CHECK_SIGNATURE and depend on X86"
++  * Revert "ubuntu: fsam7400: Depend on CHECK_SIGNATURE"
++  * Revert "ubuntu: fsam7400 -- Cleanup Makefile"
++  * Revert "ubuntu: fsam7400 -- kill switch for Fujitsu Siemens Amilo M
++    7400"
++  * Revert "ubuntu: omnibook: fix source file newline"
++  * Revert "ubuntu: omnibook -- update BOM"
++  * Revert "SAUCE: Make CONFIG_{OMNIBOOK, AVERATEC_5100P, PACKARDBELL_E5}
++    depend on X86"
++  * Revert "ubuntu: omnibook -- Added missing BOM file"
++  * Revert "ubuntu: omnibook -- support Toshiba (HP) netbooks"
++  * Revert "ubuntu: nx-emu - i386: mmap randomization for executable
++    mappings"
++  * Revert "SAUCE: disable_nx should not be in __cpuinitdata section for
++    X86_32"
++  * Revert "ubuntu: nx-emu - i386: NX emulation"
++  * Revert "ubuntu: rfkill drivers -- version 1.3"
++  * Temporarily disable module check
++  * [Config] Remove CONFIG_FSAM7400
++  * [Config] Remove CONFIG_OMNIBOOK
++  * [Config] Update configs
++  * Rebase to v3.4-rc7
++  * SAUCE: genirq: export handle_edge_irq() and irq_to_desc()
++
++  [ Tim Gardner ]
++
++  * Updated generic-pae description
++  * Rebase to v3.4-rc6
++  * install-tools depends on build targets
++
++  [ Upstream Kernel Changes ]
++
++  * kconfig: in debug mode some 0 length message prints occur
++  * rebase to v3.4-rc7
++  * rebase to v3.3-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 14 May 2012 08:22:56 -0700
++
++linux (3.4.0-1.3) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] control.stub is an intermediate product not a dependancy
++    - LP: #992414
++
++  [ Leann Ogasawara ]
++
++  * remove i386 generic from getabis
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) b43: only reload config after successful initialization
++    - LP: #950295
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 May 2012 09:48:14 -0700
++
++linux (3.4.0-1.2) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] add build depends for flex, bison and pkg-config
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 01 May 2012 13:15:41 +0100
++
++linux (3.4.0-1.1) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: overlayfs -- overlayfs: apply device cgroup and security
++    permissions to overlay files
++    - LP: #915941, #918212
++    - CVE-2012-0055
++
++  [ Leann Ogasawara ]
++
++  * Open Q
++  * Rebase to v3.4-rc5
++  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EETI on arm
++  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EGALAX on arm
++  * [Config] Temporarily disable CONFIG_EZX_PCAP on arm
++  * [Config] Temporarily disable CONFIG_MFD_OMAP_USB_HOST on arm
++  * [Config] Temporarily disable CONFIG_LIS3L02DQ on arm
++  * [Config] Temporarily disable CONFIG_USB_EHCI_HCD_PLATFORM on arm
++  * [Config] Temporarily disable CONFIG_TI_CPSW on arm
++  * [Config] Temporarily disable CONFIG_AX88796 on arm
++
++  [ Upstream Kernel Changes ]
++
++  * vfs: pass struct path to __dentry_open()
++  * vfs: add i_op->open()
++  * vfs: export do_splice_direct() to modules
++  * vfs: introduce clone_private_mount()
++  * overlay filesystem
++  * overlayfs: add statfs support
++  * overlayfs: implement show_options
++  * overlay: overlay filesystem documentation
++  * fs: limit filesystem stacking depth
++  * overlayfs: follow header cleanup
++  * overlayfs: switch from d_alloc_root() to d_make_root()
++  * overlayfs: update touch_atime() usage
++  * rebase to v3.4-rc5
++    - LP: #950490
++  * rebase to v3.4-rc4
++  * rebase to v3.4-rc3
++  * rebase to v3.4-rc2
++  * rebase to v3.4-rc1
++  * rebase to v3.3
++  * rebase to v3.3-rc7
++  * rebase to v3.3-rc6
++  * rebase to v3.3-rc5
++  * rebase to v3.3-rc4
++    - LP: #900802
++    - LP: #930842
++  * rebase to v3.3-rc3
++    - LP: #924320
++    - LP: #923316
++    - LP: #923409
++    - LP: #918254
++  * rebase to v3.3-rc2
++  * rebase to v3.3-rc1
++    - LP: #795823
++    - LP: #909419
++    - LP: #910792
++    - LP: #878701
++    - LP: #724831
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 25 Jan 2012 06:50:04 -0800
++
++linux (3.2.0-10.18) precise; urgency=low
++
++  [ Tim Gardner ]
++
++  * SAUCE: ecryptfs: Print inode on metadata error
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "proc: enable writing to /proc/pid/mem"
++    - LP: #919115
++    - CVE-2012-0056
++  * (pre-stable) ALSA: HDA: Use LPIB position fix for Macbook Pro 7, 1
++    - LP: #909419
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 24 Jan 2012 10:15:12 +0000
++
++linux (3.2.0-10.17) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: overlayfs -- fs: limit filesystem stacking depth"
++  * Revert "SAUCE: overlayfs -- overlay: overlay filesystem documentation"
++  * Revert "SAUCE: overlayfs -- overlayfs: implement show_options"
++  * Revert "SAUCE: overlayfs -- overlayfs: add statfs support"
++  * Revert "SAUCE: overlayfs -- overlay filesystem"
++  * Revert "SAUCE: overlayfs -- vfs: introduce clone_private_mount()"
++  * Revert "SAUCE: overlayfs -- vfs: export do_splice_direct() to modules"
++  * Revert "SAUCE: overlayfs -- vfs: add i_op->open()"
++  * ensure debian/ is not excluded from git by default
++  * add new scripting to handle buglinks in rebases
++  * ubuntu: overlayfs -- overlayfs: add statfs support
++  * ubuntu: overlayfs -- overlayfs: apply device cgroup and security
++    permissions to overlay files
++    - LP: #915941, #918212
++    - CVE-2012-0055
++
++  [ Erez Zadok ]
++
++  * ubuntu: overlayfs -- overlayfs: implement show_options
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: dmar: disable if ricoh multifunction detected"
++  * [Config] Disable CONFIG_INTEL_IOMMU_DEFAULT_ON
++    - LP: #907377, #911236
++  * [Config] Enable CONFIG_IRQ_REMAP
++
++  [ Miklos Szeredi ]
++
++  * ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()
++  * ubuntu: overlayfs -- vfs: add i_op->open()
++  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
++  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
++  * ubuntu: overlayfs -- overlay filesystem
++  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
++
++  [ Neil Brown ]
++
++  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) x86/PCI: amd: factor out MMCONFIG discovery
++    - LP: #647043
++  * (pre-stable) PNP: work around Dell 1536/1546 BIOS MMCONFIG bug that
++    breaks USB
++    - LP: #647043
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 Jan 2012 07:10:08 -0800
++
++linux (3.2.0-9.16) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] Enable numerous CONFIG_VIDEO_* cards on ARM
++  * [Config] pull ARM sound modules =m
++  * [Config] CONFIG_RTC_DRV_TEST is for testing only
++  * [Config] CONFIG_USB_DUMMY_HCD is testing only
++  * [Config] CONFIG_USB_FILE_STORAGE is deprecated
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Config] Temporarily disable CONFIG_CAN_TI_HECC on armel"
++  * [Config] Enable CONFIG_HW_RANDOM_PASEMI=m
++  * [Config] Enable CONFIG_MMC_TMIO=m
++  * [Config] Enable CONFIG_MTD_NAND_FSL_ELBC=m
++  * [Config] Enable CONFIG_ISI=m
++  * [Config] Enable CONFIG_MMC=y
++  * [Config] Enable CONFIG_LIRC_PARALLEL=m
++  * [Config] Enable CONFIG_MAC_EMUMOUSEBTN=m
++  * [Config] Enable CONFIG_CHR_DEV_SG=y
++  * [Config] Enable CONFIG_GPIO_PCA953X=m
++  * [Config] Enable CONFIG_GPIO_TWL4030=m
++  * [Config] Enable CONFIG_INET_DIAG=m
++  * [Config] Enable CONFIG_NLS_ISO8859_1=m
++  * [Config] Enable CONFIG_NVRAM=m
++  * [Config] Enable CONFIG_SLIP=m
++  * [Config] Enable CONFIG_PC300TOO=m
++  * [Config] Enable CONFIG_TUN=y
++  * [Config] Enable CONFIG_NET_CLS_CGROUP=m
++  * [Config] Enable CONFIG_THERMAL=y
++  * [Config] Enable CONFIG_PPP=y
++  * [Config] Enable CONFIG_PCI_STUB=m
++  * Rebase to v3.2.1
++  * [Config] Enable CONFIG_RTL8192E=m
++  * [Config] Enable CONFIG_RTS5139=m
++
++  [ Stefan Bader ]
++
++  * [Config] Make CONFIG_VIRTIO_(NET|BLK)=y
++
++  [ Upstream Kernel Changes ]
++
++  * ARM: restart: add restart hook to machine_desc record
++  * ARM: restart: allow platforms more flexibility specifying restart mode
++  * ARM: restart: move reboot failure handing into machine_restart()
++  * ARM: restart: remove argument to setup_mm_for_reboot()
++  * ARM: 7159/1: OMAP: Introduce local common.h files
++  * ARM: restart: only perform setup for restart when soft-restarting
++  * ARM: 7189/1: OMAP3: Fix build break in cpuidle34xx.c because of irq
++    function
++  * ARM: idmap: populate identity map pgd at init time using .init.text
++  * ARM: suspend: use idmap_pgd instead of suspend_pgd
++  * ARM: proc-*.S: place cpu_reset functions into .idmap.text section
++  * ARM: idmap: use idmap_pgd when setting up mm for reboot
++  * ARM: head.S: only include __turn_mmu_on in the initial identity mapping
++  * ARM: SMP: use idmap_pgd for mapping MMU enable during secondary booting
++  * ARM: 7194/1: OMAP: Fix build after a merge between v3.2-rc4 and ARM
++    restart changes
++  * ARM: lib: add call_with_stack function for safely changing stack
++  * ARM: reset: implement soft_restart for jumping to a physical address
++  * ARM: stop: execute platform callback from cpu_stop code
++  * ARM: kexec: use soft_restart for branching to the reboot buffer
++  * ARM: restart: omap: use new restart hook
++  * topdown mmap support
++    - LP: #861296
++
++  [ Upstream Kernel Changes ]
++
++  * Rebase to v3.2.1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 13 Jan 2012 20:32:08 +0100
++
++linux (3.2.0-8.15) precise; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable CONFIG_ACPI_PROCFS
++  * Remove server from getabis
++  * Temporarily disable module check
++  * [Config] Disable CONFIG_MTD_TESTS
++  * [Config] Disable CONFIG_X86_E_POWERSAVER
++  * [Config] Set CONFIG_ARCNET=m
++  * [Config] Enable CONFIG_ATM_DUMMY=m
++  * [Config] Enable CONFIG_BLK_DEV_MD=y
++  * ubuntu: fsam7400 select CHECK_SIGNATURE and depend on X86
++  * [Config] Enable CONFIG_BLK_DEV_SD=y
++  * [Config] Enable CONFIG_BLK_DEV_SR=y
++  * [Config] Enable CONFIG_BLK_DEV_UB=m
++  * [Config] Enable CONFIG_COPS=m
++  * [Config] Enable CONFIG_DVB_USB_EC168=m
++  * [Config] Enable CONFIG_ENC28J60=m
++  * [Config] Enable CONFIG_FB_UVESA=m
++  * [Config] Enable CONFIG_FB_ATY=m
++  * [Config] Enable CONFIG_BROADCOM_PHY=y
++  * [Config] Enable CONFIG_CICADA_PHY=y
++  * [Config] Enable CONFIG_DAVICOM_PHY=y
++  * [Config] Enable CONFIG_ICPLUS_PHY=y
++  * [Config] Enable CONFIG_LSI_ET1011C_PHY=y
++  * [Config] Enable CONFIG_LXT_PHY=y
++  * [Config] Enable CONFIG_MARVELL_PHY=y
++  * [Config] Enable CONFIG_NATIONAL_PHY=y
++  * [Config] Enable CONFIG_QSEMI_PHY=y
++  * [Config] Enable CONFIG_SMSC_PHY=y
++  * [Config] Enable CONFIG_VITESSE_PHY=y
++  * Add 3w-sas to scsi-modules
++    - LP: #776542
++
++  [ Mathieu Trudel-Lapierre ]
++
++  * SAUCE: ipv6: make the net.ipv6.conf.all.use_tempaddr sysctl propagate
++    to interface settings
++
++  [ Paolo Pisati ]
++
++  * Revert "SAUCE: omap3: beagle: if rev unknown, assume xM revision C"
++    - LP: #912199
++  * Revert "SAUCE: omap3: beagle: detect new xM revision B"
++    - LP: #912199
++  * Revert "SAUCE: omap3: beaglexm: fix DVI initialization"
++    - LP: #912199
++
++  [ Upstream Kernel Changes ]
++
++  * Bluetooth: Add support for BCM20702A0 [0a5c:21e3]
++    - LP: #906832
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 06 Jan 2012 10:02:03 -0800
++
++linux (3.2.0-8.14) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_SND_USB_6FIRE
++    - LP: #912197
++  * rebase to mainline v3.2 final release
++  * updateconfigs following rebase to v3.2 final
++  * ubuntu: AUFS -- add BOM and automated update script
++  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
++    - LP: #684666
++  * ubuntu: AUFS -- update aufs-update to track new locations of headers
++  * ubuntu: AUFS -- clean up the aufs updater and BOM
++  * ubuntu: AUFS -- documentation on updating aufs2
++  * ubuntu: AUFS -- aufs3-base.patch
++  * ubuntu: AUFS -- aufs3-standalone.patch
++  * ubuntu: AUFS -- fix undefined __devcgroup_inode_permission
++  * ubuntu: AUFS -- fix undefined security_path_link
++  * ubuntu: AUFS -- update to 4cf5db36bcd9748e8e7270022f295f84d1fc2245
++  * ubuntu: AUFS -- updateconfigs following update
++  * ubuntu: AUFS -- suppress benign plink warning messages
++    - LP: #621195
++  * ubuntu: AUFS -- enable in config and makefile
++  * ubuntu: AUFS -- disable in favor of overlayfs
++  * [Config] linux-virtual -- should include the extX modules
++    - LP: #912308
++
++  [ Tyler Hicks ]
++
++  * SAUCE: eCryptfs: Improve statfs reporting
++    - LP: #885744
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to upstream v3.2
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 26 Dec 2011 20:24:30 -0800
++
++linux (3.2.0-7.13) precise; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to upstream 3.2-rc7
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 19 Dec 2011 09:14:34 -0800
++
++linux (3.2.0-6.12) precise; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to upstream v3.2-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 16 Dec 2011 10:19:02 -0800
++
++linux (3.2.0-5.11) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * enforcer -- allow arch and flavour predicates to take lists
++  * enforcer -- simplify armel/armhf specific options
++  * enforcer -- fix incorrectly specified flavour matches
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable IRQ_REMAP
++  * [Config] Enable CONFIG_SENSORS_LM95245=m
++  * [Config] Enable CONFIG_SENSORS_MAX1668=m
++  * [Config] Enable CONFIG_SENSORS_NTC_THERMISTOR=m
++  * [Config] Enable CONFIG_SENSORS_MAX6639=m
++  * [Config] Enable CONFIG_SENSORS_MAX6642=m
++  * [Config] Enable CONFIG_SENSORS_LINEAGE=m
++  * [Config] Enable CONFIG_CRYPTO_SALSA20=m
++  * [Config] Enable CONFIG_PATA_TOSHIBA=m
++  * [Config] Enable CONFIG_POHMELFS=m
++  * [Config] Enable CONFIG_NET_PACKET_ENGINE=y
++  * [Config] Enable CONFIG_PATA_OPTI=m
++  * add overlayfs to virtual inclusion list
++    - LP: #903897
++  * add veth to virtual inclusion list
++    - LP: #903897
++  * SAUCE: resolve WARNING: at drivers/block/floppy.c:2929 do_fd_request
++
++  [ Paolo Pisati ]
++
++  * [Config] DEFAULT_MMAP_MIN_ADDR=32k on arm
++    - LP: #903346
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_LOCKUP_DETECTOR=y
++    - LP: #903615
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to upstream 55b02d2f
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 12 Dec 2011 07:08:10 -0800
++
++linux (3.2.0-4.10) precise; urgency=low
++
++  [ Kyle McMartin ]
++
++  * SAUCE: dmar: disable if ricoh multifunction detected
++    - LP: #894070
++
++  [ Seth Forshee ]
++
++  * SAUCE: dell-wmi: Demote unknown WMI event message to pr_debug
++    - LP: #581312
++
++  [ Tim Gardner ]
++
++  * Start new release, Bump ABI, rebase to 3.2-rc5
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_SENSORS_AK8975=m
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sat, 10 Dec 2011 08:57:04 -0700
++
++linux (3.2.0-3.9) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: ext4: correct partial write discard size calculation
++    - LP: #894768
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: x86, microcode, AMD: Restrict microcode reporting"
++    - LP: #892615
++
++  [ Matthew Garrett ]
++
++  * SAUCE: pci: Rework ASPM disable code
++
++  [ Upstream Kernel Changes ]
++
++  * x86: Fix boot failures on older AMD CPU's
++    - LP: #892615
++  * EHCI : Fix a regression in the ISO scheduler
++    - LP: #899165
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 05 Dec 2011 10:37:36 -0800
++
++linux (3.2.0-3.8) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * armhf -- add d-i configuration
++  * armhf -- disable ABI checks for armhf
++  * armhf -- add arch to getabis config
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 03 Dec 2011 14:22:52 +0000
++
++linux (3.2.0-3.7) precise; urgency=low
++
++  [ Stefan Bader ]
++
++  * SAUCE: x86/paravirt: PTE updates in k(un)map_atomic need to be
++    synchronous, regardless of lazy_mmu mode
++    - LP: #854050
++
++  [ Tim Gardner ]
++
++  * rebase to v3.2-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 02 Dec 2011 11:53:56 -0800
++
++linux (3.2.0-2.6) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * armhf -- fix omap flavour to build on armhf
++  * [Config] CONFIG_PATA_MACIO=y to fix MAC qemu boot
++
++  [ Borislav Petkov ]
++
++  * SAUCE: x86, microcode, AMD: Restrict microcode reporting
++    - LP: #892615
++
++  [ Colin Watson ]
++
++  * Add pata_macio to pata-modules
++
++  [ Tim Gardner ]
++
++  * [Config] Prefer crda over wireless-crda
++  * [Config] Fix virtual inclusion list.
++    - LP: #897795
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 30 Nov 2011 06:09:35 -0800
++
++linux (3.2.0-2.5) precise; urgency=low
++
++  [ Paolo Pisati ]
++
++  * [Config] PANEL_DVI=y
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 28 Nov 2011 09:13:24 -0800
++
++linux (3.2.0-2.4) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.2-rc3
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: xen: Do not use pv spinlocks on HVM"
++  * Revert "fix ERROR: __devcgroup_inode_permission undefined"
++  * Revert "olpc_dcon_xo_1_5 needs delay.h"
++  * Revert "olpc_dcon_xo_1 needs delay.h"
++  * rebase to 6fe4c6d4
++  * [Config] updateconfigs after rebase to 6fe4c6d4
++
++  [ Tim Gardner ]
++
++  * [Config] Replace wireless-crda with crda,wireless-regdb
++    - LP: #856421
++  * [Config] Relax the dependencies on crda
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) HID: bump maximum global item tag report size to 96 bytes
++    - LP: #724831
++  * Ubuntu: remove coreutils|fileutils package dependency
++    - LP: #892814
++  * iio: iio_event_getfd -- fix ev_int build failure
++
++  [ Upstream Kernel Changes ]
++
++  * Rebase to v3.2-rc3
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 24 Nov 2011 16:20:45 +0000
++
++linux (3.2.0-1.3) precise; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * Ubuntu: Add ext2 to fs-core-modules
++    - LP: #893395
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 Nov 2011 20:42:33 -0800
++
++linux (3.2.0-1.2) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_NFC and associated devices
++  * SAUCE: allow brcmsmac and b43 to both build
++
++  [ Soren Hansen ]
++
++  * Add ixgbe driver to d-i
++    - LP: #891969
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 Nov 2011 08:33:46 -0800
++
++linux (3.2.0-1.1) precise; urgency=low
++  [ Andy Whitcroft ]
++
++  * armhf -- enable armhf and create the first flavours
++  * SAUCE: ensure root is ready before running usermodehelpers in it
++  * [Config] enforcer -- ensure CONFIG_FAT_FS is built-in on arm
++
++  [ Leann Ogasawara ]
++
++  * Temporarily ignore module check
++  * [Config] Enable PCI_IOV on powerpc
++  * [Config] Temporarily disable CONFIG_PASEMI_MAC on powerpc
++  * rebase to v3.2-rc2
++  * SAUCE: include <linux/export.h> for cpuidle34xx arm build
++  * SAUCE: include <linux/kernel.h> for linux/mtd/map.h arm build
++  * SAUCE: include <linux/printk.h> and <stdarg.h> for mmc_core arm build
++  * SAUCE: select ARM_AMBA if OMAP3_EMU
++  * [Config] updateconfigs after select ARM_AMBA
++  * [Config] Temporarily disable CONFIG_KVM_BOOK3S_32 on powerpc
++  * [Config] Enable CONFIG_EXT2_FS=m
++  * [Config] Build in CONFIG_SATA_AHCI=y
++  * Resolve linux-image-extra's install dependency
++
++  [ Seth Forshee ]
++
++  * [Config] Enable EVENT_POWER_TRACING_DEPRECATED=y for powertop
++  * SAUCE: (drop after 3.2) Input: ALPS - move protocol information to
++    Documentation
++  * SAUCE: (drop after 3.2) Input: ALPS - add protocol version field in
++    alps_model_info
++  * SAUCE: (drop after 3.2) Input: ALPS - remove assumptions about packet
++    size
++  * SAUCE: (drop after 3.2) Input: ALPS - add support for protocol versions
++    3 and 4
++  * SAUCE: (drop after 3.2) Input: ALPS - add semi-MT support for v3
++    protocol
++  * SAUCE: (drop after 3.2) Input: ALPS - add documentation for protocol
++    versions 3 and 4
++
++  [ Stefan Bader ]
++
++  * [Config] Built-in xen-netfront and xen-blkfront
++  * Fix build of dm-raid45 and re-enable it
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_USB_XHCI_HCD=y
++    - LP: #886167
++  * [Config] CONFIG_R6040=m
++    - LP: #650899
++  * SAUCE: Add a new entry (413c:8197) to Bluetooth USB device ID table
++    - LP: #854399
++  * [Config] Consolidated amd64 server flavour into generic
++  * [Config] updateconfigs after rebase to 3.2-rc1
++  * [Config] Disabled dm-raid4-5
++  * [Config] Disabled ndiswrapper
++  * [Config] Disable vt6656
++  * [Config] exclude ppp-modules for virtual flavour
++  * [Config] CONFIG_MEMSTICK_R592=m
++    - LP: #238208
++
++  [ Upstream Kernel Changes ]
++
++  * CHROMIUM: seccomp_filter: new mode with configurable syscall filters
++    - LP: #887780
++  * CHROMIUM: seccomp_filter: add process state reporting
++    - LP: #887780
++  * CHROMIUM: seccomp_filter: Document what seccomp_filter is and how it
++    works.
++    - LP: #887780
++  * CHROMIUM: x86: add HAVE_SECCOMP_FILTER and seccomp_execve
++    - LP: #887780
++  * CHROMIUM: arm: select HAVE_SECCOMP_FILTER
++    - LP: #887780
++  * CHROMIUM: seccomp_filters: move to btrees
++  * CHROMIUM: enable CONFIG_BTREE
++  * CHROMIUM: seccomp_filter: kill NR_syscall references
++  * CHROMIUM: seccomp_filters: guard all ftrace wrapper code
++  * CHROMIUM: seccomp_filters: clean up warnings; kref mistake
++  * CHROMIUM: seccomp_filter: remove "skip" from copy and add drop helper
++  * CHROMIUM: seccomp_filter: allow CAP_SYS_ADMIN management of execve
++  * CHROMIUM: seccomp_filter: inheritance documentation
++  * CHROMIUM: seccomp_filter: make inherited filters composable
++  * CHROMIUM: Fix seccomp_t compile error
++    - LP: #887780
++  * CHROMIUM: Fix kref usage
++    - LP: #887780
++  * CHROMIUM: enable CONFIG_SECCOMP_FILTER and CONFIG_HAVE_SECCOMP_FILTER
++  * rebase to v3.2-rc2
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 31 Oct 2011 09:24:39 -0400
++
++linux (3.1.0-2.3) precise; urgency=low
++
++  [ Tim Gardner ]
++
++  * Add postinit and postrm scripts to the extras package
++    - LP: #882120
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 28 Oct 2011 12:48:33 -0700
++
++linux (3.1.0-2.2) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * debian: add locking to protect debian/files from parallel update
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.1
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 19 Oct 2011 07:12:38 -0700
++
++linux (3.1.0-1.1) precise; urgency=low
++
++  [ Andiry Xu ]
++
++  * SAUCE: (drop during 3.2 merge) xHCI: AMD isoc link TRB chain bit quirk
++    - LP: #872811
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: compcache -- follow changes to bd_claim/bd_release"
++    - LP: #832694
++  * Revert "ubuntu: compcache -- version 0.5.3"
++    - LP: #832694
++  * [Config] standardise CONFIG_NETFILTER_XT_TARGET_TCPOPTSTRIP=m
++  * [Config] Enable CONFIG_MACVTAP=m
++    - LP: #822601
++  * record the compiler in the ABI and check for inconsistant builds
++  * [Config] move ECRYPT_FS back to =y for all architectures
++    - LP: #827197
++  * [Config] enable CONFIG_DRM_VMWGFX=m
++    - LP: #698009
++  * [Config] re-fix ECRYPT_FS=y
++    - LP: #827197
++  * enforcer -- ensure we have CONFIG_ECRYPT_FS=y
++    - LP: #827197
++  * [Config] dropping compcache configuration options
++  * [Config] standardise on HZ=250
++  * SAUCE: headers_install: fix #include "..." usage for userspace
++    - LP: #824377
++  * make module-inclusion selection retain the left overs
++  * add a new linux-image-extras package for virtual
++
++  [ Colin Watson ]
++
++  * Deliver more Atheros, Ralink, and iwlagn NIC drivers to d-i
++
++  [ edwin_rong ]
++
++  * SAUCE: Staging: add driver for Realtek RTS5139 cardreader
++    - LP: #824273
++
++  [ Greg Kroah-Hartman ]
++
++  * SAUCE: staging: rts5139: add vmalloc.h to some files to fix the build.
++    - LP: #824273
++
++  [ Jesse Sung ]
++
++  * SAUCE: Unregister input device only if it is registered
++    - LP: #839238
++
++  [ Jiri Kosina ]
++
++  * SAUCE: HID: add MacBookAir4, 2 to hid_have_special_driver[]
++
++  [ Joshua V. Dillon ]
++
++  * SAUCE: HID: add support for MacBookAir4,2 keyboard.
++
++  [ Kees Cook ]
++
++  * [Config] enable and enforce SECCOMP_FILTER on x86
++
++  [ Keng-Yu Lin ]
++
++  * [Config] Enable CONFIG_RTS5139=m on i386/amd64
++    - LP: #824273
++
++  [ Leann Ogasawara ]
++
++  * Revert "ubuntu: overlayfs -- ovl: make lower mount read-only"
++  * Revert "ubuntu: overlayfs -- fs: limit filesystem stacking depth"
++  * Revert "ubuntu: overlayfs -- ovl: improve stack use of lookup and
++    readdir"
++  * Revert "ubuntu: overlayfs -- ovl: fix overlayfs over overlayfs"
++  * Revert "ubuntu: overlayfs -- overlayfs: implement show_options"
++  * Revert "ubuntu: overlayfs -- overlayfs: add statfs support"
++  * Revert "ubuntu: overlayfs -- overlay filesystem"
++  * Revert "ubuntu: overlayfs -- overlay: overlay filesystem documentation"
++  * Revert "SAUCE: ARM: OMAP: Add macros for comparing silicon revision"
++  * Revert "SAUCE: OMAP: DSS2: check for both cpu type and revision, rather
++    than just revision"
++  * Revert "SAUCE: OMAP: DSS2: enable hsclk in dsi_pll_init for OMAP36XX"
++  * Revert "ubuntu: fsam7400 disable driver"
++    - LP: #876030
++  * rebase to v3.1-rc1
++  * [Config] updateconfigs after rebase to v3.1-rc1
++  * rebase to v3.1-rc2
++  * [Config] Updateconfigs after rebase to v3.1-rc2
++  * ubuntu: Yama - update calls to generic_permission() and
++    inode->i_op->permission()
++  * ubuntu: ndiswrapper -- remove netdev_priv macro
++  * ubuntu: aufs -- Temporarily disable due to build failure
++  * [Config] Diable INTEL_MID_PTI on armel
++  * [Config] Temporarily disable CONFIG_FTMAC100 on armel
++  * [Config] Temporarily disable CONFIG_FTGMAC100 on armel
++  * [Config] Temporarily disable CONFIG_CAN_TI_HECC on armel
++  * [Config] Temporarily disable CONFIG_VIDEO_OMAP2_VOUT on armel
++  * [Config] Set CONFIG_DM_MIRROR=m on amd64, i386, and arm
++  * [Config] Set CONFIG_DM_MULTIPATH=m on amd64, i386, and arm
++  * [Config] Set CONFIG_DM_SNAPSHOT=m on amd64, i386, and arm
++  * [Config] Enable CONFIG_EDAC_AMD8111=m on powerpc
++  * [Config] Enable CONFIG_EDAC_AMD8131=m on powerpc
++  * [Config] Enable CONFIG_EDAC_CPC925=m on powerpc
++  * [Config] Enable CONFIG_EDAC_PASEMI=m on powerpc
++  * [Config] Enable CONFIG_ECHO=m on powerpc
++  * [Config] Enable CONFIG_ET131X=m on powerpc
++  * [Config] Set CONFIG_FB_MATROX=m
++  * [Config] Enable CONFIG_FB_UDL=m on powerpc
++  * [Config] Set CONFIG_FB_VIRTUAL=n
++  * [Config] Enable CONFIG_FB_VGA16=m on powerpc
++  * [Config] Enable CONFIG_GPIO_MAX732X=m on arm
++  * [Config] Enable CONFIG_GPIO_PCF857X=m on arm
++  * [Config] Set CONFIG_HOTPLUG_PCI_FAKE=m
++  * [Config] Enable CONFIG_HOTPLUG_PCI=y on powerpc
++  * [Config] Enable CONFIG_HOTPLUG_PCI_CPCI=y on powerpc
++  * [Config] Enable CONFIG_HP_ILO=m on powerpc-smp
++  * [Config] Enable CONFIG_I2C_PASEMI=m on powerpc
++  * [Config] Enable CONFIG_IBM_BSR=m on powerpc
++  * [Config] Enable CONFIG_IBMVETH=m on powerpc
++  * [Config] Enable CONFIG_IDE_PHISON=m on powerpc
++  * [Config] Enable CONFIG_IGB=m on powerpc
++  * [Config] Enable CONFIG_IIO=m on powerpc
++  * [Config] Enable CONFIG_INFINIBAND_NES=m
++  * [Config] Enable CONFIG_IPMI_HANDLER=m on arm
++  * [Config] Enable CONFIG_IWL3945=m on powerpc
++  * [Config] Disable CONFIG_KVM_BOOK3S_64
++  * [Config] Enable CONFIG_LAPBETHER=m on arm
++  * [Config] Enable CONFIG_LEDS_GPIO=m on powerpc
++  * [Config] Enable CONFIG_LEDS_CLEVO_MAIL=m all arch's
++  * [Config] Enable CONFIG_LEDS_PCA9532=m on powerpc
++  * [Config] Enable CONFIG_LEDS_PCA955X=m on powerpc
++  * [Config] Enable CONFIG_LEDS_TRIGGER_DEFAULT_ON=m on powerpc
++  * [Config] Set CONFIG_LEDS_TRIGGER_HEARTBEAT=m on arm and powerpc
++  * [Config] Set CONFIG_LEDS_TRIGGER_TIMER=m on powerpc
++  * [Config] Enable CONFIG_LINE6_USB=m on arm and powerpc
++  * [Config] Enable CONFIG_MEMSTICK=m on arm
++  * [Config] Enable CONFIG_MTD_AFS_PARTS=m on arm
++  * [Config] Enable CONFIG_MTD_ALAUDA=m on arm
++  * [Config] Enable CONFIG_MTD_AR7_PARTS=m on arm
++  * [Config] Enable CONFIG_MTD_ARM_INTEGRATOR=m on arm
++  * [Config] Enable CONFIG_MOXA_SMARTIO=m on powerpc
++  * [Config] Enable CONFIG_MTD_DATAFLASH=m on arm
++  * [Config] Enable CONFIG_MTD_GPIO_ADDR=m on arm
++  * [Config] Enable CONFIG_MTD_IMPA7=m on arm
++  * [Config] Enable CONFIG_MTD_NAND_GPIO=m on arm
++  * [Config] Enable CONFIG_MTD_NAND_NANDSIM=m on arm
++  * [Config] Enable CONFIG_MTD_NAND_PASEMI=m on powerpc
++  * [Config] Enable CONFIG_MTD_NAND_PLATFORM=m on arm
++  * [Config] Enable CONFIG_MTD_NAND_TMIO=m on arm
++  * [Config] Enable CONFIG_MTD_SST25L=m on arm
++  * [Config] Enable CONFIG_NET_CLS_CGROUP=y on arm
++  * [Config] Enable CONFIG_NET_CLS_FLOW=m on arm
++  * [Config] Enable CONFIG_NET_CLS_U32=m on arm
++  * [Config] Enable CONFIG_NET_DCCPPROBE=m on arm
++  * [Config] Enable CONFIG_NET_SCH_INGRESS=m on arm
++  * [Config] Enable CONFIG_NET_TCPPROBE=m on arm
++  * [Config] Enable CONFIG_PASEMI_MAC=m on powerpc
++  * [Config] Enable CONFIG_PATA_NS87410=m on powerpc
++  * [Config] Enable CONFIG_I2C_GPIO=m on powerpc64-smp
++  * [Config] Enable CONFIG_PANEL=m on powerpc
++  * [Config] Enable CONFIG_PATA_CMD640_PCI=m on powerpc
++  * SAUCE: x86: reboot: Make Dell Latitude E6520 use reboot=pci
++    - LP: #833705
++  * [Config] Add CONFIG_EFI_VARS=y to the enforcer
++    - LP: #837332
++  * [Config] Update CONFIG_EFI_VARS enforcer check
++  * [Config] Add aufs to virtual flavor inclusion list
++    - LP: #844159
++  * SAUCE: x86: reboot: Make Dell Optiplex 790 use reboot=pci
++    - LP: #818933
++  * SAUCE: x86: reboot: Make Dell Optiplex 990 use reboot=pci
++    - LP: #768039
++  * SAUCE: x86: reboot: Make Dell Latitude E6220 use reboot=pci
++    - LP: #838402
++  * [Config] Add igbvf to the virtual flavor inclusion list
++    - LP: #794570
++  * [Config] Add ixgbevf to the virtual inclusion list
++    - LP: #872411
++  * [Config] Transition -generic and -server to be identical
++  * rebase to v3.1-rc10
++
++  [ Luke Yelavich ]
++
++  * [Config] Disable legacy IDE drivers on powerpc
++
++  [ Ming Lei ]
++
++  * SAUCE: fireware: add NO_MSI quirks for o2micro controller
++    - LP: #801719
++  * SAUCE: ata_piix: make DVD Drive recognisable on systems with Intel
++    Sandybridge chipsets(v2)
++    - LP: #737388, #782389, #794642
++
++  [ Paolo Pisati ]
++
++  * [Config] Compile-in vfat support for armel
++    - LP: #853783
++
++  [ Randy Dunlap ]
++
++  * SAUCE: staging: fix rts5139 depends & build
++    - LP: #824273
++
++  [ Rene Bolldorf ]
++
++  * SAUCE: (drop after 3.0) ideapad: Check if acpi already handle backlight
++    power in 'ideapad_backlight_notify_power' to avoid a page fault
++
++  [ Seth Forshee ]
++
++  * SAUCE: (no-up) Input: elantech - Add v3 hardware support
++    - LP: #681904
++  * SAUCE: (drop after 3.1) usb_storage: Don't freeze in usb-stor-scan
++    - LP: #810020
++
++  [ Stefan Bader ]
++
++  * (config) Package macvlan and macvtap for virtual
++  * [Config] Force perf to use libiberty for demangling
++    - LP: #783660
++  * SAUCE: xen: Do not use pv spinlocks on HVM
++    - LP: #838026
++
++  [ Tim Gardner ]
++
++  * [Config] Clean up tools rules
++  * [Config] Package x86_energy_perf_policy and turbostat
++    - LP: #797556
++  * rebase to v3.1-rc3
++  * [Config] Simplify binary-udebs dependencies
++  * [Config] kernel preparation cannot be parallelized
++  * [Config] Linearize module/abi checks
++  * [Config] Linearize and simplify tree preparation rules
++  * [Config] Build kernel image in parallel with modules
++  * [Config] Set concurrency for kmake invocations
++  * [Config] Improve install-arch-headers speed
++  * [Config] Fix binary-perarch dependencies
++  * [Config] Removed stamp-flavours target
++  * [Config] Serialize binary indep targets
++  * [Config] Use build stamp directly
++  * [Config] Restore prepare-% target
++  * rebase to v3.1-rc4
++  * rebase to v3.1-rc5
++  * [Config] Disable makedumpfile for i386/amd64
++  * rebase to v3.1-rc6
++  * [Config] Fix binary-% build target
++  * rebase to v3.1-rc7
++  * rebase to v3.1-rc8
++  * SAUCE: Add a new entry (413c:8197) to Bluetooth USB device ID table
++    - LP: #854399
++  * [Config] Enable ftrace support in the mac80211 layer
++    - LP: #865171
++  * rebase to v3.1-rc9
++  * SAUCE: usb/core/devio.c: Check for printer class specific request
++    - LP: #872711
++
++  [ Upstream Kernel Changes ]
++
++  * overlay filesystem
++  * overlayfs: add statfs support
++  * overlayfs: implement show_options
++  * overlay: overlay filesystem documentation
++  * fs: limit filesystem stacking depth
++
++  [ Will Drewry ]
++
++  * SAUCE: seccomp_filter: new mode with configurable syscall filters
++  * SAUCE: seccomp_filter: add process state reporting
++  * SAUCE: seccomp_filter: Document what seccomp_filter is and how it
++    works.
++  * SAUCE: seccomp_filter: add HAVE_SECCOMP_FILTER and seccomp_execve
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.1-rc1
++  * rebase to v3.1-rc2
++  * rebase to v3.1-rc3
++    +CONFIG_BLK_DEV_BSGLIB=y
++    +CONFIG_BLK_DEV_LOOP_MIN_COUNT=8
++    -CONFIG_VIDEO_OMAP2_VOUT_VRFB=y
++  * rebase to v3.1-rc4
++  * rebase to v3.1-rc5
++  * rebase to v3.1-rc6
++  * rebase to v3.1-rc7
++  * rebase to v3.1-rc8
++  * rebase to v3.1-rc9
++  * rebase to v3.1-rc10
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 10 Aug 2011 15:43:38 -0700
++
++linux (3.1.0-1.0) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Open P-series
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 10 Aug 2011 13:42:40 -0700
++
++linux (3.0.0-8.10) oneiric; urgency=low
++
++  [ Adam Jackson ]
++
++  * SAUCE: drm/i915/pch: Fix integer math bugs in panel fitting
++    - LP: #753994
++
++  [ John Johansen ]
++
++  * [Config] Enable missing IPv6 options
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable config IWLWIFI_DEVICE_SVTOOL
++    - LP: #819925
++  * Rebase to 3.0.1
++
++  [ Upstream Kernel Changes ]
++
++  * x86, intel, power: Correct the MSR_IA32_ENERGY_PERF_BIAS message
++  * ALSA: hda - Turn on extra EAPDs on Conexant codecs
++    - LP: #783582
++  * KVM: Remove SMEP bit from CR4_RESERVED_BITS
++    - LP: #796476
++  * KVM: Add SMEP support when setting CR4
++    - LP: #796476
++  * KVM: Mask function7 ebx against host capability word9
++    - LP: #796476
++  * KVM: Add instruction fetch checking when walking guest page table
++    - LP: #796476
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.0.1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 05 Aug 2011 11:32:25 -0700
++
++linux (3.0.0-7.9) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Upstream] add local prefix to oss local change_bits"
++  * Revert "SAUCE: add tracing for user initiated readahead requests"
++  * Revert "SAUCE: vfs: Add a trace point in the mark_inode_dirty function"
++  * Revert "SAUCE: Input: ALPS - Enable Intellimouse mode for Lenovo
++    Zhaoyang E47"
++  * Revert "SAUCE: fix documentation strings for struct input_keymap_entry"
++  * Revert "SAUCE: vt -- fix handoff numbering to 1..n and add range checks
++    (grub)"
++  * Revert "SAUCE: vt -- fix handoff numbering to 1..n and add range
++    checks"
++  * Revert "SAUCE: vt -- allow grub to request automatic vt_handoff"
++  * Revert "SAUCE: vt -- maintain bootloader screen mode and content until
++    vt switch"
++  * [Config] enable CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT=1
++    - LP: #816035
++  * ubuntu: Yama: if an underlying filesystem provides a permissions op use
++    it
++  * SAUCE: (no-up) add tracing for user initiated readahead requests
++  * SAUCE: vt -- maintain bootloader screen mode and content until vt
++    switch
++  * SAUCE: vt -- allow grub to request automatic vt_handoff
++
++  [ Arjan van de Ven ]
++
++  * SAUCE: (no-up) vfs: Add a trace point in the mark_inode_dirty function
++
++  [ Kees Cook ]
++
++  * Revert "SAUCE: (no-up) Disable building the ACPI debugfs source"
++  * [Config] enforce ACPI_CUSTOM_METHOD disabled
++
++  [ Keng-Yu Lin ]
++
++  * SAUCE: (no-up) Input: ALPS - Enable Intellimouse mode for Lenovo
++    Zhaoyang E47
++    - LP: #632884, #803005
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_BLK_DEV_CMD64X=m on powerpc
++    - LP: #513131
++  * [Config] Enable CONFIG_RT2800PCI_RT53XX=y
++    - LP: #815064
++
++  [ Rezwanul Kabir ]
++
++  * SAUCE: (no-up) Add support for Intellimouse Mode in ALPS touchpad on
++    Dell E2 series Laptops
++    - LP: #632884
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "yama: if an underlying filesystem provides a permissions op use
++    it"
++  * Revert "Add support for Intellimouse Mode in ALPS touchpad on Dell E2
++    series Laptops"
++  * Revert "tty: include linux/slab.h for kfree"
++  * Revert "gpio/ml_ioh_gpio: include linux/slab.h for kfree"
++  * Revert "pch_dma: add include/slab.h for kfree"
++  * mmc: Added quirks for Ricoh 1180:e823 lower base clock frequency
++    - LP: #773524
++  * oss: rename local change_bits to avoid powerpc bitsops.h definition
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 25 Jul 2011 09:08:01 -0700
++
++linux (3.0.0-7.8) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: overlayfs -- overlayfs: add statfs support
++  * [Config] enable CONFIG_OVERLAYFS
++
++  [ Erez Zadok ]
++
++  * ubuntu: overlayfs -- overlayfs: implement show_options
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_ALIM7101_WDT=m on powerpc
++  * [Config] Enable CONFIG_ASUS_OLED=m on powerpc
++  * [Config] Disable CONFIG_ATM_DUMMY on arm
++  * [Config] Enable CONFIG_BLK_DEV_DRBD=m on powerpc
++  * Temporarily disable module check on arm
++  * Rebase to 3.0 final
++  * [Config] Enable CONFIG_CAN_TI_HECC=m on arm
++  * [Config] Set CONFIG_CDROM_PKTCDVD=m on amd64 and i386
++  * [Config] Enable CONFIG_CRYPTO_CCM=m on powerpc
++  * [Config] Enable CONFIG_CRYPTO_DEV_HIFN_795X=m on powerpc
++  * [Config] Enable CONFIG_CRYPTO_GCM=m on powerpc
++  * [Config] Set CRYPTO_LZO=m on powerpc64-smp
++  * [Config] Enable CONFIG_DM9000=m on arm
++  * [Config] Set CONFIG_DISPLAY_SUPPORT=m on arm
++  * [Config] Enable CONFIG_DL2K=m on amd64 and i386
++
++  [ Miklos Szeredi ]
++
++  * ubuntu: overlayfs -- vfs: add i_op->open()
++  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
++  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
++  * ubuntu: overlayfs -- overlay filesystem
++  * ubuntu: overlayfs -- ovl: fix overlayfs over overlayfs
++  * ubuntu: overlayfs -- ovl: improve stack use of lookup and readdir
++  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
++  * ubuntu: overlayfs -- ovl: make lower mount read-only
++
++  [ Neil Brown ]
++
++  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
++
++  [ Tim Gardner ]
++
++  * [Config] Add enic/fnic to udebs
++    - LP: #801610
++
++  [ Upstream Kernel Changes ]
++
++  * yama: if an underlying filesystem provides a permissions op use it
++
++  [ Major Kernel Changes ]
++
++  * Rebase to 3.0 final
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 21 Jul 2011 07:01:32 -0700
++
++linux (3.0.0-6.7) oneiric; urgency=low
++
++  [ Eagon Yager ]
++
++  * [Config] Fix misspelled 'skipmodule' in arm makefile.
++
++  [ Keng-Yu Lin ]
++
++  * SAUCE: Input: ALPS - Enable Intellimouse mode for Lenovo Zhaoyang E47
++    - LP: #632884, #803005
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Config] Temporarily disable CONFIG_SMC91X on armel-omap"
++  * Revert "[Config] Temporarily Disable CONFIG_BRCMSMAC on arm"
++  * Revert "[Config] Temporarily Disable CONFIG_RTL8192SE on powerpc"
++  * Revert "[Config] Temporarily Disable CONFIG_RTL8192SE on arm"
++  * Revert "[Config] Temporarily disable CONFIG_BRCMSMAC on powerpc"
++  * [Config] Set CONFIG_ACPI_PCI_SLOT=m
++  * [Config] Set CONFIG_ACPI_SBS=m
++  * [Config] Set CONFIG_ACPI_WMI=m
++  * [Config] Set CONFIG_AD7150=m on arm
++  * [Config] Set CONFIG_AD7152=m on arm
++  * [Config] Drop CONFIG_GPIO_S5PV210
++  * [Config] Drop CONFIG_GPIO_S5PC100
++  * [Config] Drop CONFIG_GPIO_PLAT_SAMSUNG
++  * [Config] Drop CONFIG_GPIO_EXYNOS4
++
++  [ Stefan Bader ]
++
++  * SAUCE: Re-enable RODATA for i386 virtual
++    - LP: #809838
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "Quirk to fix suspend/resume on Lenovo Edge 11,13,14,15"
++  * (drop after 3.0.0) acer-wmi: Add support for Aspire 1830 wlan hotkey
++    - LP: #771758
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 20 Jul 2011 06:36:02 -0700
++
++linux (3.0.0-5.6) oneiric; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_RTL8192CU=m
++  * Rebase to -rc7
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 11 Jul 2011 22:13:50 +0100
++
++linux (3.0.0-4.5) oneiric; urgency=low
++
++  [ Ming Lei ]
++
++  * SAUCE: fix yama_ptracer_del lockdep warning
++    - LP: #791019
++
++  [ Seth Forshee ]
++
++  * SAUCE: (drop after 3.0) asus-wmi: Add callback for hotkey filtering
++  * SAUCE: (drop after 3.0) eeepc-wmi: Add support for T101MT Home/Express Gate key
++  * SAUCE: (drop after 3.0) asus-wmi: Enable autorepeat for hotkey input device
++  * [Config] CONFIG_{ASUS,ASUS_NB,EEEPC}_WMI=m
++    - LP: #805218
++
++  [ Tim Gardner ]
++
++  * [Config] updateconfigs after rebase to -rc6+
++    Rebased against 4dd1b49c6d215dc41ce50c80b4868388b93f31a3
++  * Adopt a 3 digit verion, e.g., 3.0.0-x.x
++  * Revert "UBUNTU: add dependancies for module-init-tools"
++    This dependency is no longer required for a 3 digit version.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 05 Jul 2011 14:03:04 +0100
++
++linux (3.0-3.4) oneiric; urgency=low
++
++  [ Keng-Yu Lin ]
++
++  * SAUCE: Revert: "dell-laptop: Toggle the unsupported hardware
++    killswitch"
++    - LP: #775281
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc5
++  * [Config] updateconfigs after rebase to 3.0-rc5
++
++  [ Tim Gardner ]
++
++  * [Config] Remove ubuntu/rtl8192se
++  * [Config] Added armel ABI files
++  * [Config] Removed armel versatile flavour
++  * [Config] CONFIG_INTEL_MEI=m
++    - LP: #716867
++
++  [ Upstream Kernel Changes ]
++
++  * ALSA: hda - Enable auto-parser as default for Conexant codecs
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.0-rc5
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 30 Jun 2011 14:27:10 +0100
++
++linux (3.0-2.3) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: AUFS -- update to 0e2bafab74f0d1463383faeb93f9fc5eb8c2c54e
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc4
++  * [Config] updateconfigs after rebase to 3.0-rc4
++  * fix ERROR: __devcgroup_inode_permission undefined
++
++  [ Stefan Bader ]
++
++  * SAUCE: iscsitarget: Remove driver from the kernel
++
++  [ Tim Gardner ]
++
++  * SAUCE: rtl8192se: Force a build for a 2.6/3.0 kernel
++  * [Config] Add grub-efi as a recommended bootloader for server and
++    generic
++    - LP: #800910
++
++  [ Upstream Kernel Changes ]
++
++  * Fix node_start/end_pfn() definition for mm/page_cgroup.c
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 24 Jun 2011 11:51:12 -0700
++
++linux (3.0-1.2) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_CAN_CALC_BITTIMING
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc3
++  * [Config] updateconfigs after rebase to 3.0-rc3
++
++  [ Upstream Kernel Changes ]
++
++  * perf: clear out make flags when calling kernel make kernelver
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc3
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 14 Jun 2011 07:25:35 -0700
++
++linux (3.0-0.1) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * use the packaging version in the kernel
++  * use the kernels idea of its version for version_signature
++  * add dependancies for module-init-tools
++  * update control files to version 3
++  * printchanges/insertchanges allow override of prev_release
++  * correct Vcs-Git: to point to oneiric
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc1
++  * [Config] updateconfigs after rebase to 3.0-rc1
++  * ubuntu: dm-raid4-5 fix up build failure
++  * [Config] Temporarily Disable CONFIG_GPIO_EXYNOS4 on arm
++  * [Config] Temporarily Disable CONFIG_GPIO_PLAT_SAMSUNG on arm
++  * [Config] Temporarily Disable CONFIG_GPIO_S5PC100 on arm
++  * [Config] Temporarily Disable CONFIG_GPIO_S5PV210 on arm
++  * [Config] Temporarily disable CONFIG_BRCMSMAC on powerpc
++  * [Config] Temporarily Disable CONFIG_BRCMSMAC on arm
++  * [Config] Temporarily Disable CONFIG_RTL8192SE on arm
++  * [Config] Temporarily Disable CONFIG_RTL8192SE on powerpc
++  * [Config] Temporarily disable CONFIG_SMC91X on armel-omap
++  * rebase to v3.0-rc2
++
++  [ Manoj Iyer ]
++
++  * SAUCE: mmc: Enable MMC card reader for RICOH [1180:e823]
++    - LP: #790754
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "x86 idle: EXPORT_SYMBOL(default_idle, pm_idle) only when APM
++    demands it"
++  * drm/i915: fix regression after clock gating init split
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39 to v3.0-rc1
++  * rebase from v3.0-rc1 to v3.0-rc2
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 09 Jun 2011 15:18:33 +0100
++
++linux (2.6.39-3.10) oneiric; urgency=low
++
++  [ Colin Ian King ]
++
++  * SAUCE: S3 early resume debug via keyboard LEDs
++
++  [ Ingo Molnar ]
++
++  * ubuntu: nx-emu - i386: NX emulation
++  * ubuntu: nx-emu - i386: mmap randomization for executable mappings
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Config] Disable CONFIG_FT1000 on powerpc64-smp"
++  * Revert "[Config] Disable CONFIG_DM_RAID45"
++  * [Config] enable CONFIG_BRCMFMAC=y
++  * [Config] enable CONFIG_MDIO_BITBANG=m across all arch's and flavors
++  * [Config] enable CONFIG_VIDEO_OUTPUT_CONTROL=m on armel-omap
++
++  [ Robert Nelson ]
++
++  * SAUCE: omap3: beagle: detect new xM revision B
++    - LP: #770679
++  * SAUCE: omap3: beagle: detect new xM revision C
++    - LP: #770679
++  * SAUCE: omap3: beagle: if rev unknown, assume xM revision C
++    - LP: #770679
++
++  [ Stefan Bader ]
++
++  * SAUCE: Convert dm-raid45 to new block plugging
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 May 2011 11:46:43 -0700
++
++linux (2.6.39-3.9) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable CONFIG_SCSI_LPFC_DEBUG_FS
++  * rebase to v2.6.39
++  * [Config] enable CONFIG_LLC2=m across all arch's and flavours
++  * [Config] enable CONFIG_INPUT_APANEL=m
++
++  [ Thomas Schlichter ]
++
++  * SAUCE: vesafb: mtrr module parameter is uint, not bool
++    - LP: #778043
++  * SAUCE: vesafb: enable mtrr WC by default
++    - LP: #778043
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc7 to v2.6.39
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 20 May 2011 09:52:32 +0100
++
++linux (2.6.39-2.8) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-37"
++  * Revert "ubuntu: AUFS -- aufs2-base.patch aufs2.1-37"
++  * Revert "[Config] Disable CONFIG_AUFS_FS"
++  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-39
++  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-39
++  * ubuntu: AUFS -- update to c6b76974311efc5bf3eddf921cd015b6aae46935
++  * ubuntu: AUFS -- clean up the aufs updater and BOM
++  * ubuntu: AUFS -- documentation on updating aufs2
++
++  [ Kees Cook ]
++
++  * ubuntu: Yama - LSM hooks
++  * ubuntu: Yama - create task_free security callback
++  * ubuntu: Yama - add ptrace relationship tracking interface
++  * ubuntu: Yama - unconditionally chain to Yama LSM
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: Fix drivers/staging/easycap FTBS"
++  * Revert "[Config] Disable CONFIG_EASYCAP"
++  * ubuntu: fsam7400 disable driver
++  * ubuntu: omnibook disable driver
++  * ubuntu: rfkill disable driver
++
++  [ Tim Gardner ]
++
++  * SAUCE: Fix extra reference in fb_open()
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 May 2011 09:23:56 -0700
++
++linux (2.6.39-2.7) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc7
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc6 to v2.6.39-rc7
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 10 May 2011 10:18:28 +0200
++
++linux (2.6.39-1.6) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc6
++  * SAUCE: [arm] fixup __aeabi_uldivmod undefined build error
++
++  [ Tim Gardner ]
++
++  * [Config] updateconfigs after rebase to 2.6.39-rc6
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc5 to v2.6.39-rc6
++    - LP: #740126
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 05 May 2011 09:46:12 -0700
++
++linux (2.6.39-0.5) oneiric; urgency=low
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * SAUCE: Revert "x86, hibernate: Initialize mmu_cr4_features during boot"
++    - LP: #764758
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc5
++  * [Config] updateconfigs following rebase to v2.6.39-rc5
++
++  [ Paolo Pisati ]
++
++  * [Config] s/USB_MUSB_TUSB6010/USB_MUSB_OMAP2PLUS/ on omap3 to get musb
++    - LP: #759913
++
++  [ Stefan Bader ]
++
++  * Include nls_iso8859-1 for virtual images
++    - LP: #732046
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc4 to v2.6.39-rc5
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 27 Apr 2011 06:39:42 -0700
++
++linux (2.6.39-0.4) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc4
++  * [Config] updateconfigs following rebase to v2.6.39-rc4
++  * fixup powerpc implicit declaration of function
++    'crash_kexec_wait_realmode'
++  * [Config] Disable CONFIG_FT1000 on powerpc64-smp
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_TRANSPARENT_HUGEPAGE=y
++    - LP: #769503
++  * [Config] Add cachefiles.ko to virtual flavour
++    - LP: #770430
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc3 to v2.6.39-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 19 Apr 2011 06:25:20 -0700
++
++linux (2.6.39-0.3) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc3
++  * crash_kexec_wait_realmode() undefined when !SMP
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_PM_ADVANCED_DEBUG=y for i386/amd64
++    - LP: #632327
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc2 to v2.6.39-rc3
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 12 Apr 2011 06:52:24 -0700
++
++linux (2.6.39-0.2) oneiric; urgency=low
++
++  [ Gustavo F. Padovan ]
++
++  * SAUCE: Revert "Bluetooth: Add new PID for Atheros 3011"
++    - LP: #720949
++
++  [ John Johansen ]
++
++  * AppArmor: Fix masking of capabilities in complain mode
++    - LP: #748656
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc2
++  * [Config] updateconfigs following rebase to v2.6.39-rc2
++  * hv_mouse needs delay.h
++  * olpc_dcon_xo_1 needs delay.h
++  * olpc_dcon_xo_1_5 needs delay.h
++  * Update dropped.txt for Oneiric
++
++  [ Steve Langasek ]
++
++  * [Config] Make linux-libc-dev coinstallable under multiarch
++    - LP: #750585
++
++  [ Upstream Kernel Changes ]
++
++  * x86, hibernate: Initialize mmu_cr4_features during boot
++    - LP: #752870
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc1 to v2.6.39-rc2
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 06 Apr 2011 11:04:15 -0700
++
++linux (2.6.39-0.1) oneiric; urgency=low
++
++  [ Brad Figg ]
++
++  * [Config] Set CONFIG_NR_CPUS=256 for amd64 generic
++    - LP: #737124
++
++  [ Henrik Rydberg ]
++
++  * SAUCE: HID: hid-ntrig: add support for 1b96:0006 model
++  * SAUCE: HID: ntrig: fix suspend/resume on recent models
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * SAUCE: (drop after 2.6.39) v4l: make sure drivers supply a zeroed
++    struct v4l2_subdev
++    - LP: #745213
++
++  [ Kees Cook ]
++
++  * [Config] packaging: adjust perms on vmlinuz as well
++  * SAUCE: nx-emu: further clarify dmesg reporting
++    - LP: #745181
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc1
++  * [Config] updateconfigs following rebase to v2.6.39-rc1
++  * [Config] Disable CONFIG_DM_RAID45
++  * [Config] Disable CONFIG_SCSI_ISCSITARGET
++  * [Config] Disable CONFIG_EASYCAP
++  * [Config] Disable CONFIG_AUFS_FS
++  * update bnx2 firmware files in d-i/firmware/nic-modules
++  * xhci-pci.c resolve implicit declaration of kzalloc
++  * [Config] Enable CONFIG_DRM_PSB for only x86
++  * [Config] Enable CONFIG_RTS_PSTOR for only x86
++  * mfd/asic3: Fix typo, s/irq_data/data/
++
++  [ Luke Yelavich ]
++
++  * [Config] Disable CONFIG_CRASH_DUMP on 32-bit powerpc kernels
++    - LP: #745358
++  * [Config] Disable CONFIG_DRM_RADEON_KMS on powerpc kernels
++  * [Config] Build some framebuffer drivers as modules for powerpc kernels.
++
++  [ Manoj Iyer ]
++
++  * SAUCE: thinkpad-acpi: module autoloading for newer Lenovo ThinkPads.
++    - LP: #745217
++
++  [ Tim Gardner ]
++
++  * SAUCE: INR_OPEN=4096
++    - LP: #663090
++  * SAUCE: Increase the default hard limit for open FDs to 4096
++    - LP: #663090
++
++  [ Upstream Kernel Changes ]
++
++  * (drop after 2.6.39-rc1) arm: versatile : Fix typo introduced in irq
++    namespace cleanup
++  * (drop after 2.6.39-rc1) [media] staging: altera-jtag needs delay.h
++  * ALSA: pcm: fix infinite loop in snd_pcm_update_hw_ptr0()
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38 to v2.6.39-rc1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Mar 2011 12:50:10 -0700
++
++linux (2.6.39-0.0) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Open Oneiric 
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Mar 2011 12:29:23 -0700
++
++linux (2.6.38-7.39) natty; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * No change upload.  This is just to rebuild with gcc-4.5.2-7ubuntu1.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 24 Mar 2011 09:27:45 -0700
++
++linux (2.6.38-7.38) natty; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * No change upload take 2.  2.6.38-7.37 was accidentally uploaded before
++    gcc-4.5.2-6ubuntu5 finished building on all arches.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 22 Mar 2011 06:12:47 -0700
++
++linux (2.6.38-7.37) natty; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * No change upload.  This is just to rebuild with gcc-4.5.2-6ubuntu5.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 20 Mar 2011 16:02:48 -0700
++
++linux (2.6.38-7.36) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: KLUDGE: work around failed 'shrink-wrap' compiler
++    optimisation"
++  * purge last vestiges of maverick
++  * [Config] switch CONFIG_FB_VESA back to module
++
++  [ Chris Wilson ]
++
++  * SAUCE: drm/i915: Fix pipelined fencing
++    - LP: #717114
++
++  [ Loïc Minier ]
++
++  * Include nls_cp437 module in virtual for fat
++    - LP: #732046
++  * Support arch= cross-compilation for any arch
++  * Fix couple of typos in 0-common-vars.mk
++  * Enforce DEFAULT_MMAP_MIN_ADDR on armhf
++  * Add armhf to Debian -> Linux arch map
++  * Add initial armhf.mk
++  * Enable common packages for armhf
++
++  [ Upstream Kernel Changes ]
++
++  * Yama: fix default relationship to check thread group
++    - LP: #737676
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 18 Mar 2011 18:18:02 +0000
++
++linux (2.6.38-7.35) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to 2fbfac4e053861925fa3fffcdc327649b09af54c
++  * rebase fixes bug #715330
++  * [Config] disable CONFIG_SCSI_QLA_ISCSI for powerpc 32bit to fix FTBS
++  * rebase to v2.6.38 final
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * SAUCE: Apply OPTION_BLACKLIST_SENDSETUP also for ZTE MF626
++    - LP: #636091
++
++  [ Tim Gardner ]
++
++  * [Confg] CONFIG_BOOT_PRINTK_DELAY=y
++
++  [ Upstream Kernel Changes ]
++
++  * Yama: use thread group leader when creating match
++    - LP: #729839
++  * (drop after 2.6.38) ahci: AHCI mode SATA patch for Intel Patsburg SATA
++    RAID controller
++    - LP: #735240
++  * (drop after v2.6.38) x86, quirk: Fix SB600 revision check
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38-rc8 to v2.6.38 final
++    - LP: #715330
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 15 Mar 2011 19:04:19 +0000
++
++linux (2.6.38-6.34) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] normalise CONFIG_INTEL_TXT
++  * SAUCE: KLUDGE: work around failed 'shrink-wrap' compiler optimisation
++    - LP: #730860
++  * rebase to mainline v2.6.38-rc8
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38-rc7 + fb62c00a6d8942775abc23d1621db1252e2d93d1
++    to v2.6.38-rc8
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 08 Mar 2011 11:54:48 +0000
++
++linux (2.6.38-6.33) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * d-i -- enable speakup-modules udeb
++    - LP: #672699
++  * rebase to 493f3358cb289ccf716c5a14fa5bb52ab75943e5
++  * [Config] debian PPC64 configuration
++  * [Config] cleanup powerpc config fixing unexpected inconsistancies
++  * [Config] resync ppc64 configuration
++  * SAUCE: match up ENTRY/END naming for 32/64 bit
++  * rebase to fb62c00a6d8942775abc23d1621db1252e2d93d1
++  * [Config] update configs after rebase to
++    fb62c00a6d8942775abc23d1621db1252e2d93d1
++  * [Config] pps_gen_parport no longer built
++
++  [ Corentin Chary ]
++
++  * SAUCE: (drop after 2.6.38) eeepc-wmi: reorder keymap
++    - LP: #689393
++  * SAUCE: (drop after 2.6.38) eeepc-wmi: add wlan key found on 1015P
++    - LP: #689393
++
++  [ John Johansen ]
++
++  * SAUCE: Fix aufs calling of security_path_mknod
++    - LP: #724456
++
++  [ Kees Cook ]
++
++  * SAUCE: proc: hide kernel addresses via %pK in /proc/<pid>/stack
++
++  [ Tim Gardner ]
++
++  * rebase to 2.6.38-rc7
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "drm/i915: fix corruptions on i8xx due to relaxed fencing"
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38-rc6 to v2.6.38-rc7 +
++    fb62c00a6d8942775abc23d1621db1252e2d93d1
++    - LP: #721389
++    - LP: #722925
++    - LP: #723672
++    - LP: #723676
++    - LP: #715318
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 07 Mar 2011 15:33:17 +0000
++
++linux (2.6.38-5.32) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to mainline 6f576d57f1fa0d6026b495d8746d56d949989161
++  * [Config] updateconfigs following rebase to v2.6.38-rc6
++  * [Config] enable CONFIG_DMAR
++    - LP: #552311
++
++  [ Upstream Kernel Changes ]
++
++  * drm/i915: skip FDI & PCH enabling for DP_A
++    - LP: #561802, #600453, #681877
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38-rc5 to v2.6.38-rc6
++    - LP: #718402
++    - LP: #719524
++    - LP: #721126
++    - LP: #719691
++    - LP: #722689
++    - LP: #722310
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 22 Feb 2011 13:28:39 +0000
++
++linux (2.6.38-4.31) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * add in bugs closed by upstream patches pulled in by rebases
++  * rebase to 795abaf1e4e188c4171e3cd3dbb11a9fcacaf505
++  * [Config] enable CONFIG_VSX to allow use of vector instuctions
++  * resync with maverick 98defa1c5773a3d7e4c524967eb01d5bae035816
++  * rebase to mainline v2.6.38-rc5
++  * SAUCE: ecryptfs: read on a directory should return EISDIR if not
++    supported
++    - LP: #719691
++
++  [ Colin Ian King ]
++
++  * SAUCE: Dell All-In-One: Remove need for Dell module alias
++
++  [ Manoj Iyer ]
++
++  * SAUCE: (drop after 2.6.38) add ricoh 0xe823 pci id.
++    - LP: #717435
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_CRYPTO_CRC32C_INTEL=y
++
++  [ Upstream Kernel Changes ]
++
++  * Quirk to fix suspend/resume on Lenovo Edge 11,13,14,15
++    - LP: #702434
++  * vfs: fix BUG_ON() in fs/namei.c:1461
++
++  [ Vladislav P ]
++
++  * SAUCE: Release BTM while sleeping to avoid deadlock.
++    - LP: #713837
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38-rc4 to v2.6.38-rc5
++    - LP: #579276
++    - LP: #715877
++    - LP: #713769
++    - LP: #716811
++  * resync with Maverick Ubuntu-2.6.35-27.47
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Feb 2011 17:24:09 +0000
++
++linux (2.6.38-3.30) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.38-rc4
++  * ppc64 -- add basic architecture
++  * ubuntu: AUFS -- update to 65835da20b77c98fb538c9114fc31f5de1328230
++
++  [ Colin Ian King ]
++
++  * SAUCE: Add WMI hotkeys support for Dell All-In-One series
++    - LP: #676997
++  * SAUCE: Add WMI hotkeys support for another Dell All-In-One series
++    - LP: #701530
++  * SAUCE: Dell WMI: Use sparse keymaps and tidy up code.
++    - LP: #701530
++
++  [ Dan Rosenberg ]
++
++  * SAUCE: (drop after 2.6.38) Convert net %p usage %pK
++
++  [ Kees Cook ]
++
++  * Revert "SAUCE: kernel: make /proc/kallsyms mode 400 to reduce ease of
++    attacking"
++  * SAUCE: (drop after 2.6.38) use %pK for /proc/kallsyms and /proc/modules
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_BLK_CGROUP=y
++    - LP: #706394
++  * [Config] CONFIG_DELL_WMI_AIO=m
++
++  [ Upstream Kernel Changes ]
++
++  * drm/i915/lvds: Restore dithering on native modes for gen2/3
++    - LP: #711568
++
++  [ Upstream Kernel Changes ]
++
++  * rebase from v2.6.38-rc3 to v2.6.38-rc4.
++    - LP: #701271
++    - LP: #708521
++    - LP: #710371
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 08 Feb 2011 02:07:18 +0000
++
++linux (2.6.38-2.29) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to 1f0324caefd39985e9fe052fac97da31694db31e
++  * [Config] updateconfigs following rebase to
++    1f0324caefd39985e9fe052fac97da31694db31e
++  * rebase to 70d1f365568e0cdbc9f4ab92428e1830fdb09ab0
++  * [Config] reenable HIBERNATE
++    - LP: #710877
++  * rebase to v2.6.38-rc3
++  * [Config] reenable CONFIG_CRASH_DUMP
++
++  [ Kamal Mostafa ]
++
++  * SAUCE: rtl8192se: fix source file perms
++  * SAUCE: rtl8192se: fix source file newline
++  * SAUCE: omnibook: fix source file newline
++
++  [ Kees Cook ]
++
++  * [Config] packaging: really make System.map mode 0600
++
++  [ Ricardo Salveti de Araujo ]
++
++  * SAUCE: OMAP3630: PM: don't warn the user with a trace in case of
++    PM34XX_ERRATUM
++
++  [ Soren Hansen ]
++
++  * SAUCE: nbd: Remove module-level ioctl mutex
++
++  [ Tim Gardner ]
++
++  * SAUCE: Disable building the ACPI debugfs source
++
++  [ Upstream Kernel Changes ]
++
++  * Set physical start and alignment 1M for virtual i386
++    - LP: #710754
++
++  [ Upstream Kernel Changes ]
++
++  * rebase from v2.6.38-rc2 + c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
++    to v2.6.38-rc3
++    - LP: #707902
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jan 2011 16:30:32 +0000
++
++linux (2.6.38-1.28) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: AUFS -- update to b1cee06249dfa0ab30951e7f06490a75c155b620
++
++  [ Ricardo Salveti de Araujo ]
++
++  * SAUCE: omap3: beaglexm: fix DVI initialization
++  * [Config] omap: move CONFIG_PANEL_GENERIC_DPI to build in to make
++    display work at Beagle
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jan 2011 10:51:57 +0000
++
++linux (2.6.38-1.27) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: AUFS -- update aufs-update to track new locations of headers
++  * ubuntu: AUFS -- update to c5021514085a5d96364e096dbd34cadb2251abfd
++  * SAUCE: ensure root is ready before running usermodehelpers in it
++  * correct the Vcs linkage to point to natty
++  * rebase to linux tip e78bf5e6cbe837daa6ab628a5f679548742994d3
++  * [Config] update configs following rebase
++    e78bf5e6cbe837daa6ab628a5f679548742994d3
++  * SAUCE: Yama: follow changes to generic_permission
++  * ubuntu: compcache -- follow changes to bd_claim/bd_release
++  * ubuntu: iscsitarget -- follow changes to open_bdev_exclusive
++  * ubuntu: ndiswrapper -- fix interaction between __packed and packed
++  * ubuntu: AUFS -- update to 806051bcbeec27748aae2b7957726a4e63ff308e
++  * update package version to match payload version
++  * rebase to e6f597a1425b5af64917be3448b29e2d5a585ac8
++  * rebase to v2.6.38-rc1
++  * [Config] updateconfigs following rebase to v2.6.38-rc1
++  * SAUCE: x86 fix up jiffies/jiffies_64 handling
++  * rebase to linus tip 2b1caf6ed7b888c95a1909d343799672731651a5
++  * [Config] updateconfigs following rebase to
++    2b1caf6ed7b888c95a1909d343799672731651a5
++  * [Config] disable CONFIG_TRANSPARENT_HUGEPAGE to fix i386 boot crashes
++  * ubuntu: AUFS -- suppress benign plink warning messages
++    - LP: #621195
++  * [Config] CONFIG_NR_CPUS=256 for amd64 -server flavour
++  * rebase to v2.6.38-rc2
++  * rebase to mainline d315777b32a4696feb86f2a0c9e9f39c94683649
++  * rebase to c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
++  * [Config] update configs following rebase to
++    c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
++  * [Config] disable CONFIG_AD7152 to fix FTBS on armel versatile
++  * [Config] disable CONFIG_AD7150 to fix FTBS on armel versatile
++  * [Config] disable CONFIG_RTL8192CE to fix FTBS on armel omap
++  * [Config] disable CONFIG_MANTIS_CORE to fix FTBS on armel versatile
++
++  [ Kees Cook ]
++
++  * SAUCE: kernel: make /proc/kallsyms mode 400 to reduce ease of attacking
++
++  [ Stefan Bader ]
++
++  * Temporarily disable RODATA for virtual i386
++    - LP: #699828
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_NLS_DEFAULT=utf8
++    - LP: #683690
++  * [Config] CONFIG_HIBERNATION=n
++  * update bnx2 firmware files in d-i/firmware/nic-modules
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "drm/radeon/bo: add some fallback placements for VRAM only
++    objects."
++  * packaging: make System.map mode 0600
++  * thinkpad_acpi: Always report scancodes for hotkeys
++    - LP: #702407
++  * sched: tg->se->load should be initialised to tg->shares
++  * Input: sysrq -- ensure sysrq_enabled and __sysrq_enabled are consistent
++  * brcm80211: include linux/slab.h for kfree
++  * pch_dma: add include/slab.h for kfree
++  * i2c-eg20t: include linux/slab.h for kfree
++  * gpio/ml_ioh_gpio: include linux/slab.h for kfree
++  * tty: include linux/slab.h for kfree
++  * winbond: include linux/delay.h for mdelay et al
++
++  [ Upstream Kernel Changes ]
++
++  * mark the start of v2.6.38 versioning
++  * rebase v2.6.37 to v2.6.38-rc2 + c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
++    - LP: #689886
++    - LP: #702125
++    - LP: #608775
++    - LP: #215802
++    - LP: #686333
++    - LP: #677830
++    - LP: #677652
++    - LP: #696493
++    - LP: #697240
++    - LP: #689036
++    - LP: #705323
++    - LP: #686692
++
++ -- Andy Whitcroft <apw@canonical.com>  Sun, 09 Jan 2011 13:44:52 +0000
++
++linux (2.6.37-12.26) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.37-rc8
++  * [Config] armel -- reenable omap flavour
++  * [Config] disable CONFIG_MACH_OMAP3517EVM to fix FTBS on armel omap
++  * [Config] disable CONFIG_GPIO_VX855 to fix FTBS on omap armel
++  * [Config] disable CONFIG_WESTBRIDGE_ASTORIA to fix FTBS on omap armel
++  * [Config] disable CONFIG_TI_DAVINCI_EMAC to fix FTBS on omap armel
++  * rebase to mainline 989d873fc5b6a96695b97738dea8d9f02a60f8ab
++  * [Config] track missing modules
++  * rebase to v2.6.37 final
++
++  [ Chase Douglas ]
++
++  * SAUCE: (drop after 2.6.37) HID: magicmouse: Don't report REL_{X, Y} for
++    Magic Trackpad
++
++  [ Stefan Bader ]
++
++  * Revert "SAUCE: blkfront: default to sd devices"
++    - LP: #684875
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: (no-up) libata: Ignore HPA by default."
++    - LP: #380138
++  * [Config] Added autofs4.ko to -virtual flavour
++    - LP: #692917
++
++  [ Upstream Kernel Changes ]
++
++  * Add support for Intellimouse Mode in ALPS touchpad on Dell E2 series
++    Laptops
++    - LP: #632884
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.37-rc8
++  * rebase to mainline 989d873fc5b6a96695b97738dea8d9f02a60f8ab
++  * rebase to v2.6.37 final
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Dec 2010 18:34:13 +0000
++
++linux (2.6.37-11.25) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] d-i -- add hpsa to the list of block devices
++    - LP: #684304
++  * [Config] add vmw-balloon driver to -virtual flavour
++    - LP: #592039
++  * rebase to v2.6.37-rc7
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.37-rc7
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 21 Dec 2010 13:35:28 +0000
++
++linux (2.6.37-10.24) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.37-rc6
++  * updateconfigs following rebase to v2.6.37-rc6
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.37-rc6
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 16 Dec 2010 12:34:19 +0000
++
++linux (2.6.37-9.23) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: vt -- fix handoff numbering to 1..n and add range checks
++    - LP: #689606
++  * SAUCE: vt -- fix handoff numbering to 1..n and add range checks (grub)
++    - LP: #689606
++
++  [ Kees Cook ]
++
++  * SAUCE: RO/NX protection for loadable kernel, fix ftrace
++    - LP: #690190
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 15 Dec 2010 19:29:57 +0000
++
++linux (2.6.37-9.22) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.35-rc5
++  * [Config] updateconfigs following rebase to v2.6.37-rc5
++  * (no-up) add support for installed header files to ubuntu directory
++    - LP: #684666
++  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
++    - LP: #684666
++  * ubuntu: dm-raid4-5 -- follow changes to bio flags
++  * ubuntu: dm-raid4-5 -- re-enable
++  * ubuntu: omnibook -- update BOM
++  * ubuntu: ndiswrapper -- update BOM to match actual version
++  * ubuntu: ndiswrapper -- follow removal of the BKL and locked ioctl
++  * ubuntu: ndiswrapper -- re-enable
++  * ubuntu: iscsitarget -- re-instate copy_io_context
++  * ubuntu: iscsitarget -- follow changes to semaphore initialisation
++  * ubuntu: iscsitarget -- convert NIPQUAD to %pI4
++  * ubuntu: iscsitarget -- re-enable
++
++  [ Kees Cook ]
++
++  * [Config] update config for CONFIG_DEBUG_SET_MODULE_RONX
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Enable jack sense for Thinkpad Edge 13
++    - LP: #685015
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_9P_FSCACHE=y,CONFIG_9P_FS_POSIX_ACL=y
++  * [Config] CONFIG_CRYPTO_CRC32C=y
++    - LP: #681819
++  * [Config] CONFIG_9P_FSCACHE=n
++  * [Config] Add nfsd modules to -virtual flavour
++    - LP: #688070
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "Staging: zram: work around oops due to startup ordering snafu"
++  * NFS: Fix panic after nfs_umount()
++    - LP: #683938
++  * x86: Add NX protection for kernel data
++  * x86: Add RO/NX protection for loadable kernel modules
++  * x86: Resume trampoline must be executable
++  * x86: RO/NX protection for loadable kernel, jump_table fix
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.37-rc5
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 09 Dec 2010 18:15:35 +0000
++
++linux (2.6.37-8.21) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: AUFS -- include the aufs_types.h file in
++    linux-libc-headers"
++  * Revert "(no-up) add support for installed header files to ubuntu
++    directory"
++
++ -- Andy Whitcroft <apw@canonical.com>  Sun, 05 Dec 2010 17:33:28 +0000
++
++linux (2.6.37-8.20) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Upstream] drivers/serial/mfd.c: Fix ARM compile error"
++  * Revert "SAUCE: Nouveau: Disable acceleration on MacBook Pros"
++  * Revert "SAUCE: Nouveau: Add quirk framework to disable acceleration"
++  * Revert "SAUCE: i915 -- disable powersave by default"
++  * SAUCE: enable Marvell 9128 PCIe SATA controller
++    - LP: #658521
++  * [Config] evtchn has been renamed
++  * (no-up) add support for installed header files to ubuntu directory
++    - LP: #684666
++  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
++    - LP: #684666
++
++  [ Tim Gardner ]
++
++  * [Config] MISS: evtchn, NEW : xen-evtchn
++  * rebase to v2.6.37-rc4
++
++  [ Upstream Kernel Changes ]
++
++  * drm/i915: Clean conflicting modesetting registers upon init
++    - LP: #683775
++  * rebase to v2.6.37-rc4
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 03 Dec 2010 18:42:07 +0000
++
++linux (2.6.37-7.19) natty; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Add bnx2 firmware to nic-modules udeb
++    - LP: #676245
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 26 Nov 2010 17:53:45 +0000
++
++linux (2.6.37-7.18) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Upstream] USB: option: Remove duplicate AMOI_VENDOR_ID"
++  * Revert "SAUCE: Add extra headers to linux-libc-dev"
++  * Revert "SAUCE: Enable speedstep for sonoma processors."
++  * [Config] enable CONFIG_BT_HCIUART_ATH3K
++  * [Config] enable CONFIG_IWLWIFI_DEBUGFS
++  * [Config] standardise CONFIG_MII
++  * [Config] standardise CONFIG_PRISM2_USB
++  * [Config] standardise CONFIG_SCSI_QLA_ISCSI
++  * [Config] build in CONFIG_AGP
++  * [Config] build in CONFIG_AGP_INTEL
++  * [Config] build in CONFIG_AGP_AMD
++  * [Config] build in CONFIG_AGP_AMD64
++  * [Config] build in CONFIG_AGP_NVIDIA
++  * [Config] build in CONFIG_AGP_VIA
++  * [Config] disable CONFIG_SCSI_QLA_ISCSI for FTBS (arm)
++  * (no-up): document the new ## scheme
++  * [Config] harmonise CONFIG_SERIAL_8250_NR_UARTS
++  * [Config] update CONFIG_SERIAL_8250_RUNTIME_UARTS=32
++    - LP: #675453
++
++  [ Mathieu J. Poirier ]
++
++  * SAUCE: ARM: Adding vdd_sdi regulator supply to OMAP3EVM
++
++  [ Upstream Kernel Changes ]
++
++  * nx-emu: fix inverted report of disable_nx
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 23 Nov 2010 21:00:39 +0000
++
++linux (2.6.37-6.17) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: AUFS -- aufs2-standalone.patch
++    aufs2.1-36-UNRELEASED-20101103"
++  * Revert "ubuntu: AUFS -- aufs2-base.patch
++    aufs2.1-36-UNRELEASED-20101103"
++  * [Config] standardise CONFIG_BT
++  * [Config] standardise CONFIG_IRDA
++  * [Config] standardise CONFIG_LAPB
++  * [Config] standardise CONFIG_RDS
++  * [Config] standardise CONFIG_RFKILL
++  * [Config] standardise CONFIG_TIPC
++  * [Config] standardise CONFIG_X25
++  * [Config] standardise CONFIG_INPUT_EVDEV
++  * [Config] standardise CONFIG_INPUT_JOYDEV
++  * [Config] standardise CONFIG_INPUT_JOYSTICK
++  * [Config] standardise CONFIG_INPUT_TOUCHSCREEN
++  * [Config] CONFIG_INPUT_TOUCHSCREEN=n for FTBS (arm)
++  * [Config] CONFIG_IRDA=n for FTBS (arm)
++  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-37
++  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-37
++  * ubuntu: AUFS -- update to 097bf62d6f49619359d34bf17f242df38562489a
++
++  [ Tim Gardner ]
++
++  * SAUCE: Fix drivers/staging/easycap FTBS
++  * [Config] CONFIG_EASYCAP=m after fixing FTBS
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "x86: Add NX protection for kernel data"
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 22 Nov 2010 18:09:10 +0000
++
++linux (2.6.37-6.16) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Config] update config for CONFIG_DEBUG_SET_MODULE_RONX"
++  * rebase to v2.6.37-rc3
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_SCHED_AUTOGROUP=y
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "x86: Add RO/NX protection for loadable kernel modules"
++  * sched: automated per session task groups
++  * rebase to v2.6.37-rc3
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 22 Nov 2010 10:11:13 +0000
++
++linux (2.6.37-6.15) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] standardise CONFIG_CEPH_FS
++  * [Config] standardise CONFIG_SCSI_LPFC_DEBUG_FS
++  * [Config] standardise CONFIG_SCSI_PROC_FS
++  * [Config] standardise CONFIG_UBIFS_FS
++  * [Config] standardise CONFIG_USB_GADGET_DEBUG_FS
++
++  [ Kees Cook ]
++
++  * [Config] update config for CONFIG_DEBUG_SET_MODULE_RONX
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Enable jack sense for Thinkpad Edge 11
++    - LP: #677210
++  * SAUCE: enable rfkill for rtl8192se driver
++    - LP: #640992
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_EASYCAP=n for FTBS
++  * Rebase to v2.6.32-rc2+git
++
++  [ Upstream Kernel Changes ]
++
++  * x86: Fix improper large page preservation
++  * x86: Add NX protection for kernel data
++  * x86: Add RO/NX protection for loadable kernel modules
++
++  [ Upstream Kernel Changes ]
++
++  * Rebase to Linus 2.6.37-rc2+git
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 20 Nov 2010 11:40:00 +0000
++
++linux (2.6.37-5.14) natty; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * PCI: fix offset check for sysfs mmapped files
++    - LP: #676963
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 18 Nov 2010 18:12:27 +0000
++
++linux (2.6.37-5.13) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebased to v2.6.37-rc2
++  * updateconfigs following rebase to v2.6.37-rc2
++
++  [ Tim Gardner ]
++
++  * [Config] Added NFS and related modules to virtual flavour
++    - LP: #659084
++
++  [ Upstream Kernel Changes ]
++
++  * x86, cpu: Rename verify_cpu_64.S to verify_cpu.S
++  * x86, cpu: Clear XD_DISABLED flag on Intel to regain NX
++  * x86, cpu: Call verify_cpu during 32bit CPU startup
++  * x86, cpu: Only CPU features determine NX capabilities
++
++  [ Upstream Changes ]
++
++  * rebased to v2.67.37-rc2
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 16 Nov 2010 13:13:29 +0000
++
++linux (2.6.37-4.12) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Upstream] HID: magicmouse: add param for scroll speed"
++  * Revert "[Upstream] HID: magicmouse: properly account for scroll
++    movement in state"
++  * Revert "[Upstream] HID: magicmouse: disable and add module param for
++    scroll acceleration"
++  * Revert "[Upstream] HID: magicmouse: scroll on entire surface, not just
++    middle of mouse"
++
++  [ Henrik Rydberg ]
++
++  * SAUCE: hid: ntrig: remove sysfs nodes
++  * SAUCE: hid: ntrig: Setup input filtering manually
++  * SAUCE: hid: ntrig: New ghost-filtering event logic
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
++    - LP: #348861
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "mmc: fix all hangs related to mmc/sd card insert/removal during
++    suspend/resume"
++  * Revert "[ARM] implement arch_randomize_brk()"
++  * Revert "ARM: stack protector: change the canary value per task"
++  * Revert "ARM: initial stack protector (-fstack-protector) support"
++  * Revert "ALSA: hda - Handle pin NID 0x1a on ALC259/269"
++  * Revert "ALSA: hda - Handle missing NID 0x1b on ALC259 codec"
++  * Revert "perf probe: Add kernel source path option"
++  * hid: ntrig: Support single-touch devices
++  * hid: ntrig: Mask pen switch events
++  * net: rtnetlink.h -- only include linux/netdevice.h when used by the
++    kernel
++    - LP: #673073
++  * Fix userspace build of linux/fs.h
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 15 Nov 2010 19:31:44 +0000
++
++linux (2.6.37-3.11) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: AUFS -- update to
++    b37c575759dc4535ccc03241c584ad5fe69e3b25"
++  * Revert "ubuntu: AUFS -- track changes to the arguements to fop fsync()"
++  * Revert "ubuntu: AUFS -- update to standalone 2.6.35-rcN as at 20100601"
++  * Revert "ubuntu: AUFS -- update to standalone 2.6.34 as at 20100601"
++  * Revert "ubuntu: AUFS -- aufs2 base patch for linux-2.6.34"
++  * [Config] Disable intel_idle for -virtual kernels
++    - LP: #651370
++  * [Config] enforcer -- ensure we never enable CONFIG_IMA
++  * debian -- pass the correct flavour name when checking configs
++  * [Config] enforcer -- ensure CONFIG_INTEL_IDLE is off for -virtual
++  * [Config] ensure CONFIG_IPV6=y for powerpc
++  * [Config] enforcer -- ensure CONFIG_IPV6=y
++  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-36-UNRELEASED-20101103
++  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-36-UNRELEASED-20101103
++  * ubuntu: AUFS -- update to aufs2.1-36-UNRELEASED-20101103
++  * ubuntu: AUFS -- re-enable
++  * ubuntu: AUFS -- track changes to work queue initialisation
++  * ubuntu: AUFS -- track changes to llseek in v2.6.37-rc1
++  * SAUCE: fbcon -- fix race between open and removal of framebuffers
++  * SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
++    - LP: #614008
++  * SAUCE: drm -- stop early access to drm devices
++
++  [ Jeremy Kerr ]
++
++  * [Config] Build-in powermac ZILOG serial driver
++    - LP: #673346
++
++  [ Kees Cook ]
++
++  * SAUCE: nx-emu: use upstream ASLR when possible
++
++  [ Tim Gardner ]
++
++  * [Config] Use correct be2iscsi module name in d-i/modules/scsi-modules
++    - LP: #628776
++
++  [ Upstream Kernel Changes ]
++
++  * i386: NX emulation
++  * nx-emu: drop exec-shield sysctl, merge with disable_nx
++  * nx-emu: standardize boottime message prefix
++  * mmap randomization for executable mappings on 32-bit
++  * exec-randomization: brk away from exec rand area
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 11 Nov 2010 23:46:37 +0000
++
++linux (2.6.37-2.10) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * reinstate armel config changes:
++   * [Config] CONFIG_GPIO_PCH=n for armel FTBS
++   * [Config] CONFIG_GPIO_VX855=n for armel FTBS
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 03 Nov 2010 22:20:35 +0000
++
++linux (2.6.37-2.9) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * config -- fix genportsconfig
++  * [Config] move powerpc over from ports to distro
++  * bump master version number to match contained kernel
++  * SAUCE: fix documentation strings for struct input_keymap_entry
++  * usb: gadget: goku_udc: add registered flag bit
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 02 Nov 2010 15:14:11 +0000
++
++linux (2.6.36-2.8) natty; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config]: fix changed CONFIG_SYSFS_DEPRECATED_V2 enforcement rules
++  * [Config]: TWL4030_CORE=n for FTBS
++  * [Config]: CONFIG_ATH6K_LEGACY=n for FTBS
++  * [Config]: CONFIG_SOLO6X10=n for FTBS
++  * [Config]: CONFIG_GPIO_PCH=n for armel FTBS
++  * [Config]: CONFIG_GPIO_VX855=n for armel FTBS
++  * [Config]: CONFIG_DRM_NOUVEAU=n for armel FTBS
++  * [Config]: CONFIG_LINE6_USB=n for armel FTBS
++  * [Config]: CONFIG_SENSORS_AK8975=n for armel FTBS
++  * [Config]: CONFIG_I2C_I801=n for armel FTBS
++  * UBUNTU: SAUCE: AppArmor: Fix unpack of network tables.
++  * AppArmor: compatibility patch for v5 interface
++  * AppArmor: compatibility patch for v5 network controll
++  * Dropped (pre-stable): input: Support Clickpad devices in ClickZone mode
++  * Dropped: UBUNTU: SAUCE: libata: Add ALPM power state accounting to the AHCI driver
++  * Dropped: UBUNTU: SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
++  * Dropped: hid: 3m: Convert to MT slots
++  * Dropped: HID: magicmouse: don't allow hidinput to initialize the device
++  * Dropped: HID: magicmouse: simplify touch data bit manipulation
++  * Dropped: HID: magicmouse: simplify touch down logic
++  * Dropped: HID: magicmouse: enable Magic Trackpad support
++  * Dropped: UBUNTU: SAUCE: hid: ntrig: remove sysfs nodes
++  * Dropped: UBUNTU: SAUCE: hid: ntrig: Setup input filtering manually
++  * Dropped: UBUNTU: SAUCE: hid: ntrig: New ghost-filtering event logic
++  * Dropped: UBUNTU: SAUCE: hid: ntrig: identify firmware version (wiggled)
++  * Dropped: UBUNTU: (pre-stable): input: Support Clickpad devices in ClickZone mode
++  * Dropped: UBUNTU: SAUCE: KMS: cache the EDID information of the LVDS
++  * Dropped: UBUNTU: SAUCE: fbcon -- fix race between open and removal of framebuffers
++  * Dropped: UBUNTU: SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
++  * Dropped: UBUNTU: SAUCE: x86: implement cs-limit nx-emulation for ia32
++  * Dropped: UBUNTU: SAUCE: x86: more tightly confine cs-limit nx-emulation to ia32 only
++  * Dropped: UBUNTU: SAUCE: [um] Don't use nx_enabled under UML
++  * Dropped: UBUNTU: SAUCE: x86: brk away from exec rand area
++
++  [ Upstream Kernel Changes ]
++
++  * rebased against 2.6.27-rc1
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 22 Oct 2010 19:35:05 -0600
++
++linux (2.6.36-1.7) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebased to v2.6.36 final
++  * [Config] update configs following rebase to v2.6.36 final
++  * [Config] update ports configs following rebase to v2.6.36 final
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to v2.6.36 final
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 21 Oct 2010 14:28:57 +0100
++
++linux (2.6.36-1.6) natty; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * drop broadcom staging driver preview:
++   * Revert "Staging: Add initial release of brcm80211 - Broadcom 802.11n
++     wireless LAN driver."
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 20 Oct 2010 10:41:25 +0100
++
++linux (2.6.36-1.5) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.36-rc8
++  * updateconfigs following rebase to v2.6.36-rc8
++  * updateportsconfigs following rebase to v2.6.36-rc8
++  * config -- simplify the kernelconfig interface
++  * config -- add new config mode 'dumpconfigs'
++
++  [ Tim Gardner ]
++
++  * Simplify the use of CROSS_COMPILER
++
++  [ Upstream Kernel Changes ]
++
++  * drop broadcom staging driver preview:
++   * Revert "staging: brcm80211: Make compiling of brcm80211.ko and
++     brcmfmac.ko mutually exclusive."
++   * Revert "staging: brcm80211: Fix compile issue when BRCM80211_PCI is not
++     set."
++   * Revert "Staging: brcm80211: remove driver specific -W options"
++   * Revert "Staging: brcm80211: clean up makefile cflag lines"
++   * Revert "staging: brcm80211: add fullmac driver"
++   * Revert "staging: brcm80211: use string native library"
++   * Revert "staging: brcm80211: use native ctype library"
++   * Revert "staging: brcm80211: fix remaining checkpatch errors."
++   * Revert "staging: brcm80211: fix "ERROR: trailing whitespace.""
++   * Revert "staging: brcm80211: fix "ERROR: spaces required around that
++     ...""
++   * Revert "staging: brcm80211: fix "ERROR: spaces prohibited around that
++     ':' ...""
++   * Revert "staging: brcm80211: fix "ERROR: space required before that
++     ...""
++   * Revert "staging: brcm80211: fix "ERROR: space required after that ...""
++   * Revert "staging: brcm80211: fix "ERROR: space required after that close
++     brace""
++   * Revert "staging: brcm80211: fix "ERROR: space prohibited before
++     ...close square bracket""
++   * Revert "staging: brcm80211: fix "ERROR: space prohibited after that
++     ...""
++   * Revert "staging: brcm80211: fix "ERROR: need consistent spacing around
++     '*'""
++   * Revert "staging: brcm80211: fix 'ERROR: "(foo*)" should be "(foo *)"'"
++   * Revert "staging: brcm80211: fix "ERROR: Macros w/ mult. statements ...
++     do - while loop""
++   * Revert "staging: brcm80211: fix "ERROR: Macros w/ complex values ...
++     parenthesis""
++   * Revert "staging: brcm80211: fix "ERROR: do not initialise statics to 0
++     or NULL""
++   * Revert "staging: brcm80211: fix "ERROR: do not initialise globals to 0
++    or NULL""
++   * Revert "staging: brcm80211: fix "ERROR: while should follow close brace
++     '}'""
++   * Revert "staging: brcm80211: fix "ERROR: that open brace { ... prev
++     line""
++   * Revert "staging: brcm80211: fix "ERROR: trailing statements should be
++     on next line""
++   * Revert "staging: brcm80211: fix "ERROR: do not use assignment in if
++     condition""
++   * Revert "staging: brcm80211: fix "ERROR: return is not a function,
++     paren...""
++   * Revert "staging: brcm80211: fix "ERROR: open brace '{' following
++     function dec...""
++   * Revert "staging: brcm80211: fix 'ERROR: "foo * bar" should be "foo
++     *bar"'"
++   * Revert "staging: brcm80211: Fix URLs for firmware files."
++   * Revert "staging: brcm80211: use '%pM' format to print MAC address"
++   * Revert "staging: brcm80211: Add contact info to TODO list."
++   * Revert "staging: brcm80211: Fix some initialisation failure paths"
++  * Export dump_{write,seek} to binary loader modules
++  * rebase to v2.6.36-rc8.
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 19 Oct 2010 18:58:11 +0100
++
++linux (2.6.36-0.4) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: perf: increase stack footprint to avoid stack-protector warning
++    (fixes FTBS on powerpc)
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 14 Oct 2010 13:16:16 +0100
++
++linux (2.6.36-0.3) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] disable CONFIG_SCSI_QLA_ISCSI to fix FTBS on powerpc
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 14 Oct 2010 03:01:30 +0100
++
++linux (2.6.36-0.2) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] updateportsconfigs following rebase to 2.6.36-rc7
++    (fix FTBS on powerpc)
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 13 Oct 2010 23:25:12 +0100
++
++linux (2.6.36-0.1) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * reduce disk usage during buildd builds
++    - LP: #645653
++  * [Config] enforcer -- ensure CONFIG_INIT_PASS_ALL_PARAMS is y
++  * [Config] armel -- drop omap flavour
++
++  [ Tim Gardner ]
++
++  * Added dropped patch list
++  * more dropped patches
++  * [Config] Disable aufs, dmraid-4.5, ndis-wrapper
++  * [Config] Add support for cross compiling armel
++  * [Config] CONFIG_SCSI_QLA_ISCSI=n for armel
++  * [Upstream] drivers/serial/mfd.c: Fix ARM compile error
++  * [Config]: updateconfigs after adding brcm80211
++  * staging: brcm80211: Fix Makefile syntax error
++  * rebased to v2.6.36-rc7
++
++  [ Upstream Kernel Changes ]
++
++  * (upstream) IPS driver: don't toggle CPU turbo on unsupported CPUs
++  * (upstream) IPS driver: verify BIOS provided limits
++  * intel_ips: Print MCP limit exceeded values.
++  * Staging: Add initial release of brcm80211 - Broadcom 802.11n wireless
++    LAN driver.
++  * staging: brcm80211: Fix some initialisation failure paths
++  * staging: brcm80211: Add contact info to TODO list.
++  * staging: brcm80211: use '%pM' format to print MAC address
++  * staging: brcm80211: Fix URLs for firmware files.
++  * staging: brcm80211: fix 'ERROR: "foo * bar" should be "foo *bar"'
++  * staging: brcm80211: fix "ERROR: open brace '{' following function
++    dec..."
++  * staging: brcm80211: fix "ERROR: return is not a function, paren..."
++  * staging: brcm80211: fix "ERROR: do not use assignment in if condition"
++  * staging: brcm80211: fix "ERROR: trailing statements should be on next
++    line"
++  * staging: brcm80211: fix "ERROR: that open brace { ... prev line"
++  * staging: brcm80211: fix "ERROR: while should follow close brace '}'"
++  * staging: brcm80211: fix "ERROR: do not initialise globals to 0 or NULL"
++  * staging: brcm80211: fix "ERROR: do not initialise statics to 0 or NULL"
++  * staging: brcm80211: fix "ERROR: Macros w/ complex values ...
++    parenthesis"
++  * staging: brcm80211: fix "ERROR: Macros w/ mult. statements ... do -
++    while loop"
++  * staging: brcm80211: fix 'ERROR: "(foo*)" should be "(foo *)"'
++  * staging: brcm80211: fix "ERROR: need consistent spacing around '*'"
++  * staging: brcm80211: fix "ERROR: space prohibited after that ..."
++  * staging: brcm80211: fix "ERROR: space prohibited before ...close square
++    bracket"
++  * staging: brcm80211: fix "ERROR: space required after that close brace"
++  * staging: brcm80211: fix "ERROR: space required after that ..."
++  * staging: brcm80211: fix "ERROR: space required before that ..."
++  * staging: brcm80211: fix "ERROR: spaces prohibited around that ':' ..."
++  * staging: brcm80211: fix "ERROR: spaces required around that ..."
++  * staging: brcm80211: fix "ERROR: trailing whitespace."
++  * staging: brcm80211: fix remaining checkpatch errors.
++  * staging: brcm80211: use native ctype library
++  * staging: brcm80211: use string native library
++  * staging: brcm80211: add fullmac driver
++  * Staging: brcm80211: clean up makefile cflag lines
++  * Staging: brcm80211: remove driver specific -W options
++  * staging: brcm80211: Fix compile issue when BRCM80211_PCI is not set.
++  * staging: brcm80211: Make compiling of brcm80211.ko and brcmfmac.ko
++    mutually exclusive.
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 12 Oct 2010 16:00:27 +0100
++
++linux (2.6.35-22.33) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: Add support for Intellimouse Mode in ALPS touchpad on
++    Dell E2 series Laptops"
++    - LP: #641320
++
++  [ Brian Rogers ]
++
++  * SAUCE: ir-core: Fix null dereferences in the protocols sysfs interface
++    - LP: #624701
++
++  [ Christopher James Halse Rogers ]
++
++  * SAUCE: Nouveau: Add quirk framework to disable acceleration
++    - LP: #544088, #546393
++  * SAUCE: Nouveau: Disable acceleration on MacBook Pros
++    - LP: #546393
++
++  [ John Johansen ]
++
++  * Revert "SAUCE: AppArmor: allow newer tools to load policy on older
++    kernels"
++  * SAUCE: AppArmor: allow newer tools to load policy on older kernels
++    - LP: #639758
++
++  [ Mathieu J. Poirier ]
++
++  * SAUCE: Adding vdd_sdi regulator supply to OMAP3EVM
++
++  [ Upstream Kernel Changes ]
++
++  * ALSA: HDA: Enable internal speaker on Dell M101z
++    - LP: #640254
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 17 Sep 2010 13:21:28 -0700
++
++linux (2.6.35-22.32) maverick; urgency=low
++
++  [ Arjan van de Ven ]
++
++  * SAUCE: libata: Add ALPM power state accounting to the AHCI driver
++
++  [ David Henningsson ]
++
++  * SAUCE: ALSA: HDA: Enable internal mic on Dell E6410 and Dell E6510
++    - LP: #605047, #628961
++
++  [ John Johansen ]
++
++  * [Upstream] AppArmor: Fix splitting an fqname into separate namespace
++    and profile names
++    - LP: #615947
++  * [Upstream] AppArmor: Fix locking from removal of profile namespace
++    - LP: #615947
++  * SAUCE: AppArmor: allow newer tools to load policy on older kernels
++    - LP: #639758
++  * SAUCE: Improve Amazon EBS performance for EC2
++    - LP: #634316
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: i915 KMS -- blacklist i855"
++  * Revert "SAUCE: i915 KMS -- blacklist i845g"
++  * Revert "SAUCE: i915 KMS -- blacklist i830"
++  * Revert "SAUCE: i915 KMS -- support disabling KMS for known broken
++    devices"
++  * execute module-inclusion within a subshell
++    - LP: #621175
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) bounce: call flush_dcache_page() after bounce_copy_vec()
++    - LP: #633227
++  * (pre-stable) drm/i915: don't enable self-refresh on Ironlake
++    - LP: #629711
++  * (pre-stable) mm: Move vma_stack_continue into mm.h
++  * x86, hwmon: Fix unsafe smp_processor_id() in thermal_throttle_add_dev
++    - LP: #601073
++  * PM / Runtime: Make runtime_status attribute not debug-only (v. 2)
++  * PM / Runtime: Add runtime PM statistics (v3)
++  * compat: Make compat_alloc_user_space() incorporate the access_ok()
++    - CVE-2010-3081
++  * x86-64, compat: Test %rax for the syscall number, not %eax
++    - CVE-2010-3301
++  * x86-64, compat: Retruncate rax after ia32 syscall entry tracing
++    - CVE-2010-3301
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 14 Sep 2010 08:46:49 -0700
++
++linux (2.6.35-21.31) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * bodge linux-libc-dev package version due to ti-omap4 error
++  * linux-libc-dev -- ensure we can only build this on debian.master
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 13 Sep 2010 09:54:31 -0700
++
++linux (2.6.35-21.30) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
++    - LP: #614008
++
++  [ Daniel Lezcano ]
++
++  * SAUCE: fix compilation warning when CONFIG_SECURITY is not set
++
++  [ Henrik Rydberg ]
++
++  * SAUCE: Input: wacom - add fuzz parameters to features
++  * SAUCE: Input: wacom - collect device quirks into single function
++  * SAUCE: Input: wacom - add support for the Bamboo Touch trackpad
++  * SAUCE: Input: wacom - add a quirk for low resolution Bamboo devices
++  * SAUCE: hid: ntrig: Remove unused device ids
++  * SAUCE: hid: ntrig: remove sysfs nodes
++  * SAUCE: hid: ntrig: Correct logic for quirks
++  * SAUCE: hid: ntrig: zero-initialize ntrig struct
++  * SAUCE: hid: ntrig: Setup input filtering manually
++  * SAUCE: hid: ntrig: New ghost-filtering event logic
++
++  [ Leann Ogasawara ]
++
++  * SAUCE: ndiswrapper: Initialize buffer index and check its value
++    - LP: #613796
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Add support for Intellimouse Mode in ALPS touchpad on Dell E2
++    series Laptops
++    - LP: #632884
++
++  [ Ping Cheng ]
++
++  * SAUCE: Input: wacom - parse the Bamboo device family
++
++  [ Rafi Rubin ]
++
++  * SAUCE: hid: ntrig: identify firmware version (wiggled)
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_NL80211_TESTMODE=n
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "input: mt: Add support for the Bamboo Touch trackpad"
++  * e1000e: initial support for 82579 LOMs
++  * e1000e: correct MAC-PHY interconnect register offset for 82579
++  * (pre-stable) ALSA: hda - Add a new hp-laptop model for Conexant 5066,
++    tested on HP G60
++    - LP: #587388
++  * DSS2: Don't power off a panel twice
++    - LP: #588243
++  * mmc: build fix: mmc_pm_notify is only available with CONFIG_PM=y
++  * Input: i8042 - reset keyboard controller wehen resuming from S2R
++    - LP: #86820
++  * ALSA: hda - Fix beep frequency on IDT 92HD73xx and 92HD71Bxx codecs
++    - LP: #414795
++  * agp/intel: Support the extended physical addressing bits on
++    Sandybridge.
++    - LP: #632488
++  * drm/i915,intel_agp: Add support for Sandybridge D0
++    - LP: #632488
++  * (pre-stable) intel_agp,i915: Add more sandybridge graphics device ids
++    - LP: #632488
++  * mmc: omap: fix for bus width which improves SD card's peformance.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 07 Sep 2010 09:58:52 -0700
++
++linux (2.6.35-20.29) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: i915 KMS -- support disabling KMS for known broken devices
++    - LP: #563277
++  * SAUCE: i915 KMS -- blacklist i830
++    - LP: #542208, #563277
++  * SAUCE: i915 KMS -- blacklist i845g
++    - LP: #541492, #563277
++  * SAUCE: i915 KMS -- blacklist i855
++    - LP: #511001, #541511, #563277
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_SENSORS_PKGTEMP=m
++    - LP: #601073
++  * ARM: Temporarily disable module check for armel
++  * rebase to v2.6.35.4
++  * [Config] update configs following rebase to v2.6.35.4
++
++  [ Ricardo Salveti de Araujo ]
++
++  * [Config] Change CONFIG_LEDS_TRIGGER_HEARTBEAT from module to built-in
++    in Omap
++
++  [ Tim Gardner ]
++
++  * [Config] Added be2net, be2scsi to udebs
++    - LP: #628776
++
++  [ Upstream Kernel Changes ]
++
++  * x86, cpu: Package Level Thermal Control, Power Limit Notification
++    definitions
++    - LP: #601073
++  * x86, hwmon: Package Level Thermal/Power: pkgtemp hwmon driver
++    - LP: #601073
++  * x86, hwmon: Package Level Thermal/Power: thermal throttling handler
++    - LP: #601073
++  * x86, hwmon: Package Level Thermal/Power: power limit
++    - LP: #601073
++  * x86, hwmon: Package Level Thermal/Power: pkgtemp documentation
++    - LP: #601073
++  * hid: 3m: Adjust to sequential MT HID protocol
++  * hid: 3m: Convert to MT slots
++  * hid: 3m: Correct touchscreen emulation
++  * hid: 3m: Adjust major / minor axes to scale
++  * input: bcm5974: Adjust major / minor to scale
++  * HID: magicmouse: don't allow hidinput to initialize the device
++  * HID: magicmouse: simplify multitouch feature request
++  * HID: magicmouse: simplify touch data bit manipulation
++  * HID: magicmouse: simplify touch down logic
++  * HID: magicmouse: remove timestamp logic
++  * HID: magicmouse: enable Magic Trackpad support
++  * HID: magicmouse: Adjust major / minor axes to scale
++  * mmc: fix all hangs related to mmc/sd card insert/removal during
++    suspend/resume
++    - LP: #477106
++  * drm/i915: fix VGA plane disable for Ironlake+
++    - LP: #602281
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 30 Aug 2010 08:38:01 -0700
++
++linux (2.6.35-19.28) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * No changes from 2.6.35-19.27.  Some armel udebs were accidentally deleted
++    from the archive and a no-change rebuild was attempted.  However, the ABI
++    did not get bumped and resulted in build failures for 2.6.35-19.27.  Fix
++    up the ABI and re-upload.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sat, 28 Aug 2010 16:42:27 -0700
++
++linux (2.6.35-19.27) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * No changes from 2.6.35-19.26.  Some armel udebs were accidentally deleted
++    from the archive.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 27 Aug 2010 08:58:35 -0700
++
++linux (2.6.35-19.26) maverick; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * ARM: OMAP: Beagle: revision detection
++  * ARM: OMAP: Beagle: only Cx boards use pin 23 for write protect
++  * ARM: OMAP: Beagle: no gpio_wp pin connection on xM
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 26 Aug 2010 09:15:09 -0700
++
++linux (2.6.35-19.25) maverick; urgency=low
++
++  [ Jarod Wilson ]
++
++  * SAUCE: Bring in staging/lirc from 2.6.36
++    - LP: #609234
++  * SAUCE: Update ir-core to linuxtv/other which should be merged for
++    2.6.36.
++    - LP: #609234
++  * SAUCE: Fix memleaks in imon and mceusb drivers
++    - LP: #609234
++  * SAUCE: Bring in streamzap support from linuxtv/other
++    - LP: #609234
++
++  [ Mario Limonciello ]
++
++  * Remove ubuntu/lirc in favor of staging/lirc from 2.6.36
++    - LP: #609234
++
++  [ Mathieu J. Poirier ]
++
++  * SAUCE: ARM: adding i2c eeprom driver to read EDID
++    - LP: #608279
++
++  [ Upstream Kernel Changes ]
++
++  * intel_idle: disable module support
++    - LP: #615265
++  * (pre-stable) ALSA: hda - Ensure codec patch files are checked for the
++    correct codec ID
++  * (pre-stable) ALSA: hda - Rename iMic to Int Mic on Lenovo NB0763
++    - LP: #605101
++  * (pre-stable) ALSA: HDA: Use model=auto for LG R510
++    - LP: #495134
++  * (pre-stable) ALSA: HDA: Add Sony VAIO quirk for ALC269
++    - LP: #519066
++  * (pre-stable) ALSA: HDA: Fix front mic on Dell Precision M6500
++    - LP: #519066
++  * input: mt: Initialize slots to unused (rev2)
++  * input: mt: Add support for the Bamboo Touch trackpad
++  * hid: Add a hid quirk for input sync override
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 Aug 2010 12:42:52 -0700
++
++linux (2.6.35-18.24) maverick; urgency=low
++
++  [ Colin Watson ]
++
++  * Pass DEB_MAINT_PARAMS to hook scripts
++
++  [ Leann Ogasawara ]
++
++  * [Config] Add CONFIG_INPUT_UINPUT=y to config enforcer
++    - LP: #584812
++  * rebase to v2.6.35.3
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) dell-wmi: Add support for eject key on Dell Studio 1555
++    - LP: #609234
++  * can: add limit for nframes and clean up signed/unsigned variables
++    - CVE-2010-2959
++  * drm: Initialize ioctl struct when no user data is present
++    - CVE-2010-2803
++  * ARM: initial stack protector (-fstack-protector) support
++  * ARM: stack protector: change the canary value per task
++  * [ARM] implement arch_randomize_brk()
++  * [ARM] add address randomization to mmap()
++  * ARM: fix ASLR of PIE executables
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 22 Aug 2010 19:22:04 -0700
++
++linux (2.6.35-17.23) maverick; urgency=low
++
++  [ Jeremy Kerr ]
++
++  * [Config] build-in uinput module
++    - LP: #584812
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Config] [FTBS] ia64: Temporarily disable CONFIG_CEPH_FS"
++  * Revert "[Config] [FTBS] ia64: Temporarily disable gpiolib"
++  * Revert "[Config] [FTBS] sparc: Temporarily disable
++    CONFIG_MTD_NAND_DENALI"
++  * Revert "[Config] [FTBS] sparc: Temporarily disable
++    CONFIG_MFD_JANZ_CMODIO"
++  * Revert "[Config] [FTBS] sparc: Temporarily disable
++    CONFIG_INFINIBAND_QIB"
++  * [Config] Enable INTEL_IPS
++    - LP: #601057
++  * Remove ia64 support
++  * [Config] Update portsconfigs after removing ia64 support
++  * Remove sparc support
++  * [Config] Update portsconfigs after removing sparc support
++
++  [ Linus Torvalds ]
++
++  * (pre-stable) mm: fix page table unmap for stack guard page properly
++
++  [ Mathieu J. Poirier ]
++
++  * SAUCE: (no-up) ARM: Resetting power_mode to its original value.
++    - LP: #591941
++
++  [ Upstream Kernel Changes ]
++
++  * timer: add on-stack deferrable timer interfaces
++    - LP: #601057
++  * x86 platform driver: intelligent power sharing driver
++    - LP: #601057
++  * IPS driver: add GPU busy and turbo checking
++    - LP: #601057
++  * X86: intel_ips, check for kzalloc properly
++    - LP: #601057
++  * ips driver: make it less chatty
++    - LP: #601057
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 17 Aug 2010 09:38:08 -0700
++
++linux (2.6.35-16.22) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * debian -- more agressivly clean up after depmod on purge
++    - LP: #618591
++
++  [ Henrik Rydberg ]
++
++  * SAUCE: hid: 3m: Simplify touchsreen emulation logic
++
++  [ Leann Ogasawara ]
++
++  * ubuntu: iscsitarget -- version 1.4.20.2
++  * ubuntu: rtl8192se -- update to version 0017.0507.2010
++  * rebase to v2.6.35.2
++  * [Config] update configs following rebase to v2.6.35.2
++  * [Config] update ports configs following rebase to v2.6.35.2
++
++  [ Luke Yelavich ]
++
++  * [Config] Enable new firewire stack on powerpc
++
++  [ Mathieu J. Poirier ]
++
++  * SAUCE: (drop after 2.6.35) ARM: Using gpmc function to init nand flash.
++    - LP: #608266
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 12 Aug 2010 09:58:01 -0700
++
++linux (2.6.35-15.21) maverick; urgency=low
++
++  [ Luke Yelavich ]
++
++  * [Config] CONFIG_SND_USB_UA101=m for all architectures
++
++  [ Upstream Kernel Changes ]
++
++  * Input: introduce MT event slots
++  * Input: document the MT event slot protocol
++  * (pre-stable) sched: Revert nohz_ratelimit() for now
++  * (pre-stable) drm/radeon/kms: add missing copy from user
++    - LP: #606081
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35.1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 09 Aug 2010 09:24:04 -0700
++
++linux (2.6.35-14.20) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * update Vcs-Git to point to maverick repo
++  * debian -- include the debian packaging in the -source package
++    - LP: #608674
++  * select debian source format 1.0
++  * add support for building selected stages of kernel
++    - LP: #603087
++  * cleanup conditional dependancy handling
++    - LP: #603087
++
++  [ Upstream Kernel Changes ]
++
++  * ALSA: hda - Handle missing NID 0x1b on ALC259 codec
++    - LP: #582199, #586418, #588031
++  * ALSA: hda - Handle pin NID 0x1a on ALC259/269
++    - LP: #582199, #586418, #588031
++  * sched: Revert nohz_ratelimit() for now
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 03 Aug 2010 08:46:47 -0700
++
++linux (2.6.35-14.19) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 01 Aug 2010 10:35:56 -0700
++
++linux (2.6.35-13.18) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: (no-up) Modularize vesafb -- fix initialisation
++  * SAUCE: add tracing for user initiated readahead requests
++  * SAUCE: vt -- maintain bootloader screen mode and content until vt
++    switch
++  * SAUCE: vt -- allow grub to request automatic vt_handoff
++  * SAUCE: fbcon -- fix race between open and removal of framebuffers
++  * SAUCE: drm -- stop early access to drm devices
++
++  [ Bryan Wu ]
++
++  * CONFIG: compile in OTG driver and Transceiver driver
++    - LP: #566645
++  * remove OTG modules from modules list file
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: -- sync to AppArmor mainline 2010-07-27
++    - LP: #581525, #599450
++  * SAUCE: AppArmor: -- sync to AppArmor mainline 2010-07-29
++  * SAUCE: AppArmor 2.4 compatibility patch
++  * SAUCE: AppArmor: Allow dfa backward compatibility with broken userspace
++  * SAUCE: fix pv-ops for legacy Xen
++  * SAUCE: blkfront: default to sd devices
++  * [Config] Build in drivers required for Xen pv-ops
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Upstream] i915: Use the correct mask to detect i830 aperture
++    size."
++
++  [ Lee Jones ]
++
++  * SAUCE: ARM: OMAP: Add macros for comparing silicon revision
++    - LP: #608095
++  * SAUCE: OMAP: DSS2: check for both cpu type and revision, rather than
++    just revision
++    - LP: #608095
++  * SAUCE: OMAP: DSS2: enable hsclk in dsi_pll_init for OMAP36XX
++    - LP: #608095
++  * SAUCE: ARM: OMAP: Beagle: support twl gpio differences on xM
++    - LP: #608095
++
++  [ Upstream Kernel Changes ]
++
++  * agp/intel: Use the correct mask to detect i830 aperture size.
++    - LP: #597075
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 30 Jul 2010 15:46:59 -0700
++
++linux (2.6.35-12.17) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35-rc6
++  * [Config] update configs following rebase to v2.6.35-rc6
++  * [Config] update ports configs following rebase to v2.6.35-rc6
++  * SAUCE: [FTBS] armel: define KEY_F10 and KEYF11
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 23 Jul 2010 16:16:38 +0200
++
++linux (2.6.35-11.16) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Bump ABI for new compiler update 
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 23 Jul 2010 10:24:58 +0200
++
++linux (2.6.35-10.15) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: ensure vga16fb loads if no other driver claims the VGA
++    device"
++  * [Config] Enable CONFIG_M686=y
++    - LP: #592495
++
++  [ Upstream Kernel Changes ]
++
++  * tracing: Add alignment to syscall metadata declarations
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 20 Jul 2010 18:18:49 +0200
++
++linux (2.6.35-9.14) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: AUFS -- add BOM and automated update script
++  * ubuntu: AUFS -- update to b37c575759dc4535ccc03241c584ad5fe69e3b25
++
++  [ John Johansen ]
++
++  * [Config] Enable DRBD as a module
++
++  [ Kees Cook ]
++
++  * SAUCE: Yama: verify inode is symlink to avoid bind mounts
++    - LP: #604407
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable CONFIG_DRM_VMWGFX (staging driver)
++    - LP: #606139
++  * [Config] ports: Disable CONFIG_DRM_VMWGFX (staging driver)
++    - LP: #606139
++  * [Config] Enable CONFIG_DEBUG_STRICT_USER_COPY_CHECKS=y
++  * [Config] ports: Enable CONFIG_DEBUG_STRICT_USER_COPY_CHECKS=y
++
++  [ Lee Jones ]
++
++  * Stop ARM boards crashing when CUPS is loaded
++    - LP: #601226
++
++  [ Upstream Kernel Changes ]
++
++  * perf probe: Support tracing an entry of array
++  * perf probe: Support static and global variables
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 16 Jul 2010 14:38:17 -0700
++
++linux (2.6.35-8.13) maverick; urgency=low
++
++  [ Kees Cook ]
++
++  * SAUCE: Yama: check PTRACE using thread group leader
++  * SAUCE: Yama: search for PTRACE exceptions via thread group leader
++    - LP: #603716
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35-rc5
++  * [Config] update configs following rebase to v2.6.35-rc5
++
++  [ Nicolas Pitre ]
++
++  * SAUCE: make ndiswrapper available on X86 only
++
++  [ Tim Gardner ]
++
++  * [Config] Added ums-cypress to udeb
++    - LP: #576066
++  * SAUCE: fix build error with CONFIG_BLK_DEV_INITRD=n
++  * [Config] CONFIG_NDISWRAPPER=m across all configs
++
++  [ Upstream Kernel Changes ]
++
++  * HID: magicmouse: report last touch up
++  * rebase to 2.6.35-rc5
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 13 Jul 2010 18:57:59 -0700
++
++linux (2.6.35-7.12) maverick; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Upstream] i915: Use the correct mask to detect i830 aperture size.
++    - LP: #597075
++
++  [ Upstream Kernel Changes ]
++
++  * (drop after 2.6.35) drm/radeon/kms: add ioport register access
++    (squashed)
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Jul 2010 09:53:13 -0600
++
++linux (2.6.35-7.11) maverick; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_X86_MRST=n
++
++  [ Upstream Kernel Changes ]
++
++  * (drop after 2.6.35-rc5) writeback: remove writeback_inodes_wbc
++  * (drop after 2.6.35-rc5) writeback: split writeback_inodes_wb
++  * (drop after 2.6.35-rc5) writeback: simplify the write back thread queue
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 06 Jul 2010 18:39:08 -0600
++
++linux (2.6.35-7.10) maverick; urgency=low
++
++  [ Kees Cook ]
++
++  * SAUCE: security: create task_free security callback
++  * SAUCE: Yama: add PTRACE exception tracking and interface
++  * SAUCE: security: unconditionally chain to Yama LSM
++  * Revert "SAUCE: ptrace: restrict ptrace scope to children"
++  * Revert "SAUCE: fs: block hardlinks to non-accessible sources"
++  * Revert "SAUCE: fs: block cross-uid sticky symlinks"
++  * [Upstream] security: Yama LSM
++  * [Config] Enable CONFIG_SECURITY_YAMA=y
++
++  [ Tim Gardner ]
++
++  * [Config] updateconfigs/updateportsconfigs after rebase to 2.6.35-rc4
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to 2.6.35-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 01 Jul 2010 08:55:57 -0700
++
++linux (2.6.35-6.9) maverick; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Upstream] direct_splice_actor() should not use pos in sd
++    - LP: #588861
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 28 Jun 2010 12:35:49 -0700
++
++linux (2.6.35-6.8) maverick; urgency=low
++
++  [ Mathieu J. Poirier ]
++
++  * ARM: Adding regulator supply for vdds_sdi.
++    - LP: #597904
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 27 Jun 2010 16:34:43 -0700
++
++linux (2.6.35-6.7) maverick; urgency=low
++
++  [ Alberto Milone ]
++
++  * [Upstream] Add support for the ATIF ACPI method to the radeon driver
++
++  [ Chase Douglas ]
++
++  * [Upstream] HID: magicmouse: scroll on entire surface, not just middle
++    of mouse
++  * [Upstream] HID: magicmouse: disable and add module param for scroll
++    acceleration
++  * [Upstream] HID: magicmouse: properly account for scroll movement in
++    state
++  * [Upstream] HID: magicmouse: add param for scroll speed
++  * [Upstream] HID: magicmouse: enable horizontal scrolling
++
++  [ Henrik Rydberg ]
++
++  * [Upstream] Input: evdev - convert to dynamic event buffer
++  * [Upstream] Input: evdev - use driver hint to compute size of event
++    buffer
++  * [Upstream] Input: bcm5974 - set the average number of events per MT
++    event packet
++  * [Upstream] Input: hid-input - use a larger event buffer for MT devices
++  * [Upstream] Input: evdev - never leave the client buffer empty after
++    write
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: -- mainline 2010-06-23
++  * SAUCE: AppArmor 2.4 compatibility patch
++  * SAUCE: fs: block hardlinks to non-accessible sources AppArmor portion
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_INTR_REMAP=y
++    - LP: #597091
++  * [Config] Enable CONFIG_X86_X2APIC
++    - LP: #597091
++
++  [ Mathieu J. Poirier ]
++
++  * [Config] ARM: Turning off CONFIG_CPU_IDLE on omap
++    - LP: #594382
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 24 Jun 2010 12:19:48 -0700
++
++linux (2.6.35-5.6) maverick; urgency=low
++
++  [ Amit Kucheria ]
++
++  * [Config] update omap flavour description
++
++  [ Andy Whitcroft ]
++
++  * update to ubuntu-debian:508b7aa34b578c0d1e51bfb571f2bfb824dc65ac
++    - LP: #570500, #576274
++  * SAUCE: add option to hand off all kernel parameters to init
++    - LP: #586386
++  * [Config] enable passing all kernel command line to init
++    - LP: #586386
++  * [Config] disable CONFIG_VMI
++    - LP: #537601
++  * [Config] enable CONFIG_IPV6_SIT_6RD
++    - LP: #591869
++  * [Config] enable CONFIG_VMWARE_BALOON as module
++    - LP: #592039
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: pm: Config option to disable handling of console during
++    suspend/resume"
++    - LP: #594885
++  * [Config] Remove CONFIG_PM_DISABLE_CONSOLE
++  * [Config] ports: enable passing all kernel command line to init
++    - LP: #586386
++  * [Config] Enable CONFIG_FB_VESA=y for x86
++  * [Config] Add CONFIG_FRAMEBUFFER_CONSOLE=y to config enforcer
++  * [Config] Add CONFIG_FB_VESA=y for x86 to config enforcer
++  * [Config] Enable CONFIG_TASK_DELAY_ACCT=y
++    - LP: #493156
++
++  [ Mathieu Poirier ]
++
++  * ARM: Adding MosChip MCS7830 to nic-usb
++    - LP: #584920
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[Upstream] docbook: need xmldoclinks for all doc types"
++  * docbook: need xmldoclinks for all doc types
++  * perf probe: Add kernel source path option
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 17 Jun 2010 08:05:29 -0700
++
++linux (2.6.35-4.5) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Upstream] (evdev) Use driver hint to compute the evdev buffer
++    size (rev2)"
++  * Revert "[Upstream] (evdev) Convert to dynamic event buffer (rev4)"
++  * Revert "[Upstream] (evdev) Use multi-reader buffer to save space
++    (rev4)"
++  * Revert "SAUCE: drivers: Remove some duplicate device entries in various
++    modules"
++  * [Upstream] USB: option: Remove duplicate AMOI_VENDOR_ID
++  * [Upstream] Revert "USB: Adding support for HTC Smartphones to ipaq"
++  * [Upstream] p54usb: Comment out duplicate Medion MD40900 device id
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_NFS_FSCACHE=y
++    - LP: #440522
++  * [Config] CONFIG_FSCACHE_STATS=y, CONFIG_FSCACHE_HISTOGRAM=y
++    - LP: #440522
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 16 Jun 2010 08:43:07 -0700
++
++linux (2.6.35-3.4) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * debian -- ensure the version number is clean
++
++  [ Henrik Rydberg ]
++
++  * [Upstream] Introduce MT event slots (rev 5)
++  * [Upstream] Document the MT event slot protocol (rev5)
++  * [Upstream] (evdev) Use multi-reader buffer to save space (rev4)
++  * [Upstream] (evdev) Convert to dynamic event buffer (rev4)
++  * [Upstream] (evdev) Use driver hint to compute the evdev buffer size
++    (rev2)
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: Add MODULE_ALIAS for Dell WMI module"
++  * Revert "SAUCE: hostap: send events on data interface as well as master
++    interface"
++  * Revert "Fix webcam having USB ID 0ac8:303b"
++  * Revert "SAUCE: toshiba_acpi -- pull in current -dev version of driver"
++  * rebase to v2.6.35-rc3
++
++  [ Maxim Levitsky ]
++
++  * [Config] Enable new Smartmedia/xD translation layer
++    - LP: #202490
++
++  [ Upstream Kernel Changes ]
++
++  * net: fix deliver_no_wcard regression on loopback device
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.35-rc3
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 10 Jun 2010 16:15:22 -0700
++
++linux (2.6.35-2.3) maverick; urgency=low
++
++  [ Bryan Wu ]
++
++  * CONFIG: enforce -- make sure we disable CONFIG_LOCALVERSION_AUTO
++
++  [ Leann Ogasawara ]
++
++  * [Config] armel: Enable CONFIG_BNX2=m
++  * [Config] ports: Enable CONFIG_BNX2X=m
++  * SAUCE: armel: define get_dma_ops to fix FTBS
++
++  [ Tim Gardner ]
++
++  * [Upstream] net: Print num_rx_queues imbalance warning only when there
++    are allocated queues
++    - LP: #591416
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 09 Jun 2010 08:27:41 -0700
++
++linux (2.6.35-2.2) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] d-i: make armel configuration versatile flavour specific
++    - LP: #588805
++  * [Config] d-i: enable .udebs for omap flavour
++    - LP: #588805
++
++  [ Kees Cook ]
++
++  * ptrace: limit scope to attach only (allow read)
++    - LP: #589656
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35-rc2
++  * [Config] update configs following rebase to v2.6.35-rc2
++  * [Config] update port configs following rebase to v2.6.35-rc2
++
++  [ Lee Jones ]
++
++  * Enable perf to be more helpful when perf_<version> does not exist.
++    - LP: #570500
++  * 'fdr editconfig' modification. Easily skip over unwanted menuconfigs.
++
++  [ Tim Gardner ]
++
++  * [Config] Update bnx2 udeb firmware files
++    - LP: #589304
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.35-rc2
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 07 Jun 2010 09:45:04 -0700
++
++linux (2.6.35-1.1) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: AUFS -- update to standalone 2.6.35-rcN as at 20100601
++    - LP: #587888
++  * ubuntu: AUFS -- track changes to the arguements to fop fsync()
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35-rc1
++  * [Config] update configs following rebase to v2.6.35-rc1
++  * [Config] update port configs following rebase to v2.6.35-rc1
++  * SAUCE: lirc: rename usb_buffer_alloc() and usb_buffer_free()
++  * SAUCE: ndiswrapper: rename usb_buffer_alloc() and usb_buffer_free()
++  * SAUCE: ndiswrapper: convert multicast list to list_head
++  * [Config] [FTBS] armel: Temporarily disable CONFIG_GPIO_JANZ_TTL
++  * [Config] [FTBS] ia64: Temporarily disable gpiolib
++  * [Config] [FTBS] ia64: Temporarily disable CONFIG_CEPH_FS
++  * [Config] [FTBS] sparc: Temporarily disable CONFIG_INFINIBAND_QIB
++  * [Config] [FTBS] sparc: Temporarily disable CONFIG_MFD_JANZ_CMODIO
++  * [Config] [FTBS] armel: Temporarily disable CONFIG_MFD_JANZ_CMODIO
++  * [Config] [FTBS] armel: Temporarily disable CONFIG_DT3155
++  * [Config] [FTBS] sparc: Temporarily disable CONFIG_MTD_NAND_DENALI
++  * [Config] [FTBS] armel: Temporarily disable bnx2
++  * [Config] [FTBS] armel: Temporarily disable CONFIG_SERIAL_UARTLITE
++  * SAUCE: [FTBS] armel: Don't include asm/agp.h for ttm
++  * SAUCE: [FTBS] armel: include linux/dma-mapping.h
++  * SAUCE: [FTBS] armel: replace omap_set_gpio_debounce with
++    gpio_set_debounce
++
++  [ Upstream Kernel Changes ]
++
++  * of/usb: fix build error due to of_node pointer move
++  * n2_crypto: Fix build after of_device/of_platform_driver changes.
++  * powerpc/fsl-booke: fix the case where we are not in the first page
++  * powerpc/fsl-booke: Move the entry setup code into a seperate file
++  * powerpc/kexec: Add support for FSL-BookE
++  * greth: Fix build after OF device conversions.
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.35-rc1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 04 Jun 2010 23:01:52 -0700
++
++linux (2.6.35-1.0) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Null entry.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 Jun 2010 15:17:41 -0700
++
++linux (2.6.34-5.14) maverick; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Added module inclusion support
++  * [Config] Added virtual flavour module inclusion list and d-i package
++    definitions
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 Jun 2010 12:58:14 -0700
++
++linux (2.6.34-5.13) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: AUFS -- aufs2 20091209"
++  * Revert "ubuntu: AUFS -- export various core functions
++    (aufs2-standalone.patch)"
++  * Revert "ubuntu: AUFS -- export various core functions
++    (aufs2-base.patch)"
++  * ubuntu: AUFS -- aufs2 base patch for linux-2.6.34
++    - LP: #587888
++  * ubuntu: AUFS -- aufs2 standalone patch for linux-2.6.34
++    - LP: #587888
++  * ubuntu: AUFS -- update to standalone 2.6.34 as at 20100601
++    - LP: #587888
++  * [Config] AUFS -- enable aufs options
++    - LP: #587888
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 01 Jun 2010 08:56:43 -0700
++
++linux (2.6.34-5.12) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * enforce -- ensure SYSFS compatibility is disabled
++
++  [ Chase Douglas ]
++
++  * build with libdw-dev for perf probe symbol support
++  * maverick ftrace configuration changes
++
++  [ Kees Cook ]
++
++  * Revert "SAUCE: x86: brk away from exec rand area"
++  * Revert "SAUCE: [um] Don't use nx_enabled under UML"
++  * Revert "SAUCE: [x86] implement cs-limit nx-emulation for ia32"
++  * SAUCE: x86: implement cs-limit nx-emulation for ia32
++    - LP: #369978
++  * SAUCE: x86: more tightly confine cs-limit nx-emulation to ia32 only
++  * SAUCE: x86: brk away from exec rand area
++    - LP: #452175
++  * SAUCE: ptrace: restrict ptrace scope to children
++
++  [ Leann Ogasawara ]
++
++  * Add new omap flavour to getabis
++  * [Config] Enable CONFIG_FRAMEBUFFER_CONSOLE=y for all archs
++    - LP: #585490
++  * build/modules: Temorarily add ignore.modules
++  * ubuntu: iscsitarget -- version 1.4.20.1
++
++  [ Loïc Minier ]
++
++  * SAUCE: [um] Don't use nx_enabled under UML
++    - LP: #524849
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 28 May 2010 08:27:17 -0700
++
++linux (2.6.34-4.11) maverick; urgency=low
++
++  [ Amit Kucheria ]
++
++  * SAUCE: omap: remove calls to usb_nop_xceiv_register from board files
++  * [Config] Add support for OMAP-mainline flavour
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: powerpc: fix compile error when ptrace.h is included from
++    userspace
++    - LP: #583733
++
++  [ Chase Douglas ]
++
++  * Revert "SAUCE: Don't register vga16fb framebuffer if other framebuffers
++    are present"
++  * Revert "SAUCE: Disable function tracing after hitting __schedule_bug"
++  * Revert "SAUCE: drm/i915: don't change DRM configuration when releasing
++    load detect pipe"
++
++  [ Kees Cook ]
++
++  * SAUCE: fs: block cross-uid sticky symlinks
++  * SAUCE: fs: block hardlinks to non-accessible sources
++
++  [ Koen Kooi ]
++
++  * SAUCE: board-omap3-beagle: add DSS2 support
++
++  [ Leann Ogasawara ]
++
++  * Revert "staging/go7007 -- disable"
++  * Revert "[Config] staging/winbond -- disable"
++  * Revert "Disable 4MB page tables for Atom, work around errata AAE44"
++  * Revert "SAUCE: sync before umount to reduce time taken by ext4 umount"
++  * Revert "SAUCE: Enable an e1000e Intel Corporation 82567 Gigabit
++    controller"
++  * Revert "SAUCE: Fix MODULE_IMPORT/MODULE_EXPORT"
++  * Revert "SAUCE: Created MODULE_EXPORT/MODULE_IMPORT macros"
++  * Revert "SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps"
++  * Revert "SAUCE: r8169: disable TSO by default for RTL8111/8168B
++    chipsets."
++  * Revert "[Upstream] b43: Declare all possible firmware files."
++  * Revert "add Breaks: against hardy lvm2"
++  * Revert "SAUCE: Guest OS does not recognize a lun with non zero target
++    id on Vmware ESX Server"
++  * Revert "SAUCE: Catch nonsense keycodes and silently ignore"
++  * [Config] Enable CONFIG_ECRYPT_FS=y for ports
++  * [Config] Enable CONFIG_USB=y for armel and sparc
++  * [Config] Enable CONFIG_SCSI=y for ia64 and sparc
++  * [Config] Enable CONFIG_RFKILL=y for ports
++  * [Config] Enable CONFIG_ATH9K_DEBUGFS=y
++  * [Config] Enable CONFIG_IWMC3200TOP_DEBUGFS=y
++  * [Config] Enable CONFIG_RCU_FAST_NO_HZ=y
++  * [Config] Enable CONFIG_IWLWIFI_DEVICE_TRACING=y
++  * [Config] Enable CONFIG_LIBERTAS_MESH=y
++  * [Config] Enable CONFIG_MMC_RICOH_MMC=y
++  * [Config] CONFIG_RT2800USB_UNKNOWN=y
++  * [Config] Enable CONFIG_VGA_SWITCHEROO=y
++  * [Config] Enable CONFIG_CEPH_FS=m
++  * [Config] Enable CONFIG_CRYPTO_PCRYPT=m
++  * [Config] Enable CONFIG_EEEPC_WMI=m
++  * [Config] Enable CONFIG_RT2800PCI=m
++  * [Config] Enable CONFIG_SCSI_HPSA=m
++  * [Config] Enable CONFIG_VHOST_NET=m
++  * [Config] Disable CONFIG_SND_HDA_INPUT_BEEP_MODE by default
++    - LP: #582350
++  * [Config] Disable CONFIG_SOUND_OSS* and CONFIG_SND_*OSS
++    - LP: #579300
++  * [Config] Enable CONFIG_PCIEASPM=y
++    - LP: #333990
++  * [Config] updateconfigs for OMAP flavour
++
++  [ Loïc Minier ]
++
++  * Enable perf tools on armel
++
++  [ Tim Gardner ]
++
++  * SAUCE: Updated ndiswrapper to 1.56
++    - LP: #582555
++  * [Config] Added virtual flavour
++  * [Config] Remove support for sub-flavours
++  * [Config] Removed amd64 preempt flavour
++  * [Config] updateconfigs, updateportsconfigs after flavour munging
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 25 May 2010 09:34:55 -0700
++
++linux (2.6.34-3.10) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.34
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 18 May 2010 17:35:35 -0700
++
++linux (2.6.34-2.9) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] [FTBS] Disable comedi for armel
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 13 May 2010 23:20:55 +0200
++
++linux (2.6.34-2.8) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Drop lpia
++  * [Config] [FTBS] disable KVM
++  * [Config] [FTBS] disable ipr for armel
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 13 May 2010 16:07:52 +0200
++
++linux (2.6.34-2.7) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] disable CONFIG_SCSI_IPR on powerpc
++  * [Config] Remove 386 flavour per UDS discussion
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 12 May 2010 18:26:43 +0200
++
++linux (2.6.34-1.6) maverick; urgency=low
++
++  [ Chase Douglas ]
++
++  * enforce CONFIG_TMPFS_POSIX_ACL=y
++    - LP: #575940
++  * don't force module dependency checking
++    - LP: #577029
++
++  [ Kees Cook ]
++
++  * SAUCE: mmap_min_addr check CAP_SYS_RAWIO only for write
++    - LP: #568844
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: ata: blacklist FUJITSU MHW2160BH PL"
++  * rebase to v2.6.34-rc7
++  * [Config] update configs following rebase to v2.6.34-rc7
++  * [Config] update port configs following rebase to v2.6.34-rc7
++  * Add btrfs to the udebs
++
++  [ Tim Gardner ]
++
++  * [Config] Add atl1c to nic-modules udeb
++    - LP: #557130
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc7
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 11 May 2010 11:29:08 +0200
++
++linux (2.6.34-1.5) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.34-rc6
++  * [Config] update configs following rebase to v2.6.34-rc6
++  * [Config] update port configs following rebase to v2.6.34-rc6
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 30 Apr 2010 15:54:05 +0100
++
++linux (2.6.34-1.4) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.34-rc5
++  * [Config] update ports configs following rebase to v2.6.34-rc5
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc5
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 22 Apr 2010 15:36:12 -0700
++
++linux (2.6.34-1.3) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.34-rc4
++  * [Config] update configs following rebase to v2.6.34-rc4
++  * [Config] update port configs following rebase to v2.6.34-rc4
++  * ubuntu: dm-raid4-5 -- update to compile with 2.6.34-rc4
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 13 Apr 2010 18:33:44 -0700
++
++linux (2.6.34-1.2) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Temorarily disable building linux-doc
++  * rebase to v2.6.34-rc3
++  * [Config] update configs following rebase to v2.6.34-rc3
++  * [Config] update port configs following rebase to v2.6.34-rc3
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc3
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 30 Mar 2010 16:55:44 -0700
++
++linux (2.6.34-1.1) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.34-rc2
++  * ubuntu: dm-raid4-5 -- update to compile with 2.6.34-rc2
++  * [Config] update port configs following rebase to v2.6.34-rc2
++  * [Config] update configs following rebase to v2.6.34-rc2
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc2
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 24 Mar 2010 23:00:39 -0700
++
++linux (2.6.33-1.1) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * ubuntu: dm-raid4-5 -- update to compile with 2.6.33
++  * ubuntu: lirc -- drop explicit include of linux/autoconf.h
++  * ubuntu: lirc -- pass kfifo to kfifo_alloc and move spinlock
++  * ubuntu: lirc -- rename kfifo_put and kfifo_get
++  * ubuntu: iscsitarget -- rename daddr inet_sock field
++  * rebased to v2.6.33
++  * [Config] update configs following rebase to v2.6.33
++  * [Config] update ports configs following rebase to v2.6.33
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.33
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 23 Mar 2010 03:55:46 -0700
++
++linux (2.6.33-0.0) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Null entry.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 17 Mar 2010 07:48:56 -0700
++
++linux (2.6.32-16.25) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * linux-tools -- move to Suggests: with explicit seeding
++    - LP: #534635
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_HID=m
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) sched: Fix SMT scheduler regression in
++    find_busiest_queue()
++  * KVM: introduce kvm_vcpu_on_spin
++  * KVM: VMX: Add support for Pause-Loop Exiting
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 09 Mar 2010 14:13:51 +0000
++
++linux (2.6.32-16.24) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * armel -- perf userspace does not support arm
++  * ia64 -- libelf-dev/binutils-dev to not provide necessary libraries
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 06 Mar 2010 11:42:12 +0000
++
++linux (2.6.32-16.23) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: PM report driver and device suspend/resume times -- move config
++  * update to standards version 3.8.4.0
++  * printenv -- expose all of the package selectors
++  * source package -- cleanup source content control
++  * doc package -- ensure we do build package content on buildd
++  * lintian -- correct the address in the debian/copyright
++  * lintian -- update debhelper package version dependancy
++  * lintian -- fix ghostscript dependancy
++  * lintian -- add required misc:Depends
++  * lintian -- move our debhelper compat level to debian/compat
++  * perf -- build the kernel carried tools
++  * perf -- add linux-tools carrying the version switches and manuals
++  * SAUCE: fix up Kconfig for staging drivers
++  * [Config] enable NOUVEAU etc following drm backport
++  * update DRM to mainline v2.6.33
++  * [Config] Remove AppArmor config options that no longer exist (ports)
++  * [Config] updateportsconfigs following drm update
++
++  [ John Johansen ]
++
++  * ubuntu: AppArmor -- update to mainline 2010-03-04
++  * SAUCE: AppArmor: Reintroduce AppArmor 2.4 compatibility
++  * SAUCE: AppArmor: replace strim with strstrip for 2.6.32 kernels
++  * [Config] Remove AppArmor config options that no longer exist
++
++  [ Manoj Iyer ]
++
++  * ubuntu: rtl8192se -- version 2010-0115,0014
++    - LP: #530275
++  * [Config] added CONFIG_RTL8192SE module.
++    - LP: #530275
++
++  [ Tim Gardner ]
++
++  * [Config] Added vmw_pvscsi to d-i/scsi-modules
++    - LP: #531017
++  * [Upstream] netfilter: xt_recent: Add an entry reaper
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "KVM: x86 emulator: Check CPL level during privilege instruction
++    emulation"
++  * Revert "KVM: x86 emulator: Fix popf emulation"
++  * Revert "KVM: x86 emulator: Check IOPL level during io instruction
++    emulation"
++  * Revert "KVM: x86 emulator: Add Virtual-8086 mode of emulation"
++  * Revert "KVM: fix memory access during x86 emulation."
++  * Add vlan (8021.Q) module package for d-i.
++  * (pre-stable) drm/i915: blacklist lid status: Sony VGN-BX196VP, Dell
++    Inspiron 700m
++    - LP: #515246
++  * [Upstream] docbook: need xmldoclinks for all doc types
++  * x86: set_personality_ia32() misses force_personality32
++  * lib: Introduce generic list_sort function
++  * drm/nv50: Implement ctxprog/state generation.
++  * drm/nv50: Remove redundant/incorrect ctxvals initialisation.
++  * (pre-stable) drm/i915: blacklist lid status: Sony VGN-BX196VP, Dell
++    Inspiron 700m
++    - LP: #515246
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Mar 2010 15:40:38 +0000
++
++linux (2.6.32-15.22) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Config] added new config option CONFIG_SR_REPORT_TIME_LIMIT"
++  * Revert "SAUCE: PM report driver and device suspend/resume times."
++  * [Config] set CONFIG_SR_REPORT_TIME_LIMIT
++
++  [ Manoj Iyer ]
++
++  * SAUCE: PM report driver and device suspend/resume times.
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 02 Mar 2010 01:35:37 +0000
++
++linux (2.6.32-15.21) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "(pre-stable) drm/i915: Increase fb alignment to 64k"
++  * Revert "[Config] lenovo-sl-laptop -- enable"
++  * Revert "ubuntu: lenovo-sl-laptop -- git tip (b19a08f81f)"
++  * armel -- cramfs module will no longer be built
++  * d-i -- make all modules optional
++  * rename the debug packages to match archive standard
++    - LP: #527837
++  * lenovo-sl-laptop is no longer built
++
++  [ Colin Ian King ]
++
++  * Disable 4MB page tables for Atom, work around errata AAE44
++    - LP: #523112
++
++  [ Colin Watson ]
++
++  * ubuntu: dm-raid4-5: Depend on XOR_BLOCKS
++  * ubuntu: fsam7400: Depend on CHECK_SIGNATURE
++
++  [ Jesse Barnes ]
++
++  * SAUCE: drm/i915: don't change DRM configuration when releasing load
++    detect pipe
++    - LP: #488328
++
++  [ Loïc Minier ]
++
++  * [Config] armel Update versatile initrd configs
++    - LP: #524893
++  * SAUCE: [um] Don't use nx_enabled under UML
++    - LP: #524849
++
++  [ Manoj Iyer ]
++
++  * [Config] added new config option CONFIG_SR_REPORT_TIME_LIMIT
++
++  [ Mario Limonciello ]
++
++  * SAUCE: v3 - Add Dell Business Class Netbook LED driver
++
++  [ Rafael J. Wysocki ]
++
++  * SAUCE: PM report driver and device suspend/resume times.
++
++  [ Surbhi Palande ]
++
++  * Revert "[Upstream] e1000e: enhance frame fragment detection"
++    - CVE-2009-4538
++  * Revert "[Upstream] e1000: enhance frame fragment detection"
++    - CVE-2009-4536
++
++  [ Tim Gardner ]
++
++  * [Config] Enabled CONFIG_LEDS_DELL_NETBOOKS=m
++  * SAUCE: (pre-stable) netfilter: xt_recent: fix buffer overflow
++  * SAUCE: (pre-stable) netfilter: xt_recent: fix false match
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "(pre-stable) eCryptfs: Add getattr function"
++  * Fix potential crash with sys_move_pages
++  * futex_lock_pi() key refcnt fix
++  * futex: Handle user space corruption gracefully
++  * futex: Handle futex value corruption gracefully
++  * Fix race in tty_fasync() properly
++  * hwmon: (w83781d) Request I/O ports individually for probing
++  * hwmon: (lm78) Request I/O ports individually for probing
++  * hwmon: (adt7462) Wrong ADT7462_VOLT_COUNT
++  * ALSA: ctxfi - fix PTP address initialization
++  * drm/i915: disable hotplug detect before Ironlake CRT detect
++  * drm/i915: enable self-refresh on 965
++  * drm/i915: Disable SR when more than one pipe is enabled
++  * drm/i915: Fix DDC on some systems by clearing BIOS GMBUS setup.
++  * drm/i915: Add HP nx9020/SamsungSX20S to ACPI LID quirk list
++  * drm/i915: Fix the incorrect DMI string for Samsung SX20S laptop
++  * drm/i915: Add MALATA PC-81005 to ACPI LID quirk list
++  * usb: r8a66597-hcd: Flush the D-cache for the pipe-in transfer buffers.
++  * i2c-tiny-usb: Fix on big-endian systems
++  * drm/i915: handle FBC and self-refresh better
++  * drm/i915: Increase fb alignment to 64k
++  * drm/i915: Update write_domains on active list after flush.
++  * regulator: Fix display of null constraints for regulators
++  * ALSA: hda-intel: Avoid divide by zero crash
++  * CPUFREQ: Fix use after free of struct powernow_k8_data
++  * freeze_bdev: don't deactivate successfully frozen MS_RDONLY sb
++  * cciss: Make cciss_seq_show handle holes in the h->drv[] array
++  * ioat: fix infinite timeout checking in ioat2_quiesce
++  * resource: add helpers for fetching rlimits
++  * fs/exec.c: restrict initial stack space expansion to rlimit
++  * cifs: fix length calculation for converted unicode readdir names
++  * NFS: Fix a reference leak in nfs_wb_cancel_page()
++  * NFS: Try to commit unstable writes in nfs_release_page()
++  * NFSv4: Don't allow posix locking against servers that don't support it
++  * NFSv4: Ensure that the NFSv4 locking can recover from stateid errors
++  * NFS: Fix an Oops when truncating a file
++  * NFS: Fix a umount race
++  * NFS: Fix a bug in nfs_fscache_release_page()
++  * NFS: Fix the mapping of the NFSERR_SERVERFAULT error
++  * md: fix 'degraded' calculation when starting a reshape.
++  * V4L/DVB: dvb-core: fix initialization of feeds list in demux filter
++  * Export the symbol of getboottime and mmonotonic_to_bootbased
++  * kvmclock: count total_sleep_time when updating guest clock
++  * KVM: PIT: control word is write-only
++  * tpm_infineon: fix suspend/resume handler for pnp_driver
++  * amd64_edac: Do not falsely trigger kerneloops
++  * netfilter: nf_conntrack: fix memory corruption with multiple namespaces
++  * netfilter: nf_conntrack: per netns nf_conntrack_cachep
++  * netfilter: nf_conntrack: restrict runtime expect hashsize modifications
++  * netfilter: xtables: compat out of scope fix
++  * netfilter: nf_conntrack: fix hash resizing with namespaces
++  * drm/i915: remove full registers dump debug
++  * drm/i915: add i915_lp_ring_sync helper
++  * drm/i915: Don't wait interruptible for possible plane buffer flush
++  * dasd: remove strings from s390dbf
++  * crypto: padlock-sha - Add import/export support
++  * wmi: Free the allocated acpi objects through wmi_get_event_data
++  * dell-wmi, hp-wmi, msi-wmi: check wmi_get_event_data() return value
++  * /dev/mem: introduce size_inside_page()
++  * devmem: check vmalloc address on kmem read/write
++  * devmem: fix kmem write bug on memory holes
++  * SCSI: mptfusion : mptscsih_abort return value should be SUCCESS instead
++    of value 0.
++  * sh: Couple kernel and user write page perm bits for CONFIG_X2TLB
++  * ALSA: hda - use WARN_ON_ONCE() for zero-division detection
++  * dst: call cond_resched() in dst_gc_task()
++  * ALSA: hda - Improved MacBook (Pro) 5,1 / 5,2 support
++  * befs: fix leak
++  * rtc-fm3130: add missing braces
++  * Call flush_dcache_page after PIO data transfers in libata-sff.c
++  * ahci: add Acer G725 to broken suspend list
++  * pktgen: Fix freezing problem
++  * x86/amd-iommu: Fix IOMMU-API initialization for iommu=pt
++  * x86/amd-iommu: Fix deassignment of a device from the pt_domain
++  * x86: Re-get cfg_new in case reuse/move irq_desc
++  * Staging: fix rtl8187se compilation errors with mac80211
++  * ALSA: usb-audio - Avoid Oops after disconnect
++  * serial: 8250: add serial transmitter fully empty test
++  * sysfs: sysfs_sd_setattr set iattrs unconditionally
++  * class: Free the class private data in class_release
++  * USB: usbfs: only copy the actual data received
++  * USB: usbfs: properly clean up the as structure on error paths
++  * rtl8187: Add new device ID
++  * ACPI: Add NULL pointer check in acpi_bus_start
++  * ACPI: fix High cpu temperature with 2.6.32
++  * drm/radeon/kms: use udelay for short delays
++  * NFS: Too many GETATTR and ACCESS calls after direct I/O
++  * eCryptfs: Add getattr function
++  * b43: Fix throughput regression
++  * ath9k: Fix sequence numbers for PAE frames
++  * mac80211: Fix probe request filtering in IBSS mode
++  * iwlwifi: Fix to set correct ht configuration
++  * dm stripe: avoid divide by zero with invalid stripe count
++  * dm log: userspace fix overhead_size calcuations
++  * Linux 2.6.32.9
++  * sfc: Fix SFE4002 initialisation
++  * sfc: Fix sign of efx_mcdi_poll_reboot() error in efx_mcdi_poll()
++  * sfc: SFE4002/SFN4112F: Widen temperature and voltage tolerances
++  * (pre-stable) HID: handle joysticks with large number of buttons
++    - LP: #492056
++  * (pre-stable) HID: extend mask for BUTTON usage page
++    - LP: #492056
++  * PM: Measure device suspend and resume times
++  * e1000: enhance frame fragment detection
++    - CVE-2009-4536
++  * e1000e: enhance frame fragment detection
++    - CVE-2009-4538
++  * KVM: fix memory access during x86 emulation.
++    - CVE-2010-0306
++  * KVM: x86 emulator: Add Virtual-8086 mode of emulation
++    - CVE-2010-0306
++  * KVM: x86 emulator: Check IOPL level during io instruction emulation
++    - CVE-2010-0306
++  * KVM: x86 emulator: Fix popf emulation
++    - CVE-2010-0306
++  * KVM: x86 emulator: Check CPL level during privilege instruction
++    emulation
++    - CVE-2010-0306
++  * Input: wacom - ensure the device is initialized properly upon resume
++  * Input: wacom - add defines for packet lengths of various devices
++  * Input: wacom - add support for new LCD tablets
++    - LP: #516777
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 01 Mar 2010 22:56:28 +0000
++
++linux (2.6.32-14.20) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebuild following the GCC update to match compiler for out of tree modules
++  * Revert "[Config] drbd -- enable"
++  * Revert "ubuntu: drbd -- version 8.3.1"
++  * SAUCE: khubd -- switch USB product/manufacturer/serial handling to RCU
++    - LP: #510937
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 19 Feb 2010 18:47:18 +0000
++
++linux (2.6.32-14.19) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ensure we build the source package contents when enabled
++    - LP: #522308
++  * [Config] enable CONFIG_X86_MCE_XEON75XX
++  * SAUCE: AppArmor -- add linux/kref.h for struct kref
++  * [Config] enable CONFIG_HID_ORTEK
++  * enable udeb generation for arm versatile flavour
++    - LP: #522515
++
++  [ John Johansen ]
++
++  * ubuntu: AppArmor -- update to mainline 2010-02-18
++    - LP: #439560, #496110, #507069
++
++  [ Johnathon Harris ]
++
++  * SAUCE: HID: add support for Ortek WKB-2000
++    - LP: #405390
++
++  [ Upstream Kernel Changes ]
++
++  * tpm_tis: TPM_STS_DATA_EXPECT workaround
++    - LP: #490487
++  * x86, mce: Xeon75xx specific interface to get corrected memory error
++    information
++  * x86, mce: Rename cpu_specific_poll to mce_cpu_specific_poll
++  * x86, mce: Make xeon75xx memory driver dependent on PCI
++  * drm/edid: Unify detailed block parsing between base and extension
++    blocks
++    - LP: #500999
++  * (pre-stable) eCryptfs: Add getattr function
++    - LP: #390833
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 18 Feb 2010 19:22:02 +0000
++
++linux (2.6.32-13.18) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "enforcer -- make the enforcement configuration common"
++  * Revert "(pre-stable) Input: ALPS - add interleaved protocol support
++    (Dell E6x00 series)"
++  * Revert "(pre-stable) driver-core: fix devtmpfs crash on s390"
++  * Revert "(pre-stable) Driver-Core: devtmpfs - set root directory mode to
++    0755"
++  * Revert "SAUCE: Adds support for COMPAL JHL90 webcam"
++  * Revert "SAUCE: fix kernel oops in VirtualBox during paravirt patching"
++  * Revert "SAUCE: make fc transport removal of target configurable"
++  * enforcer -- make the enforcement configuration common
++  * getabis -- add preempt flavour to the list
++  * [Config] enforce DEVTMPFS options
++  * [Config] armel -- cleanup to-be builtin modules
++  * [Config] cleanup ports configs
++  * [Config] enable CRYPTO_GHASH_CLMUL_NI_INTEL
++    - LP: #485536
++  * add printdebian target to find branch target
++  * distclean -- do not remove debian.env
++  * [Config] generic-pae switch to M586TSC
++    - LP: #519448
++  * git-ubuntu-log -- commonise duplicated log handling
++  * git-ubuntu-log -- tighten up Bug: NNNN matching
++  * git-ubuntu-log -- sort the bug numbers
++
++  [ Chris Wilson ]
++
++  * (pre-stable) drm/i915: Increase fb alignment to 64k
++    - LP: #404064
++
++  [ Eric Miao ]
++
++  * arm -- enable ubuntu/ directory
++
++  [ Huang Ying ]
++
++  * SAUCE: crypto: ghash - Add PCLMULQDQ accelerated implementation
++  * SAUCE: crypto: ghash-intel - Fix building failure on x86_32
++
++  [ Loïc Minier ]
++
++  * [Config] cleanup preempt configuration
++  * [Config] versatile: Fix video output
++    - LP: #517594
++  * [Config] armel DEFAULT_MMAP_MIN_ADDR=32768
++  * [Config] Large update to armel/versatile
++  * [Config] versatile: Add RTC support
++  * [Config] armel: Enable NEON
++  * [Config] versatile: Builtin MMC support
++  * [Config] versatile Builtin SCSI controller
++  * [Config] armel Disable dma_cache_sync callers
++  * [Config] armel Disable asm/time.h users
++  * [Config] armel Disable out of range udelay()
++  * [Config] armel Disable flush_cache_range() users
++  * [Config] armel -- Enable ubuntu/ drivers
++
++  [ Steve Conklin ]
++
++  * SAUCE: drm/i915: Add display hotplug event on Ironlake
++  * SAUCE: drm/i915: Add ACPI OpRegion support for Ironlake
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[Upstream]: oprofile/x86: add Xeon 7500 series support"
++  * Revert "Revert "[Bluetooth] Eliminate checks for impossible conditions
++    in IRQ handler""
++  * clockevent: Don't remove broadcast device when cpu is dead
++  * clockevents: Add missing include to pacify sparse
++  * ACPI: don't cond_resched if irq is disabled
++  * be2net: Add support for next generation of BladeEngine device.
++  * be2net: Add the new PCI IDs to PCI_DEVICE_TABLE.
++  * mpt2sas: New device SAS2208 support is added
++  * ar9170: Add support for D-Link DWA 160 A2
++  * powerpc/fsl: Add PCI device ids for new QoirQ chips
++  * davinci: dm646x: Add support for 3.x silicon revision
++  * Input: ALPS - add interleaved protocol support (Dell E6x00 series)
++  * Driver-Core: devtmpfs - set root directory mode to 0755
++  * driver-core: fix devtmpfs crash on s390
++  * vfs: get_sb_single() - do not pass options twice
++  * ALSA: hda - Add PCI IDs for Nvidia G2xx-series
++  * V4L/DVB (13569): smsusb: add autodetection support for five additional
++    Hauppauge USB IDs
++  * USB: mos7840: add device IDs for B&B electronics devices
++  * USB: ftdi_sio: add USB device ID's for B&B Electronics line
++  * V4L/DVB (13168): Add support for Asus Europa Hybrid DVB-T card (SAA7134
++    SubVendor ID: 0x1043 Device ID: 0x4847)
++  * iTCO_wdt: Add support for Intel Ibex Peak
++  * atl1c:use common_task instead of reset_task and link_chg_task
++  * atl1e:disable NETIF_F_TSO6 for hardware limit
++  * V4L/DVB (13680a): DocBook/media: copy images after building HTML
++  * V4L/DVB (13680b): DocBook/media: create links for included sources
++  * netfilter: xtables: fix conntrack match v1 ipt-save output
++  * partitions: read whole sector with EFI GPT header
++  * partitions: use sector size for EFI GPT
++  * ALSA: ice1724 - Patch for suspend/resume for ESI Juli@
++  * sched: Fix isolcpus boot option
++  * sched: Fix missing sched tunable recalculation on cpu add/remove
++  * nohz: Prevent clocksource wrapping during idle
++  * nfsd: Fix sort_pacl in fs/nfsd/nf4acl.c to actually sort groups
++  * timers, init: Limit the number of per cpu calibration bootup messages
++  * PCI: Always set prefetchable base/limit upper32 registers
++  * iscsi class: modify handling of replacement timeout
++  * NFS: Revert default r/wsize behavior
++  * HID: fixup quirk for NCR devices
++  * scsi_devinfo: update Hitachi entries (v2)
++  * scsi_dh: create sysfs file, dh_state for all SCSI disk devices
++  * scsi_transport_fc: remove invalid BUG_ON
++  * lpfc: fix hang on SGI ia64 platform
++  * libfc: fix typo in retry check on received PRLI
++  * libfc: fix ddp in fc_fcp for 0 xid
++  * fcoe: remove redundant checking of netdev->netdev_ops
++  * libfc: Fix wrong scsi return status under FC_DATA_UNDRUN
++  * libfc: lport: fix minor documentation errors
++  * libfc: don't WARN_ON in lport_timeout for RESET state
++  * fcoe: initialize return value in fcoe_destroy
++  * libfc: Fix frags in frame exceeding SKB_MAX_FRAGS in fc_fcp_send_data
++  * libfc: fix memory corruption caused by double frees and bad error
++    handling
++  * libfc: fix free of fc_rport_priv with timer pending
++  * libfc: remote port gets stuck in restart state without really
++    restarting
++  * fcoe, libfc: fix an libfc issue with queue ramp down in libfc
++  * fcoe: Fix checking san mac address
++  * fcoe: Fix getting san mac for VLAN interface
++  * qlge: Remove explicit setting of PCI Dev CTL reg.
++  * qlge: Set PCIE max read request size.
++  * qlge: Don't fail open when port is not initialized.
++  * qlge: Add handler for DCBX firmware event.
++  * qlge: Bonding fix for mode 6.
++  * PCI: AER: fix aer inject result in kernel oops
++  * DMI: allow omitting ident strings in DMI tables
++  * Input: i8042 - remove identification strings from DMI tables
++  * Input: i8042 - add Gigabyte M1022M to the noloop list
++  * Input: i8042 - add Dritek quirk for Acer Aspire 5610.
++  * ALSA: hda - select IbexPeak handler for Calpella
++  * ALSA: hda - Fix quirk for Maxdata obook4-1
++  * ALSA: hda - Add missing Line-Out and PCM switches as slave
++  * iTCO_wdt.c - cleanup chipset documentation
++  * iTCO_wdt: add PCI ID for the Intel EP80579 (Tolapai) SoC
++  * iTCO_wdt: Add Intel Cougar Point and PCH DeviceIDs
++  * ahci: disable SNotification capability for ich8
++  * ata_piix: fix MWDMA handling on PIIX3
++  * md: fix small irregularity with start_ro module parameter
++  * V4L/DVB (13826): uvcvideo: Fix controls blacklisting
++  * cio: fix double free in case of probe failure
++  * cio: dont panic in non-fatal conditions
++  * netiucv: displayed TX bytes value much too high
++  * ipc ns: fix memory leak (idr)
++  * ALSA: hda - Fix HP T5735 automute
++  * hwmon: (fschmd) Fix a memleak on multiple opens of /dev/watchdog
++  * UBI: fix memory leak in update path
++  * UBI: initialise update marker
++  * ASoC: fix a memory-leak in wm8903
++  * mac80211: check that ieee80211_set_power_mgmt only handles STA
++    interfaces.
++  * cfg80211: fix channel setting for wext
++  * KVM: S390: fix potential array overrun in intercept handling
++  * KVM: only allow one gsi per fd
++  * KVM: Fix race between APIC TMR and IRR
++  * KVM: MMU: bail out pagewalk on kvm_read_guest error
++  * KVM: x86: Fix host_mapping_level()
++  * KVM: x86: Fix probable memory leak of vcpu->arch.mce_banks
++  * KVM: x86: Fix leak of free lapic date in kvm_arch_vcpu_init()
++  * KVM: fix lock imbalance in kvm_*_irq_source_id()
++  * KVM: only clear irq_source_id if irqchip is present
++  * IPoIB: Clear ipoib_neigh.dgid in ipoib_neigh_alloc()
++  * x86: Reenable TSC sync check at boot, even with NONSTOP_TSC
++  * ACPI: enable C2 and Turbo-mode on Nehalem notebooks on A/C
++    - LP: #516325
++  * iwlwifi: Fix throughput stall issue in HT mode for 5000
++  * fnctl: f_modown should call write_lock_irqsave/restore
++  * x86, msr/cpuid: Pass the number of minors when unregistering MSR and
++    CPUID drivers.
++  * Linux 2.6.32.7
++  * scsi_lib: Fix bug in completion of bidi commands
++  * mptsas: Fix issue with chain pools allocation on katmai
++  * mm: add new 'read_cache_page_gfp()' helper function
++  * drm/i915: Selectively enable self-reclaim
++  * firewire: ohci: fix crashes with TSB43AB23 on 64bit systems
++  * S390: fix single stepped svcs with TRACE_IRQFLAGS=y
++  * x86: Set hotpluggable nodes in nodes_possible_map
++  * x86: Remove "x86 CPU features in debugfs" (CONFIG_X86_CPU_DEBUG)
++  * libata: retry FS IOs even if it has failed with AC_ERR_INVALID
++  * zcrypt: Do not remove coprocessor for error 8/72
++  * dasd: fix possible NULL pointer errors
++  * ACPI: Add a generic API for _OSC -v2
++  * ACPI: Add platform-wide _OSC support.
++  * ACPI: fix OSC regression that caused aer and pciehp not to load
++  * ACPI: Advertise to BIOS in _OSC: _OST on _PPC changes
++  * UBI: fix volume creation input checking
++  * e1000/e1000e: don't use small hardware rx buffers
++  * drm/i915: Reload hangcheck timer too for Ironlake
++  * Fix a leak in affs_fill_super()
++  * Fix failure exits in bfs_fill_super()
++  * fix oops in fs/9p late mount failure
++  * fix leak in romfs_fill_super()
++  * Fix remount races with symlink handling in affs
++  * fix affs parse_options()
++  * Fix failure exit in ipathfs
++  * mm: fix migratetype bug which slowed swapping
++  * FDPIC: Respect PT_GNU_STACK exec protection markings when creating
++    NOMMU stack
++  * Split 'flush_old_exec' into two functions
++  * sparc: TIF_ABI_PENDING bit removal
++  * x86: get rid of the insane TIF_ABI_PENDING bit
++  * Input: winbond-cir - remove dmesg spam
++  * x86: Disable HPET MSI on ATI SB700/SB800
++  * iwlwifi: set default aggregation frame count limit to 31
++  * drm/i915: only enable hotplug for detected outputs
++  * firewire: core: add_descriptor size check
++  * SECURITY: selinux, fix update_rlimit_cpu parameter
++  * regulator: Specify REGULATOR_CHANGE_STATUS for WM835x LED constraints
++  * x86: Add Dell OptiPlex 760 reboot quirk
++    - LP: #488319
++  * x86: Add quirk for Intel DG45FC board to avoid low memory corruption
++  * x86/amd-iommu: Fix possible integer overflow
++  * clocksource: fix compilation if no GENERIC_TIME
++  * tcp: update the netstamp_needed counter when cloning sockets
++  * sky2: Fix oops in sky2_xmit_frame() after TX timeout
++  * net: restore ip source validation
++  * af_packet: Don't use skb after dev_queue_xmit()
++  * ax25: netrom: rose: Fix timer oopses
++  * KVM: allow userspace to adjust kvmclock offset
++  * oprofile/x86: add Xeon 7500 series support
++  * oprofile/x86: fix crash when profiling more than 28 events
++  * libata: retry link resume if necessary
++  * mm: percpu-vmap fix RCU list walking
++  * mm: purge fragmented percpu vmap blocks
++  * block: fix bio_add_page for non trivial merge_bvec_fn case
++  * Fix 'flush_old_exec()/setup_new_exec()' split
++  * random: drop weird m_time/a_time manipulation
++  * random: Remove unused inode variable
++  * block: fix bugs in bio-integrity mempool usage
++  * usb: r8a66597-hdc disable interrupts fix
++  * connector: Delete buggy notification code.
++  * be2net: Bug fix to support newer generation of BE ASIC
++  * be2net: Fix memset() arg ordering.
++  * mm: flush dcache before writing into page to avoid alias
++  * mac80211: fix NULL pointer dereference when ftrace is enabled
++  * imxfb: correct location of callbacks in suspend and resume
++  * mx3fb: some debug and initialisation fixes
++  * starfire: clean up properly if firmware loading fails
++  * kernel/cred.c: use kmem_cache_free
++  * uartlite: fix crash when using as console
++  * pktcdvd: removing device does not remove its sysfs dir
++  * ath9k: fix eeprom INI values override for 2GHz-only cards
++  * ath9k: fix beacon slot/buffer leak
++  * powerpc: TIF_ABI_PENDING bit removal
++  * NET: fix oops at bootime in sysctl code
++  * Linux 2.6.32.8
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 10 Feb 2010 18:56:52 +0000
++
++linux (2.6.32-12.17) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * restore linux-image prefix -- master
++  * enforce -- we require SELINUX enabled -- master
++  * enforce -- ensure APPARMOR is our default LSM -- master
++  * make doc package completely optional -- master
++  * make source package completely optional -- master
++  * make linux-libc-dev completly optional -- master
++  * convert package disable to a deps list -- master
++  * allow common headers to switch from indep to arch -- master
++  * convert binary package disable to a deps list -- master
++  * add configuration option for a full source build tree -- master
++  * add support for uImage kernels in package control scripts
++  * getabis -- cleanup and parameterise repository list -- master
++  * getabis -- move configuration to etc/getabi -- master
++  * kernelconfig -- move configuration to etc -- master
++  * rules -- make debian/debian.env master for branch name
++  * set the current branch name -- master
++  * pull back common debian.master files into debian -- master
++  * enforcer -- make the enforcement configuration common
++  * insert-changes -- correctly link to debian/rules in DROOT
++
++  [ Colin Watson ]
++
++  * future-proof ddeb handling against buildd changes
++
++  [ Eric Miao ]
++
++  * SAUCE: Make CONFIG_{OMNIBOOK, AVERATEC_5100P, PACKARDBELL_E5} depend on
++    X86
++
++  [ Loïc Minier ]
++
++  * Add modules.builtin.bin to prerm rm list
++    - LP: #516584
++
++  [ Tim Gardner ]
++
++  * [Config] Implement the amd64 preempt flavour
++
++  [ Upstream Kernel Changes ]
++
++  * syslog: distinguish between /proc/kmsg and syscalls
++    - LP: #515623
++  * sfc: Fix polling for slow MCDI operations
++  * sfc: Fix conditions for MDIO self-test
++  * sfc: QT202x: Remove unreliable MMD check at initialisation
++  * sfc: Add workspace for GMAC bug workaround to MCDI MAC_STATS buffer
++  * sfc: Use fixed-size buffers for MCDI NVRAM requests
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Feb 2010 07:09:31 +0000
++
++linux (2.6.32-12.16) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: acpi battery -- delay first lookup of the battery until
++    first use"
++  * SAUCE: acpi battery -- move first lookup asynchronous
++    - LP: #507211
++  * [Config] update configs to cleanup generic configs
++  * [Config] disable CONFIG_X86_CPU_DEBUG for amd64
++  * [Config] enable USER_NS
++    - LP: #480739, #509808
++
++  [ Heiko Carstens ]
++
++  * (pre-stable) driver-core: fix devtmpfs crash on s390
++    - LP: #512370
++
++  [ John Johansen ]
++
++  * [Config] for server and virtual flavours make CONFIG_SCSI_SYM53C8XX_2=y
++    - LP: #494565
++  * [Config] VIRTIO=y for server/virtual flavours
++    - LP: #494565
++
++  [ Kay Sievers ]
++
++  * (pre-stable) Driver-Core: devtmpfs - set root directory mode to 0755
++    - LP: #512370
++
++  [ Kees Cook ]
++
++  * SAUCE: x86: brk away from exec rand area
++    - LP: #452175
++
++  [ Leann Ogasawara ]
++
++  * [Upstream] e1000: enhance frame fragment detection
++    - CVE-2009-4536
++  * [Upstream] e1000e: enhance frame fragment detection
++    - CVE-2009-4538
++
++  [ Sebastian Kapfer ]
++
++  * (pre-stable) Input: ALPS - add interleaved protocol support (Dell E6x00
++    series)
++    - LP: #296610
++
++  [ Upstream Kernel Changes ]
++
++  * inotify: do not reuse watch descriptors
++    - LP: #485556
++  * inotify: only warn once for inotify problems
++  * revert "drivers/video/s3c-fb.c: fix clock setting for Samsung SoC
++    Framebuffer"
++  * memcg: ensure list is empty at rmdir
++  * drm/i915: remove loop in Ironlake interrupt handler
++  * block: Fix incorrect reporting of partition alignment
++  * x86, mce: Thermal monitoring depends on APIC being enabled
++  * futexes: Remove rw parameter from get_futex_key()
++  * page allocator: update NR_FREE_PAGES only when necessary
++  * x86, apic: use physical mode for IBM summit platforms
++  * edac: i5000_edac critical fix panic out of bounds
++  * x86: SGI UV: Fix mapping of MMIO registers
++  * mfd: WM835x GPIO direction register is not locked
++  * mfd: Correct WM835x ISINK ramp time defines
++  * ALSA: hda - Fix missing capture mixer for ALC861/660 codecs
++  * V4L/DVB (13868): gspca - sn9c20x: Fix test of unsigned.
++  * reiserfs: truncate blocks not used by a write
++  * HID: add device IDs for new model of Apple Wireless Keyboard
++  * PCI/cardbus: Add a fixup hook and fix powerpc
++  * Input: pmouse - move Sentelic probe down the list
++  * asus-laptop: add Lenovo SL hotkey support
++  * sched: Fix cpu_clock() in NMIs, on !CONFIG_HAVE_UNSTABLE_SCHED_CLOCK
++  * sparc64: Fix NMI programming when perf events are active.
++  * sparc64: Fix Niagara2 perf event handling.
++  * i2c: Do not use device name after device_unregister
++  * i2c/pca: Don't use *_interruptible
++  * serial/8250_pnp: add a new Fujitsu Wacom Tablet PC device
++  * sched: Fix task priority bug
++  * vfs: Fix vmtruncate() regression
++  * Linux 2.6.32.5
++  * x86, msr/cpuid: Register enough minors for the MSR and CPUID drivers
++  * V4L/DVB (13900): gspca - sunplus: Fix bridge exchanges.
++  * Staging: asus_oled: fix oops in 2.6.32.2
++  * Staging: hv: fix smp problems in the hyperv core code
++  * tty: fix race in tty_fasync
++  * ecryptfs: use after free
++  * ecryptfs: initialize private persistent file before dereferencing
++    pointer
++  * nozomi: quick fix for the close/close bug
++  * serial: 8250_pnp: use wildcard for serial Wacom tablets
++  * usb: serial: fix memory leak in generic driver
++  * USB: fix bitmask merge error
++  * USB: Don't use GFP_KERNEL while we cannot reset a storage device
++  * USB: EHCI: fix handling of unusual interrupt intervals
++  * USB: EHCI & UHCI: fix race between root-hub suspend and port resume
++  * USB: add missing delay during remote wakeup
++  * USB: add speed values for USB 3.0 and wireless controllers
++  * ACPI: EC: Accelerate query execution
++  * ACPI: EC: Add wait for irq storm
++  * SCSI: enclosure: fix oops while iterating enclosure_status array
++  * drm/i915: Read the response after issuing DDC bus switch command
++  * drm/i915: try another possible DDC bus for the SDVO device with
++    multiple outputs
++  * block: bdev_stack_limits wrapper
++  * DM: Fix device mapper topology stacking
++  * x86/PCI/PAT: return EINVAL for pci mmap WC request for !pat_enabled
++  * USB: fix usbstorage for 2770:915d delivers no FAT
++  * vmalloc: remove BUG_ON due to racy counting of VM_LAZY_FREE
++  * perf timechart: Use tid not pid for COMM change
++  * perf events: Dont report side-band events on each cpu for
++    per-task-per-cpu events
++  * perf: Honour event state for aux stream data
++  * Linux 2.6.32.6
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 27 Jan 2010 16:40:23 +0000
++
++linux (2.6.32-11.15) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "(pre-stable) drm/radeon/kms: fix crtc vblank update for r600"
++  * Revert "(pre-stable) sched: Fix balance vs hotplug race"
++  * Revert "[Upstream] acerhdf: Limit modalias matching to supported
++    boards"
++  * Revert "[Upstream] mmc: prevent dangling block device from accessing
++    stale queues"
++  * Revert "SAUCE: Fix nx_enable reporting"
++  * Revert "SAUCE: [x86] fix report of cs-limit nx-emulation"
++  * Revert "SAUCE: [x86] implement cs-limit nx-emulation for ia32"
++  * SAUCE: i915 -- disable powersave by default
++    - LP: #492392
++
++  [ Kees Cook ]
++
++  * SAUCE: [x86] implement cs-limit nx-emulation for ia32
++    - LP: #369978
++  * SAUCE: [x86] fix report of cs-limit nx-emulation
++    - LP: #454285
++  * SAUCE: Fix nx_enable reporting
++    - LP: #454285
++
++  [ Tim Gardner ]
++
++  * [Upstream] b43: Declare all possible firmware files.
++    - LP: #488636
++  * [Config] updateconfigs after adding pvscsi
++    - LP: #497156
++  * [Config] CONFIG_BT=m
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "x86: Side-step lguest problem by only building cmpxchg8b_emu
++    for pre-Pentium"
++  * SCSI: ipr: fix EEH recovery
++  * SCSI: qla2xxx: dpc thread can execute before scsi host has been added
++  * SCSI: st: fix mdata->page_order handling
++  * SCSI: fc class: fix fc_transport_init error handling
++  * sched: Fix task_hot() test order
++  * x86, cpuid: Add "volatile" to asm in native_cpuid()
++  * sched: Select_task_rq_fair() must honour SD_LOAD_BALANCE
++  * clockevents: Prevent clockevent_devices list corruption on cpu hotplug
++  * pata_hpt3x2n: fix clock turnaround
++  * pata_cmd64x: fix overclocking of UDMA0-2 modes
++  * ASoC: wm8974: fix a wrong bit definition
++  * sound: sgio2audio/pdaudiocf/usb-audio: initialize PCM buffer
++  * ALSA: hda - Fix missing capsrc_nids for ALC88x
++  * acerhdf: limit modalias matching to supported
++    - LP: #435958
++  * ACPI: EC: Fix MSI DMI detection
++  * ACPI: Use the return result of ACPI lid notifier chain correctly
++  * powerpc: Handle VSX alignment faults correctly in little-endian mode
++  * ASoC: Do not write to invalid registers on the wm9712.
++  * drm/radeon: fix build on 64-bit with some compilers.
++  * USB: emi62: fix crash when trying to load EMI 6|2 firmware
++  * USB: option: support hi speed for modem Haier CE100
++  * USB: Fix a bug on appledisplay.c regarding signedness
++  * USB: musb: gadget_ep0: avoid SetupEnd interrupt
++  * Bluetooth: Prevent ill-timed autosuspend in USB driver
++  * USB: rename usb_configure_device
++  * USB: fix bugs in usb_(de)authorize_device
++  * drivers/net/usb: Correct code taking the size of a pointer
++  * x86: SGI UV: Fix writes to led registers on remote uv hubs
++  * md: Fix unfortunate interaction with evms
++  * dma: at_hdmac: correct incompatible type for argument 1 of
++    'spin_lock_bh'
++  * dma-debug: Do not add notifier when dma debugging is disabled.
++  * dma-debug: Fix bug causing build warning
++  * cifs: NULL out tcon, pSesInfo, and srvTcp pointers when chasing DFS
++    referrals
++  * x86/amd-iommu: Fix initialization failure panic
++  * ioat3: fix p-disabled q-continuation
++  * ioat2,3: put channel hardware in known state at init
++  * KVM: MMU: remove prefault from invlpg handler
++  * KVM: LAPIC: make sure IRR bitmap is scanned after vm load
++  * Libertas: fix buffer overflow in lbs_get_essid()
++  * iwmc3200wifi: fix array out-of-boundary access
++  * mac80211: fix propagation of failed hardware reconfigurations
++  * mac80211: fix WMM AP settings application
++  * mac80211: Fix IBSS merge
++  * cfg80211: fix race between deauth and assoc response
++  * ath5k: fix SWI calibration interrupt storm
++  * ath9k: wake hardware for interface IBSS/AP/Mesh removal
++  * ath9k: Fix TX queue draining
++  * ath9k: fix missed error codes in the tx status check
++  * ath9k: wake hardware during AMPDU TX actions
++  * ath9k: fix suspend by waking device prior to stop
++  * ath9k_hw: Fix possible OOB array indexing in gen_timer_index[] on
++    64-bit
++  * ath9k_hw: Fix AR_GPIO_INPUT_EN_VAL_BT_PRIORITY_BB and its shift value
++    in 0x4054
++  * iwl3945: disable power save
++  * iwl3945: fix panic in iwl3945 driver
++  * iwlwifi: fix EEPROM/OTP reading endian annotations and a bug
++  * iwlwifi: fix more eeprom endian bugs
++  * iwlwifi: fix 40MHz operation setting on cards that do not allow it
++  * mac80211: fix race with suspend and dynamic_ps_disable_work
++  * NOMMU: Optimise away the {dac_,}mmap_min_addr tests
++  * 'sysctl_max_map_count' should be non-negative
++  * kernel/sysctl.c: fix the incomplete part of
++    sysctl_max_map_count-should-be-non-negative.patch
++  * V4L/DVB (13596): ov511.c typo: lock => unlock
++  * x86/ptrace: make genregs[32]_get/set more robust
++  * memcg: avoid oom-killing innocent task in case of use_hierarchy
++  * e100: Fix broken cbs accounting due to missing memset.
++  * ipv6: reassembly: use seperate reassembly queues for conntrack and
++    local delivery
++  * netfilter: fix crashes in bridge netfilter caused by fragment jumps
++  * hwmon: (sht15) Off-by-one error in array index + incorrect constants
++  * b43: avoid PPC fault during resume
++  * Keys: KEYCTL_SESSION_TO_PARENT needs TIF_NOTIFY_RESUME architecture
++    support
++  * sched: Fix balance vs hotplug race
++  * drm/radeon/kms: fix crtc vblank update for r600
++  * drm: disable all the possible outputs/crtcs before entering KMS mode
++  * S390: dasd: support DIAG access for read-only devices
++  * xen: fix is_disconnected_device/exists_disconnected_device
++  * xen: improvement to wait_for_devices()
++  * xen: wait up to 5 minutes for device connetion
++  * orinoco: fix GFP_KERNEL in orinoco_set_key with interrupts disabled
++  * udf: Try harder when looking for VAT inode
++  * Add unlocked version of inode_add_bytes() function
++  * quota: decouple fs reserved space from quota reservation
++  * ext4: Convert to generic reserved quota's space management.
++  * ext4: fix sleep inside spinlock issue with quota and dealloc (#14739)
++  * x86, msr: Unify rdmsr_on_cpus/wrmsr_on_cpus
++  * cpumask: use modern cpumask style in drivers/edac/amd64_edac.c
++  * amd64_edac: unify MCGCTL ECC switching
++  * x86, msr: Add support for non-contiguous cpumasks
++  * x86, msr: msrs_alloc/free for CONFIG_SMP=n
++  * amd64_edac: fix driver instance freeing
++  * amd64_edac: make driver loading more robust
++  * amd64_edac: fix forcing module load/unload
++  * sched: Sched_rt_periodic_timer vs cpu hotplug
++  * ext4: Update documentation to correct the inode_readahead_blks option
++    name
++  * lguest: fix bug in setting guest GDT entry
++  * vmscan: do not evict inactive pages when skipping an active list scan
++  * ksm: fix mlockfreed to munlocked
++  * rt2x00: Disable powersaving for rt61pci and rt2800pci.
++  * generic_permission: MAY_OPEN is not write access
++  * Linux 2.6.32.3
++  * untangle the do_mremap() mess
++  * fasync: split 'fasync_helper()' into separate add/remove functions
++  * ASoC: fix params_rate() macro use in several codecs
++  * modules: Skip empty sections when exporting section notes
++  * exofs: simple_write_end does not mark_inode_dirty
++  * nfsd: make sure data is on disk before calling ->fsync
++  * sunrpc: fix peername failed on closed listener
++  * SUNRPC: Fix up an error return value in
++    gss_import_sec_context_kerberos()
++  * SUNRPC: Fix the return value in gss_import_sec_context()
++  * sunrpc: on successful gss error pipe write, don't return error
++  * drm/i915: Update LVDS connector status when receiving ACPI LID event
++  * drm/i915: fix order of fence release wrt flushing
++  * drm/i915: Permit pinning whilst the device is 'suspended'
++  * drm: remove address mask param for drm_pci_alloc()
++  * drm/i915: Enable/disable the dithering for LVDS based on VBT setting
++  * drm/i915: Make the BPC in FDI rx/transcoder be consistent with that in
++    pipeconf on Ironlake
++  * drm/i915: Select the correct BPC for LVDS on Ironlake
++  * drm/i915: fix unused var
++  * rtc_cmos: convert shutdown to new pnp_driver->shutdown
++  * drivers/cpuidle/governors/menu.c: fix undefined reference to
++    `__udivdi3'
++  * cgroups: fix 2.6.32 regression causing BUG_ON() in cgroup_diput()
++  * lib/rational.c needs module.h
++  * dma-debug: allow DMA_BIDIRECTIONAL mappings to be synced with
++    DMA_FROM_DEVICE and
++  * kernel/signal.c: fix kernel information leak with print-fatal-signals=1
++  * mmc_block: add dev_t initialization check
++  * mmc_block: fix probe error cleanup bug
++  * mmc_block: fix queue cleanup
++  * ALSA: hda - Fix ALC861-VD capture source mixer
++  * ALSA: ac97: Add Dell Dimension 2400 to Headphone/Line Jack Sense
++    blacklist
++  * ALSA: atiixp: Specify codec for Foxconn RC4107MA-RS2
++    - LP: #498863
++  * ASoC: Fix WM8350 DSP mode B configuration
++  * netfilter: ebtables: enforce CAP_NET_ADMIN
++  * netfilter: nf_ct_ftp: fix out of bounds read in update_nl_seq()
++  * hwmon: (coretemp) Fix TjMax for Atom N450/D410/D510 CPUs
++  * hwmon: (adt7462) Fix pin 28 monitoring
++  * quota: Fix dquot_transfer for filesystems different from ext4
++  * xen: fix hang on suspend.
++  * iwlwifi: fix iwl_queue_used bug when read_ptr == write_ptr
++  * ath5k: Fix eeprom checksum check for custom sized eeproms
++  * cfg80211: fix syntax error on user regulatory hints
++  * iwl: off by one bug
++  * mac80211: add missing sanity checks for action frames
++  * drm/i915: remove render reclock support
++  * libertas: Remove carrier signaling from the scan code
++  * kernel/sysctl.c: fix stable merge error in NOMMU mmap_min_addr
++  * mac80211: fix skb buffering issue (and fixes to that)
++  * fix braindamage in audit_tree.c untag_chunk()
++  * fix more leaks in audit_tree.c tag_chunk()
++  * module: handle ppc64 relocating kcrctabs when CONFIG_RELOCATABLE=y
++  * ipv6: skb_dst() can be NULL in ipv6_hop_jumbo().
++  * agp/intel-agp: Clear entire GTT on startup
++  * Linux 2.6.32.4
++  * ethtool: Add reset operation
++  * gro: Name the GRO result enumeration type
++  * gro: Change all receive functions to return GRO result codes
++  * sfc: 10Xpress: Initialise pause advertising flags
++  * sfc: 10Xpress: Report support for pause frames
++  * sfc: Remove redundant header gmii.h
++  * sfc: Remove redundant hardware initialisation
++  * sfc: Rename Falcon-specific board code and types
++  * sfc: Remove boards.h, moving last remaining declaration to falcon.h
++  * sfc: Remove versioned bitfield macros
++  * sfc: Move RX data FIFO thresholds out of struct efx_nic_type
++  * sfc: Update hardware definitions for Siena
++  * sfc: Rename register I/O header and functions used by both Falcon and
++    Siena
++  * sfc: Eliminate indirect lookups of queue size constants
++  * sfc: Define DMA address mask explicitly in terms of descriptor field
++    width
++  * sfc: Move all TX DMA length limiting into tx.c
++  * sfc: Change order of device removal to reverse of probe order
++  * sfc: Remove declarations of nonexistent functions
++  * sfc: Move efx_xmit_done() declaration into correct stanza
++  * sfc: Move shared members of struct falcon_nic_data into struct efx_nic
++  * sfc: Maintain interrupt moderation values in ticks, not microseconds
++  * sfc: Removed kernel-doc for nonexistent member of efx_phy_operations
++  * sfc: Remove pointless abstraction of memory BAR number
++  * sfc: Remove incorrect assertion from efx_pci_remove_main()
++  * sfc: Remove unnecessary tests of efx->membase
++  * sfc: Move MTD probe after netdev registration and name allocation
++  * sfc: Remove unused code for non-autoneg speed/duplex switching
++  * sfc: Rename 'xfp' file and functions to reflect reality
++  * sfc: Really allow RX checksum offload to be disabled
++  * sfc: Feed GRO result into RX allocation policy and interrupt moderation
++  * sfc: Enable heuristic selection between page and skb RX buffers
++  * sfc: Remove pointless abstraction of memory BAR number (2)
++  * sfc: Remove redundant gotos from __efx_rx_packet()
++  * sfc: Remove ridiculously paranoid assertions
++  * sfc: Move assertions and buffer cleanup earlier in efx_rx_packet_lro()
++  * sfc: Record RX queue number on GRO path
++  * sfc: SFT9001: Reset LED configuration correctly after blinking
++  * sfc: Use a single blink implementation
++  * sfc: Rename efx_board::init_leds to init_phy and use for SFN4111T
++  * sfc: Make board information explicitly Falcon-specific
++  * sfc: Move definition of struct falcon_nic_data into falcon.h
++  * sfc: Move struct falcon_board into struct falcon_nic_data
++  * sfc: Move all I2C stuff into struct falcon_board
++  * sfc: Gather link state fields in struct efx_nic into new struct
++    efx_link_state
++  * sfc: Remove unnecessary casts to struct sk_buff *
++  * sfc: Remove redundant efx_xmit() function
++  * sfc: Combine high-level header files
++  * sfc: Log interrupt and reset type names, not numbers
++  * sfc: Fix descriptor cache sizes
++  * sfc: Treat all MAC registers as 128-bit
++  * sfc: Strengthen EFX_ASSERT_RESET_SERIALISED
++  * sfc: Comment corrections
++  * sfc: Remove unused constant
++  * sfc: Clean up struct falcon_board and struct falcon_board_data
++  * sfc: Fix bugs in RX queue flushing
++  * sfc: Remove unused function efx_flush_queues()
++  * sfc: Only switch Falcon MAC clocks as necessary
++  * sfc: Hold MAC lock for longer in efx_init_port()
++  * sfc: Split MAC stats DMA initiation and completion
++  * sfc: Move Falcon board/PHY/MAC monitoring code to falcon.c
++  * sfc: Simplify XMAC link polling
++  * sfc: Change MAC promiscuity and multicast hash at the same time
++  * sfc: Move inline comment into kernel-doc
++  * sfc: Do not set net_device::trans_start in self-test
++  * sfc: Simplify PHY polling
++  * sfc: QT202x: Reset before reading PHY id
++  * sfc: Replace MDIO spinlock with mutex
++  * sfc: Always start Falcon using the XMAC
++  * sfc: Limit some hardware workarounds to Falcon
++  * sfc: Remove EFX_WORKAROUND_9141 macro
++  * sfc: Remove another unused workaround macro
++  * sfc: Remove some redundant whitespace
++  * sfc: Decouple NIC revision number from Falcon PCI revision number
++  * sfc: Move descriptor cache base addresses to struct efx_nic_type
++  * sfc: Clean up RX event handling
++  * sfc: Remove redundant writes to INT_ADR_KER
++  * sfc: Remove duplicate hardware structure definitions
++  * sfc: Turn pause frame generation on and off at the MAC, not the RX FIFO
++  * sfc: Move Falcon NIC operations to efx_nic_type
++  * sfc: Refactor link configuration
++  * sfc: Generalise link state monitoring
++  * sfc: Add power-management and wake-on-LAN support
++  * sfc: Implement ethtool reset operation
++  * sfc: Add efx_nic_type operation for register self-test
++  * sfc: Add efx_nic_type operation for NVRAM self-test
++  * sfc: Add efx_nic_type operation for identity LED control
++  * sfc: Separate shared NIC code from Falcon-specific and rename
++    accordingly
++  * sfc: Fold falcon_probe_nic_variant() into falcon_probe_nic()
++  * sfc: Extend loopback mode enumeration
++  * sfc: Remove static PHY data and enumerations
++  * sfc: Extend MTD driver for use with new NICs
++  * sfc: Allow for additional checksum offload features
++  * sfc: Rename falcon.h to nic.h
++  * sfc: Move shared NIC code from falcon.c to new source file nic.c
++  * sfc: Add firmware protocol definitions (MCDI)
++  * sfc: Add support for SFC9000 family (1)
++  * sfc: Add support for SFC9000 family (2)
++  * sfc: Implement TSO for TCP/IPv6
++  * sfc: Update version, copyright dates, authors
++  * drivers/net/sfc: Correct code taking the size of a pointer
++  * sfc: Move PHY software state initialisation from init() into probe()
++  * sfc: Include XGXS in XMAC link status check except in XGMII loopback
++  * sfc: Fix DMA mapping cleanup in case of an error in TSO
++  * sfc: QT2025C: Work around PHY bug
++  * sfc: QT2025C: Switch into self-configure mode when not in loopback
++  * sfc: QT2025C: Work around PHY firmware initialisation bug
++  * sfc: QT2025C: Add error message for suspected bad SFP+ cables
++  * sfc: Disable TX descriptor prefetch watchdog
++  * [SCSI] vmw_pvscsi: SCSI driver for VMware's virtual HBA.
++    - LP: #497156
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 19 Jan 2010 16:12:47 +0000
++
++linux (2.6.32-10.14) lucid; urgency=low
++
++  [ Alex Deucher ]
++
++  * SAUCE: drm/radeon/kms: fix LVDS setup on r4xx
++    - LP: #493795
++
++  [ Andy Whitcroft ]
++
++  * Revert "(pre-stable) acpi: Use the ARB_DISABLE for the CPU which model
++    id is less than 0x0f."
++  * config-check -- ensure the checks get run at build time
++  * config-check -- check the processed config during updateconfigs
++  * config-check -- CONFIG_SECCOMP may not be present
++  * TUN is now built in ignore
++  * SAUCE: acpi battery -- delay first lookup of the battery until first
++    use
++  * SAUCE: async_populate_rootfs: move rootfs init earlier
++  * ubuntu: AppArmor -- update to mainline 2010-01-06
++  * SAUCE: move RLIMIT_CORE pipe dumper marker to 1
++    - LP: #498525
++
++  [ Dave Airlie ]
++
++  * (pre-stable) drm/radeon/kms: fix crtc vblank update for r600
++
++  [ Leann Ogasawara ]
++
++  * Add asix to nic-usb-modules file
++    - LP: #499785
++
++  [ Peter Zijlstra ]
++
++  * (pre-stable) sched: Fix balance vs hotplug race
++
++  [ Tim Gardner ]
++
++  * [Config] Enable CONFIG_FUNCTION_TRACER
++    - LP: #497989
++  * [Config] Drop lpia from getabis
++  * [Config] Build in TUN/TAP driver
++    - LP: #499491
++  * [Config] DH_COMPAT=5
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "(pre-stable) drm/i915: Avoid NULL dereference with
++    component_only tv_modes"
++  * Revert "(pre-stable) drm/i915: Fix sync to vblank when VGA output is
++    turned off"
++  * USB: usb-storage: fix bug in fill_inquiry
++  * USB: option: add pid for ZTE
++  * firewire: ohci: handle receive packets with a data length of zero
++  * rcu: Prepare for synchronization fixes: clean up for non-NO_HZ handling
++    of ->completed counter
++  * rcu: Fix synchronization for rcu_process_gp_end() uses of ->completed
++    counter
++  * rcu: Fix note_new_gpnum() uses of ->gpnum
++  * rcu: Remove inline from forward-referenced functions
++  * perf_event: Fix invalid type in ioctl definition
++  * perf_event: Initialize data.period in perf_swevent_hrtimer()
++  * perf: Don't free perf_mmap_data until work has been done
++  * PM / Runtime: Fix lockdep warning in __pm_runtime_set_status()
++  * sched: Check for an idle shared cache in select_task_rq_fair()
++  * sched: Fix affinity logic in select_task_rq_fair()
++  * sched: Rate-limit newidle
++  * sched: Fix and clean up rate-limit newidle code
++  * x86/amd-iommu: attach devices to pre-allocated domains early
++  * x86/amd-iommu: un__init iommu_setup_msi
++  * x86, Calgary IOMMU quirk: Find nearest matching Calgary while walking
++    up the PCI tree
++  * x86: Fix iommu=nodac parameter handling
++  * x86: GART: pci-gart_64.c: Use correct length in strncmp
++  * x86: ASUS P4S800 reboot=bios quirk
++    - LP: #366682
++  * x86, apic: Enable lapic nmi watchdog on AMD Family 11h
++  * ssb: Fix range check in sprom write
++  * ath5k: allow setting txpower to 0
++  * ath5k: enable EEPROM checksum check
++  * hrtimer: Fix /proc/timer_list regression
++  * ALSA: hrtimer - Fix lock-up
++  * ALSA: hda - Terradici HDA controllers does not support 64-bit mode
++  * KVM: x86 emulator: limit instructions to 15 bytes
++  * KVM: s390: Fix prefix register checking in arch/s390/kvm/sigp.c
++  * KVM: s390: Make psw available on all exits, not just a subset
++  * KVM: fix irq_source_id size verification
++  * KVM: x86: include pvclock MSRs in msrs_to_save
++  * x86: Prevent GCC 4.4.x (pentium-mmx et al) function prologue wreckage
++  * x86: Use -maccumulate-outgoing-args for sane mcount prologues
++  * x86, mce: don't restart timer if disabled
++  * x86/mce: Set up timer unconditionally
++  * x86: SGI UV: Fix BAU initialization
++  * x86: Fix duplicated UV BAU interrupt vector
++  * x86: Add new Intel CPU cache size descriptors
++  * x86: Fix typo in Intel CPU cache size descriptor
++  * pata_hpt{37x|3x2n}: fix timing register masks (take 2)
++  * s390: clear high-order bits of registers after sam64
++  * V4L/DVB: Fix test in copy_reg_bits()
++  * bsdacct: fix uid/gid misreporting
++  * UBI: flush wl before clearing update marker
++  * jbd2: don't wipe the journal on a failed journal checksum
++  * USB: xhci: Add correct email and files to MAINTAINERS entry.
++  * USB: musb_gadget_ep0: fix unhandled endpoint 0 IRQs, again
++  * USB: option.c: add support for D-Link DWM-162-U5
++  * USB: usbtmc: repeat usb_bulk_msg until whole message is transfered
++  * USB: usb-storage: add BAD_SENSE flag
++  * USB: Close usb_find_interface race v3
++  * pxa/em-x270: fix usb hub power up/reset sequence
++  * hfs: fix a potential buffer overflow
++  * SUNRPC: IS_ERR/PTR_ERR confusion
++  * NFS: Fix nfs_migrate_page()
++  * md/bitmap: protect against bitmap removal while being updated.
++  * futex: Take mmap_sem for get_user_pages in fault_in_user_writeable
++  * devpts_get_tty() should validate inode
++  * debugfs: fix create mutex racy fops and private data
++  * Driver core: fix race in dev_driver_string
++  * Serial: Do not read IIR in serial8250_start_tx when UART_BUG_TXEN
++  * mac80211: Fix bug in computing crc over dynamic IEs in beacon
++  * mac80211: Fixed bug in mesh portal paths
++  * mac80211: Revert 'Use correct sign for mesh active path refresh'
++  * mac80211: fix scan abort sanity checks
++  * wireless: correctly report signal value for IEEE80211_HW_SIGNAL_UNSPEC
++  * rtl8187: Fix wrong rfkill switch mask for some models
++  * x86: Fix bogus warning in apic_noop.apic_write()
++  * mm: hugetlb: fix hugepage memory leak in mincore()
++  * mm: hugetlb: fix hugepage memory leak in walk_page_range()
++  * powerpc/windfarm: Add detection for second cpu pump
++  * powerpc/therm_adt746x: Record pwm invert bit at module load time]
++  * powerpc: Fix usage of 64-bit instruction in 32-bit altivec code
++  * drm/radeon/kms: Add quirk for HIS X1300 board
++  * drm/radeon/kms: handle vblanks properly with dpms on
++  * drm/radeon/kms: fix legacy crtc2 dpms
++  * drm/radeon/kms: fix vram setup on rs600
++  * drm/radeon/kms: rs6xx/rs740: clamp vram to aperture size
++  * drm/ttm: Fix build failure due to missing struct page
++  * drm/i915: Set the error code after failing to insert new offset into mm
++    ht.
++  * drm/i915: Add the missing clonemask for display port on Ironlake
++  * xen/xenbus: make DEVICE_ATTR()s static
++  * xen: re-register runstate area earlier on resume.
++  * xen: restore runstate_info even if !have_vcpu_info_placement
++  * xen: correctly restore pfn_to_mfn_list_list after resume
++  * xen: register timer interrupt with IRQF_TIMER
++  * xen: register runstate on secondary CPUs
++  * xen: don't call dpm_resume_noirq() with interrupts disabled.
++  * xen: register runstate info for boot CPU early
++  * xen: call clock resume notifier on all CPUs
++  * xen: improve error handling in do_suspend.
++  * xen: don't leak IRQs over suspend/resume.
++  * xen: use iret for return from 64b kernel to 32b usermode
++  * xen: explicitly create/destroy stop_machine workqueues outside
++    suspend/resume region.
++  * Xen balloon: fix totalram_pages counting.
++  * xen: try harder to balloon up under memory pressure.
++  * dm exception store: free tmp_store on persistent flag error
++  * dm snapshot: only take lock for statustype info not table
++  * dm crypt: move private iv fields to structs
++  * dm crypt: restructure essiv error path
++  * dm: avoid _hash_lock deadlock
++  * dm snapshot: cope with chunk size larger than origin
++  * dm crypt: separate essiv allocation from initialisation
++  * dm crypt: make wipe message also wipe essiv key
++  * slc90e66: fix UDMA handling
++  * tcp: Stalling connections: Fix timeout calculation routine
++  * ip_fragment: also adjust skb->truesize for packets not owned by a
++    socket
++  * b44 WOL setup: one-bit-off stack corruption kernel panic fix
++  * sparc64: Don't specify IRQF_SHARED for LDC interrupts.
++  * sparc64: Fix overly strict range type matching for PCI devices.
++  * sparc64: Fix stack debugging IRQ stack regression.
++  * sparc: Set UTS_MACHINE correctly.
++  * b43legacy: avoid PPC fault during resume
++  * tracing: Fix event format export
++  * ath9k: Fix TX hang poll routine
++  * ath9k: fix processing of TX PS null data frames
++  * ath9k: Fix maximum tx fifo settings for single stream devices
++  * ath9k: fix tx status reporting
++  * mac80211: Fix dynamic power save for scanning.
++  * drm/i915: Fix sync to vblank when VGA output is turned off
++  * memcg: fix memory.memsw.usage_in_bytes for root cgroup
++  * thinkpad-acpi: fix default brightness_mode for R50e/R51
++  * thinkpad-acpi: preserve rfkill state across suspend/resume
++  * ipw2100: fix rebooting hang with driver loaded
++  * matroxfb: fix problems with display stability
++  * acerhdf: add new BIOS versions
++  * asus-laptop: change light sens default values.
++  * vmalloc: conditionalize build of pcpu_get_vm_areas()
++  * ACPI: Use the ARB_DISABLE for the CPU which model id is less than 0x0f.
++  * net: Fix userspace RTM_NEWLINK notifications.
++  * ext3: Fix data / filesystem corruption when write fails to copy data
++  * V4L/DVB (13116): gspca - ov519: Webcam 041e:4067 added.
++  * bcm63xx_enet: fix compilation failure after get_stats_count removal
++  * x86: Under BIOS control, restore AP's APIC_LVTTHMR to the BSP value
++  * drm/i915: Avoid NULL dereference with component_only tv_modes
++  * drm/i915: PineView only has LVDS and CRT ports
++  * drm/i915: Fix LVDS stability issue on Ironlake
++  * mm: sigbus instead of abusing oom
++  * ipvs: zero usvc and udest
++  * jffs2: Fix long-standing bug with symlink garbage collection.
++  * intel-iommu: Detect DMAR in hyperspace at probe time.
++  * intel-iommu: Apply BIOS sanity checks for interrupt remapping too.
++  * intel-iommu: Check for an RMRR which ends before it starts.
++  * intel-iommu: Fix oops with intel_iommu=igfx_off
++  * intel-iommu: ignore page table validation in pass through mode
++  * netfilter: xtables: document minimal required version
++  * perf_event: Fix incorrect range check on cpu number
++  * implement early_io{re,un}map for ia64
++  * Linux 2.6.32.2
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 07 Jan 2010 15:28:43 +0000
++
++linux (2.6.32-9.13) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_B43_PHY_LP
++    - LP: #493059
++  * include modules.builtin in the binary debs
++  * config-check -- add a configuration enforcer
++  * config-check -- add a unit-test suite to the checker
++  * [Config] Enable CONFIG_SYN_COOKIES for versatile
++  * [Config] Enable CONFIG_SECURITY_SMACK for ports
++  * [Config] Enable CONFIG_SECURITY_FILE_CAPABILITIES for ports
++  * [Config] Disable CONFIG_COMPAT_BRK for ports
++  * getabis -- add armel versatile to the list
++
++  [ Brad Figg ]
++
++  * SAUCE: Increase the default prealloc buffer for HDA audio devices
++    (non-modem)
++
++  [ Manoj Iyer ]
++
++  * ubuntu: onmibook -- Added missing BOM file
++
++  [ Tim Gardner ]
++
++  * ubuntu: fsam7400 -- Cleanup Makefile
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT"
++  * signal: Fix alternate signal stack check
++  * SCSI: scsi_lib_dma: fix bug with dma maps on nested scsi objects
++  * SCSI: osd_protocol.h: Add missing #include
++  * SCSI: megaraid_sas: fix 64 bit sense pointer truncation
++  * ext4: fix potential buffer head leak when add_dirent_to_buf() returns
++    ENOSPC
++  * ext4: avoid divide by zero when trying to mount a corrupted file system
++  * ext4: fix the returned block count if EXT4_IOC_MOVE_EXT fails
++  * ext4: fix lock order problem in ext4_move_extents()
++  * ext4: fix possible recursive locking warning in EXT4_IOC_MOVE_EXT
++  * ext4: plug a buffer_head leak in an error path of ext4_iget()
++  * ext4: make sure directory and symlink blocks are revoked
++  * ext4: fix i_flags access in ext4_da_writepages_trans_blocks()
++  * ext4: journal all modifications in ext4_xattr_set_handle
++  * ext4: don't update the superblock in ext4_statfs()
++  * ext4: fix uninit block bitmap initialization when s_meta_first_bg is
++    non-zero
++  * ext4: fix block validity checks so they work correctly with meta_bg
++  * ext4: avoid issuing unnecessary barriers
++  * ext4: fix error handling in ext4_ind_get_blocks()
++  * ext4: make trim/discard optional (and off by default)
++  * ext4: make "norecovery" an alias for "noload"
++  * ext4: Fix double-free of blocks with EXT4_IOC_MOVE_EXT
++  * ext4: initialize moved_len before calling ext4_move_extents()
++  * ext4: move_extent_per_page() cleanup
++  * jbd2: Add ENOMEM checking in and for
++    jbd2_journal_write_metadata_buffer()
++  * ext4: Return the PTR_ERR of the correct pointer in
++    setup_new_group_blocks()
++  * ext4: Avoid data / filesystem corruption when write fails to copy data
++  * ext4: wait for log to commit when umounting
++  * ext4: remove blocks from inode prealloc list on failure
++  * ext4: ext4_get_reserved_space() must return bytes instead of blocks
++  * ext4: quota macros cleanup
++  * ext4: fix incorrect block reservation on quota transfer.
++  * ext4: Wait for proper transaction commit on fsync
++  * ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT
++  * ext4: Fix potential fiemap deadlock (mmap_sem vs. i_data_sem)
++  * Linux 2.6.32.1
++  * kbuild: generate modules.builtin
++  * (pre-stable) drm/i915: Fix sync to vblank when VGA output is turned off
++    - LP: #494461
++  * (pre-stable) drm/i915: Avoid NULL dereference with component_only
++    tv_modes
++    - LP: #494045
++
++  [ Zhao Yakui ]
++
++  * (pre-stable) acpi: Use the ARB_DISABLE for the CPU which model id is
++    less than 0x0f.
++    - LP: #481765
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 17 Dec 2009 15:41:21 +0000
++
++linux (2.6.32-8.12) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: AppArmor -- add linux/err.h for ERR_PTR
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 12 Dec 2009 10:56:16 +0000
++
++linux (2.6.32-8.11) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: default ATI Radeon KMS to off until userspace catches
++    up"
++  * Revert "SAUCE: AppArmor: Fix oops there is no tracer and doing unsafe
++    transition."
++  * Revert "SAUCE: AppArmor: Fix refcounting bug causing leak of creds"
++  * Revert "SAUCE: AppArmor: Fix cap audit_caching preemption disabling"
++  * Revert "SAUCE: AppArmor: Fix Oops when in apparmor_bprm_set_creds"
++  * Revert "SAUCE: AppArmor: Fix oops after profile removal"
++  * Revert "SAUCE: AppArmor: AppArmor disallows truncate of deleted files."
++  * Revert "SAUCE: AppArmor: AppArmor fails to audit change_hat correctly"
++  * Revert "SAUCE: AppArmor: Policy load and replacement can fail to alloc
++    mem"
++  * Revert "SAUCE: AppArmor: AppArmor wrongly reports allow perms as
++    denied"
++  * Revert "SAUCE: AppArmor: Fix mediation of "deleted" paths"
++  * Revert "SAUCE: AppArmor: Fix off by 2 error in getprocattr mem
++    allocation"
++  * Revert "SAUCE: AppArmor: Set error code after structure
++    initialization."
++  * Revert "AppArmor -- fix pstrace_may_access rename"
++  * Revert "ubuntu: AppArmor security module"
++  * Revert "SAUCE: Add config option to set a default LSM"
++  * Revert "ubuntu: fsam7400 -- sw kill switch driver"
++  * Revert "[Config] fsam7400 -- enable"
++  * Revert "[Config] AUFS -- enable"
++  * Revert "ubuntu: AUFS -- aufs2-30 20090727"
++  * Revert "ubuntu: AUFS -- export various core functions -- fixes"
++  * Revert "ubuntu: AUFS -- export various core functions"
++  * Revert "[Config] ubuntu/iscsitarget -- disable"
++  * Revert "[Config] iscsitarget -- enable"
++  * Revert "ubuntu: iscsitarget -- SVN revision r214"
++  * update Vcs-Git to point to the correct repository
++    - LP: #493589
++  * update build environment overrides to lucid
++    - LP: #493589
++  * [Config] enable CONFIG_DEVTMPFS
++  * [Config] update all configs following AppArmor 2009-12-08 update
++  * SAUCE: isapnp_init: make isa PNP scans occur async
++  * [Config] fsam7400 -- enable
++  * [Config] omnibook -- enable
++  * [Config] cleanup CONFIG_AUDIT
++  * ubuntu: AUFS -- export various core functions (aufs2-base.patch)
++  * ubuntu: AUFS -- export various core functions (aufs2-standalone.patch)
++  * ubuntu: AUFS -- aufs2 20091209
++  * [Config] AUFS -- enable
++  * [Config] iscsitarget -- enable
++
++  [ Arjan van de Ven ]
++
++  * SAUCE: KMS: cache the EDID information of the LVDS
++
++  [ Colin Watson ]
++
++  * bnx2: update d-i firmware filenames
++    - LP: #494052
++  * add cdc_ether to nic-usb-modules udeb
++    - LP: #495060
++
++  [ John Johansen ]
++
++  * ubuntu: AppArmor -- mainline 2009-10-08
++
++  [ Manoj Iyer ]
++
++  * ubuntu: fsam7400 -- kill switch for Fujitsu Siemens Amilo M 7400
++  * ubuntu: omnibook -- support Toshiba (HP) netbooks
++  * ubuntu: iscsitarget --- version 1.4.19
++    - LP: #494693
++
++  [ Surbhi Palande ]
++
++  * SAUCE: Make populate_rootfs asynchronous
++
++  [ Tim Gardner ]
++
++  * Parallelize flavour builds and packaging
++  * [Config] Enable CONFIG_KSM
++
++  [ Upstream Kernel Changes ]
++
++  * Config option to set a default LSM
++  * LSM: Add security_path_chroot().
++  * LSM: Add security_path_chroot().
++  * LSM: Move security_path_chmod()/security_path_chown() to after
++    mutex_lock().
++  * ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Dec 2009 17:45:19 +0000
++
++linux (2.6.32-7.10) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] disable CONFIG_THUMB2_KERNEL to fix arm FTBFS
++
++ -- Andy Whitcroft <apw@canonical.com>  Sun, 06 Dec 2009 12:56:48 +0000
++
++linux (2.6.32-7.9) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: set /proc/acpi/video/*/DOS to 4 by default
++    - LP: #458982
++  * SAUCE: ensure vga16fb loads if no other driver claims the VGA device
++  * [Config] update configs following versatile switch to V7
++  * rebased to v2.6.32
++  * [Config] update configs following rebase to v2.6.32
++  * [Config] update ports configs following rebase to v2.6.32
++  * SAUCE: default ATI Radeon KMS to off until userspace catches up
++
++  [ Arjan van de Ven ]
++
++  * SAUCE: vfs: Add a trace point in the mark_inode_dirty function
++
++  [ Leann Ogasawara ]
++
++  * [SCSI] megaraid_sas: remove sysfs poll_mode_io world writeable
++    permissions
++    - CVE-2009-3939
++
++  [ Loic Minier ]
++
++  * SAUCE: select a v7 CPU for versatile
++
++  [ Takashi Iwai ]
++
++  * SAUCE: ALSA: hda - Add power on/off counter
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.32
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 04 Dec 2009 10:44:50 +0000
++
++linux (2.6.32-6.8) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] disable SSB devices for armel
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 28 Nov 2009 12:16:40 +0000
++
++linux (2.6.32-6.7) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: default ATI Radeon KMS to off until userspace catches up"
++  * Revert "SAUCE: Dell XPS710 reboot quirk"
++  * Revert "SAUCE: Link acpi-cpufreq.o first"
++  * Revert "SAUCE: LPIA  Logical reset of USB port on resume"
++  * Revert "SAUCE: LPIA Reboot fix for Intel Crownbeach development boards"
++  * Revert "SAUCE: Enable HDMI audio codec on Studio XPS 1340"
++  * Revert "SAUCE: Dell laptop digital mic does not work, PCI 1028:0271"
++  * Revert "Add Dell Dimension 9200 reboot quirk"
++  * Revert "SAUCE: Correctly blacklist Thinkpad r40e in ACPI"
++  * Revert "SAUCE: tulip: Define ULI PCI ID's"
++  * Revert "SAUCE: Lower warning level of some PCI messages"
++  * Revert "mac80211: fix two issues in debugfs"
++    Drop a number of known redundant commits as identified in the Ubuntu
++    delta review blueprint.
++
++  * reenable armel versatile flavour
++  * [Config] disable CONFIG_USB_DEVICEFS
++
++  [ Tim Gardner ]
++
++  * [Config] udeb: Add squashfs to fs-core-modules
++    - LP: #352615
++  * [Config] Create a real squashfs udeb
++    - LP: #352615
++
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 27 Nov 2009 17:31:16 +0000
++
++linux (2.6.32-5.6) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.32-rc8
++  * update configs following rebase to v2.6.32-rc8
++  * update ports configs since rebase to v2.6.32-rc8
++  * [Config] enable cgroup options
++    - LP: #480739
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.32-rc8
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 23 Nov 2009 11:16:14 +0000
++
++linux (2.6.32-4.5) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] SERIO_LIBPS2 and SERIO_I8042 must match
++  * rebase to v2.6.32-rc7
++  * resync with Karmic proposed
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: Fix oops after profile removal
++    - LP: #475619
++  * SAUCE: AppArmor: Fix Oops when in apparmor_bprm_set_creds
++    - LP: #437258
++  * SAUCE: AppArmor: Fix cap audit_caching preemption disabling
++    - LP: #479102
++  * SAUCE: AppArmor: Fix refcounting bug causing leak of creds
++    - LP: #479115
++  * SAUCE: AppArmor: Fix oops there is no tracer and doing unsafe
++    transition.
++    - LP: #480112
++
++  [ Ubuntu Changes ]
++
++  * resync with Karmic proposed (ddbc670a86a3dee18541a3734149f250ff307adf)
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.32-rc7
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 13 Nov 2009 11:35:13 +0000
++
++linux (2.6.32-3.4) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] SERIO_LIBPS2 and SERIO_I8042 must match
++  * [Upstream] add local prefix to oss local change_bits
++
++  [ Upstream Kernel Changes ]
++
++  * mtd/maps: gpio-addr-flash: pull in linux/ headers rather than asm/
++  * mtd/maps: gpio-addr-flash: depend on GPIO arch support
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 11 Nov 2009 14:47:04 +0000
++
++linux (2.6.32-3.3) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.32-rc6
++  * [Config] update configs following rebase to v2.6.32-rc6
++  * [Config] update ports configs following rebase to v2.6.32-rc6
++  * resync with Karmic Ubuntu-2.6.31-15.49
++  * [Config] add module ignores for broken drivers
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: AppArmor wrongly reports allow perms as denied
++    - LP: #453335
++  * SAUCE: AppArmor: Policy load and replacement can fail to alloc mem
++    - LP: #458299
++  * SAUCE: AppArmor: AppArmor fails to audit change_hat correctly
++    - LP: #462824
++  * SAUCE: AppArmor: AppArmor disallows truncate of deleted files.
++    - LP: #451375
++
++  [ Kees Cook ]
++
++  * SAUCE: Fix nx_enable reporting
++    - LP: #454285
++
++  [ Scott James Remnant ]
++
++  * Revert "SAUCE: trace: add trace_event for the open() syscall"
++  * SAUCE: trace: add trace events for open(), exec() and uselib()
++    - LP: #462111
++
++  [ Stefan Bader ]
++
++  * SAUCE: Fix sub-flavour script to not stop on missing directories
++    - LP: #453073
++
++  [ Ubuntu Changes ]
++
++  * resync with Karmic Ubuntu-2.6.31-15.49
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.32-rc6
++    - LP: #464552
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 10 Nov 2009 15:00:57 +0000
++
++linux (2.6.32-2.2) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * install the full changelog with the binary package
++  * changelog -- explicitly note rebases and clean history
++  * reinstate armel.mk with no flavours
++    - LP: #449637
++  * [Upstream] block: silently error unsupported empty barriers too
++    - LP: #420423
++  * [Config] udate configs following karmic resync
++  * [Config] update ports configs following karmic resync
++  * [Upstream] lirc -- follow removal of .id element
++
++  [ Colin Watson ]
++
++  * Use section 'admin' rather than 'base'
++  * Add more e100 firmware to nic-modules
++    - LP: #451872
++  * Add qla1280 firmware to scsi-modules
++    - LP: #381037
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: Set error code after structure initialization.
++    - LP: #427948
++  * SAUCE: AppArmor: Fix off by 2 error in getprocattr mem allocation
++    - LP: #446595
++  * SAUCE: AppArmor: Fix mediation of "deleted" paths
++
++  [ Kees Cook ]
++
++  * SAUCE: [x86] fix report of cs-limit nx-emulation
++    - LP: #454285
++
++  [ Leann Ogasawara ]
++
++  * SAUCE: (drop after 2.6.31) input: Add support for filtering input
++    events
++    - LP: #430809
++  * SAUCE: (drop after 2.6.31) dell-laptop: Trigger rfkill updates on wifi
++    toggle switch press
++    - LP: #430809
++
++  [ Luke Yelavich ]
++
++  * SAUCE: Add sr_mod to the scsi-modules udeb for powerpc
++  * [Config] Add sd_mod to scsi-modules udeb for powerpc
++
++  [ Mario Limonciello ]
++
++  * SAUCE: Update to LIRC 0.8.6
++    - LP: #432678
++  * SAUCE: dell-laptop: Store the HW switch status internally rather than
++    requerying every time
++    - LP: #430809
++  * SAUCE: dell-laptop: Blacklist machines not supporting dell-laptop
++    - LP: #430809
++
++  [ Stefan Bader ]
++
++  * [Upstream] acerhdf: Limit modalias matching to supported boards
++    - LP: #435958
++
++  [ Tim Gardner ]
++
++  * [Upstream] i915: Fix i2c init message
++    - LP: #409361
++  * [Config] Add sym53c8xx.ko to virtual sub-flavour
++    - LP: #439415
++  * [Config] Add d101m_ucode.bin to d-i/firmware/nic-modules
++    - LP: #439456
++  * [Config] Set default I/O scheduler back to CFQ for desktop flavours
++    - LP: #381300
++  * SAUCE: Created MODULE_EXPORT/MODULE_IMPORT macros
++    - LP: #430694
++  * SAUCE: Use MODULE_IMPORT macro to tie intel_agp to i915
++    - LP: #430694
++  * [Config] CONFIG_GFS2_FS_LOCKING_DLM=y
++    - LP: #416325
++  * SAUCE: Fix MODULE_IMPORT/MODULE_EXPORT
++    - LP: #430694
++  * SAUCE: Raise the default console 'quiet' level to 2
++  * [Config] CONFIG_X86_PAT=y
++  * [Config] Add armel arch to linux-libc-dev arches.
++    - LP: #449637
++  * [Config] CONFIG_X86_MCE
++  * [Upstream] (drop after 2.6.31) Input: synaptics - add another Protege
++    M300 to rate blacklist
++    - LP: #433801
++
++  [ Upstream Kernel Changes ]
++
++  * sgi-gru: Fix kernel stack buffer overrun, CVE-2009-2584
++  * drm/i915: Fix FDI M/N setting according with correct color depth
++    - LP: #416792
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 22 Oct 2009 16:53:33 +0100
++
++linux (2.6.32-1.1) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.32-rc3
++  * [Config] update configs following rebase to 2.6.32-rc3
++  * [Config] update ports configs following rebase to 2.6.32-rc3
++  * AppArmor -- fix pstrace_may_access rename
++  * staging/android -- disable
++  * ubuntu: dm-raid-45 -- update to compile with 2.6.32
++  * ubuntu: drbd -- disable
++  * staging/comdi -- disable
++  * staging/go7007 -- disable
++  * [Config] staging/winbond -- disable
++  * [Config] ubuntu/iscsitarget -- disable
++  * [d-i] cbc and ecb are builtin make them optional in udebs
++  * rebase to v2.6.32-rc5
++  * [Config] update configs following rebase to v2.6.32-rc5
++  * [Config] update ports configs following rebase to v2.6.31-rc5
++
++  [ Tim Gardner ]
++
++  * [Config] Add cpio as a build dependency.
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.32-rc3
++  * rebase to v2.6.32-rc5
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 05 Oct 2009 15:48:58 +0100
++
++linux (2.6.31-11.37) karmic; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Increase kernel log buffer to 256K for amd64 flavours
++    - LP: #424810
++  * [Config] Set HZ=100 for amd64 flavours
++    - LP: #438234
++  * [Upstream] e1000e: Emit notice instead of an error when
++    pci_enable_pcie_error_reporting() fails
++    - LP: #436370
++
++  [ Upstream Kernel Changes ]
++
++  * n_tty: honor opost flag for echoes
++  * n_tty: move echoctl check and clean up logic
++    - LP: #438310
++
++  * Revert "[Upstream] drm/i915: Check that the relocation points to within
++    the target" - Use upstream cherry-pick.
++  * drm/i915: Check that the relocation points to within the target
++    - LP: #429241
++
++  * drm/i915: fix tiling on IGDNG
++  * drm/i915: add B43 chipset support
++  * agp/intel: Add B43 chipset support
++    Intel request from kernel team mailing list.
++
++  * HID: completely remove apple mightymouse from blacklist
++    - LP: #428111
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 28 Sep 2009 11:47:29 -0600
++
++linux (2.6.31-11.36) karmic; urgency=low
++
++  [ Brian Rogers ]
++
++  * SAUCE: (drop after 2.6.31) em28xx: ir-kbd-i2c init data needs a
++    persistent object
++  * SAUCE: (drop after 2.6.31) saa7134: ir-kbd-i2c init data needs a
++    persistent object
++
++  [ Takashi Iwai ]
++
++  * [Upstream] ALSA: hda - Add another entry for Nvidia HDMI device
++    - LP: #416482
++
++  [ Tyler Hicks ]
++
++  * SAUCE: (drop after 2.6.31) eCryptfs: Prevent lower dentry from going
++    negative during unlink
++
++  [ Upstream Kernel Changes ]
++
++  * sg: fix oops in the error path in sg_build_indirect()
++  * mpt2sas : Rescan topology from Interrupt context instead of work thread
++  * mpt2sas: Prevent sending command to FW while Host Reset
++  * mpt2sas: setting SDEV into RUNNING state from Interrupt context
++  * mpt2sas: Raid 10 Volume is showing as Raid 1E in dmesg
++  * SCSI: fix oops during scsi scanning
++  * SCSI: libsrp: fix memory leak in srp_ring_free()
++  * cfg80211: fix looping soft lockup in find_ie()
++  * ath5k: write PCU registers on initial reset
++  * binfmt_elf: fix PT_INTERP bss handling
++  * TPM: Fixup boot probe timeout for tpm_tis driver
++  * md: Fix "strchr" [drivers/md/dm-log-userspace.ko] undefined!
++  * x86/amd-iommu: fix broken check in amd_iommu_flush_all_devices
++  * fix undefined reference to user_shm_unlock
++  * perf_counter: Fix buffer overflow in perf_copy_attr()
++  * perf_counter: Start counting time enabled when group leader gets
++    enabled
++  * powerpc/perf_counters: Reduce stack usage of power_check_constraints
++  * powerpc: Fix bug where perf_counters breaks oprofile
++  * powerpc/ps3: Workaround for flash memory I/O error
++  * block: don't assume device has a request list backing in nr_requests
++    store
++  * agp/intel: remove restore in resume
++  * ALSA: cs46xx - Fix minimum period size
++  * ASoC: Fix WM835x Out4 capture enumeration
++  * sound: oxygen: work around MCE when changing volume
++  * mlx4_core: Allocate and map sufficient ICM memory for EQ context
++  * perf stat: Change noise calculation to use stddev
++  * x86: Fix x86_model test in es7000_apic_is_cluster()
++  * x86/i386: Make sure stack-protector segment base is cache aligned
++  * PCI: apply nv_msi_ht_cap_quirk on resume too
++  * x86, pat: Fix cacheflush address in change_page_attr_set_clr()
++  * ARM: 5691/1: fix cache aliasing issues between kmap() and kmap_atomic()
++    with highmem
++  * KVM guest: do not batch pte updates from interrupt context
++  * KVM: Fix coalesced interrupt reporting in IOAPIC
++  * KVM: VMX: Check cpl before emulating debug register access
++  * KVM guest: fix bogus wallclock physical address calculation
++  * KVM: x86: Disallow hypercalls for guest callers in rings > 0
++  * KVM: VMX: Fix cr8 exiting control clobbering by EPT
++  * KVM: x86 emulator: Implement zero-extended immediate decoding
++  * KVM: MMU: make __kvm_mmu_free_some_pages handle empty list
++  * KVM: x86 emulator: fix jmp far decoding (opcode 0xea)
++  * KVM: limit lapic periodic timer frequency
++  * libata: fix off-by-one error in ata_tf_read_block()
++  * PCI quirk: update 82576 device ids in SR-IOV quirks list
++  * PCI: Unhide the SMBus on the Compaq Evo D510 USDT
++  * powerpc/pseries: Fix to handle slb resize across migration
++  * Linux 2.6.31.1
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 24 Sep 2009 13:04:28 -0600
++
++linux (2.6.31-10.35) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Disable CONFIG_UEVENT_HELPER_PATH
++
++  [ Andy Whitcroft ]
++
++  * [Config] Enable CONFIG_USB_GADGET_DUMMY_HCD
++  * remove the tlsup driver
++  * remove lmpcm logitech driver support
++
++  [ Bryan Wu ]
++
++  * Add 3 missing files to prerm remove file list
++    - LP: #345623, #415832
++
++  [ Chris Wilson ]
++
++  * [Upstream] drm/i915: Check that the relocation points to within the
++    target
++    - LP: #429241
++
++  [ Luke Yelavich ]
++
++  * [Config] Set CONFIG_EXT4_FS=y on ports architectures
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
++    - LP: #348861
++
++  [ Tim Gardner ]
++
++  * Revert "[Upstream] ACPI: Add Thinkpad W500, W700, & W700ds to OSI(Linux) white-list"
++  * Revert "[Upstream] ACPI: Add Thinkpad R400 & Thinkpad R500 to OSI(Linux) white-list"
++  * Revert "[Upstream] ACPI: Add Thinkpad X300 & Thinkpad X301 to OSI(Linux) white-list"
++  * Revert "[Upstream] ACPI: Add Thinkpad X200, X200s, X200t to OSI(Linux) white-list"
++  * Revert "[Upstream] ACPI: Add Thinkpad T400 & Thinkpad T500 to OSI(Linux) white-list"
++    Upstream suggests that this is not the right approach.
++
++  * [Config] Set default I/O scheduler to DEADLINE
++    CFQ seems to have some load related problems which are often exacerbated by sreadahead.
++    - LP: #381300
++
++  [ ubuntu@tjworld.net ]
++
++  * SAUCE: ipw2200: Enable LED by default
++    - LP: #21367
++
++  [ Upstream Kernel Changes ]
++
++  * ALSA: hda - Add support for new AMD HD audio devices
++    - LP: #430564
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 16 Sep 2009 15:37:49 +0100
++
++linux (2.6.31-10.34) karmic; urgency=low
++
++  [ Ted Tso ]
++
++  * [Upstream] ext3: Don't update superblock write time when filesystem is
++    read-only
++    - LP: #427822
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Sep 2009 16:00:45 -0600
++
++linux (2.6.31-10.33) karmic; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Upstream] dvb-usb: fix tuning with Cinergy T2
++    - LP: #421258
++
++  [ Tim Gardner ]
++
++  * [Config] Unconditionally copy files from sub-flavours lists.
++    (really, really fix it this time)
++    - LP: #423426
++  * [Config] Set CONFIG_CACHEFILES=m for all flavours
++
++  [ Upstream Kernel Changes ]
++
++  * ext4: Don't update superblock write time when filesystem is read-only
++    - LP: #427822
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Sep 2009 07:50:21 -0600
++
++linux (2.6.31-10.32) karmic; urgency=low
++
++  [ Eric Miao ]
++
++  * [Config] enable module support for memory stick
++    - LP: #159951
++
++  [ Tim Gardner ]
++
++  * [Config] Unconditionally copy files from sub-flavours lists.
++    - LP: #423426
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 10 Sep 2009 15:57:55 -0600
++
++linux (2.6.31-10.31) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.31 final
++
++  [ Colin Watson ]
++
++  * [Config] Recommend grub-pc in linux-image
++    - LP: #385741
++
++  [ Ike Panhc ]
++
++  * [Upstream] Pull latest update of lenovo-sl-laptop
++
++  [ Peter Feuerer ]
++
++  * [Upstream] (drop after 2.6.31) acerhdf: fix fan control for AOA150
++    model
++    - LP: #426691
++
++  [ Tim Gardner ]
++
++  * [Config] De-macro some package names.
++
++  [ Upstream Changes ]
++
++  * rebase to 2.6.31 final.
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 10 Sep 2009 09:38:10 +0100
++
++linux (2.6.31-10.30) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * [Config] Enable CONFIG_USB_DEVICEFS
++    - LP: #417748
++  * [Config] Populate the config-update template a bit more
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.31-rc9
++  * [Config] update configs following rebase to v2.6.31-rc9
++  * [Config] update ports configs following rebase to v2.6.31-rc9
++
++  [ Colin Ian King ]
++
++  * SAUCE: wireless: hostap, fix oops due to early probing interrupt
++    - LP: #254837
++
++  [ Jerone Young ]
++
++  * [Upstream] ACPI: Add Thinkpad T400 & Thinkpad T500 to OSI(Linux)
++    white-list
++    - LP: #281732
++  * [Upstream] ACPI: Add Thinkpad X200, X200s, X200t to OSI(Linux)
++    white-list
++    - LP: #281732
++  * [Upstream] ACPI: Add Thinkpad X300 & Thinkpad X301 to OSI(Linux)
++    white-list
++    - LP: #281732
++  * [Upstream] ACPI: Add Thinkpad R400 & Thinkpad R500 to OSI(Linux)
++    white-list
++    - LP: #281732
++  * [Upstream] ACPI: Add Thinkpad W500, W700, & W700ds to OSI(Linux)
++    white-list
++    - LP: #281732
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: Fix profile attachment for regexp based profile names
++    - LP: #419308
++  * SAUCE: AppArmor: Return the correct error codes on profile
++    addition/removal
++    - LP: #408473
++  * SAUCE: AppArmor: Fix OOPS in profile listing, and display full list
++    - LP: #408454
++  * SAUCE: AppArmor: Fix mapping of pux to new internal permission format
++    - LP: #419222
++  * SAUCE: AppArmor: Fix change_profile failure
++    - LP: #401931
++  * SAUCE: AppArmor: Tell git to ignore generated include files
++    - LP: #419505
++
++  [ Stefan Bader ]
++
++  * [Upstream] acpi: video: Loosen strictness of video bus detection code
++    - LP: #333386
++  * SAUCE: Remove ov511 driver from ubuntu subdirectory
++
++  [ Tim Gardner ]
++
++  * [Config] Exclude char-modules from non-x86 udeb creation
++  * SAUCE: Notify the ACPI call chain of AC events
++  * [Config] CONFIG_SATA_VIA=m
++    - LP: #403385
++  * [Config] Build in all phylib support modules.
++  * [Config] Don't fail when sub-flavour files are missing
++    - LP: #423426
++  * [Config] Set CONFIG_LSM_MMAP_MIN_ADDR=0
++    - LP: #423513
++
++  [ Upstream ]
++
++  * Rebased against v2.6.31-rc9
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 07 Sep 2009 11:33:45 +0100
++
++linux (2.6.31-9.29) karmic; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Upstream] agp/intel: support for new chip variant of IGDNG mobile
++    - LP: #419993
++  * [Config] d-i/modules: Add new char-modules file, initialize with
++    intel-agp
++    - LP: #420605
++
++  [ Upstream ]
++
++  * Rebased against 2.6.31-rc8 plus some inotify regression patches:
++    up through git://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux-2.6.git
++    adda766193ea1cf3137484a9521972d080d0b7af.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 28 Aug 2009 06:31:30 -0600
++
++linux (2.6.31-8.28) karmic; urgency=low
++
++  [ Ike Panhc ]
++
++  * [Config] Let nic-shared-modules depends on crypto-modules
++    - LP: #360966
++
++  [ Leann Ogasawara ]
++
++  * [Upstream] (drop after 2.6.31) drm/i915: increase default latency
++    constant
++    - LP: #412492
++
++  [ Mario Limonciello ]
++
++  * [Upstream]: (drop after 2.6.31) dell-laptop: don't change softblock
++    status if HW switch is disabled
++    - LP: #418721
++  * [Upstream]: (drop after 2.6.31) compal-laptop: Add support for known
++    Compal made Dell laptops
++  * [Upstream]: (drop after 2.6.31) compal-laptop: Replace sysfs support
++    with rfkill support
++
++  [ Tim Gardner ]
++
++  * [Config] Add acpiphp to virtual sub-flavour
++    - LP: #364916
++  * Drop KSM patch set for now because of instabilities with encrypted swap.
++    - LP: #418781
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 26 Aug 2009 08:14:26 -0600
++
++linux (2.6.31-7.27) karmic; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] updateconfigs updateportsconfigs after 2.6.31-rc7 rebase
++  * SAUCE: (drop after 2.6.31) Added KSM from mmotm-2009-08-20-19-18
++    Replaces previous ksm patches from 2.6.31-6.25
++  * [Config] KSM=y
++
++  [ Upstream ]
++
++  * Rebased against v2.6.31-rc7
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sat, 22 Aug 2009 20:32:11 -0600
++
++linux (2.6.31-6.26) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_AUFS_BR_RAMFS
++    - LP: #414738
++  * split out debian directory ready for abstraction
++  * add printdebian target to find branch target
++  * abstracted debian -- debian/files is not abstracted
++  * abstracted debian -- packages must be built in debian/<pkg>
++  * abstracted debian -- kernel-wedge needs to work in debian/
++  * abstracted debian -- ensure we install the copyright file
++  * abstracted-debian -- drop the debian directories from headers
++  * abstracted-debian -- drop the debian directories from headers part 2
++  * SAUCE: ubuntu-insert-changes -- follow abstracted debian
++  * [Upstream] aoe: ensure we initialise the request_queue correctly V2
++    - LP: #410198
++
++  [ Luke Yelavich ]
++
++  * [Config] Ports: Disable CONFIG_CPU_FREQ_DEBUG on powerpc-smp
++  * [Config] Ports: Re-enable windfarm modules on powerpc64-smp
++    - LP: #413150
++  * [Config] Ports: Build all cpu frequency scaling governors into ports
++    kernels
++  * [Config] Ports: Build ext2 and ext3 modules into ports kernels
++  * [Config] Ports: CONFIG_PACKET=y for all ports kernels
++  * [Config] Ports: Enable PS3 network driver
++
++  [ Stefan Bader ]
++
++  * abstracted debian -- call $(DEBIAN)/rules using make
++
++  [ Tim Gardner ]
++
++  * [Config] Abstract the debian directory
++  * SAUCE: Improve error reporting in postinst
++    - LP: #358564
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 16 Aug 2009 20:33:28 -0600
++
++linux (2.6.31-6.25) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * script to generate Ubuntu changes from changelog
++  * [Config] standardise ANDROID options
++  * [Config] standardise CONFIG_ATM as module
++  * [Config] standardise CONFIG_LIB80211 as module
++  * [Config] disable CONFIG_PRINT_QUOTA_WARNING
++  * [Config] set CONFIG_CRAMFS as module
++  * [Config] enable CONFIG_DAB and modules
++  * [Config] set CONFIG_MAC80211_HWSIM as module
++  * [Config] set CONFIG_NET_CLS_FLOW as module
++  * [Config] set CONFIG_NF_CONNTRACK_SANE as module
++  * [Config] set CONFIG_NF_CT_PROTO_DCCP as module
++  * [Config] set CONFIG_RTC_DRV_DS1511 as module
++  * [Config] set CONFIG_RTC_DRV_R9701 as module
++  * [Config] set CONFIG_RTC_DRV_S35390A as module
++  * [Config] set CONFIG_TOIM3232_DONGLE as module
++  * [Config] standardise CONFIG_USB_MIDI_GADGET as module
++  * [Config] standardise CONFIG_USB_G_PRINTER as module
++  * [Config] standardise CONFIG_USB_SERIAL_IR as module
++  * [Config] set CONFIG_USB_SERIAL_IUU as module
++  * [Config] standardise CONFIG_USB_STORAGE_CYPRESS_ATACB as module
++  * [Config] standardise CONFIG_USB_STORAGE_ONETOUCH as module
++  * cleanup remains of dm-loop
++  * drop thinkpad ec and smapi support
++  * drop appleir
++  * [Config] update configs following rebase to v2.6.31-rc6
++  * rebase to v2.6.31-rc6
++
++  [ Hugh Dickins ]
++
++  * SAUCE: ksm patch 1, drop after 2.6.31
++  * SAUCE: ksm patch 2, drop after 2.6.31
++  * SAUCE: ksm patch 3, drop after 2.6.31
++  * SAUCE: ksm patch 4, drop after 2.6.31
++  * SAUCE: ksm patch 5, drop after 2.6.31
++  * SAUCE: ksm patch 7, drop after 2.6.31
++
++  [ Izik Eidus ]
++
++  * SAUCE: ksm patch 0, drop after 2.6.31
++  * SAUCE: ksm patch 6, drop after 2.6.31
++  * SAUCE: ksm patch 8, drop after 2.6.31
++  * SAUCE: ksm patch 9, drop after 2.6.31
++
++  [ Luke Yelavich ]
++
++  * [Config] Ports: Re-add PS3 modules to udebs
++
++  [ Michael Casadevall ]
++
++  * [Config] Update SPARC config and d-i files to reflect what can be built
++
++  [ Tim Gardner ]
++
++  * [Config] Removed armel package support
++  * [Config] Enabled CONFIG_KSM=y
++
++  [ Upstream Kernel Changes ]
++
++  * Rebased against v2.6.31-rc6
++  * ARM: Cleanup: Revert "ARM: Add more cache memory types macros"
++  * ARM: Cleanup: Revert "Do not use OOB with MLC NAND"
++  * ARM: Cleanup: Revert "ARM: Make ARM arch aware of ubuntu/ drivers"
++  * ARM: Cleanup: Revert "ARM: IMX51: Make video capture drivers compile"
++  * ARM: Cleanup: Revert "ARM: IMX51: Fix isl29003 HWMON driver for i2c
++    changes"
++  * ARM: Cleanup: Revert "ARM: IMX51: IPU irq handler deadlock fix"
++  * ARM: Cleanup: Revert "ARM: IMX51: Babbage 2.5 needs a different system
++    revision"
++  * ARM: Cleanup: Revert "ARM: IMX51: Compile-in the IMX51 cpufreq driver
++    by default"
++  * ARM: Cleanup: Revert "ARM: IMX51: Enable ZONE_DMA for ARCH_MXC"
++  * ARM: Cleanup: Revert "ARM: IMX51: Make ARCH_MXC auto-enable
++    ARCH_MXC_CANONICAL"
++  * ARM: Cleanup: Revert "ARM: IMX51: Unconditionally disable
++    CONFIG_GPIOLIB"
++  * ARM: Cleanup: Revert "ARM: IMX51: Minimal changes for USB to work on
++    2.6.31"
++  * ARM: Cleanup: Revert "ARM: IMX51: Fix plat-mxc/timer.c to handle imx51"
++  * ARM: Cleanup: Revert "ARM: IMX51: Make it compile."
++  * ARM: Cleanup: Revert "ARM: IMX51: Clean-up the craziness of including
++    mxc_uart.h _everywhere_"
++  * ARM: Cleanup: Revert "ARM: IMX51: Move board-mx51* header files to the
++    correct location"
++  * ARM: Cleanup: Revert "ARM: IMX51: Changed from snd_card_new to
++    snd_card_create"
++  * ARM: Cleanup: Revert "ARM: IMX51: Fix up merge error in Kconfig"
++  * ARM: Cleanup: Revert "ARM: IMX51: mxc_timer_init prototype"
++  * ARM: Cleanup: Revert "ARM: IMX51: Removed the mxc_gpio_port structure."
++  * ARM: Cleanup: Revert "ARM: IMX51: Added external declaration for
++    mxc_map_io."
++  * ARM: Cleanup: Revert "ARM: IMX51: Get to bus_id by calling dev_name."
++  * ARM: Cleanup: Revert "ARM: IMX51: Get to bus_id by calling dev_name."
++  * ARM: Cleanup: Revert "ARM: IMX51: snd_soc_machine structure replaced
++    with snd_soc_card."
++  * ARM: Cleanup: Revert "ARM: IMX51: codec structure was moved to the card
++    structure"
++  * ARM: Cleanup: Revert "ARM: IMX51: Hack to add defines for
++    DMA_MODE_READ/WRITE/MASK"
++  * ARM: Cleanup: Revert "ARM: IMX51: Add SoC and board support for
++    Freescale mx51 platform"
++  * Driver core: add new device to bus's list before probing
++  * [Upstream] (drop after 2.6.31) ALSA: hda - Reduce click noise at
++    power-saving
++    - LP: #381693, #399750, #380892
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 14 Aug 2009 11:32:23 +0100
++
++linux (2.6.31-5.24) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * ARM: IMX51: Make video capture drivers compile
++  * [Config] IMX51: Config updates
++
++  [ Andy Whitcroft ]
++
++  * remove leftovers of dm-bbr
++
++  [ Leann Ogasawara ]
++
++  * Add pata_cs5535 to pata-modules
++    - LP: #318805
++
++  [ Luke Yelavich ]
++
++  * [Config] CONFIG_PPC64=y for powerpc64-smp
++  * [Config] Set the maximum number of CPUs to 1024 for powerpc64-smp
++  * [Config] CONFIG_PPC_PS3=y for powerpc64-smp
++  * [Config] CONFIG_PPC_MAPLE=y on powerpc64-smp
++  * [Config] CONFIG_PPC_PASEMI=y on powerpc64-smp
++  * [Config] CONFIG_CPU_FREQ_PMAC64=y on powerpc64-smp
++  * [Config] Enable all PS3 drivers in powerpc64-smp
++
++  [ Mario Limonciello ]
++
++  * LIRC -- fix lirc-i2c 2.6.31 compilation
++
++  [ Matthew Garrett ]
++
++  * [Upstream] dell-laptop: Fix rfkill state queries
++
++  [ Tim Gardner ]
++
++  * [Config] Ignore armel ABI and module changes
++  * [Config] Update configs after rebase against 2.6.31-rc5
++
++  [ Upstream ]
++
++  * Rebased to 2.6.31-rc5
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 28 Jul 2009 10:10:09 +0100
++
++linux (2.6.31-4.23) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * AUFS -- update to aufs2-30 20090727
++  * [Config] enable AUFS FUSE support
++
++  [ Luke Yelavich ]
++
++  * [Config] CONFIG_JFS_FS=m on sparc
++
++  [ Tim Gardner ]
++
++  * [Upstream] dell-laptop: Fix rfkill state setting.
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 27 Jul 2009 11:11:47 +0100
++
++linux (2.6.31-4.22) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * ARM: IMX51: Add SoC and board support for Freescale mx51 platform
++  * ARM: IMX51: Move board-mx51* header files to the correct location
++  * ARM: IMX51: Clean-up the craziness of including mxc_uart.h _everywhere_
++  * ARM: IMX51: Make it compile.
++  * ARM: IMX51: Unconditionally disable CONFIG_GPIOLIB
++  * ARM: IMX51: Make ARCH_MXC auto-enable ARCH_MXC_CANONICAL
++  * ARM: IMX51: Enable ZONE_DMA for ARCH_MXC
++  * ARM: IMX51: Compile-in the IMX51 cpufreq driver by default
++  * ARM: IMX51: Fix isl29003 HWMON driver for i2c changes
++  * ARM: USB: musb: Refer to musb_otg_timer_func under correct #ifdef
++  * ARM: staging: udlfb: Add vmalloc.h include
++  * UBUNTU [Config]: Bring imx51 config upto date with other flavours
++
++  [ Brad Figg ]
++
++  * ARM: IMX51: Hack to add defines for DMA_MODE_READ/WRITE/MASK
++  * ARM: IMX51: codec structure was moved to the card structure
++  * ARM: IMX51: snd_soc_machine structure replaced with snd_soc_card.
++  * ARM: IMX51: Get to bus_id by calling dev_name.
++  * ARM: IMX51: Get to bus_id by calling dev_name.
++  * ARM: IMX51: Added external declaration for mxc_map_io.
++  * ARM: IMX51: Removed the mxc_gpio_port structure.
++  * ARM: IMX51: mxc_timer_init prototype
++  * ARM: IMX51: Fix up merge error in Kconfig
++  * ARM: IMX51: Changed from snd_card_new to snd_card_create
++
++  [ Dinh Nguyen ]
++
++  * ARM: IMX51: Fix plat-mxc/timer.c to handle imx51
++  * ARM: IMX51: Minimal changes for USB to work on 2.6.31
++  * ARM: IMX51: Babbage 2.5 needs a different system revision
++  * ARM: IMX51: IPU irq handler deadlock fix
++
++  [ Tim Gardner ]
++
++  * [Config] Enabled CONFIG_CAN=m
++    - LP: #327243
++  * [Config] Enabled CONFIG_SERIAL=m
++    - LP: #397189
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 24 Jul 2009 06:19:10 -0600
++
++linux (2.6.31-4.21) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * dm-raid-4-5: Add missing brackets around test_bit()
++
++  [ John Johansen ]
++
++  * AppArmor: Fix change_profile failing lpn401931
++  * AppArmor: Fix determination of forced AUDIT messages.
++  * AppArmor: Fix oops in auditing of the policy interface offset
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Jul 2009 19:18:30 +0100
++
++linux (2.6.31-4.20) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: iscsitarget -- update to SVN revision r214
++  * SAUCE: iscsitarget -- renable driver
++  * [Config] consolidate lpia/lpia and i386/generic configs
++  * [Config] enable CRYPTO modules for all architectures
++  * [Config] enable cryptoloop
++  * [Config] enable various filesystems for armel
++  * [Config] sync i386 generic and generic-pae
++  * [Config] add the 386 (486 processors and above) flavour
++  * [Config] re-set DEFAULT_MMAP_MIN_ADDR
++    - LP: #399914
++  * add genconfigs/genportsconfigs to extract the built configs
++  * updateconfigs -- alter concatenation order allow easier updates
++  * intelfb -- INTELFB now conflicts with DRM_I915
++  * printchanges -- rebase tree does not have stable tags use changelog
++  * AppArmor: fix argument size missmatch on 64 bit builds
++
++  [ Ike Panhc ]
++
++  * Ship bnx2x firmware in nic-modules udeb
++    - LP: #360966
++
++  [ Jeff Mahoney ]
++
++  * AppArmor: fix build failure on ia64
++
++  [ John Johansen ]
++
++  * AppArmour: ensure apparmor enabled parmater is off if AppArmor fails to
++    initialize.
++  * AppArmour: fix auditing of domain transitions to include target profile
++    information
++  * AppArmor: fix C99 violation
++  * AppArmor: revert reporting of create to write permission.
++  * SAUCE: Add config option to set a default LSM
++  * [Config] enable AppArmor by default
++  * AppArmor: Fix NULL pointer dereference oops in profile attachment.
++
++  [ Keith Packard ]
++
++  * SAUCE: drm/i915: Allow frame buffers up to 4096x4096 on 915/945 class
++    hardware
++    - LP: #351756
++
++  [ Luke Yelavich ]
++
++  * [Config] add .o files found in arch/powerpc/lib to all powerpc kernel
++    header packages
++    - LP: #355344
++
++  [ Michael Casadevall ]
++
++  * [Config] update SPARC config files to allow success build
++
++  [ Scott James Remnant ]
++
++  * SAUCE: trace: add trace_event for the open() syscall
++
++  [ Stefan Bader ]
++
++  * SAUCE: jfs: Fix early release of acl in jfs_get_acl
++    - LP: #396780
++
++  [ Tim Gardner ]
++
++  * [Upstream] Fix Soltech TA12 volume hotkeys not sending key release
++    - LP: #397499
++  * [Upstream] USB Option driver - Add USB ID for Novatel MC727/U727/USB727
++    refresh
++    - LP: #365291
++  * [Config] SSB/B44 are common across all arches/flavours.
++
++  [ Upstream ]
++
++  * Rebased to 2.6.31-rc4
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Jul 2009 08:41:39 +0100
++
++linux (2.6.31-3.19) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Config] Disabled NDISWRAPPER"
++  * ndiswrapper -- fix i386 compilation failures on cmpxchg8b
++  * AUFS -- export various core functions
++  * AUFS -- export various core functions -- fixes
++  * AUFS -- core filesystem
++  * AUFS -- track changes in v2.6.31
++  * [Config] Enable AUFS
++  * droppped 'iwl3945: do not send scan command if channel count zero' as it
++    is already upstream but failed to auto-drop on rebase.
++
++  [ Eric Paris ]
++
++  * SAUCE: fsnotify: use def_bool in kconfig instead of letting the user
++    choose
++  * SAUCE: inotify: check filename before dropping repeat events
++  * SAUCE: fsnotify: fix inotify tail drop check with path entries
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 14 Jul 2009 12:52:55 +0100
++
++linux (2.6.31-3.18) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "Add splice-2.6.23.patch from AUFS to export a symbol needed by
++    AUFS"
++  * Revert "Add put_filp.patch from AUFS to export a symbol needed by AUFS"
++  * Revert "Add sec_perm-2.6.24.patch from AUFS - export
++    security_inode_permission"
++  * clear out left over AUFS files and modifications
++
++  [ Luke Yelavich ]
++
++  * [Config] Enable CONFIG_USB_ISP116X_HCD on sparc
++  * SAUCE: Explicitly include header files to allow apparmor to build on
++    powerpc
++  * [Config] Enable CONFIG_BLK_DEV_IDECD on powerpc
++
++  [ Tim Gardner ]
++
++  * [Config] Dropped ubuntu/misc/wireless/acx
++  * [Config] Disabled NDISWRAPPER until the compile issues are fixed.
++
++  [ Upstream ]
++
++  * Rebased to 2.6.31-rc3
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 10 Jul 2009 18:59:33 +0100
++
++linux (2.6.31-2.17) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_BLK_DEV_CRYPTOLOOP=m for sparc
++  * compcache -- remove redundant Kconfig entries part 2
++  * compcache -- clean up CCFLAGS declarations
++  * [Config] enable AppArmor
++  * AppArmor: fix operator precidence issue in as_path_link
++
++  [ John Johansen ]
++
++  * AppArmor security module
++  * AppArmor: Correct mapping of file permissions.
++  * AppArmor: Turn auditing of ptrace on
++
++  [ Luke Yelavich ]
++
++  * [Config] disable CONFIG_DM_RAID45 on powerpc
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 10 Jul 2009 15:02:05 +0100
++
++linux (2.6.31-2.16) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * compcache -- remove redundant Kconfig entries
++    added ignore and ignore.modules for all arches since the compcache update
++    changes the modules names as well as some compcache ABI values.
++
++  [ Manoj Iyer ]
++
++  * SAUCE: updated dm-raid45 module version to 2009.04.24 (2.6.30-rc3)
++  * SAUCE: update compcache version to 0.5.3
++
++  [ Tim Gardner ]
++
++  * [Config]: Fix sparc FTBS by adding ignore.modules
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 06 Jul 2009 13:35:29 -0600
++
++linux (2.6.31-2.15) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: default ATI Radeon KMS to off until userspace catches up
++  * [Config] Update configs following rebase to 2.6.31-rc2
++  * [Config] update ports configs following update to 2.6.31-rc2
++
++  [ Luke Yelavich ]
++
++  * [Config] powerpc - Disable CONFIG_RDS
++
++  [ Matt Zimmerman ]
++
++  * Rename linux-doc-PKGVER to linux-doc and clean up its description
++    - LP: #382115
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to mainline 2.6.31-rc2
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 04 Jul 2009 17:39:13 +0100
++
++linux (2.6.31-1.14) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * update ndiswrapper to 1.55
++  * remove leftovers of gfs
++  * [Config] powerpc: enable CONFIG_PPC_DISABLE_WERROR
++
++  [ Luke Yelavich ]
++
++  * [Config] re-enable and build the ide-pmac driver into powerpc kernels
++  * [Config] Build the ServerWorks Frodo / Apple K2 SATA driver into the
++    kernel
++
++  [ Manoj Iyer ]
++
++  * Remove snd-bt-sco ubuntu driver
++
++  [ Michael Casadevall ]
++
++  * [Config] updates ia64 config and d-i folders to allow succesful build
++  * [Config] Update powerpc and sparc for 2.6.31
++
++  [ Upstream Kernel Changes ]
++
++  * intel-iommu: fix Identity Mapping to be arch independent
++    - LP: #384695
++  * ACPI: video: prevent NULL deref in acpi_get_pci_dev()
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 30 Jun 2009 17:47:32 +0100
++
++linux (2.6.31-1.13) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * REBASE: rebased to mainline 2.6.31-rc1
++    - "UBUNTU: SAUCE: UHCI USB quirk for resume"
++      no longer applies, using deprecated interfaces, LPIA only, dropped
++    - "UBUNTU: SAUCE: Mask off garbage in Dell WMI scan code data"
++      changes now upstream, dropped
++  * [Config] Update configs following rebase to 2.6.31-rc1
++  * [Config] update ports configs following update to 2.6.31-rc1
++
++  * [Config] disable broken staging driver CONFIG_STLC45XX
++  * SAUCE: fix compcache to use updates accessors
++  * [Config] disable staging driver CONFIG_VT6655
++  * SAUCE: fix DRDB to use updates accessors
++  * [Disable] ndiswrapper needs update
++  * [Disable] LIRC I2C needs update
++  * [Disable] CONFIG_LENOVO_SL_LAPTOP needs update
++  * [Config] disable I2C_DESIGNWARE does not compile
++  * [Config] disable CONFIG_TLSUP for lpia
++  * [Config] disable CONFIG_FB_UDL for arm
++  * SAUCE: disable adding scsi headers to linux-libc-dev
++
++  [ Mario Limonciello ]
++
++  * SAUCE: Add LIRC drivers
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 25 Jun 2009 12:06:22 +0100
++
++linux (2.6.30-10.12) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] split out the ports configs into their own family
++  * [Config] update configs following introduction of ports family
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "Rename linux-doc-PKGVER to linux-doc and clean up its
++    description". Fixes linux-doc package name conflicts for now.
++    - LP: #382115
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 22 Jun 2009 09:17:14 -0600
++
++linux (2.6.30-10.11) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * [Config] Comment splitconfig.pl and misc cleanup
++  * [Config] Rename all configs to the new naming scheme
++  * [Config] Splitconfig rework
++  * [Config] Rename scripts/misc/oldconfig to kernelconfig
++  * [Config] Fix build system for new config split
++  * [Config] Run updateconfigs after the splitconfig rework
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: Default to i915.modeset=0 if CONFIG_DRM_I915_KMS=y"
++  * [Config] standardise CONFIG_STAGING=y
++  * [Config] standardise CONFIG_RD_LZMA=y
++  * [Config] CONFIG_PCI_IOV=y
++  * [Config] CONFIG_PCI_STUB=m
++  * [Config] merge kernel configs more agressively
++
++  [ Colin Watson ]
++
++  * [Config] Run kernel-wedge in $(builddir) rather than at the top level
++  * [Config] Add support for including firmware in udebs
++  * [Config] Ship bnx2 firmware in nic-modules udeb
++    - LP: #384861
++
++  [ Luke Yelavich ]
++
++  * [Config] ports - Import of ports architectures into kernel packaging
++    infrastructure
++  * [Config] ports - Do not update ports kernel configurations by default
++  * [Config] ports - Disable ABI checking for ports architectures
++  * [Config] ports - Build drivers in ubuntu sub-directory on powerpc
++  * [Config] ports - Add control.d/vars.* files for ports architectures
++  * [Config] ports - Add ports architectures for linux-libc-dev
++  * [Config] ports - Create powerpc specific message-modules and
++    block-modules udebs
++  * [Config] ports - Add configuration files for ports architectures
++
++  [ Manoj Iyer ]
++
++  * [Config] Enable CONFIG_BLK_DEV_AEC62XX=m for amd64 and i386
++    - LP: #329864
++
++  [ Michael Casadevall ]
++
++  * [Config] ports - Fix compression of kernels
++
++  [ Stefan Bader ]
++
++  * [Upstream] mmc: prevent dangling block device from accessing stale
++    queues
++    - LP: #383668
++
++  [ Tim Gardner ]
++
++  * [Config] Recommend grub-pc in linux-image
++    - LP: #385741
++  * [Config] Implement i386 generic and generic-pae flavours
++  * [Config] ports - Add control info after integrating ports arches
++  * [Config] Removed auto-generated files from git
++  * [Config] Added netxen_nic to nic-modules
++    - LP: #389603
++
++  [ Matt Zimmerman ]
++
++  * Rename linux-doc-PKGVER to linux-doc and clean up its description
++    - LP: #382115
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 15 Jun 2009 14:38:26 -0600
++
++linux (2.6.30-9.10) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_SECURITY_TOMOYO=y (amd64, i386, lpia)
++  * [Config] CONFIG_KEXEC_JUMP=y (amd64, lpia)
++  * [Config] CONFIG_LENOVO_SL_LAPTOP=m (amd64, lpia)
++  * [Config] CONFIG_POHMELFS_CRYPTO=y (i386, amd64)
++  * [Config] CONFIG_SERIAL_MAX3100=m (i386, amd64, lpia)
++  * [Config] CONFIG_VIDEO_GO7007=m (amd64, i386)
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30 final
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Jun 2009 11:42:53 +0100
++
++linux (2.6.30-8.9) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Config update removed the following options:
++        CONFIG_EDAC_AMD8111=m
++        CONFIG_EDAC_AMD8131=m
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30-rc8
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 03 Jun 2009 09:21:13 +0100
++
++linux (2.6.30-7.8) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Enabled NEW configration options:
++      Paravirtualization layer for spinlocks (PARAVIRT_SPINLOCKS) [N/y/?] Y
++      Cisco FNIC Driver (FCOE_FNIC) [N/m/y/?] M
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30-rc7
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 23 May 2009 23:47:24 +0100
++
++linux (2.6.30-6.7) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Dropped: UBUNTU: SAUCE: input: Blacklist digitizers from joydev.c (now
++    upstream)
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30-rc6
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 18 May 2009 18:05:54 +0100
++
++linux (2.6.30-5.6) karmic; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Enable Keyspan USB serial device firmware in kernel module
++    - LP: #334285
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30-rc5
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 11 May 2009 12:02:16 -0600
++
++linux (2.6.30-4.5) karmic; urgency=low
++
++  [ Colin Watson ]
++
++  * Build-Conflict with findutils (= 4.4.1-1ubuntu1), to avoid
++    /usr/include/asm/* going missing
++    - LP: #373214
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Fri, 08 May 2009 11:09:08 +0200
++
++linux (2.6.30-3.4) karmic; urgency=low
++
++  [ Kees Cook ]
++
++  * SAUCE: [x86] implement cs-limit nx-emulation for ia32
++    - LP: #369978
++
++  [ Stefan Bader ]
++
++  * SAUCE: input: Blacklist digitizers from joydev.c
++    - LP: #300143
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 01 May 2009 14:00:42 -0600
++
++linux (2.6.30-2.3) karmic; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Enabled CC_STACKPROTECTOR=y for all x86en
++    - LP: #369152
++  * SAUCE: Default to i915_modeset=0 if CONFIG_DRM_I915_KMS=y
++  * [Config] CONFIG_DRM_I915_KMS=y
++  * [Config] Set CONFIG_SECURITY_DEFAULT_MMAP_MIN_ADDR to appropriate ARCH
++    minimums
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30-rc4
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 30 Apr 2009 09:17:05 -0600
++
++linux (2.6.30-1.2) karmic; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] armel: disable staging drivers, fixes FTBS
++  * [Config] armel imx51: Disable CONFIG_MTD_NAND_MXC, fixes FTBS
++
++  [ Upstream Kernel Changes ]
++
++  * mpt2sas: Change reset_type enum to avoid namespace collision.
++    Submitted upstream.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 28 Apr 2009 16:54:41 -0600
++
++linux (2.6.30-1.1) karmic; urgency=low
++
++  * Initial release after rebasing against v2.6.30-rc3
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 12 Mar 2009 19:16:07 -0600
++
+diff --git a/debian.master/changelog.historical b/debian.master/changelog.historical
+new file mode 100644
+index 0000000..9e3beaf
+--- /dev/null
++++ b/debian.master/changelog.historical
+@@ -0,0 +1,4171 @@
++
++linux (2.6.28-9.31) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: cpufreq-nforce2: probe failures are not errors
++    - LP: #332170
++  * SAUCE: mmc: add MODALIAS linkage for MMC/SD devices
++    - LP: #30335
++  * remove test-suspend script
++    - LP: #333856
++
++  [ Kees Cook ]
++
++  * handle relative paths in modules.dep
++    Fixes 2.6.28-9.30 FTBS.
++
++  [ Upstream Kernel Changes ]
++
++  * ricoh_mmc: Handle newer models of Ricoh controllers
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 11 Mar 2009 08:19:24 -0600
++
++linux (2.6.28-9.30) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * ARM:mx51 Add SoC and board support for mx51 platforms
++  * ARM:mx51 Add CONFIG_ARCH_MXC_CANONICAL to disable parts of Freescale's
++    code
++  * MMC: Add support for 8-bit cards
++  * Add ARM:MX51 SoC support to the build system
++  * ARM: Make ARM arch aware of ubuntu/ drivers
++  * ARM: Add imx51 configuration
++  * Disable d-i modules for imx51 and mv78xx0
++  * Disable Apparmor on boot for ARM
++  * Updating imx51 config
++
++  [ Jason Liu ]
++
++  * Do not use OOB with MLC NAND
++
++  [ Richard Zhu ]
++
++  * Support the eMMC4.3 card
++
++  [ Rob Herring ]
++
++  * ARM: Add more cache memory types macros
++
++  [ Tim Gardner ]
++
++  * Set CONFIG_CPU_FREQ_DEFAULT_GOV_PERFORMANCE=y for i386/amd64/lpia
++
++  [ Manoj Iyer ]
++
++  * Enable CONFIG_RTL8187SE=m
++
++  [ Upstream Kernel Changes ]
++
++  * USB: EHCI: slow down ITD reuse
++    - LP: #329437
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 08 Mar 2009 14:14:15 -0600
++
++linux (2.6.28-9.29) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * link-headers -- only link directories which do not already exist
++    - LP: #315252
++
++  [ Daniel Marjamäki ]
++
++  * SAUCE: (drop after 2.6.28) netxen: fix memory leak in
++    drivers/net/netxen_nic_init.c
++    - LP: #330813
++
++  [ Dhananjay Phadke ]
++
++  * SAUCE: (drop after 2.6.28) netxen: fix endianness in firmware commands
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: fix ipv6 offload and tx cleanup
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: fix link speed reporting for some
++    boards
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: firmware init fix
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: cleanup mac list on driver unload
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: hold tx lock while sending firmware
++    commands
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: handle dma mapping failures
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: avoid invalid iounmap
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: include ipv6.h (fixes build failure)
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: fix vlan tso/checksum offload
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: reduce memory footprint
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: revert jumbo ringsize
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: fix msi-x interrupt handling
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: remove pcie workaround
++    - LP: #330813
++
++  [ Hannes Eder ]
++
++  * SAUCE: (drop after 2.6.28) drivers/net/netxen: fix sparse warnings: use
++    NULL pointer instead of plain integer
++    - LP: #330813
++
++  [ Huaxu Wan ]
++
++  * SAUCE: report rfkill changes event if interface is down
++    - LP: #193970
++
++  [ Tim Gardner ]
++
++  * MV78XX0 must specify a target in the vars definition.
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "ext4: wait on all pending commits in ext4_sync_fs()"
++  * jbd2: Fix return value of jbd2_journal_start_commit()
++  * jbd2: Avoid possible NULL dereference in
++    jbd2_journal_begin_ordered_truncate()
++  * ext4: Fix to read empty directory blocks correctly in 64k
++  * ext4: Fix lockdep warning
++  * ext4: Initialize preallocation list_head's properly
++  * ext4: Implement range_cyclic in ext4_da_writepages instead of
++    write_cache_pages
++  * ext4: Fix NULL dereference in ext4_ext_migrate()'s error handling
++  * ext4: Add fallback for find_group_flex
++  * ext4: Fix deadlock in ext4_write_begin() and ext4_da_write_begin()
++  * Added mv78xx0 flavor
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 06 Mar 2009 06:13:31 -0700
++
++linux (2.6.28-8.28) jaunty; urgency=low
++
++  [ Alexey Starikovskiy ]
++
++  * SAUCE: ACPI: EC: Limit workaround for ASUS notebooks even more
++    - LP: #288385
++
++  [ Scott James Remnant ]
++
++  * SAUCE: Auto-load esp module when device opened.
++  * SAUCE: Auto-load bridge module when socket opened.
++  * SAUCE: Auto-load af_netlink module when socket opened.
++  * SAUCE: Auto-load wanrouter module when socket opened.
++  * SAUCE: Auto-load ip_queue module when socket opened.
++  * SAUCE: Auto-load ip6_queue module when socket opened.
++  * SAUCE: Auto-load cn module when socket opened.
++  * SAUCE: Auto-load scsi_transport_iscsi module when socket opened.
++  * SAUCE: Auto-load ftl module when device opened.
++  * SAUCE: Auto-load pcd module when device opened.
++  * SAUCE: Auto-load pf module when device opened.
++  * SAUCE: Auto-load nftl module when device opened.
++  * SAUCE: Auto-load mousedev module when psaux device opened.
++  * SAUCE: Auto-load mousedev module when /dev/input/mice opened.
++  * SAUCE: Auto-load rng-core module when device opened.
++  * SAUCE: Auto-load openprom module when device opened.
++  * SAUCE: Auto-load applicom module when device opened.
++  * SAUCE: Auto-load toshiba module when device opened.
++  * SAUCE: Auto-load cyclades module when device opened.
++  * SAUCE: Auto-load riscom8 module when device opened.
++  * SAUCE: Auto-load specialix module when device opened.
++  * SAUCE: Auto-load videodev module when device opened.
++  * SAUCE: Auto-load i2c_dev module when device opened.
++  * SAUCE: Auto-load mtdchar module when device opened.
++  * SAUCE: Auto-load pt module when device opened.
++  * SAUCE: Auto-load pg module when device opened.
++  * SAUCE: Auto-load cdc_acm module when device opened.
++  * SAUCE: Auto-load msr module when device opened.
++  * SAUCE: Auto-load cpuid module when device opened.
++  * SAUCE: quickcam: Enable double-buffering by default
++  * SAUCE: libata: Ignore HPA by default.
++  * SAUCE: hostap: Change initial operation mode to managed (infra)
++  * SAUCE: floppy: Provide a PnP device table in the module.
++    - LP: #255651
++  * SAUCE: Auto-load mwave module when device opened.
++  * Build CONFIG_FUSE_FS into kernel, not as module.
++
++  [ Stefan Bader ]
++
++  * Enable build of ext4 as a module on LPIA
++    - LP: #331848
++
++  [ Tim Gardner ]
++
++  * Update configs to fix LPIA FTBS
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 05 Mar 2009 10:43:24 -0700
++
++linux (2.6.28-8.27) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Updating configs (arm:ixp4xx)
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: enable Intel HDMI output
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Added quirk for Linksys WUSB600N USB wifi-n networking adapter
++    - LP: #323473
++
++  [ Steve Beattie ]
++
++  * fix apparmor memory leak on unlinked file ops
++    - LP: #329489
++
++  [ Tim Gardner ]
++
++  * SAUCE: Dell XPS710 reboot quirk
++    - LP: #323592
++  * SAUCE: (drop after 2.6.28) ieee80211: Add infrastructure to obsolete
++    scan results
++    - LP: #336055
++  * Add modules.order to the linux-image package.
++
++  [ Upstream Kernel Changes ]
++
++  * iwlwifi: fix time interval misuse in iwl_poll_{direct_}bit
++  * x86: only scan the root bus in early PCI quirks
++    - LP: #267295
++  * ALSA: hda - Intel HDMI audio support
++  * ALSA: hda - Fix unused function in patch_intelhdmi.c
++  * ALSA: handle SiI1392 HDMI codec in patch_intelhdmi.c
++  * ALSA: hda-intel: reorder HDMI audio enabling sequence
++  * ALSA: introduce snd_print_pcm_rates()
++  * ALSA: create hda_eld.c for ELD routines and proc interface
++  * ALSA: ELD proc interface for HDMI sinks
++  * ALSA: hda: make standalone hdmi_fill_audio_infoframe()
++  * ALSA: hda: make global snd_print_channel_allocation()
++  * ALSA: hda: HDMI channel allocations for audio infoframe
++  * ALSA: hda: HDMI channel mapping cleanups
++  * ALSA: hda: minor code cleanups
++  * ALSA: hda: rename sink_eld to hdmi_eld
++  * ALSA: hda - Release ELD proc file
++  * ALSA: hda - minor HDMI code cleanups
++  * ALSA: hda - report selected CA index for Audio InfoFrame
++  * ALSA: hda - Add Intel vendor id string
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 25 Feb 2009 14:23:46 -0700
++
++linux (2.6.28-8.26) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Updating configs (armel:ixp4xx)
++    - LP: #331510
++
++  [ Tim Gardner ]
++
++  * Add more missing modules
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 24 Feb 2009 06:58:53 -0700
++
++linux (2.6.28-8.25) jaunty; urgency=low
++
++  [ Scott James Remnant ]
++
++  * SAUCE: Prefer powernow-k8 to acpi-cpufreq
++  * Change CONFIG_X86_P4_CLOCKMOD to be a module again.
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Initialize the new
++    group descriptor when resizing the filesystem"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Add sanity check
++    to make_indexed_dir"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: only use
++    i_size_high for regular files"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Add sanity checks
++    for the superblock before mounting the filesystem"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Fix
++    s_dirty_blocks_counter if block allocation failed with nodelalloc"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Init the complete
++    page while building buddy cache"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Don't allow new
++    groups to be added during block allocation"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: mark the
++    blocks/inode bitmap beyond end of group as used"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Use new
++    buffer_head flag to check uninit group bitmaps initialization"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Fix the race
++    between read_inode_bitmap() and ext4_new_inode()"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Fix race between
++    read_block_bitmap() and mark_diskspace_used()"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: don't use blocks
++    freed but not yet committed in buddy cache init"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: cleanup mballoc
++    header files"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Use
++    EXT4_GROUP_INFO_NEED_INIT_BIT during resize"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Add blocks added
++    during resize to bitmap"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Don't overwrite
++    allocation_context ac_status"
++  * Revert "SAUCE: (revert before 2.6.28.y update) jbd2: Add barrier not
++    supported test to journal_wait_on_commit_record"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Widen type of
++    ext4_sb_info.s_mb_maxs[]"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: avoid ext4_error
++    when mounting a fs with a single bg"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Fix the delalloc
++    writepages to allocate blocks at the right offset."
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: tone down
++    ext4_da_writepages warnings"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Add support for
++    non-native signed/unsigned htree hash algorithms"
++  * Enabled X86_ACPI_CPUFREQ=y
++
++  [ Upstream Kernel Changes ]
++
++  * ath9k: quiet harmless ForceXPAon messages
++    - LP: #321474
++  * [WATCHDOG] iTCO_wdt: fix SMI_EN regression 2
++    - LP: #314050
++  * pid: implement ns_of_pid
++  * mqueue: fix si_pid value in mqueue do_notify()
++  * powerpc/vsx: Fix VSX alignment handler for regs 32-63
++  * sata_nv: give up hardreset on nf2
++  * Fix Intel IOMMU write-buffer flushing
++  * SCSI: libiscsi: fix iscsi pool leak
++  * x86/cpa: make sure cpa is safe to call in lazy mmu mode
++  * sched: SCHED_OTHER vs SCHED_IDLE isolation
++  * x86, vm86: fix preemption bug
++  * Add support for VT6415 PCIE PATA IDE Host Controller
++  * ext2/xip: refuse to change xip flag during remount with busy inodes
++  * 3c505: do not set pcb->data.raw beyond its size
++  * Bluetooth: Fix TX error path in btsdio driver
++  * ext4: Add support for non-native signed/unsigned htree hash algorithms
++  * ext4: tone down ext4_da_writepages warnings
++  * ext4: Fix the delalloc writepages to allocate blocks at the right
++    offset.
++  * ext4: avoid ext4_error when mounting a fs with a single bg
++  * ext4: Widen type of ext4_sb_info.s_mb_maxs[]
++  * jbd2: Add barrier not supported test to journal_wait_on_commit_record
++  * ext4: Don't overwrite allocation_context ac_status
++  * ext4: Add blocks added during resize to bitmap
++  * ext4: Use EXT4_GROUP_INFO_NEED_INIT_BIT during resize
++  * ext4: cleanup mballoc header files
++  * ext4: don't use blocks freed but not yet committed in buddy cache init
++  * ext4: Fix race between read_block_bitmap() and mark_diskspace_used()
++  * ext4: Fix the race between read_inode_bitmap() and ext4_new_inode()
++  * ext4: Use new buffer_head flag to check uninit group bitmaps
++    initialization
++  * ext4: mark the blocks/inode bitmap beyond end of group as used
++  * ext4: Don't allow new groups to be added during block allocation
++  * ext4: Init the complete page while building buddy cache
++  * ext4: Fix s_dirty_blocks_counter if block allocation failed with
++    nodelalloc
++  * ext4: Add sanity checks for the superblock before mounting the
++    filesystem
++  * ext4: only use i_size_high for regular files
++  * ext4: Add sanity check to make_indexed_dir
++  * ext4: Initialize the new group descriptor when resizing the filesystem
++  * Fix longstanding "error: storage size of '__mod_dmi_device_table' isn't
++    known"
++  * Linux 2.6.28.7
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 19 Feb 2009 06:45:55 -0700
++
++linux (2.6.28-8.24) jaunty; urgency=low
++
++  [ Scott James Remnant ]
++
++  * Change CPU_FREQ_DEFAULT_GOV_ONDEMAND to y
++  * SAUCE: Link acpi-cpufreq.o first
++
++  [ Tim Gardner ]
++
++  * Build in CPU Frequency scaling drivers
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 18 Feb 2009 06:12:24 -0700
++
++linux (2.6.28-8.23) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * include the kernel configuration in the sub-flavour images
++    - LP: #328859
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: (drop after 2.6.28) [eCryptfs] Regression in unencrypted
++    filename symlinks" in favor of upstream commit.
++  * Fix compile issues with qc-usb
++  * SAUCE: (remove after 2.6.28) V4L/DVB (10216): saa7127: fix broken
++    S-Video with saa7129
++    - LP: #329267
++
++  [ Upstream Kernel Changes ]
++
++  * Subject:SAUCE: LP#193970 iwlagn: fix hw-rfkill while the interface is
++    down
++    - LP: #193970
++  * x86, vmi: put a missing paravirt_release_pmd in pgd_dtor
++  * nbd: fix I/O hang on disconnected nbds
++  * mac80211: restrict to AP in outgoing interface heuristic
++  * w1: w1 temp calculation overflow fix
++  * zd1211rw: adding 0ace:0xa211 as a ZD1211 device
++  * zd1211rw: treat MAXIM_NEW_RF(0x08) as UW2453_RF(0x09) for TP-Link
++    WN322/422G
++  * parport: parport_serial, don't bind netmos ibm 0299
++  * syscall define: fix uml compile bug
++  * kernel-doc: fix syscall wrapper processing
++  * Fix page writeback thinko, causing Berkeley DB slowdown
++  * write-back: fix nr_to_write counter
++  * writeback: fix break condition
++  * mm: rearrange exit_mmap() to unlock before arch_exit_mmap
++  * powerpc/fsl-booke: Fix mapping functions to use phys_addr_t
++  * lockd: fix regression in lockd's handling of blocked locks
++  * sctp: Fix crc32c calculations on big-endian arhes.
++  * sctp: Correctly start rtx timer on new packet transmissions.
++  * sctp: Properly timestamp outgoing data chunks for rtx purposes
++  * net: Fix frag_list handling in skb_seq_read
++  * net: Fix OOPS in skb_seq_read().
++  * drivers/net/skfp: if !capable(CAP_NET_ADMIN): inverted logic
++  * ipv4: fix infinite retry loop in IP-Config
++  * net: Fix userland breakage wrt. linux/if_tunnel.h
++  * net: packet socket packet_lookup_frame fix
++  * packet: Avoid lock_sock in mmap handler
++  * sungem: Soft lockup in sungem on Netra AC200 when switching interface
++    up
++  * udp: Fix UDP short packet false positive
++  * udp: increments sk_drops in __udp_queue_rcv_skb()
++  * ipv6: Disallow rediculious flowlabel option sizes.
++  * ipv6: Copy cork options in ip6_append_data
++  * net: 4 bytes kernel memory disclosure in SO_BSDCOMPAT gsopt try #2
++  * sky2: fix hard hang with netconsoling and iface going up
++  * tun: Add some missing TUN compat ioctl translations.
++  * tun: Fix unicast filter overflow
++  * virtio_net: Fix MAX_PACKET_LEN to support 802.1Q VLANs
++  * tcp: splice as many packets as possible at once
++  * tcp: Fix length tcp_splice_data_recv passes to skb_splice_bits.
++  * sparc: Enable syscall wrappers for 64-bit (CVE-2009-0029)
++  * sparc64: Annotate sparc64 specific syscalls with SYSCALL_DEFINEx()
++  * ALSA: hda - Add missing terminator in slave dig-out array
++  * ALSA: mtpav - Fix initial value for input hwport
++  * HID: adjust report descriptor fixup for MS 1028 receiver
++  * ide/libata: fix ata_id_is_cfa() (take 4)
++  * libata: fix EH device failure handling
++  * netfilter: fix tuple inversion for Node information request
++  * netfilter: xt_sctp: sctp chunk mapping doesn't work
++  * x86: microcode_amd: fix wrong handling of equivalent CPU id
++  * ide-cd: fix DMA for non bio-backed requests
++  * net: Fix data corruption when splicing from sockets.
++  * Linux 2.6.28.6
++  * eCryptfs: Regression in unencrypted filename symlinks
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 16 Feb 2009 06:43:51 -0700
++
++linux (2.6.28-8.22) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Remove perm-blacklist
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: psmouse/synaptics: ensure we reset the device on resume
++    - LP: #317270
++
++  [ Tim Gardner ]
++
++  * Add lpia to getabi script
++  * SAUCE: tracer for sreadahead
++
++ -- Amit Kucheria <amit.kucheria@ubuntu.com>  Fri, 13 Feb 2009 15:23:21 +0200
++
++linux (2.6.28-8.21) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: switch the Asus Pundit P1-AH2 to old acpi sleep ordering
++    - LP: #327267
++
++  [ Tim Gardner ]
++
++  * Added LPIA arch support
++  * Added libdrm-dev as a 'Replaces' to linux-libc-dev
++  * SAUCE: LPIA support for 9202 HDA Sigmatel codec
++  * SAUCE: Add an X86_LPIA Kconfig option
++  * SAUCE: UHCI USB quirk for resume
++  * SAUCE: LPIA Reboot fix for Intel Crownbeach development boards
++  * SAUCE: LPIA  Logical reset of USB port on resume
++  * Set CONFIG_WIRELESS_OLD_REGULATORY=n, added wireless-crda
++    as an install dependency.
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "Revert "x86, early_ioremap: fix fencepost error""
++    - LP: #312554
++  * drm/i915: capture last_vblank count at IRQ uninstall time too
++    - LP: #320813
++  * drm/i915: add get_vblank_counter function for GM45
++    - LP: #320813
++  * Staging: comedi: fix Kbuild
++  * Staging: meilhaus: fix Kbuild
++  * Staging: android: binder: fix arm build errors
++  * Staging: android: timed_gpio: Fix build to build on kernels after
++    2.6.25.
++  * Staging: android: fix build error on 64bit boxes
++  * Staging: android: Add lowmemorykiller documentation.
++  * Staging: android: task_get_unused_fd_flags: fix the wrong usage of
++    tsk->signal
++  * staging: agnx: drivers/staging/agnx/agnx.h needs <linux/io.h>
++  * Staging: usbip: usbip_start_threads(): handle kernel_thread failure
++  * Staging: poch: fix verification of memory area
++  * Documentation: move DMA-mapping.txt to Doc/PCI/
++  * sgi-xp: fix writing past the end of kzalloc()'d space
++  * do_wp_page: fix regression with execute in place
++  * wait: prevent exclusive waiter starvation
++  * shm: fix shmctl(SHM_INFO) lockup with !CONFIG_SHMEM
++  * revert "rlimit: permit setting RLIMIT_NOFILE to RLIM_INFINITY"
++  * prevent kprobes from catching spurious page faults
++  * sound: usb-audio: handle wMaxPacketSize for FIXED_ENDPOINT devices
++  * md: Ensure an md array never has too many devices.
++  * md: Fix a bug in linear.c causing which_dev() to return the wrong
++    device.
++  * ACPI: Enable bit 11 in _PDC to advertise hw coord
++  * ACPI: dock: Don't eval _STA on every show_docked sysfs read
++  * ieee1394: ohci1394: increase AT req. retries, fix ack_busy_X from
++    Panasonic camcorders and others
++  * firewire: ohci: increase AT req. retries, fix ack_busy_X from Panasonic
++    camcorders and others
++  * firewire: sbp2: fix DMA mapping leak on the failure path
++  * firewire: sbp2: add workarounds for 2nd and 3rd generation iPods
++  * ieee1394: sbp2: add workarounds for 2nd and 3rd generation iPods
++  * module: remove over-zealous check in __module_get()
++  * x86: APIC: enable workaround on AMD Fam10h CPUs
++  * eeepc-laptop: fix oops when changing backlight brightness during
++    eeepc-laptop init
++  * eeepc-laptop: Add support for extended hotkeys
++  * e1000: fix bug with shared interrupt during reset
++  * e1000: Fix PCI enable to honor the need_ioport flag
++  * agp/intel: Fix broken ® symbol in device name.
++  * ALSA: hda - Add quirk for FSC Amilo Xi2550
++  * ALSA: hda - Add missing COEF initialization for ALC887
++  * ALSA: hda - Add missing initialization for ALC272
++  * asus_acpi: Add R1F support
++  * panasonic-laptop: fix X[ ARRAY_SIZE(X) ]
++  * ACPI: Skip the first two elements in the _BCL package
++  * ACPI: proc_dir_entry 'video/VGA' already registered
++  * ACPI: disable ACPI cleanly when bad RSDP found
++  * ACPICA: Fix table entry truncation calculation
++  * PCI: properly clean up ASPM link state on device remove
++  * PCI: return error on failure to read PCI ROMs
++  * seq_file: move traverse so it can be used from seq_read
++  * seq_file: fix big-enough lseek() + read()
++  * serial: set correct baud_base for Oxford Semiconductor Ltd EXSYS
++    EX-41092 Dual 16950 Serial adapter
++  * Add support for '8-port RS-232 MIC-3620 from advantech'
++  * mm: fix error case in mlock downgrade reversion
++  * elf core dump: fix get_user use
++  * ACPI: video: Fix reversed brightness behavior on ThinkPad SL series
++  * ipw2200: fix scanning while associated
++  * XFS: set b_error from bio error in xfs_buf_bio_end_io
++  * Revert USB: option: add Pantech cards
++  * USB: option: New mobile broadband modems to be supported
++  * USB: new id for ti_usb_3410_5052 driver
++  * USB: two more usb ids for ti_usb_3410_5052
++  * USB: usb-storage: add Pentax to the bad-vendor list
++  * sata_via: Add VT8261 support
++  * nbd: do not allow two clients at the same time
++  * sctp: Fix another socket race during accept/peeloff
++  * Linux 2.6.28.5
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 09 Feb 2009 16:11:28 -0700
++
++linux (2.6.28-7.20) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * SAUCE: Input: atkbd - Samsung NC10 key repeat fix
++
++  [ Upstream Kernel Changes ]
++
++  * Manually revert "mlock: downgrade mmap sem while populating mlocked
++    regions"
++  * xen: make sysfs files behave as their names suggest
++  * sata_mv: fix 8-port timeouts on 508x/6081 chips
++  * m68knommu: set NO_DMA
++  * PCI/MSI: bugfix/utilize for msi_capability_init()
++  * x86: use early clobbers in usercopy*.c
++  * netfilter: ctnetlink: fix scheduling while atomic
++  * orinoco: move kmalloc(..., GFP_KERNEL) outside spinlock in
++    orinoco_ioctl_set_genie
++  * fbdev/atyfb: Fix DSP config on some PowerMacs & PowerBooks
++  * kmalloc: return NULL instead of link failure
++  * sata_nv: rename nv_nf2_hardreset()
++  * sata_nv: fix MCP5x reset
++  * sata_nv: ck804 has borked hardreset too
++  * Fix memory corruption in console selection
++  * Add enable_ms to jsm driver
++  * nfsd: only set file_lock.fl_lmops in nfsd4_lockt if a stateowner is
++    found
++  * nfsd: Ensure nfsv4 calls the underlying filesystem on LOCKT
++  * iwlwifi: fix rs_get_rate WARN_ON()
++  * p54: fix lm87 checksum endianness
++  * p54: fix p54_read_eeprom to cope with tx_hdr_len
++  * p54usb: rewriting rx/tx routines to make use of usb_anchor's facilities
++  * minstrel: fix warning if lowest supported rate index is not 0
++  * PCI: irq and pci_ids patch for Intel Tigerpoint DeviceIDs
++  * cpuidle: Add decaying history logic to menu idle predictor
++  * ACPI: Avoid array address overflow when _CST MWAIT hint bits are set
++  * video: always update the brightness when poking "brightness"
++  * Newly inserted battery might differ from one just removed, so update of
++    battery info fields is required.
++  * ACPI: Do not modify SCI_EN directly
++  * dlm: initialize file_lock struct in GETLK before copying conflicting
++    lock
++  * sata_mv: Fix chip type for Hightpoint RocketRaid 1740/1742
++  * ACPICA: Allow multiple backslash prefix in namepaths
++  * Linux 2.6.28.4
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sat, 07 Feb 2009 18:53:42 -0700
++
++linux (2.6.28-7.19) jaunty; urgency=low
++
++  * Fix missing modules FTBS
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 05 Feb 2009 15:28:15 -0700
++
++linux (2.6.28-7.18) jaunty; urgency=low
++
++  [ Alok Kataria ]
++
++  * SAUCE: (drop after 2.6.29) x86: add a synthetic TSC_RELIABLE feature
++    bit
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: add X86_FEATURE_HYPERVISOR feature bit
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: Hypervisor detection and get tsc_freq
++    from hypervisor
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: Add a synthetic TSC_RELIABLE feature
++    bit.
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: Skip verification by the watchdog for
++    TSC clocksource.
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: VMware: Fix vmware_get_tsc code
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: vmware: look for DMI string in the
++    product serial key
++    - LP: #319945
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: toshiba_acpi -- pull in current -dev version of driver
++    - LP: #269831
++  * SAUCE: toshiba_acpi -- add acpi hotkey kernel thread
++    - LP: #269831
++  * move toshiba laptops back from tlsup to toshiba_acpi
++    - LP: #269831
++
++  [ Aneesh Kumar K.V ]
++
++  * SAUCE: (revert before 2.6.28.y update) ext4: Fix the delalloc
++    writepages to allocate blocks at the right offset.
++  * SAUCE: (revert before 2.6.28.y update) ext4: avoid ext4_error when
++    mounting a fs with a single bg
++  * SAUCE: (revert before 2.6.28.y update) ext4: Don't overwrite
++    allocation_context ac_status
++  * SAUCE: (revert before 2.6.28.y update) ext4: Add blocks added during
++    resize to bitmap
++  * SAUCE: (revert before 2.6.28.y update) ext4: Use
++    EXT4_GROUP_INFO_NEED_INIT_BIT during resize
++  * SAUCE: (revert before 2.6.28.y update) ext4: cleanup mballoc header
++    files
++  * SAUCE: (revert before 2.6.28.y update) ext4: don't use blocks freed but
++    not yet committed in buddy cache init
++  * SAUCE: (revert before 2.6.28.y update) ext4: Fix race between
++    read_block_bitmap() and mark_diskspace_used()
++  * SAUCE: (revert before 2.6.28.y update) ext4: Fix the race between
++    read_inode_bitmap() and ext4_new_inode()
++  * SAUCE: (revert before 2.6.28.y update) ext4: Use new buffer_head flag
++    to check uninit group bitmaps initialization
++  * SAUCE: (revert before 2.6.28.y update) ext4: mark the blocks/inode
++    bitmap beyond end of group as used
++  * SAUCE: (revert before 2.6.28.y update) ext4: Don't allow new groups to
++    be added during block allocation
++  * SAUCE: (revert before 2.6.28.y update) ext4: Init the complete page
++    while building buddy cache
++  * SAUCE: (revert before 2.6.28.y update) ext4: Fix s_dirty_blocks_counter
++    if block allocation failed with nodelalloc
++
++  [ Hannes Eder ]
++
++  * SAUCE: (drop after 2.6.29) x86: vmware - fix sparse warnings
++    - LP: #319945
++
++  [ Luke Yelavich ]
++
++  * hid modules have hyphens instead of underscores in their names
++
++  [ Mark Fasheh ]
++
++  * SAUCE: (revert before 2.6.28.y update) jbd2: Add BH_JBDPrivateStart
++
++  [ Theodore Ts'o ]
++
++  * SAUCE: (revert before 2.6.28.y update) ext4: Add support for non-native
++    signed/unsigned htree hash algorithms
++  * SAUCE: (revert before 2.6.28.y update) ext4: tone down
++    ext4_da_writepages warnings
++  * SAUCE: (revert before 2.6.28.y update) jbd2: Add barrier not supported
++    test to journal_wait_on_commit_record
++  * SAUCE: (revert before 2.6.28.y update) ext4: Add sanity checks for the
++    superblock before mounting the filesystem
++  * SAUCE: (revert before 2.6.28.y update) ext4: only use i_size_high for
++    regular files
++  * SAUCE: (revert before 2.6.28.y update) ext4: Add sanity check to
++    make_indexed_dir
++  * SAUCE: (revert before 2.6.28.y update) jbd2: On a __journal_expect()
++    assertion failure printk "JBD2", not "EXT3-fs"
++  * SAUCE: (revert before 2.6.28.y update) ext4: Initialize the new group
++    descriptor when resizing the filesystem
++
++  [ Tyler Hicks ]
++
++  * SAUCE: (drop after 2.6.28) [eCryptfs] Regression in unencrypted
++    filename symlinks
++    - LP: #322532
++
++  [ Upstream Kernel Changes ]
++
++  * Input: atkbd - broaden the Dell DMI signatures
++    - LP: #261721
++  * ti_usb_3410_5052: support alternate firmware
++  * ath5k: fix mesh point operation
++  * mac80211: decrement ref count to netdev after launching mesh discovery
++  * inotify: clean up inotify_read and fix locking problems
++  * fuse: destroy bdi on umount
++  * fuse: fix missing fput on error
++  * fuse: fix NULL deref in fuse_file_alloc()
++  * x86, mm: fix pte_free()
++  * klist.c: bit 0 in pointer can't be used as flag
++  * sysfs: fix problems with binary files
++  * x86: fix page attribute corruption with cpa()
++  * USB: fix toggle mismatch in disable_endpoint paths
++  * sound: virtuoso: enable UART on Xonar HDAV1.3
++  * USB: usbmon: Implement compat_ioctl
++  * USB: fix char-device disconnect handling
++  * USB: storage: add unusual devs entry
++  * alpha: nautilus - fix compile failure with gcc-4.3
++  * alpha: fix vmalloc breakage
++  * resources: skip sanity check of busy resources
++  * rtl8187: Add termination packet to prevent stall
++  * it821x: Add ultra_mask quirk for Vortex86SX
++  * libata: pata_via: support VX855, future chips whose IDE controller use
++    0x0571
++  * serial_8250: support for Sealevel Systems Model 7803 COMM+8
++  * drm: stash AGP include under the do-we-have-AGP ifdef
++  * Fix OOPS in mmap_region() when merging adjacent VM_LOCKED file segments
++  * bnx2x: Block nvram access when the device is inactive
++  * ext3: Add sanity check to make_indexed_dir
++  * rtl8187: Fix error in setting OFDM power settings for RTL8187L
++  * epoll: drop max_user_instances and rely only on max_user_watches
++  * gpiolib: fix request related issue
++  * sgi-xpc: Remove NULL pointer dereference.
++  * sgi-xpc: ensure flags are updated before bte_copy
++  * include/linux: Add bsg.h to the Kernel exported headers
++  * ALSA: hda - Fix PCM reference NID for STAC/IDT analog outputs
++  * ALSA: hda - add another MacBook Pro 4, 1 subsystem ID
++  * ALSA: hda - Add quirk for HP DV6700 laptop
++  * crypto: authenc - Fix zero-length IV crash
++  * crypto: ccm - Fix handling of null assoc data
++  * x86, pat: fix reserve_memtype() for legacy 1MB range
++  * x86, pat: fix PTE corruption issue while mapping RAM using /dev/mem
++  * PCI hotplug: fix lock imbalance in pciehp
++  * dmaengine: fix dependency chaining
++  * NET: net_namespace, fix lock imbalance
++  * relay: fix lock imbalance in relay_late_setup_files
++  * Linux 2.6.28.3
++  * ALSA: Enable SPDIF output on ALC655
++  * ALSA: hda - Add ASUS V1Sn support
++  * ALSA: hda - support detecting HD Audio devices with PCI class code
++  * ALSA: hda: alc883 model for ASUS P5Q-EM boards
++  * ALSA: hda - Add quirk for MSI 7260 mobo
++  * ALSA: hda - Add quirk for Sony VAIO VGN-SR19XN
++  * ALSA: oxygen: add Claro halo support
++  * ALSA: hda - Add a new function to seek for a codec ID
++  * ALSA: patch_sigmatel: Add missing Gateway entries and autodetection
++  * ALSA: hda - More fixes on Gateway entries
++  * ALSA: hda - Add MCP67 HDMI support
++  * ALSA: hda - fix name for ALC1200
++  * LSA: hda - Add HP Acacia detection
++  * ALSA: hda - Add quirk for HP 2230s
++  * ALSA: hda - Add quirk for Dell Inspiron Mini9
++  * ALSA: hda - add support for Intel DX58SO board
++  * ALSA: hda - Fix silent headphone output on Panasonic CF-74
++  * ALSA: USB quirk for Logitech Quickcam Pro 9000 name
++  * ALSA: hda - add quirks for some 82801H variants to use ALC883_MITAC
++
++  [ Yasunori Goto ]
++
++  * SAUCE: (revert before 2.6.28.y update) ext4: Widen type of
++    ext4_sb_info.s_mb_maxs[]
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 02 Feb 2009 23:07:13 -0700
++
++linux (2.6.28-6.17) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Updating configs: ARMEL/versatile
++
++ -- Amit Kucheria <amit.kucheria@ubuntu.com>  Fri, 30 Jan 2009 13:36:59 +0200
++
++linux (2.6.28-6.16) jaunty; urgency=low
++
++  [ Luke Yelavich ]
++
++  * Add hid quirks to input-modules udeb
++
++  [ Tim Gardner ]
++
++  * Revert "[arm] Fix kexec on ARM by properly calling the relocation
++    function". This patch was deemed 'bogus' by Russell King on the
++    ARM mailing list.
++
++  [ Upstream Kernel Changes ]
++
++  * PCI: keep ASPM link state consistent throughout PCIe hierarchy
++  * security: introduce missing kfree
++  * rt2x00: add USB ID for the Linksys WUSB200.
++  * p54usb: Add USB ID for Thomson Speedtouch 121g
++  * lib/idr.c: use kmem_cache_zalloc() for the idr_layer cache
++  * sgi-xp: eliminate false detection of no heartbeat
++  * sched: fix update_min_vruntime
++  * IA64: Turn on CONFIG_HAVE_UNSTABLE_CLOCK
++  * sound: virtuoso: do not overwrite EEPROM on Xonar D2/D2X
++  * ALSA: hda - Add quirk for another HP dv5
++  * ALSA: hda - Fix HP dv5 mic input
++  * ALSA: hda - Don't reset HP pinctl in patch_sigmatel.c
++  * ALSA: hda - make laptop-eapd model back for AD1986A
++  * drivers/net/irda/irda-usb.c: fix buffer overflow
++  * usb-storage: add last-sector hacks
++  * usb-storage: set CAPACITY_HEURISTICS flag for bad vendors
++  * pkt_sched: sch_htb: Fix deadlock in hrtimers triggered by HTB
++  * ipv6: Fix fib6_dump_table walker leak
++  * sctp: Avoid memory overflow while FWD-TSN chunk is received with bad
++    stream ID
++  * pkt_sched: cls_u32: Fix locking in u32_change()
++  * r6040: fix wrong logic in mdio code
++  * r6040: save and restore MIER correctly in the interrupt routine
++  * r6040: bump release number to 0.19
++  * tcp: don't mask EOF and socket errors on nonblocking splice receive
++  * p54usb: fix traffic stalls / packet drop
++  * netfilter: x_tables: fix match/target revision lookup
++  * netfilter: ebtables: fix inversion in match code
++  * netfilter: nf_conntrack: fix ICMP/ICMPv6 timeout sysctls on big-endian
++  * dell_rbu: use scnprintf() instead of less secure sprintf()
++  * powerpc: is_hugepage_only_range() must account for both 4kB and 64kB
++    slices
++  * hwmon: (abituguru3) Fix CONFIG_DMI=n fallback to probe
++  * mm: write_cache_pages cyclic fix
++  * mm: write_cache_pages early loop termination
++  * mm: write_cache_pages writepage error fix
++  * mm: write_cache_pages integrity fix
++  * mm: write_cache_pages cleanups
++  * mm: write_cache_pages optimise page cleaning
++  * mm: write_cache_pages terminate quickly
++  * mm: write_cache_pages more terminate quickly
++  * mm: do_sync_mapping_range integrity fix
++  * mm: direct IO starvation improvement
++  * fs: remove WB_SYNC_HOLD
++  * fs: sync_sb_inodes fix
++  * fs: sys_sync fix
++  * Linux 2.6.28.2
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 25 Jan 2009 13:36:16 -0700
++
++linux (2.6.28-5.15) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * Revert "Enabled CONFIG_PID_NS=y for i386/amd64"
++    Somehow this commit also reverted the 7 prior commits (which is bad).
++  * Enabled CONFIG_PID_NS=y for i386/amd64 (version 2)
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 22 Jan 2009 13:48:34 -0700
++
++linux (2.6.28-5.14) jaunty; urgency=low
++
++  [ Ben Collins ]
++
++  * lirc_gpio: Forward ported to current kernel (jaunty)
++  * configs: Enable LIRC_GPIO on 64-bit/32-bit x86
++    - LP: #298791
++
++  [ Jeff Layton ]
++
++  * SAUCE: cifs: make sure we allocate enough storage for socket address
++    - LP: #318565
++
++  [ Tim Gardner ]
++
++  * check-abi: Return success when ABI skip is requested and no ABI files exist.
++    This ought to fix the armel FTBS.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 22 Jan 2009 06:42:49 -0700
++
++linux (2.6.28-5.13) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: don't use buggy _BCL/_BCM/_BQC for backlight control"
++
++  [ Tim Gardner ]
++
++  * Fix udeb generation breakage caused by the previous armel versatile
++    flavour config update.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 21 Jan 2009 12:38:35 -0700
++
++linux (2.6.28-5.12) jaunty; urgency=low
++
++  [ Ante ]
++
++  * Update drbd to 8.3.0
++
++  [ Dave Airlie ]
++
++  * i915/drm: provide compat defines for userspace for certain struct
++
++  [ Eric Anholt ]
++
++  * drm/i915: Don't double-unpin buffers if we take a signal in
++  * drm/i915: Don't complain when interrupted while pinning in execbuffers.
++  * drm/i915: Don't allow objects to get bound while VT switched.
++
++  [ Jani Monoses ]
++
++  * Fix webcam having USB ID 0ac8:303b
++    - LP: #292086
++
++  [ Jesse Barnes ]
++
++  * drm/i915: set vblank enabled flag correctly across IRQ
++  * drm/i915: don't enable vblanks on disabled pipes
++
++  [ Michael Casadevall ]
++
++  * [arm] Fix kexec on ARM by properly calling the relocation function
++
++  [ Tim Gardner ]
++
++  * Enabled CONFIG_PID_NS=y for i386/amd64
++  * SAUCE: Increase ATA_TMOUT_PMP_SRST_WAIT to 5 seconds.
++    - LP: #318978
++  * Update armel versatile config
++    - LP: #314789
++  * Enabled CONFIG_RT2860=m for i386/amd64
++  * Enabled CONFIG_RT2870=m for i386/amd64
++
++  [ Upstream Kernel Changes ]
++
++  * Input: atkbd - add keyboard quirk for HP Pavilion ZV6100 laptop
++    - LP: #291878
++  * ALSA: hda - Add quirk for another HP dv7
++  * ALSA: hda - Add quirk for HP6730B laptop
++  * ALSA: caiaq - Fix Oops with MIDI
++  * ALSA: hda - Fix typos for AD1882 codecs
++  * x86: fix intel x86_64 llc_shared_map/cpu_llc_id anomolies
++  * x86: default to SWIOTLB=y on x86_64
++  * CIFS: make sure that DFS pathnames are properly formed
++  * ring-buffer: prevent false positive warning
++  * ring-buffer: fix dangling commit race
++  * iwlwifi: use GFP_KERNEL to allocate Rx SKB memory
++  * tx493[89]ide: Fix length for __ide_flush_dcache_range
++  * tx4939ide: Do not use zero count PRD entry
++  * SCSI: eata: fix the data buffer accessors conversion regression
++  * USB: emi26: fix oops on load
++  * x86, UV: remove erroneous BAU initialization
++  * x86: fix incorrect __read_mostly on _boot_cpu_pda
++  * vmalloc.c: fix flushing in vmap_page_range()
++  * fs: symlink write_begin allocation context fix
++  * cgroups: fix a race between cgroup_clone and umount
++  * dm raid1: fix error count
++  * dm log: fix dm_io_client leak on error paths
++  * minix: fix add link's wrong position calculation
++  * md: fix bitmap-on-external-file bug.
++  * sched_clock: prevent scd->clock from moving backwards, take #2
++  * devices cgroup: allow mkfifo
++  * SCSI: aha152x_cs: Fix regression that keeps driver from using shared
++    interrupts
++  * ioat: fix self test for multi-channel case
++  * USB: isp1760: use a specific PLX bridge instead of any bdridge
++  * USB: isp1760: Fix probe in PCI glue code
++  * USB: unusual_devs.h additions for Pentax K10D
++  * inotify: fix type errors in interfaces
++  * Move compat system call declarations to compat header file
++  * Convert all system calls to return a long
++  * Rename old_readdir to sys_old_readdir
++  * Remove __attribute__((weak)) from sys_pipe/sys_pipe2
++  * Make sys_pselect7 static
++  * Make sys_syslog a conditional system call
++  * System call wrapper infrastructure
++  * powerpc: Enable syscall wrappers for 64-bit
++  * s390: enable system call wrappers
++  * System call wrapper special cases
++  * System call wrappers part 01
++  * System call wrappers part 02
++  * System call wrappers part 03
++  * System call wrappers part 04
++  * System call wrappers part 05
++  * System call wrappers part 06
++  * System call wrappers part 07
++  * System call wrappers part 08
++  * System call wrappers part 09
++  * System call wrappers part 10
++  * System call wrappers part 11
++  * System call wrappers part 12
++  * System call wrappers part 13
++  * System call wrappers part 14
++  * System call wrappers part 15
++  * System call wrappers part 16
++  * System call wrappers part 17
++  * System call wrappers part 18
++  * System call wrappers part 19
++  * System call wrappers part 20
++  * System call wrappers part 21
++  * System call wrappers part 22
++  * System call wrappers part 23
++  * System call wrappers part 24
++  * System call wrappers part 25
++  * System call wrappers part 26
++  * System call wrappers part 27
++  * System call wrappers part 28
++  * System call wrappers part 29
++  * System call wrappers part 30
++  * System call wrappers part 31
++  * System call wrappers part 32
++  * System call wrappers part 33
++  * s390 specific system call wrappers
++  * x86: fix RIP printout in early_idt_handler
++  * Fix timeouts in sys_pselect7
++  * USB: another unusual_devs entry for another bad Argosy storage device
++  * USB: storage: extend unusual range for 067b:3507
++  * USB: storage: recognizing and enabling Nokia 5200 cell phoes
++  * HID: fix error condition propagation in hid-sony driver
++  * fix switch_names() breakage in short-to-short case
++  * nfs: remove redundant tests on reading new pages
++  * eCryptfs: check readlink result was not an error before using it
++  * mvsas: increase port type detection delay to suit Seagate's 10k6 drive ST3450856SS 0003
++  * x86: avoid theoretical vmalloc fault loop
++  * ath9k: enable RXing of beacons on STA/IBSS
++  * mm lockless pagecache barrier fix
++  * powerpc: Disable Collaborative Memory Manager for kdump
++  * ibmvfc: Delay NPIV login retry and add retries
++  * ibmvfc: Improve async event handling
++  * getrusage: RUSAGE_THREAD should return ru_utime and ru_stime
++  * ath5k: ignore the return value of ath5k_hw_noise_floor_calibration
++  * mm: fix assertion
++  * XFS: truncate readdir offsets to signed 32 bit values
++  * Linux 2.6.28.1
++  * eCryptfs: Filename Encryption: Tag 70 packets
++  * eCryptfs: Filename Encryption: Header updates
++  * eCryptfs: Filename Encryption: Encoding and encryption functions
++  * eCryptfs: Filename Encryption: filldir, lookup, and readlink
++  * eCryptfs: Filename Encryption: mount option
++  * eCryptfs: Replace %Z with %z
++  * eCryptfs: Fix data types (int/size_t)
++  * eCryptfs: kerneldoc for ecryptfs_parse_tag_70_packet()
++  * eCryptfs: Clean up ecryptfs_decode_from_filename()
++  * fs/ecryptfs/inode.c: cleanup kerneldoc
++  * staging-p80211: Kill directly reference of netdev->priv
++  * staging-slicoss: Kill directly reference of netdev->priv
++  * staging-winbond: Kill directly reference of netdev->priv
++  * Staging: go7007: fixes due to video_usercopy api change
++  * Staging: go7007: fixes due v4l2_file_operations api change
++  * staging: correct dubious use of !x & y
++  * Staging: w35und: make wb35_probe() and wb35_disconnect() funtions static
++  * Staging: w35und: remove unused wb35_open() and wb35_close() functions
++  * Staging: w35und: use msleep() and udelay()
++  * Staging: w35und: remove the no-op pa_stall_execution macro
++  * Staging: w35und: purb typedef removal
++  * Staging: w35und: reg queue struct typedef removal
++  * Staging: w35und: wb35reg struct typedef removal
++  * Staging: w35und: padapter struct typedef removal
++  * Staging: w35und: merge wblinux struct to adapter
++  * Staging: w35und: wb35_probe() cleanup
++  * Staging: w35und: remove usb_submit_urb wrapper function
++  * Staging: w35und: remove usb_alloc_urb wrapper function
++  * w35und: remove dead code from wbusb_f.h
++  * Staging: w35und: remove true/false boolean macros
++  * Staging: w35und: OS_MEMORY_ALLOC wrapper removal
++  * Staging: w35und: usb_put_dev() is missing from wb35_disconnect()
++  * Staging: w35und: remove macro magic from MLME_GetNextPacket()
++  * Staging: w35und: plug memory leak in wbsoft_tx()
++  * Staging: w35und: move supported band initialization out of wb35_probe()
++  * Staging: w35und: remove timer wrappers
++  * Staging: w35und: remove atomic op wrappers
++  * Staging: w35und: remove memcpy/memcmp wrappers
++  * Staging: w35und: remove abs() and BIT() macros
++  * Staging: w35und: remove unused macros from common.h
++  * Staging: w35und: remove unused link status code
++  * Staging: w35und: #include cleanup
++  * Staging: w35und: remove some dead code
++  * Staging: w35und: move source files to one directory
++  * Staging: w35und: move struct wbsoft_priv to core.h and use it
++  * Staging: w35und: remove ->adapter from struct _HW_DATA_T
++  * Staging: w35und: clean up adapter.h a bit
++  * Staging: w35und: merge struct wb35_adapter to struct wbsoft_priv
++  * Staging: w35und: remove global struct ieee80211_hw
++  * Staging: w35und: inline DRIVER_AUTHOR and DRIVER_DESC macros
++  * Staging: w35und: clean up wblinux.c a bit
++  * Staging: w35und: remove unused ->ShutDowned member from struct
++    LOCAL_PARA
++  * Staging: w35und: move global wbsoft_enabled to struct wbsoft_priv
++  * Staging: w35und: move packet_came() to wb35rx.c
++  * Staging: w35und: remove ->skb_array from struct wbsoft_priv
++  * Staging: w35und: remove ->shutdown from struct wbsoft_priv
++  * Staging: w35und: make functions local to mds.c static
++  * Staging: w35und: make functions local to mlmetxrx.c static
++  * Staging: w35und: remove dead code from mto.c
++  * Staging: w35und: make functions local to wb35rx.c static
++  * Staging: w35und: make functions local to wb35tx.c static
++  * Staging: w35und: remove dead code from wbhal.c
++  * Staging: w35und: remove rxisr.c as dead code
++  * Staging: w35und: fix Kconfig
++  * Staging: w35und: fix config build warnings
++  * Staging: wlan-ng: Remove PCI/PLX/PCMCIA files.
++  * Staging: wlan-ng: Update Help text to mention prism3 devices.
++  * Staging: wlan-ng: Delete PCI/PLX/PCMCIA-specific code.
++  * Staging: wlan-ng: Make wlan-ng use WEXT mode by default.
++  * Staging: wlan-ng: Eliminate more <2.6 kernel support.
++  * Staging: wlan-ng: Eliminate all backwards-compatibility for <2.6.13 kernels.
++  * Staging: wlan-ng: Eliminate a boatload of tertiaryAP-only code.
++  * Staging: wlan-ng: Remove AP-only code from MLME functions.
++  * Staging: wlan-ng: Get rid of the MTU tests in the rx conversion path.
++  * Staging: wlan-ng: Eliminate one more rx mtu test.
++  * Staging: wlan-ng: Eliminate local 'version.h'
++  * Staging: wlan-ng: Eliminate usage of procfs.
++  * Staging: wlan-ng: Use standard kernel integer (u32/s32/etc) types.
++  * Staging: wlan-ng: Eliminate all backwards-compatible kernel code.
++  * Staging: wlan-ng: Wireless Extension support is mandatory.
++  * Staging: wlan-ng: use WIRELESS_EXT, not CONFIG_WIRELESS_EXT
++  * Staging: wlan-ng: Delete a large pile of now-unused code.
++  * Staging: wlan-ng: Delete a pile of unused mibs. And fix WEXT SET_TXPOWER.
++  * Staging: wlan-ng: Consolidate wlan-ng into a single module.
++  * Staging: wlan-ng: Purge all MIBs not used internally.
++  * Staging: wlan-ng: p80211netdev.c fix netdev alloc to prevent oops on device start
++  * Staging: wlan-ng: prism2_usb.c always enable the card in probe_usb
++  * Staging: wlan-ng: hfa384x_usb.c use newest version of 384x_drvr_start
++  * Staging: wlan-ng: p80211wext.c add latest changes & remove extra nulls from wext_handlers
++  * Staging: wlan-ng: p80211wext don't set default key id twice
++  * Staging: wlan-ng: hfa384x_usbin_callback: check for hardware removed
++  * Staging: wlan-ng: p80211conv.c copy code from wlan-ng-devel branch to not drop packets
++  * Staging: wlan-ng: remove unused #include <version.h>
++  * Staging: wlan-ng: p80211wext.c: use ARRAY_SIZE
++  * Staging: wlan-ng: fix compiler warnings
++  * Staging: wlan-ng: skb_p80211_to_ether() - payload_length is unsigned, check before subtraction
++  * Staging: at76_usb: update drivers/staging/at76_usb w/ mac80211 port
++  * Staging: at76_usb: fix build breakage
++  * Staging: at76_usb: remove compiler warnings
++  * Staging: at76_usb: fix up all remaining checkpatch.pl warnings
++  * Staging: at76_usb: cleanup dma on stack issues
++  * Staging: poch: Block size bug fix
++  * Staging: poch: Update TODO list
++  * Staging: poch: Correct pages from bytes.
++  * Staging: poch: minor fixes
++  * Staging: poch: Fix build warnings
++  * Staging: poch: Rx control register init
++  * Staging: poch: Fix user space protocol syncing
++  * Staging: poch: Fine grained locking
++  * Staging: sxg: remove typedefs
++  * Staging: sxg: break the build in a cleaner way when !x86
++  * Staging: sxg: update README
++  * staging: struct device - replace bus_id with dev_name(), dev_set_name()
++  * Staging: echo: remove typedefs
++  * Staging: echo: Lindent drivers/staging/echo
++  * Staging: go7007: saa7134 updates
++  * Staging: go7007: add sensoray 2250/2251 support
++  * Staging: go7007: Convert driver to use video_ioctl2
++  * Staging: go7007: annotate code pointers
++  * Staging: go7007: fix minor build warnings
++  * Staging: go7007: small cleanup
++  * Staging: go7007: add some more v4l2 ioctls
++  * Staging: et131x: Cleanup et131x_debug.h defines
++  * Staging: et131x: fix build failure
++  * Staging: et131x: remove unused variable in et1310_tx.c
++  * Staging: usbip: cleanup kerneldoc
++  * Staging: slicoss: use kzalloc
++  * Staging: slicoss: use correct type for memory allcations
++  * Staging: slicoss: use request_firmware
++  * Staging: add agnx wireless driver
++  * Staging: agnx: fix build errors due to ssid removal
++  * Staging: agnx: fix build errors due to rate control API changes
++  * Staging: agnx: fix build warnings
++  * Staging: add otus Atheros wireless network driver
++  * Staging: otus: fix netdev->priv usage
++  * Staging: otus: fix name clash
++  * Staging: otus: fix urb callback function type
++  * Staging: otus: remove dependence on kernel version
++  * Staging: add rt2860 wireless driver
++  * Staging: rt2860: disable root hack for reading files
++  * Staging: rt2860: fix up netdev->priv usage
++  * Staging: rt2860: use standard bit-reverse function
++  * Staging: rt2860: Fix minor compiler warnings
++  * Staging: rt2860: enable WPA_SUPPLICANT support
++  * Staging: Add ServerEngines benet 10Gb ethernet driver
++  * Staging: benet: fix netif api breakage
++  * Staging: benet: fix up netdev->priv change
++  * Staging: benet: build is broken unless CONFIG_NETPOLL is enabled
++  * Staging: benet: patch to remove subdirectories
++  * Staging: benet: fix build errors when CONFIG_NETPOLL is off
++  * Staging: benet: fix build error.
++  * Staging: benet: patch to use offsetof() instead of AMAP_BYTE_OFFSET()
++  * Staging: benet: fix problems reported by checkpatch
++  * Staging: benet: cleanup a check while posting rx buffers
++  * Staging: add comedi core
++  * Staging: comedi: fix up a lot of checkpatch.pl warnings
++  * Staging: comedi: fix checkpatch.pl errors in comedi_fops.c
++  * Staging: comedi: fix build error in comedilib.h
++  * Staging: comedi: add kcomedilib to the tree
++  * Staging: comedi: set up infrastructure for individual drivers
++  * Staging: comedi: add local copy of interrupt.h
++  * Staging: comedi: add pci and usb wrapper header files
++  * Staging: comedi: comedi driver common function module
++  * Staging: comedi: add mite comedi pci driver
++  * Staging: comedi: add usb usbdux driver
++  * Staging: comedi: add usb usbduxfast driver
++  * Staging: comedi: add usb dt9812 driver
++  * Staging: comedi: add comedi_bond driver
++  * Staging: comedi: add comedi_test driver
++  * Staging: comedi: add comedi_parport driver
++  * Staging: comedi: dt9812: fix up a lot of coding style issues
++  * Staging: comedi: dt9812: remove dt9812.h
++  * Staging: comedi: dt9812: remove typedefs
++  * Staging: comedi: dt9812: fix sparse warnings
++  * Staging: comedi: usbdux: remove kernel version checks
++  * Staging: comedi: usbdux: code style cleanups
++  * Staging: comedi: usbdux: remove // comments
++  * Staging: comedi: usbdux: fix up printk calls
++  * Staging: comedi: usbdux: remove checkpatch.pl warnings
++  * Staging: comedi: usbdux: remove typedef
++  * Staging: comedi: usbdux: remove comedi usb wrappers
++  * Staging: comedi: usbduxfast: remove comedi usb wrappers
++  * Staging: comedi: dt9812: remove #ifdef that is not needed
++  * Staging: comedi: remove usb wrappers
++  * Staging: comedi: remove PCI wrappers
++  * Staging: comedi: add icp_multi driver
++  * Staging: comedi: add me4000 driver
++  * Staging: comedi: fix checkpatch.pl issues in comedi_bond.c
++  * Staging: comedi: fix checkpatch.pl issues in comedi_fc.c
++  * Staging: comedi: remove typedefs from comedi_bond.c
++  * Staging: comedi: fix sparse issues in comedi_bond.c
++  * Staging: comedi: fix checkpatch.pl issues in comedi_test.c
++  * Staging: comedi: fix sparse issues in comedi_test.c
++  * Staging: comedi: remove typedefs from comedi_test.c
++  * Staging: comedi: fix comedi_parport.c checkpatch.pl issues.
++  * Staging: comedi: fix comedi_fc.h checkpatch.pl issues.
++  * Staging: comedi: fix comedi_pci.h checkpatch.pl issues.
++  * Staging: comedi: comedi_pci.h: remove unneeded wrapper
++  * Staging: comedi: comedi_pci.h: remove comedi_pci_enable_no_regions
++  * Staging: comedi: comedi_pci.h: remove comedi_pci_disable_no_regions
++  * Staging: comedi: add s626 driver
++  * Staging: comedi: add rtd520 driver
++  * Staging: comedi: add me_daq driver
++  * Staging: comedi: me_daq: fix checkpatch.pl issues
++  * Staging: comedi: me_daq: remove typedefs
++  * Staging: comedi: me_daq: fix sparse issues
++  * Staging: comedi: fix checkpatch.pl warning in interrupt.h
++  * Staging: comedi: fix build if CONFIG_PROC_FS is not set
++  * Staging: add asus_oled driver
++  * Staging: asus_oled: fix build dependancy
++  * Staging: Add the Meilhaus ME-IDS driver package
++  * Staging: meilhaus: fix __symbol_get problems
++  * Staging: add lcd-panel driver
++  * Staging: panel: major checkpatch cleanup
++  * Staging: panel: remove ifdefs and code for pre-2.6 kernels
++  * Staging: panel: remove support for smartcards
++  * Staging: add Driver for Altera PCI Express Chaining DMA reference design
++  * Staging: add rtl8187se driver
++  * Staging: rtl8187se: remove unneeded files
++  * Staging: rtl8187se: make the built module be the proper name
++  * Staging: rtl8187se: remove duplicate pci ids
++  * Staging: me4000: switch to list_for_each*()
++  * Staging: usbip: switch to list_for_each_entry()
++  * Staging: add princeton instruments usb camera driver
++  * Staging: add mimio xi driver
++  * Staging: add rt2870 wireless driver
++  * Staging: rt2870: disable root hack for reading files
++  * Staging: rt2870: fix up netdev->priv usage
++  * Staging: add frontier tranzport and alphatrack drivers
++  * Staging: frontier: remove unused alphatrack_sysfs.c file
++  * Staging: frontier: fix compiler warnings
++  * Staging: add epl stack
++  * Staging: epl: run Lindent on all kernel/*.h files
++  * Staging: epl: run Lindent on all user/*.h files
++  * Staging: epl: run Lindent on *.h files
++  * Staging: epl: run Lindent on *.c files
++  * Staging: epl: hr timers all run in hard irq context now
++  * Staging: epl: fix netdev->priv b0rkage
++  * Staging: add android framework
++  * Staging: android: add binder driver
++  * Staging: android: binder: Fix gcc warnings about improper format specifiers for size_t in printk
++  * staging: android: binder: Fix use of euid
++  * Staging: android: add logging driver
++  * Staging: android: add ram_console driver
++  * Staging: android: add timed_gpio driver
++  * Staging: android: timed_gpio: Rename android_timed_gpio to timed_gpio
++  * Staging: android: remove dummy android.c driver
++  * Staging: android: add lowmemorykiller driver
++  * Staging: android: binder: fix build errors
++  * staging: __FUNCTION__ is gcc-specific, use __func__
++  * V4L/DVB (10176a): Switch remaining clear_user_page users over to
++    clear_user_highpage
++
++  [ Zhenyu Wang ]
++
++  * agp/intel: add support for G41 chipset
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 18 Jan 2009 20:22:54 -0700
++
++linux (2.6.28-4.11) jaunty; urgency=low
++
++  [ Mario Limonciello ]
++
++  * SAUCE: Enable HDMI audio codec on Studio XPS 1340
++    - LP: #309508
++
++  [ Tim Gardner ]
++
++  * Fix armel d-i FTBSs
++
++  [ Upstream Kernel Changes ]
++
++  * USB: re-enable interface after driver unbinds
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 13 Jan 2009 16:33:08 -0700
++
++linux (2.6.28-4.10) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * update kernel bootloader recommends: to prefer grub
++    - LP: #314004
++  * SAUCE: don't use buggy _BCL/_BCM/_BQC for backlight control
++    - LP: #311716
++  * SAUCE: test-suspend -- add the suspend test scripts
++    - LP: #316419
++
++  [ Colin Watson ]
++
++  * Enable udebs for armel
++
++  [ Tim Gardner ]
++
++  * SAUCE: Dell laptop digital mic does not work, PCI 1028:0271
++    - LP: #309508
++  * Enable CIFS_XATTR=y and CONFIG_CIFS_POSIX=y
++    - LP: #220658
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Jan 2009 10:38:22 -0700
++
++linux (2.6.28-4.9) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * Restore DM_CRYPT, AES, ECB, and CBC as modules. This fixes
++    some installer issues with encrypted /home and Private directories.
++  * Take one more stab at building armel without module or ABI errors.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 06 Jan 2009 08:38:23 -0700
++
++linux (2.6.28-4.8) jaunty; urgency=low
++
++  * Fix i386/amd64 FTBS by ignoring all module and ABI changes,
++    not something you would normally do, but I'm sure the ABI
++    has not changed. This will probably also allow the ARM builds to complete.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 05 Jan 2009 14:42:58 -0700
++
++linux (2.6.28-4.7) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * Enable CONFIG_ATH5K=m for i386/amd64
++    - LP: #306719
++  * Build all i386/amd64 AGP/DRM components as modules.
++    - LP: #312721
++  * git commands are now installed outside the default $PATH
++    Use 'git  CMD' instead of 'git-CMD'.
++  * Build in most PATA/SATA drivers. This should allow most i386/amd64 systems to boot
++    without an initramfs, though some support work is still required in initramfs-tools
++    and grub.
++    - LP: #311730
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 02 Jan 2009 07:33:09 -0700
++
++linux (2.6.28-4.6) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * Enable CONFIG_X86_E_POWERSAVER=m for i386 generic
++    - LP: #237405
++  * Build i386 AGP drivers as modules
++    - LP: #312721
++  * Build i386 DRM as a module
++    - LP: #312721
++
++  [ Upstream Kernel Changes ]
++
++  * drm/i915: Add missing userland definitions for gem init/execbuffer.
++    - LP: #308387
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Dec 2008 09:16:47 -0700
++
++linux (2.6.28-4.5) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * clean up module dependancy information on package removal/purge
++    - LP: #300773
++
++  [ Tim Gardner ]
++
++  * Update iscsitarget to 0.4.17
++  * Build in ext{234}
++  * Build in Crypto modules AES, CBC, ECB
++  * Build in ACPI AC,BATTERY,BUTTON,FAN,PCI_SLOT,PROCESSOR,SBS,THERMAL,WMI
++  * Build in AGP intel,via,sis,ali,amd,amd64,efficeon,nvidia,sworks
++  * Build in ata,dev_dm,dev_loop,dev_md,dev_sd,dev_sr
++  * Build in BT l2cap,rfcomm,sco
++  * Reduce CONFIG_LEGACY_PTY_COUNT to 0
++  * Build in CDROM_PKTCDVD and CHR_DEV_SG
++  * Build in CPU_FREQ
++    GOV_CONSERVATIVE,GOV_ONDEMAND,GOV_POWERSAVE,GOV_USERSPACE,STAT,TABLE
++  * Build in DM CRYPT,MIRROR,MULTIPATH,SNAPSHOT
++  * Build in DRM
++  * Build in HID
++  * Build in HOTPLUG PCI,PCIE
++  * Build in I2C
++  * Build in IEEE1394 OHCI1394
++  * Build in INPUT EVDEV
++  * Build in IPV6
++  * Build in MMC
++  * Build in PACKET
++  * Enable both IEEE1394 (Firewire) stacks as modules
++    - LP: #276463
++  * Disable SUNRPC_REGISTER_V4
++    - LP: #306016
++  * Enable dm-raid4-5
++    - LP: #309378
++  * Build in PPP
++  * Build in RFKILL
++  * Build in USB SERIAL
++
++  [ Upstream Kernel Changes ]
++
++  * Rebased to v2.6.28
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 18 Dec 2008 21:18:44 -0700
++
++linux (2.6.28-3.4) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * Build ecryptfs into the kernel
++    - LP: #302870
++  * Deprecated gnbd
++
++  [ Upstream Kernel Changes ]
++
++  * Rebased to v2.6.28-rc8
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 10 Dec 2008 22:45:13 -0700
++
++linux (2.6.28-2.3) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * update the templates so that we have spaces following the title line
++
++  [ Tim Gardner ]
++
++  * Add upload number to kernel version signature. This has the side effect
++    of renaming kernel packages back to the original way, e.g., without '-ub'
++    in the name.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 04 Dec 2008 12:18:31 -0700
++
++linux (2.6.28-2.2) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: (no-up) version: Implement version_signature proc file."
++  * SAUCE: (no-up) version: Implement version_signature proc file.
++  * SAUCE: serial: RS485 ioctl structure uses __u32 include linux/types.h
++    - LP: #303711
++
++  [ Tim Gardner ]
++
++  * UBUNTU: Removed CONFIG_DRM_VIA_CHROME9 since it is upstream.
++  * UBUNTU: Removed ubuntu/via_chrome9
++
++  [ Upstream Kernel Changes ]
++
++  * Rebased to v2.6.28-rc7
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 02 Dec 2008 07:33:32 -0700
++
++linux (2.6.28-1.1) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * SAUCE: make fc transport removal of target configurable
++  * SAUCE: pm: Config option to disable handling of console during
++    suspend/resume
++  * SAUCE: Adds support for COMPAL JHL90 webcam
++  * Map armel to arm to all editconfigs to work correctly
++  * Add armel to getabis for completeness sake
++  * Add -ub to our versioning to allow kerneloops.org to identify us
++
++  [ Andy Whitcroft ]
++
++  * Fix Vcs-Git path for the kernel repository.
++    - LP: #296915
++
++  [ Ben Collins ]
++
++  * SAUCE: Lower warning level of some PCI messages
++    - LP: #159241
++  * SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps
++  * SAUCE: tulip: Let dmfe handle davicom on non-sparc
++  * SAUCE: tulip: Define ULI PCI ID's
++  * SAUCE: (no-up) version: Implement version_signature proc file.
++  * SAUCE: (no-up) connector.h: Add idx/val for drbd
++  * SAUCE: (no-up) swap: Add notify_swap_entry_free callback for compcache
++  * SAUCE: drivers: Remove some duplicate device entries in various modules
++  * SAUCE: (no-up) [AppArmor] merge with upstream subversion r1291
++  * SAUCE: (no-up) Enable ubuntu extra subdirectory
++  * SAUCE: (no-up) ACPI: initramfs DSDT override support
++  * ubuntu: Add drbd module
++  * ubuntu: Add iscsitarget module
++  * ubuntu: Add BOM for iscsitarget
++  * ubuntu: Add squashfs driver
++  * SAUCE: (no-up) Check for squashfs superblock in initramfs mounting.
++  * ubuntu: Add aufs module
++  * ubuntu: Added atl2 driver
++  * ubuntu: Added et131x driver
++  * ubuntu: Add dm-raid4-5 driver
++  * ubuntu: Add ndiswrapper driver
++  * ubuntu: Added ram backed compressed swap module (compcache)
++  * ubuntu: Add misc drivers from hardy lum
++  * ubuntu: Add heci driver 3.2.0.24
++  * ubuntu: Add ov511 and bt-sco drivers
++  * ubuntu: Add acx, prism2_usb wireless drivers
++  * ubuntu: Add at76 driver to build
++  * ubuntu: Add fsam7400 sw kill switch driver
++  * ubuntu: Added qc-usb driver
++  * ubuntu: e1000e: Upgraded module to 0.4.1.7
++  * ubuntu: Added rfkill drivers
++  * ubuntu: VIA - Add VIA DRM Chrome9 3D engine
++  * ubuntu: unionfs: Added v1.4 module from hardy
++  * ubuntu: Add LIRC driver
++  * ubuntu: Add GFS driver
++  * ubuntu: New tlsup driver for toshiba laptops
++  * SAUCE: (no-up) Export lookup_has for aufs
++  * SAUCE: (no-up) Modularize vesafb
++  * ubuntu: Config files
++  * Disable some modules that need porting to 2.6.28
++  * ubuntu: Fixup headers creation to include arch/*/include
++  * ubuntu/module-check: Ignore comment lines
++
++  [ Chuck Short ]
++
++  * SAUCE: ata: blacklist FUJITSU MHW2160BH PL
++
++  [ cking ]
++
++  * SAUCE: Enable speedstep for sonoma processors.
++
++  [ Colin Ian King ]
++
++  * ubuntu: Add dm-loop
++  * SAUCE: cx88: Support Leadtek WinFast DTV2000 H version J.
++  * SAUCE: fix kernel oops in VirtualBox during paravirt patching
++  * SAUCE: qc-usb: Enable Logitech QuickCam Messenger
++  * SAUCE: appleir: Enable driver for new MacBook Pro
++
++  [ Colin Watson ]
++
++  * Enable configfs, fuse, jfs, reiserfs, and xfs for armel
++  * Extend debian/d-i/ modules handling to make armel easier to support
++  * Create udebs for armel
++
++  [ Fabio M. Di Nitto ]
++
++  * ubuntu: update GFS Cluster File System
++
++  [ Kees Cook ]
++
++  * SAUCE: AppArmor: update to upstream subversion r1302
++
++  [ Leann Ogasawara ]
++
++  * Add automatic model setting for Samsung Q45
++  * Add Dell Dimension 9200 reboot quirk
++
++  [ Mackenzie Morgan ]
++
++  * SAUCE: Add quirk for ASUS Z37E to make sound audible after resume
++
++  [ Matthew Garrett ]
++
++  * SAUCE: hostap: send events on data interface as well as master
++    interface
++
++  [ Michael Frey (Senior Manager, MID ]
++
++  * SAUCE: Send HCI_RESET for Broadcomm 2046
++
++  [ Michael Haas ]
++
++  * add proper aufs source tree from 20080922
++  * Fix AUFS compilation in vfsub.c
++  * Add splice-2.6.23.patch from AUFS to export a symbol needed by AUFS
++  * Add put_filp.patch from AUFS to export a symbol needed by AUFS
++  * Add deny_write_access.patch from AUFS - export deny_write_access
++  * Add sec_perm-2.6.24.patch from AUFS - export security_inode_permission
++  * make sure TMPFS_MAGIC is defined in AUFS Makefile
++  * SAUCE: Revert aufs changes from AppArmor merge
++
++  [ Mohamed Abbas ]
++
++  * SAUCE: iwlagn -- fix rfkill when on when driver loaded
++
++  [ Phillip Lougher ]
++
++  * SAUCE: r8169: disable TSO by default for RTL8111/8168B chipsets.
++
++  [ Stefan Bader ]
++
++  * SAUCE: (no-up) Export dm_disk function of device-mapper
++  * SAUCE: Restore VT fonts on switch
++  * SAUCE: mmc: Increase power_up deleay to fix TI readers
++  * gfs1: GFS1 can't create more than 4kb file
++  * uvcvideo: Commit streaming parameters when enabling the video stream.
++
++  [ Tim Gardner ]
++
++  * SAUCE: Add extra headers to linux-libc-dev
++  * SAUCE: Catch nonsense keycodes and silently ignore
++  * SAUCE: Added support for HDAPS on various ThinkPads from Lenovo and IBM
++  * SAUCE: Guest OS does not recognize a lun with non zero target id on
++    Vmware ESX Server
++  * SAUCE: (no-up) Take care of orinoco_cs overlap with hostap_cs
++  * ubuntu: Add GNBD driver
++  * SAUCE: e1000e: Map NV RAM dynamically only when needed.
++  * SAUCE: Correctly blacklist Thinkpad r40e in ACPI
++  * SAUCE: Update Wacom tablet driver to 1.49
++  * SAUCE: Fix Wacom tablet 1.49 porting errors
++  * SAUCE: Enable an e1000e Intel Corporation 82567 Gigabit controller
++  * SAUCE: Fix Oops in wlan_setup
++  * SAUCE: ipw2200: change default policy for auto-associate
++  * Dell Wireless 365 needs BTUSB_RESET quirk.
++  * ndiswrapper remote buffer overflows on long ESSIDs (CVE 2008-4395)
++  * Disabled ubuntu/e1000e config
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[Bluetooth] Eliminate checks for impossible conditions in IRQ
++    handler"
++  * Revert "x86, early_ioremap: fix fencepost error"
++  * mac80211: fix two issues in debugfs
++  * iwl3945: do not send scan command if channel count zero
++
++ --  Ben Collins <ben.collins@canonical.com>  Fri, 07 Nov 2008 09:37:42 -0700
++
++linux (2.6.27-8.17) intrepid-proposed; urgency=low
++
++  [ John W. Linville ]
++
++  * SAUCE: iwlagn: avoid sleep in softirq context
++    -LP: #286285
++
++  [ Tim Gardner ]
++
++  * Dell Wireless 365 needs BTUSB_RESET quirk.
++    - LP: #293670
++  * SAUCE: ALSA: hda: make a STAC_DELL_EQ option (version 2)
++    - LP: #293271
++
++  [ Upstream Kernel Changes ]
++
++  * iwlagn: downgrade BUG_ON in interrupt
++  * Input: atkbd - expand Latitude's force release quirk to other Dells
++  * fbcon_set_all_vcs: fix kernel crash when switching the rotated consoles
++  * modules: fix module "notes" kobject leak
++  * Driver core: Fix cleanup in device_create_vargs().
++  * Driver core: Clarify device cleanup.
++  * ath9k/mac80211: disallow fragmentation in ath9k, report to userspace
++  * md: Fix rdev_size_store with size == 0
++  * xfs: fix remount rw with unrecognized options
++  * OHCI: Allow broken controllers to auto-stop
++  * USB: OHCI: fix endless polling behavior
++  * USB: Fix s3c2410_udc usb speed handling
++  * USB: EHCI: log a warning if ehci-hcd is not loaded first
++  * usb gadget: cdc ethernet notification bugfix
++  * usb: musb_hdrc build fixes
++  * drm/i915: fix ioremap of a user address for non-root (CVE-2008-3831)
++  * DVB: au0828: add support for another USB id for Hauppauge HVR950Q
++  * DVB: sms1xxx: support two new revisions of the Hauppauge WinTV
++    MiniStick
++  * security: avoid calling a NULL function pointer in
++    drivers/video/tvaudio.c
++  * Linux 2.6.27.3
++    -LP: #294152
++
++  * gpiolib: fix oops in gpio_get_value_cansleep()
++  * edac cell: fix incorrect edac_mode
++  * x86 ACPI: fix breakage of resume on 64-bit UP systems with SMP kernel
++  * sched: fix the wrong mask_len
++  * USB: cdc-wdm: make module autoload work
++  * USB: don't rebind drivers after failed resume or reset
++  * USB: fix memory leak in cdc-acm
++  * USB: Speedtouch: add pre_reset and post_reset routines
++  * dm kcopyd: avoid queue shuffle
++  * dm snapshot: fix primary_pe race
++  * amd_iommu: fix nasty bug that caused ILLEGAL_DEVICE_TABLE_ENTRY errors
++  * CIFS: fix saving of resume key before CIFSFindNext
++  * netfilter: xt_iprange: fix range inversion match
++  * netfilter: snmp nat leaks memory in case of failure
++  * netfilter: restore lost ifdef guarding defrag exception
++  * anon_vma_prepare: properly lock even newly allocated entries
++  * hvc_console: Fix free_irq in spinlocked section
++  * ACPI Suspend: Enable ACPI during resume if SCI_EN is not set
++  * ACPI suspend: Blacklist HP xw4600 Workstation for old code ordering
++  * ACPI suspend: Always use the 32-bit waking vector
++  * proc: fix vma display mismatch between /proc/pid/{maps,smaps}
++  * SCSI: scsi_dh: add Dell product information into rdac device handler
++  * PCI hotplug: cpqphp: fix kernel NULL pointer dereference
++  * V4L/DVB (9300): pvrusb2: Fix deadlock problem
++  * Linux 2.6.27.4
++    -LP: #294155
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 04 Nov 2008 12:16:07 -0700
++
++linux (2.6.27-7.16) intrepid-security; urgency=low
++
++  [ Tim Gardner ]
++
++  * ndiswrapper remote buffer overflows on long ESSIDs (CVE 2008-4395)
++    - LP: #275860
++
++  [ Upstream Kernel Changes ]
++
++  * ext[234]: Avoid printk floods in the face of directory corruption
++    (CVE-2008-3528)
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 03 Nov 2008 13:34:42 -0700
++
++linux (2.6.27-7.15) intrepid-security; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * tcp: Restore ordering of TCP options for the sake of inter-operability
++    - LP: #264019
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 27 Oct 2008 19:28:06 -0600
++
++linux (2.6.27-7.14) intrepid; urgency=low
++
++  [ Tim Gardner ]
++
++  * Disable ath5k in 2.6.27
++    - LP: #288148
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 23 Oct 2008 07:40:43 -0600
++
++linux (2.6.27-7.13) intrepid; urgency=low
++
++  [ Stefan Bader ]
++
++  * gfs1: GFS1 can't create more than 4kb file
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: x86: Reserve FIRST_DEVICE_VECTOR in used_vectors
++    bitmap.". Use upstream commit to avoid future conflicts.
++  * Revert "STABLE queue: mac80211: fix two issues in debugfs".
++    Use upstream commit to avoid future conflicts.
++  * Revert "x86, early_ioremap: fix fencepost error"
++    Use upstream commit to avoid future conflicts.
++
++  [ Upstream Kernel Changes ]
++
++  * sched_rt.c: resch needed in rt_rq_enqueue() for the root rt_rq
++  * x86: Reserve FIRST_DEVICE_VECTOR in used_vectors bitmap.
++  * mac80211: fix two issues in debugfs
++  * Fix barrier fail detection in XFS
++  * tty: Termios locking - sort out real_tty confusions and lock reads
++  * CIFS: make sure we have the right resume info before calling
++    CIFSFindNext
++  * rfkill: update LEDs for all state changes
++  * libertas: clear current command on card removal
++  * b43legacy: Fix failure in rate-adjustment mechanism
++  * x86, early_ioremap: fix fencepost error
++  * x86: SB450: skip IRQ0 override if it is not routed to INT2 of IOAPIC
++  * x86: improve UP kernel when CPU-hotplug and SMP is enabled
++  * sky2: Fix WOL regression
++  * netdrvr: atl1e: Don't take the mdio_lock in atl1e_probe
++  * Linux 2.6.27.2
++
++  [ Amit Kucheria ]
++
++  * Ubuntu: agp: Fix stolen memory counting on G4X.
++    -LP: 285572
++
++  [ Scott Remnant ]
++
++  * add MODULE_ALIAS to load ipmi_devintf with ipmi_si
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 19 Oct 2008 10:06:21 -0600
++
++linux (2.6.27-7.12) intrepid; urgency=low
++
++  [ Chuck Short ]
++
++  * xen: Add xen modules to virtual flavours.
++
++  [ Mario Limonciello ]
++
++  * SAUCE: Add back in lost commit for Apple BT Wireless Keyboard
++    - LP: #162083
++
++  [ Tim Gardner ]
++
++  * Remove depmod created files from packages.
++    - LP: #250511
++  *  Changed default TCP congestion algorithm to 'cubic' (again)
++    - LP: #278801
++  * Update configs for 'disable CONFIG_DYNAMIC_FTRACE'
++    - LP: #263555
++
++  [ Upstream Kernel Changes ]
++
++  * x86: register a platform RTC device if PNP doesn't describe it
++  * disable CONFIG_DYNAMIC_FTRACE due to possible memory corruption on
++    module unload
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 17 Oct 2008 11:25:39 -0600
++
++linux (2.6.27-7.11) intrepid; urgency=low
++
++  [ Amit Kucheria ]
++
++  * STABLE queue: mac80211: fix two issues in debugfs
++    - LP: #275227
++  * SAUCE: Adds support for COMPAL JHL90 webcam
++
++  [ Ben Collins ]
++
++  * SAUCE: (no-up) x86: Quiet "Kernel alive" messages
++    - LP: #39985
++  * SAUCE: (no-up) Modularize vesafb
++  * build/config: Enable vesafb module
++  * build: Switch to vesafb as preferred.
++
++  [ Leann Ogasawara ]
++
++  * Add Dell Dimension 9200 reboot quirk
++    - LP: #271370
++
++  [ Michael Haas ]
++
++  * SAUCE: Revert aufs changes from AppArmor merge
++
++  [ Tim Gardner ]
++
++  * fix virtio udeb layout
++    - LP: #257739
++  * Enabled CONFIG_EXT4DEV_FS=m
++  * Changed default TCP congestion algorithm to 'cubic'
++    - LP: #278801
++  * SAUCE: ipw2200: change default policy for auto-associate
++    - LP: #264104
++
++  [ Upstream Kernel Changes ]
++
++  * x86, early_ioremap: fix fencepost error
++    - LP: #263543
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sat, 11 Oct 2008 08:07:42 -0600
++
++linux (2.6.27-7.10) intrepid; urgency=low
++
++  [ Alexey Starikovskiy ]
++
++  * SAUCE: ACPI: EC: do transaction from interrupt context
++    - LP: #277802
++
++  [ Ben Collins ]
++
++  * build/d-i: Change virtio-modules udeb to prio standard
++
++  [ Colin Ian King ]
++
++  * SAUCE: Blacklist IBM 2656 in serio/i8042
++    - LP: #21558
++
++  [ Henrik Rydberg ]
++
++  * Revert "SAUCE: applesmc: Add MacBookAir"
++  * SAUCE: [PATCH 1/5] hwmon: applesmc: Specified number of bytes to read
++    should match actual
++  * SAUCE: [PATCH 2/5] hwmon: applesmc: Fix the 'wait status failed: c !=
++    8' problem
++  * SAUCE: [PATCH 3/5] hwmon: applesmc: Prolong status wait
++  * SAUCE: [PATCH 4/5] hwmon: applesmc: Allow for variable ALV0 and ALV1
++    package length
++  * SAUCE: [PATCH 5/5] hwmon: applesmc: Add support for Macbook Air
++  * SAUCE: hwmon: applesmc: Add support for Macbook Pro 4
++  * SAUCE: hwmon: applesmc: Add support for Macbook Pro 3
++  * SAUCE: hwmon: applesmc: Lighter wait mechanism, drastic improvement
++
++  [ Leann Ogasawara ]
++
++  * Add automatic model setting for Samsung Q45
++    - LP: #200210
++
++  [ Tim Gardner ]
++
++  * SAUCE: Correctly blacklist Thinkpad r40e in ACPI
++    - LP: #278794
++  * SAUCE: Update Wacom tablet driver to 1.49
++    - LP: #260675
++  * SAUCE: ALPS touchpad for Dell Latitude E6500/E6400
++    - LP: #270643
++  * SAUCE: Fix Wacom tablet 1.49 porting errors
++  * SAUCE: Enable an e1000e Intel Corporation 82567 Gigabit controller
++  * SAUCE: Fix Oops in wlan_setup
++    - LP: #263309
++
++  [ Upstream Kernel Changes ]
++
++  * ath9k: fix oops on trying to hold the wrong spinlock
++  * [Bluetooth] Fix double frees on error paths of btusb and bpa10x drivers
++  * [Bluetooth] Add reset quirk for new Targus and Belkin dongles
++  * [Bluetooth] Add reset quirk for A-Link BlueUSB21 dongle
++  * Revert "ax25: Fix std timer socket destroy handling."
++  * ax25: Quick fix for making sure unaccepted sockets get destroyed.
++  * netrom: Fix sock_orphan() use in nr_release
++  * Revert "V4L/DVB (8904): cx88: add missing unlock_kernel"
++  * SLOB: fix bogus ksize calculation
++  * net: only invoke dev->change_rx_flags when device is UP
++  * tcp: Fix possible double-ack w/ user dma
++  * net: Fix netdev_run_todo dead-lock
++  * tcp: Fix tcp_hybla zero congestion window growth with small rho and large cwnd.
++  * [MIPS] Sibyte: Register PIO PATA device only for Swarm and Litte Sur
++  * eeepc-laptop: Fix hwmon interface
++  * hwmon: (it87) Prevent power-off on Shuttle SN68PT
++  * hwmon: Define sysfs interface for energy consumption register
++  * hwmon: (adt7473) Fix some bogosity in documentation file
++  * hwmon: (abituguru3) Enable reading from AUX3 fan on Abit AT8 32X
++  * hwmon: (abituguru3) Enable DMI probing feature on Abit AT8 32X
++  * [CPUFREQ] correct broken links and email addresses
++  * SLOB: fix bogus ksize calculation fix
++  * Don't allow splice() to files opened with O_APPEND
++  * Linux 2.6.27
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 08 Oct 2008 21:19:34 -0600
++
++linux (2.6.27-6.9) intrepid; urgency=low
++
++  [ Kees Cook ]
++
++  * SAUCE: AppArmor: update to upstream subversion r1302
++    - LP: #269921
++
++  [ Stefan Bader ]
++
++  * Update configuration files to be compliant to desktop specs
++    - LP: #279019
++
++  [ Tim Gardner ]
++
++  * Add support in e1000e for a couple of ICH10 PCI IDs
++  * Enable CONFIG_INPUT_PCSPKR=m
++    - LP: #275453
++
++  [ Upstream Kernel Changes ]
++
++  * V4L/DVB (8559a): Fix a merge conflict at gspca/sonixb
++  * V4L/DVB (8789): wm8739: remove wrong kfree
++  * V4L/DVB (8883): w9968cf: Fix order of usb_alloc_urb validation
++  * V4L/DVB (8884): em28xx-audio: fix memory leak
++  * V4L/DVB (8885): cpia2_usb: fix memory leak
++  * V4L/DVB (8886): ov511: fix memory leak
++  * V4L/DVB (8887): gspca: fix memory leak
++  * V4L/DVB (8892): pvrusb2: Handle USB ID 2040:2950 same as 2040:2900
++  * V4L/DVB (8904): cx88: add missing unlock_kernel
++  * V4L/DVB (8905): ov511: fix exposure sysfs attribute bug
++  * V4L/DVB (8909): gspca: PAC 7302 webcam 093a:262a added.
++  * hrtimer: migrate pending list on cpu offline
++  * hrtimer: fix migration of CB_IRQSAFE_NO_SOFTIRQ hrtimers
++  * hrtimer: mark migration state
++  * hrtimer: prevent migration of per CPU hrtimers
++  * [IA64] Put the space for cpu0 per-cpu area into .data section
++  * powerpc: Fix PCI in Holly device tree
++  * powerpc: Fix failure to shutdown with CPU hotplug
++  * mfd: Fix Kconfig accroding to the new gpiolib symbols
++  * mfd: Fix asic3 compilation
++  * x86: fix typo in enable_mtrr_cleanup early parameter
++  * ipsec: Fix pskb_expand_head corruption in xfrm_state_check_space
++  * iucv: Fix mismerge again.
++  * ALSA: ASoC: Fix cs4270 error path
++  * ALSA: hda - Fix model for Dell Inspiron 1525
++  * sctp: Fix kernel panic while process protocol violation parameter
++  * x86: Fix broken LDT access in VMI
++  * x86, vmi: fix broken LDT access
++  * tcp: Fix NULL dereference in tcp_4_send_ack()
++  * ipv6: NULL pointer dereferrence in tcp_v6_send_ack
++  * XFRM,IPv6: initialize ip6_dst_blackhole_ops.kmem_cachep
++  * af_key: Free dumping state on socket close
++  * dm: always allow one page in dm_merge_bvec
++  * dm: cope with access beyond end of device in dm_merge_bvec
++  * dm mpath: add missing path switching locking
++  * MN10300: Fix IRQ handling
++  * pxa2xx_spi: fix build breakage
++  * e1000e: write protect ICHx NVM to prevent malicious write/erase
++  * powerpc: Fix boot hang regression on MPC8544DS
++  * ASoC: Set correct name for WM8753 rec mixer output
++  * ALSA: snd-powermac: mixers for PowerMac G4 AGP
++  * ALSA: snd-powermac: HP detection for 1st iMac G3 SL
++  * fbcon: fix monochrome color value calculation
++  * inotify: fix lock ordering wrt do_page_fault's mmap_sem
++  * braille_console: only register notifiers when the braille console is used
++  * fix error-path NULL deref in alloc_posix_timer()
++  * memory hotplug: missing zone->lock in test_pages_isolated()
++  * mm: tiny-shmem nommu fix
++  * mm: handle initialising compound pages at orders greater than MAX_ORDER
++  * e1000e: reset swflag after resetting hardware
++  * e1000e: do not ever sleep in interrupt context
++  * e1000e: remove phy read from inside spinlock
++  * e1000e: drop stats lock
++  * e1000e: debug contention on NVM SWFLAG
++  * e1000e: update version from k4 to k6
++  * Check mapped ranges on sysfs resource files
++  * e1000e: Fix incorrect debug warning
++  * [MIPS] Build fix: Fix irq flags type
++  * [MIPS] SMTC: Build fix: Fix filename in Makefile
++  * [MIPS] SMTC: Fix holes in SMTC and FPU affinity support.
++  * [MIPS] SMTC: Close tiny holes in the SMTC IPI replay system.
++  * [MIPS] SMTC: Fix SMTC dyntick support.
++  * [S390] nohz: Fix __udelay.
++  * [S390] qdio: prevent stack clobber
++  * Fix init/main.c to use regular printk with '%pF' for initcall fn
++  * x86 setup: correct segfault in generation of 32-bit reloc kernel
++  * selinux: Fix an uninitialized variable BUG/panic in selinux_secattr_to_sid()
++  * rtc: fix kernel panic on second use of SIGIO nofitication
++  * fbdev: fix recursive notifier and locking when fbdev console is blanked
++  * orion_spi: fix handling of default transfer speed
++  * include/linux/stacktrace.h: declare struct task_struct
++  * cpusets: remove pj from cpuset maintainers
++  * MAINTAINERS: add mailing list for man-pages
++  * SubmitChecklist: interfaces changes should CC linux-api@
++  * Documentation/HOWTO: info about interface changes should CC linux-api@vger
++  * dw_dmac: fix copy/paste bug in tasklet
++  * leds-fsg: change order of initialization and deinitialization
++  * leds-pca955x: add proper error handling and fix bogus memory handling
++  * ACPI: Make /proc/acpi/wakeup interface handle PCI devices (again)
++  * clockevents: check broadcast tick device not the clock events device
++  * V4L/DVB (8919): cx18: Fix tuner audio input for Compro H900 cards
++  * V4L/DVB (8926): gspca: Bad fix of leak memory (changeset 43d2ead315b1).
++  * V4L/DVB (8933): gspca: Disable light frquency for zc3xx cs2102 Kokom.
++  * V4L/DVB (8935): em28xx-cards: Remove duplicate entry (EM2800_BOARD_KWORLD_USB2800)
++  * V4L/DVB (8955): bttv: Prevent NULL pointer dereference in radio_open
++  * V4L/DVB (8957): zr36067: Restore the default pixel format
++  * V4L/DVB (8958): zr36067: Return proper bytes-per-line value
++  * V4L/DVB (8960): drivers/media/video/cafe_ccic.c needs mm.h
++  * V4L/DVB (8961): zr36067: Fix RGBR pixel format
++  * V4L/DVB (8963): s2255drv field count fix
++  * V4L/DVB (8967): Use correct XC3028L firmware for AMD ATI TV Wonder 600
++  * V4L/DVB (8978): sms1xxx: fix product name for Hauppauge WinTV MiniStick
++  * V4L/DVB (8979): sms1xxx: Add new USB product ID for Hauppauge WinTV MiniStick
++  * V4L/DVB (9029): Fix deadlock in demux code
++  * V4L/DVB (9037): Fix support for Hauppauge Nova-S SE
++  * V4L/DVB (9043): S5H1420: Fix size of shadow-array to avoid overflow
++  * V4L/DVB (9053): fix buffer overflow in uvc-video
++  * V4L/DVB (9075): gspca: Bad check of returned status in i2c_read() spca561.
++  * V4L/DVB (9080): gspca: Add a delay after writing to the sonixj sensors.
++  * V4L/DVB (9092): gspca: Bad init values for sonixj ov7660.
++  * V4L/DVB (9099): em28xx: Add detection for K-WORLD DVB-T 310U
++  * V4L/DVB (9103): em28xx: HVR-900 B3C0 - fix audio clicking issue
++  * x86: gart iommu have direct mapping when agp is present too
++  * ide-cd: temporary tray close fix
++  * ide-dma: fix ide_build_dmatable() for TRM290
++  * IDE: Fix platform device registration in Swarm IDE driver (v2)
++  * ide-cd: Optiarc DVD RW AD-7200A does play audio
++  * ide: workaround for bogus gcc warning in ide_sysfs_register_port()
++  * [MIPS] Fix CMP Kconfig configuration and mark as broken.
++  * [MIPS] IP27: Fix build errors if CONFIG_MAPPED_KERNEL=y
++  * x86 ACPI: Blacklist two HP machines with buggy BIOSes
++  * kgdb, x86: Avoid invoking kgdb_nmicallback twice per NMI
++  * kgdb: call touch_softlockup_watchdog on resume
++  * atmel-mci: Initialize BLKR before sending data transfer command
++  * Marker depmod fix core kernel list
++  * Linux 2.6.27-rc9
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 05 Oct 2008 21:27:49 -0600
++
++linux (2.6.27-5.8) intrepid; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Update AUFS-related Kconfig
++    - LP: #264048
++
++  [ Michael Haas ]
++
++  * add proper aufs source tree from 20080922
++  * Fix AUFS compilation in vfsub.c
++  * Add splice-2.6.23.patch from AUFS to export a symbol needed by AUFS
++  * Add put_filp.patch from AUFS to export a symbol needed by AUFS
++  * apply (modified) lhash.patch from AUFS to export __lookup_hash()
++  * Add deny_write_access.patch from AUFS - export deny_write_access
++  * Add sec_perm-2.6.24.patch from AUFS - export security_inode_permission
++  * make sure TMPFS_MAGIC is defined in AUFS Makefile
++
++  [ Tim Gardner ]
++
++  * Enabled CONFIG_IPWIRELESS
++    - LP: #274748
++  * Enabled CONFIG_E1000E, disabled CONFIG_E1000E_NEW
++    This takes advantage of the upstream NVM protection fix in
++    commit 4a7703582836f55a1cbad0e2c1c6ebbee3f9b3a7.
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[Bluetooth] Eliminate checks for impossible conditions in IRQ
++    handler"
++  * [SCSI] qla2xxx: Defer enablement of RISC interrupts until ISP
++    initialization completes.
++  * PCI: Fix pcie_aspm=force
++  * PCI: fix compiler warnings in pci_get_subsys()
++  * UBIFS: create the name of the background thread in every case
++  * UBIFS: TNC / GC race fixes
++  * UBIFS: remove incorrect assert
++  * UBIFS: fix printk format warnings
++  * AMD IOMMU: set iommu sunc flag after command queuing
++  * AMD IOMMU: protect completion wait loop with iommu lock
++  * sparc64: Fix disappearing PCI devices on e3500.
++  * x86, oprofile: BUG scheduling while atomic
++  * ALSA: ASoC: Fix at32-pcm build breakage with PM enabled
++  * ath9k: connectivity is lost after Group rekeying is done
++  * wireless: zd1211rw: add device ID fix wifi dongle "trust nw-3100"
++  * [IA64] Ski simulator doesn't need check_sal_cache_flush
++  * [IA64] kexec fails on systems with blocks of uncached memory
++  * ath9k: Fix IRQ nobody cared issue with ath9k
++  * [Bluetooth] Fix I/O errors on MacBooks with Broadcom chips
++  * [Bluetooth] Fix wrong URB handling of btusb driver
++  * [Bluetooth] Fix USB disconnect handling of btusb driver
++  * sparc64: Fix missing devices due to PCI bridge test in
++    of_create_pci_dev().
++  * [WATCHDOG] ibmasr: remove unnecessary spin_unlock()
++  * [WATCHDOG] wdt285: fix sparse warnings
++  * [WATCHDOG] unlocked_ioctl changes
++  * x86: fix 27-rc crash on vsmp due to paravirt during module load
++  * sched: fix init_hrtick() section mismatch warning
++  * clockevents: prevent cpu online to interfere with nohz
++  * x86: prevent stale state of c1e_mask across CPU offline/online
++  * clockevents: prevent stale tick_next_period for onlining CPUs
++  * clockevents: check broadcast device not tick device
++  * clockevents: prevent mode mismatch on cpu online
++  * x86: prevent C-states hang on AMD C1E enabled machines
++  * x86: c1e_idle: don't mark TSC unstable if CPU has invariant TSC
++  * timers: fix build error in !oneshot case
++  * ALSA: ASoC: maintainers - update email address for Liam Girdwood
++  * ibmasr: remove unnecessary spin_unlock()
++  * smb.h: do not include linux/time.h in userspace
++  * kernel-doc: allow structs whose members are all private
++  * kexec: fix segmentation fault in kimage_add_entry
++  * Documentation/DMA-mapping.txt: update for pci_dma_mapping_error()
++    changes
++  * sys_paccept: disable paccept() until API design is resolved
++  * mm: tiny-shmem fix lock ordering: mmap_sem vs i_mutex
++  * Documentation/sysctl/kernel.txt: fix softlockup_thresh description
++  * memcg: check under limit at shrink_usage
++  * atmel_serial: update the powersave handler to match serial core
++  * [SCSI] Fix hang with split requests
++  * USB Storage: Sierra: Non-configurable TRU-Install
++  * USB Serial: Sierra: Device addition & version rev
++  * USB: ehci: fix some ehci hangs and crashes
++  * USB: Fix the Nokia 6300 storage-mode.
++  * USB: Correct Sierra Wireless USB EVDO Modem Device ID
++  * USB: fix hcd interrupt disabling
++  * USB: update of Documentation/usb/anchors.txt
++  * usb gadget: fix omap_udc DMA regression
++  * USB: Fixing Nokia 3310c in storage mode
++  * usb: musb: fix include path
++  * USB: fix EHCI periodic transfers
++  * usb-serial: Add Siemens EF81 to PL-2303 hack triggers
++  * USB: SERIAL CP2101 add device IDs
++  * USB: unusual_devs addition for RockChip MP3 player
++  * USB: fsl_usb2_udc: fix VDBG() format string
++  * usb serial: ti_usb_3410_5052 obviously broken by firmware changes
++  * USB: ftdi_sio: Add 0x5050/0x0900 USB IDs (Papouch Quido USB 4/4)
++  * USB: serial: add ZTE CDMA Tech id to option driver
++  * USB Serial: Sierra: Add MC8785 VID/PID
++  * USB: drivers/usb/musb/: disable it on SuperH
++  * usb: ftdi_sio: add support for Domintell devices
++  * usb: unusual devs patch for Nokia 5310 Music Xpress
++  * USB: revert recovery from transient errors
++  * [MIPS] au1000: Fix gpio direction
++  * [MIPS] Fixe the definition of PTRS_PER_PGD
++  * x86: prevent stale state of c1e_mask across CPU offline/online, fix
++  * x86: disable apm on the olpc
++  * i2c-powermac: Fix section for probe and remove functions
++  * i2c-dev: Return correct error code on class_create() failure
++  * i2c: Fix mailing lists in two MAINTAINERS entries
++  * ath9k: disable MIB interrupts to fix interrupt storm
++  * 9p: implement proper trans module refcounting and unregistration
++  * 9p-trans_fd: fix trans_fd::p9_conn_destroy()
++  * 9p-trans_fd: clean up p9_conn_create()
++  * 9p-trans_fd: don't do fs segment mangling in p9_fd_poll()
++  * 9p-trans_fd: fix and clean up module init/exit paths
++  * 9p: introduce missing kfree
++  * 9p: use an IS_ERR test rather than a NULL test
++  * 9p: fix put_data error handling
++  * netfilter: ip6t_{hbh,dst}: Rejects not-strict mode on rule insertion
++  * MN10300: Move asm-arm/cnt32_to_63.h to include/linux/
++  * MN10300: Make sched_clock() report time since boot
++  * ALSA: fix locking in snd_pcm_open*() and snd_rawmidi_open*()
++  * ALSA: remove unneeded power_mutex lock in snd_pcm_drop
++  * IPoIB: Fix crash when path record fails after path flush
++  * [XFS] Fix extent list corruption in xfs_iext_irec_compact_full().
++  * [XFS] Remove xfs_iext_irec_compact_full()
++  * kgdb: could not write to the last of valid memory with kgdb
++  * kgdb, x86, arm, mips, powerpc: ignore user space single stepping
++  * kgdb, x86_64: gdb serial has BX and DX reversed
++  * kgdb, x86_64: fix PS CS SS registers in gdb serial
++  * kgdboc,tty: Fix tty polling search to use name correctly
++  * ARM: Delete ARM's own cnt32_to_63.h
++  * m32r: remove the unused NOHIGHMEM option
++  * m32r: don't offer CONFIG_ISA
++  * m32r: export empty_zero_page
++  * m32r: export __ndelay
++  * m32r/kernel/: cleanups
++  * [MIPS] au1000: Make sure GPIO value is zero or one
++  * [MIPS] IP27: Switch to dynamic interrupt routing avoding panic on
++    error.
++  * [MIPS] BCM47xx: Fix build error due to missing PCI functions
++  * [SSB] Initialise dma_mask for SSB_BUSTYPE_SSB devices
++  * Swarm: Fix crash due to missing initialization
++  * ide-tape: fix vendor strings
++  * ide: note that IDE generic may prevent other drivers from attaching
++  * cdrom: update ioctl documentation
++  * [SCSI] qlogicpti: fix sg list traversal error in continuation entries
++  * sata_nv: reinstate nv_hardreset() for non generic controllers
++  * scsi: fix fall out of sg-chaining patch in qlogicpti
++  * ALSA: make the CS4270 driver a new-style I2C driver
++  * ALSA: ASoC: Fix another cs4270 error path
++  * Fix NULL pointer dereference in proc_sys_compare
++  * kconfig: fix silentoldconfig
++  * kconfig: readd lost change count
++  * mm owner: fix race between swapoff and exit
++  * Linux 2.6.27-rc8
++  * e1000e: write protect ICHx NVM to prevent malicious write/erase
++
++ -- Amit Kucheria <amit.kucheria@canonical.com>  Tue, 30 Sep 2008 18:22:35 +0300
++
++linux (2.6.27-4.7) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * build/abi: Add gfs1 to perm blacklist
++  * build/abi: Ignored changes in gfs2 symbols
++
++  [ Fabio M. Di Nitto ]
++
++  * Revert "SAUCE: Export gfs2 symbols required for gfs1 kernel module"
++  * ubuntu: update GFS Cluster File System
++
++  [ Stefan Bader ]
++
++  * SAUCE: x86: Reserve FIRST_DEVICE_VECTOR in used_vectors bitmap.
++    - LP: #276334
++
++  [ Tim Gardner ]
++
++  * Revert "Disable e1000e until the NVRAM corruption problem is found."
++  * Add atl1e and atl2 to Debian installer bits
++    - LP: #273904
++  * SAUCE: e1000e: Map NV RAM dynamically only when needed.
++    - LP: #263555
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 26 Sep 2008 20:51:22 -0600
++
++linux (2.6.27-4.6) intrepid; urgency=low
++
++  [ Tim Gardner ]
++
++  * Disable e1000e until the NVRAM corruption problem is found.
++    - LP: #263555
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[Bluetooth] Eliminate checks for impossible conditions in IRQ
++    handler"
++
++ -- Ben Collins <ben.collins@canonical.com>  Tue, 23 Sep 2008 09:53:57 -0400
++
++linux (2.6.27-4.5) intrepid; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "b43/b43legacy: add RFKILL_STATE_HARD_BLOCKED support"
++  * udf: Fix lock inversion between iprune_mutex and alloc_mutex (v2)
++  * udf: Fix error paths in udf_new_inode()
++  * [SCSI] sd: select CRC_T10DIF only when necessary
++  * [SCSI] zfcp: Fix request queue locking
++  * [SCSI] zfcp: Correctly query end flag in gpn_ft response
++  * [SCSI] zfcp: Simplify ccw notify handler
++  * [SCSI] zfcp: Fix reference counter for remote ports
++  * [SCSI] zfcp: channel cannot be detached due to refcount imbalance
++  * [SCSI] zfcp: Remove duplicated unlikely() macros.
++  * [SCSI] scsi_dh: make check_sense return ADD_TO_MLQUEUE
++  * [SCSI] make scsi_check_sense HARDWARE_ERROR return ADD_TO_MLQUEUE on
++    retry
++  * [SCSI] fix check of PQ and PDT bits for WLUNs
++  * pcm037: add rts/cts support for serial port
++  * i.MX serial: fix init failure
++  * imx serial: set RXD mux bit on i.MX27 and i.MX31
++  * imx serial: fix rts handling for non imx1 based hardware
++  * mlx4_core: Set RAE and init mtt_sz field in FRMR MPT entries
++  * udf: add llseek method
++  * PCI/iommu: blacklist DMAR on Intel G31/G33 chipsets
++  * PCI: Fix printk warnings in probe.c
++  * PCI: Fix printk warnings in setup-bus.c
++  * PCI Hotplug: fakephp: fix deadlock... again
++  * clockevents: remove WARN_ON which was used to gather information
++  * ocfs2: Fix a bug in direct IO read.
++  * arch/x86/kernel/kdebugfs.c: introduce missing kfree
++  * [IA64] fix compile failure with non modular builds
++  * [IA64] fix up bte.h
++  * [IA64] arch/ia64/sn/pci/tioca_provider.c: introduce missing kfree
++  * PCI: fix pciehp_free_irq()
++  * [IA64] prevent ia64 from invoking irq handlers on offline CPUs
++  * ide: Fix pointer arithmetic in hpt3xx driver code (3rd try)
++  * add deprecated ide-scsi to feature-removal-schedule.txt
++  * swiotlb: fix back-off path when memory allocation fails
++  * sparc64: Fix interrupt register calculations on Psycho and Sabre.
++  * VIDEO_SH_MOBILE_CEU should depend on HAS_DMA
++  * m68k: Update defconfigs for 2.6.27-rc6
++  * sparc32: Fix function signature of of_bus_sbus_get_flags().
++  * sched: fix 2.6.27-rc5 couldn't boot on tulsa machine randomly
++  * sched: fix deadlock in setting scheduler parameter to zero
++  * KVM: SVM: fix random segfaults with NPT enabled
++  * KVM: SVM: fix guest global tlb flushes with NPT
++  * KVM: VMX: Always return old for clear_flush_young() when using EPT
++  * clocksource, acpi_pm.c: fix check for monotonicity
++  * [ARM] OMAP: Fix MMC device data
++  * block: disable sysfs parts of the disk command filter
++  * ath9k: Assign seq# when mac80211 requests this
++  * sg: disable interrupts inside sg_copy_buffer
++  * MN10300: Change the fault handler to check in_atomic() not
++    in_interrupt()
++  * [Bluetooth] Fix regression from using default link policy
++  * netlink: fix overrun in attribute iteration
++  * x86: fix possible x86_64 and EFI regression
++  * sparc64: Fix PCI error interrupt registry on PSYCHO.
++  * sparc: Fix user_regset 'n' field values.
++  * niu: panic on reset
++  * PCI: re-add debug prints for unmodified BARs
++  * [ARM] 5245/1: Fix warning about unused return value in drivers/pcmcia
++  * [ARM] 5246/1: tosa: add proper clock alias for tc6393xb clock
++  * [ARM] 5247/1: tosa: SW_EAR_IN support
++  * [ARM] Fix PCI_DMA_BUS_IS_PHYS for ARM
++  * ata: duplicate variable sparse warning
++  * sata_inic162x: enable LED blinking
++  * [libata] LBA28/LBA48 off-by-one bug in ata.h
++  * proc: more debugging for "already registered" case
++  * include/linux/ioport.h: add missing macro argument for devm_release_*
++    family
++  * cpuset: avoid changing cpuset's cpus when -errno returned
++  * cpuset: hotplug documentation fix
++  * coredump_filter: add description of bit 4
++  * bfs: fix Lockdep warning
++  * mm: ifdef Quicklists in /proc/meminfo
++  * spi_mpc83xx: fix clockrate calculation for low speed
++  * spi_mpc83xx: reject invalid transfer sizes
++  * pxa2xx_spi: chipselect bugfixes
++  * pxa2xx_spi: dma bugfixes
++  * mm: mark the correct zone as full when scanning zonelists
++  * Documentation/ABI: /sys/class/gpio
++  * MAINTAINERS: fix USB VIDEO CLASS mail list address
++  * ia64: fix panic during `modprobe -r xpc'
++  * atmel_lcdfb: disable LCD and DMA engines when suspending
++  * spi_s3c24xx: fix section warning
++  * rescan_partitions(): make device capacity errors non-fatal
++  * memstick: fix MSProHG 8-bit interface mode support
++  * Add Uwe Kleine-König to .mailmap
++  * xen: fix for xen guest with mem > 3.7G
++  * x86/paravirt: Remove duplicate paravirt_pagetable_setup_{start, done}()
++  * crypto: talitos - Avoid consecutive packets going out with same IV
++  * slub: fixed uninitialized counter in struct kmem_cache_node
++  * udp: Fix rcv socket locking
++  * IB/mlx4: Fix up fast register page list format
++  * [MIPS] VR41xx: unsigned irq cannot be negative
++  * x86: completely disable NOPL on 32 bits
++  * [S390] cio: Fix driver_data handling for ccwgroup devices.
++  * [S390] cio: fix orb initialization in cio_start_key
++  * sparc64: Fix OOPS in psycho_pcierr_intr_other().
++  * sparc64: Fix SMP bootup with CONFIG_STACK_DEBUG or ftrace.
++  * RDMA/nes: Fix client side QP destroy
++  * IPoIB: Fix deadlock on RTNL between bcast join comp and ipoib_stop()
++  * clockevents: make device shutdown robust
++  * powerpc: Fix interrupt values for DMA2 in MPC8610 HPCD device tree
++  * hpplus: fix build regression
++  * Fix PNP build failure, bugzilla #11276
++  * warn: Turn the netdev timeout WARN_ON() into a WARN()
++  * [XFS] Move memory allocations for log tracing out of the critical path
++  * [XFS] Fix regression introduced by remount fixup
++  * [XFS] Prevent direct I/O from mapping extents beyond eof
++  * [XFS] Fix barrier status change detection.
++  * [XFS] Prevent lockdep false positives when locking two inodes.
++  * [XFS] Fix use-after-free with buffers
++  * [XFS] Don't do I/O beyond eof when unreserving space
++  * powerpc: Holly board needs dtbImage target
++  * Fix compile failure with non modular builds
++  * [ARM] 5249/1: davinci: remove redundant check in davinci_psc_config()
++  * [ARM] omap: back out 'internal_clock' support
++  * sctp: set the skb->ip_summed correctly when sending over loopback.
++  * [ARM] 5255/1: Update jornada ssp to remove build errors/warnings
++  * sctp: do not enable peer features if we can't do them.
++  * sctp: Fix oops when INIT-ACK indicates that peer doesn't support AUTH
++  * bnx2: Promote vector field in bnx2_irq structure from u16 to unsigned
++    int
++  * forcedeth: call restore mac addr in nv_shutdown path
++  * e1000: prevent corruption of EEPROM/NVM
++  * e100: Use pci_pme_active to clear PME_Status and disable PME#
++  * md: Don't wait UNINTERRUPTIBLE for other resync to finish
++  * atstk1000: fix build breakage with BOARD_ATSTK100X_SW2_CUSTOM=y
++  * avr32: add .gitignore files
++  * avr32: add generic_find_next_le_bit bit function
++  * avr32: fix sys_sync_file_range() call convention
++  * avr32: nmi_enter() without nmi_exit()
++  * KVM: ia64: 'struct fdesc' build fix
++  * hwmon: (atxp1) Fix device detection logic
++  * hwmon: (it87) Fix fan tachometer reading in IT8712F rev 0x7 (I)
++  * hwmon: (ad7414) Make ad7414_update_device() static
++  * tmio_mmc: fix compilation with debug enabled
++  * atmel-mci: debugfs: enable clock before dumping regs
++  * atmel-mci: Fix memory leak in atmci_regs_show
++  * atmel-mci: Fix bogus debugfs file size
++  * atmel-mci: Set MMC_CAP_NEEDS_POLL if no detect_pin
++  * mmc_block: handle error from mmc_register_driver()
++  * mmc_test: initialize mmc_test_lock statically
++  * [MIPS] Fix 64-bit IP checksum code
++  * [MIPS] SMTC: Clear TIF_FPUBOUND on clone / fork.
++  * [MIPS] Fix potential latency problem due to non-atomic cpu_wait.
++  * [MIPS] vmlinux.lds.S: handle .text.*
++  * MAINTAINERS: Trivial whitespace cleanups
++  * MAINTAINERS: Various fixes
++  * Linux 2.6.27-rc7
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 21 Sep 2008 21:49:28 -0600
++
++linux (2.6.27-3.4) intrepid; urgency=low
++
++  [ Colin Ian King ]
++
++  * SAUCE: fix kernel oops in VirtualBox during paravirt patching
++    - LP: #246067
++  * SAUCE: qc-usb: Enable Logitech QuickCam Messenger
++    - LP: #209901
++  * SAUCE: appleir: Enable driver for new MacBook Pro
++    - LP: #157919
++
++  [ Tim Gardner ]
++
++  * Enabled CONFIG_DEBUG_RODATA=y
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "ALSA: hda - Added model selection for iMac 24""
++  * Revert "x86: fix HPET regression in 2.6.26 versus 2.6.25, check hpet
++    against BAR, v3"
++  * Revert "[ARM] use the new byteorder headers"
++  * Revert "mac80211: Use IWEVASSOCREQIE instead of IWEVCUSTOM"
++  * Revert "crypto: camellia - Use kernel-provided bitops, unaligned access
++    helpers"
++  * svcrdma: Fix race between svc_rdma_recvfrom thread and the dto_tasklet
++  * sched, cpuset: rework sched domains and CPU hotplug handling (v4)
++  * ACPI: Fix now signed module parameter.
++  * ACPI: Change package length error to warning
++  * ACPI: Fix now signed module parameter.
++  * ACPI: Fix typo in "Disable MWAIT via DMI on broken Compal board"
++  * acpi: add checking for NULL early param
++  * UBIFS: fix zero-length truncations
++  * Input: bcm5974 - add maintainer entry
++  * sh64: re-add the __strnlen_user() prototype
++  * sh: fix ptrace_64.c:user_disable_single_step()
++  * PNPACPI: ignore the producer/consumer bit for extended IRQ descriptors
++  * UBIFS: always read hashed-key nodes under TNC mutex
++  * UBIFS: allow for racing between GC and TNC
++  * [CIFS] Fix plaintext authentication
++  * sparc32: Implement smp_call_function_single().
++  * sh: crash kernel resource fix
++  * sh: fix kexec entry point for crash kernels
++  * sh: fix platform_resource_setup_memory() section mismatch
++  * sh: update Migo-R defconfig
++  * sh: update AP325RXA defconfig
++  * sh: fix semtimedop syscall
++  * cifs: fix O_APPEND on directio mounts
++  * [CIFS] update cifs change log
++  * [CIFS] Turn off Unicode during session establishment for plaintext
++    authentication
++  * ACPI: thinkpad-acpi: wan radio control is not experimental
++  * sparc: Fix resource flags for PCI children in OF device tree.
++  * remove blk_register_filter and blk_unregister_filter in gendisk
++  * ALSA: oxygen: fix distorted output on AK4396-based cards
++  * ipv6: When we droped a packet, we should return NET_RX_DROP instead of
++    0
++  * pkt_sched: Fix locking of qdisc_root with qdisc_root_sleeping_lock()
++  * net: Unbreak userspace usage of linux/mroute.h
++  * Don't trigger softlockup detector on network fs blocked tasks
++  * Resource handling: add 'insert_resource_expand_to_fit()' function
++  * sparc64: setup_valid_addr_bitmap_from_pavail() should be __init
++  * UBIFS: do not update min_idx_lebs in stafs
++  * UBIFS: push empty flash hack down
++  * UBIFS: remove incorrect index space check
++  * UBIFS: improve statfs reporting
++  * UBIFS: fix assertion
++  * UBIFS: add forgotten gc_idx_lebs component
++  * UBIFS: introduce LEB overhead
++  * UBIFS: improve statfs reporting even more
++  * UBIFS: fill f_fsid
++  * drm/radeon: downgrade debug message from info to debug.
++  * Remove invalidate_partition call from do_md_stop.
++  * Fix problem with waiting while holding rcu read lock in md/bitmap.c
++  * ALSA: hda: Distortion fix for dell_m6_core_init
++  * ALSA: ASoC: fix pxa2xx-i2s clk_get call
++  * block: restore original behavior of /proc/partition when there's no
++    partition
++  * debugobjects: fix lockdep warning
++  * avr32: Fix lockup after Java stack underflow in user mode
++  * avr32: pm_standby low-power ram bug fix
++  * nfsd: fix compound state allocation error handling
++  * sunrpc: fix possible overrun on read of /proc/sys/sunrpc/transports
++  * nfsd: fix buffer overrun decoding NFSv4 acl
++  * audit: Moved variable declaration to beginning of function
++  * Fix modules_install on RO nfs-exported trees.
++  * Remove '#include <stddef.h>' from mm/page_isolation.c
++  * dabusb_fpga_download(): fix a memory leak
++  * [MTD] mtdchar.c: Fix regression in MEMGETREGIONINFO ioctl()
++  * ALSA: hda - Fix ALC663 auto-probe
++  * ALSA: hda - Add mic-boost controls to ALC662/663 auto configuration
++  * Un-break printk strings in x86 PCI probing code
++  * kernel/resource.c: fix new kernel-doc warning
++  * softlockup: minor cleanup, don't check task->state twice
++  * fix typo in arch/parisc/hpux/fs.c
++  * m68k: atari_keyb_init operator precedence fix
++  * ACPI: Fix typo in "Disable MWAIT via DMI on broken Compal board"
++  * don't diff generated firmware files
++  * IDE: compile fix for sff_dma_ops
++  * IDE: palm_bk3710: fix compile warning for unused variable
++  * ide: fix hwif_to_node()
++  * palm_bk3710: improve IDE registration
++  * ide-disk: remove stale init_idedisk_capacity() documentation
++  * ide/Kconfig: mark ide-scsi as deprecated
++  * net/wireless/Kconfig: clarify the description for
++    CONFIG_WIRELESS_EXT_SYSFS
++  * iwlwifi: do not use GFP_DMA in iwl_tx_queue_init
++  * iwlwifi: workaround interrupt handling no some platforms
++  * iwlwifi: fix apm_stop (wrong bit polarity for FLAG_INIT_DONE)
++  * iwlwifi: fix 64bit platform firmware loading
++  * orinoco: Multicast to the specified addresses
++  * wireless/libertas/if_cs.c: fix memory leaks
++  * mac80211: Fix debugfs union misuse and pointer corruption
++  * rt2x00: Compiler warning unmasked by fix of BUILD_BUG_ON
++  * ath9k: Incorrect key used when group and pairwise ciphers are
++    different.
++  * ath9: Fix ath_rx_flush_tid() for IRQs disabled kernel warning message.
++  * net/xfrm: Use an IS_ERR test rather than a NULL test
++  * ipv: Re-enable IP when MTU > 68
++  * NTFS: update homepage
++  * mm: make setup_zone_migrate_reserve() aware of overlapping nodes
++  * VFS: fix dio write returning EIO when try_to_release_page fails
++  * acer-wmi: remove debugfs entries upon unloading
++  * mm/bootmem: silence section mismatch warning -
++    contig_page_data/bootmem_node_data
++  * MAINTAINERS: add a maintainer for the BCM5974 multitouch driver
++  * 8250: improve workaround for UARTs that don't re-assert THRE correctly
++  * mmc: at91_mci: don't use coherent dma buffers
++  * pid_ns: zap_pid_ns_processes: fix the ->child_reaper changing
++  * pid_ns: (BUG 11391) change ->child_reaper when init->group_leader exits
++  * cirrusfb: check_par fixes
++  * devcgroup: fix race against rmdir()
++  * mm: show quicklist usage in /proc/meminfo
++  * mm: size of quicklists shouldn't be proportional to the number of CPUs
++  * ipc: document the new auto_msgmni proc file
++  * hp-wmi: update to match current rfkill semantics
++  * hp-wmi: add proper hotkey support
++  * tdfxfb: fix SDRAM memory size detection
++  * tdfxfb: fix frame buffer name overrun
++  * rtc_time_to_tm: fix signed/unsigned arithmetic
++  * ibft: fix target info parsing in ibft module
++  * sysfs: document files in /sys/firmware/sgi_uv/
++  * rtc-cmos: wake again from S5
++  * pm_qos_requirement might sleep
++  * drivers/char/random.c: fix a race which can lead to a bogus BUG()
++  * ipsec: Fix deadlock in xfrm_state management.
++  * [x86] Fix TSC calibration issues
++  * tipc: Don't use structure names which easily globally conflict.
++  * sparc64: Fix IPI call locking.
++  * [ARM] omap: fix gpio.c build error
++  * sparc64: Prevent sparc64 from invoking irq handlers on offline CPUs
++  * powerpc: Fix uninitialised variable in VSX alignment code
++  * powerpc: Only make kernel text pages of linear mapping executable
++  * powerpc: Make sure _etext is after all kernel text
++  * powerpc: Work around gcc's -fno-omit-frame-pointer bug
++  * powerpc: Fix build error with 64K pages and !hugetlbfs
++  * powerpc: Fix for getting CPU number in power_save_ppc32_restore()
++  * UBIFS: amend f_fsid
++  * net/usb/pegasus: avoid hundreds of diagnostics
++  * ixgbe: initialize interrupt throttle rate
++  * pcnet-cs, axnet_cs: add new IDs, remove dup ID with less info
++  * netxen: Remove workaround for chipset quirk
++  * Split up PIT part of TSC calibration from native_calibrate_tsc
++  * iwlwifi: W/A for the TSF correction in IBSS
++  * iwlwifi: fix hidden ssid discovery in passive channels
++  * iwlwifi: remove false rxon if rx chain changes
++  * iwlwifi: fix station mimo power save values
++  * iwlwifi: fix rx_chain computation
++  * iwlwifi: fix Tx cmd memory allocation failure handling
++  * iwlwifi: call apm stop on exit
++  * iwlwifi: fix STATUS_EXIT_PENDING is not set on pci_remove
++  * ath9k: Fix TX status reporting
++  * ath9k: Fix TX control flag use for no ACK and RTS/CTS
++  * V4L/DVB (8555): au8522: add mechanism to configure IF frequency for vsb
++    and qam
++  * V4L/DVB (8556): au0828: add support for Hauppauge Woodbury
++  * V4L/DVB (8598): au8522: clean up function au8522_set_if
++  * V4L/DVB (8599): au8522: remove if frequency settings from vsb/qam
++    modulation tables
++  * V4L/DVB (8600): au0828: explicitly set 6 MHz IF frequency in
++    hauppauge_hvr950q_config
++  * V4L/DVB (8629): v4l2-ioctl: do not try to handle private V4L1 ioctls
++  * V4L/DVB (8633): ivtv: update ivtv version number
++  * V4L/DVB (8648): ivtv: improve CC support
++  * V4L/DVB (8660): gspca: Simplify the scan of URB packets in pac7311.
++  * V4L/DVB (8661): gspca: Bug in the previous changeset about pac7311.
++  * V4L/DVB (8663): gspca: Webcam 0c45:6128 added in sonixj.
++  * V4L/DVB (8664): gspca: The bridge/sensor of the webcam 093a:2621 is a
++    PAC 7302.
++  * V4L/DVB (8665): gspca: Fix the 640x480 resolution of the webcam
++    093a:2621.
++  * V4L/DVB (8666): gspca: Bad scanning of frames in pac7311.
++  * V4L/DVB (8667): gspca: Bad probe of Z-Star/Vimicro webcams with pas106
++    sensor.
++  * V4L/DVB (8668): gspca: Conflict GSPCA / ET61X251 for the webcam
++    102c:6251.
++  * V4L/DVB (8669): gspca: Add white balance control for spca561 rev 012A.
++  * V4L/DVB (8671): gspca: Remove the unused field 'dev_name' of the device
++    structure.
++  * V4L/DVB (8672): gspca: Big rewrite of spca561.
++  * V4L/DVB (8673): gspca: Bad frame scanning again and bad init in
++    pac7311.
++  * V4L/DVB (8674): gspca: Webcam 0c45:612e added in sonixj.
++  * V4L/DVB (8675): gspca: Pixmap PJPG (Pixart 73xx JPEG) added, generated
++    by pac7311.
++  * V4L/DVB (8678): Remove the dead CONFIG_RADIO_MIROPCM20{,_RDS} code
++  * V4L/DVB (8681): v4l2-ioctl.c: fix warning
++  * V4L/DVB (8682): V4L: fix return value of register video func
++  * V4L/DVB (8701): cx18: Add missing lock for when the irq handler
++    manipulates the queues
++  * V4L/DVB (8703): gspca: Do controls work for spca561 revision 12a.
++  * V4L/DVB (8705): gspca: Adjust some control limits in spca561.
++  * V4L/DVB (8706): Make contrast and brightness work for pac7302.
++  * V4L/DVB (8707): gspca: Colors, hflip and vflip controls added for
++    pac7302.
++  * V4L/DVB (8709): gspca: Fix initialization and controls of sn9x110 -
++    ov7630.
++  * V4L/DVB (8710): gspca: Bad color control in sonixj.
++  * V4L/DVB (8711): gspca: Bad controls and quantization table of pac7311.
++  * V4L/DVB (8712): gspca: Bad start of sonixj webcams since changeset
++    a8779025e7e8.
++  * V4L/DVB (8713): gspca: Bad color control again in sonixj.
++  * V4L/DVB (8714): gspca: Bad start of sn9c110 and sensor om6802.
++  * V4L/DVB (8715): gspca: Change the name of some webcam in the gspca doc.
++  * V4L/DVB (8716): gspca: Bad start of sn9c110 and sensor ov7630.
++  * V4L/DVB (8717): gspca: Frame buffer too small for small resolutions
++    (sonixj and t613).
++  * V4L/DVB (8718): gspca: suspend/resume added.
++  * V4L/DVB (8719): gspca: Have VIDIOC_QUERYCTRL more compliant to the
++    spec.
++  * V4L/DVB (8720): gspca: V4L2_CAP_SENSOR_UPSIDE_DOWN added as a cap for
++    some webcams.
++  * V4L/DVB (8722): sms1xxx: fix typo in license header
++  * V4L/DVB (8726): link tuner before saa7134
++  * V4L/DVB (8727): V4L1: make PMS not autoprobe when builtin.
++  * V4L/DVB (8728): 1-make-pms-not-autoprobe-when-builtin update
++  * V4L/DVB (8749): Fix error code, when camera is not turned on by sonypi
++  * V4L/DVB (8750): V4L: check inval in video_register_device_index()
++  * V4L/DVB (8751): vivi: Fix some issues at vivi register routine
++  * V4L/DVB (8757): v4l-dvb: fix a bunch of sparse warnings
++  * V4L/DVB (8769): cx18: Simplify queue flush logic to prevent oops in
++    cx18_flush_queues()
++  * V4L/DVB (8778): radio: fix incorrect video_register_device result check
++  * V4L/DVB (8779): v4l: fix more incorrect video_register_device result
++    checks
++  * V4L/DVB (8790): saa7115: call i2c_set_clientdata only when state !=
++    NULL
++  * V4L/DVB (8803): s5h1409: Enable QAM_AUTO mode
++  * V4L/DVB (8804): s5h1411: Enable QAM_AUTO mode
++  * V4L/DVB (8805): Steven Toth email address change
++  * V4L/DVB (8809): gspca: Revert commit
++    9a9335776548d01525141c6e8f0c12e86bbde982
++  * V4L/DVB (8810): gspca: Compile error when CONFIG_PM not defined.
++  * V4L/DVB (8812): gspca: Do pac73xx webcams work.
++  * V4L/DVB (8813): gspca: Adjust SOF detection for pac73xx.
++  * V4L/DVB (8814): gspca: Set DISABLED the disabled controls at query
++    control time.
++  * V4L/DVB (8815): gspca: Fix problems with disabled controls.
++  * V4L/DVB (8816): gspca: Set disabled ctrls and fix a register pb with
++    ovxxxx in sonixb.
++  * V4L/DVB (8817): gspca: LED and proble changes in sonixb.
++  * V4L/DVB (8818): gspca: Reinitialize the device on resume.
++  * V4L/DVB (8819): gspca: Initialize the ov519 at open time and source
++    cleanup.
++  * V4L/DVB (8820): gspca: Change initialization and gamma of zc3xx -
++    pas106.
++  * V4L/DVB (8822): gspca: Change some subdriver functions for
++    suspend/resume.
++  * V4L/DVB (8823): gspca: H and V flips work for ov7670 only in ov519.
++  * V4L/DVB (8824): gspca: Too much code removed in the suspend/resume
++    changeset.
++  * V4L/DVB (8825): gspca: More controls for pac73xx and new webcam
++    093a:2624.
++  * V4L/DVB (8826): gspca: Webcam Labtec 2200 (093a:2626) added in pac7311.
++  * V4L/DVB (8827): gspca: Stop pac7302 autogain oscillation.
++  * V4L/DVB (8828): gspca: Set the clock at the end of initialization in
++    sonixj.
++  * V4L/DVB (8829): gspca: Have a clean kmalloc-ated buffer for USB
++    exchanges.
++  * V4L/DVB (8830): gspca: Move some probe code to the new init function.
++  * V4L/DVB (8831): gspca: Resolve webcam conflicts between some drivers.
++  * V4L/DVB (8832): gspca: Bad pixelformat of vc0321 webcams.
++  * V4L/DVB (8833): gspca: Cleanup the sonixb code.
++  * V4L/DVB (8834): gspca: Have a bigger buffer for sn9c10x compressed
++    images.
++  * V4L/DVB (8835): gspca: Same pixfmt as the sn9c102 driver and raw Bayer
++    added in sonixb.
++  * V4L/DVB (8837): dvb: fix I2C adapters name size
++  * V4L/DVB (8839): dib0700: add comment to identify 35th USB id pair
++  * V4L/DVB (8840): dib0700: add basic support for Hauppauge Nova-TD-500
++    (84xxx)
++  * V4L/DVB (8842): vivi_release(): fix use-after-free
++  * V4L/DVB (8843): tda10048_firmware_upload(): fix a memory leak
++  * V4L/DVB (8844): dabusb_fpga_download(): fix a memory leak
++  * bnx2x: Accessing un-mapped page
++  * SELinux: memory leak in security_context_to_sid_core
++  * x86: add io delay quirk for Presario F700
++  * mmap: fix petty bug in anonymous shared mmap offset handling
++  * x86: Change warning message in TSC calibration.
++  * PCI: fix pbus_size_mem() resource alignment for CardBus controllers
++  * [ARM] omap: fix build error in ohci-omap.c
++  * [ARM] remove unused #include <version.h>
++  * ACPI: Make Len Brown the ACPI maintainer again
++  * fujitsu-laptop: fix regression for P8010 in 2.6.27-rc
++  * ACPI: Avoid bogus timeout about SMbus check
++  * acer-wmi: remove debugfs entries upon unloading
++  * forgotten refcount on sysctl root table
++  * V4L/DVB (8868): gspca: Support for vga modes with sif sensors in
++    sonixb.
++  * V4L/DVB (8869): gspca: Move the Sonix webcams with TAS5110C1B from
++    sn9c102 to gspca.
++  * V4L/DVB (8870): gspca: Fix dark room problem with sonixb.
++  * V4L/DVB (8872): gspca: Bad image format and offset with rev072a of
++    spca561.
++  * V4L/DVB (8873): gspca: Bad image offset with rev012a of spca561 and
++    adjust exposure.
++  * V4L/DVB (8874): gspca: Adjust hstart for sn9c103/ov7630 and update
++    usb-id's.
++  * [ARM] omap: fix virtual vs physical address space confusions
++  * V4L/DVB (8876): budget: udelay changed to mdelay
++  * V4L/DVB (8877): b2c2 and bt8xx: udelay to mdelay
++  * V4L/DVB (8880): PATCH: Fix parents on some webcam drivers
++  * V4L/DVB (8881): gspca: After 'while (retry--) {...}', retry will be -1
++    but not 0.
++  * powerpc/spufs: Fix multiple get_spu_context()
++  * powerpc/spufs: Fix race for a free SPU
++  * Input: bcm5974 - small formatting cleanup
++  * Input: bcm5974 - improve finger tracking and counting
++  * Input: bcm5974 - add BTN_TOUCH event for mousedev benefit
++  * Input: i8042 - make Lenovo 3000 N100 blacklist entry more specific
++  * sh: resume_kernel fix for kernel oops built with CONFIG_BKL_PREEMPT=y.
++  * sh64: resume_kernel fix for kernel oops built with
++    CONFIG_BKL_PREEMPT=y.
++  * i2c: fix i2c-sh_mobile timing issues
++  * clockevents: prevent clockevent event_handler ending up handler_noop
++  * clockevents: prevent endless loop in periodic broadcast handler
++  * clockevents: enforce reprogram in oneshot setup
++  * clockevents: prevent multiple init/shutdown
++  * clockevents: prevent endless loop lockup
++  * HPET: make minimum reprogramming delta useful
++  * [MTD] [NAND] tmio_nand: fix base address programming
++  * Fix conditional export of kvh.h and a.out.h to userspace.
++  * async_tx: fix the bug in async_tx_run_dependencies
++  * sched_clock: fix NOHZ interaction
++  * sched: fix process time monotonicity
++  * UBIFS: fix division by zero
++  * UBIFS: make minimum fanout 3
++  * [MIPS] Fix data bus error recovery
++  * [MIPS] Fix WARNING: at kernel/smp.c:290
++  * [MIPS] TXx9: Fix txx9_pcode initialization
++  * [MIPS] TX39xx: Add missing local_flush_icache_range initialization
++  * [MIPS] Probe initrd header only if explicitly specified
++  * res_counter: fix off-by-one bug in setting limit
++  * forcedeth: fix kexec regression
++  * atmel_lcdfb: fix oops in rmmod when framebuffer fails to register
++  * tracehook: comment pasto fixes
++  * drivers/mmc/card/block.c: fix refcount leak in mmc_block_open()
++  * x86: boot: stub out unimplemented CPU feature words
++  * x86: add NOPL as a synthetic CPU feature bit
++  * x86: use X86_FEATURE_NOPL in alternatives
++  * clockevents: broadcast fixup possible waiters
++  * x86: HPET fix moronic 32/64bit thinko
++  * x86: HPET: read back compare register before reading counter
++  * Fix CONFIG_AC97_BUS dependency
++  * [ARM] 5241/1: provide ioremap_wc()
++  * ntp: fix calculation of the next jiffie to trigger RTC sync
++  * clocksource, acpi_pm.c: use proper read function also in errata mode
++  * clocksource, acpi_pm.c: check for monotonicity
++  * x86: delay early cpu initialization until cpuid is done
++  * x86: move mtrr cpu cap setting early in early_init_xxxx
++  * sched: arch_reinit_sched_domains() must destroy domains to force
++    rebuild
++  * x86, xen: Use native_pte_flags instead of native_pte_val for .pte_flags
++  * x86: pda_init(): fix memory leak when using CPU hotplug
++  * x86: cpu_init(): fix memory leak when using CPU hotplug
++  * powerpc/spufs: Fix possible scheduling of a context to multiple SPEs
++  * netfilter: nf_conntrack_sip: de-static helper pointers
++  * netfilter: nf_conntrack_gre: more locking around keymap list
++  * netfilter: nf_conntrack_gre: nf_ct_gre_keymap_flush() fixlet
++  * netfilter: nf_conntrack_irc: make sure string is terminated before
++    calling simple_strtoul
++  * pkt_sched: Fix qdisc state in net_tx_action()
++  * powerpc: Fix rare boot build breakage
++  * ahci, pata_marvell: play nicely together
++  * sata_mv: add RocketRaid 1720 PCI ID to driver
++  * ahci: disable PMP for marvell ahcis
++  * sata_nv: disable hardreset for generic
++  * libata-sff: kill spurious WARN_ON() in ata_hsm_move()
++  * pata_sil680: remove duplicate pcim_enable_device
++  * ahci: RAID mode SATA patch for Intel Ibex Peak DeviceIDs
++  * [MIPS] IP22: Fix detection of second HPC3 on Challenge S
++  * xen: fix 2.6.27-rc5 xen balloon driver warnings
++  * x86: disable static NOPLs on 32 bits
++  * netns : fix kernel panic in timewait socket destruction
++  * bridge: don't allow setting hello time to zero
++  * NFS: Restore missing hunk in NFS mount option parser
++  * usb: fix null deferences in low level usb serial
++  * Fix format of MAINTAINERS
++  * sparc64: Disable timer interrupts in fixup_irqs().
++  * [Bluetooth] Fix reference counting during ACL config stage
++  * [Bluetooth] Enforce correct authentication requirements
++  * [Bluetooth] Reject L2CAP connections on an insecure ACL link
++  * [S390] CVE-2008-1514: prevent ptrace padding area read/write in 31-bit
++    mode
++  * [S390] cio: Correct cleanup on error.
++  * [S390] cio: handle ssch() return codes correctly.
++  * [S390] cio: allow offline processing for disconnected devices
++  * ipsec: Restore larval states and socket policies in dump
++  * update Documentation/filesystems/Locking for 2.6.27 changes
++  * MAINTAINERS: add Atheros maintainer for atlx
++  * lib: Correct printk %pF to work on all architectures
++  * x86: fix memmap=exactmap boot argument
++  * clockevents: remove WARN_ON which was used to gather information
++  * ipv6: Fix OOPS in ip6_dst_lookup_tail().
++  * Linux 2.6.27-rc6
++
++ -- Ben Collins <ben.collins@canonical.com>  Tue, 02 Sep 2008 12:45:56 -0400
++
++linux (2.6.27-2.3) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * build/retag: Make script save .orig of tags for later use
++  * ubuntu/lirc: Fix device_create call
++  * build/firmware: Put in-kernel firmware into version specific subdir
++    - LP: #262115
++  * Rebase on linux-2.6 git.
++  * ABI bump
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * SAUCE: (no-up) Apparmor warning fixes
++
++  [ John Johansen ]
++
++  * SAUCE: (no-up) Proper AppArmor ptrace updates for newer lsm API
++
++  [ Mackenzie Morgan ]
++
++  * SAUCE: Add quirk for ASUS Z37E to make sound audible after resume
++    - LP: #25896
++
++ -- Ben Collins <ben.collins@canonical.com>  Wed, 27 Aug 2008 14:03:05 -0400
++
++linux (2.6.27-1.2) intrepid; urgency=low
++
++  [ Amit Kucheria ]
++
++  * SAUCE: make fc transport removal of target configurable
++  * SAUCE: pm: Config option to disable handling of console during
++    suspend/resume
++
++  [ Ben Collins ]
++
++  * SAUCE: Lower warning level of some PCI messages
++  * SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps
++  * SAUCE: tulip: Let dmfe handle davicom on non-sparc
++  * SAUCE: tulip: Define ULI PCI ID's
++  * SAUCE: (no-up) version: Implement version_signature proc file.
++  * SAUCE: (no-up) connector.h: Add idx/val for drbd
++  * SAUCE: (no-up) swap: Add notify_swap_entry_free callback for compcache
++  * SAUCE: drivers: Remove some duplicate device entries in various modules
++  * SAUCE: (no-up) [AppArmor] merge with upstream subversion r1291
++  * SAUCE: apparmor: Update for changes to ptrace lsm hooks
++  * SAUCE: (no-up) Enable ubuntu extra subdirectory
++  * SAUCE: applesmc: Add MacBookAir
++  * SAUCE: (no-up) ACPI: initramfs DSDT override support
++  * ubuntu: Add drbd module
++  * ubuntu: Add iscsitarget module
++  * ubuntu: Add BOM for iscsitarget
++  * ubuntu: Add squashfs driver
++  * SAUCE: (no-up) Check for squashfs superblock in initramfs mounting.
++  * ubuntu: Add aufs module
++  * ubuntu: Added atl2 driver
++  * ubuntu: Added et131x driver
++  * ubuntu: Add dm-raid4-5 driver
++  * ubuntu: Add ndiswrapper driver
++  * ubuntu: Added ram backed compressed swap module (compcache)
++  * ubuntu: Add misc drivers from hardy lum
++  * ubuntu: Add heci driver 3.2.0.24
++  * ubuntu: Add ov511 and bt-sco drivers
++  * ubuntu: Add acx, prism2_usb wireless drivers
++  * ubuntu: Add at76 driver to build
++  * ubuntu: Add fsam7400 sw kill switch driver
++  * ubuntu: Added qc-usb driver
++  * ubuntu: e1000e: Upgraded module to 0.4.1.7
++  * ubuntu: Added rfkill drivers
++  * ubuntu: VIA - Add VIA DRM Chrome9 3D engine
++  * ubuntu: unionfs: Added v1.4 module from hardy
++  * ubuntu: Add LIRC driver
++  * ubuntu: Add GFS driver
++  * ubuntu: New tlsup driver for toshiba laptops
++  * Update config files
++  * build/d-i: Remove obsolete dm modules
++
++  [ Chuck Short ]
++
++  * SAUCE: ata: blacklist FUJITSU MHW2160BH PL
++
++  [ Colin Ian King ]
++
++  * ubuntu: Add dm-loop
++  * SAUCE: Enable speedstep for sonoma processors.
++
++  [ Dennis Noordsij ]
++
++  * SAUCE: Work around ACPI corruption upon suspend on some Dell machines.
++
++  [ Fabio M. Di Nitto ]
++
++  * SAUCE: Export gfs2 symbols required for gfs1 kernel module
++
++  [ Matthew Garrett ]
++
++  * SAUCE: hostap: send events on data interface as well as master
++    interface
++
++  [ Michael Frey (Senior Manager, MID ]
++
++  * SAUCE: Send HCI_RESET for Broadcomm 2046
++
++  [ Phillip Lougher ]
++
++  * SAUCE: r8169: disable TSO by default for RTL8111/8168B chipsets.
++
++  [ Stefan Bader ]
++
++  * SAUCE: (no-up) Export dm_disk function of device-mapper
++  * SAUCE: Restore VT fonts on switch
++  * SAUCE: mmc: Increase power_up deleay to fix TI readers
++
++  [ Tim Gardner ]
++
++  * SAUCE: Add extra headers to linux-libc-dev
++  * SAUCE: Catch nonsense keycodes and silently ignore
++  * SAUCE: Added support for HDAPS on various ThinkPads from Lenovo and IBM
++  * SAUCE: Guest OS does not recognize a lun with non zero target id on
++    Vmware ESX Server
++  * SAUCE: (no-up) Take care of orinoco_cs overlap with hostap_cs
++  * ubuntu: Add GNBD driver
++
++ -- Ben Collins <ben.collins@canonical.com>  Sat, 23 Aug 2008 15:48:35 -0400
++
++linux (2.6.27-0.0) intrepid; urgency=low
++
++  * Not uploaded, placeholder for new release
++
++ -- Ben Collins <ben.collins@canonical.com>  Sat, 23 Aug 2008 15:48:35 -0400
++
++linux (2.6.26-5.17) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * build/abi: Add tosh_smm symbol to blacklist
++
++ -- Ben Collins <ben.collins@canonical.com>  Fri, 15 Aug 2008 09:29:34 -0400
++
++linux (2.6.26-5.16) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * Revert "SAUCE: toshiba_acpi: Rewrote most of the proc entry bits."
++  * Revert "SAUCE: Update toshiba_acpi.c to version 0.19a"
++  * build/config: Disable in-kernel toshiba driver(s)
++  * ubuntu/tlsup: New driver for toshiba laptops
++  * build/config: Enable TLSUP driver
++  * SAUCE: e1000e: Fix E1000E_ENABLED logic to check for our E1000E_NEW
++    driver as well
++  * ubuntu/e1000e: Remove E1000E_ENABLED option in local config
++  * build/config: Update configs to have E1000E_ENABLED set
++  * ubuntu/prism2: Remove duplicate device
++
++  [ Fabio M. Di Nitto ]
++
++  * SAUCE: Export gfs2 symbols required for gfs1 kernel module
++
++  [ Stefan Bader ]
++
++  * SAUCE: x86: HPET rework for SB700
++    - LP: #255910
++
++  [ Tim Gardner ]
++
++  * Add GNBD driver
++  * Enable GNBD driver
++  * SAUCE: Add GFS driver
++  * SAUCE: Enable gfs driver configs
++  * b43: Linksys WMP54G (BCM4306/3) card in a PCI format has an SPROM
++    coding
++
++  [ Upstream Kernel Changes ]
++
++  * KVM: x86 emulator: emulate clflush
++  * USB: quirk PLL power down mode
++
++ -- Ben Collins <ben.collins@canonical.com>  Mon, 11 Aug 2008 13:19:28 -0400
++
++linux (2.6.26-5.15) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * Revert "SAUCE: Add blacklist support to fix Belkin bluetooth dongle."
++    - Superceded by upstream changes.
++  * build/config: New option enabled for uvcvideo
++  * build/control: Add Vcs-Git meta data to control file
++  * SAUCE: toshiba_acpi: Rewrote most of the new code
++  * abi/perm-blacklist: Add emu10k1 driver to blacklist
++
++  [ Upstream Kernel Changes ]
++
++  * pxamci: trivial fix of DMA alignment register bit clearing
++  * udplite: Protection against coverage value wrap-around
++  * ipv6: use timer pending
++  * ipv6: __KERNEL__ ifdef struct ipv6_devconf
++  * hdlcdrv: Fix CRC calculation.
++  * quota: fix possible infinite loop in quota code
++  * isofs: fix minor filesystem corruption
++  * KVM: VMX: Fix a wrong usage of vmcs_config
++  * KVM: SVM: fix suspend/resume support
++  * KVM: mmu_shrink: kvm_mmu_zap_page requires slots_lock to be held
++  * KVM: VMX: Add ept_sync_context in flush_tlb
++  * KVM: x86 emulator: Fix HLT instruction
++  * KVM: MMU: nuke shadowed pgtable pages and ptes on memslot destruction
++  * KVM: MMU: Fix potential race setting upper shadow ptes on nonpae hosts
++  * Patch Upstream: x86 ptrace: fix PTRACE_GETFPXREGS error
++  * rcu: fix rcu_try_flip_waitack_needed() to prevent grace-period stall
++  * Fix typos from signal_32/64.h merge
++  * x86 reboot quirks: add Dell Precision WorkStation T5400
++  * USB: fix usb serial pm counter decrement for disconnected interfaces
++  * x86, suspend, acpi: enter Big Real Mode
++  * markers: fix duplicate modpost entry
++  * Fix build on COMPAT platforms when CONFIG_EPOLL is disabled
++  * proc: fix /proc/*/pagemap some more
++  * cpusets: fix wrong domain attr updates
++  * x86: fix crash due to missing debugctlmsr on AMD K6-3
++  * ide-cd: fix oops when using growisofs
++  * rtc-at91rm9200: avoid spurious irqs
++  * vmlinux.lds: move __attribute__((__cold__)) functions back into final
++    .text section
++  * ARM: fix fls() for 64-bit arguments
++  * tcp: Clear probes_out more aggressively in tcp_ack().
++  * sparc64: Fix lockdep issues in LDC protocol layer.
++  * sparc64: Fix cpufreq notifier registry.
++  * sparc64: Do not define BIO_VMERGE_BOUNDARY.
++  * iop-adma: fix platform driver hotplug/coldplug
++  * myri10ge: do not forget to setup the single slice pointers
++  * myri10ge: do not use mgp->max_intr_slots before loading the firmware
++  * ALSA: trident - pause s/pdif output
++  * V4L: cx18: Upgrade to newer firmware & update documentation
++  * DVB: dib0700: add support for Hauppauge Nova-TD Stick 52009
++  * V4L: uvcvideo: Fix a buffer overflow in format descriptor parsing
++  * V4L: uvcvideo: Use GFP_NOIO when allocating memory during resume
++  * V4L: uvcvideo: Don't free URB buffers on suspend
++  * V4L: uvcvideo: Make input device support optional
++  * V4L: uvcvideo: Add support for Medion Akoya Mini E1210 integrated
++    webcam
++  * V4L: saa7134: Copy tuner data earlier to avoid overwriting manual tuner
++    type
++  * V4L: cx23885: Bugfix for concurrent use of /dev/video0 and /dev/video1
++  * DVB: cx23885: Ensure PAD_CTRL is always reset to a sensible default
++  * DVB: cx23885: DVB Transport cards using DVB port VIDB/TS1 did not
++    stream
++  * DVB: cx23885: Reallocated the sram to avoid concurrent VIDB/C issues
++  * DVB: cx23885: SRAM changes for the 885 and 887 silicon parts
++  * x86: fix kernel_physical_mapping_init() for large x86 systems
++  * eCryptfs: use page_alloc not kmalloc to get a page of memory
++  * UML - Fix boot crash
++  * ixgbe: remove device ID for unsupported device
++  * mpc52xx_psc_spi: fix block transfer
++  * tmpfs: fix kernel BUG in shmem_delete_inode
++  * markers: fix markers read barrier for multiple probes
++  * VFS: increase pseudo-filesystem block size to PAGE_SIZE
++  * cpufreq acpi: only call _PPC after cpufreq ACPI init funcs got called
++    already
++  * b43legacy: Release mutex in error handling code
++  * ath5k: don't enable MSI, we cannot handle it yet
++  * Fix off-by-one error in iov_iter_advance()
++  * Linux 2.6.26.1
++  * ftrace: remove unneeded documentation
++  * romfs_readpage: don't report errors for pages beyond i_size
++  * netfilter: nf_nat_sip: c= is optional for session
++  * SCSI: bsg: fix bsg_mutex hang with device removal
++  * x86: idle process - add checking for NULL early param
++  * x86: io delay - add checking for NULL early param
++  * Close race in md_probe
++  * Kprobe smoke test lockdep warning
++  * netfilter: xt_time: fix time's time_mt()'s use of do_div()
++  * linear: correct disk numbering error check
++  * SCSI: ch: fix ch_remove oops
++  * NFS: Ensure we zap only the access and acl caches when setting new acls
++  * jbd: fix race between free buffer and commit transaction
++  * Input: i8042 - add Intel D845PESV to nopnp list
++  * Input: i8042 - add Gericom Bellagio to nomux blacklist
++  * Input: i8042 - add Acer Aspire 1360 to nomux blacklist
++  * Bluetooth: Signal user-space for HIDP and BNEP socket errors
++  * Add compat handler for PTRACE_GETSIGINFO
++  * ALSA: hda - Fix wrong volumes in AD1988 auto-probe mode
++  * ALSA: hda - Fix DMA position inaccuracy
++  * ALSA: hda - Add missing Thinkpad Z60m support
++  * ALSA: emu10k1 - Fix inverted Analog/Digital mixer switch on Audigy2
++  * vfs: fix lookup on deleted directory
++  * Ath5k: fix memory corruption
++  * Ath5k: kill tasklets on shutdown
++  * sound: ensure device number is valid in snd_seq_oss_synth_make_info
++  * Linux 2.6.26.2
++
++ -- Ben Collins <ben.collins@canonical.com>  Sun, 03 Aug 2008 13:25:02 -0400
++
++linux (2.6.26-5.14) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * SAUCE: applesmc: Add MacBookAir
++  * build: Do not build ddeb unless we are on the buildd
++  * build: control: Consistency in arch fields.
++  * SAUCE: Update toshiba_acpi.c to version 0.19a
++    - LP: #77026
++  * build: Added perm blacklist support and per-module support to abi-check
++    - Blacklist p80211 module from abi checks
++  * ubuntu/lirc: Get rid of drivers symlink and use real include stuff
++
++
++  [ Colin Ian King ]
++
++  * SAUCE: acerhk module - add support for Amilo A1650g keyboard
++    - LP: #84159
++  * SAUCE: rt2x00: Fix OOPS on failed creation of rt2x00lib workqueue
++    - LP: #249242
++
++  [ Mario Limonciello ]
++
++  * Add LIRC back in
++
++  [ Tim Gardner ]
++
++  * Makefile race condition can lead to ndiswrapper build failure
++    - LP: #241547
++  * update linux-wlan-ng (prism2_usb) to upstream version 1861
++    - LP: #245026
++
++  [ Upstream Kernel Changes ]
++
++  * Fix typos from signal_32/64.h merge
++
++ -- Ben Collins <ben.collins@canonical.com>  Fri, 01 Aug 2008 00:05:01 -0400
++
++linux (2.6.26-5.13) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * build: Make makedumpfile an amd64/i386 only build-dep
++  * ubuntu/acerhk: Fixup assembly to compile with newer binutils
++
++ -- Ben Collins <ben.collins@canonical.com>  Sat, 26 Jul 2008 16:41:50 -0400
++
++linux (2.6.26-4.12) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * e1000e: Upgraded module to 0.4.1.7 upstream. Placed in ubuntu/,
++    in-kernel driver disabled
++  * config: Disable e1000e in-kernel, and enable newer driver in ubuntu/
++  * rfkill: Update to 1.3 drivers, and move to common location
++  * ubuntu: Actually link kconfig/kbuild into rfkill subdir
++  * config: Enable loading dsdt from initramfs
++    - LP: #246222
++  * ubuntu: [compcache] Update to fix crashes in improper BUG()
++  * build: Create a retag scripts to recover tags from rebases
++  * build: Updates for dbg pkg
++  * build: Make sure no empty lines show up in debian/files
++  * ubuntu: atl1e: Add new driver from 2.6.27-pre-rc1
++    - LP: #243894
++  * sys_getcwd: Fix some brokeness introduced by AppArmor __d_path
++    changes
++    - LP: #251223
++  * ubuntu: unionfs: Added v1.4 module from hardy
++  * build: Add sub-flavour infrastructure, and virtual subflav
++
++  [ Eric Piel ]
++
++  * ACPI: Allow custom DSDT tables to be loaded from initramfs
++
++  [ Kees Cook ]
++
++  * AppArmor: Smack VFS patches
++
++  [ Mario Limonciello ]
++
++  * Work around ACPI corruption upon suspend on some Dell machines.
++    - LP: #183033
++
++  [ Tim Gardner ]
++
++  * Export usbhid_modify_dquirk for LBM module bcm5974
++    - LP: #250838
++  * VIA - Add VIA DRM Chrome9 3D engine
++    - LP: #251862
++  * Define TRUE/FALSE for VIA DRM driver.
++
++ -- Ben Collins <ben.collins@canonical.com>  Tue, 15 Jul 2008 12:51:39 -0400
++
++linux (2.6.26-4.11) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * config: Enable bcm5974 driver in all configs
++
++  [ 2.6.26-4.10 ]
++
++  [ Amit Kucheria ]
++
++  * Fix typo in GSPCA Makefile and make it compile
++
++  [ Ben Collins ]
++
++  * ubuntu: Remove UVC driver in favor of in-kernel one (-rc9)
++  * config: Updates for -rc9
++  * ubuntu: Add acx, prism2_usb wireless drivers
++  * config: Enable prism2_usb and acx drivers.
++  * ubuntu: Add at76 driver to build
++  * config: Enable at76_usb driver.
++  * iscsitarget: Fix prototype for bi_end_io callback.
++  * acx: Fix section type mismatch warnings
++  * fsam7400: Add sw kill switch driver
++  * config: Enable fsam7400 driver
++  * qc-usb: Added new driver
++  * config: Enable qc-usb driver
++  * drbd: Remove built-in connector usage
++  * drbd: Do not define idx/val for connector here
++  * connector.h: Add idx/val for drbd
++  * bcm5974: Added new driver
++
++  [ Kees Cook ]
++
++  * SAUCE: [AppArmor] merge with upstream subversion r1291
++  * SAUCE: [AppArmor] fix typo in selinux_inode_link
++  * SAUCE: [AppArmor] aufs patches
++
++  [ Michael Frey (Senior Manager, MID ]
++
++  * SAUCE: Send HCI_RESET for Broadcomm 2046
++    - LP: #241749
++
++  [ Tim Gardner ]
++
++  * SAUCE: Medion Akoya Mini E1210
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "BAST: Remove old IDE driver"
++  * ARM: OMAP: DMA: Don't mark channel active in omap_enable_channel_irq
++  * ARM: OMAP: Correcting the gpmc prefetch control register address
++  * debugobjects: fix lockdep warning
++  * [ARM] 5115/1: pxafb: fix ifdef for command line option handling
++  * [ARM] 5116/1: pxafb: cleanup and fix order of failure handling
++  * [ARM] 5109/1: Mark rtc sa1100 driver as wakeup source before
++    registering it
++  * [ARM] Export dma_sync_sg_for_device()
++  * fix cgroup-inflicted breakage in block_dev.c
++  * [patch for 2.6.26 2/4] vfs: utimensat(): be consistent with utime() for
++    immutable and append-only files
++  * [patch for 2.6.26 1/4] vfs: utimensat(): ignore tv_sec if tv_nsec ==
++    UTIME_OMIT or UTIME_NOW
++  * [patch for 2.6.26 3/4] vfs: utimensat(): fix error checking for
++    {UTIME_NOW,UTIME_OMIT} case
++  * [patch for 2.6.26 4/4] vfs: utimensat(): fix write access check for
++    futimens()
++  * [patch 1/4] vfs: path_{get,put}() cleanups
++  * [patch 2/4] fs: make struct file arg to d_path const
++  * [patch 3/4] vfs: fix ERR_PTR abuse in generic_readlink
++  * [patch 4/4] flock: remove unused fields from file_lock_operations
++  * [patch 3/3] vfs: make d_path() consistent across mount operations
++  * [patch 1/3] vfs: dcache sparse fixes
++  * [patch 2/3] vfs: dcache cleanups
++  * udf: Fix regression in UDF anchor block detection
++  * [SCSI] ses: Fix timeout
++  * netfilter: ip6table_mangle: don't reroute in LOCAL_IN
++  * [SCSI] esp: Fix OOPS in esp_reset_cleanup().
++  * kernel/audit.c: nlh->nlmsg_type is gotten more than once
++  * audit: fix kernel-doc parameter notation
++  * remove useless argument type in audit_filter_user()
++  * Blackfin arch: fix bug - kernel boot fails when Spinlock and rw-lock
++    debugging enabled
++  * Blackfin arch: fix up section mismatch warning
++  * mac80211: implement EU regulatory domain
++  * b43: Do not return TX_BUSY from op_tx
++  * b43legacy: Do not return TX_BUSY from op_tx
++  * b43: Fix possible MMIO access while device is down
++  * b43legacy: Fix possible NULL pointer dereference in DMA code
++  * rt2x00: Fix unbalanced mutex locking
++  * iwlwifi: improve scanning band selection management
++  * [SCSI] esp: tidy up target reference counting
++  * [ARM] 5117/1: pxafb: fix __devinit/exit annotations
++  * thermal: Create CONFIG_THERMAL_HWMON=n
++  * ACPI: don't walk tables if ACPI was disabled
++  * dock: bay: Don't call acpi_walk_namespace() when ACPI is disabled.
++  * x86: shift bits the right way in native_read_tscp
++  * x86: section/warning fixes
++  * V4L/DVB (8004): Fix INPUT dependency at budget-ci
++  * V4L/DVB (8005): Fix OOPS if frontend is null
++  * V4L/DVB (8007): cx18/cx25840: the S-Video LUMA input can use all
++    In1-In8 inputs
++  * V4L/DVB (8008): cx18: remove duplicate audio and video input enums
++  * V4L/DVB (8010): em28xx: Properly register extensions for already
++    attached devices
++  * V4L/DVB (8011): em28xx: enable DVB for HVR-900
++  * V4L/DVB (8012): gl861: sleep a little to avoid I2C errors
++  * V4L/DVB (8013): gl861: remove useless identify_state
++  * V4L/DVB (8015): gl861: replace non critical msleep(0) with msleep(1) to
++    be on the safe side
++  * V4L/DVB (8017): Ensure em28xx extensions only get run against devs that
++    support them
++  * V4L/DVB (8018): Add em2860 chip ID
++  * V4L/DVB (8020): Fix callbacks functions of saa7134_empress
++  * V4L/DVB (8022): saa7134: fix race between opening and closing the
++    device
++  * V4L/DVB (8026): Avoids an OOPS if dev struct can't be successfully
++    recovered
++  * V4L/DVB (8027): saa7134: Avermedia A700: only s-video and composite
++    input are working
++  * V4L/DVB (8028): Improve error messages for tda1004x attach
++  * V4L/DVB (8029): Improve error message at tda1004x_attach
++  * V4L/DVB (8034): tda18271: fix IF notch frequency handling
++  * V4L/DVB (8035): tda18271: dont touch EB14 if rf_cal lookup is out of
++    range
++  * V4L/DVB (8036): tda18271: toggle rf agc speed mode on TDA18271HD/C2
++    only
++  * V4L/DVB (8037): tda18271: ensure that the thermometer is off during
++    channel configuration
++  * V4L/DVB (8039): pxa-camera: fix platform_get_irq() error handling.
++  * V4L/DVB (8040): soc-camera: remove soc_camera_host_class class
++  * V4L/DVB (8042): DVB-USB UMT-010 channel scan oops
++  * V4L/DVB (8043): au0828: add support for additional USB device id's
++  * V4L/DVB (8044): au8522: tuning optimizations
++  * V4L/DVB (8048): saa7134: Fix entries for Avermedia A16d and Avermedia
++    E506
++  * V4L/DVB (8061): cx18: only select tuner / frontend modules if
++    !DVB_FE_CUSTOMISE
++  * V4L/DVB (8063): cx18: Fix unintended auto configurations in
++    cx18-av-core
++  * V4L/DVB (8066): cx18: Fix audio mux input definitions for HVR-1600 Line
++    In 2 and FM radio
++  * V4L/DVB (8067): cx18: Fix firmware load for case when digital capture
++    happens first
++  * V4L/DVB (8068): cx18: Add I2C slave reset via GPIO upon initialization
++  * V4L/DVB (8069): cx18: Fix S-Video and Compsite inputs for the Yuan
++    MPC718 and enable card entry
++  * V4L/DVB (8071): tda10023: Fix possible kernel oops during
++    initialisation
++  * V4L/DVB (8073): av7110: Catch another type of ARM crash
++  * V4L/DVB (8074): av7110: OSD transfers should not be interrupted
++  * V4L/DVB (8075): stv0299: Uncorrected block count and bit error rate
++    fixed
++  * V4L/DVB (8092): videodev: simplify and fix standard enumeration
++  * V4L/DVB (8096): au8522: prevent false-positive lock status
++  * V4L/DVB (8097): xc5000: check device hardware state to determine if
++    firmware download is needed
++  * V4L/DVB (8100): V4L/vivi: fix possible memory leak in vivi_fillbuff
++  * V4L/DVB (8108): Fix open/close race in saa7134
++  * s2io: fix documentation about intr_type
++  * tc35815: Mark carrier-off before starting PHY
++  * tc35815: Fix receiver hangup on Rx FIFO overflow
++  * ixgbe: fix EEH recovery during reset on PPC
++  * igb: fix EEH recovery during reset on PPC
++  * e1000e: fix EEH recovery during reset on PPC
++  * pcnet_cs, axnet_cs: clear bogus interrupt before request_irq
++  * drivers/net/r6040.c: Eliminate double sizeof
++  * ipg: fix jumbo frame compilation
++  * ipg: use NULL, not zero, for pointers
++  * [netdrvr] 3c59x: remove irqs_disabled warning from local_bh_enable
++  * [netdrvr] netxen: fix netxen_pci_tbl[] breakage
++  * e100: Do pci_dma_sync after skb_alloc for proper operation on ixp4xx
++  * e1000: only enable TSO6 via ethtool when using correct hardware
++  * [netdrvr] Fix IOMMU overflow checking in s2io.c
++  * qla3xxx: Hold RTNL while calling dev_close()
++  * Hold RTNL while calling dev_close()
++  * sata_uli: hardreset is broken
++  * rt2x00: Fix lock dependency errror
++  * prism: islpci_eth.c endianness fix
++  * mac80211: fix an oops in several failure paths in key allocation
++  * firewire: fw-sbp2: fix parsing of logical unit directories
++  * kbuild: fix a.out.h export to userspace with O= build.
++  * Ensure interrupted recovery completed properly (v1 metadata plus
++    bitmap)
++  * Don't acknowlege that stripe-expand is complete until it really is.
++  * Fix error paths if md_probe fails.
++  * hamradio: remove unused variable
++  * tcp: calculate tcp_mem based on low memory instead of all memory
++  * tcp: fix for splice receive when used with software LRO
++  * af_unix: fix 'poll for write'/connected DGRAM sockets
++  * netdevice: Fix typo of dev_unicast_add() comment
++  * pkt_sched: ERR_PTR() ususally encodes an negative errno, not positive.
++  * pkt_sched: Remove CONFIG_NET_SCH_RR
++  * include/linux/netdevice.h: don't export MAX_HEADER to userspace
++  * tcp: /proc/net/tcp rto,ato values not scaled properly (v2)
++  * netlink: Fix some doc comments in net/netlink/attr.c
++  * CONNECTOR: add a proc entry to list connectors
++  * inet fragments: fix race between inet_frag_find and
++    inet_frag_secret_rebuild
++  * net/inet_lro: remove setting skb->ip_summed when not LRO-able
++  * netlabel: Fix a problem when dumping the default IPv6 static labels
++  * ipv6 route: Convert rt6_device_match() to use RT6_LOOKUP_F_xxx flags.
++  * sched: fix cpu hotplug
++  * Fix and clean top .gitignore
++  * x86: fix cpu hotplug crash
++  * ptrace GET/SET FPXREGS broken
++  * Input: add KEY_MEDIA_REPEAT definition
++  * Input: fix locking in force-feedback core
++  * [ARM] 5131/1: Annotate platform_secondary_init with trace_hardirqs_off
++  * ide: fix /proc/ide/ide?/mate reporting
++  * netfilter: nf_conntrack_tcp: fixing to check the lower bound of valid
++    ACK
++  * textsearch: fix Boyer-Moore text search bug
++  * hostap: don't report useless WDS frames by default
++  * hostap: fix sparse warnings
++  * mac80211: don't accept WEP keys other than WEP40 and WEP104
++  * V4L/DVB (8145a): USB Video Class driver
++  * [IA64] Bugfix for system with 32 cpus
++  * [IA64] export account_system_vtime
++  * sched: fix divide error when trying to configure rt_period to zero
++  * x86: fix NODES_SHIFT Kconfig range
++  * block: Fix the starving writes bug in the anticipatory IO scheduler
++  * Properly notify block layer of sync writes
++  * rcu: fix hotplug vs rcu race
++  * I2C: S3C2410: Check ACK on byte transmission
++  * I2C: S3C2410: Fixup error codes returned rom a transfer.
++  * I2C: S3C2410: Add MODULE_ALIAS() for s3c2440 device.
++  * PCI: Restrict VPD read permission to root
++  * powerpc/bootwrapper: update for initrd with simpleImage
++  * i2c: Documentation: fix device matching description
++  * i2c: Fix bad hint about irqs in i2c.h
++  * powerpc/legacy_serial: Bail if reg-offset/shift properties are present
++  * powerpc/mpc5200: Fix lite5200b suspend/resume
++  * ipv4: fix sysctl documentation of time related values
++  * net-sched: change tcf_destroy_chain() to clear start of filter list
++  * net-sched: fix filter destruction in atm/hfsc qdisc destruction
++  * netlink: Unneeded local variable
++  * net: Tyop of sk_filter() comment
++  * netdevice: Fix wrong string handle in kernel command line parsing
++  * net: fib_rules: fix error code for unsupported families
++  * dm crypt: use cond_resched
++  * V4L/DVB (8178): uvc: Fix compilation breakage for the other drivers, if
++    uvc is selected
++  * PCI: Limit VPD read/write lengths for Broadcom 5706, 5708, 5709 rev.
++  * PCI: acpiphp: cleanup notify handler on all root bridges
++  * drivers/input/ff-core.c needs <linux/sched.h>
++  * DRM/i915: only use tiled blits on 965+
++  * tty: Fix inverted logic in send_break
++  * x86: fix Intel Mac booting with EFI
++  * arch/x86/mm/init_64.c: early_memtest(): fix types
++  * 9p: fix O_APPEND in legacy mode
++  * slub: Do not use 192 byte sized cache if minimum alignment is 128 byte
++  * Do not overwrite nr_zones on !NUMA when initialising zlcache_ptr
++  * [MIPS] IP32: Fix unexpected irq 71
++  * [MIPS] IP22: Fix crashes due to wrong L1_CACHE_BYTES
++  * [MIPS] cevt-txx9: Reset timer counter on initialization
++  * hrtimer: prevent migration for raising softirq
++  * svcrpc: fix handling of garbage args
++  * OHCI: Fix problem if SM501 and another platform driver is selected
++  * USB: fix cdc-acm resume()
++  * USB: ehci - fix timer regression
++  * USB: ohci - record data toggle after unlink
++  * USB: mass storage: new id for US_SC_CYP_ATACB
++  * sisusbvga: Fix oops on disconnect.
++  * USB: New device ID for ftdi_sio driver
++  * USB: fix interrupt disabling for HCDs with shared interrupt handlers
++  * USB: don't lose disconnections during suspend
++  * USB: another option device id
++  * USB: add a pl2303 device id
++  * USB: fix Oops on loading ipaq module since 2.6.26
++  * USB: adding comment for ipaq forcing number of ports
++  * [MIPS] Fix bug in atomic_sub_if_positive.
++  * xen: fix address truncation in pte mfn<->pfn conversion
++  * sata_sil24: add DID for another adaptec flavor
++  * ahci: always clear all bits in irq_stat
++  * libata-sff: improve HSM violation reporting
++  * sata_mv: safer logic for limit_warnings
++  * Update maintainers for powerpc
++  * Christoph has moved
++  * mm: dirty page accounting vs VM_MIXEDMAP
++  * rtc: rtc_read_alarm() handles wraparound
++  * firmware: fix the request_firmware() dummy
++  * serial: fix serial_match_port() for dynamic major tty-device numbers
++  * get_user_pages(): fix possible page leak on oom
++  * rtc-x1205: Fix alarm set
++  * rtc: fix CMOS time error after writing /proc/acpi/alarm
++  * pci: VT3336 can't do MSI either
++  * Miguel Ojeda has moved
++  * ext3: add missing unlock to error path in ext3_quota_write()
++  * ext4: add missing unlock to an error path in ext4_quota_write()
++  * reiserfs: add missing unlock to an error path in reiserfs_quota_write()
++  * ecryptfs: remove unnecessary mux from ecryptfs_init_ecryptfs_miscdev()
++  * lib: taint kernel in common report_bug() WARN path.
++  * gpio: pca953x (i2c) handles max7310 too
++  * fsl_diu_fb: fix build with CONFIG_PM=y, plus fix some warnings
++  * Update taskstats-struct document for scaled time accounting
++  * cciss: fix regression that no device nodes are created if no logical
++    drives are configured.
++  * delay accounting: maintainer update
++  * Doc*/kernel-parameters.txt: fix stale references
++  * hdaps: add support for various newer Lenovo thinkpads
++  * mn10300: export certain arch symbols required to build allmodconfig
++  * mn10300: provide __ucmpdi2() for MN10300
++  * Introduce rculist.h
++  * man-pages is supported
++  * ntfs: update help text
++  * add kernel-doc for simple_read_from_buffer and memory_read_from_buffer
++  * w100fb: do not depend on SHARPSL
++  * w100fb: add 80 MHz modeline
++  * MFD maintainer
++  * cgroups: document the effect of attaching PID 0 to a cgroup
++  * spi: fix the read path in spidev
++  * doc: doc maintainers
++  * security: filesystem capabilities: fix fragile setuid fixup code
++  * security: filesystem capabilities: fix CAP_SETPCAP handling
++  * Alpha Linux kernel fails with inconsistent kallsyms data
++  * cpusets: document proc status cpus and mems allowed lists
++  * MAINTAINERS: update the email address of Andreas Dilger
++  * cciss: read config to obtain max outstanding commands per controller
++  * olpc: sdhci: add quirk for the Marvell CaFe's vdd/powerup issue
++  * olpc: sdhci: add quirk for the Marvell CaFe's interrupt timeout
++  * cpumask: introduce new APIs
++  * mm: switch node meminfo Active & Inactive pages to Kbytes
++  * Update MAINTAINERS file for the TPM device driver
++  * devcgroup: fix odd behaviour when writing 'a' to devices.allow
++  * doc: document the relax_domain_level kernel boot argument
++  * mmc: don't use DMA on newer ENE controllers
++  * mempolicy: mask off internal flags for userspace API
++  * x86 ACPI: normalize segment descriptor register on resume
++  * x86 ACPI: fix resume from suspend to RAM on uniprocessor x86-64
++  * softlockup: print a module list on being stuck
++  * ide: fix hwif->gendev refcounting
++  * ide: ide_unregister() warm-plug bugfix
++  * ide: ide_unregister() locking bugfix
++  * ahci: give another shot at clearing all bits in irq_stat
++  * Fix clear_refs_write() use of struct mm_walk
++  * Move _RET_IP_ and _THIS_IP_ to include/linux/kernel.h
++  * Fix pagemap_read() use of struct mm_walk
++  * Linux 2.6.26-rc9
++  * Revert "USB: don't explicitly reenable root-hub status interrupts"
++  * Revert "PCI: Correct last two HP entries in the bfsort whitelist"
++  * iwlwifi: fix incorrect 5GHz rates reported in monitor mode
++  * iwlwifi: drop skb silently for Tx request in monitor mode
++  * libertas: support USB persistence on suspend/resume (resend)
++  * tcp: net/ipv4/tcp.c needs linux/scatterlist.h
++  * tcp: fix a size_t < 0 comparison in tcp_read_sock
++  * bridge: fix use-after-free in br_cleanup_bridges()
++  * Add missing skb->dev assignment in Frame Relay RX code
++  * forcedeth: fix lockdep warning on ethtool -s
++  * ehea: fix might sleep problem
++  * ehea: add MODULE_DEVICE_TABLE
++  * ehea: fix race condition
++  * ehea: Access iph->tot_len with correct endianness
++  * pasemi_mac: Access iph->tot_len with correct endianness
++  * ibm_newemac: Fixes kernel crashes when speed of cable connected changes
++  * ibm_newemac: Fixes entry of short packets
++  * fs_enet: restore promiscuous and multicast settings in restart()
++  * can: add sanity checks
++  * x86: KVM guest: Add memory clobber to hypercalls
++  * KVM: IOAPIC: Fix level-triggered irq injection hang
++  * [SCSI] erase invalid data returned by device
++  * pxamci: fix byte aligned DMA transfers
++  * vsprintf: split out '%s' handling logic
++  * vsprintf: split out '%p' handling logic
++  * vsprintf: add infrastructure support for extended '%p' specifiers
++  * vsprintf: add support for '%pS' and '%pF' pointer formats
++  * powerpc: Fix unterminated of_device_id array in legacy_serial.c
++  * [UML] fix gcc ICEs and unresolved externs
++  * ocfs2/dlm: Fixes oops in dlm_new_lockres()
++  * hostap_cs: correct poor NULL checks in suspend/resume routines
++  * drivers/net/wireless/iwlwifi/iwl-3945.c Fix type issue on 64bit
++  * mac80211: move netif_carrier_on to after
++    ieee80211_bss_info_change_notify
++  * mac80211: Only flush workqueue when last interface was removed
++  * zd1211rw: add ID for AirTies WUS-201
++  * ssb-pcicore: Fix IRQ-vector init on embedded devices
++  * mac80211: don't report selected IBSS when not found
++  * crypto: tcrypt - Fix memory leak in test_cipher
++  * sctp: Mark the tsn as received after all allocations finish
++  * [S390] protect _PAGE_SPECIAL bit against mprotect
++  * irda: via-ircc proper dma freeing
++  * irda: New device ID for nsc-ircc
++  * irda: Fix netlink error path return value
++  * [SCSI] mptspi: fix oops in mptspi_dv_renegotiate_work()
++  * Correct hash flushing from huge_ptep_set_wrprotect()
++  * ide: add __ide_default_irq() inline helper
++  * palm_bk3710: fix IDECLK period calculation
++  * it8213: fix return value in it8213_init_one()
++  * [MIPS] Atlas, decstation: Fix section mismatches triggered by
++    defconfigs
++  * [MIPS] Fix 32bit kernels on R4k with 128 byte cache line size
++  * NFS: Fix readdir cache invalidation
++  * SUNRPC: Fix a double-free in rpcbind
++  * SUNRPC: Fix an rpcbind breakage for the case of IPv6 lookups
++  * reiserfs: discard prealloc in reiserfs_delete_inode
++  * Fix broken fix for fsl-diu-db
++  * RDMA/cxgb3: Fix regression caused by class_device -> device conversion
++  * ipv6: fix race between ipv6_del_addr and DAD timer
++  * sctp: Add documentation for sctp sysctl variable
++  * kernel/printk.c: Made printk_recursion_bug_msg static.
++  * powerpc: Add missing reference to coherent_dma_mask
++  * rc80211_pid: Fix fast_start parameter handling
++  * rt2x00: Disable synchronization during initialization
++  * zd1211rw: stop beacons on remove_interface
++  * libertas: fix memory alignment problems on the blackfin
++  * netfilter: nf_conntrack_tcp: fix endless loop
++  * netfilter: nf_nat_snmp_basic: fix a range check in NAT for SNMP
++  * md: ensure all blocks are uptodate or locked when syncing
++  * sched: fix cpu hotplug
++  * x86: fix /dev/mem compatibility under PAT
++  * crypto: chainiv - Invoke completion function
++  * ocfs2: Fix flags in ocfs2_file_lock
++  * kernel/kprobes.c: Made kprobe_blacklist static.
++  * arch/x86/kernel/.gitignore: Added vmlinux.lds to .gitignore file
++    because it shouldn't be tracked.
++  * ftrace: Documentation
++  * Fix PREEMPT_RCU without HOTPLUG_CPU
++  * sched: fix cpu hotplug, cleanup
++  * exec: fix stack excutability without PT_GNU_STACK
++  * slub: Fix use-after-preempt of per-CPU data structure
++  * Documentation: clarify tcp_{r,w}mem sysctl docs
++  * ip: sysctl documentation cleanup
++  * tcp: correct kcalloc usage
++  * ipv4: fib_trie: Fix lookup error return
++  * netlabel: netlink_unicast calls kfree_skb on error path by itself
++  * ipv6: missed namespace context in ipv6_rthdr_rcv
++  * xfrm: Add a XFRM_STATE_AF_UNSPEC flag to xfrm_usersa_info
++  * tun: Persistent devices can get stuck in xoff state
++  * tpm: add Intel TPM TIS device HID
++  * rapidio: fix device reference counting
++  * Fix name of Russell King in various comments
++  * rtc: fix reported IRQ rate for when HPET is enabled
++  * libata-acpi: filter out DIPM enable
++  * Added Targa Visionary 1000 IDE adapter to pata_sis.c
++  * libata-acpi: don't call sleeping function from invalid context
++  * Fix reference counting race on log buffers
++  * [SCSI] ipr: Fix HDIO_GET_IDENTITY oops for SATA devices
++  * IPMI: return correct value from ipmi_write
++  * x86: fix ldt limit for 64 bit
++  * [SCSI] fusion: default MSI to disabled for SPI and FC controllers
++  * [SCSI] bsg: fix oops on remove
++  * drivers/char/pcmcia/ipwireless/hardware.c fix resource leak
++  * drivers/isdn/i4l/isdn_common.c fix small resource leak
++  * fbdev: bugfix for multiprocess defio
++  * serial8250: sanity check nr_uarts on all paths.
++  * ov7670: clean up ov7670_read semantics
++  * rtc-fm3130: fix chip naming
++  * rtc-pcf8563: add chip id
++  * OProfile kernel maintainership changes
++  * frv: fix irqs_disabled() to return an int, not an unsigned long
++  * cifs: fix inode leak in cifs_get_inode_info_unix
++  * cifs: fix wksidarr declaration to be big-endian friendly
++  * cpusets, hotplug, scheduler: fix scheduler domain breakage
++  * Documentation/HOWTO: correct wrong kernel bugzilla FAQ URL
++  * devcgroup: always show positive major/minor num
++  * devcgroup: fix permission check when adding entry to child cgroup
++  * Linux 2.6.26
++
++ -- Ben Collins <ben.collins@canonical.com>  Mon, 14 Jul 2008 13:41:50 -0400
++
++linux (2.6.26-3.9) intrepid; urgency=low
++
++  * abi: Add dca and ioatdma to modules.ignore
++
++  [ 2.6.26-3.8 ]
++
++  [ Ben Collins ]
++
++  * ubuntu: Add heci driver 3.2.0.24
++  * ubuntu: Add heci to kconfig/kbuild
++  * config: Enable heci module on all flavours
++  * dm-bbr: Update to get it to compile with 2.6.26
++  * config: Enable dm-bbr
++  * ubuntu: Add some media drivers
++  * config: Enable misc media drivers
++  * udeb: Switch to uvesafb in fb-modules
++  * abi: Add more modules to ignore (known)
++
++  [ 2.6.26-3.7 ]
++
++  [Amit Kucheria]
++
++  * SAUCE: make fc transport removal of target configurable
++     - LP: #163075
++  * SAUCE: pm: Config option to disable handling of console during
++    suspend/resume
++
++  [Ben Collins]
++
++  * SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps
++  * SAUCE: irda: Default to dongle type 9 on IBM hardware
++  * SAUCE: tulip: Let dmfe handle davicom on non-sparc
++  * SAUCE: tulip: Define ULI PCI ID's
++  * SAUCE: version: Implement version_signature proc file.
++  * build: Cleanup arches
++  * build: Remove remnants of unused binary-custom infrastructure
++  * build: Remove disable_d_i (not needed) and cleanup ppa build stuff
++  * ubuntu: New modules, acer-acpi
++  * build: Remove -virtual, and rebuild configs
++  * ubuntu: Add drbd module
++  * acer-acpi: Fix makefile
++  * x86/Kconfig: Fix missing quote for ubuntu Kconfig source
++  * ubuntu: Add iscsitarget module
++  * ubuntu: Added Amiga FS driver
++  * ubuntu: Add squashfs driver
++  * ubuntu: Remove asfs (Amiga FS). Need to be in linux-ports instead
++  * squashfs: Move headers to real include directory
++  * build/configs: The Great Config Consistency Check of 2008
++  * ubuntu: Move third-party includes to ubuntu/include
++  * ubuntu: Add aufs module
++  * ubuntu: Added atl2 driver
++  * ubuntu: Add dm-radi4-5 driver
++  * build: Add CONFIG_DEBUG_SECTION_MISMATCH=y to get old style warnings
++    from build
++  * ubuntu/Makefile: Fixup dm-raid4-5 and add kludge for kbuild
++  * squashfs: Fixes for VFS changes
++  * ubuntu/dm-raid4-5: Fixups for moved/renamed headers/functions in core
++    md
++  * ubuntu: Add ndiswrapper driver
++  * d-i: Update module listings
++  * build: Disable xd block device (ancient)
++  * ndiswrapper: Fixup makefile
++  * d-i: Remove efi-modules. The only module, efivars, is built-in
++  * build: Remove install-source, obsolete and caused build failure
++  * Ubuntu-2.6.26-1.3
++  * build: linux-doc rules got broken when disabling html side. Fixed now.
++  * Ubuntu-2.6.26-1.4
++  * x86: Update to -rc6 allows CONFIG_PCI_OLPC to work with PCI_GOANY
++  * d-i: Make virtio-ring optional (it's built-in on i386)
++  * Ubuntu-2.6.26-1.4
++  * Ubuntu-2.6.26-1.5
++  * config: Enable DVB devices
++  * ubuntu/aufs: Make aufs a bool config, since it needs to be built-in
++  * config: Build aufs into the kernels
++  * build: Fix arguments passed to link-headers script
++  * config: Disable early printk
++  * d-i: Move isofs to storage-core and kill st (scsi tape) from list
++  * config: Enable non-promiscuous access to /dev/mem
++  * x86: Add option to disable decompression info messages
++  * config: Enable no-bz-chatter config options
++  * build: Re-add linux-source package
++  * d-i: Re-add socket-modules. Accidentally removed
++    - LP: #241295
++  * Ubuntu-2.6.26-2.6
++  * Use makedumpfile to generate a vmcoreinfo file.
++  * build: Build-Depend on makedumpfile for vmcoreinfo generation
++  * build: Remove debug print from git-ubuntu-log
++  * Updated configs for -rc7
++  * build: postinst, do not call depmod with -F
++  * config: Enable rtc-cmos as a built-in driver.
++  * control: Provide ndiswrapper-modules-1.9
++  * build: Generate vmcoreinfo in image build for crashdumps without debug
++    image
++  * config: Disable vesafb, since we'll prefer uvesafb
++  * build: Copy uvesafb module to initrd mod directory
++  * abi-check: New, more robust script
++  * config: Enable heap randomization by default
++  * abi-check: Cleanup output and call with perl (not $SHELL)
++  * abi: Ignore missing vesafb (known)
++  * config: Disable pcspkr (in favor of snd-pcsp)
++  * swap: Add notify_swap_entry_free callback for compcache
++  * compcache: Added ram backed compressed swap module
++  * ubuntu: Enable kbuild and kconfig for compcache
++  * config: Enable compcache and tlsf allocator as modules
++  * config: Updated for -rc8. Disables XEN on i386
++  * config: Switch i386-server to 64G, enable PAE, 64-bit res, and XEN
++  * ubuntu: Add misc drivers from hardy lum
++  * ubuntu: Enable build of misc/ subdir
++  * config: Enable misc drivers
++  * aufs: Fix warning about single non-string-literal arg to printf style
++    function
++  * drivers: Remove some duplicate device entries in various modules
++  * config: Disable some duplicate drivers
++  * keyspan: Remove duplicate device ID's
++  * check-aliases: Cleanup output, and fix rolling checks
++  * ubuntu: Disable dm-bbr for now
++  * dm-bbr: First cut at forward portiong. Still needs work.
++  * ubuntu: Disable dm-bbr in kbuild/kconfig
++
++  [Chuck Short]
++
++  * SAUCE: ata: blacklist FUJITSU MHW2160BH PL
++     - LP: #175834
++  * SAUCE: [USB]: add ASUS LCM to the blacklist
++
++  [Colin Ian King]
++
++  * SAUCE: airprime.c supports more devices
++    - LP: #208250
++  * SAUCE: Enable speedstep for sonoma processors. 
++     - LP: #132271
++  * Add dm-loop
++  * Add dm-loop BOM
++
++  [Kyle McMartin]
++
++  * SAUCE: fix orinoco_cs oops
++
++  [Mario Limonciello]
++
++  * SAUCE: Enable Reset and SCO workaround on Dell 410 BT adapter
++
++  [Matthew Garrett]
++
++  * SAUCE: hostap: send events on data interface as well as master
++    interface
++
++  [Phillip Lougher]
++
++  * SAUCE: r8169: disable TSO by default for RTL8111/8168B chipsets.
++
++  [Stefan Bader]
++
++  * SAUCE: Export dm_disk function of device-mapper
++  * SAUCE: Restore VT fonts on switch
++  * SAUCE: Always use SCO protocol (disable eSCO support) Bug: #39414
++  * SAUCE: mmc: Increase power_up deleay to fix TI readers OriginalAuthor:
++    Pascal Terjan <pterjan@mandriva.com> Bug: #137686
++  * SAUCE: Add blacklist support to fix Belkin bluetooth dongle. Bug:
++    #140511
++  * SAUCE: Lower warning level of pci resource allocation messages. Bug:
++    159241
++  * SAUCE: Lower message level for PCI memory and I/O allocation.
++    - LP: #159241
++  * Modify log generation to catch bug numbers when adding with git-am.
++
++  [Tim Gardner]
++
++  * Added the debian directory. Ignore: yes
++  * Add support for UBUNTUINCLUDE Ignore: yes
++  * LUM headers go in /usr/src Ignore: yes
++  * First pass at 2.6.25 configs Ignore: yes
++  * i386 -generic builds. Ignore: yes
++  * SAUCE: Increase CONFIG_IDE_MAX_HWIFS to 8 (from 4)
++  * SAUCE: Add extra headers to linux-libc-dev OriginalAuthor: Soren Hansen
++    OriginalLocation:
++    https://lists.ubuntu.com/archives/kernel-team/2007-November/001891.html
++  * Set CONFIG_DEVKMEM=n Ignore: yes
++  * Enabled ALSA and CGROUPS for i386 Ignore: yes
++  * Enabled amd64 configs. Ignore: yes
++  * CONFIG_STANDALONE=n Ignore: yes
++  * CONFIG_BLK_DEV_4DRIVES=n for i386 Ignore: yes
++  * CONFIG: CONFIG_DEFAULT_RELATIME=y for all flavours. Ignore: yes
++  * Set CONFIG_EDD_OFF=y Ignore: yes
++  * SAUCE: Blacklist Bluetooth Dell Wireless 370 for SCO MTU
++    OriginalAuthor: Mario Limonciello <Mario_Limonciello@Dell.com> Bug:
++    #209715
++  * SAUCE: Catch nonsense keycodes and silently ignore
++  * SAUCE: frame buffer regression - screen blank except for blinking
++    cursor after fbcon vtswitch OriginalAuthor: Matthew Garrett
++    <mjg59@srcf.ucam.org> Bug: #201591
++  * SAUCE: Added support for HDAPS on various ThinkPads from Lenovo and IBM
++    OriginalAuthor: Klaus S. Madsen <ubuntu@hjernemadsen.org>
++    OriginalAuthor: Chuck Short <zulcss@ubuntu.com>
++  * SAUCE: Guest OS does not recognize a lun with non zero target id on
++    Vmware ESX Server
++  * SAUCE: orinoco_cs.ko missing
++  * Set CONFIG_FB_VESA=m for i386/amd64 Ignore: yes
++  * Set CONFIG_PM_DISABLE_CONSOLE=y for all flavours Ignore: yes
++  * Thorough review of amd64 -generic config Ignore: yes
++  * Build PPA packages for Hardy until the Intrepid archive is opened.
++  * Deleted obsolete flavours Ignore: yes
++  * Don't build docs for PPA Ignore: yes
++  * Build all standard packages in PPA. Ignore: yes
++  * Remove duplicate USB ids
++  * SAUCE: DVB-USB UMT-010 driver oops on install Bug: #115284
++  * Update configs after rebase to 2.6.26-rc1 Ignore: yes
++  * Update configs after rebase Ignore: yes
++  * Disable V4L until the build issues get ironed out. Ignore: yes
++  * Update configs after rebase. Ignore: yes
++  * Another device enable pass Ignore: yes
++  * Update configs after merge. Ignore: yes
++  * SAUCE: fn key doesn't work in hardy with macbook pro fourth generation
++    (4,1)
++    - LP: #207127
++  * Enabled CONFIG_CIFS_DFS_UPCALL=y and CONFIG_CIFS_UPCALL=y
++    - LP: #236830
++
++  [Upstream Kernel Changes]
++
++  * Revert "[WATCHDOG] hpwdt: Add CFLAGS to get driver working"
++  * mac80211: detect driver tx bugs
++  * hwmon: (lm85) Fix function RANGE_TO_REG()
++  * hwmon: (adt7473) Initialize max_duty_at_overheat before use
++  * hwmon: Update the sysfs interface documentation
++  * hwmon: (abituguru3) Identify Abit AW8D board as such
++  * hwmon: (w83791d) new maintainer
++  * hwmon: (abituguru3) update driver detection
++  * hwmon: (lm75) sensor reading bugfix
++  * ipv6: Remove options header when setsockopt's optlen is 0
++  * ipv6: Drop packets for loopback address from outside of the box.
++  * sched: rt: dont stop the period timer when there are tasks wanting to
++    run
++  * sched: fix wait_for_completion_timeout() spurious failure under heavy
++    load
++  * x86: fix NULL pointer deref in __switch_to
++  * xen: Use wmb instead of rmb in xen_evtchn_do_upcall().
++  * xen: mask unwanted pte bits in __supported_pte_mask
++  * xen: don't drop NX bit
++  * sched: refactor wait_for_completion_timeout()
++  * Ext4: Fix online resize block group descriptor corruption
++  * [IA64] SN2: security hole in sn2_ptc_proc_write
++  * alpha: fix module load failures on smp (bug #10926)
++  * alpha: link failure fix
++  * alpha: fix compile failures with gcc-4.3 (bug #10438)
++  * alpha: resurrect Cypress IDE quirk
++  * pppoe: warning fix
++  * sctp: Make sure N * sizeof(union sctp_addr) does not overflow.
++  * netns: Don't receive new packets in a dead network namespace.
++  * Add return value to reserve_bootmem_node()
++  * Slab: Fix memory leak in fallback_alloc()
++  * Fix performance regression on lmbench select benchmark
++  * ALSA: aw2 - Fix Oops at initialization
++  * ALSA: sb - Fix wrong assertions
++  * futexes: fix fault handling in futex_lock_pi
++  * IB/mthca: Clear ICM pages before handing to FW
++  * tty_driver: Update required method documentation
++  * removed unused var real_tty on n_tty_ioctl()
++  * Fix ZERO_PAGE breakage with vmware
++  * mm: fix race in COW logic
++  * NFS: Reduce the NFS mount code stack usage.
++  * NFS: Fix filehandle size comparisons in the mount code
++  * NFS: nfs_updatepage(): don't mark page as dirty if an error occurred
++  * alpha: fix compile error in arch/alpha/mm/init.c
++  * KVM: Fix race between timer migration and vcpu migration
++  * KVM: close timer injection race window in __vcpu_run
++  * KVM: MMU: Fix rmap_write_protect() hugepage iteration bug
++  * KVM: MMU: large page update_pte issue with non-PAE 32-bit guests
++    (resend)
++  * KVM: MMU: Fix oops on guest userspace access to guest pagetable
++  * KVM: ioapic: fix lost interrupt when changing a device's irq
++  * KVM: VMX: Fix host msr corruption with preemption enabled
++  * [GFS2] BUG: unable to handle kernel paging request at ffff81002690e000
++  * xen: remove support for non-PAE 32-bit
++  * kgdb: documentation update - remove kgdboe
++  * kgdb: sparse fix
++  * [IA64] Fix boot failure on ia64/sn2
++  * [IA64] Handle count==0 in sn2_ptc_proc_write()
++  * [IA64] Eliminate NULL test after alloc_bootmem in iosapic_alloc_rte()
++  * [GFS2] fix gfs2 block allocation (cleaned up)
++  * x86: Add structs and functions for paravirt clocksource
++  * x86: Make xen use the paravirt clocksource structs and functions
++  * KVM: Make kvm host use the paravirt clocksource structs
++  * x86: KVM guest: Use the paravirt clocksource structs and functions
++  * KVM: Remove now unused structs from kvm_para.h
++  * enable bus mastering on i915 at resume time
++  * Linux 2.6.26-rc8
++  * # Ubuntu external driver commit.
++  * # Ubuntu commit template.
++
++ -- Ben Collins <ben.collins@canonical.com>  Sat, 21 Jun 2008 09:05:15 -0400
++
++linux (2.6.26-2.6) intrepid; urgency=low
++
++  [Ben Collins]
++
++  * Revert "SAUCE: Export symbols for aufs (in lum) (not needed)
++  * config: Enable DVB devices
++  * ubuntu/aufs: Make aufs a bool config, since it needs to be built-in
++  * config: Build aufs into the kernels
++  * build: Fix arguments passed to link-headers script
++  * config: Disable early printk
++  * d-i: Move isofs to storage-core and kill st (scsi tape) from list
++  * config: Enable non-promiscuous access to /dev/mem
++  * x86: Add option to disable decompression info messages
++  * config: Enable no-bz-chatter config options
++  * build: Re-add linux-source package
++  * d-i: Re-add socket-modules. Accidentally removed
++    - LP: #241295
++
++  [Colin Ian King]
++
++  * Add dm-loop
++
++  [Tim Gardner]
++
++  * Revert "SAUCE: USB bluetooth device 0x0e5e:0x6622 floods errors to
++    syslog (merged upstream)
++
++ -- Ben Collins <ben.collins@canonical.com>  Mon, 16 Jun 2008 10:56:01 -0400
++
++linux (2.6.26-1.5) intrepid; urgency=low
++
++  * d-i: Make virtio-ring optional (it's built-in on i386)
++  * Rebased on 2.6.26-rc6
++
++  [Ubuntu-2.6.26-1.4 Changes below]
++
++  * build: linux-doc rules got broken when disabling html side. Fixed now.
++
++  [Ubuntu-2.6.26-1.3 Changes below]
++
++  * build: Remove install-source, obsolete and caused build failure
++
++  [Ubuntu-2.6.26-1.2 Changes below]
++
++  * Remove efi-modules from d-i module list (efivars is built-in). Caused a
++    build failure.
++  * Patch to arch/x86/xen/time.c to remove __divdi3 usage (build failure on
++    i386).
++
++  [Ubuntu-2.6.26-1.1 Changes below]
++
++  [Amit Kucheria]
++
++  * SAUCE: make fc transport removal of target configurable
++  * SAUCE: Add AGP support for Radeon Mobility 9000 chipset
++  * SAUCE: pm: Config option to disable handling of console during
++    suspend/resume
++
++  [Ben Collins]
++
++  * SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps
++  * SAUCE: irda: Default to dongle type 9 on IBM hardware
++  * SAUCE: tulip: Let dmfe handle davicom on non-sparc
++  * SAUCE: tulip: Define ULI PCI ID's
++  * SAUCE: version: Implement version_signature proc file.
++  * build: Remove remnants of unused binary-custom infrastructure
++  * mmc_block: Fix bad allocation on 64-bit (zero len array)
++  * ubuntu: New modules, acer-acpi
++  * build: Remove -virtual, and rebuild configs
++  * ubuntu: Add drbd module
++  * ubuntu: Add iscsitarget module
++  * ubuntu: Add squashfs driver
++  * build/configs: The Great Config Consistency Check of 2008
++  * ubuntu: Add aufs module
++  * ubuntu: Added atl2 driver
++  * ubuntu: Add dm-radi4-5 driver
++  * build: Add CONFIG_DEBUG_SECTION_MISMATCH=y to get old style warnings
++    from build
++  * squashfs: Fixes for VFS changes
++  * ubuntu/dm-raid4-5: Fixups for moved/renamed headers/functions in core
++    md
++  * ubuntu: Add ndiswrapper driver
++  * d-i: Update module listings
++
++  [Chuck Short]
++
++  * SAUCE: ata: blacklist FUJITSU MHW2160BH PL
++  * SAUCE: [USB]: add ASUS LCM to the blacklist
++
++  [Colin Ian King]
++
++  * SAUCE: Enable speedstep for sonoma processors.
++  * SAUCE: airprime.c supports more devices
++
++  [Kyle McMartin]
++
++  * SAUCE: fix orinoco_cs oops
++
++  [Mario Limonciello]
++
++  * SAUCE: Enable Reset and SCO workaround on Dell 410 BT adapter
++
++  [Matthew Garrett]
++
++  * SAUCE: hostap: send events on data interface as well as master
++    interface
++
++  [Phillip Lougher]
++
++  * SAUCE: r8169: disable TSO by default for RTL8111/8168B chipsets.
++
++  [Stefan Bader]
++
++  * SAUCE: Export dm_disk function of device-mapper
++  * SAUCE: Restore VT fonts on switch
++  * SAUCE: Always use SCO protocol (disable eSCO support) Bug: #39414
++  * SAUCE: mmc: Increase power_up deleay to fix TI readers
++  * SAUCE: Add blacklist support to fix Belkin bluetooth dongle.
++  * SAUCE: Lower warning level of pci resource allocation messages.
++  * SAUCE: Lower message level for PCI memory and I/O allocation.
++    - LP: #159241
++  * Modify log generation to catch bug numbers when adding with git-am.
++
++  [Tim Gardner]
++
++  * SAUCE: hdaps module does not load on Thinkpad T61P
++  * SAUCE: Add extra headers to linux-libc-dev
++  * SAUCE: Export symbols for aufs (in lum).
++  * SAUCE: USB bluetooth device 0x0e5e:0x6622 floods errors to syslog
++  * SAUCE: Blacklist Bluetooth Dell Wireless 370 for SCO MTU
++  * SAUCE: Catch nonsense keycodes and silently ignore
++  * SAUCE: frame buffer regression - screen blank except for blinking
++    cursor after fbcon vtswitch
++  * SAUCE: Added support for HDAPS on various ThinkPads from Lenovo and IBM
++  * SAUCE: Guest OS does not recognize a lun with non zero target id on
++    Vmware ESX Server
++  * SAUCE: Modualrize vesafb
++  * SAUCE: DVB-USB UMT-010 driver oops on install
++  * SAUCE: fn key doesn't work in hardy with macbook pro fourth generation
++    (4,1)
++    - LP: #207127
++
++ -- Ben Collins <ben.collins@canonical.com>  Wed, 11 Jun 2008 05:28:35 -0400
+diff --git a/debian.master/config/amd64/config.common.amd64 b/debian.master/config/amd64/config.common.amd64
+new file mode 100644
+index 0000000..1377cde
+--- /dev/null
++++ b/debian.master/config/amd64/config.common.amd64
+@@ -0,0 +1,476 @@
++#
++# Config options for config.common.amd64 automatically generated by splitconfig.pl
++#
++CONFIG_64BIT=y
++CONFIG_6LOWPAN=m
++CONFIG_ABX500_CORE=y
++CONFIG_AC97_BUS=m
++# CONFIG_ACPI_REDUCED_HARDWARE_ONLY is not set
++CONFIG_ADFS_FS=m
++CONFIG_AFFS_FS=m
++CONFIG_AIX_PARTITION=y
++CONFIG_ALIM7101_WDT=m
++CONFIG_ALTERA_TSE=m
++CONFIG_AMIGA_PARTITION=y
++CONFIG_APPLICOM=m
++CONFIG_ARCH_DEFCONFIG="arch/x86/configs/x86_64_defconfig"
++CONFIG_ARCH_DMA_ADDR_T_64BIT=y
++CONFIG_ARCH_HWEIGHT_CFLAGS="-fcall-saved-rdi -fcall-saved-rsi -fcall-saved-rdx -fcall-saved-rcx -fcall-saved-r8 -fcall-saved-r9 -fcall-saved-r10 -fcall-saved-r11"
++# CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
++CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
++CONFIG_ARCH_RANDOM=y
++CONFIG_ARCH_SELECT_MEMORY_MODEL=y
++CONFIG_ARCH_SPARSEMEM_DEFAULT=y
++CONFIG_ARCNET=m
++CONFIG_ATALK=m
++CONFIG_ATARI_PARTITION=y
++CONFIG_ATA_GENERIC=y
++# CONFIG_ATA_NONSTANDARD is not set
++CONFIG_ATA_OVER_ETH=m
++CONFIG_ATA_PIIX=y
++CONFIG_ATM=m
++# CONFIG_AUDIT_ARCH_COMPAT_GENERIC is not set
++CONFIG_AUTOFS4_FS=m
++CONFIG_AUXDISPLAY=y
++CONFIG_BACKLIGHT_LCD_SUPPORT=y
++CONFIG_BATMAN_ADV=m
++CONFIG_BCH=m
++CONFIG_BCMA=m
++CONFIG_BCM_KONA_USB2_PHY=m
++CONFIG_BE2ISCSI=m
++CONFIG_BEFS_FS=m
++CONFIG_BFS_FS=m
++CONFIG_BLK_CPQ_CISS_DA=m
++CONFIG_BLK_DEV_3W_XXXX_RAID=m
++CONFIG_BLK_DEV_CRYPTOLOOP=m
++CONFIG_BLK_DEV_DAC960=m
++CONFIG_BLK_DEV_NVME=m
++CONFIG_BLK_DEV_PCIESSD_MTIP32XX=m
++CONFIG_BLK_DEV_RSXX=m
++CONFIG_BLK_DEV_SKD=m
++# CONFIG_BLK_DEV_SR_VENDOR is not set
++CONFIG_BLK_DEV_SX8=m
++CONFIG_BLK_DEV_UMEM=m
++CONFIG_BOUNCE=y
++CONFIG_BSD_DISKLABEL=y
++CONFIG_C2PORT=m
++CONFIG_CADENCE_WATCHDOG=m
++CONFIG_CAIF=m
++CONFIG_CAN=m
++CONFIG_CB710_CORE=m
++CONFIG_CC_STACKPROTECTOR=y
++CONFIG_CDROM_PKTCDVD=m
++CONFIG_CMA=y
++CONFIG_CMDLINE_PARTITION=y
++CONFIG_CONFIGFS_FS=m
++CONFIG_CRAMFS=m
++CONFIG_CRASH_DUMP=y
++# CONFIG_CXL_BASE is not set
++# CONFIG_CXL_EEH is not set
++# CONFIG_CXL_KERNEL_API is not set
++CONFIG_DECNET=m
++CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
++CONFIG_DMADEVICES=y
++CONFIG_DMA_SHARED_BUFFER=y
++CONFIG_DMA_VIRTUAL_CHANNELS=m
++# CONFIG_DM_DEBUG is not set
++CONFIG_DNET=m
++CONFIG_DRM=m
++CONFIG_DUMMY_IRQ=m
++CONFIG_DW_WATCHDOG=m
++CONFIG_ECHO=m
++CONFIG_EEPROM_93CX6=m
++CONFIG_EFS_FS=m
++# CONFIG_EM_TIMER_STI is not set
++CONFIG_ENCLOSURE_SERVICES=m
++CONFIG_ETHOC=m
++CONFIG_EXOFS_FS=m
++CONFIG_EXTCON=y
++CONFIG_F2FS_FS=m
++CONFIG_FB=y
++CONFIG_FB_ATY128=m
++CONFIG_FB_BOOT_VESA_SUPPORT=y
++# CONFIG_FB_CFB_REV_PIXELS_IN_BYTE is not set
++CONFIG_FB_IBM_GXT4500=m
++# CONFIG_FB_MACMODES is not set
++CONFIG_FB_SYS_COPYAREA=m
++CONFIG_FB_SYS_FILLRECT=m
++CONFIG_FB_SYS_FOPS=m
++CONFIG_FB_SYS_IMAGEBLIT=m
++CONFIG_FB_UDL=m
++CONFIG_FB_VOODOO1=m
++CONFIG_FDDI=y
++CONFIG_FEALNX=m
++CONFIG_FIREWIRE=m
++CONFIG_FIREWIRE_NOSY=m
++CONFIG_FIRMWARE_IN_KERNEL=y
++CONFIG_FIXED_PHY=y
++CONFIG_FMC=m
++# CONFIG_FONTS is not set
++CONFIG_FRAME_WARN=1024
++CONFIG_FUSION=y
++CONFIG_GAMEPORT=m
++CONFIG_GENERIC_PHY=y
++CONFIG_GPIO_GENERIC=m
++CONFIG_GPIO_GENERIC_PLATFORM=m
++CONFIG_GPIO_TWL4030=m
++CONFIG_GPIO_TWL6040=m
++# CONFIG_HAVE_64BIT_ALIGNED_ACCESS is not set
++# CONFIG_HAVE_AOUT is not set
++# CONFIG_HAVE_ARCH_BITREVERSE is not set
++CONFIG_HAVE_BOOTMEM_INFO_NODE=y
++# CONFIG_HAVE_GENERIC_DMA_COHERENT is not set
++CONFIG_HAVE_SETUP_PER_CPU_AREA=y
++CONFIG_HFSPLUS_FS=m
++CONFIG_HFS_FS=m
++CONFIG_HIBERNATION=y
++CONFIG_HIO=m
++CONFIG_HOTPLUG_PCI_PCIE=y
++CONFIG_HOTPLUG_PCI_SHPC=m
++CONFIG_HPET=y
++CONFIG_HPFS_FS=m
++CONFIG_HP_ILO=m
++CONFIG_HSI=m
++CONFIG_HSR=m
++CONFIG_HTC_PASIC3=m
++CONFIG_HUGETLB_PAGE=y
++CONFIG_HWMON=y
++CONFIG_HW_RANDOM_TIMERIOMEM=m
++# CONFIG_HZ_100 is not set
++CONFIG_I2C=y
++# CONFIG_I2C_SLAVE is not set
++CONFIG_I6300ESB_WDT=m
++CONFIG_IEEE802154=m
++CONFIG_IIO=m
++CONFIG_ILLEGAL_POINTER_VALUE=0xdead000000000000
++CONFIG_IMA=y
++CONFIG_INFINIBAND_NES=m
++CONFIG_INFINIBAND_OCRDMA=m
++CONFIG_INFINIBAND_QIB=m
++CONFIG_INPUT=y
++CONFIG_IPACK_BUS=m
++CONFIG_IPMI_HANDLER=m
++CONFIG_IPMI_SI_PROBE_DEFAULTS=y
++CONFIG_IPX=m
++# CONFIG_IP_DCCP_CCID3 is not set
++CONFIG_IRQ_BYPASS_MANAGER=m
++CONFIG_JFS_FS=m
++CONFIG_JME=m
++CONFIG_JUMP_LABEL=y
++CONFIG_KARMA_PARTITION=y
++CONFIG_KERNEL_GZIP=y
++# CONFIG_KERNEL_XZ is not set
++CONFIG_KVM=m
++CONFIG_LAPB=m
++CONFIG_LDM_PARTITION=y
++CONFIG_LIBNVDIMM=y
++CONFIG_LLC2=m
++CONFIG_LOG_BUF_SHIFT=18
++CONFIG_LPC_ICH=m
++CONFIG_LPC_SCH=m
++CONFIG_MAC_PARTITION=y
++CONFIG_MAGIC_SYSRQ_DEFAULT_ENABLE=0x1
++CONFIG_MAILBOX=y
++CONFIG_MAX63XX_WATCHDOG=m
++CONFIG_MCB=m
++CONFIG_MD_MULTIPATH=m
++CONFIG_MEDIA_SUPPORT=m
++CONFIG_MEGARAID_LEGACY=m
++CONFIG_MEGARAID_NEWGEN=y
++CONFIG_MEGARAID_SAS=m
++CONFIG_MEMORY=y
++CONFIG_MEMSTICK=m
++CONFIG_MFD_CORE=y
++CONFIG_MFD_JANZ_CMODIO=m
++CONFIG_MFD_KEMPLD=m
++CONFIG_MFD_MT6397=m
++CONFIG_MFD_RDC321X=m
++CONFIG_MFD_RTSX_PCI=m
++CONFIG_MFD_SM501=m
++CONFIG_MFD_SYSCON=y
++CONFIG_MFD_TI_AM335X_TSCADC=m
++# CONFIG_MFD_TMIO is not set
++CONFIG_MFD_VX855=m
++CONFIG_MII=m
++CONFIG_MINIX_FS=m
++CONFIG_MINIX_SUBPARTITION=y
++CONFIG_MMC=y
++CONFIG_MMC_BLOCK=m
++CONFIG_MMC_SDHCI=m
++CONFIG_MMC_SDHCI_PLTFM=m
++CONFIG_MTD=m
++CONFIG_MTD_BLKDEVS=m
++CONFIG_MTD_BLOCK=m
++CONFIG_MTD_CMDLINE_PARTS=m
++CONFIG_MTD_NAND=m
++CONFIG_MTD_NAND_BCH=m
++CONFIG_MTD_NAND_ECC=m
++CONFIG_MTD_NAND_IDS=m
++# CONFIG_MTD_NAND_OMAP_BCH_BUILD is not set
++CONFIG_NCP_FS=m
++CONFIG_NEED_DMA_MAP_STATE=y
++CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK=y
++CONFIG_NET_CADENCE=y
++CONFIG_NET_PACKET_ENGINE=y
++CONFIG_NET_VENDOR_3COM=y
++CONFIG_NET_VENDOR_ADAPTEC=y
++CONFIG_NET_VENDOR_AGERE=y
++CONFIG_NET_VENDOR_ALTEON=y
++CONFIG_NET_VENDOR_AMD=y
++CONFIG_NET_VENDOR_ARC=y
++CONFIG_NET_VENDOR_ATHEROS=y
++CONFIG_NET_VENDOR_BROADCOM=y
++CONFIG_NET_VENDOR_BROCADE=y
++CONFIG_NET_VENDOR_CAVIUM=y
++CONFIG_NET_VENDOR_CHELSIO=y
++CONFIG_NET_VENDOR_CISCO=y
++CONFIG_NET_VENDOR_DEC=y
++CONFIG_NET_VENDOR_DLINK=y
++CONFIG_NET_VENDOR_EMULEX=y
++CONFIG_NET_VENDOR_EXAR=y
++CONFIG_NET_VENDOR_EZCHIP=y
++CONFIG_NET_VENDOR_HP=y
++CONFIG_NET_VENDOR_INTEL=y
++CONFIG_NET_VENDOR_MARVELL=y
++CONFIG_NET_VENDOR_MICREL=y
++CONFIG_NET_VENDOR_MYRI=y
++CONFIG_NET_VENDOR_NATSEMI=y
++CONFIG_NET_VENDOR_NVIDIA=y
++CONFIG_NET_VENDOR_OKI=y
++CONFIG_NET_VENDOR_QLOGIC=y
++CONFIG_NET_VENDOR_QUALCOMM=y
++CONFIG_NET_VENDOR_RDC=y
++CONFIG_NET_VENDOR_REALTEK=y
++CONFIG_NET_VENDOR_RENESAS=y
++CONFIG_NET_VENDOR_ROCKER=y
++CONFIG_NET_VENDOR_SAMSUNG=y
++CONFIG_NET_VENDOR_SEEQ=y
++CONFIG_NET_VENDOR_SILAN=y
++CONFIG_NET_VENDOR_SIS=y
++CONFIG_NET_VENDOR_SMSC=y
++CONFIG_NET_VENDOR_STMICRO=y
++CONFIG_NET_VENDOR_SUN=y
++CONFIG_NET_VENDOR_SYNOPSYS=y
++CONFIG_NET_VENDOR_TEHUTI=y
++CONFIG_NET_VENDOR_TI=y
++CONFIG_NET_VENDOR_VIA=y
++CONFIG_NET_VENDOR_WIZNET=y
++CONFIG_NEW_LEDS=y
++CONFIG_NFC=m
++CONFIG_NODES_SHIFT=6
++CONFIG_NOZOMI=m
++CONFIG_NR_CPUS=512
++CONFIG_NTB=m
++# CONFIG_NTFS_RW is not set
++CONFIG_NUMA=y
++CONFIG_NUMA_BALANCING_DEFAULT_ENABLED=y
++# CONFIG_NUMA_EMU is not set
++CONFIG_NVMEM=m
++CONFIG_NVRAM=m
++CONFIG_N_GSM=m
++# CONFIG_OF is not set
++CONFIG_OMFS_FS=m
++CONFIG_OSF_PARTITION=y
++CONFIG_OUTPUT_FORMAT="elf64-x86-64"
++# CONFIG_PAGE_EXTENSION is not set
++CONFIG_PANIC_TIMEOUT=0
++CONFIG_PARPORT=m
++CONFIG_PATA_SIS=y
++CONFIG_PCCARD=m
++CONFIG_PCIPCWATCHDOG=m
++CONFIG_PCI_PASID=y
++CONFIG_PCI_PRI=y
++CONFIG_PCI_QUIRKS=y
++CONFIG_PCMCIA=m
++CONFIG_PGTABLE_LEVELS=4
++CONFIG_PGTABLE_MAPPING=y
++CONFIG_PHANTOM=m
++CONFIG_PHONET=m
++CONFIG_PHYLIB=y
++CONFIG_PHYSICAL_ALIGN=0x1000000
++CONFIG_PHYSICAL_START=0x1000000
++CONFIG_PHYS_ADDR_T_64BIT=y
++# CONFIG_PHY_EXYNOS5250_USB2 is not set
++CONFIG_PHY_PXA_28NM_HSIC=m
++CONFIG_PHY_PXA_28NM_USB2=m
++CONFIG_PM_DEBUG=y
++CONFIG_PM_DEVFREQ=y
++CONFIG_PM_WAKELOCKS=y
++CONFIG_POWERCAP=y
++CONFIG_POWER_AVS=y
++CONFIG_POWER_SUPPLY=y
++CONFIG_PPP=y
++CONFIG_PPS=m
++CONFIG_PPS_CLIENT_GPIO=m
++CONFIG_PPS_CLIENT_LDISC=m
++# CONFIG_PREEMPT_NONE is not set
++CONFIG_PROBE_EVENTS=y
++CONFIG_PSTORE=y
++# CONFIG_PSTORE_CONSOLE is not set
++CONFIG_PSTORE_RAM=m
++CONFIG_PTP_1588_CLOCK=m
++CONFIG_PWM=y
++CONFIG_QNX4FS_FS=m
++CONFIG_QNX6FS_FS=m
++CONFIG_R3964=m
++CONFIG_RANDOMIZE_BASE_MAX_OFFSET=0x40000000
++CONFIG_RAW_DRIVER=m
++CONFIG_RCU_CPU_STALL_TIMEOUT=60
++CONFIG_REED_SOLOMON=m
++CONFIG_REGULATOR=y
++CONFIG_REGULATOR_FIXED_VOLTAGE=m
++CONFIG_REGULATOR_TWL4030=m
++CONFIG_REISERFS_FS=m
++CONFIG_RESET_CONTROLLER=y
++CONFIG_RFKILL=y
++CONFIG_ROMFS_FS=m
++CONFIG_RTC_DRV_CMOS=y
++CONFIG_RTC_DRV_DS3232=m
++CONFIG_RTC_DRV_PCF8523=m
++CONFIG_RTC_DRV_TWL4030=m
++CONFIG_SATA_AHCI_PLATFORM=m
++CONFIG_SATA_SVW=m
++CONFIG_SCHED_SMT=y
++CONFIG_SCSI_3W_9XXX=m
++CONFIG_SCSI_3W_SAS=m
++CONFIG_SCSI_AACRAID=m
++CONFIG_SCSI_ACARD=m
++CONFIG_SCSI_ADVANSYS=m
++CONFIG_SCSI_AIC79XX=m
++CONFIG_SCSI_AIC7XXX=m
++CONFIG_SCSI_AIC94XX=m
++CONFIG_SCSI_AM53C974=m
++CONFIG_SCSI_ARCMSR=m
++CONFIG_SCSI_BFA_FC=m
++CONFIG_SCSI_BNX2X_FCOE=m
++CONFIG_SCSI_BNX2_ISCSI=m
++CONFIG_SCSI_CHELSIO_FCOE=m
++CONFIG_SCSI_CXGB3_ISCSI=m
++CONFIG_SCSI_CXGB4_ISCSI=m
++CONFIG_SCSI_DC395x=m
++CONFIG_SCSI_DMX3191D=m
++CONFIG_SCSI_DPT_I2O=m
++CONFIG_SCSI_ESAS2R=m
++CONFIG_SCSI_FUTURE_DOMAIN=m
++CONFIG_SCSI_HPSA=m
++CONFIG_SCSI_HPTIOP=m
++CONFIG_SCSI_INIA100=m
++CONFIG_SCSI_INITIO=m
++CONFIG_SCSI_IPS=m
++CONFIG_SCSI_LPFC=m
++CONFIG_SCSI_MVSAS=m
++CONFIG_SCSI_MVUMI=m
++CONFIG_SCSI_PM8001=m
++CONFIG_SCSI_PMCRAID=m
++CONFIG_SCSI_QLA_FC=m
++CONFIG_SCSI_QLA_ISCSI=m
++CONFIG_SCSI_QLOGIC_1280=m
++CONFIG_SCSI_SNIC=m
++CONFIG_SCSI_SRP_ATTRS=m
++CONFIG_SCSI_STEX=m
++CONFIG_SCSI_SYM53C8XX_2=m
++CONFIG_SCSI_UFSHCD=m
++CONFIG_SCSI_WD719X=m
++CONFIG_SECURITY_SELINUX_BOOTPARAM=y
++CONFIG_SECURITY_SELINUX_DISABLE=y
++CONFIG_SENSORS_SCH56XX_COMMON=m
++CONFIG_SERIAL_8250=y
++CONFIG_SERIAL_8250_DW=m
++# CONFIG_SERIAL_8250_FSL is not set
++CONFIG_SERIAL_ALTERA_JTAGUART=m
++CONFIG_SERIAL_ALTERA_UART=m
++CONFIG_SERIAL_ARC=m
++CONFIG_SERIAL_CORE=y
++CONFIG_SERIAL_FSL_LPUART=m
++CONFIG_SERIAL_JSM=m
++CONFIG_SERIAL_NONSTANDARD=y
++CONFIG_SERIAL_RP2=m
++CONFIG_SERIAL_SCCNXP=y
++CONFIG_SERIO=y
++CONFIG_SFC=m
++CONFIG_SGI_IOC4=m
++CONFIG_SGI_PARTITION=y
++# CONFIG_SH_TIMER_CMT is not set
++# CONFIG_SH_TIMER_MTU2 is not set
++# CONFIG_SH_TIMER_TMU is not set
++CONFIG_SLIP=m
++CONFIG_SND=m
++CONFIG_SND_DMAENGINE_PCM=m
++CONFIG_SND_EMU10K1_SEQ=m
++# CONFIG_SND_OPL4_LIB_SEQ is not set
++CONFIG_SND_PCM=m
++# CONFIG_SND_SBAWE_SEQ is not set
++CONFIG_SND_SOC=m
++CONFIG_SND_SOC_FSL_SSI=m
++CONFIG_SND_SOC_I2C_AND_SPI=m
++CONFIG_SND_SOC_IMX_AUDMUX=m
++# CONFIG_SND_SOC_RT5677_SPI is not set
++CONFIG_SND_SOC_SGTL5000=m
++CONFIG_SND_TIMER=m
++CONFIG_SOC_TI=y
++CONFIG_SOLARIS_X86_PARTITION=y
++CONFIG_SOUND=m
++CONFIG_SPI=y
++CONFIG_SPI_PXA2XX_PCI=m
++CONFIG_SPMI=m
++CONFIG_SRAM=y
++CONFIG_SSB=m
++CONFIG_STAGING=y
++# CONFIG_STANDALONE is not set
++CONFIG_STE_MODEM_RPROC=m
++CONFIG_SUN_PARTITION=y
++CONFIG_SYSV68_PARTITION=y
++CONFIG_SYSV_FS=m
++CONFIG_SYS_HYPERVISOR=y
++CONFIG_THERMAL=y
++CONFIG_THUNDERBOLT=m
++CONFIG_TIFM_CORE=m
++CONFIG_TIGON3=m
++CONFIG_TI_CPSW_ALE=m
++CONFIG_TRACE_SINK=m
++CONFIG_TTY_PRINTK=y
++CONFIG_UFS_FS=m
++CONFIG_UIO=m
++CONFIG_ULTRIX_PARTITION=y
++CONFIG_UNIXWARE_DISKLABEL=y
++CONFIG_UPROBES=y
++CONFIG_USB_EHCI_HCD_PLATFORM=y
++CONFIG_USB_GADGET=m
++# CONFIG_USB_G_MULTI is not set
++CONFIG_USB_HCD_BCMA=m
++CONFIG_USB_HCD_SSB=m
++CONFIG_USB_MUSB_HDRC=m
++CONFIG_USB_OHCI_HCD_PLATFORM=y
++CONFIG_USB_SUPPORT=y
++CONFIG_UWB=m
++CONFIG_VFIO=m
++CONFIG_VFIO_IOMMU_TYPE1=m
++CONFIG_VFIO_PCI=m
++CONFIG_VFIO_VIRQFD=m
++CONFIG_VGASTATE=m
++CONFIG_VIRTIO_MMIO=y
++# CONFIG_VM86 is not set
++CONFIG_VME_BUS=y
++CONFIG_VMXNET3=m
++CONFIG_VXFS_FS=m
++CONFIG_W1=m
++CONFIG_WAN=y
++CONFIG_WDTPCI=m
++CONFIG_WIMAX=m
++CONFIG_X25=m
++CONFIG_X86_MINIMUM_CPU_FAMILY=64
++CONFIG_X86_SPEEDSTEP_LIB=m
++CONFIG_XEN=y
++CONFIG_XEN_BALLOON_MEMORY_HOTPLUG_LIMIT=512
++CONFIG_XILINX_WATCHDOG=m
++CONFIG_XILLYBUS=m
++CONFIG_XZ_DEC_ARM=y
++CONFIG_XZ_DEC_ARMTHUMB=y
++CONFIG_XZ_DEC_BCJ=y
++CONFIG_XZ_DEC_IA64=y
++CONFIG_XZ_DEC_POWERPC=y
++CONFIG_XZ_DEC_SPARC=y
++CONFIG_XZ_DEC_TEST=m
++CONFIG_XZ_DEC_X86=y
++CONFIG_ZLIB_DEFLATE=y
++CONFIG_ZONE_DMA_FLAG=1
+diff --git a/debian.master/config/amd64/config.flavour.generic b/debian.master/config/amd64/config.flavour.generic
+new file mode 100644
+index 0000000..4a96322
+--- /dev/null
++++ b/debian.master/config/amd64/config.flavour.generic
+@@ -0,0 +1,10 @@
++#
++# Config options for config.flavour.generic automatically generated by splitconfig.pl
++#
++CONFIG_HZ=250
++# CONFIG_HZ_1000 is not set
++CONFIG_HZ_250=y
++# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
++CONFIG_OPENNSL=y
++# CONFIG_PREEMPT is not set
++CONFIG_PREEMPT_VOLUNTARY=y
+diff --git a/debian.master/config/amd64/config.flavour.lowlatency b/debian.master/config/amd64/config.flavour.lowlatency
+new file mode 100644
+index 0000000..305bd16
+--- /dev/null
++++ b/debian.master/config/amd64/config.flavour.lowlatency
+@@ -0,0 +1,10 @@
++#
++# Config options for config.flavour.lowlatency automatically generated by splitconfig.pl
++#
++CONFIG_HZ=1000
++CONFIG_HZ_1000=y
++# CONFIG_HZ_250 is not set
++CONFIG_IRQ_FORCED_THREADING_DEFAULT=y
++# CONFIG_OPENNSL is not set
++CONFIG_PREEMPT=y
++# CONFIG_PREEMPT_VOLUNTARY is not set
+diff --git a/debian.master/config/annotations b/debian.master/config/annotations
+new file mode 100644
+index 0000000..03907f5
+--- /dev/null
++++ b/debian.master/config/annotations
+@@ -0,0 +1,10303 @@
++# Menu: HEADER
++# FORMAT: 2
++# ARCH: x86 arm powerpc s390
++
++# Mark debugging symbols.
++#  exceptions
++CONFIG_DEBUG_FS                                 note<required debug option>
++CONFIG_DEBUG_KERNEL                             note<required debug option>
++
++# Menu: ROOT
++CONFIG_RELOCATABLE                              policy<{'amd64': 'y', 'i386': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_LIVEPATCH                                policy<{'amd64': 'y', 's390x': 'n'}>
++
++# Menu: ARM Accelerated Cryptographic Algorithms >> Architecture: arm
++CONFIG_ARM_CRYPTO                               policy<{'armhf': 'y'}>
++CONFIG_CRYPTO_SHA1_ARM                          policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_SHA1_ARM_NEON                     policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_SHA1_ARM_CE                       policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_SHA2_ARM_CE                       policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_SHA256_ARM                        policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_SHA512_ARM                        policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_AES_ARM                           policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_AES_ARM_BS                        policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_AES_ARM_CE                        policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_GHASH_ARM_CE                      policy<{'armhf': 'm'}>
++
++# Menu: Advanced setup >> Architecture: powerpc
++
++# Menu: Advanced setup >> Prompt for advanced kernel configuration options
++
++# Menu: Advanced setup >> Prompt for advanced kernel configuration options >> Architecture: powerpc
++CONFIG_ADVANCED_OPTIONS                         policy<{'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_LOWMEM_CAM_NUM                           policy<{'powerpc-powerpc-e500mc': '3'}>
++
++# Menu: Architecture: arm
++CONFIG_ARM_DMA_IOMMU_ALIGNMENT                  policy<{'armhf': '8'}>
++CONFIG_ARM_PATCH_PHYS_VIRT                      policy<{'armhf': 'y'}>
++
++# Menu: Architecture: arm64
++CONFIG_ARM64_VA_BITS                            policy<{'arm64': '48'}>
++CONFIG_ARM64_VA_BITS                            mark<ENFORCED> note<Cavium ThunderX 2-socket needs a minimum of 41 bits of VA>
++
++# Menu: Architecture: powerpc
++CONFIG_PPC64                                    policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'y'}>
++CONFIG_NR_IRQS                                  policy<{'powerpc': '512', 'ppc64el': '512'}>
++CONFIG_SCOM_DEBUGFS                             policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++
++# Menu: Architecture: x86
++CONFIG_64BIT                                    policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'n', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Boot options
++CONFIG_CMDLINE                                  policy<{'arm64': '"console=ttyAMA0"', 'armhf': '""'}>
++CONFIG_KEXEC                                    policy<{'amd64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRASH_DUMP                               policy<{'amd64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_CRASH_DUMP                               mark<ENFORCED> note<LP:1363180>
++
++# Menu: Boot options >> Architecture: arm
++CONFIG_USE_OF                                   policy<{'armhf': 'y'}>
++CONFIG_ATAGS                                    policy<{'armhf': 'y'}>
++CONFIG_DEPRECATED_PARAM_STRUCT                  policy<{'armhf': 'n'}>
++CONFIG_ARM_APPENDED_DTB                         policy<{'armhf': 'y'}>
++CONFIG_ARM_ATAG_DTB_COMPAT                      policy<{'armhf-generic': 'y', 'armhf-generic-lpae': 'n'}>
++CONFIG_ATAGS_PROC                               policy<{'armhf': 'y'}>
++CONFIG_AUTO_ZRELADDR                            policy<{'armhf': 'y'}>
++#
++CONFIG_ARM_ATAG_DTB_COMPAT                      flag<REVIEW>
++
++# Menu: Boot options >> Kernel command line type
++CONFIG_CMDLINE_FORCE                            policy<{'arm64': 'n'}>
++
++# Menu: Boot options >> Kernel command line type >> Architecture: arm
++CONFIG_ARM_ATAG_DTB_COMPAT_CMDLINE_FROM_BOOTLOADER policy<{'armhf-generic': 'n'}>
++CONFIG_ARM_ATAG_DTB_COMPAT_CMDLINE_EXTEND       policy<{'armhf-generic': 'y'}>
++
++# Menu: Bus options (PCI etc.)
++CONFIG_ISA                                      policy<{'i386': 'y', 'powerpc-powerpc-smp': 'n'}>
++
++# Menu: Bus options (PCI etc.) >> Architecture: arm
++
++# Menu: Bus options (PCI etc.) >> Architecture: powerpc
++CONFIG_FSL_LBC                                  policy<{'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Bus options (PCI etc.) >> Architecture: s390
++CONFIG_QDIO                                     policy<{'s390x': 'm'}>
++CONFIG_CHSC_SCH                                 policy<{'s390x': 'm'}>
++CONFIG_SCM_BUS                                  policy<{'s390x': 'y'}>
++CONFIG_EADM_SCH                                 policy<{'s390x': 'm'}>
++
++# Menu: Bus options (PCI etc.) >> Architecture: x86
++CONFIG_ISA_DMA_API                              policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SCx200                                   policy<{'i386': 'm'}>
++CONFIG_SCx200HR_TIMER                           policy<{'i386': 'm'}>
++CONFIG_ALIX                                     policy<{'i386': 'y'}>
++CONFIG_NET5501                                  policy<{'i386': 'y'}>
++CONFIG_GEOS                                     policy<{'i386': 'y'}>
++CONFIG_X86_SYSFB                                policy<{'amd64': 'n', 'i386': 'n'}>
++#
++CONFIG_X86_SYSFB                                flag<REVIEW>
++
++# Menu: Bus options (PCI etc.) >> EISA support
++CONFIG_EISA_VLB_PRIMING                         policy<{'i386': 'y'}>
++CONFIG_EISA_PCI_EISA                            policy<{'i386': 'y'}>
++CONFIG_EISA_VIRTUAL_ROOT                        policy<{'i386': 'y'}>
++CONFIG_EISA_NAMES                               policy<{'i386': 'y'}>
++
++# Menu: Bus options (PCI etc.) >> EISA support >> Architecture: x86
++CONFIG_EISA                                     policy<{'i386': 'y'}>
++
++# Menu: Bus options (PCI etc.) >> PCCard (PCMCIA/CardBus) support
++CONFIG_PCCARD                                   policy<{'amd64': 'm', 'armhf': 'n', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'n'}>
++CONFIG_CARDBUS                                  policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y'}>
++
++# Menu: Bus options (PCI etc.) >> PCCard (PCMCIA/CardBus) support >> 16-bit PCMCIA support
++CONFIG_PCMCIA                                   policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 's390x': 'n'}>
++CONFIG_PCMCIA_LOAD_CIS                          policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y'}>
++CONFIG_PD6729                                   policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_I82092                                   policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_I82365                                   policy<{'i386': 'm'}>
++CONFIG_TCIC                                     policy<{'i386': 'm'}>
++CONFIG_ELECTRA_CF                               policy<{'powerpc-powerpc64-smp': 'm'}>
++
++# Menu: Bus options (PCI etc.) >> PCCard (PCMCIA/CardBus) support >> CardBus yenta-compatible bridge support
++CONFIG_YENTA                                    policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_YENTA_O2                                 policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y'}>
++CONFIG_YENTA_RICOH                              policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y'}>
++CONFIG_YENTA_TI                                 policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y'}>
++CONFIG_YENTA_ENE_TUNE                           policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y'}>
++CONFIG_YENTA_TOSHIBA                            policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y'}>
++
++# Menu: Bus options (PCI etc.) >> PCI support
++CONFIG_PCI                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PCI_MSI                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PCI_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_PCI_REALLOC_ENABLE_AUTO                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PCI_STUB                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_XEN_PCIDEV_FRONTEND                      policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_HT_IRQ                                   policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_PCI_IOV                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PCI_PRI                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_PCI_PASID                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++
++# Menu: Bus options (PCI etc.) >> PCI support >> Architecture: s390
++CONFIG_PCI_NR_FUNCTIONS                         policy<{'s390x': '64'}>
++CONFIG_PCI_NR_MSI                               policy<{'s390x': '256'}>
++
++# Menu: Bus options (PCI etc.) >> PCI support >> Architecture: x86
++CONFIG_PCI_MMCONFIG                             policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_PCI_CNB20LE_QUIRK                        policy<{'amd64': 'n', 'i386': 'n'}>
++
++# Menu: Bus options (PCI etc.) >> PCI support >> PCI Express Port Bus support
++CONFIG_PCIEPORTBUS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_HOTPLUG_PCI_PCIE                         policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'n', 's390x': 'y'}>
++CONFIG_PCIEAER                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PCIE_ECRC                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_PCIEAER_INJECT                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_PCIEASPM                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PCIEASPM_DEBUG                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_PCIEASPM_DEBUG                           note<LP#1398544>
++CONFIG_HOTPLUG_PCI_PCIE                         mark<ENFORCED> note<LP#1374440>
++CONFIG_PCIEAER_INJECT                           flag<TESTING>
++
++# Menu: Bus options (PCI etc.) >> PCI support >> PCI Express Port Bus support >> Default ASPM policy
++CONFIG_PCIEASPM_DEFAULT                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PCIEASPM_POWERSAVE                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_PCIEASPM_PERFORMANCE                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_PCIEASPM_DEFAULT                         note<LP#1398544>
++
++# Menu: Bus options (PCI etc.) >> PCI support >> PCI access mode >> Architecture: x86
++CONFIG_PCI_GOBIOS                               policy<{'i386': 'n'}>
++CONFIG_PCI_GOMMCONFIG                           policy<{'i386': 'n'}>
++CONFIG_PCI_GODIRECT                             policy<{'i386': 'n'}>
++CONFIG_PCI_GOANY                                policy<{'i386': 'y'}>
++
++# Menu: Bus options (PCI etc.) >> PCI support >> PCI host controller drivers
++CONFIG_PCI_DRA7XX                               policy<{'armhf': 'y'}>
++CONFIG_PCI_MVEBU                                policy<{'armhf': 'y'}>
++CONFIG_PCI_EXYNOS                               policy<{'armhf': 'y'}>
++CONFIG_PCI_IMX6                                 policy<{'armhf-generic': 'y'}>
++CONFIG_PCI_TEGRA                                policy<{'armhf-generic': 'y'}>
++CONFIG_PCI_RCAR_GEN2                            policy<{'armhf': 'y'}>
++CONFIG_PCI_RCAR_GEN2_PCIE                       policy<{'armhf': 'y'}>
++CONFIG_PCI_HOST_GENERIC                         policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_PCI_XGENE                                policy<{'arm64': 'y'}>
++CONFIG_PCI_XGENE_MSI                            policy<{'arm64': 'y'}>
++CONFIG_PCI_LAYERSCAPE                           policy<{'armhf': 'n'}>
++CONFIG_PCIE_IPROC                               policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PCIE_IPROC_PLATFORM                      policy<{'arm64': 'm'}>
++
++# Menu: Bus options (PCI etc.) >> PCI support >> RapidIO support
++CONFIG_RAPIDIO                                  policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RAPIDIO_TSI721                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RAPIDIO_DISC_TIMEOUT                     policy<{'amd64': '30', 'i386': '30', 'powerpc': '30', 'ppc64el': '30'}>
++CONFIG_RAPIDIO_ENABLE_RX_TX_PORTS               policy<{'amd64': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_RAPIDIO_DMA_ENGINE                       policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RAPIDIO_DEBUG                            policy<{'amd64': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Bus options (PCI etc.) >> PCI support >> RapidIO support >> Architecture: powerpc
++CONFIG_FSL_RIO                                  policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++
++# Menu: Bus options (PCI etc.) >> PCI support >> RapidIO support >> Enumeration method
++CONFIG_RAPIDIO_ENUM_BASIC                       policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Bus options (PCI etc.) >> PCI support >> RapidIO support >> RapidIO Switch drivers
++CONFIG_RAPIDIO_TSI57X                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RAPIDIO_CPS_XX                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RAPIDIO_TSI568                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RAPIDIO_CPS_GEN2                         policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Bus options (PCI etc.) >> PCI support >> Support for PCI Hotplug
++CONFIG_HOTPLUG_PCI                              policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_HOTPLUG_PCI_COMPAQ                       policy<{'i386': 'm'}>
++CONFIG_HOTPLUG_PCI_COMPAQ_NVRAM                 policy<{'i386': 'y'}>
++CONFIG_HOTPLUG_PCI_IBM                          policy<{'i386': 'm'}>
++CONFIG_HOTPLUG_PCI_ACPI                         policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_HOTPLUG_PCI_ACPI_IBM                     policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_HOTPLUG_PCI_CPCI                         policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_HOTPLUG_PCI_CPCI_ZT5550                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_HOTPLUG_PCI_CPCI_GENERIC                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_HOTPLUG_PCI_SHPC                         policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_HOTPLUG_PCI_RPA                          policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_HOTPLUG_PCI_RPA_DLPAR                    policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_HOTPLUG_PCI_S390                         policy<{'s390x': 'y'}>
++#
++CONFIG_HOTPLUG_PCI_SHPC                         note<LP#1374440>
++
++# Menu: Cryptographic API
++CONFIG_CRYPTO                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_RSA                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_MANAGER                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_USER                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_MANAGER_DISABLE_TESTS             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_GF128MUL                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_NULL                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_PCRYPT                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CRYPTD                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_MCRYPTD                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_AUTHENC                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_TEST                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CCM                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_GCM                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CHACHA20POLY1305                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_SEQIV                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_ECHAINIV                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CBC                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_CTR                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CTS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_ECB                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_LRW                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_PCBC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_XTS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CMAC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_HMAC                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_XCBC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_VMAC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CRC32C                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_CRC32C_INTEL                      policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_CRYPTO_CRC32                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CRC32_PCLMUL                      policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_CRYPTO_CRCT10DIF                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_CRCT10DIF_PCLMUL                  policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_GHASH                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_POLY1305                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_POLY1305_X86_64                   policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_MD4                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_MD5                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_MD5_PPC                           policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CRYPTO_MICHAEL_MIC                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_RMD128                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_RMD160                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_RMD256                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_RMD320                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_SHA1                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_SHA1_SSSE3                        policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_SHA256_SSSE3                      policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_SHA512_SSSE3                      policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_SHA1_PPC                          policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CRYPTO_SHA1_MB                           policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_SHA256                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_SHA512                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_TGR192                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_WP512                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_GHASH_CLMUL_NI_INTEL              policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_AES                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_AES_586                           policy<{'i386': 'm'}>
++CONFIG_CRYPTO_AES_X86_64                        policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_AES_NI_INTEL                      policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_CRYPTO_ANUBIS                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_ARC4                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_BLOWFISH                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_BLOWFISH_X86_64                   policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_CAMELLIA                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CAMELLIA_X86_64                   policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_CAMELLIA_AESNI_AVX_X86_64         policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_CAMELLIA_AESNI_AVX2_X86_64        policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_CAST5                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CAST5_AVX_X86_64                  policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_CAST6                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CAST6_AVX_X86_64                  policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_DES                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_DES3_EDE_X86_64                   policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_FCRYPT                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_KHAZAD                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_SALSA20                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_SALSA20_586                       policy<{'i386': 'm'}>
++CONFIG_CRYPTO_SALSA20_X86_64                    policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_CHACHA20                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_CHACHA20_X86_64                   policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_SEED                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_SERPENT                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_SERPENT_SSE2_X86_64               policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_SERPENT_SSE2_586                  policy<{'i386': 'm'}>
++CONFIG_CRYPTO_SERPENT_AVX_X86_64                policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_SERPENT_AVX2_X86_64               policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_TEA                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_TWOFISH                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_TWOFISH_586                       policy<{'i386': 'm'}>
++CONFIG_CRYPTO_TWOFISH_X86_64                    policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_TWOFISH_X86_64_3WAY               policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_TWOFISH_AVX_X86_64                policy<{'amd64': 'm'}>
++CONFIG_CRYPTO_DEFLATE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_ZLIB                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_LZO                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_842                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_LZ4                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_LZ4HC                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_ANSI_CPRNG                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_JITTERENTROPY                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_USER_API_HASH                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_USER_API_SKCIPHER                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_USER_API_RNG                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_USER_API_AEAD                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++#
++CONFIG_CRYPTO_MANAGER_DISABLE_TESTS             flag<TESTING>
++CONFIG_CRYPTO_TEST                              flag<TESTING>
++CONFIG_CRYPTO_SHA512                            note<module signing>
++
++# Menu: Cryptographic API >> Asymmetric (public-key cryptographic) key type
++CONFIG_ASYMMETRIC_KEY_TYPE                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ASYMMETRIC_PUBLIC_KEY_SUBTYPE            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PUBLIC_KEY_ALGO_RSA                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_X509_CERTIFICATE_PARSER                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PKCS7_MESSAGE_PARSER                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PKCS7_TEST_KEY                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SIGNED_PE_FILE_VERIFICATION              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_ASYMMETRIC_KEY_TYPE                      note<module signing>
++CONFIG_ASYMMETRIC_PUBLIC_KEY_SUBTYPE            note<module signing>
++CONFIG_PUBLIC_KEY_ALGO_RSA                      note<module signing>
++CONFIG_X509_CERTIFICATE_PARSER                  note<module signing>
++
++# Menu: Cryptographic API >> Certificates for signature checking
++CONFIG_MODULE_SIG_KEY                           policy<{'amd64': '"certs/signing_key.pem"', 'arm64': '"certs/signing_key.pem"', 'armhf': '"certs/signing_key.pem"', 'i386': '"certs/signing_key.pem"', 'powerpc': '"certs/signing_key.pem"', 'ppc64el': '"certs/signing_key.pem"', 's390x': '"certs/signing_key.pem"'}>
++CONFIG_SYSTEM_TRUSTED_KEYRING                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SYSTEM_TRUSTED_KEYS                      policy<{'amd64': '""', 'arm64': '""', 'armhf': '""', 'i386': '""', 'powerpc': '""', 'ppc64el': '""', 's390x': '""'}>
++
++# Menu: Cryptographic API >> Hardware crypto devices
++CONFIG_CRYPTO_HW                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_DEV_PADLOCK                       policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_CRYPTO_DEV_PADLOCK_AES                   policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_CRYPTO_DEV_PADLOCK_SHA                   policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_CRYPTO_DEV_GEODE                         policy<{'i386': 'm'}>
++CONFIG_ZCRYPT                                   policy<{'s390x': 'm'}>
++CONFIG_CRYPTO_SHA1_S390                         policy<{'s390x': 'm'}>
++CONFIG_CRYPTO_SHA256_S390                       policy<{'s390x': 'm'}>
++CONFIG_CRYPTO_SHA512_S390                       policy<{'s390x': 'm'}>
++CONFIG_CRYPTO_DES_S390                          policy<{'s390x': 'm'}>
++CONFIG_CRYPTO_AES_S390                          policy<{'s390x': 'm'}>
++CONFIG_S390_PRNG                                policy<{'s390x': 'm'}>
++CONFIG_CRYPTO_GHASH_S390                        policy<{'s390x': 'm'}>
++CONFIG_CRYPTO_DEV_MV_CESA                       policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_DEV_MARVELL_CESA                  policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_DEV_HIFN_795X                     policy<{'armhf-generic': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_CRYPTO_DEV_HIFN_795X_RNG                 policy<{'armhf-generic': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_CRYPTO_DEV_FSL_CAAM                      policy<{'armhf-generic': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_CRYPTO_DEV_FSL_CAAM_DEBUG                policy<{'armhf-generic': 'n', 'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_CRYPTO_DEV_TALITOS                       policy<{'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_CRYPTO_DEV_TALITOS2                      policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_CRYPTO_DEV_OMAP_SHAM                     policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_DEV_OMAP_AES                      policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_DEV_OMAP_DES                      policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_DEV_SAHARA                        policy<{'armhf-generic': 'm'}>
++CONFIG_CRYPTO_DEV_S5P                           policy<{'armhf': 'm'}>
++CONFIG_CRYPTO_DEV_NX                            policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_CRYPTO_DEV_NX_ENCRYPT                    policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_CRYPTO_DEV_NX_COMPRESS                   policy<{'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_CRYPTO_DEV_NX_COMPRESS_PSERIES           policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_CRYPTO_DEV_NX_COMPRESS_POWERNV           policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_CRYPTO_DEV_CCP                           policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_CRYPTO_DEV_CCP_DD                        policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_CRYPTO_DEV_CCP_CRYPTO                    policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_CRYPTO_DEV_QAT_DH895xCC                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_CRYPTO_DEV_QAT_DH895xCCVF                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_CRYPTO_DEV_QCE                           policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_CRYPTO_DEV_VMX                           policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_CRYPTO_DEV_VMX_ENCRYPT                   policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++
++# Menu: Cryptographic API >> Hardware crypto devices >> Freescale CAAM Job Ring driver backend
++CONFIG_CRYPTO_DEV_FSL_CAAM_JR                   policy<{'armhf-generic': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_CRYPTO_DEV_FSL_CAAM_RINGSIZE             policy<{'armhf-generic': '9', 'powerpc-powerpc64-emb': '9', 'powerpc-powerpc-e500mc': '9'}>
++CONFIG_CRYPTO_DEV_FSL_CAAM_INTC                 policy<{'armhf-generic': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_CRYPTO_DEV_FSL_CAAM_INTC_COUNT_THLD      policy<{'armhf-generic': '255', 'powerpc-powerpc64-emb': '255', 'powerpc-powerpc-e500mc': '255'}>
++CONFIG_CRYPTO_DEV_FSL_CAAM_INTC_TIME_THLD       policy<{'armhf-generic': '2048', 'powerpc-powerpc64-emb': '2048', 'powerpc-powerpc-e500mc': '2048'}>
++CONFIG_CRYPTO_DEV_FSL_CAAM_CRYPTO_API           policy<{'armhf-generic': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_CRYPTO_DEV_FSL_CAAM_AHASH_API            policy<{'armhf-generic': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_CRYPTO_DEV_FSL_CAAM_RNG_API              policy<{'armhf-generic': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++
++# Menu: Cryptographic API >> NIST SP800-90A DRBG
++CONFIG_CRYPTO_DRBG_MENU                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRYPTO_DRBG_HASH                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRYPTO_DRBG_CTR                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Device Drivers
++CONFIG_TEGRA_AHB                                policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_RESET_CONTROLLER                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_THUNDERBOLT                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++
++# Menu: Device Drivers >> ATA/ATAPI/MFM/RLL support (DEPRECATED)
++CONFIG_IDE                                      policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> ATA/ATAPI/MFM/RLL support (DEPRECATED) >> IDE Mode for AMD Alchemy Au1200
++
++# Menu: Device Drivers >> Accessibility support
++CONFIG_ACCESSIBILITY                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_ACCESSIBILITY                            flag<REVIEW>
++
++# Menu: Device Drivers >> Adaptive Voltage Scaling class support
++CONFIG_POWER_AVS                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++
++# Menu: Device Drivers >> Android
++CONFIG_ANDROID                                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Device Drivers >> Auxiliary Display support
++CONFIG_AUXDISPLAY                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_KS0108                                   policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KS0108_DELAY                             policy<{'amd64': '2', 'armhf': '2', 'i386': '2', 'powerpc': '2', 'ppc64el': '2'}>
++CONFIG_CFAG12864B                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_CFAG12864B_RATE                          policy<{'amd64': '20', 'i386': '20'}>
++
++# Menu: Device Drivers >> Block devices
++CONFIG_BLK_DEV                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_DEV_NULL_BLK                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BLK_DEV_FD                               policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MAC_FLOPPY                               policy<{'powerpc-powerpc-smp': 'm'}>
++CONFIG_BLK_DEV_PCIESSD_MTIP32XX                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_ZRAM                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_ZRAM_LZ4_COMPRESS                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_CPQ_CISS_DA                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_CISS_SCSI_TAPE                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BLK_DEV_DAC960                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_BLK_DEV_UMEM                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_BLK_DEV_LOOP                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_DEV_LOOP_MIN_COUNT                   policy<{'amd64': '8', 'arm64': '8', 'armhf': '8', 'i386': '8', 'powerpc': '8', 'ppc64el': '8', 's390x': '8'}>
++CONFIG_BLK_DEV_CRYPTOLOOP                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_BLK_DEV_DRBD                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DRBD_FAULT_INJECTION                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_BLK_DEV_NBD                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BLK_DEV_NVME                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_BLK_DEV_SKD                              policy<{'amd64': 'm', 'arm64': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_BLK_DEV_OSD                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BLK_DEV_SX8                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_CDROM_PKTCDVD                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_CDROM_PKTCDVD_BUFFERS                    policy<{'amd64': '8', 'arm64': '8', 'armhf': '8', 'i386': '8', 'powerpc': '8', 'ppc64el': '8'}>
++CONFIG_CDROM_PKTCDVD_WCACHE                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATA_OVER_ETH                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MG_DISK                                  policy<{'armhf': 'm'}>
++CONFIG_MG_DISK_RES                              policy<{'armhf': '0'}>
++CONFIG_BLK_DEV_XPRAM                            policy<{'s390x': 'n'}>
++CONFIG_DCSSBLK                                  policy<{'s390x': 'm'}>
++CONFIG_SCM_BLOCK                                policy<{'s390x': 'm'}>
++CONFIG_SCM_BLOCK_CLUSTER_WRITE                  policy<{'s390x': 'y'}>
++CONFIG_XEN_BLKDEV_FRONTEND                      policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_XEN_BLKDEV_BACKEND                       policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_VIRTIO_BLK                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_DEV_HD                               policy<{'amd64': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_BLK_DEV_RBD                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BLK_DEV_RSXX                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++#
++CONFIG_BLK_DEV_UMEM                             note<experimental NVRAM disk driver -- opt-in>
++CONFIG_CDROM_PKTCDVD_WCACHE                     mark<DANGEROUS>
++CONFIG_XEN_BLKDEV_FRONTEND                      note<not autoloadable -- XEN paravirt support>
++CONFIG_VIRTIO_BLK                               note<KVM paravirt support -- not autoloadable>
++CONFIG_BLK_DEV_HD                               note<very old disk device support> mark<ANCIENT>
++
++# Menu: Device Drivers >> Block devices >> Parallel port IDE device support
++CONFIG_PARIDE                                   policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_PD                                policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_PCD                               policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_PF                                policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_PT                                policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_PG                                policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_ATEN                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_BPCK                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_BPCK6                             policy<{'armhf': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_PARIDE_COMM                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_DSTR                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_FIT2                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_FIT3                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_EPAT                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_EPATC8                            policy<{'amd64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PARIDE_EPIA                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_FRIQ                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_FRPW                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_KBIC                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_KTTI                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_ON20                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARIDE_ON26                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Block devices >> RAM block device support
++CONFIG_BLK_DEV_RAM                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BLK_DEV_RAM_COUNT                        policy<{'amd64': '16', 'arm64': '16', 'armhf': '16', 'i386': '16', 'powerpc': '16', 'ppc64el': '16', 's390x': '16'}>
++CONFIG_BLK_DEV_RAM_SIZE                         policy<{'amd64': '65536', 'arm64': '65536', 'armhf': '65536', 'i386': '65536', 'powerpc': '65536', 'ppc64el': '65536', 's390x': '65536'}>
++CONFIG_BLK_DEV_RAM_DAX                          policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_BLK_DEV_RAM				note<LP #1593293>
++CONFIG_BLK_DEV_RAM_SIZE                         mark<ENFORCED> note<Ramdisk size should be a minimum of 64M> flag<REVIEW>
++
++# Menu: Device Drivers >> Block devices >> Support for DASD devices
++CONFIG_DASD                                     policy<{'s390x': 'm'}>
++CONFIG_DASD_PROFILE                             policy<{'s390x': 'y'}>
++CONFIG_DASD_ECKD                                policy<{'s390x': 'm'}>
++CONFIG_DASD_FBA                                 policy<{'s390x': 'm'}>
++CONFIG_DASD_DIAG                                policy<{'s390x': 'm'}>
++CONFIG_DASD_EER                                 policy<{'s390x': 'y'}>
++
++# Menu: Device Drivers >> Broadcom specific AMBA
++CONFIG_BCMA_HOST_PCI                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Broadcom specific AMBA >> BCMA support
++CONFIG_BCMA                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_BCMA_HOST_SOC                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BCMA_DRIVER_PCI                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BCMA_DRIVER_GMAC_CMN                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BCMA_DRIVER_GPIO                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BCMA_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Bus devices
++CONFIG_ARM_CCI400_PMU                           policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_ARM_CCI500_PMU                           policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_ARM_CCN                                  policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_BRCMSTB_GISB_ARB                         policy<{'armhf': 'y'}>
++CONFIG_IMX_WEIM                                 policy<{'armhf-generic': 'y'}>
++CONFIG_OMAP_INTERCONNECT                        policy<{'armhf': 'y'}>
++CONFIG_OMAP_OCP2SCP                             policy<{'armhf': 'm'}>
++CONFIG_SIMPLE_PM_BUS                            policy<{'armhf': 'y'}>
++CONFIG_VEXPRESS_CONFIG                          policy<{'arm64': 'y', 'armhf': 'y'}>
++
++# Menu: Device Drivers >> Character devices
++CONFIG_DEVMEM                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEVKMEM                                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_TTY_PRINTK                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_PRINTER                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LP_CONSOLE                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_PPDEV                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HVC_CONSOLE                              policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_HVC_OLD_HVSI                             policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_HVC_OPAL                                 policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_HVC_RTAS                                 policy<{'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_HVC_IUCV                                 policy<{'s390x': 'y'}>
++CONFIG_HVC_XEN                                  policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_HVC_XEN_FRONTEND                         policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_HVC_UDBG                                 policy<{'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HVC_DCC                                  policy<{'armhf': 'n'}>
++CONFIG_HVCS                                     policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_VIRTIO_CONSOLE                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IBM_BSR                                  policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_NVRAM                                    policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_DTLK                                     policy<{'i386': 'm'}>
++CONFIG_R3964                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_APPLICOM                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SONYPI                                   policy<{'i386': 'm'}>
++CONFIG_MWAVE                                    policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SCx200_GPIO                              policy<{'i386': 'm'}>
++CONFIG_PC8736x_GPIO                             policy<{'i386': 'm'}>
++CONFIG_NSC_GPIO                                 policy<{'i386': 'm'}>
++CONFIG_RAW_DRIVER                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MAX_RAW_DEVS                             policy<{'amd64': '256', 'arm64': '256', 'armhf': '256', 'i386': '256', 'powerpc': '256', 'ppc64el': '256'}>
++CONFIG_HPET                                     policy<{'amd64': 'y', 'arm64': 'n', 'i386': 'y'}>
++CONFIG_HPET_MMAP                                policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_HPET_MMAP_DEFAULT                        policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_HANGCHECK_TIMER                          policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TELCLOCK                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_TN3270                                   policy<{'s390x': 'y'}>
++CONFIG_TN3270_TTY                               policy<{'s390x': 'y'}>
++CONFIG_TN3270_FS                                policy<{'s390x': 'm'}>
++CONFIG_TN3270_CONSOLE                           policy<{'s390x': 'y'}>
++CONFIG_TN3215                                   policy<{'s390x': 'y'}>
++CONFIG_TN3215_CONSOLE                           policy<{'s390x': 'y'}>
++CONFIG_SCLP_TTY                                 policy<{'s390x': 'y'}>
++CONFIG_SCLP_CONSOLE                             policy<{'s390x': 'y'}>
++CONFIG_SCLP_VT220_TTY                           policy<{'s390x': 'y'}>
++CONFIG_SCLP_VT220_CONSOLE                       policy<{'s390x': 'y'}>
++CONFIG_SCLP_CPI                                 policy<{'s390x': 'm'}>
++CONFIG_SCLP_ASYNC                               policy<{'s390x': 'm'}>
++CONFIG_SCLP_ASYNC_ID                            policy<{'s390x': '"000000000"'}>
++CONFIG_HMC_DRV                                  policy<{'s390x': 'm'}>
++CONFIG_S390_TAPE                                policy<{'s390x': 'm'}>
++CONFIG_S390_TAPE_34XX                           policy<{'s390x': 'm'}>
++CONFIG_S390_TAPE_3590                           policy<{'s390x': 'm'}>
++CONFIG_VMLOGRDR                                 policy<{'s390x': 'm'}>
++CONFIG_VMCP                                     policy<{'s390x': 'y'}>
++CONFIG_MONREADER                                policy<{'s390x': 'm'}>
++CONFIG_MONWRITER                                policy<{'s390x': 'm'}>
++CONFIG_S390_VMUR                                policy<{'s390x': 'm'}>
++CONFIG_XILLYBUS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_XILLYBUS_PCIE                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_XILLYBUS_OF                              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_DEVKMEM                                  mark<ENFORCED> note</dev/kmem is a large attack vector>
++CONFIG_NVRAM                                    mark<ENFORCED> note<boot essential on powerpc LP:942193>
++
++# Menu: Device Drivers >> Character devices >> Enable TTY
++CONFIG_TTY                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_VT                                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CONSOLE_TRANSLATIONS                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VT_CONSOLE                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VT_HW_CONSOLE_BINDING                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_UNIX98_PTYS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEVPTS_MULTIPLE_INSTANCES                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_LEGACY_PTYS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_LEGACY_PTY_COUNT                         policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0', 's390x': '0'}>
++CONFIG_NOZOMI                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_N_GSM                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_TRACE_ROUTER                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TRACE_SINK                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_PPC_EPAPR_HV_BYTECHAN                    policy<{'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_N_GSM                                    note<LP#1404670>
++
++# Menu: Device Drivers >> Character devices >> Enable TTY >> Non-standard serial port support
++CONFIG_SERIAL_NONSTANDARD                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ROCKETPORT                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CYCLADES                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CYZ_INTR                                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MOXA_INTELLIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MOXA_SMARTIO                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SYNCLINK                                 policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SYNCLINKMP                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SYNCLINK_GT                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISI                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_N_HDLC                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Character devices >> Hardware Random Number Generator Core support
++CONFIG_HW_RANDOM                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_HW_RANDOM_TIMERIOMEM                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_HW_RANDOM_INTEL                          policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_HW_RANDOM_AMD                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc64-smp': 'm'}>
++CONFIG_HW_RANDOM_IPROC_RNG200                   policy<{'arm64': 'm'}>
++CONFIG_HW_RANDOM_GEODE                          policy<{'i386': 'm'}>
++CONFIG_HW_RANDOM_VIA                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_HW_RANDOM_OMAP                           policy<{'armhf': 'm'}>
++CONFIG_HW_RANDOM_OMAP3_ROM                      policy<{'armhf-generic': 'm'}>
++CONFIG_HW_RANDOM_PASEMI                         policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_HW_RANDOM_VIRTIO                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_HW_RANDOM_PSERIES                        policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_HW_RANDOM_POWERNV                        policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_HW_RANDOM_EXYNOS                         policy<{'armhf': 'm'}>
++CONFIG_HW_RANDOM_TPM                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_HW_RANDOM_MSM                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_HW_RANDOM_XGENE                          policy<{'arm64': 'm'}>
++#
++CONFIG_HW_RANDOM_ATMEL                          note<depends on CONFIG_ARCH_AT91SAM9G45>
++
++# Menu: Device Drivers >> Character devices >> IPMI top-level message handler
++CONFIG_IPMI_HANDLER                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_IPMI_PANIC_EVENT                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_IPMI_DEVICE_INTERFACE                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IPMI_SI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IPMI_SI_PROBE_DEFAULTS                   policy<{'amd64': 'y', 'arm64': 'n', 'armhf': 'n', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IPMI_SSIF                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IPMI_POWERNV                             policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_IPMI_WATCHDOG                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IPMI_POWEROFF                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Character devices >> PCMCIA character devices
++CONFIG_SYNCLINK_CS                              policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_CARDMAN_4000                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_CARDMAN_4040                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_IPWIRELESS                               policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++
++# Menu: Device Drivers >> Character devices >> Serial drivers
++CONFIG_SERIAL_AMBA_PL010                        policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SERIAL_AMBA_PL011                        policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_SERIAL_AMBA_PL011_CONSOLE                policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_SERIAL_EARLYCON_ARM_SEMIHOST             policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_SERIAL_KGDB_NMI                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_MESON                             policy<{'armhf': 'm'}>
++CONFIG_SERIAL_SAMSUNG                           policy<{'armhf': 'm'}>
++CONFIG_SERIAL_TEGRA                             policy<{'armhf-generic': 'm'}>
++CONFIG_SERIAL_MAX3100                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIAL_MAX310X                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_IMX                               policy<{'armhf-generic': 'y'}>
++CONFIG_SERIAL_IMX_CONSOLE                       policy<{'armhf-generic': 'y'}>
++CONFIG_SERIAL_PMACZILOG                         policy<{'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_SERIAL_PMACZILOG_TTYS                    policy<{'powerpc-powerpc64-smp': 'n', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_SERIAL_PMACZILOG_CONSOLE                 policy<{'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_SERIAL_CPM                               policy<{'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_SERIAL_ICOM                              policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIAL_JSM                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SERIAL_MSM                               policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_SERIAL_MSM_CONSOLE                       policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_SERIAL_OF_PLATFORM                       policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_OMAP                              policy<{'armhf': 'y'}>
++CONFIG_SERIAL_OMAP_CONSOLE                      policy<{'armhf': 'y'}>
++CONFIG_SERIAL_SCCNXP                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SERIAL_SCCNXP_CONSOLE                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_SC16IS7XX                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIAL_SC16IS7XX_I2C                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_SC16IS7XX_SPI                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_TIMBERDALE                        policy<{'i386': 'm'}>
++CONFIG_SERIAL_BCM63XX                           policy<{'armhf': 'm'}>
++CONFIG_SERIAL_ALTERA_JTAGUART                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SERIAL_IFX6X60                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SERIAL_PCH_UART                          policy<{'i386': 'm'}>
++CONFIG_SERIAL_XILINX_PS_UART                    policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIAL_ARC                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SERIAL_ARC_NR_PORTS                      policy<{'amd64': '1', 'arm64': '1', 'armhf': '1', 'i386': '1', 'powerpc': '1', 'ppc64el': '1'}>
++CONFIG_SERIAL_RP2                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SERIAL_RP2_NR_UARTS                      policy<{'amd64': '32', 'arm64': '32', 'armhf': '32', 'i386': '32', 'powerpc': '32', 'ppc64el': '32'}>
++CONFIG_SERIAL_FSL_LPUART                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SERIAL_CONEXANT_DIGICOLOR                policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIAL_ST_ASC                            policy<{'armhf': 'm'}>
++CONFIG_SERIAL_MEN_Z135                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIAL_SPRD                              policy<{'arm64': 'm'}>
++CONFIG_SERIAL_STM32                             policy<{'armhf': 'm'}>
++CONFIG_SERIAL_UARTLITE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Device Drivers >> Character devices >> Serial drivers >> 8250/16550 and compatible serial support
++CONFIG_SERIAL_8250                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SERIAL_8250_DEPRECATED_OPTIONS           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SERIAL_8250_PNP                          policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_SERIAL_8250_CONSOLE                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_8250_DMA                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_8250_PCI                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_8250_CS                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_SERIAL_8250_NR_UARTS                     policy<{'amd64': '48', 'arm64': '48', 'armhf': '48', 'i386': '48', 'powerpc': '48', 'ppc64el': '48'}>
++CONFIG_SERIAL_8250_RUNTIME_UARTS                policy<{'amd64': '32', 'arm64': '32', 'armhf': '32', 'i386': '32', 'powerpc': '32', 'ppc64el': '32'}>
++CONFIG_SERIAL_8250_DW                           policy<{'amd64': 'm', 'arm64': 'y', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIAL_8250_EM                           policy<{'armhf': 'n'}>
++CONFIG_SERIAL_8250_OMAP                         policy<{'armhf': 'm'}>
++CONFIG_SERIAL_8250_FINTEK                       policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_SERIAL_8250_MT6577                       policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_SERIAL_8250_UNIPHIER                     policy<{'armhf': 'm'}>
++CONFIG_SERIAL_8250_INGENIC                      policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++#
++CONFIG_SERIAL_8250_DW                           note<Otherwise can't boot APM xgene2 via UEFI+ACPI>
++
++# Menu: Device Drivers >> Character devices >> Serial drivers >> 8250/16550 and compatible serial support >> Extended 8250/16550 serial driver options
++CONFIG_SERIAL_8250_EXTENDED                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_8250_SHARE_IRQ                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_8250_DETECT_IRQ                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SERIAL_8250_RSA                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Character devices >> Serial drivers >> 8250/16550 and compatible serial support >> Extended 8250/16550 serial driver options >> Support more than 4 legacy serial ports
++CONFIG_SERIAL_8250_MANY_PORTS                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIAL_8250_FOURPORT                     policy<{'i386': 'm'}>
++CONFIG_SERIAL_8250_ACCENT                       policy<{'i386': 'm'}>
++CONFIG_SERIAL_8250_BOCA                         policy<{'i386': 'm'}>
++CONFIG_SERIAL_8250_EXAR_ST16C554                policy<{'i386': 'm'}>
++CONFIG_SERIAL_8250_HUB6                         policy<{'i386': 'm'}>
++
++# Menu: Device Drivers >> Character devices >> Serial drivers >> AT91 / AT32 on-chip serial port support
++
++# Menu: Device Drivers >> Character devices >> Serial drivers >> Altera UART support
++CONFIG_SERIAL_ALTERA_UART                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SERIAL_ALTERA_UART_MAXPORTS              policy<{'amd64': '4', 'arm64': '4', 'armhf': '4', 'i386': '4', 'powerpc': '4', 'ppc64el': '4'}>
++CONFIG_SERIAL_ALTERA_UART_BAUDRATE              policy<{'amd64': '115200', 'arm64': '115200', 'armhf': '115200', 'i386': '115200', 'powerpc': '115200', 'ppc64el': '115200'}>
++
++# Menu: Device Drivers >> Character devices >> Serial drivers >> Blackfin SPORT emulate UART
++
++# Menu: Device Drivers >> Character devices >> Serial drivers >> Blackfin serial port support
++
++# Menu: Device Drivers >> Character devices >> Serial drivers >> Blackfin serial port support >> UART Mode
++
++# Menu: Device Drivers >> Character devices >> Serial drivers >> SuperH SCI(F) serial port support
++CONFIG_SERIAL_SH_SCI                            policy<{'armhf': 'm'}>
++CONFIG_SERIAL_SH_SCI_NR_UARTS                   policy<{'armhf': '2'}>
++CONFIG_SERIAL_SH_SCI_DMA                        policy<{'armhf': 'y'}>
++
++# Menu: Device Drivers >> Character devices >> Serial drivers >> TMPTX39XX/49XX SIO support
++
++# Menu: Device Drivers >> Character devices >> TPM Hardware Support
++CONFIG_TCG_TPM                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TCG_TIS                                  policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_TCG_TIS_I2C_ATMEL                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TCG_TIS_I2C_INFINEON                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TCG_TIS_I2C_NUVOTON                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TCG_NSC                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_TCG_ATMEL                                policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TCG_INFINEON                             policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_TCG_IBMVTPM                              policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_TCG_XEN                                  policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_TCG_CRB                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_TCG_TIS_ST33ZP24                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TCG_TIS_ST33ZP24_I2C                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TCG_TIS_ST33ZP24_SPI                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_TCG_TPM                                  note<needed for early validation>
++
++# Menu: Device Drivers >> Clock Source drivers
++CONFIG_ARM_ARCH_TIMER_EVTSTREAM                 policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_ARM_TIMER_SP804                          policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_SH_TIMER_CMT                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'y', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SH_TIMER_MTU2                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'y', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SH_TIMER_TMU                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'y', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_EM_TIMER_STI                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'y', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_CLKSRC_VERSATILE                         policy<{'armhf': 'y'}>
++CONFIG_CLKSRC_IMX_GPT                           policy<{'armhf-generic': 'y'}>
++
++# Menu: Device Drivers >> Common Clock Framework
++CONFIG_COMMON_CLK_WM831X                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_COMMON_CLK_VERSATILE                     policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_CLK_SP810                                policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_CLK_VEXPRESS_OSC                         policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_COMMON_CLK_MAX77686                      policy<{'arm64': 'm', 'armhf': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_COMMON_CLK_MAX77802                      policy<{'arm64': 'm', 'armhf': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_COMMON_CLK_RK808                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_COMMON_CLK_SI5351                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_COMMON_CLK_SI570                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_COMMON_CLK_CDCE925                       policy<{'arm64': 'm', 'armhf': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_COMMON_CLK_S2MPS11                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_CLK_TWL6040                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_CLK_QORIQ                                policy<{'armhf': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_COMMON_CLK_XGENE                         policy<{'arm64': 'y'}>
++CONFIG_COMMON_CLK_PALMAS                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_COMMON_CLK_PWM                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_COMMON_CLK_CDCE706                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_COMMON_CLK_IPROC                         policy<{'arm64': 'y'}>
++CONFIG_COMMON_CLK_HI6220                        policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_STUB_CLK_HI6220                          policy<{'arm64': 'y', 'armhf': 'y'}>
++
++# Menu: Device Drivers >> Common Clock Framework >> Support for Qualcomm's clock controllers
++CONFIG_COMMON_CLK_QCOM                          policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_APQ_GCC_8084                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_APQ_MMCC_8084                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_IPQ_GCC_806X                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_IPQ_LCC_806X                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MSM_GCC_8660                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MSM_GCC_8916                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MSM_GCC_8960                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MSM_LCC_8960                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MSM_MMCC_8960                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MSM_GCC_8974                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MSM_MMCC_8974                            policy<{'arm64': 'm', 'armhf': 'm'}>
++
++# Menu: Device Drivers >> Connector - unified userspace <-> kernelspace linker
++CONFIG_CONNECTOR                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PROC_EVENTS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Device Drivers >> DMA Engine support
++CONFIG_DMADEVICES                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_DMADEVICES_DEBUG                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_AMBA_PL08X                               policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_DMA_OMAP                                 policy<{'armhf': 'y'}>
++CONFIG_FSL_DMA                                  policy<{'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_FSL_EDMA                                 policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IMX_DMA                                  policy<{'armhf-generic': 'm'}>
++CONFIG_IMX_SDMA                                 policy<{'armhf-generic': 'm'}>
++CONFIG_IDMA64                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INTEL_IOATDMA                            policy<{'amd64': 'm'}>
++CONFIG_INTEL_MIC_X100_DMA                       policy<{'amd64': 'm'}>
++CONFIG_K3_DMA                                   policy<{'armhf': 'm'}>
++CONFIG_MV_XOR                                   policy<{'armhf': 'y'}>
++CONFIG_MXS_DMA                                  policy<{'armhf-generic': 'y'}>
++CONFIG_MX3_IPU                                  policy<{'armhf-generic': 'y'}>
++CONFIG_MX3_IPU_IRQS                             policy<{'armhf-generic': '4'}>
++CONFIG_NBPFAXI_DMA                              policy<{'armhf': 'm'}>
++CONFIG_PCH_DMA                                  policy<{'i386': 'm'}>
++CONFIG_PL330_DMA                                policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_QCOM_BAM_DMA                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_TEGRA20_APB_DMA                          policy<{'armhf-generic': 'y'}>
++CONFIG_TIMB_DMA                                 policy<{'i386': 'm'}>
++CONFIG_TI_CPPI41                                policy<{'armhf': 'm'}>
++CONFIG_TI_EDMA                                  policy<{'armhf': 'y'}>
++CONFIG_XGENE_DMA                                policy<{'arm64': 'm'}>
++CONFIG_ZX_DMA                                   policy<{'armhf': 'm'}>
++CONFIG_DW_DMAC                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DW_DMAC_PCI                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HSU_DMA_PCI                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RCAR_DMAC                                policy<{'armhf': 'm'}>
++CONFIG_RENESAS_USB_DMAC                         policy<{'armhf': 'm'}>
++CONFIG_ASYNC_TX_DMA                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DMATEST                                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_DMATEST                                  flag<TESTING>
++
++# Menu: Device Drivers >> DMA Engine support >> Renesas SuperH DMA Engine support
++CONFIG_SH_DMAE_BASE                             policy<{'armhf': 'y'}>
++CONFIG_SH_DMAE                                  policy<{'armhf': 'm'}>
++CONFIG_SUDMAC                                   policy<{'armhf': 'm'}>
++CONFIG_RCAR_HPB_DMAE                            policy<{'armhf': 'm'}>
++
++# Menu: Device Drivers >> Dallas's 1-wire support
++CONFIG_W1                                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_W1_CON                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Dallas's 1-wire support >> 1-wire Bus Masters
++CONFIG_W1_MASTER_MATROX                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_MASTER_DS2490                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_MASTER_DS2482                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_MASTER_MXC                            policy<{'armhf-generic': 'm'}>
++CONFIG_W1_MASTER_DS1WM                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_MASTER_GPIO                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HDQ_MASTER_OMAP                          policy<{'armhf': 'm'}>
++
++# Menu: Device Drivers >> Dallas's 1-wire support >> 1-wire Slaves
++CONFIG_W1_SLAVE_THERM                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_SMEM                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_DS2408                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_DS2408_READBACK                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_W1_SLAVE_DS2413                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_DS2406                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_DS2423                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_DS2431                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_DS2433                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_DS2433_CRC                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_W1_SLAVE_DS2760                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_DS2780                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_DS2781                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_DS28E04                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_W1_SLAVE_BQ27000                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Device Tree and Open Firmware support
++CONFIG_OF                                       policy<{'amd64': 'n', 'arm64': 'y', 'armhf': 'y', 'i386': 'n', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_OF_UNITTEST                              policy<{'arm64': 'n', 'armhf': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_OF_DYNAMIC                               policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_OF_OVERLAY                               policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++#
++CONFIG_OF_UNITTEST                              flag<DEBUG>
++
++# Menu: Device Drivers >> EDAC (Error Detection And Correction) reporting
++CONFIG_EDAC                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_EDAC_LEGACY_SYSFS                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_EDAC_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_EDAC_DECODE_MCE                          policy<{'amd64': 'm', 'i386': 'm'}>
++
++# Menu: Device Drivers >> EDAC (Error Detection And Correction) reporting >> Main Memory EDAC (Error Detection And Correction) reporting
++CONFIG_EDAC_MM_EDAC                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EDAC_AMD64                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_AMD64_ERROR_INJECTION               policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_EDAC_AMD76X                              policy<{'i386': 'm'}>
++CONFIG_EDAC_E7XXX                               policy<{'i386': 'm'}>
++CONFIG_EDAC_E752X                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_I82875P                             policy<{'i386': 'm'}>
++CONFIG_EDAC_I82975X                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_I3000                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_I3200                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_IE31200                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_X38                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_I5400                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_I7CORE                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_I82860                              policy<{'i386': 'm'}>
++CONFIG_EDAC_R82600                              policy<{'i386': 'm'}>
++CONFIG_EDAC_I5000                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_I5100                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_I7300                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EDAC_SBRIDGE                             policy<{'amd64': 'm'}>
++CONFIG_EDAC_MPC85XX                             policy<{'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_EDAC_PASEMI                              policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_EDAC_AMD8131                             policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_EDAC_AMD8111                             policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_EDAC_CPC925                              policy<{'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_EDAC_HIGHBANK_MC                         policy<{'armhf': 'm'}>
++CONFIG_EDAC_HIGHBANK_L2                         policy<{'armhf': 'm'}>
++CONFIG_EDAC_XGENE                               policy<{'arm64': 'm'}>
++
++# Menu: Device Drivers >> External Connector Class (extcon) support
++CONFIG_EXTCON                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_EXTCON_ADC_JACK                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EXTCON_ARIZONA                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EXTCON_AXP288                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EXTCON_GPIO                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EXTCON_MAX14577                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EXTCON_MAX77693                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EXTCON_MAX77843                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EXTCON_MAX8997                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EXTCON_PALMAS                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EXTCON_RT8973A                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EXTCON_SM5502                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EXTCON_USB_GPIO                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> FMC support
++CONFIG_FMC                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_FMC_FAKEDEV                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FMC_TRIVIAL                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FMC_WRITE_EEPROM                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FMC_CHARDEV                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Fusion MPT device support
++CONFIG_FUSION                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_FUSION_SPI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FUSION_FC                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FUSION_SAS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FUSION_MAX_SGE                           policy<{'amd64': '128', 'arm64': '128', 'armhf': '128', 'i386': '128', 'powerpc': '128', 'ppc64el': '128'}>
++CONFIG_FUSION_CTL                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FUSION_LAN                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FUSION_LOGGING                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> GPIO Support
++CONFIG_GPIOLIB                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DEBUG_GPIO                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_GPIO_SYSFS                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++#
++CONFIG_GPIO_SYSFS                               note<LP#1342153>
++
++# Menu: Device Drivers >> GPIO Support >> I2C GPIO expanders
++CONFIG_GPIO_ADP5588                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_ADNP                                policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_MAX7300                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_MAX732X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_PCA953X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_PCF857X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_SX150X                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> GPIO Support >> MFD GPIO expanders
++CONFIG_GPIO_ADP5520                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_ARIZONA                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_CRYSTAL_COVE                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_CS5535                              policy<{'i386': 'm'}>
++CONFIG_GPIO_DA9052                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_DA9055                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_DLN2                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_JANZ_TTL                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_KEMPLD                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_LP3943                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_MSIC                                policy<{'i386': 'y'}>
++CONFIG_GPIO_PALMAS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_GPIO_RC5T583                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_GPIO_STMPE                               policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_GPIO_TC3589X                             policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_GPIO_TIMBERDALE                          policy<{'i386': 'y'}>
++CONFIG_GPIO_TPS6586X                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_GPIO_TPS65910                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_GPIO_TPS65912                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_TWL4030                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_TWL6040                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_UCB1400                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_WM831X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_WM8350                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_WM8994                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_GPIO_TWL4030                             mark<ENFORCED> note<LP:#921934>
++
++# Menu: Device Drivers >> GPIO Support >> Memory mapped GPIO drivers
++CONFIG_GPIO_74XX_MMIO                           policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_ALTERA                              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_DWAPB                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_EM                                  policy<{'armhf': 'n'}>
++CONFIG_GPIO_F7188X                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_GPIO_GENERIC_PLATFORM                    policy<{'amd64': 'm', 'arm64': 'y', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_GRGPIO                              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_ICH                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_GPIO_IT8761E                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_GPIO_LYNXPOINT                           policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_GPIO_MPC8XXX                             policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_GPIO_MSM_V2                              policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_GPIO_OMAP                                policy<{'armhf': 'y'}>
++CONFIG_GPIO_PL061                               policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_GPIO_RCAR                                policy<{'armhf': 'm'}>
++CONFIG_GPIO_SCH                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_GPIO_SCH311X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_SYSCON                              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_VX855                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_XGENE                               policy<{'arm64': 'y'}>
++CONFIG_GPIO_XGENE_SB                            policy<{'arm64': 'm'}>
++CONFIG_GPIO_XILINX                              policy<{'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_GPIO_ZEVIO                               policy<{'armhf': 'y'}>
++CONFIG_GPIO_ZYNQ                                policy<{'arm64': 'm'}>
++#
++CONFIG_GPIO_EM                                  note<h/w not encounted>
++
++# Menu: Device Drivers >> GPIO Support >> PCI GPIO expanders
++CONFIG_GPIO_AMD8111                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_INTEL_MID                           policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_GPIO_ML_IOH                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_PCH                                 policy<{'i386': 'm'}>
++CONFIG_GPIO_RDC321X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> GPIO Support >> SPI GPIO expanders
++CONFIG_GPIO_74X164                              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_MAX7301                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_MCP23S08                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_MC33880                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_ZX                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> GPIO Support >> USB GPIO expanders
++CONFIG_GPIO_VIPERBOARD                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Generic Driver Options
++CONFIG_UEVENT_HELPER                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_UEVENT_HELPER_PATH                       policy<{'amd64': '""', 'arm64': '""', 'armhf': '""', 'i386': '""', 'powerpc': '""', 'ppc64el': '""', 's390x': '""'}>
++CONFIG_DEVTMPFS                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEVTMPFS_MOUNT                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_STANDALONE                               policy<{'amd64': 'n', 'arm64': 'y', 'armhf': 'y', 'i386': 'n', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PREVENT_FIRMWARE_BUILD                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ALLOW_DEV_COREDUMP                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEBUG_DRIVER                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_DEVRES                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_FENCE_TRACE                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_DEVTMPFS                                 note<ENFORCED> note<upstart requirement>
++CONFIG_DEVTMPFS_MOUNT                           note<ENFORCED> note<upstart requirement>
++CONFIG_FENCE_TRACE                              flag<DEBUG>
++
++# Menu: Device Drivers >> Generic Driver Options >> DMA Contiguous Memory Allocator
++CONFIG_DMA_CMA                                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n'}>
++#
++CONFIG_DMA_CMA                                  note<LP#1362261>
++
++# Menu: Device Drivers >> Generic Driver Options >> DMA Contiguous Memory Allocator >> Selected region size
++
++# Menu: Device Drivers >> Generic Driver Options >> Userspace firmware loading support
++CONFIG_FW_LOADER                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FIRMWARE_IN_KERNEL                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_EXTRA_FIRMWARE                           policy<{'amd64': '""', 'arm64': '""', 'armhf': '""', 'i386': '""', 'powerpc': '""', 'ppc64el': '""', 's390x': '""'}>
++CONFIG_FW_LOADER_USER_HELPER_FALLBACK           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_FW_LOADER_USER_HELPER_FALLBACK           mark<ENFORCED> note<LP#1398458>
++
++# Menu: Device Drivers >> Generic Dynamic Voltage and Frequency Scaling (DVFS) support
++CONFIG_PM_DEVFREQ                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_DEVFREQ_GOV_SIMPLE_ONDEMAND              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DEVFREQ_GOV_PERFORMANCE                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DEVFREQ_GOV_POWERSAVE                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DEVFREQ_GOV_USERSPACE                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ARM_EXYNOS5_BUS_DEVFREQ                  policy<{'armhf': 'n'}>
++CONFIG_ARM_TEGRA_DEVFREQ                        policy<{'armhf-generic': 'm'}>
++
++# Menu: Device Drivers >> Generic Dynamic Voltage and Frequency Scaling (DVFS) support >> DEVFREQ-Event device Support
++CONFIG_PM_DEVFREQ_EVENT                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DEVFREQ_EVENT_EXYNOS_PPMU                policy<{'armhf': 'n'}>
++
++# Menu: Device Drivers >> Generic Target Core Mod (TCM) and ConfigFS Infrastructure
++CONFIG_TARGET_CORE                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCM_IBLOCK                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCM_FILEIO                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCM_PSCSI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCM_USER2                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LOOPBACK_TARGET                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCM_FC                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_ISCSI_TARGET                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SBP_TARGET                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Generic Thermal sysfs driver
++CONFIG_THERMAL                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_THERMAL_HWMON                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_THERMAL_OF                               policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_THERMAL_WRITABLE_TRIPS                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_THERMAL_GOV_FAIR_SHARE                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_THERMAL_GOV_STEP_WISE                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_THERMAL_GOV_BANG_BANG                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_THERMAL_GOV_USER_SPACE                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_THERMAL_GOV_POWER_ALLOCATOR              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CLOCK_THERMAL                            policy<{'arm64': 'n', 'armhf': 'n', 'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_THERMAL_EMULATION                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RCAR_THERMAL                             policy<{'armhf': 'm'}>
++CONFIG_DOVE_THERMAL                             policy<{'armhf': 'm'}>
++CONFIG_ARMADA_THERMAL                           policy<{'armhf': 'y'}>
++CONFIG_TEGRA_SOCTHERM                           policy<{'armhf-generic': 'n'}>
++CONFIG_INTEL_POWERCLAMP                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_X86_PKG_TEMP_THERMAL                     policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_SOC_DTS_THERMAL                    policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INT340X_THERMAL                          policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_PCH_THERMAL                        policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_QCOM_SPMI_TEMP_ALARM                     policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Generic Thermal sysfs driver >> Default Thermal governor
++CONFIG_THERMAL_DEFAULT_GOV_STEP_WISE            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_THERMAL_DEFAULT_GOV_FAIR_SHARE           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_THERMAL_DEFAULT_GOV_USER_SPACE           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_THERMAL_DEFAULT_GOV_POWER_ALLOCATOR      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Generic Thermal sysfs driver >> STMicroelectronics thermal drivers
++
++# Menu: Device Drivers >> Generic Thermal sysfs driver >> Samsung thermal drivers
++CONFIG_EXYNOS_THERMAL                           policy<{'armhf': 'y'}>
++
++# Menu: Device Drivers >> Generic Thermal sysfs driver >> Texas Instruments thermal drivers
++
++# Menu: Device Drivers >> Generic Thermal sysfs driver >> Texas Instruments thermal drivers >> Texas Instruments SoCs temperature sensor driver
++CONFIG_TI_SOC_THERMAL                           policy<{'armhf': 'm'}>
++CONFIG_TI_THERMAL                               policy<{'armhf': 'y'}>
++CONFIG_OMAP4_THERMAL                            policy<{'armhf-generic': 'y'}>
++CONFIG_DRA752_THERMAL                           policy<{'armhf': 'y'}>
++
++# Menu: Device Drivers >> Generic Thermal sysfs driver >> generic cpu cooling support
++CONFIG_CPU_THERMAL                              policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISI_THERMAL                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_IMX_THERMAL                              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Generic powercap sysfs driver
++CONFIG_POWERCAP                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_INTEL_RAPL                               policy<{'amd64': 'm', 'i386': 'm'}>
++
++# Menu: Device Drivers >> Graphics support
++CONFIG_VGA_ARB                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VGA_ARB_MAX_GPUS                         policy<{'amd64': '16', 'arm64': '16', 'armhf': '16', 'i386': '16', 'powerpc': '16', 'ppc64el': '16'}>
++CONFIG_VGA_SWITCHEROO                           policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_TEGRA_HOST1X                             policy<{'armhf-generic': 'm'}>
++CONFIG_TEGRA_HOST1X_FIREWALL                    policy<{'armhf-generic': 'y'}>
++CONFIG_IMX_IPUV3_CORE                           policy<{'armhf': 'm'}>
++CONFIG_DRM_LOAD_EDID_FIRMWARE                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> /dev/agpgart (AGP Support)
++CONFIG_AGP                                      policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_AGP_ALI                                  policy<{'i386': 'm'}>
++CONFIG_AGP_ATI                                  policy<{'i386': 'm'}>
++CONFIG_AGP_AMD                                  policy<{'i386': 'y'}>
++CONFIG_AGP_AMD64                                policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_AGP_INTEL                                policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_AGP_NVIDIA                               policy<{'i386': 'y'}>
++CONFIG_AGP_SIS                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_AGP_SWORKS                               policy<{'i386': 'm'}>
++CONFIG_AGP_VIA                                  policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_AGP_UNINORTH                             policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_AGP_EFFICEON                             policy<{'i386': 'm'}>
++#
++CONFIG_AGP                                      note<not autoloadable> flag<REVIEW>
++
++# Menu: Device Drivers >> Graphics support >> Backlight & LCD device support
++CONFIG_BACKLIGHT_LCD_SUPPORT                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++
++# Menu: Device Drivers >> Graphics support >> Backlight & LCD device support >> Lowlevel Backlight controls
++CONFIG_BACKLIGHT_CLASS_DEVICE                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BACKLIGHT_GENERIC                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_LM3533                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_CARILLO_RANCH                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_BACKLIGHT_PWM                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_DA903X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_DA9052                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_MAX8925                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_APPLE                          policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_BACKLIGHT_PM8941_WLED                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_SAHARA                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_BACKLIGHT_WM831X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_ADP5520                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_ADP8860                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_ADP8870                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_88PM860X                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_PCF50633                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_AAT2870                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_LM3630A                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_LM3639                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_LP855X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_LP8788                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_PANDORA                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_SKY81452                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_TPS65217                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_AS3711                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_GPIO                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_LV5207LP                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BACKLIGHT_BD6107                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Graphics support >> Backlight & LCD device support >> Lowlevel LCD controls
++CONFIG_LCD_CLASS_DEVICE                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_L4F00242T03                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_LMS283GF05                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_LTV350QV                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_ILI922X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_ILI9320                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_TDO24M                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_VGG2432A4                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_PLATFORM                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_S6E63M0                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_LD9040                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_AMS369FG06                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_LMS501KF03                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LCD_HX8357                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Graphics support >> Bootup logo
++CONFIG_LOGO                                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Graphics support >> Console display driver support
++CONFIG_VGA_CONSOLE                              policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VGACON_SOFT_SCROLLBACK                   policy<{'amd64': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MDA_CONSOLE                              policy<{'i386': 'm'}>
++CONFIG_DUMMY_CONSOLE_COLUMNS                    policy<{'amd64': '80', 'arm64': '80', 'i386': '80', 'powerpc': '80', 'ppc64el': '80'}>
++CONFIG_DUMMY_CONSOLE_ROWS                       policy<{'amd64': '25', 'arm64': '25', 'i386': '25', 'powerpc': '25', 'ppc64el': '25'}>
++CONFIG_FRAMEBUFFER_CONSOLE                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FRAMEBUFFER_CONSOLE_DETECT_PRIMARY       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FRAMEBUFFER_CONSOLE_ROTATION             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++#
++CONFIG_FRAMEBUFFER_CONSOLE                      mark<ENFORCED> note<boot essential for grub2 console>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support)
++CONFIG_DRM                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_DRM_FBDEV_EMULATION                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DRM_TDFX                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_R128                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_RADEON                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_RADEON_USERPTR                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_DRM_RADEON_UMS                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_DRM_I810                                 policy<{'amd64-generic': 'm', 'i386-generic': 'm'}>
++CONFIG_DRM_I915                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_DRM_I915_PRELIMINARY_HW_SUPPORT          policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_DRM_MGA                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_SIS                                  policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_VIA                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_SAVAGE                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_VGEM                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_VMWGFX                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_DRM_VMWGFX_FBCON                         policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_DRM_UDL                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_AST                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_MGAG200                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_DRM_CIRRUS_QEMU                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_ARMADA                               policy<{'armhf': 'm'}>
++CONFIG_DRM_ATMEL_HLCDC                          policy<{'armhf': 'm'}>
++CONFIG_DRM_RCAR_DU                              policy<{'armhf': 'm'}>
++CONFIG_DRM_RCAR_HDMI                            policy<{'armhf': 'y'}>
++CONFIG_DRM_RCAR_LVDS                            policy<{'armhf': 'y'}>
++CONFIG_DRM_SHMOBILE                             policy<{'armhf': 'm'}>
++CONFIG_DRM_OMAP                                 policy<{'armhf': 'n'}>
++CONFIG_DRM_TILCDC                               policy<{'armhf': 'm'}>
++CONFIG_DRM_TILCDC_SLAVE_COMPAT                  policy<{'armhf': 'y'}>
++CONFIG_DRM_QXL                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_BOCHS                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_DRM_VIRTIO_GPU                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_FSL_DCU                              policy<{'armhf': 'm'}>
++CONFIG_DRM_STI                                  policy<{'armhf': 'n'}>
++#
++CONFIG_DRM_MGAG200                              mark<ENFORCED> note<LP#1042903: CONFIG_DRM_MGAG200, experimental driver hangs boot on HP Proliant Gen8>
++CONFIG_DRM_BOCHS                                note<LP#1378648>
++CONFIG_DRM_STI                                  note<LP#1398458>
++CONFIG_DRM_I915_PRELIMINARY_HW_SUPPORT          note<LP:1473319>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> AMD GPU
++CONFIG_DRM_AMDGPU                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_AMDGPU_CIK                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_DRM_AMDGPU_USERPTR                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HSA_AMD                                  policy<{'amd64': 'm'}>
++#
++CONFIG_DRM_AMDGPU_CIK				note<LP:1510405>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> DRM Support for Freescale i.MX
++CONFIG_DRM_IMX                                  policy<{'armhf': 'm'}>
++CONFIG_DRM_IMX_FB_HELPER                        policy<{'armhf': 'm'}>
++CONFIG_DRM_IMX_PARALLEL_DISPLAY                 policy<{'armhf': 'm'}>
++CONFIG_DRM_IMX_TVE                              policy<{'armhf': 'm'}>
++CONFIG_DRM_IMX_LDB                              policy<{'armhf': 'm'}>
++CONFIG_DRM_IMX_HDMI                             policy<{'armhf': 'm'}>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> DRM Support for Samsung SoC EXYNOS Series
++CONFIG_DRM_EXYNOS                               policy<{'armhf': 'm'}>
++CONFIG_DRM_EXYNOS_FIMD                          policy<{'armhf': 'n'}>
++CONFIG_DRM_EXYNOS5433_DECON                     policy<{'armhf': 'y'}>
++CONFIG_DRM_EXYNOS_VIDI                          policy<{'armhf': 'n'}>
++CONFIG_DRM_EXYNOS_G2D                           policy<{'armhf': 'n'}>
++CONFIG_DRM_EXYNOS_MIC                           policy<{'armhf': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> DRM Support for Samsung SoC EXYNOS Series >> Exynos DRM IPP
++CONFIG_DRM_EXYNOS_IPP                           policy<{'armhf': 'n'}>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> DRM Support for Samsung SoC EXYNOS Series >> Exynos7 DRM DECON
++CONFIG_DRM_EXYNOS7_DECON                        policy<{'armhf': 'n'}>
++CONFIG_DRM_EXYNOS_DSI                           policy<{'armhf': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> Display Interface Bridges
++CONFIG_DRM_NXP_PTN3460                          policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_PARADE_PS8622                        policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> Display Panels
++CONFIG_DRM_PANEL_SIMPLE                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_PANEL_SAMSUNG_LD9040                 policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_PANEL_LG_LG4573                      policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_PANEL_SAMSUNG_S6E8AA0                policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_PANEL_SHARP_LQ101R1SX01              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> I2C encoder or helper chips
++CONFIG_DRM_I2C_ADV7511                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_I2C_CH7006                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_I2C_SIL164                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRM_I2C_NXP_TDA998X                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> Intel GMA5/600 KMS Framebuffer
++CONFIG_DRM_GMA500                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_DRM_GMA600                               policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_DRM_GMA3600                              policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_DRM_MEDFIELD                             policy<{'i386': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> MSM DRM
++CONFIG_DRM_MSM                                  policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_DRM_MSM_FBDEV                            policy<{'arm64': 'n', 'armhf': 'n'}>
++CONFIG_DRM_MSM_REGISTER_LOGGING                 policy<{'arm64': 'y', 'armhf': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> MSM DRM >> Enable DSI support in MSM DRM driver
++CONFIG_DRM_MSM_DSI                              policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_DRM_MSM_DSI_PLL                          policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_DRM_MSM_DSI_28NM_PHY                     policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_DRM_MSM_DSI_20NM_PHY                     policy<{'arm64': 'y', 'armhf': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> NVIDIA Tegra DRM
++CONFIG_DRM_TEGRA                                policy<{'armhf-generic': 'm'}>
++CONFIG_DRM_TEGRA_FBDEV                          policy<{'armhf-generic': 'y'}>
++CONFIG_DRM_TEGRA_DEBUG                          policy<{'armhf-generic': 'n'}>
++CONFIG_DRM_TEGRA_STAGING                        policy<{'armhf-generic': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) >> Nouveau (NVIDIA) cards
++CONFIG_DRM_NOUVEAU                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NOUVEAU_PLATFORM_DRIVER                  policy<{'armhf-generic': 'y'}>
++CONFIG_NOUVEAU_DEBUG                            policy<{'amd64': '5', 'arm64': '5', 'armhf': '5', 'i386': '5', 'powerpc': '5', 'ppc64el': '5'}>
++CONFIG_NOUVEAU_DEBUG_DEFAULT                    policy<{'amd64': '3', 'arm64': '3', 'armhf': '3', 'i386': '3', 'powerpc': '3', 'ppc64el': '3'}>
++CONFIG_DRM_NOUVEAU_BACKLIGHT                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices
++CONFIG_FB_SH_MOBILE_MERAM                       policy<{'armhf': 'm'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Exynos Video driver support
++CONFIG_EXYNOS_VIDEO                             policy<{'armhf': 'y'}>
++CONFIG_EXYNOS_MIPI_DSI                          policy<{'armhf': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Marvell MMP Display Subsystem support
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> OMAP Display Device Drivers (new device model)
++CONFIG_DISPLAY_ENCODER_OPA362                   policy<{'armhf': 'm'}>
++CONFIG_DISPLAY_ENCODER_TFP410                   policy<{'armhf': 'm'}>
++CONFIG_DISPLAY_ENCODER_TPD12S015                policy<{'armhf': 'y'}>
++CONFIG_DISPLAY_CONNECTOR_DVI                    policy<{'armhf': 'm'}>
++CONFIG_DISPLAY_CONNECTOR_HDMI                   policy<{'armhf': 'y'}>
++CONFIG_DISPLAY_CONNECTOR_ANALOG_TV              policy<{'armhf': 'm'}>
++CONFIG_DISPLAY_PANEL_DPI                        policy<{'armhf': 'm'}>
++CONFIG_DISPLAY_PANEL_DSI_CM                     policy<{'armhf': 'm'}>
++CONFIG_DISPLAY_PANEL_SONY_ACX565AKM             policy<{'armhf': 'm'}>
++CONFIG_DISPLAY_PANEL_LGPHILIPS_LB035Q02         policy<{'armhf': 'm'}>
++CONFIG_DISPLAY_PANEL_SHARP_LS037V7DW01          policy<{'armhf': 'm'}>
++CONFIG_DISPLAY_PANEL_TPO_TD028TTEC1             policy<{'armhf': 'm'}>
++CONFIG_DISPLAY_PANEL_TPO_TD043MTEA1             policy<{'armhf': 'm'}>
++CONFIG_DISPLAY_PANEL_NEC_NL8048HL11             policy<{'armhf': 'm'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> OMAP2+ Display Subsystem support
++CONFIG_OMAP2_DSS                                policy<{'armhf': 'y'}>
++CONFIG_OMAP2_DSS_DEBUG                          policy<{'armhf': 'n'}>
++CONFIG_OMAP2_DSS_DEBUGFS                        policy<{'armhf': 'n'}>
++CONFIG_OMAP2_DSS_DPI                            policy<{'armhf': 'y'}>
++CONFIG_OMAP2_DSS_VENC                           policy<{'armhf': 'y'}>
++CONFIG_OMAP4_DSS_HDMI                           policy<{'armhf': 'y'}>
++CONFIG_OMAP5_DSS_HDMI                           policy<{'armhf': 'y'}>
++CONFIG_OMAP2_DSS_SDI                            policy<{'armhf': 'y'}>
++CONFIG_OMAP2_DSS_DSI                            policy<{'armhf': 'n'}>
++CONFIG_OMAP2_DSS_MIN_FCK_PER_PCK                policy<{'armhf': '0'}>
++CONFIG_OMAP2_DSS_SLEEP_AFTER_VENC_RESET         policy<{'armhf': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices
++CONFIG_FB                                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_FIRMWARE_EDID                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_MODE_HELPERS                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_TILEBLITTING                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_CIRRUS                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_PM2                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_PM2_FIFO_DISCONNECT                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_ARMCLCD                               policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_FB_IMX                                   policy<{'armhf-generic': 'm'}>
++CONFIG_FB_CYBER2000                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_CYBER2000_DDC                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_ARC                                   policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_FB_OF                                    policy<{'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_CONTROL                               policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_FB_PLATINUM                              policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_FB_VALKYRIE                              policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_FB_CT65550                               policy<{'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_FB_ASILIANT                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_IMSTT                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_VGA16                                 policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_UVESA                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_VESA                                  policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_FB_EFI                                   policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_FB_N411                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_FB_HGA                                   policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_FB_OPENCORES                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_S1D13XXX                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_I740                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_I810                                  policy<{'i386': 'm'}>
++CONFIG_FB_I810_GTF                              policy<{'i386': 'n'}>
++CONFIG_FB_LE80578                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_FB_CARILLO_RANCH                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_FB_INTEL                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_FB_INTEL_DEBUG                           policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_FB_INTEL_I2C                             policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_FB_ATY128                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'y', 'ppc64el': 'm'}>
++CONFIG_FB_ATY128_BACKLIGHT                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_S3                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_S3_DDC                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_SAVAGE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_SAVAGE_I2C                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_SAVAGE_ACCEL                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_FB_SIS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_SIS_300                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_SIS_315                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_VIA                                   policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_FB_VIA_DIRECT_PROCFS                     policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_FB_VIA_X_COMPATIBILITY                   policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_FB_NEOMAGIC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_KYRO                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_3DFX                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_3DFX_ACCEL                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_FB_3DFX_I2C                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_FB_VOODOO1                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'y', 'ppc64el': 'm'}>
++CONFIG_FB_VT8623                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TRIDENT                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_ARK                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_PM3                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_CARMINE                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_FSL_DIU                               policy<{'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_FB_SH_MOBILE_LCDC                        policy<{'armhf': 'm'}>
++CONFIG_FB_SH_MOBILE_HDMI                        policy<{'armhf': 'm'}>
++CONFIG_FB_TMIO                                  policy<{'armhf': 'm'}>
++CONFIG_FB_TMIO_ACCELL                           policy<{'armhf': 'y'}>
++CONFIG_FB_S3C                                   policy<{'armhf': 'm'}>
++CONFIG_FB_S3C_DEBUG_REGWRITE                    policy<{'armhf': 'n'}>
++CONFIG_FB_SM501                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_SMSCUFX                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_UDL                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_IBM_GXT4500                           policy<{'powerpc': 'm', 'ppc64el': 'y'}>
++CONFIG_FB_PS3                                   policy<{'powerpc-powerpc64-smp': 'y'}>
++CONFIG_FB_PS3_DEFAULT_SIZE_M                    policy<{'powerpc-powerpc64-smp': '9'}>
++CONFIG_FB_DA8XX                                 policy<{'armhf-generic': 'm'}>
++CONFIG_FB_VIRTUAL                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_XEN_FBDEV_FRONTEND                       policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_FB_METRONOME                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_MB862XX                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_MB862XX_I2C                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_MX3                                   policy<{'armhf-generic': 'y'}>
++CONFIG_FB_BROADSHEET                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_AUO_K190X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_AUO_K1900                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_AUO_K1901                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_MXS                                   policy<{'armhf-generic': 'm'}>
++CONFIG_FB_HYPERV                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_FB_SIMPLE                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_SSD1307                               policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_SM712                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_FB_ATY128                                note<boot essential on powerpc>
++CONFIG_FB_VOODOO1                               note<boot essential on powerpc>
++CONFIG_FB_VIRTUAL                               flag<TESTING>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> AMD Geode family framebuffer support
++CONFIG_FB_GEODE                                 policy<{'i386': 'y'}>
++CONFIG_FB_GEODE_LX                              policy<{'i386': 'm'}>
++CONFIG_FB_GEODE_GX                              policy<{'i386': 'm'}>
++CONFIG_FB_GEODE_GX1                             policy<{'i386': 'm'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> ATI Mach64 display support
++CONFIG_FB_ATY                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_ATY_CT                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_ATY_GENERIC_LCD                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_FB_ATY_GX                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_ATY_BACKLIGHT                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> ATI Radeon display support
++CONFIG_FB_RADEON                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_RADEON_I2C                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_RADEON_BACKLIGHT                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_RADEON_DEBUG                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> Amiga native chipset support
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> DRAM timing
++CONFIG_FB_CARMINE_DRAM_EVAL                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CARMINE_DRAM_CUSTOM                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> Framebuffer foreign endianness support
++CONFIG_FB_FOREIGN_ENDIAN                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> Framebuffer foreign endianness support >> Choice endianness support
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> GDC variant
++CONFIG_FB_MB862XX_PCI_GDC                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_MB862XX_LIME                          policy<{'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> Matrox acceleration
++CONFIG_FB_MATROX                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_MATROX_MILLENIUM                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_MATROX_MYSTIQUE                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_MATROX_G                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_MATROX_I2C                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_MATROX_MAVEN                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> OMAP frame buffer support
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> OMAP2+ frame buffer support
++CONFIG_FB_OMAP2                                 policy<{'armhf': 'm'}>
++CONFIG_FB_OMAP2_DEBUG_SUPPORT                   policy<{'armhf': 'n'}>
++CONFIG_FB_OMAP2_NUM_FBS                         policy<{'armhf': '3'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> PXA LCD framebuffer support
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> SBUS and UPA framebuffers
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> Size of ADV7393 frame buffer memory Single/Double Size
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> Video mode support
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> nVidia Framebuffer Support
++CONFIG_FB_NVIDIA                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_NVIDIA_I2C                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_NVIDIA_DEBUG                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_FB_NVIDIA_BACKLIGHT                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices >> nVidia Riva support
++CONFIG_FB_RIVA                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_RIVA_I2C                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FB_RIVA_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_FB_RIVA_BACKLIGHT                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> HID support
++
++# Menu: Device Drivers >> HID support >> HID bus support
++CONFIG_HID                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_BATTERY_STRENGTH                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HIDRAW                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_UHID                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_GENERIC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> HID support >> HID bus support >> Special HID drivers
++CONFIG_HID_A4TECH                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_ACRUX                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_ACRUX_FF                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_APPLE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_APPLEIR                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_AUREAL                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_BELKIN                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_BETOP_FF                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_CHERRY                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_CHICONY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_PRODIKEYS                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_CP2112                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_CYPRESS                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_DRAGONRISE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DRAGONRISE_FF                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_EMS_FF                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_ELECOM                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_ELO                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_EZKEY                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_GEMBIRD                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_HOLTEK                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HOLTEK_FF                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_GT683R                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_KEYTOUCH                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_KYE                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_UCLOGIC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_WALTOP                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_GYRATION                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_ICADE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_TWINHAN                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_KENSINGTON                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_LCPOWER                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_LENOVO                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_MAGICMOUSE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_MICROSOFT                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_MONTEREY                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_MULTITOUCH                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_NTRIG                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_ORTEK                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_PANTHERLORD                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PANTHERLORD_FF                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_PENMOUNT                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_PETALYNX                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_PLANTRONICS                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_PRIMAX                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_ROCCAT                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SAITEK                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SAMSUNG                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SONY                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SONY_FF                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_SPEEDLINK                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_STEELSERIES                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SUNPLUS                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_RMI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_GREENASIA                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GREENASIA_FF                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_HYPERV_MOUSE                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_HID_SMARTJOYPLUS                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SMARTJOYPLUS_FF                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_TIVO                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_TOPSEED                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_THINGM                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_THRUSTMASTER                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_THRUSTMASTER_FF                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_WACOM                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_WIIMOTE                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_XINMO                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_ZEROPLUS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ZEROPLUS_FF                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_ZYDACRON                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SENSOR_HUB                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SENSOR_CUSTOM_SENSOR                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> HID support >> HID bus support >> Special HID drivers >> Logitech devices
++CONFIG_HID_LOGITECH                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_LOGITECH_DJ                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_LOGITECH_HIDPP                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LOGITECH_FF                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LOGIRUMBLEPAD2_FF                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LOGIG940_FF                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LOGIWHEELS_FF                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> HID support >> HID bus support >> Special HID drivers >> PicoLCD (graphic version)
++CONFIG_HID_PICOLCD                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_PICOLCD_FB                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_PICOLCD_BACKLIGHT                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_PICOLCD_LCD                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_PICOLCD_LEDS                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HID_PICOLCD_CIR                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> HID support >> I2C HID support
++CONFIG_I2C_HID                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> HID support >> USB HID support
++CONFIG_USB_HID                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_PID                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_HIDDEV                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> HID support >> USB HID support >> USB HID Boot Protocol drivers
++CONFIG_USB_KBD                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MOUSE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> HSI support
++CONFIG_HSI                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_OMAP_SSI                                 policy<{'armhf-generic': 'm'}>
++CONFIG_NOKIA_MODEM                              policy<{'armhf-generic': 'm'}>
++CONFIG_CMT_SPEECH                               policy<{'armhf-generic': 'm'}>
++CONFIG_SSI_PROTOCOL                             policy<{'armhf-generic': 'm'}>
++CONFIG_HSI_CHAR                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Hardware Monitoring support
++CONFIG_HWMON                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_HWMON_DEBUG_CHIP                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SENSORS_ABITUGURU                        policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_ABITUGURU3                       policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_AD7314                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_AD7414                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_AD7418                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADM1021                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADM1025                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADM1026                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADM1029                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADM1031                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADM9240                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADT7310                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADT7410                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADT7411                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADT7462                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADT7470                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADT7475                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ASC7621                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_K8TEMP                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_K10TEMP                          policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_FAM15H_POWER                     policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_APPLESMC                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_ASB100                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_ATXP1                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_DS620                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_DS1621                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_DELL_SMM                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_DA9052_ADC                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_DA9055                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_I5K_AMB                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_F71805F                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_F71882FG                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_F75375S                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MC13783_ADC                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_FSCHMD                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_GL518SM                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_GL520SM                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_G760A                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_G762                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_GPIO_FAN                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_HIH6130                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_IBMAEM                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_IBMPEX                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_IBMPOWERNV                       policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_IIO_HWMON                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_I5500                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_CORETEMP                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_IT87                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_JC42                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_POWR1220                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LINEAGE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LTC2945                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LTC4151                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LTC4215                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LTC4222                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LTC4245                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LTC4260                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LTC4261                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX1111                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX16065                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX1619                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX1668                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX197                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX6639                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX6642                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX6650                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX6697                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_HTU21                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MCP3021                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MENF21BMC_HWMON                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADCXX                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM63                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM70                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM73                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM75                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM77                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM78                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM80                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM83                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM85                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM87                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM90                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM92                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM93                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM95234                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM95241                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM95245                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_PC87360                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_PC87427                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_NTC_THERMISTOR                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_NCT6683                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_NCT6775                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_NCT7802                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_NCT7904                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_PCF8591                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_PWM_FAN                          policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_SHT15                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_SHT21                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_SHTC1                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_SIS5595                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_DME1737                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_EMC1403                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_EMC2103                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_EMC6W201                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_SMSC47M1                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_SMSC47M192                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_SMSC47B397                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_SCH5627                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_SCH5636                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_SMM665                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADC128D818                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADS1015                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADS7828                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADS7871                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_AMC6821                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_INA209                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_INA2XX                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_TC74                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_THMC50                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_TMP102                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_TMP103                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_TMP401                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_TMP421                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_TWL4030_MADC                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_VEXPRESS                         policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SENSORS_VIA_CPUTEMP                      policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_VIA686A                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_VT1211                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_VT8231                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_W83781D                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_W83791D                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_W83792D                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_W83793                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_W83795                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_W83795_FANCTRL                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SENSORS_W83L785TS                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_W83L786NG                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_W83627HF                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_W83627EHF                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_WM831X                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_WM8350                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ACPI_POWER                       policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_ATK0110                          policy<{'amd64': 'm', 'i386': 'm'}>
++
++# Menu: Device Drivers >> Hardware Monitoring support >> PMBus support
++CONFIG_PMBUS                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_PMBUS                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ADM1275                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM25066                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LTC2978                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LTC2978_REGULATOR                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SENSORS_MAX16064                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX20751                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX34440                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_MAX8688                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_TPS40422                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_UCD9000                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_UCD9200                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ZL6100                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Hardware Spinlock drivers
++CONFIG_HWSPINLOCK_OMAP                          policy<{'armhf': 'm'}>
++CONFIG_HWSPINLOCK_QCOM                          policy<{'arm64': 'm', 'armhf': 'm'}>
++
++# Menu: Device Drivers >> I2C support
++
++# Menu: Device Drivers >> I2C support >> I2C support
++CONFIG_I2C                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ACPI_I2C_OPREGION                        policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_I2C_COMPAT                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_I2C_CHARDEV                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_I2C_MUX                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_HELPER_AUTO                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_I2C_SMBUS                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_STUB                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_SLAVE                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'y', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_I2C_SLAVE_EEPROM                         policy<{'armhf': 'm'}>
++CONFIG_I2C_THUNDERX				policy<{'arm64': 'y'}>
++CONFIG_I2C_DEBUG_CORE                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_I2C_DEBUG_ALGO                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_I2C_DEBUG_BUS                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_I2C_CHARDEV                              note<LP:1417032>
++CONFIG_I2C_THUNDERX				note<LP:1688132>
++
++# Menu: Device Drivers >> I2C support >> I2C support >> I2C Algorithms
++CONFIG_I2C_ALGOBIT                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_ALGOPCA                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> I2C support >> I2C support >> I2C Hardware Bus support
++CONFIG_I2C_ALI1535                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_ALI1563                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_ALI15X3                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_AMD756                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_AMD756_S4882                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_I2C_AMD8111                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_HIX5HD2                              policy<{'armhf': 'm'}>
++CONFIG_I2C_I801                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_ISCH                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_ISMT                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_I2C_PIIX4                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_NFORCE2                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_NFORCE2_S4985                        policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_I2C_SIS5595                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_SIS630                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_SIS96X                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_VIA                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_VIAPRO                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_SCMI                                 policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_I2C_HYDRA                                policy<{'powerpc-powerpc-smp': 'm'}>
++CONFIG_I2C_POWERMAC                             policy<{'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_I2C_AXXIA                                policy<{'armhf-generic-lpae': 'm'}>
++CONFIG_I2C_BCM_IPROC                            policy<{'arm64': 'm'}>
++CONFIG_I2C_CBUS_GPIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_CPM                                  policy<{'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_I2C_DESIGNWARE_PLATFORM                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_DESIGNWARE_PCI                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_EG20T                                policy<{'i386': 'm'}>
++CONFIG_I2C_EMEV2                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_I2C_EXYNOS5                              policy<{'armhf': 'm'}>
++CONFIG_I2C_GPIO                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_IMX                                  policy<{'armhf-generic': 'y'}>
++CONFIG_I2C_KEMPLD                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_MESON                                policy<{'armhf': 'm'}>
++CONFIG_I2C_MPC                                  policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_MT65XX                               policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_I2C_MV64XXX                              policy<{'armhf': 'm'}>
++CONFIG_I2C_NOMADIK                              policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_I2C_OCORES                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_OMAP                                 policy<{'armhf': 'y'}>
++CONFIG_I2C_PASEMI                               policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_I2C_PCA_PLATFORM                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_QUP                                  policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_I2C_RIIC                                 policy<{'armhf': 'm'}>
++CONFIG_I2C_RK3X                                 policy<{'arm64': 'm', 'armhf': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_I2C_S3C2410                              policy<{'armhf': 'y'}>
++CONFIG_I2C_SH_MOBILE                            policy<{'armhf': 'm'}>
++CONFIG_I2C_SIMTEC                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_TEGRA                                policy<{'armhf-generic': 'm'}>
++CONFIG_I2C_VERSATILE                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_I2C_XILINX                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_RCAR                                 policy<{'armhf': 'm'}>
++CONFIG_I2C_DIOLAN_U2C                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_DLN2                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_PARPORT                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_PARPORT_LIGHT                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_ROBOTFUZZ_OSIF                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_TAOS_EVM                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_TINY_USB                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_VIPERBOARD                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_PCA_ISA                              policy<{'i386': 'm'}>
++CONFIG_I2C_CROS_EC_TUNNEL                       policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_I2C_XGENE_SLIMPRO                        policy<{'arm64': 'm'}>
++CONFIG_SCx200_ACB                               policy<{'i386': 'm'}>
++CONFIG_I2C_OPAL                                 policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> I2C support >> I2C support >> Multiplexer I2C Chip support
++CONFIG_I2C_ARB_GPIO_CHALLENGE                   policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_MUX_GPIO                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_MUX_PCA9541                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_MUX_PCA954x                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_MUX_PINCTRL                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_I2C_MUX_REG                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> IEEE 1394 (FireWire) support
++CONFIG_FIREWIRE_NOSY                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++
++# Menu: Device Drivers >> IEEE 1394 (FireWire) support >> FireWire driver stack
++CONFIG_FIREWIRE                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_FIREWIRE_OHCI                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FIREWIRE_SBP2                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FIREWIRE_NET                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> IOMMU Hardware Support
++CONFIG_IOMMU_SUPPORT                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_FSL_PAMU                                 policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_AMD_IOMMU                                policy<{'amd64': 'y'}>
++CONFIG_AMD_IOMMU_STATS                          policy<{'amd64': 'y'}>
++CONFIG_AMD_IOMMU_V2                             policy<{'amd64': 'm'}>
++CONFIG_INTEL_IOMMU                              policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_INTEL_IOMMU_DEFAULT_ON                   policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_IRQ_REMAP                                policy<{'amd64': 'y'}>
++CONFIG_OMAP_IOMMU                               policy<{'armhf': 'y'}>
++CONFIG_OMAP_IOMMU_DEBUG                         policy<{'armhf': 'n'}>
++CONFIG_TEGRA_IOMMU_GART                         policy<{'armhf-generic': 'y'}>
++CONFIG_TEGRA_IOMMU_SMMU                         policy<{'armhf-generic': 'y'}>
++CONFIG_EXYNOS_IOMMU                             policy<{'armhf': 'y'}>
++CONFIG_EXYNOS_IOMMU_DEBUG                       policy<{'armhf': 'n'}>
++CONFIG_SHMOBILE_IOMMU                           policy<{'armhf': 'y'}>
++CONFIG_IPMMU_VMSA                               policy<{'armhf-generic-lpae': 'y'}>
++CONFIG_SPAPR_TCE_IOMMU                          policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_ARM_SMMU                                 policy<{'arm64': 'y', 'armhf': 'n'}>
++CONFIG_ARM_SMMU_V3                              policy<{'arm64': 'y'}>
++#
++CONFIG_INTEL_IOMMU_DEFAULT_ON                   note<the IOMMU can trigger boot failures> flag<REVIEW>
++
++# Menu: Device Drivers >> IOMMU Hardware Support >> Generic IOMMU Pagetable Support
++CONFIG_IOMMU_IO_PGTABLE_LPAE                    policy<{'arm64': 'y', 'armhf-generic': 'n', 'armhf-generic-lpae': 'y'}>
++CONFIG_IOMMU_IO_PGTABLE_LPAE_SELFTEST           policy<{'arm64': 'n', 'armhf-generic-lpae': 'n'}>
++
++# Menu: Device Drivers >> IOMMU Hardware Support >> IPMMU/IPMMUI address space size
++CONFIG_SHMOBILE_IOMMU_ADDRSIZE_2048MB           policy<{'armhf': 'y'}>
++CONFIG_SHMOBILE_IOMMU_ADDRSIZE_1024MB           policy<{'armhf': 'n'}>
++CONFIG_SHMOBILE_IOMMU_ADDRSIZE_512MB            policy<{'armhf': 'n'}>
++CONFIG_SHMOBILE_IOMMU_ADDRSIZE_256MB            policy<{'armhf': 'n'}>
++CONFIG_SHMOBILE_IOMMU_ADDRSIZE_128MB            policy<{'armhf': 'n'}>
++CONFIG_SHMOBILE_IOMMU_ADDRSIZE_64MB             policy<{'armhf': 'n'}>
++CONFIG_SHMOBILE_IOMMU_ADDRSIZE_32MB             policy<{'armhf': 'n'}>
++
++# Menu: Device Drivers >> ISDN support
++CONFIG_ISDN                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HYSDN                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HYSDN_CAPI                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> ISDN support >> CAPI 2.0 subsystem
++CONFIG_ISDN_CAPI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAPI_TRACE                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ISDN_CAPI_CAPI20                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISDN_CAPI_MIDDLEWARE                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ISDN_CAPI_CAPIDRV                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISDN_CAPI_CAPIDRV_VERBOSE                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> ISDN support >> CAPI 2.0 subsystem >> Active AVM cards
++CONFIG_CAPI_AVM                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ISDN_DRV_AVMB1_B1ISA                     policy<{'i386': 'm'}>
++CONFIG_ISDN_DRV_AVMB1_B1PCI                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISDN_DRV_AVMB1_B1PCIV4                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ISDN_DRV_AVMB1_T1ISA                     policy<{'i386': 'm'}>
++CONFIG_ISDN_DRV_AVMB1_B1PCMCIA                  policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_ISDN_DRV_AVMB1_AVM_CS                    policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_ISDN_DRV_AVMB1_T1PCI                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISDN_DRV_AVMB1_C4                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> ISDN support >> CAPI 2.0 subsystem >> Active Eicon DIVA Server cards
++CONFIG_CAPI_EICON                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> ISDN support >> CAPI 2.0 subsystem >> Active Eicon DIVA Server cards >> Support Eicon DIVA Server cards
++CONFIG_ISDN_DIVAS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISDN_DIVAS_BRIPCI                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ISDN_DIVAS_PRIPCI                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ISDN_DIVAS_DIVACAPI                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISDN_DIVAS_USERIDI                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISDN_DIVAS_MAINT                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> ISDN support >> Modular ISDN driver
++CONFIG_MISDN                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MISDN_DSP                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MISDN_L1OIP                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MISDN_HFCPCI                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MISDN_HFCMULTI                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MISDN_HFCUSB                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MISDN_AVMFRITZ                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MISDN_SPEEDFAX                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MISDN_INFINEON                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MISDN_W6692                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MISDN_NETJET                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> ISDN support >> Old ISDN4Linux (deprecated)
++CONFIG_ISDN_I4L                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISDN_AUDIO                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ISDN_TTY_FAX                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ISDN_X25                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++#
++CONFIG_ISDN_I4L                                 flag<REVIEW>
++
++# Menu: Device Drivers >> ISDN support >> Old ISDN4Linux (deprecated) >> Active cards
++CONFIG_ISDN_DRV_ICN                             policy<{'i386': 'm'}>
++CONFIG_ISDN_DRV_PCBIT                           policy<{'i386': 'm'}>
++CONFIG_ISDN_DRV_SC                              policy<{'i386': 'm'}>
++CONFIG_ISDN_DRV_ACT2000                         policy<{'i386': 'm'}>
++
++# Menu: Device Drivers >> ISDN support >> Old ISDN4Linux (deprecated) >> ISDN feature submodules
++CONFIG_ISDN_DIVERSION                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> ISDN support >> Old ISDN4Linux (deprecated) >> Passive cards
++
++# Menu: Device Drivers >> ISDN support >> Old ISDN4Linux (deprecated) >> Passive cards >> HiSax SiemensChipSet driver support
++CONFIG_ISDN_DRV_HISAX                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HISAX_1TR6                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_NI1                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_MAX_CARDS                          policy<{'amd64': '8', 'arm64': '8', 'armhf': '8', 'i386': '8', 'powerpc': '8', 'ppc64el': '8'}>
++CONFIG_HISAX_16_0                               policy<{'i386': 'y'}>
++CONFIG_HISAX_16_3                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_TELESPCI                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y'}>
++CONFIG_HISAX_S0BOX                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_AVM_A1                             policy<{'i386': 'y'}>
++CONFIG_HISAX_FRITZPCI                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_HISAX_AVM_A1_PCMCIA                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_ELSA                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_IX1MICROR2                         policy<{'i386': 'y'}>
++CONFIG_HISAX_DIEHLDIVA                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_ASUSCOM                            policy<{'i386': 'y'}>
++CONFIG_HISAX_TELEINT                            policy<{'i386': 'y'}>
++CONFIG_HISAX_HFCS                               policy<{'i386': 'y'}>
++CONFIG_HISAX_SEDLBAUER                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_SPORTSTER                          policy<{'i386': 'y'}>
++CONFIG_HISAX_MIC                                policy<{'i386': 'y'}>
++CONFIG_HISAX_NETJET                             policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_HISAX_NETJET_U                           policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_HISAX_NICCY                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_ISURF                              policy<{'i386': 'y'}>
++CONFIG_HISAX_HSTSAPHIR                          policy<{'i386': 'y'}>
++CONFIG_HISAX_BKM_A4T                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_SCT_QUADRO                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_GAZEL                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_HFC_PCI                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y'}>
++CONFIG_HISAX_W6692                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_HFC_SX                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_ENTERNOW_PCI                       policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_HISAX_DEBUG                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_HISAX_SEDLBAUER_CS                       policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_HISAX_ELSA_CS                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_HISAX_AVM_A1_CS                          policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_HISAX_TELES_CS                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_HISAX_ST5481                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HISAX_HFCUSB                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HISAX_HFC4S8S                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HISAX_FRITZ_PCIPNP                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> ISDN support >> Old ISDN4Linux (deprecated) >> Passive cards >> HiSax SiemensChipSet driver support >> HiSax Support for EURO/DSS1
++CONFIG_HISAX_EURO                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DE_AOC                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HISAX_NO_SENDCOMPLETE                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_HISAX_NO_LLC                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_HISAX_NO_KEYPAD                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> ISDN support >> Old ISDN4Linux (deprecated) >> Support synchronous PPP
++CONFIG_ISDN_PPP                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ISDN_PPP_VJ                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ISDN_MPP                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IPPP_FILTER                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ISDN_PPP_BSDCOMP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> ISDN support >> Siemens Gigaset support
++CONFIG_ISDN_DRV_GIGASET                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GIGASET_CAPI                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_GIGASET_BASE                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GIGASET_M105                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GIGASET_M101                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GIGASET_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Industrial I/O support
++CONFIG_IIO                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_IIO_BUFFER                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IIO_BUFFER_CB                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IIO_KFIFO_BUF                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IIO_TRIGGER                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IIO_CONSUMERS_PER_TRIGGER                policy<{'amd64': '2', 'arm64': '2', 'armhf': '2', 'i386': '2', 'powerpc': '2', 'ppc64el': '2'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Accelerometers
++CONFIG_BMA180                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BMC150_ACCEL                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SENSOR_ACCEL_3D                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IIO_ST_ACCEL_3AXIS                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KXSD9                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMA8452                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KXCJK1013                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMA9551                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMA9553                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_STK8312                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_STK8BA50                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Amplifiers
++CONFIG_AD8366                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Analog to digital converters
++CONFIG_AD7266                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7291                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7298                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7476                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7791                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7793                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7887                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7923                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD799X                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AXP288_ADC                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BERLIN2_ADC                              policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_DA9150_GPADC                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CC10001_ADC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_EXYNOS_ADC                               policy<{'armhf': 'm'}>
++CONFIG_LP8788_ADC                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MAX1027                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MAX1363                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MCP320X                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MCP3422                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEN_Z188_ADC                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NAU7802                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_QCOM_SPMI_IADC                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_QCOM_SPMI_VADC                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TI_ADC081C                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TI_ADC128S052                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TI_AM335X_ADC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TWL4030_MADC                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TWL6030_GPADC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VF610_ADC                                policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIPERBOARD_ADC                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Digital gyroscope sensors
++CONFIG_ADIS16080                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADIS16130                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADIS16136                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADIS16260                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADXRS450                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BMG160                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SENSOR_GYRO_3D                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IIO_ST_GYRO_3AXIS                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ITG3200                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Digital to analog converters
++CONFIG_AD5064                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD5360                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD5380                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD5421                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD5446                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD5449                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD5504                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD5624R_SPI                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD5686                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD5755                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD5764                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD5791                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7303                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_M62332                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MAX517                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MAX5821                                  policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MCP4725                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MCP4922                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Frequency Synthesizers DDS/PLL
++
++# Menu: Device Drivers >> Industrial I/O support >> Frequency Synthesizers DDS/PLL >> Clock Generator/Distribution
++CONFIG_AD9523                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Frequency Synthesizers DDS/PLL >> Phase-Locked Loop (PLL) frequency synthesizers
++CONFIG_ADF4350                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Hid Sensor IIO Common
++CONFIG_HID_SENSOR_IIO_COMMON                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SENSOR_IIO_TRIGGER                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Humidity sensors
++CONFIG_DHT11                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SI7005                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SI7020                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Inclinometer sensors
++CONFIG_HID_SENSOR_INCLINOMETER_3D               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SENSOR_DEVICE_ROTATION               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Inertial measurement units
++CONFIG_ADIS16400                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADIS16480                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KMX61                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INV_MPU6050_IIO                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Light sensors
++CONFIG_ACPI_ALS                                 policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_ADJD_S311                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AL3320A                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_APDS9300                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BH1750                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CM32181                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CM3232                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CM3323                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CM36651                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GP2AP020A00F                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISL29125                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SENSOR_ALS                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SENSOR_PROX                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JSA1212                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RPR0521                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LM3533                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LTR501                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_OPT3001                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PA12203001                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_STK3310                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TCS3414                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TCS3472                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_TSL2563                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TSL4531                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VCNL4000                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Lightning sensors
++CONFIG_AS3935                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Magnetometer sensors
++CONFIG_AK8975                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AK09911                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MAG3110                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SENSOR_MAGNETOMETER_3D               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC35240                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IIO_ST_MAGN_3AXIS                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BMC150_MAGN                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Pressure sensors
++CONFIG_BMP280                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HID_SENSOR_PRESS                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MPL115                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MPL3115                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MS5611                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MS5611_I2C                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MS5611_SPI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IIO_ST_PRESS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_T5403                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Proximity sensors
++CONFIG_SX9500                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> SSP Sensor Common
++CONFIG_IIO_SSP_SENSORS_COMMONS                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IIO_SSP_SENSORHUB                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Temperature sensors
++CONFIG_MLX90614                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TMP006                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Industrial I/O support >> Triggers - standalone
++CONFIG_IIO_INTERRUPT_TRIGGER                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IIO_SYSFS_TRIGGER                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> IndustryPack bus support
++CONFIG_IPACK_BUS                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_BOARD_TPCI200                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIAL_IPOCTAL                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> InfiniBand support
++CONFIG_INFINIBAND                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INFINIBAND_USER_MAD                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INFINIBAND_USER_ACCESS                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INFINIBAND_ON_DEMAND_PAGING              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_INFINIBAND_MTHCA                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INFINIBAND_MTHCA_DEBUG                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_INFINIBAND_QIB                           policy<{'amd64': 'm', 'arm64': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_INFINIBAND_QIB_DCA                       policy<{'amd64': 'y'}>
++CONFIG_INFINIBAND_CXGB3                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INFINIBAND_CXGB3_DEBUG                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_INFINIBAND_CXGB4                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MLX4_INFINIBAND                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MLX5_INFINIBAND                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INFINIBAND_NES                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_INFINIBAND_NES_DEBUG                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_INFINIBAND_OCRDMA                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_INFINIBAND_USNIC                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INFINIBAND_IPOIB                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INFINIBAND_IPOIB_CM                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_INFINIBAND_IPOIB_DEBUG                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_INFINIBAND_SRP                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INFINIBAND_SRPT                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INFINIBAND_ISER                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INFINIBAND_ISERT                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Device Drivers >> Input device support
++
++# Menu: Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...)
++CONFIG_INPUT                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_INPUT_LEDS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_FF_MEMLESS                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_POLLDEV                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_SPARSEKMAP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_MATRIXKMAP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_JOYDEV                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_EVDEV                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_INPUT_EVBUG                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_APMPOWER                           policy<{'powerpc-powerpc-smp': 'm'}>
++
++# Menu: Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Joysticks/Gamepads
++CONFIG_INPUT_JOYSTICK                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JOYSTICK_ANALOG                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_A3D                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_ADI                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_COBRA                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_GF2K                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_GRIP                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_GRIP_MP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_GUILLEMOT                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_INTERACT                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_SIDEWINDER                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_TMDC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_IFORCE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_IFORCE_USB                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JOYSTICK_IFORCE_232                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JOYSTICK_WARRIOR                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_MAGELLAN                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_SPACEORB                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_SPACEBALL                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_STINGER                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_TWIDJOY                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_ZHENHUA                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_DB9                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_GAMECON                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_TURBOGRAFX                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_AS5011                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_JOYDUMP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_XPAD                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JOYSTICK_XPAD_FF                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JOYSTICK_XPAD_LEDS                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JOYSTICK_WALKERA0701                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Keyboards
++CONFIG_INPUT_KEYBOARD                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_KEYBOARD_ADP5520                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_ADP5588                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_ADP5589                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_ATKBD                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_KEYBOARD_QT1070                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_QT2160                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_LKKBD                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_GPIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_GPIO_POLLED                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_TCA6416                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_TCA8418                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_MATRIX                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_LM8323                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_LM8333                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_MAX7359                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_MCS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_MPR121                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_SNVS_PWRKEY                     policy<{'armhf-generic': 'm'}>
++CONFIG_KEYBOARD_IMX                             policy<{'armhf-generic': 'm'}>
++CONFIG_KEYBOARD_NEWTON                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_TEGRA                           policy<{'armhf-generic': 'm'}>
++CONFIG_KEYBOARD_OPENCORES                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_PMIC8XXX                        policy<{'armhf': 'm'}>
++CONFIG_KEYBOARD_SAMSUNG                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_KEYBOARD_STOWAWAY                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_SUNKBD                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_SH_KEYSC                        policy<{'armhf': 'm'}>
++CONFIG_KEYBOARD_STMPE                           policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_OMAP4                           policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_TC3589X                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_TWL4030                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_XTKBD                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_CROS_EC                         policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_KEYBOARD_CAP11XX                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KEYBOARD_BCM                             policy<{'arm64': 'm', 'armhf': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++
++# Menu: Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Mice
++CONFIG_INPUT_MOUSE                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_SERIAL                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MOUSE_APPLETOUCH                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MOUSE_BCM5974                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MOUSE_CYAPA                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MOUSE_ELAN_I2C                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MOUSE_ELAN_I2C_I2C                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_ELAN_I2C_SMBUS                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_INPORT                             policy<{'i386': 'n'}>
++CONFIG_MOUSE_LOGIBM                             policy<{'i386': 'm'}>
++CONFIG_MOUSE_PC110PAD                           policy<{'i386': 'm'}>
++CONFIG_MOUSE_VSXXXAA                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MOUSE_GPIO                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MOUSE_SYNAPTICS_I2C                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MOUSE_SYNAPTICS_USB                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_MOUSE_INPORT                             note<very old ISA based mouse support>
++
++# Menu: Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Mice >> PS/2 mouse
++CONFIG_MOUSE_PS2                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MOUSE_PS2_ALPS                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_PS2_LOGIPS2PP                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_PS2_SYNAPTICS                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_PS2_CYPRESS                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_PS2_LIFEBOOK                       policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_MOUSE_PS2_TRACKPOINT                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_PS2_ELANTECH                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_PS2_SENTELIC                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_PS2_TOUCHKIT                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_PS2_FOCALTECH                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MOUSE_PS2_VMMOUSE                        policy<{'amd64': 'y', 'i386': 'y'}>
++
++# Menu: Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Miscellaneous devices
++CONFIG_INPUT_MISC                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_INPUT_88PM860X_ONKEY                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_88PM80X_ONKEY                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_AD714X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_AD714X_I2C                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_AD714X_SPI                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_ARIZONA_HAPTICS                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_BMA150                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_E3X0_BUTTON                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_PCSPKR                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_PM8941_PWRKEY                      policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_INPUT_PM8XXX_VIBRATOR                    policy<{'armhf': 'm'}>
++CONFIG_INPUT_PMIC8XXX_PWRKEY                    policy<{'armhf': 'm'}>
++CONFIG_INPUT_MAX77693_HAPTIC                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_MAX8925_ONKEY                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_MAX8997_HAPTIC                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_MC13783_PWRBUTTON                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_MMA8450                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_MPU3050                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_APANEL                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INPUT_GP2A                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_GPIO_BEEPER                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_GPIO_TILT_POLLED                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_WISTRON_BTNS                       policy<{'i386': 'm'}>
++CONFIG_INPUT_ATLAS_BTNS                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INPUT_ATI_REMOTE2                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_KEYSPAN_REMOTE                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_KXTJ9                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_KXTJ9_POLLED_MODE                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_INPUT_POWERMATE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_YEALINK                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_CM109                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_REGULATOR_HAPTIC                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_RETU_PWRBUTTON                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_TPS65218_PWRBUTTON                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_AXP20X_PEK                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_TWL4030_PWRBUTTON                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_TWL4030_VIBRA                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_TWL6040_VIBRA                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_UINPUT                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_INPUT_PALMAS_PWRBUTTON                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_PCF50633_PMU                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_PCF8574                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_PWM_BEEPER                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_GPIO_ROTARY_ENCODER                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_DA9052_ONKEY                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_DA9055_ONKEY                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_DA9063_ONKEY                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_WM831X_ON                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_PCAP                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_ADXL34X                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_ADXL34X_I2C                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_ADXL34X_SPI                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_IMS_PCU                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_CMA3000                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_CMA3000_I2C                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_XEN_KBDDEV_FRONTEND                policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_INPUT_IDEAPAD_SLIDEBAR                   policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_SOC_BUTTON_ARRAY                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_DRV260X_HAPTICS                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_DRV2665_HAPTICS                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INPUT_DRV2667_HAPTICS                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_INPUT_UINPUT                             mark<ENFORCED> note<LP:584812>
++
++# Menu: Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Mouse interface
++CONFIG_INPUT_MOUSEDEV                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_INPUT_MOUSEDEV_PSAUX                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_INPUT_MOUSEDEV_SCREEN_X                  policy<{'amd64': '1024', 'arm64': '1024', 'armhf': '1024', 'i386': '1024', 'powerpc': '1024', 'ppc64el': '1024'}>
++CONFIG_INPUT_MOUSEDEV_SCREEN_Y                  policy<{'amd64': '768', 'arm64': '768', 'armhf': '768', 'i386': '768', 'powerpc': '768', 'ppc64el': '768'}>
++
++# Menu: Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Tablets
++CONFIG_INPUT_TABLET                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TABLET_USB_ACECAD                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TABLET_USB_AIPTEK                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TABLET_USB_GTCO                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TABLET_USB_HANWANG                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TABLET_USB_KBTAB                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TABLET_SERIAL_WACOM4                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Touchscreens
++CONFIG_INPUT_TOUCHSCREEN                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_88PM860X                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_ADS7846                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_AD7877                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_AD7879                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_AD7879_I2C                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_AD7879_SPI                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_AR1021_I2C                   policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_ATMEL_MXT                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_AUO_PIXCIR                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_BU21013                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_CHIPONE_ICN8318              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_CY8CTMG110                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_CYTTSP_CORE                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_CYTTSP_I2C                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_CYTTSP_SPI                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_CYTTSP4_CORE                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_CYTTSP4_I2C                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_CYTTSP4_SPI                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_DA9034                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_DA9052                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_DYNAPRO                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_HAMPSHIRE                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_EETI                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_EGALAX                       policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_FUJITSU                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_GOODIX                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_ILI210X                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_IPROC                        policy<{'arm64': 'm'}>
++CONFIG_TOUCHSCREEN_GUNZE                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_ELAN                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_ELO                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_WACOM_W8001                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_WACOM_I2C                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_MAX11801                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_MCS5000                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_MMS114                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_MTOUCH                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_IMX6UL_TSC                   policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_INEXIO                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_INTEL_MID                    policy<{'i386': 'm'}>
++CONFIG_TOUCHSCREEN_MK712                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_HTCPEN                       policy<{'i386': 'm'}>
++CONFIG_TOUCHSCREEN_PENMOUNT                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_EDT_FT5X06                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_TOUCHRIGHT                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_TOUCHWIN                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_TI_AM335X_TSC                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_UCB1400                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_PIXCIR                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_WDT87XX_I2C                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_WM831X                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_MC13783                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_TOUCHIT213                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_TSC_SERIO                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_TSC2005                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_TSC2007                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_PCAP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_ST1232                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_STMPE                        policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_SUR40                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_SX8654                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_TPS6507X                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_ZFORCE                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_COLIBRI_VF50                 policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Touchscreens >> Support for WM97xx AC97 touchscreen controllers
++CONFIG_TOUCHSCREEN_WM97XX                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_WM9705                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_WM9712                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_WM9713                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Touchscreens >> USB Touchscreen Driver
++CONFIG_TOUCHSCREEN_USB_COMPOSITE                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOUCHSCREEN_USB_EGALAX                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_PANJIT                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_3M                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_ITM                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_ETURBO                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_GUNZE                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_DMC_TSC10                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_IRTOUCH                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_IDEALTEK                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_GENERAL_TOUCH            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_GOTOP                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_JASTEC                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_ELO                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_E2I                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_ZYTRONIC                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_ETT_TC45USB              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_NEXIO                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TOUCHSCREEN_USB_EASYTOUCH                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Input device support >> Hardware I/O ports
++
++# Menu: Device Drivers >> Input device support >> Hardware I/O ports >> Gameport support
++CONFIG_GAMEPORT                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_GAMEPORT_NS558                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GAMEPORT_L4                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GAMEPORT_EMU10K1                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GAMEPORT_FM801                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Input device support >> Hardware I/O ports >> Serial I/O support
++CONFIG_SERIO                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SERIO_I8042                              policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIO_SERPORT                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIO_CT82C710                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SERIO_PARKBD                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIO_AMBAKMI                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SERIO_PCIPS2                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIO_LIBPS2                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SERIO_RAW                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIO_XILINX_XPS_PS2                     policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIO_ALTERA_PS2                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIO_PS2MULT                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIO_ARC_PS2                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SERIO_APBPS2                             policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HYPERV_KEYBOARD                          policy<{'amd64': 'm', 'i386': 'm'}>
++
++# Menu: Device Drivers >> LED Support
++CONFIG_NEW_LEDS                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_LEDS_LP55XX_COMMON                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> LED Support >> LED Class Support
++CONFIG_LEDS_CLASS                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LEDS_88PM860X                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_BCM6328                             policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_BCM6358                             policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_LM3530                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_LM3533                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_LM3642                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_NET48XX                             policy<{'i386': 'm'}>
++CONFIG_LEDS_WRAP                                policy<{'i386': 'm'}>
++CONFIG_LEDS_PCA9532                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_PCA9532_GPIO                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LEDS_GPIO                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_LP3944                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_LP5521                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_LP5523                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_LP5562                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_LP8501                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_LP8788                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_LP8860                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_CLEVO_MAIL                          policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_LEDS_PCA955X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_PCA963X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_WM831X_STATUS                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_WM8350                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_DA903X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_DA9052                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_DAC124S085                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_PWM                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_REGULATOR                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_BD2802                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_INTEL_SS4200                        policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_LEDS_LT3593                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_ADP5520                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_DELL_NETBOOKS                       policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_LEDS_MC13783                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_NS2                                 policy<{'armhf': 'm'}>
++CONFIG_LEDS_ASIC3                               policy<{'armhf': 'y'}>
++CONFIG_LEDS_TCA6507                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_TLC591XX                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_MAX8997                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_LM355x                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_OT200                               policy<{'i386': 'm'}>
++CONFIG_LEDS_MENF21BMC                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_BLINKM                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_POWERNV                             policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_SYSCON                              policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> LED Support >> LED Class Support >> LED Flash Class Support
++CONFIG_LEDS_CLASS_FLASH                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_AAT1290                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_LEDS_MAX77693                            policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_KTD2692                             policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> LED Support >> LED Class Support >> LED Trigger support
++CONFIG_LEDS_TRIGGERS                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LEDS_TRIGGER_TIMER                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_TRIGGER_ONESHOT                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_TRIGGER_HEARTBEAT                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_TRIGGER_BACKLIGHT                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_TRIGGER_CPU                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LEDS_TRIGGER_GPIO                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_TRIGGER_DEFAULT_ON                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_TRIGGER_TRANSIENT                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LEDS_TRIGGER_CAMERA                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> MCB support
++CONFIG_MCB                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MCB_PCI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> MIPS Platform Specific Device Drivers
++
++# Menu: Device Drivers >> MMC/SD/SDIO card support
++CONFIG_MMC                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_MMC_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MMC_CLKGATE                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MMC_BLOCK                                policy<{'amd64': 'm', 'arm64': 'y', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_BLOCK_MINORS                         policy<{'amd64': '8', 'arm64': '8', 'armhf': '8', 'i386': '8', 'powerpc': '8', 'ppc64el': '8'}>
++CONFIG_MMC_BLOCK_BOUNCE                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SDIO_UART                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_TEST                                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MMC_ARMMMCI                              policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_MMC_QCOM_DML                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MMC_OMAP                                 policy<{'armhf': 'm'}>
++CONFIG_MMC_OMAP_HS                              policy<{'armhf': 'y'}>
++CONFIG_MMC_WBSD                                 policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_MXC                                  policy<{'armhf-generic': 'm'}>
++CONFIG_MMC_TIFM_SD                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_MVSDIO                               policy<{'armhf': 'm'}>
++CONFIG_MMC_SPI                                  policy<{'amd64': 'm', 'arm64': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_SDRICOH_CS                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_MMC_TMIO                                 policy<{'armhf': 'm'}>
++CONFIG_MMC_SDHI                                 policy<{'armhf': 'm'}>
++CONFIG_MMC_CB710                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_VIA_SDMMC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_SH_MMCIF                             policy<{'armhf': 'm'}>
++CONFIG_MMC_VUB300                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_USHC                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_USDHI6ROL0                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_REALTEK_PCI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_REALTEK_USB                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_TOSHIBA_PCI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_MTK                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_MMC_BLOCK                                note<boot essential on armhf/arm64>
++CONFIG_MMC_TEST                                 flag<TESTING>
++CONFIG_MMC_OMAP_HS                              note<boot essential on arm>
++
++# Menu: Device Drivers >> MMC/SD/SDIO card support >> Samsung S3C SD/MMC transfer code
++
++# Menu: Device Drivers >> MMC/SD/SDIO card support >> Secure Digital Host Controller Interface support
++CONFIG_MMC_SDHCI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_SDHCI_PCI                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_RICOH_MMC                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MMC_SDHCI_ACPI                           policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_MMC_SDHCI_S3C                            policy<{'armhf': 'm'}>
++CONFIG_MMC_SDHCI_S3C_DMA                        policy<{'armhf': 'y'}>
++#
++CONFIG_MMC_SDHCI                                note<installation essential on omap/highbank>
++
++# Menu: Device Drivers >> MMC/SD/SDIO card support >> Secure Digital Host Controller Interface support >> SDHCI platform and OF driver helper
++CONFIG_MMC_SDHCI_PLTFM                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_SDHCI_OF_ARASAN                      policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_SDHCI_OF_AT91                        policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_SDHCI_OF_ESDHC                       policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_SDHCI_OF_HLWD                        policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_SDHCI_ESDHC_IMX                      policy<{'armhf-generic': 'y'}>
++CONFIG_MMC_SDHCI_DOVE                           policy<{'armhf': 'm'}>
++CONFIG_MMC_SDHCI_TEGRA                          policy<{'armhf-generic': 'm'}>
++CONFIG_MMC_SDHCI_PXAV3                          policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MMC_SDHCI_F_SDH30                        policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MMC_SDHCI_IPROC                          policy<{'arm64': 'm'}>
++CONFIG_MMC_SDHCI_MSM                            policy<{'arm64': 'm', 'armhf': 'm'}>
++#
++CONFIG_MMC_SDHCI_PLTFM                          note<boot essential on highbank>
++
++# Menu: Device Drivers >> MMC/SD/SDIO card support >> Synopsys DesignWare Memory Card Interface
++CONFIG_MMC_DW                                   policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MMC_DW_IDMAC                             policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_MMC_DW_PLTFM                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MMC_DW_EXYNOS                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MMC_DW_K3                                policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MMC_DW_PCI                               policy<{'arm64': 'm', 'armhf': 'm'}>
++
++# Menu: Device Drivers >> Macintosh device drivers
++CONFIG_MACINTOSH_DRIVERS                        policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PMAC_SMU                                 policy<{'powerpc-powerpc64-smp': 'y'}>
++CONFIG_PMAC_MEDIABAY                            policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_MAC_EMUMOUSEBTN                          policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_THERM_WINDTUNNEL                         policy<{'powerpc-powerpc-smp': 'm'}>
++CONFIG_THERM_ADT746X                            policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_PMAC_RACKMETER                           policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm'}>
++#
++CONFIG_THERM_ADT746X                            mark<ENFORCED> note<LP:#923094>
++
++# Menu: Device Drivers >> Macintosh device drivers >> Apple Desktop Bus (ADB) support
++CONFIG_ADB                                      policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_ADB_CUDA                                 policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_ADB_MACIO                                policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_INPUT_ADBHID                             policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_ANSLCD                                   policy<{'powerpc-powerpc-smp': 'm'}>
++
++# Menu: Device Drivers >> Macintosh device drivers >> New PowerMac thermal control infrastructure
++CONFIG_WINDFARM                                 policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WINDFARM_PM81                            policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_WINDFARM_PM72                            policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_WINDFARM_RM31                            policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_WINDFARM_PM91                            policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_WINDFARM_PM112                           policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_WINDFARM_PM121                           policy<{'powerpc-powerpc64-smp': 'm'}>
++
++# Menu: Device Drivers >> Macintosh device drivers >> Support for PMU  based PowerMacs
++CONFIG_ADB_PMU                                  policy<{'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_ADB_PMU_LED                              policy<{'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_PMAC_APM_EMU                             policy<{'powerpc-powerpc-smp': 'm'}>
++CONFIG_PMAC_BACKLIGHT                           policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_PMAC_BACKLIGHT_LEGACY                    policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_SENSORS_AMS                              policy<{'powerpc-powerpc-smp': 'm'}>
++CONFIG_SENSORS_AMS_PMU                          policy<{'powerpc-powerpc-smp': 'n'}>
++CONFIG_SENSORS_AMS_I2C                          policy<{'powerpc-powerpc-smp': 'n'}>
++
++# Menu: Device Drivers >> Mailbox Hardware Support
++CONFIG_MAILBOX                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ARM_MHU                                  policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PL320_MBOX                               policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_OMAP2PLUS_MBOX                           policy<{'armhf': 'm'}>
++CONFIG_OMAP_MBOX_KFIFO_SIZE                     policy<{'armhf': '256'}>
++CONFIG_PCC                                      policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_ALTERA_MBOX                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Memory Controller drivers
++CONFIG_MEMORY                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ARM_PL172_MPMC                           policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_TI_EMIF                                  policy<{'armhf': 'm'}>
++CONFIG_OMAP_GPMC_DEBUG                          policy<{'armhf': 'n'}>
++CONFIG_MVEBU_DEVBUS                             policy<{'armhf': 'y'}>
++CONFIG_TEGRA20_MC                               policy<{'armhf-generic': 'y'}>
++CONFIG_FSL_CORENET_CF                           policy<{'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_TEGRA_MC                                 policy<{'armhf-generic': 'y'}>
++CONFIG_TEGRA124_EMC                             policy<{'armhf-generic': 'y'}>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support
++CONFIG_MTD                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MTD_TESTS                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_CMDLINE_PARTS                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_AFS_PARTS                            policy<{'armhf': 'm'}>
++CONFIG_MTD_OF_PARTS                             policy<{'arm64': 'm', 'armhf': 'y', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_AR7_PARTS                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_BLOCK                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_BLOCK_RO                             policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FTL                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFTL                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFTL_RW                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_INFTL                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RFD_FTL                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SSFDC                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SM_FTL                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_OOPS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_SWAP                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_PARTITIONED_MASTER                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_NAND_ECC_SMC                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_MTD                                      note<boot essential on arm>
++CONFIG_MTD_CMDLINE_PARTS                        flag<REVIEW>
++CONFIG_MTD_BLOCK                                note<boot essential on arm>
++CONFIG_MTD_OF_PARTS                             note<boot essential on arm>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> Enable UBI - Unsorted block images
++CONFIG_MTD_UBI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_UBI_WL_THRESHOLD                     policy<{'amd64': '4096', 'arm64': '4096', 'armhf': '4096', 'i386': '4096', 'powerpc': '4096', 'ppc64el': '4096'}>
++CONFIG_MTD_UBI_BEB_LIMIT                        policy<{'amd64': '20', 'arm64': '20', 'armhf': '20', 'i386': '20', 'powerpc': '20', 'ppc64el': '20'}>
++CONFIG_MTD_UBI_FASTMAP                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MTD_UBI_GLUEBI                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_UBI_BLOCK                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> LPDDR & LPDDR2 PCM memory drivers
++CONFIG_MTD_LPDDR                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_QINFO_PROBE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_LPDDR2_NVM                           policy<{'armhf': 'm'}>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> Mapping drivers for chip access
++CONFIG_MTD_PHYSMAP                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_PHYSMAP_COMPAT                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_PHYSMAP_OF                           policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_SCx200_DOCFLASH                      policy<{'i386': 'm'}>
++CONFIG_MTD_AMD76XROM                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MTD_ICHXROM                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MTD_ESB2ROM                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MTD_CK804XROM                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MTD_SCB2_FLASH                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MTD_NETtel                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MTD_L440GX                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MTD_IMPA7                                policy<{'armhf': 'm'}>
++CONFIG_MTD_INTEL_VR_NOR                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_PLATRAM                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> Mapping drivers for chip access >> Maximum mappable memory available for flash IO
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> Mapping drivers for chip access >> Support non-linear mappings of flash chips
++CONFIG_MTD_COMPLEX_MAPPINGS                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MTD_SBC_GXX                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MTD_PCI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_PCMCIA                               policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_MTD_PCMCIA_ANONYMOUS                     policy<{'amd64': 'n', 'i386': 'n', 'powerpc': 'n'}>
++CONFIG_MTD_GPIO_ADDR                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_LATCH_ADDR                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> NAND Device Support
++CONFIG_MTD_NAND                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_NAND_ECC_BCH                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MTD_NAND_DENALI_PCI                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_NAND_DENALI_DT                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_MTD_NAND_GPIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_NAND_OMAP2                           policy<{'armhf': 'y'}>
++CONFIG_MTD_NAND_OMAP_BCH                        policy<{'armhf': 'y'}>
++CONFIG_MTD_NAND_RICOH                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_NAND_DISKONCHIP                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_NAND_DISKONCHIP_PROBE_ADVANCED       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_NAND_DISKONCHIP_BBTWRITE             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_NAND_DOCG4                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_NAND_CAFE                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_NAND_CS553X                          policy<{'i386': 'm'}>
++CONFIG_MTD_NAND_PXA3xx                          policy<{'armhf': 'm'}>
++CONFIG_MTD_NAND_PASEMI                          policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_MTD_NAND_TMIO                            policy<{'armhf': 'm'}>
++CONFIG_MTD_NAND_NANDSIM                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_NAND_GPMI_NAND                       policy<{'armhf-generic': 'm'}>
++CONFIG_MTD_NAND_BRCMNAND                        policy<{'armhf': 'm'}>
++CONFIG_MTD_NAND_PLATFORM                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_NAND_ORION                           policy<{'armhf': 'm'}>
++CONFIG_MTD_NAND_FSL_ELBC                        policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_NAND_FSL_IFC                         policy<{'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_MTD_NAND_FSL_UPM                         policy<{'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_MTD_NAND_MXC                             policy<{'armhf-generic': 'm'}>
++CONFIG_MTD_NAND_SH_FLCTL                        policy<{'armhf': 'm'}>
++CONFIG_MTD_NAND_HISI504                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_MTD_NAND                                 note<boot essential on arm>
++CONFIG_MTD_NAND_OMAP2                           note<boot essential on arm>
++CONFIG_MTD_NAND_OMAP_BCH                        note<boot essential on arm>
++CONFIG_MTD_NAND_DISKONCHIP_BBTWRITE             note<can be enabled at runtime>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> NAND Device Support >> NAND Flash support for Samsung S3C SoCs
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> OneNAND Device Support
++CONFIG_MTD_ONENAND                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_ONENAND_VERIFY_WRITE                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MTD_ONENAND_GENERIC                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_ONENAND_OMAP2                        policy<{'armhf-generic': 'm'}>
++CONFIG_MTD_ONENAND_OTP                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_ONENAND_2X_PROGRAM                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++#
++CONFIG_MTD_ONENAND_VERIFY_WRITE                 note<writes here are not checked in full without>
++CONFIG_MTD_ONENAND_OTP                          flag<REVIEW>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> RAM/ROM/Flash chip drivers
++CONFIG_MTD_CFI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_JEDECPROBE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_CFI_INTELEXT                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_CFI_AMDSTD                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_CFI_STAA                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_RAM                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_ROM                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_ABSENT                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> RAM/ROM/Flash chip drivers >> Flash chip driver advanced configuration options
++CONFIG_MTD_CFI_ADV_OPTIONS                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> RAM/ROM/Flash chip drivers >> Flash chip driver advanced configuration options >> Flash cmd/query data swapping
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> RAM/ROM/Flash chip drivers >> Flash chip driver advanced configuration options >> Specific CFI Flash geometry selection
++CONFIG_MTD_MAP_BANK_WIDTH_1                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MTD_MAP_BANK_WIDTH_2                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MTD_MAP_BANK_WIDTH_4                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MTD_MAP_BANK_WIDTH_8                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_MAP_BANK_WIDTH_16                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_MAP_BANK_WIDTH_32                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_CFI_I1                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MTD_CFI_I2                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MTD_CFI_I4                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_CFI_I8                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> RedBoot partition table parsing
++CONFIG_MTD_REDBOOT_PARTS                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_REDBOOT_DIRECTORY_BLOCK              policy<{'amd64': '-1', 'arm64': '-1', 'armhf': '-1', 'i386': '-1', 'powerpc': '-1', 'ppc64el': '-1'}>
++CONFIG_MTD_REDBOOT_PARTS_UNALLOCATED            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_REDBOOT_PARTS_READONLY               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> SPI-NOR device support
++CONFIG_MTD_SPI_NOR                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_SPI_NOR_USE_4K_SECTORS               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SPI_FSL_QUADSPI                          policy<{'armhf-generic': 'm'}>
++
++# Menu: Device Drivers >> Memory Technology Device (MTD) support >> Self-contained MTD device drivers
++CONFIG_MTD_PMC551                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_PMC551_BUGFIX                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_PMC551_DEBUG                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_DATAFLASH                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_DATAFLASH_WRITE_VERIFY               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MTD_DATAFLASH_OTP                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MTD_M25P80                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_SST25L                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_SLRAM                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_PHRAM                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_MTDRAM                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTDRAM_TOTAL_SIZE                        policy<{'amd64': '4096', 'arm64': '4096', 'armhf': '4096', 'i386': '4096', 'powerpc': '4096', 'ppc64el': '4096'}>
++CONFIG_MTDRAM_ERASE_SIZE                        policy<{'amd64': '128', 'arm64': '128', 'armhf': '128', 'i386': '128', 'powerpc': '128', 'ppc64el': '128'}>
++CONFIG_MTD_BLOCK2MTD                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_POWERNV_FLASH                        policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_DOCG3                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Microsoft Hyper-V guest support
++CONFIG_HYPERV                                   policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_HYPERV_UTILS                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_HYPERV_BALLOON                           policy<{'amd64': 'm', 'i386': 'm'}>
++
++# Menu: Device Drivers >> Misc devices
++CONFIG_AD525X_DPOT                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD525X_DPOT_I2C                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD525X_DPOT_SPI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DUMMY_IRQ                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_IBM_ASM                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_PHANTOM                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_INTEL_MID_PTI                            policy<{'i386': 'm'}>
++CONFIG_SGI_IOC4                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_TIFM_CORE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_TIFM_7XX1                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ICS932S401                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ENCLOSURE_SERVICES                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_CS5535_MFGPT                             policy<{'i386': 'n'}>
++CONFIG_HP_ILO                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_QCOM_COINCELL                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_APDS9802ALS                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISL29003                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ISL29020                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_TSL2550                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_BH1780                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_BH1770                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_APDS990X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HMC6352                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DS1682                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TI_DAC7512                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VMWARE_BALLOON                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ARM_CHARLCD                              policy<{'armhf': 'y'}>
++CONFIG_BMP085_I2C                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BMP085_SPI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PCH_PHUB                                 policy<{'i386': 'm'}>
++CONFIG_USB_SWITCH_FSA9480                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LATTICE_ECP3_CONFIG                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SRAM                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_VEXPRESS_SYSCFG                          policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_CB710_CORE                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_CB710_DEBUG                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SENSORS_LIS3_SPI                         policy<{'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_LIS3_I2C                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ALTERA_STAPL                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INTEL_MEI                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_MEI_ME                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_MEI_TXE                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_VMWARE_VMCI                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_MIC_BUS                            policy<{'amd64': 'm'}>
++CONFIG_ECHO                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_CXL                                      policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_CS5535_MFGPT                             note<should be disabled by default>
++
++# Menu: Device Drivers >> Misc devices >> EEPROM support
++CONFIG_EEPROM_AT24                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EEPROM_AT25                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EEPROM_LEGACY                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EEPROM_MAX6875                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EEPROM_93CX6                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_EEPROM_93XX46                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Misc devices >> GenWQE PCIe Accelerator
++CONFIG_GENWQE                                   policy<{'amd64': 'm', 'arm64': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_GENWQE_PLATFORM_ERROR_RECOVERY           policy<{'amd64': '0', 'arm64': '0', 'powerpc-powerpc64-emb': '0', 'powerpc-powerpc64-smp': '0', 'ppc64el': '0', 's390x': '0'}>
++
++# Menu: Device Drivers >> Misc devices >> SCIF Bus Driver
++CONFIG_SCIF_BUS                                 policy<{'amd64': 'm'}>
++CONFIG_INTEL_MIC_HOST                           policy<{'amd64': 'm'}>
++CONFIG_INTEL_MIC_CARD                           policy<{'amd64': 'm'}>
++CONFIG_SCIF                                     policy<{'amd64': 'm'}>
++
++# Menu: Device Drivers >> Misc devices >> Silicon Labs C2 port support
++CONFIG_C2PORT                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_C2PORT_DURAMAR_2150                      policy<{'amd64': 'm', 'i386': 'm'}>
++
++# Menu: Device Drivers >> Misc devices >> Texas Instruments shared transport line discipline
++CONFIG_TI_ST                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multifunction device drivers
++CONFIG_MFD_CS5535                               policy<{'i386': 'm'}>
++CONFIG_MFD_AS3711                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_AS3722                               policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PMIC_ADP5520                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_AAT2870_CORE                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_ATMEL_HLCDC                          policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_BCM590XX                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_AXP20X                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_CROS_EC                              policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_MFD_CROS_EC_I2C                          policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_MFD_CROS_EC_SPI                          policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_MFD_ASIC3                                policy<{'armhf': 'y'}>
++CONFIG_PMIC_DA903X                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_DA9052_SPI                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_DA9052_I2C                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_DA9055                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_DA9062                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_DA9063                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_DA9150                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_DLN2                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_MC13XXX_SPI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_MC13XXX_I2C                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_HI6421_PMIC                          policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HTC_EGPIO                                policy<{'armhf': 'y'}>
++CONFIG_HTC_PASIC3                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_HTC_I2CPLD                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_INTEL_QUARK_I2C_GPIO                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_LPC_ICH                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_LPC_SCH                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_INTEL_SOC_PMIC                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_INTEL_LPSS_ACPI                      policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MFD_INTEL_LPSS_PCI                       policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MFD_INTEL_MSIC                           policy<{'i386': 'y'}>
++CONFIG_MFD_JANZ_CMODIO                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MFD_KEMPLD                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MFD_88PM800                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_88PM805                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_88PM860X                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_MAX14577                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_MAX77686                             policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_MAX77693                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_MAX77843                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_MAX8907                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_MAX8925                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_MAX8997                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_MAX8998                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_MT6397                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MFD_MENF21BMC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EZX_PCAP                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_VIPERBOARD                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_RETU                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_PCF50633                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PCF50633_ADC                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PCF50633_GPIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UCB1400_CORE                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_PM8921_CORE                          policy<{'armhf': 'm'}>
++CONFIG_MFD_QCOM_RPM                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MFD_SPMI_PMIC                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MFD_RDC321X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MFD_RTSX_PCI                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MFD_RT5033                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_RTSX_USB                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_RC5T583                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_RK808                                policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_RN5T618                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_SEC_CORE                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_SI476X_CORE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_SM501                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MFD_SM501_GPIO                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_SKY81452                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_SMSC                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ABX500_CORE                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_AB3100_CORE                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_AB3100_OTP                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_STMPE                                policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_SYSCON                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_MFD_TI_AM335X_TSCADC                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MFD_LP3943                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_LP8788                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_OMAP_USB_HOST                        policy<{'armhf': 'y'}>
++CONFIG_MFD_PALMAS                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TPS6105X                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TPS65010                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TPS6507X                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_TPS65090                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_TPS65217                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_TPS65218                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_TPS6586X                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_TPS65910                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_TPS65912                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_TPS65912_I2C                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_TPS65912_SPI                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_TPS80031                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TWL4030_CORE                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TWL4030_POWER                            policy<{'armhf': 'y'}>
++CONFIG_MFD_TWL4030_AUDIO                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_TWL6040_CORE                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_WL1273_CORE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_LM3533                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_TIMBERDALE                           policy<{'i386': 'm'}>
++CONFIG_MFD_TC3589X                              policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_T7L66XB                              policy<{'armhf': 'y'}>
++CONFIG_MFD_TC6387XB                             policy<{'armhf': 'y'}>
++CONFIG_MFD_TC6393XB                             policy<{'armhf': 'y'}>
++CONFIG_MFD_VX855                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MFD_ARIZONA_I2C                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_ARIZONA_SPI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_WM5102                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_WM5110                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_WM8997                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_WM8998                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_WM8400                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_WM831X_I2C                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_WM831X_SPI                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_WM8350_I2C                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MFD_WM8994                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MFD_VEXPRESS_SYSREG                      policy<{'arm64': 'y', 'armhf': 'y'}>
++#
++CONFIG_MFD_SM501                                note<boot essential on OMAP4>
++
++# Menu: Device Drivers >> Multifunction device drivers >> Multimedia Capabilities Port drivers
++
++# Menu: Device Drivers >> Multifunction device drivers >> STMicroelectronics STMPE Interface Drivers
++CONFIG_STMPE_I2C                                policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_STMPE_SPI                                policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Multimedia support
++CONFIG_MEDIA_SUPPORT                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MEDIA_ANALOG_TV_SUPPORT                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MEDIA_DIGITAL_TV_SUPPORT                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MEDIA_RADIO_SUPPORT                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MEDIA_SDR_SUPPORT                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MEDIA_RC_SUPPORT                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MEDIA_CONTROLLER                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_V4L2_SUBDEV_API                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_ADV_DEBUG                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_VIDEO_FIXED_MINOR_RANGES                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_V4L2_FLASH_LED_CLASS                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_NET                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DVB_MAX_ADAPTERS                         policy<{'amd64': '8', 'arm64': '8', 'armhf': '8', 'i386': '8', 'powerpc': '8', 'ppc64el': '8'}>
++CONFIG_DVB_DYNAMIC_MINORS                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RC_MAP                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SMS_SDIO_DRV                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_FIREDTV                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CYPRESS_FIRMWARE                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SMS_SIANO_RC                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SMS_SIANO_DEBUGFS                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MEDIA_SUBDRV_AUTOSELECT                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_IR_I2C                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Cameras/video grabbers support
++CONFIG_MEDIA_CAMERA_SUPPORT                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Multimedia support >> Cameras/video grabbers support >> Media test drivers
++CONFIG_V4L_TEST_DRIVERS                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_VIVID                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_VIM2M                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Cameras/video grabbers support >> Memory-to-memory multimedia devices
++CONFIG_V4L_MEM2MEM_DRIVERS                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_CODA                               policy<{'armhf-generic': 'm'}>
++CONFIG_VIDEO_MEM2MEM_DEINTERLACE                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_SAMSUNG_S5P_G2D                    policy<{'armhf': 'm'}>
++CONFIG_VIDEO_SAMSUNG_S5P_JPEG                   policy<{'armhf': 'm'}>
++CONFIG_VIDEO_SAMSUNG_S5P_MFC                    policy<{'armhf': 'm'}>
++CONFIG_VIDEO_SAMSUNG_EXYNOS_GSC                 policy<{'armhf': 'm'}>
++CONFIG_VIDEO_SH_VEU                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_RENESAS_JPU                        policy<{'armhf': 'm'}>
++CONFIG_VIDEO_RENESAS_VSP1                       policy<{'armhf': 'm'}>
++CONFIG_VIDEO_TI_VPE                             policy<{'armhf': 'm'}>
++CONFIG_VIDEO_TI_VPE_DEBUG                       policy<{'armhf': 'n'}>
++
++# Menu: Device Drivers >> Multimedia support >> Cameras/video grabbers support >> V4L platform devices
++CONFIG_V4L_PLATFORM_DRIVERS                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_CAFE_CCIC                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_VIA_CAMERA                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_VIDEO_OMAP2_VOUT                         policy<{'armhf-generic': 'm'}>
++CONFIG_VIDEO_SH_VOU                             policy<{'armhf': 'm'}>
++CONFIG_VIDEO_TIMBERDALE                         policy<{'i386': 'm'}>
++CONFIG_VIDEO_OMAP3                              policy<{'armhf-generic': 'm'}>
++CONFIG_VIDEO_OMAP3_DEBUG                        policy<{'armhf-generic': 'n'}>
++CONFIG_VIDEO_XILINX                             policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_XILINX_TPG                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_XILINX_VTC                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Cameras/video grabbers support >> V4L platform devices >> Samsung S5P/EXYNOS4 SoC series Camera Subsystem driver
++CONFIG_VIDEO_SAMSUNG_EXYNOS4_IS                 policy<{'armhf': 'n'}>
++
++# Menu: Device Drivers >> Multimedia support >> Cameras/video grabbers support >> V4L platform devices >> Samsung TV driver for S5P platform
++CONFIG_VIDEO_SAMSUNG_S5P_TV                     policy<{'armhf': 'y'}>
++CONFIG_VIDEO_SAMSUNG_S5P_HDMI                   policy<{'armhf': 'm'}>
++CONFIG_VIDEO_SAMSUNG_S5P_HDMI_DEBUG             policy<{'armhf': 'n'}>
++CONFIG_VIDEO_SAMSUNG_S5P_HDMIPHY                policy<{'armhf': 'm'}>
++CONFIG_VIDEO_SAMSUNG_S5P_SII9234                policy<{'armhf': 'm'}>
++CONFIG_VIDEO_SAMSUNG_S5P_SDO                    policy<{'armhf': 'm'}>
++CONFIG_VIDEO_SAMSUNG_S5P_MIXER                  policy<{'armhf': 'm'}>
++CONFIG_VIDEO_SAMSUNG_S5P_MIXER_DEBUG            policy<{'armhf': 'n'}>
++
++# Menu: Device Drivers >> Multimedia support >> Cameras/video grabbers support >> V4L platform devices >> SoC camera support
++CONFIG_SOC_CAMERA                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_PLATFORM                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_MX3                                policy<{'armhf-generic': 'm'}>
++CONFIG_VIDEO_RCAR_VIN                           policy<{'armhf': 'm'}>
++CONFIG_VIDEO_SH_MOBILE_CSI2                     policy<{'armhf': 'm'}>
++CONFIG_VIDEO_SH_MOBILE_CEU                      policy<{'armhf': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Customise DVB Frontends
++CONFIG_DVB_STB0899                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_STB6100                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_STV090x                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_STV6110x                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_M88DS3103                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DRXK                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TDA18271C2DD                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_SI2165                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_CX24110                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_CX24123                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_MT312                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_ZL10036                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_ZL10039                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_S5H1420                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_STV0288                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_STB6000                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_STV0299                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_STV6110                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_STV0900                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TDA8083                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TDA10086                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TDA8261                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_VES1X93                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TUNER_ITD1000                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TUNER_CX24113                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TDA826X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TUA6100                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_CX24116                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_CX24117                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_CX24120                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_SI21XX                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TS2020                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DS3000                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_MB86A16                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TDA10071                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_SP8870                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_SP887X                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_CX22700                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_CX22702                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DRXD                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_L64781                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TDA1004X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_NXT6000                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_MT352                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_ZL10353                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DIB3000MB                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DIB3000MC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DIB7000M                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DIB7000P                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TDA10048                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_AF9013                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_EC100                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_STV0367                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_CXD2820R                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_CXD2841ER                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_RTL2830                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_RTL2832                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_RTL2832_SDR                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_SI2168                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_VES1820                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TDA10021                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TDA10023                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_STV0297                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_NXT200X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_OR51211                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_OR51132                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_BCM3510                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_LGDT330X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_LGDT3305                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_LGDT3306A                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_LG2160                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_S5H1409                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_AU8522_DTV                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_AU8522_V4L                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_S5H1411                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_S921                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DIB8000                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_MB86A20S                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TC90522                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_PLL                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TUNER_DIB0070                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TUNER_DIB0090                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DRX39XYJ                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_LNBH25                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_LNBP21                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_LNBP22                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_ISL6405                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_ISL6421                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_ISL6423                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_A8293                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_SP2                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_LGS8GXX                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_ATBM8830                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TDA665x                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_IX2505V                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_M88RS2000                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_AF9033                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_HORUS3A                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_ASCOT2E                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DUMMY_FE                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_DVB_DUMMY_FE                             note<expert use only>
++
++# Menu: Device Drivers >> Multimedia support >> Customize TV tuners
++CONFIG_MEDIA_TUNER_SIMPLE                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_TDA8290                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_TDA827X                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_TDA18271                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_TDA9887                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_TEA5761                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_TEA5767                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_MSI001                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_MT20XX                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_MT2060                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_MT2063                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_MT2266                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_MT2131                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_QT1010                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_XC2028                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_XC5000                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_XC4000                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_MXL5005S                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_MXL5007T                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_MC44S803                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_MAX2165                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_TDA18218                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_FC0011                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_FC0012                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_FC0013                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_TDA18212                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_E4000                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_FC2580                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_M88RS6000T                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_TUA9001                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_SI2157                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_IT913X                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_R820T                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_MXL301RF                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_TUNER_QM1D1C0042                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> DVB platform devices
++CONFIG_DVB_PLATFORM_DRIVERS                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DVB_C8SECTPFE                            policy<{'armhf': 'n'}>
++#
++CONFIG_DVB_C8SECTPFE				flag<REVIEW>
++
++# Menu: Device Drivers >> Multimedia support >> Encoders, decoders, sensors and other helper chips
++CONFIG_VIDEO_TVAUDIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_TDA7432                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_TDA9840                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_TEA6415C                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_TEA6420                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_MSP3400                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CS5345                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CS53L32A                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_UDA1342                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_WM8775                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_WM8739                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_VP27SMPX                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_SONY_BTF_MPX                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_SAA6588                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_ADV7180                            policy<{'i386': 'm'}>
++CONFIG_VIDEO_ADV7604                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_ADV7842                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_BT819                              policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_BT856                              policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_BT866                              policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_KS0127                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_SAA7110                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_SAA711X                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_TVP5150                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_TW2804                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_TW9903                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_TW9906                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_VPX3220                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_SAA717X                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX25840                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_SAA7127                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_SAA7185                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_ADV7170                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_ADV7175                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_ADV7511                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_OV7640                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_OV7670                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_MT9V011                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_UPD64031A                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_UPD64083                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_SAA6752HS                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_M52790                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Media PCI Adapters
++CONFIG_MEDIA_PCI_SUPPORT                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_MEYE                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_VIDEO_SOLO6X10                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_TW68                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_ZORAN                              policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_ZORAN_DC30                         policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_IVTV                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_IVTV_ALSA                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_FB_IVTV                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_HEXIUM_GEMINI                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_HEXIUM_ORION                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_MXB                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_DT3155                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX18                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX18_ALSA                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX23885                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEDIA_ALTERA_CI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX25821                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX25821_ALSA                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_BT848                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_BT8XX                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_SAA7164                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_COBALT                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_AV7110                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_AV7110_OSD                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DVB_B2C2_FLEXCOP_PCI                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_B2C2_FLEXCOP_PCI_DEBUG               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_DVB_PLUTO2                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DM1105                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_PT1                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_PT3                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MANTIS_CORE                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_MANTIS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_HOPPER                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_NGENE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_DDBRIDGE                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_SMIPCIE                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_NETUP_UNIDVB                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Media PCI Adapters >> Conexant 2388x (bt878 successor) support
++CONFIG_VIDEO_CX88                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX88_ALSA                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX88_BLACKBIRD                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX88_DVB                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX88_ENABLE_VP3054                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Multimedia support >> Media PCI Adapters >> Philips SAA7134 support
++CONFIG_VIDEO_SAA7134                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_SAA7134_ALSA                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_SAA7134_RC                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_SAA7134_DVB                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_SAA7134_GO7007                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Media PCI Adapters >> SAA7146 DVB cards (aka Budget, Nova-PCI)
++CONFIG_DVB_BUDGET_CORE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_BUDGET                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_BUDGET_CI                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_BUDGET_AV                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_BUDGET_PATCH                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Media PCI Adapters >> Zoran ZR36060
++CONFIG_VIDEO_ZORAN_ZR36060                      policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_ZORAN_BUZ                          policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_ZORAN_DC10                         policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_ZORAN_LML33                        policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_ZORAN_LML33R10                     policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VIDEO_ZORAN_AVS6EYES                     policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Media USB Adapters
++CONFIG_MEDIA_USB_SUPPORT                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_VIDEO_CLASS                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_VIDEO_CLASS_INPUT_EVDEV              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_PWC                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_PWC_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_PWC_INPUT_EVDEV                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_CPIA2                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_ZR364XX                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STKWEBCAM                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_S2255                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_USBTV                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_PVRUSB2                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_PVRUSB2_SYSFS                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_PVRUSB2_DVB                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_PVRUSB2_DEBUGIFC                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_VIDEO_HDPVR                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_USBVISION                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_STK1160_COMMON                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_STK1160_AC97                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_GO7007                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_GO7007_USB                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_GO7007_LOADER                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_GO7007_USB_S2250_BOARD             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_AU0828                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_AU0828_V4L2                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_AU0828_RC                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_TM6000                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_TM6000_ALSA                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_TM6000_DVB                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TTUSB_BUDGET                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_TTUSB_DEC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SMS_USB_DRV                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_B2C2_FLEXCOP_USB                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_B2C2_FLEXCOP_USB_DEBUG               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_DVB_AS102                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_AIRSPY                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_HACKRF                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MSI2500                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Media USB Adapters >> Conexant cx231xx USB video capture support
++CONFIG_VIDEO_CX231XX                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX231XX_RC                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIDEO_CX231XX_ALSA                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_CX231XX_DVB                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Media USB Adapters >> Empia EM28xx USB devices support
++CONFIG_VIDEO_EM28XX                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_EM28XX_V4L2                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_EM28XX_ALSA                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_EM28XX_DVB                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIDEO_EM28XX_RC                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Media USB Adapters >> GSPCA based webcams
++CONFIG_USB_GSPCA                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_M5602                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STV06XX                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GL860                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_BENQ                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_CONEX                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_CPIA1                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_DTCS033                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_ETOMS                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_FINEPIX                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_JEILINJ                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_JL2005BCD                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_KINECT                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_KONICA                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_MARS                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_MR97310A                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_NW80X                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_OV519                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_OV534                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_OV534_9                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_PAC207                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_PAC7302                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_PAC7311                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SE401                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SN9C2028                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SN9C20X                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SONIXB                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SONIXJ                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SPCA500                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SPCA501                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SPCA505                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SPCA506                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SPCA508                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SPCA561                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SPCA1528                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SQ905                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SQ905C                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SQ930X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_STK014                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_STK1135                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_STV0680                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_SUNPLUS                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_T613                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_TOPRO                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_TOUPTEK                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_TV8532                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_VC032X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_VICAM                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_XIRLINK_CIT                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GSPCA_ZC3XX                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Media USB Adapters >> Support for various USB DVB devices
++CONFIG_DVB_USB                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_DVB_USB_A800                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_DIBUSB_MB                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_DIBUSB_MB_FAULTY                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_DVB_USB_DIBUSB_MC                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_DIB0700                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_UMT_010                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_CXUSB                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_M920X                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_DIGITV                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_VP7045                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_VP702X                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_GP8PSK                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_NOVA_T_USB2                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_TTUSB2                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_DTT200U                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_OPERA1                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_AF9005                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_AF9005_REMOTE                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_PCTV452E                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_DW2102                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_CINERGY_T2                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_DTV5100                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_FRIIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_AZ6027                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_TECHNISAT_USB2                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Media USB Adapters >> Support for various USB DVB devices v2
++CONFIG_DVB_USB_V2                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_AF9015                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_AF9035                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_ANYSEE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_AU6610                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_AZ6007                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_CE6230                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_EC168                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_GL861                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_LME2510                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_MXL111SF                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_RTL28XXU                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_USB_DVBSKY                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Radio Adapters
++CONFIG_RADIO_ADAPTERS                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RADIO_SI470X                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SI470X                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_SI470X                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RADIO_SI476X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MR800                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_DSBR                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RADIO_MAXIRADIO                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RADIO_SHARK                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RADIO_SHARK2                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_KEENE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_RAREMONO                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MA901                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RADIO_TEA5764                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RADIO_SAA7706H                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RADIO_TEF6862                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RADIO_TIMBERDALE                         policy<{'i386': 'm'}>
++CONFIG_RADIO_WL1273                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Radio Adapters >> ISA radio devices
++CONFIG_V4L_RADIO_ISA_DRIVERS                    policy<{'i386': 'y'}>
++CONFIG_RADIO_CADET                              policy<{'i386': 'm'}>
++CONFIG_RADIO_RTRACK                             policy<{'i386': 'm'}>
++CONFIG_RADIO_RTRACK2                            policy<{'i386': 'm'}>
++CONFIG_RADIO_AZTECH                             policy<{'i386': 'm'}>
++CONFIG_RADIO_GEMTEK                             policy<{'i386': 'm'}>
++CONFIG_RADIO_MIROPCM20                          policy<{'i386': 'm'}>
++CONFIG_RADIO_SF16FMI                            policy<{'i386': 'm'}>
++CONFIG_RADIO_SF16FMR2                           policy<{'i386': 'm'}>
++CONFIG_RADIO_TERRATEC                           policy<{'i386': 'm'}>
++CONFIG_RADIO_TRUST                              policy<{'i386': 'm'}>
++CONFIG_RADIO_TYPHOON                            policy<{'i386': 'm'}>
++CONFIG_RADIO_ZOLTRIX                            policy<{'i386': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Radio Adapters >> Silicon Labs Si4713 FM Radio with RDS Transmitter support
++CONFIG_RADIO_SI4713                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SI4713                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PLATFORM_SI4713                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I2C_SI4713                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Radio Adapters >> Texas Instruments WL128x FM driver (ST based)
++CONFIG_RADIO_WL128X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Remote Controller devices
++CONFIG_RC_DEVICES                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RC_ATI_REMOTE                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_ENE                                   policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_IR_HIX5HD2                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_IMON                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_MCEUSB                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_ITE_CIR                               policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_IR_FINTEK                                policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_IR_MESON                                 policy<{'armhf': 'm'}>
++CONFIG_IR_NUVOTON                               policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_IR_REDRAT3                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_STREAMZAP                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_WINBOND_CIR                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_IR_IGORPLUGUSB                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_IGUANA                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_TTUSBIR                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RC_LOOPBACK                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_GPIO_CIR                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Remote Controller devices >> Hardware decoder
++
++# Menu: Device Drivers >> Multimedia support >> Remote controller decoders
++CONFIG_RC_DECODERS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LIRC                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_LIRC_CODEC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_NEC_DECODER                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_RC5_DECODER                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_RC6_DECODER                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_JVC_DECODER                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_SONY_DECODER                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_SANYO_DECODER                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_SHARP_DECODER                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_MCE_KBD_DECODER                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IR_XMP_DECODER                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multimedia support >> Sensors used on soc_camera driver
++CONFIG_SOC_CAMERA_IMX074                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_MT9M001                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_MT9M111                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_MT9T031                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_MT9T112                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_MT9V022                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_OV2640                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_OV5642                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_OV6650                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_OV772X                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_OV9640                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_OV9740                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_RJ54N1                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SOC_CAMERA_TW9910                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Multiple devices driver support (RAID and LVM)
++CONFIG_MD                                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BCACHE                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BCACHE_DEBUG                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_BCACHE_CLOSURES_DEBUG                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DM_DEBUG_BLOCK_STACK_TRACING             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Device Drivers >> Multiple devices driver support (RAID and LVM) >> Device mapper support
++CONFIG_BLK_DEV_DM                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DM_MQ_DEFAULT                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DM_DEBUG                                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'y'}>
++CONFIG_DM_CRYPT                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_SNAPSHOT                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_THIN_PROVISIONING                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_ERA                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_MIRROR                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_LOG_USERSPACE                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_RAID                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_ZERO                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_MULTIPATH                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_MULTIPATH_QL                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_MULTIPATH_ST                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_DELAY                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_UEVENT                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DM_FLAKEY                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_VERITY                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_SWITCH                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_LOG_WRITES                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++#
++CONFIG_BLK_DEV_DM                               mark<ENFORCED> note<LP:#560717>
++
++# Menu: Device Drivers >> Multiple devices driver support (RAID and LVM) >> Device mapper support >> Cache target (EXPERIMENTAL)
++CONFIG_DM_CACHE                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_CACHE_MQ                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_CACHE_SMQ                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DM_CACHE_CLEANER                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Device Drivers >> Multiple devices driver support (RAID and LVM) >> RAID support
++CONFIG_BLK_DEV_MD                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MD_AUTODETECT                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MD_LINEAR                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MD_RAID0                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MD_RAID1                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MD_RAID10                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MD_RAID456                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MD_MULTIPATH                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'y'}>
++CONFIG_MD_FAULTY                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MD_CLUSTER                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Device Drivers >> NVDIMM (Non-Volatile Memory Device) Support
++CONFIG_LIBNVDIMM                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf-generic-lpae': 'y', 'i386': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_BLK_DEV_PMEM                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf-generic-lpae': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-e500mc': 'm', 'ppc64el': 'm'}>
++CONFIG_ND_BLK                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf-generic-lpae': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-e500mc': 'm', 'ppc64el': 'm'}>
++CONFIG_BTT                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf-generic-lpae': 'y', 'i386': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> NVMEM Support
++CONFIG_NVMEM                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_QCOM_QFPROM                              policy<{'arm64': 'm', 'armhf': 'm'}>
++#
++CONFIG_NVMEM					flag<REVIEW> note<Q: is this appropriate for s390x>
++
++# Menu: Device Drivers >> Network device support
++CONFIG_NETDEVICES                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CAIF_TTY                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAIF_SPI_SLAVE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAIF_SPI_SYNC                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CAIF_HSI                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FDDI                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_DEFXX                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DEFXX_MMIO                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SKFP                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HIPPI                                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_NET_SB1000                               policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_MICREL_KS8995MA                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PLIP                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_XEN_NETDEV_FRONTEND                      policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_XEN_NETDEV_BACKEND                       policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_VMXNET3                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_FUJITSU_ES                               policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_HYPERV_NET                               policy<{'amd64': 'm', 'i386': 'm'}>
++#
++CONFIG_HIPPI                                    note<DEPRECATED>
++CONFIG_XEN_NETDEV_FRONTEND                      note<not autoloadable -- XEN paravirt support>
++CONFIG_DEFXX_MMIO                               flag<REVIEW>
++
++# Menu: Device Drivers >> Network device support >> ARCnet support
++CONFIG_ARCNET                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_ARCNET_1201                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ARCNET_1051                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ARCNET_RAW                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ARCNET_CAP                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ARCNET_COM90xx                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ARCNET_COM90xxIO                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ARCNET_RIM_I                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> ARCnet support >> ARCnet COM20020 chipset driver
++CONFIG_ARCNET_COM20020                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ARCNET_COM20020_ISA                      policy<{'i386': 'm'}>
++CONFIG_ARCNET_COM20020_PCI                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ARCNET_COM20020_CS                       policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> ATM drivers
++CONFIG_ATM_DRIVERS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATM_DUMMY                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_TCP                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_LANAI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_ENI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_ENI_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATM_FIRESTREAM                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_ATM_ZATM                                 policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_ATM_ZATM_DEBUG                           policy<{'amd64': 'n', 'i386': 'n', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_ATM_NICSTAR                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_NICSTAR_USE_SUNI                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATM_NICSTAR_USE_IDT77105                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATM_IDT77252                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_IDT77252_DEBUG                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATM_IDT77252_RCV_ALL                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATM_AMBASSADOR                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_ATM_AMBASSADOR_DEBUG                     policy<{'amd64': 'n', 'i386': 'n', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_ATM_HORIZON                              policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_ATM_HORIZON_DEBUG                        policy<{'amd64': 'n', 'i386': 'n', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_ATM_IA                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_IA_DEBUG                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATM_HE                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_HE_USE_SUNI                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATM_SOLOS                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_ATM_NICSTAR_USE_IDT77105                 flag<REVIEW>
++
++# Menu: Device Drivers >> Network device support >> ATM drivers >> FORE Systems 200E-series
++CONFIG_ATM_FORE200E                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_FORE200E_USE_TASKLET                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATM_FORE200E_TX_RETRY                    policy<{'amd64': '16', 'arm64': '16', 'armhf': '16', 'i386': '16', 'powerpc': '16', 'ppc64el': '16'}>
++CONFIG_ATM_FORE200E_DEBUG                       policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++
++# Menu: Device Drivers >> Network device support >> ATM drivers >> Fine-tune burst settings
++CONFIG_ATM_ENI_TUNE_BURST                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> CAIF virtio transport driver
++CONFIG_CAIF_VIRTIO                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VHOST_NET                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_VHOST_SCSI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_VHOST_CROSS_ENDIAN_LEGACY                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Distributed Switch Architecture drivers
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support
++CONFIG_ETHERNET                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_VENDOR_ADAPTEC                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ADAPTEC_STARFIRE                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_AGERE                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ET131X                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_ALTEON                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ACENIC                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ACENIC_OMIT_TIGON_I                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ALTERA_TSE                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_NET_XGENE                                policy<{'arm64': 'm'}>
++CONFIG_NET_VENDOR_ARC                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ARC_EMAC                                 policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_EMAC_ROCKCHIP                            policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_CADENCE                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_MACB                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_BROCADE                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_BNA                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_CALXEDA_XGMAC                        policy<{'armhf': 'm'}>
++CONFIG_NET_VENDOR_CISCO                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ENIC                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CX_ECAT                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_DM9000                                   policy<{'armhf': 'm'}>
++CONFIG_DM9000_FORCE_SIMPLE_PHY_POLL             policy<{'armhf': 'n'}>
++CONFIG_DNET                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_NET_VENDOR_DEC                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_NET_VENDOR_DLINK                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_DL2K                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SUNDANCE                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SUNDANCE_MMIO                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_NET_VENDOR_EMULEX                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_BE2NET                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BE2NET_HWMON                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BE2NET_VXLAN                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_VENDOR_EZCHIP                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_EZCHIP_NPS_MANAGEMENT_ENET               policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_EXAR                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_S2IO                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VXGE                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VXGE_DEBUG_TRACE_ALL                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_NET_VENDOR_FARADAY                       policy<{'armhf': 'y'}>
++CONFIG_FTMAC100                                 policy<{'armhf': 'm'}>
++CONFIG_FTGMAC100                                policy<{'armhf': 'm'}>
++CONFIG_NET_VENDOR_FUJITSU                       policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y'}>
++CONFIG_PCMCIA_FMVJ18X                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_NET_VENDOR_HISILICON                     policy<{'armhf': 'y'}>
++CONFIG_HIX5HD2_GMAC                             policy<{'armhf': 'm'}>
++CONFIG_HIP04_ETH                                policy<{'armhf': 'm'}>
++CONFIG_NET_VENDOR_HP                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_HP100                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IP1000                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_JME                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_NET_VENDOR_MICROCHIP                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ENC28J60                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ENC28J60_WRITEVERIFY                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_NET_VENDOR_MYRI                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_MYRI10GE                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MYRI10GE_DCA                             policy<{'amd64': 'y'}>
++CONFIG_FEALNX                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_NET_VENDOR_NVIDIA                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_FORCEDETH                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_OKI                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_PCH_GBE                                  policy<{'i386': 'm'}>
++CONFIG_ETHOC                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_NET_PACKET_ENGINE                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_HAMACHI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_YELLOWFIN                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_PASEMI                        policy<{'powerpc-powerpc64-smp': 'y'}>
++CONFIG_PASEMI_MAC                               policy<{'powerpc-powerpc64-smp': 'n'}>
++CONFIG_NET_VENDOR_QUALCOMM                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_QCA7000                                  policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_RENESAS                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SH_ETH                                   policy<{'armhf': 'm'}>
++CONFIG_RAVB                                     policy<{'armhf': 'm'}>
++CONFIG_NET_VENDOR_RDC                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_R6040                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_ROCKER                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_NET_VENDOR_SAMSUNG                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SXGBE_ETH                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_SEEQ                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_NET_VENDOR_SILAN                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SC92031                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_SIS                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SIS900                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SIS190                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_STMICRO                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_STMMAC_ETH                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_STMMAC_PCI                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_NET_VENDOR_TEHUTI                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_TEHUTI                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_VIA                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_VIA_RHINE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIA_RHINE_MMIO                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIA_VELOCITY                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_WIZNET                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_WIZNET_W5100                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WIZNET_W5300                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_VENDOR_XIRCOM                        policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y'}>
++CONFIG_PCMCIA_XIRC2PS                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_NET_VENDOR_SYNOPSYS                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SYNOPSYS_DWC_ETH_QOS                     policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> 3Com devices
++CONFIG_NET_VENDOR_3COM                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_EL3                                      policy<{'i386': 'm'}>
++CONFIG_3C515                                    policy<{'i386': 'm'}>
++CONFIG_PCMCIA_3C574                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_PCMCIA_3C589                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_VORTEX                                   policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TYPHOON                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> AMD devices
++CONFIG_NET_VENDOR_AMD                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_AMD8111_ETH                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LANCE                                    policy<{'i386': 'm'}>
++CONFIG_PCNET32                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PCMCIA_NMCLAN                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_NI65                                     policy<{'i386': 'm'}>
++CONFIG_AMD_XGBE                                 policy<{'arm64': 'm'}>
++CONFIG_AMD_XGBE_DCB                             policy<{'arm64': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Apple devices
++CONFIG_NET_VENDOR_APPLE                         policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_MACE                                     policy<{'powerpc-powerpc-smp': 'm'}>
++CONFIG_MACE_AAUI_PORT                           policy<{'powerpc-powerpc-smp': 'n'}>
++CONFIG_BMAC                                     policy<{'powerpc-powerpc-smp': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Atheros devices
++CONFIG_NET_VENDOR_ATHEROS                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ATL2                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATL1                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATL1E                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATL1C                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ALX                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Blackfin on-chip MAC support
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Broadcom devices
++CONFIG_NET_VENDOR_BROADCOM                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_B44                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BCMGENET                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BNX2                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CNIC                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TIGON3                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'y'}>
++CONFIG_BNX2X                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BNX2X_SRIOV                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BNX2X_VXLAN                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SYSTEMPORT                               policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_TIGON3                                   flag<REVIEW>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Cavium ethernet drivers
++CONFIG_NET_VENDOR_CAVIUM                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_THUNDER_NIC_PF                           policy<{'amd64': 'm', 'arm64': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_THUNDER_NIC_VF                           policy<{'amd64': 'm', 'arm64': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_THUNDER_NIC_BGX                          policy<{'amd64': 'm', 'arm64': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_LIQUIDIO                                 policy<{'amd64': 'm', 'arm64': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Chelsio devices
++CONFIG_NET_VENDOR_CHELSIO                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_CHELSIO_T1                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHELSIO_T1_1G                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CHELSIO_T3                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHELSIO_T4                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHELSIO_T4_DCB                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CHELSIO_T4_FCOE                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CHELSIO_T4VF                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Cirrus devices
++CONFIG_NET_VENDOR_CIRRUS                        policy<{'armhf': 'y', 'i386': 'y'}>
++CONFIG_CS89x0                                   policy<{'armhf': 'm', 'i386': 'm'}>
++CONFIG_CS89x0_PLATFORM                          policy<{'armhf': 'y', 'i386': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> DEC - Tulip devices
++CONFIG_NET_TULIP                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DE2104X                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DE2104X_DSL                              policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++CONFIG_DE4X5                                    policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WINBOND_840                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DM9102                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ULI526X                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PCMCIA_XIRCOM                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> DEC - Tulip devices >> DECchip Tulip (dc2114x) PCI support
++CONFIG_TULIP                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TULIP_MWI                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_TULIP_MMIO                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_TULIP_NAPI                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_TULIP_NAPI                               flag<REVIEW>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Freescale devices
++CONFIG_NET_VENDOR_FREESCALE                     policy<{'armhf-generic': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_FEC                                      policy<{'armhf-generic': 'y'}>
++CONFIG_FSL_PQ_MDIO                              policy<{'armhf-generic': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_FSL_XGMAC_MDIO                           policy<{'armhf-generic': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_GIANFAR                                  policy<{'armhf-generic': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Freescale devices >> Freescale Ethernet Driver
++CONFIG_FS_ENET                                  policy<{'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_FS_ENET_HAS_SCC                          policy<{'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_FS_ENET_HAS_FCC                          policy<{'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_FS_ENET_MDIO_FCC                         policy<{'powerpc-powerpc-e500mc': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> IBM devices
++CONFIG_NET_VENDOR_IBM                           policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_IBMVETH                                  policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'y'}>
++CONFIG_EHEA                                     policy<{'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> IBM devices >> IBM EMAC Ethernet support
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Intel (82586/82593/82596) devices
++CONFIG_NET_VENDOR_I825XX                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Intel devices
++CONFIG_NET_VENDOR_INTEL                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_E100                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_E1000                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_E1000E                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IGB                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IGB_HWMON                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IGB_DCA                                  policy<{'amd64': 'y'}>
++CONFIG_IGBVF                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IXGB                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IXGBEVF                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I40EVF                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FM10K                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FM10K_VXLAN                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Intel devices >> Intel(R) 10GbE PCI Express adapters support
++CONFIG_IXGBE                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IXGBE_VXLAN                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IXGBE_HWMON                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IXGBE_DCA                                policy<{'amd64': 'y'}>
++CONFIG_IXGBE_DCB                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Intel devices >> Intel(R) Ethernet Controller XL710 Family support
++CONFIG_I40E                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_I40E_VXLAN                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_I40E_DCB                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_I40E_FCOE                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Marvell devices
++CONFIG_NET_VENDOR_MARVELL                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_MV643XX_ETH                              policy<{'armhf': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_MVMDIO                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MVNETA                                   policy<{'armhf': 'm'}>
++CONFIG_MVPP2                                    policy<{'armhf': 'm'}>
++CONFIG_PXA168_ETH                               policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SKGE                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SKGE_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SKGE_GENESIS                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SKY2                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SKY2_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Mellanox devices
++CONFIG_NET_VENDOR_MELLANOX                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MLX4_EN                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MLX4_EN_DCB                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MLX4_EN_VXLAN                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MLX4_DEBUG                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MLX5_CORE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MLX5_CORE_EN                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MLXSW_CORE                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MLXSW_PCI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Micrel devices
++CONFIG_NET_VENDOR_MICREL                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_KS8842                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KS8851                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KS8851_MLL                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KSZ884X_PCI                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> National Semi-conductor 8390 devices
++CONFIG_NET_VENDOR_8390                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PCMCIA_AXNET                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_AX88796                                  policy<{'armhf': 'm'}>
++CONFIG_AX88796_93CX6                            policy<{'armhf': 'n'}>
++CONFIG_NE2000                                   policy<{'i386': 'm'}>
++CONFIG_NE2K_PCI                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PCMCIA_PCNET                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_ULTRA                                    policy<{'i386': 'm'}>
++CONFIG_WD80x3                                   policy<{'i386': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> National Semi-conductor devices
++CONFIG_NET_VENDOR_NATSEMI                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_NATSEMI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NS83820                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> QLogic devices
++CONFIG_NET_VENDOR_QLOGIC                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_QLA3XXX                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_QLGE                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NETXEN_NIC                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> QLogic devices >> QLOGIC QLCNIC 1/10Gb Converged Ethernet NIC Support
++CONFIG_QLCNIC                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_QLCNIC_SRIOV                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_QLCNIC_DCB                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_QLCNIC_VXLAN                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_QLCNIC_HWMON                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Realtek devices
++CONFIG_NET_VENDOR_REALTEK                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ATP                                      policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_8139CP                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_R8169                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Realtek devices >> RealTek RTL-8129/8130/8139 PCI Fast Ethernet Adapter support
++CONFIG_8139TOO                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_8139TOO_PIO                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_8139TOO_TUNE_TWISTER                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_8139TOO_8129                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_8139_OLD_RX_RESET                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_8139TOO_TUNE_TWISTER                     flag<REVIEW>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> SMC (SMSC)/Western Digital devices
++CONFIG_NET_VENDOR_SMSC                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SMC9194                                  policy<{'i386': 'm'}>
++CONFIG_SMC91X                                   policy<{'arm64': 'y', 'armhf': 'm'}>
++CONFIG_PCMCIA_SMC91C92                          policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_EPIC100                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SMC911X                                  policy<{'armhf': 'm'}>
++CONFIG_SMSC911X                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SMSC9420                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> STMMAC Platform bus support
++CONFIG_STMMAC_PLATFORM                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DWMAC_GENERIC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DWMAC_IPQ806X                            policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DWMAC_LPC18XX                            policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DWMAC_MESON                              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DWMAC_ROCKCHIP                           policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DWMAC_SOCFPGA                            policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DWMAC_STI                                policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DWMAC_SUNXI                              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Solarflare SFC4000/SFC9000/SFC9100-family support
++CONFIG_SFC                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SFC_MTD                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SFC_MCDI_MON                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SFC_SRIOV                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SFC_MCDI_LOGGING                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Sun devices
++CONFIG_NET_VENDOR_SUN                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_HAPPYMEAL                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SUNGEM                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CASSINI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NIU                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Texas Instruments (TI) devices
++CONFIG_NET_VENDOR_TI                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_TI_DAVINCI_EMAC                          policy<{'armhf-generic': 'm'}>
++CONFIG_TI_DAVINCI_MDIO                          policy<{'armhf': 'y'}>
++CONFIG_TI_DAVINCI_CPDMA                         policy<{'armhf': 'y'}>
++CONFIG_TI_CPSW_PHY_SEL                          policy<{'armhf': 'y'}>
++CONFIG_TI_CPSW_ALE                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TI_CPSW                                  policy<{'armhf': 'y'}>
++CONFIG_TI_CPTS                                  policy<{'armhf': 'y'}>
++CONFIG_TLAN                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Toshiba devices
++CONFIG_NET_VENDOR_TOSHIBA                       policy<{'powerpc-powerpc64-smp': 'y'}>
++CONFIG_GELIC_NET                                policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_GELIC_WIRELESS                           policy<{'powerpc-powerpc64-smp': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> WIZnet interface mode
++CONFIG_WIZNET_BUS_DIRECT                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_WIZNET_BUS_INDIRECT                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_WIZNET_BUS_ANY                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Ethernet driver support >> Xilinx devices
++CONFIG_NET_VENDOR_XILINX                        policy<{'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_XILINX_EMACLITE                          policy<{'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_XILINX_LL_TEMAC                          policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> IEEE 802.15.4 drivers
++CONFIG_IEEE802154_DRIVERS                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IEEE802154_FAKELB                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IEEE802154_AT86RF230                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IEEE802154_MRF24J40                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IEEE802154_CC2520                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IEEE802154_ATUSB                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Network core driver support
++CONFIG_NET_CORE                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BONDING                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DUMMY                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_EQUALIZER                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_FC                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IFB                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MACVLAN                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MACVTAP                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IPVLAN                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_VXLAN                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_GENEVE                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETCONSOLE                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETCONSOLE_DYNAMIC                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NTB_NETDEV                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RIONET                                   policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RIONET_TX_SIZE                           policy<{'amd64': '128', 'i386': '128', 'powerpc': '128', 'ppc64el': '128'}>
++CONFIG_RIONET_RX_SIZE                           policy<{'amd64': '128', 'i386': '128', 'powerpc': '128', 'ppc64el': '128'}>
++CONFIG_TUN                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TUN_VNET_CROSS_LE                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_VETH                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_VIRTIO_NET                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NLMON                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_VRF                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++#
++CONFIG_VIRTIO_NET                               note<KVM paravirt support -- not autoloadable> flag<REVIEW>
++
++# Menu: Device Drivers >> Network device support >> Network core driver support >> Ethernet team driver support
++CONFIG_NET_TEAM                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_TEAM_MODE_BROADCAST                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_TEAM_MODE_ROUNDROBIN                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_TEAM_MODE_RANDOM                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_TEAM_MODE_ACTIVEBACKUP               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_TEAM_MODE_LOADBALANCE                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> PHY Device support and infrastructure
++CONFIG_PHYLIB                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_AQUANTIA_PHY                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AT803X_PHY                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AMD_PHY                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MARVELL_PHY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DAVICOM_PHY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_QSEMI_PHY                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LXT_PHY                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CICADA_PHY                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VITESSE_PHY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TERANETICS_PHY                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SMSC_PHY                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BROADCOM_PHY                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BCM7XXX_PHY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BCM87XX_PHY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ICPLUS_PHY                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REALTEK_PHY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NATIONAL_PHY                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_STE10XP                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LSI_ET1011C_PHY                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MICREL_PHY                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DP83848_PHY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DP83867_PHY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MICROCHIP_PHY                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FIXED_PHY                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MDIO_BITBANG                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MDIO_GPIO                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MDIO_OCTEON                              policy<{'amd64': 'm', 'arm64': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_MDIO_BUS_MUX_GPIO                        policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MDIO_BUS_MUX_MMIOREG                     policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MDIO_BCM_UNIMAC                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> PPP (point-to-point protocol) support
++CONFIG_PPP                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_PPP_BSDCOMP                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PPP_DEFLATE                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PPP_FILTER                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PPP_MPPE                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PPP_MULTILINK                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PPPOATM                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PPPOE                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PPTP                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PPPOL2TP                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PPP_ASYNC                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PPP_SYNC_TTY                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> S/390 network device drivers
++CONFIG_LCS                                      policy<{'s390x': 'm'}>
++CONFIG_CTCM                                     policy<{'s390x': 'm'}>
++CONFIG_NETIUCV                                  policy<{'s390x': 'm'}>
++CONFIG_SMSGIUCV                                 policy<{'s390x': 'y'}>
++CONFIG_SMSGIUCV_EVENT                           policy<{'s390x': 'm'}>
++CONFIG_QETH                                     policy<{'s390x': 'm'}>
++CONFIG_QETH_L2                                  policy<{'s390x': 'm'}>
++CONFIG_QETH_L3                                  policy<{'s390x': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> SLIP (serial line) support
++CONFIG_SLIP                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SLIP_COMPRESSED                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SLIP_SMART                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SLIP_MODE_SLIP6                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> USB Network Adapters
++CONFIG_USB_NET_DRIVERS                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_CATC                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_KAWETH                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_PEGASUS                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_RTL8150                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_RTL8152                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_LAN78XX                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_HSO                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_CDC_PHONET                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_IPHETH                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> USB Network Adapters >> Multi-purpose USB Networking Framework
++CONFIG_USB_USBNET                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_AX8817X                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_AX88179_178A                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_CDCETHER                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_CDC_EEM                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_CDC_NCM                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_HUAWEI_CDC_NCM                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_CDC_MBIM                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_DM9601                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_SR9700                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_SR9800                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_SMSC75XX                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_SMSC95XX                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_GL620A                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_NET1080                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_PLUSB                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_MCS7830                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_RNDIS_HOST                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_ZAURUS                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_CX82310_ETH                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_KALMIA                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_QMI_WWAN                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_INT51X1                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SIERRA_NET                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_VL600                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_CH9200                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> USB Network Adapters >> Multi-purpose USB Networking Framework >> Simple USB Network Links (CDC Ethernet subset)
++CONFIG_USB_NET_CDC_SUBSET                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_ALI_M5632                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_AN2720                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_BELKIN                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_ARMLINUX                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_EPSON2888                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_KC2190                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Wan interfaces support
++CONFIG_WAN                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_HOSTESS_SV11                             policy<{'i386': 'm'}>
++CONFIG_COSA                                     policy<{'i386': 'm'}>
++CONFIG_LANMEDIA                                 policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_SEALEVEL_4021                            policy<{'i386': 'm'}>
++CONFIG_DLCI                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DLCI_MAX                                 policy<{'amd64': '8', 'arm64': '8', 'armhf': '8', 'i386': '8', 'powerpc': '8', 'ppc64el': '8'}>
++CONFIG_SDLA                                     policy<{'i386': 'm'}>
++CONFIG_LAPBETHER                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_X25_ASY                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SBNI                                     policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SBNI_MULTILINE                           policy<{'amd64': 'n', 'i386': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Wan interfaces support >> Generic HDLC layer
++CONFIG_HDLC                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HDLC_RAW                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HDLC_RAW_ETH                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HDLC_CISCO                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HDLC_FR                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HDLC_PPP                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HDLC_X25                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PCI200SYN                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WANXL                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PC300TOO                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_N2                                       policy<{'i386': 'm'}>
++CONFIG_C101                                     policy<{'i386': 'm'}>
++CONFIG_FARSYNC                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DSCC4                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DSCC4_PCISYNC                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DSCC4_PCI_RST                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> WiMAX Wireless Broadband devices
++CONFIG_WIMAX_I2400M_USB                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WIMAX_I2400M_DEBUG_LEVEL                 policy<{'amd64': '8', 'arm64': '8', 'armhf': '8', 'i386': '8', 'powerpc': '8', 'ppc64el': '8'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN
++CONFIG_WLAN                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PCMCIA_RAYCS                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_LIBERTAS_THINFIRM                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIBERTAS_THINFIRM_DEBUG                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_LIBERTAS_THINFIRM_USB                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AIRO                                     policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATMEL                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PCI_ATMEL                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PCMCIA_ATMEL                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_AT76C50X_USB                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AIRO_CS                                  policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_PCMCIA_WL3501                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_PRISM54                                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_ZD1201                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET_RNDIS_WLAN                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8180                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8187                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADM8211                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MAC80211_HWSIM                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MWL8K                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_B43LEGACY                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_B43LEGACY_DEBUG                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_BRCMSMAC                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IPW2100                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IPW2100_MONITOR                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IPW2100_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_LIBIPW_DEBUG                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_IWL4965                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IWL3945                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ZD1211RW                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ZD1211RW_DEBUG                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CW1200                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CW1200_WLAN_SDIO                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CW1200_WLAN_SPI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Atheros Wireless Cards
++CONFIG_ATH_CARDS                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATH_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATH5K_PCI                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATH9K_BTCOEX_SUPPORT                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATH9K_HTC                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATH9K_HTC_DEBUGFS                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_AR5523                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WIL6210                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WIL6210_ISR_COR                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_WIL6210_TRACING                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_WCN36XX                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WCN36XX_DEBUGFS                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Atheros Wireless Cards >> Atheros 5xxx wireless cards support
++CONFIG_ATH5K                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATH5K_DEBUG                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATH5K_TRACER                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Atheros Wireless Cards >> Atheros 802.11ac wireless cards support
++CONFIG_ATH10K                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATH10K_PCI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATH10K_DEBUG                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATH10K_DEBUGFS                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATH10K_TRACING                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Atheros Wireless Cards >> Atheros 802.11n wireless cards support
++CONFIG_ATH9K                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATH9K_PCI                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATH9K_AHB                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATH9K_DEBUGFS                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATH9K_STATION_STATISTICS                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATH9K_DYNACK                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATH9K_WOW                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATH9K_RFKILL                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATH9K_CHANNEL_CONTEXT                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATH9K_PCOEM                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Atheros Wireless Cards >> Atheros mobile chipsets support
++CONFIG_ATH6KL                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATH6KL_SDIO                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATH6KL_USB                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATH6KL_DEBUG                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATH6KL_TRACING                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Atheros Wireless Cards >> Linux Community AR9170 802.11n USB support
++CONFIG_CARL9170                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CARL9170_LEDS                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CARL9170_DEBUGFS                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CARL9170_HWRNG                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Broadcom 43xx wireless support (mac80211 stack)
++CONFIG_B43                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_B43_PCMCIA                               policy<{'amd64': 'n', 'i386': 'n', 'powerpc': 'n'}>
++CONFIG_B43_SDIO                                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_B43_PHY_G                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_B43_PHY_N                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_B43_PHY_LP                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_B43_PHY_HT                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_B43_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Broadcom 43xx wireless support (mac80211 stack) >> Supported bus types
++CONFIG_B43_BUSES_BCMA_AND_SSB                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_B43_BUSES_BCMA                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_B43_BUSES_SSB                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Broadcom 43xx-legacy data transfer mode
++CONFIG_B43LEGACY_DMA_AND_PIO_MODE               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_B43LEGACY_DMA_MODE                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_B43LEGACY_PIO_MODE                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Broadcom IEEE802.11n embedded FullMAC WLAN driver
++CONFIG_BRCMFMAC                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BRCMFMAC_SDIO                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BRCMFMAC_USB                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BRCMFMAC_PCIE                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BRCM_TRACING                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BRCMDBG                                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_BRCMDBG                                  flag<DEBUG>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Hermes chipset 802.11b support (Orinoco/Prism2/Symbol)
++CONFIG_HERMES                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HERMES_PRISM                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_HERMES_CACHE_FW_ON_INIT                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_APPLE_AIRPORT                            policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_PLX_HERMES                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TMD_HERMES                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NORTEL_HERMES                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PCMCIA_HERMES                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_PCMCIA_SPECTRUM                          policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_ORINOCO_USB                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> IEEE 802.11 for Host AP (Prism2/2.5/3 and WEP/TKIP/CCMP)
++CONFIG_HOSTAP                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HOSTAP_FIRMWARE                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HOSTAP_FIRMWARE_NVRAM                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_HOSTAP_PLX                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HOSTAP_PCI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HOSTAP_CS                                policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Intel PRO/Wireless 2200BG and 2915ABG Network Connection
++CONFIG_IPW2200                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IPW2200_MONITOR                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IPW2200_RADIOTAP                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IPW2200_PROMISCUOUS                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IPW2200_QOS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IPW2200_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Intel Wireless WiFi Next Gen AGN - Wireless-N/Advanced-N/Ultimate-N (iwlwifi)
++CONFIG_IWLWIFI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IWLDVM                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IWLMVM                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IWLWIFI_BCAST_FILTERING                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_IWLWIFI_UAPSD                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_IWLWIFI_UAPSD                            note<linus d6ca18de129fc4dd4374389561930b32820f35ff>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Intel Wireless WiFi Next Gen AGN - Wireless-N/Advanced-N/Ultimate-N (iwlwifi) >> Debugging Options
++CONFIG_IWLWIFI_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_IWLWIFI_DEBUGFS                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IWLWIFI_DEVICE_TRACING                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Marvell 8xxx Libertas WLAN driver support
++CONFIG_LIBERTAS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIBERTAS_USB                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIBERTAS_CS                              policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_LIBERTAS_SDIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIBERTAS_SPI                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIBERTAS_DEBUG                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_LIBERTAS_MESH                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Marvell WiFi-Ex Driver
++CONFIG_MWIFIEX                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MWIFIEX_SDIO                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MWIFIEX_PCIE                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MWIFIEX_USB                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Mediatek Wireless LAN support
++CONFIG_WL_MEDIATEK                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MT7601U                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Ralink driver support
++CONFIG_RT2X00                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RT2400PCI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RT2500PCI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RT61PCI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RT2500USB                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RT73USB                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RT2X00_LIB_DEBUGFS                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_RT2X00_DEBUG                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Ralink driver support >> Ralink rt27xx/rt28xx/rt30xx (PCI/PCIe/PCMCIA) support
++CONFIG_RT2800PCI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RT2800PCI_RT33XX                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RT2800PCI_RT35XX                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RT2800PCI_RT53XX                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RT2800PCI_RT3290                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Ralink driver support >> Ralink rt27xx/rt28xx/rt30xx (USB) support
++CONFIG_RT2800USB                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RT2800USB_RT33XX                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RT2800USB_RT35XX                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RT2800USB_RT3573                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RT2800USB_RT53XX                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RT2800USB_RT55XX                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RT2800USB_UNKNOWN                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Realtek rtlwifi family of devices
++CONFIG_RTL_CARDS                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8192CE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8192SE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8192DE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8723AE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8723BE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8188EE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8192EE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8821AE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8192CU                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTLWIFI_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Redpine Signals Inc 91x WLAN driver support
++CONFIG_RSI_91X                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RSI_DEBUGFS                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_RSI_SDIO                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RSI_USB                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> Softmac Prism54 support
++CONFIG_P54_COMMON                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_P54_USB                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_P54_PCI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_P54_SPI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_P54_SPI_DEFAULT_EEPROM                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> TI Wireless LAN support
++CONFIG_WL_TI                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_WL12XX                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WL18XX                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WLCORE                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WLCORE_SPI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WLCORE_SDIO                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WILINK_PLATFORM_DATA                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> TI Wireless LAN support >> TI wl1251 driver support
++CONFIG_WL1251                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WL1251_SPI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WL1251_SDIO                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Network device support >> Wireless LAN >> iwl3945 / iwl4965 Debugging Options
++CONFIG_IWLEGACY_DEBUG                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_IWLEGACY_DEBUGFS                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Non-Transparent Bridge support
++CONFIG_NTB                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_NTB_INTEL                                policy<{'amd64': 'm'}>
++CONFIG_NTB_PINGPONG                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NTB_TOOL                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NTB_TRANSPORT                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> PHY Subsystem
++CONFIG_GENERIC_PHY                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_PHY_BERLIN_USB                           policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PHY_BERLIN_SATA                          policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PHY_DM816X_USB                           policy<{'armhf': 'm'}>
++CONFIG_PHY_EXYNOS_MIPI_VIDEO                    policy<{'armhf': 'y'}>
++CONFIG_PHY_PXA_28NM_HSIC                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_PHY_PXA_28NM_USB2                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_PHY_RCAR_GEN2                            policy<{'armhf': 'm'}>
++CONFIG_OMAP_CONTROL_PHY                         policy<{'armhf': 'm'}>
++CONFIG_OMAP_USB2                                policy<{'armhf': 'm'}>
++CONFIG_TI_PIPE3                                 policy<{'armhf': 'm'}>
++CONFIG_TWL4030_USB                              policy<{'armhf': 'm'}>
++CONFIG_PHY_EXYNOS_DP_VIDEO                      policy<{'armhf': 'y'}>
++CONFIG_BCM_KONA_USB2_PHY                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_PHY_EXYNOS5250_SATA                      policy<{'armhf': 'y'}>
++CONFIG_PHY_HIX5HD2_SATA                         policy<{'armhf': 'm'}>
++CONFIG_PHY_SAMSUNG_USB2                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PHY_EXYNOS5_USBDRD                       policy<{'armhf': 'm'}>
++CONFIG_PHY_QCOM_APQ8064_SATA                    policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PHY_QCOM_IPQ806X_SATA                    policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PHY_XGENE                                policy<{'arm64': 'y'}>
++CONFIG_PHY_QCOM_UFS                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PHY_TUSB1210                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> PPS support
++
++# Menu: Device Drivers >> PPS support >> PPS support
++CONFIG_PPS                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'y', 's390x': 'm'}>
++CONFIG_PPS_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_PPS_CLIENT_KTIMER                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_PPS_CLIENT_LDISC                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_PPS_CLIENT_PARPORT                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PPS_CLIENT_GPIO                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++#
++CONFIG_PPS_CLIENT_KTIMER                        flag<TESTING>
++CONFIG_PPS                                      flag<REVIEW>
++
++# Menu: Device Drivers >> PTP clock support
++CONFIG_PTP_1588_CLOCK                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'y', 's390x': 'm'}>
++CONFIG_PTP_1588_CLOCK_GIANFAR                   policy<{'armhf-generic': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_PTP_1588_CLOCK_PCH                       policy<{'i386': 'm'}>
++#
++CONFIG_PTP_1588_CLOCK                           flag<REVIEW>
++
++# Menu: Device Drivers >> Parallel port support
++CONFIG_PARPORT                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_PARPORT_AX88796                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARPORT_1284                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Parallel port support >> PC-style hardware
++CONFIG_PARPORT_PC                               policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARPORT_SERIAL                           policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PARPORT_PC_FIFO                          policy<{'amd64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PARPORT_PC_SUPERIO                       policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_PARPORT_PC_PCMCIA                        policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++
++# Menu: Device Drivers >> Performance monitor support
++CONFIG_ARM_PMU                                  policy<{'armhf': 'y'}>
++
++# Menu: Device Drivers >> Pin controllers
++CONFIG_PINMUX                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y'}>
++CONFIG_PINCONF                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y'}>
++CONFIG_DEBUG_PINCTRL                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n'}>
++CONFIG_PINCTRL_AS3722                           policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_PINCTRL_AMD                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y'}>
++CONFIG_PINCTRL_SINGLE                           policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_PINCTRL_PALMAS                           policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_PINCTRL_IMX50                            policy<{'armhf-generic': 'y'}>
++CONFIG_PINCTRL_IMX51                            policy<{'armhf-generic': 'y'}>
++CONFIG_PINCTRL_IMX6Q                            policy<{'armhf-generic': 'y'}>
++CONFIG_PINCTRL_IMX6SL                           policy<{'armhf-generic': 'y'}>
++CONFIG_PINCTRL_IMX6SX                           policy<{'armhf-generic': 'y'}>
++CONFIG_PINCTRL_IMX6UL                           policy<{'armhf-generic': 'y'}>
++CONFIG_PINCTRL_IMX7D                            policy<{'armhf-generic': 'y'}>
++CONFIG_PINCTRL_VF610                            policy<{'armhf-generic': 'y'}>
++CONFIG_PINCTRL_BAYTRAIL                         policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_PINCTRL_CHERRYVIEW                       policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_PINCTRL_SUNRISEPOINT                     policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_PINCTRL_APQ8064                          policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PINCTRL_APQ8084                          policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PINCTRL_IPQ8064                          policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PINCTRL_MSM8660                          policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PINCTRL_MSM8960                          policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PINCTRL_MSM8X74                          policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PINCTRL_MSM8916                          policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PINCTRL_QDF2XXX                          policy<{'arm64': 'm'}>
++CONFIG_PINCTRL_QCOM_SPMI_PMIC                   policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PINCTRL_QCOM_SSBI_PMIC                   policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_PINCTRL_EXYNOS                           policy<{'armhf': 'y'}>
++CONFIG_PINCTRL_EXYNOS5440                       policy<{'armhf': 'y'}>
++CONFIG_GPIO_SH_PFC                              policy<{'armhf': 'y'}>
++CONFIG_PINCTRL_UNIPHIER_PH1_LD4                 policy<{'armhf': 'm'}>
++CONFIG_PINCTRL_UNIPHIER_PH1_PRO4                policy<{'armhf': 'm'}>
++CONFIG_PINCTRL_UNIPHIER_PH1_SLD8                policy<{'armhf': 'm'}>
++CONFIG_PINCTRL_UNIPHIER_PH1_PRO5                policy<{'armhf': 'm'}>
++CONFIG_PINCTRL_UNIPHIER_PROXSTREAM2             policy<{'armhf': 'm'}>
++CONFIG_PINCTRL_UNIPHIER_PH1_LD6B                policy<{'armhf': 'm'}>
++CONFIG_PINCTRL_MT8135                           policy<{'arm64': 'n', 'armhf': 'y'}>
++CONFIG_PINCTRL_MT8127                           policy<{'arm64': 'n', 'armhf': 'y'}>
++CONFIG_PINCTRL_MT8173                           policy<{'arm64': 'y'}>
++CONFIG_PINCTRL_MT6397                           policy<{'arm64': 'y', 'armhf': 'y'}>
++#
++CONFIG_PINCTRL_MT8135                           flag<REVIEW>
++CONFIG_PINCTRL_MT8127                           flag<REVIEW>
++
++# Menu: Device Drivers >> Pin controllers >> Nomadik pin controller driver
++
++# Menu: Device Drivers >> Pin controllers >> ST-Ericsson ABx500 family Mixed Signal Circuit gpio functions
++
++# Menu: Device Drivers >> Platform support for Chrome hardware
++CONFIG_CHROME_PLATFORMS                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_CHROMEOS_LAPTOP                          policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_CHROMEOS_PSTORE                          policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_CROS_EC_CHARDEV                          policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm'}>
++CONFIG_CROS_EC_LPC                              policy<{'amd64': 'm', 'i386': 'm'}>
++
++# Menu: Device Drivers >> Plug and Play support
++CONFIG_PNP                                      policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_PNP_DEBUG_MESSAGES                       policy<{'amd64': 'n', 'arm64': 'n', 'i386': 'n'}>
++CONFIG_ISAPNP                                   policy<{'i386': 'y'}>
++CONFIG_PNPBIOS                                  policy<{'i386': 'y'}>
++CONFIG_PNPBIOS_PROC_FS                          policy<{'i386': 'y'}>
++
++# Menu: Device Drivers >> Power supply class support
++CONFIG_POWER_SUPPLY                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_POWER_SUPPLY_DEBUG                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_PDA_POWER                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_APM_POWER                                policy<{'powerpc-powerpc-smp': 'm'}>
++CONFIG_GENERIC_ADC_BATTERY                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MAX8925_POWER                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WM831X_BACKUP                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WM831X_POWER                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WM8350_POWER                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TEST_POWER                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_88PM860X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_DS2760                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_DS2780                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_DS2781                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_DS2782                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_PMU                              policy<{'powerpc-powerpc-smp': 'm'}>
++CONFIG_BATTERY_SBS                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_BQ27x00                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_BQ27X00_I2C                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BATTERY_BQ27X00_PLATFORM                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BATTERY_DA9030                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_DA9052                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_DA9150                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AXP288_CHARGER                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AXP288_FUEL_GAUGE                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_MAX17040                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_MAX17042                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_TWL4030_MADC                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_88PM860X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_PCF50633                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_INTEL_MID                        policy<{'i386': 'm'}>
++CONFIG_BATTERY_RX51                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_ISP1704                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_MAX8903                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_TWL4030                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_LP8727                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_LP8788                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_GPIO                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_MANAGER                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CHARGER_MAX14577                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_MAX77693                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_MAX8997                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_MAX8998                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_BQ2415X                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_BQ24190                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_BQ24257                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_BQ24735                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_BQ25890                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_SMB347                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_TPS65090                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_GAUGE_LTC2941                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BATTERY_RT5033                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CHARGER_RT9455                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Power supply class support >> Board level reset or power off
++CONFIG_POWER_RESET                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_POWER_RESET_AS3722                       policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_POWER_RESET_AXXIA                        policy<{'armhf-generic-lpae': 'y'}>
++CONFIG_POWER_RESET_BRCMSTB                      policy<{'armhf': 'n'}>
++CONFIG_POWER_RESET_GPIO                         policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_POWER_RESET_GPIO_RESTART                 policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_POWER_RESET_HISI                         policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_POWER_RESET_IMX                          policy<{'armhf-generic': 'n'}>
++CONFIG_POWER_RESET_MSM                          policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_POWER_RESET_LTC2952                      policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_POWER_RESET_QNAP                         policy<{'armhf': 'n'}>
++CONFIG_POWER_RESET_RESTART                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_POWER_RESET_VERSATILE                    policy<{'armhf': 'y'}>
++CONFIG_POWER_RESET_VEXPRESS                     policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_POWER_RESET_XGENE                        policy<{'arm64': 'n'}>
++CONFIG_POWER_RESET_SYSCON                       policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_POWER_RESET_SYSCON_POWEROFF              policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_POWER_RESET_RMOBILE                      policy<{'armhf': 'm'}>
++CONFIG_POWER_RESET_ZX                           policy<{'armhf': 'm'}>
++
++# Menu: Device Drivers >> Pulse-Width Modulation (PWM) Support
++CONFIG_PWM                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_PWM_ATMEL_HLCDC_PWM                      policy<{'arm64': 'm', 'armhf': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_PWM_CRC                                  policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_PWM_FSL_FTM                              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PWM_IMX                                  policy<{'armhf-generic': 'm'}>
++CONFIG_PWM_LP3943                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PWM_LPSS                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_PWM_LPSS_PCI                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_PWM_LPSS_PLATFORM                        policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_PWM_PCA9685                              policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PWM_RENESAS_TPU                          policy<{'armhf': 'm'}>
++CONFIG_PWM_SAMSUNG                              policy<{'armhf': 'm'}>
++CONFIG_PWM_TEGRA                                policy<{'armhf-generic': 'm'}>
++CONFIG_PWM_TIECAP                               policy<{'armhf-generic': 'm'}>
++CONFIG_PWM_TIEHRPWM                             policy<{'armhf-generic': 'm'}>
++CONFIG_PWM_TWL                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PWM_TWL_LED                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Real Time Clock
++CONFIG_RTC_CLASS                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RTC_HCTOSYS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RTC_HCTOSYS_DEVICE                       policy<{'amd64': '"rtc0"', 'arm64': '"rtc0"', 'armhf': '"rtc0"', 'i386': '"rtc0"', 'powerpc': '"rtc0"', 'ppc64el': '"rtc0"'}>
++CONFIG_RTC_SYSTOHC                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RTC_SYSTOHC_DEVICE                       policy<{'amd64': '"rtc0"', 'arm64': '"rtc0"', 'armhf': '"rtc0"', 'i386': '"rtc0"', 'powerpc': '"rtc0"', 'ppc64el': '"rtc0"'}>
++CONFIG_RTC_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_RTC_INTF_SYSFS                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RTC_INTF_PROC                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RTC_INTF_DEV                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RTC_INTF_DEV_UIE_EMUL                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_RTC_DRV_TEST                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_RTC_DRV_88PM860X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_88PM80X                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_ABB5ZES3                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_ABX80X                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_AS3722                           policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS1307                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS1374                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS1374_WDT                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RTC_DRV_DS1672                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS3232                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_HYM8563                          policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_LP8788                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MAX6900                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MAX8907                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MAX8925                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MAX8998                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MAX8997                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MAX77686                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_RK808                            policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MAX77802                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_RS5C372                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_ISL1208                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_ISL12022                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_ISL12057                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_X1205                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_PALMAS                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_PCF2127                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_PCF8523                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf-generic': 'y', 'armhf-generic-lpae': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_PCF8563                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_PCF85063                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_PCF8583                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_M41T80                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_M41T80_WDT                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RTC_DRV_BQ32K                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_TWL4030                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_TPS6586X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_TPS65910                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_TPS80031                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_RC5T583                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_S35390A                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_FM3130                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_RX8581                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_RX8025                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_EM3027                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_RV3029C2                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_S5M                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_M41T93                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_M41T94                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS1305                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS1343                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS1347                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS1390                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MAX6902                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_R9701                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_RS5C348                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS3234                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_PCF2123                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_RX4581                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MCP795                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_CMOS                             policy<{'amd64': 'y', 'armhf': 'm', 'i386': 'y', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_VRTC                             policy<{'i386': 'm'}>
++CONFIG_RTC_DRV_DS1286                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS1511                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS1553                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS1742                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DS2404                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DA9052                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DA9055                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_DA9063                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_EFI                              policy<{'arm64': 'y'}>
++CONFIG_RTC_DRV_STK17TA8                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_M48T86                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_M48T35                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_M48T59                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MSM6242                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_BQ4802                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_RP5C01                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_V3020                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_WM831X                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_WM8350                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_PCF50633                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_AB3100                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_OPAL                             policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_RTC_DRV_ZYNQMP                           policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_IMXDI                            policy<{'armhf-generic': 'm'}>
++CONFIG_RTC_DRV_OMAP                             policy<{'armhf': 'y'}>
++CONFIG_RTC_DRV_S3C                              policy<{'armhf': 'y'}>
++CONFIG_RTC_DRV_PL030                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_RTC_DRV_PL031                            policy<{'arm64': 'm', 'armhf': 'y'}>
++CONFIG_RTC_DRV_GENERIC                          policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MV                               policy<{'armhf': 'y'}>
++CONFIG_RTC_DRV_ARMADA38X                        policy<{'armhf': 'm'}>
++CONFIG_RTC_DRV_PS3                              policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_RTC_DRV_PCAP                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MC13XXX                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_PM8XXX                           policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_RTC_DRV_TEGRA                            policy<{'armhf-generic': 'm'}>
++CONFIG_RTC_DRV_MXC                              policy<{'armhf-generic': 'm'}>
++CONFIG_RTC_DRV_SNVS                             policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_MT6397                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DRV_XGENE                            policy<{'arm64': 'y'}>
++CONFIG_RTC_DRV_HID_SENSOR_TIME                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_RTC_DRV_TEST                             flag<TESTING>
++CONFIG_RTC_DRV_CMOS                             note<boot essential on i386/amd64>
++CONFIG_RTC_DRV_EFI                              note<LP:#1583738>
++CONFIG_RTC_DRV_TWL4030                          note<boot essential on OMAP3/OMAP4>
++
++# Menu: Device Drivers >> Real Time Clock >> Dallas/Maxim DS1685 Family
++CONFIG_RTC_DRV_DS1685_FAMILY                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTC_DS1685_PROC_REGS                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_RTC_DS1685_SYSFS_REGS                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Real Time Clock >> Dallas/Maxim DS1685 Family >> Subtype
++CONFIG_RTC_DRV_DS1685                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RTC_DRV_DS1689                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_RTC_DRV_DS17285                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_RTC_DRV_DS17485                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_RTC_DRV_DS17885                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Reliability, Availability and Serviceability (RAS) features
++CONFIG_RAS                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_AMD_MCE_INJ                              policy<{'amd64': 'm', 'i386': 'm'}>
++
++# Menu: Device Drivers >> Remoteproc drivers
++CONFIG_OMAP_REMOTEPROC                          policy<{'armhf-generic': 'm'}>
++CONFIG_STE_MODEM_RPROC                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_WKUP_M3_RPROC                            policy<{'armhf-generic': 'm'}>
++
++# Menu: Device Drivers >> SCSI device support
++CONFIG_RAID_ATTRS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support
++CONFIG_SCSI                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SCSI_MQ_DEFAULT                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SCSI_PROC_FS                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_DEV_SD                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CHR_DEV_ST                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CHR_DEV_OSST                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BLK_DEV_SR                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_DEV_SR_VENDOR                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'y'}>
++CONFIG_CHR_DEV_SG                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CHR_DEV_SCH                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_ENCLOSURE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SCSI_CONSTANTS                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SCSI_LOGGING                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SCSI_SCAN_ASYNC                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_SCSI                                     flag<REVIEW>
++CONFIG_CHR_DEV_SG                               note<not autoloadable>
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support >> OSD-Initiator library
++CONFIG_SCSI_OSD_INITIATOR                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_OSD_ULD                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_OSD_DPRINT_SENSE                    policy<{'amd64': '1', 'arm64': '1', 'armhf': '1', 'i386': '1', 'powerpc': '1', 'ppc64el': '1', 's390x': '1'}>
++CONFIG_SCSI_OSD_DEBUG                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support >> PCMCIA SCSI adapter support
++CONFIG_SCSI_LOWLEVEL_PCMCIA                     policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y', 'powerpc': 'y'}>
++CONFIG_PCMCIA_AHA152X                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_PCMCIA_FDOMAIN                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_PCMCIA_NINJA_SCSI                        policy<{'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_PCMCIA_QLOGIC                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_PCMCIA_SYM53C500                         policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support >> SCSI Device Handlers
++CONFIG_SCSI_DH                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SCSI_DH_RDAC                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_DH_HP_SW                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_DH_EMC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_DH_ALUA                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support >> SCSI Transports
++CONFIG_SCSI_SPI_ATTRS                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_FC_ATTRS                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_ISCSI_ATTRS                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_SAS_ATTRS                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_SAS_LIBSAS                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_SAS_ATA                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SCSI_SAS_HOST_SMP                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SCSI_SRP_ATTRS                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm', 'ppc64el': 'y', 's390x': 'm'}>
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support >> SCSI low-level drivers
++CONFIG_SCSI_LOWLEVEL                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ISCSI_TCP                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_ISCSI_BOOT_SYSFS                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_CXGB3_ISCSI                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_CXGB4_ISCSI                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_BNX2_ISCSI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_BNX2X_FCOE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_BE2ISCSI                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_CXLFLASH                                 policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_BLK_DEV_3W_XXXX_RAID                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_HPSA                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_3W_9XXX                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_3W_SAS                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_7000FASST                           policy<{'i386': 'm'}>
++CONFIG_SCSI_ACARD                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_AHA152X                             policy<{'i386': 'm'}>
++CONFIG_SCSI_AHA1542                             policy<{'i386': 'm'}>
++CONFIG_SCSI_AHA1740                             policy<{'i386': 'm'}>
++CONFIG_SCSI_AACRAID                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_AIC94XX                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_AIC94XX_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SCSI_MVSAS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_MVSAS_DEBUG                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SCSI_MVSAS_TASKLET                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SCSI_MVUMI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_DPT_I2O                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm', 's390x': 'n'}>
++CONFIG_SCSI_ADVANSYS                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_IN2000                              policy<{'i386': 'm'}>
++CONFIG_SCSI_ARCMSR                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_ESAS2R                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MEGARAID_NEWGEN                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_MEGARAID_MM                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEGARAID_MAILBOX                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEGARAID_LEGACY                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MEGARAID_SAS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_MPT2SAS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_MPT2SAS_MAX_SGE                     policy<{'amd64': '128', 'arm64': '128', 'armhf': '128', 'i386': '128', 'powerpc': '128', 'ppc64el': '128'}>
++CONFIG_SCSI_MPT2SAS_LOGGING                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SCSI_MPT3SAS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_MPT3SAS_MAX_SGE                     policy<{'amd64': '128', 'arm64': '128', 'armhf': '128', 'i386': '128', 'powerpc': '128', 'ppc64el': '128'}>
++CONFIG_SCSI_MPT3SAS_LOGGING                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SCSI_UFSHCD                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_UFSHCD_PCI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SCSI_UFSHCD_PLATFORM                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SCSI_UFS_QCOM                            policy<{'arm64': 'n', 'armhf': 'n'}>
++CONFIG_SCSI_HPTIOP                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_BUSLOGIC                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_SCSI_FLASHPOINT                          policy<{'amd64': 'y', 'i386': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_VMWARE_PVSCSI                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_XEN_SCSI_FRONTEND                        policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_HYPERV_STORAGE                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_LIBFC                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_LIBFCOE                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_FCOE                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_FCOE_FNIC                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SCSI_SNIC                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_SNIC_DEBUG_FS                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SCSI_DMX3191D                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_DTC3280                             policy<{'i386': 'm'}>
++CONFIG_SCSI_FUTURE_DOMAIN                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_GDTH                                policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SCSI_ISCI                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SCSI_GENERIC_NCR5380                     policy<{'i386': 'm'}>
++CONFIG_SCSI_GENERIC_NCR5380_MMIO                policy<{'i386': 'm'}>
++CONFIG_SCSI_GENERIC_NCR53C400                   policy<{'i386': 'y'}>
++CONFIG_SCSI_IPS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_IBMVSCSI                            policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_SCSI_IBMVFC                              policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_SCSI_IBMVFC_TRACE                        policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_SCSI_INITIO                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_INIA100                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_PPA                                 policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SCSI_IMM                                 policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SCSI_IZIP_EPP16                          policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SCSI_IZIP_SLOW_CTR                       policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SCSI_NCR53C406A                          policy<{'i386': 'm'}>
++CONFIG_SCSI_STEX                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_IPR                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SCSI_IPR_TRACE                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SCSI_IPR_DUMP                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SCSI_PAS16                               policy<{'i386': 'm'}>
++CONFIG_SCSI_QLOGIC_FAS                          policy<{'i386': 'm'}>
++CONFIG_SCSI_QLOGIC_1280                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_QLA_FC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_TCM_QLA2XXX                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SCSI_QLA_ISCSI                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_LPFC                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_LPFC_DEBUG_FS                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SCSI_SIM710                              policy<{'i386': 'm'}>
++CONFIG_SCSI_SYM53C416                           policy<{'i386': 'm'}>
++CONFIG_SCSI_DC395x                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_AM53C974                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_T128                                policy<{'i386': 'm'}>
++CONFIG_SCSI_ULTRASTOR                           policy<{'i386': 'm'}>
++CONFIG_SCSI_NSP32                               policy<{'armhf': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_SCSI_WD719X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_DEBUG                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_MESH                                policy<{'powerpc-powerpc-smp': 'm'}>
++CONFIG_SCSI_MESH_SYNC_RATE                      policy<{'powerpc-powerpc-smp': '5'}>
++CONFIG_SCSI_MESH_RESET_DELAY_MS                 policy<{'powerpc-powerpc-smp': '4000'}>
++CONFIG_SCSI_MAC53C94                            policy<{'powerpc-powerpc-smp': 'm'}>
++CONFIG_ZFCP                                     policy<{'s390x': 'm'}>
++CONFIG_SCSI_PMCRAID                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_PM8001                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_BFA_FC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_VIRTIO                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCSI_CHELSIO_FCOE                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++#
++CONFIG_SCSI_IPR_TRACE                           note<LP:1343109>
++CONFIG_SCSI_IPR_DUMP                            note<LP:1343109>
++CONFIG_SCSI_VIRTIO                              note<tech preview of new feature>
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support >> SCSI low-level drivers >> Adaptec AIC79xx U320 support
++CONFIG_SCSI_AIC79XX                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_AIC79XX_CMDS_PER_DEVICE                  policy<{'amd64': '32', 'arm64': '32', 'armhf': '32', 'i386': '32', 'powerpc': '32', 'ppc64el': '32'}>
++CONFIG_AIC79XX_RESET_DELAY_MS                   policy<{'amd64': '5000', 'arm64': '5000', 'armhf': '5000', 'i386': '5000', 'powerpc': '5000', 'ppc64el': '5000'}>
++CONFIG_AIC79XX_DEBUG_ENABLE                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_AIC79XX_DEBUG_MASK                       policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++CONFIG_AIC79XX_REG_PRETTY_PRINT                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support >> SCSI low-level drivers >> Adaptec AIC7xxx Fast -> U160 support (New Driver)
++CONFIG_SCSI_AIC7XXX                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_AIC7XXX_CMDS_PER_DEVICE                  policy<{'amd64': '8', 'arm64': '8', 'armhf': '8', 'i386': '8', 'powerpc': '8', 'ppc64el': '8'}>
++CONFIG_AIC7XXX_RESET_DELAY_MS                   policy<{'amd64': '5000', 'arm64': '5000', 'armhf': '5000', 'i386': '5000', 'powerpc': '5000', 'ppc64el': '5000'}>
++CONFIG_AIC7XXX_DEBUG_ENABLE                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_AIC7XXX_DEBUG_MASK                       policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++CONFIG_AIC7XXX_REG_PRETTY_PRINT                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support >> SCSI low-level drivers >> EATA ISA/EISA/PCI (DPT and generic EATA/DMA-compliant boards) support
++CONFIG_SCSI_EATA                                policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SCSI_EATA_TAGGED_QUEUE                   policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SCSI_EATA_LINKED_COMMANDS                policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SCSI_EATA_MAX_TAGS                       policy<{'amd64': '16', 'i386': '16', 'powerpc': '16', 'ppc64el': '16'}>
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support >> SCSI low-level drivers >> NCR Quad 720 MCA SCSI support
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support >> SCSI low-level drivers >> SYM53C8XX Version 2 SCSI support
++CONFIG_SCSI_SYM53C8XX_2                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SCSI_SYM53C8XX_DMA_ADDRESSING_MODE       policy<{'amd64': '1', 'arm64': '1', 'armhf': '1', 'i386': '1', 'powerpc': '1', 'ppc64el': '1'}>
++CONFIG_SCSI_SYM53C8XX_DEFAULT_TAGS              policy<{'amd64': '16', 'arm64': '16', 'armhf': '16', 'i386': '16', 'powerpc': '16', 'ppc64el': '16'}>
++CONFIG_SCSI_SYM53C8XX_MAX_TAGS                  policy<{'amd64': '64', 'arm64': '64', 'armhf': '64', 'i386': '64', 'powerpc': '64', 'ppc64el': '64'}>
++CONFIG_SCSI_SYM53C8XX_MMIO                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> SCSI device support >> SCSI device support >> SCSI low-level drivers >> UltraStor 14F/34F support
++CONFIG_SCSI_U14_34F                             policy<{'i386': 'm'}>
++CONFIG_SCSI_U14_34F_TAGGED_QUEUE                policy<{'i386': 'y'}>
++CONFIG_SCSI_U14_34F_LINKED_COMMANDS             policy<{'i386': 'y'}>
++CONFIG_SCSI_U14_34F_MAX_TAGS                    policy<{'i386': '8'}>
++
++# Menu: Device Drivers >> SOC (System On Chip) specific Drivers
++CONFIG_MTK_INFRACFG                             policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_MTK_PMIC_WRAP                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MTK_SCPSYS                               policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_QCOM_GSBI                                policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_QCOM_PM                                  policy<{'armhf': 'y'}>
++CONFIG_QCOM_SMD                                 policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_QCOM_SMD_RPM                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_QCOM_SMEM                                policy<{'arm64': 'm', 'armhf': 'm'}>
++
++# Menu: Device Drivers >> SOC (System On Chip) specific Drivers >> TI SOC drivers support
++CONFIG_SOC_TI                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++#
++CONFIG_SOC_TI                                   flag<REVIEW>
++
++# Menu: Device Drivers >> SPI support
++CONFIG_SPI                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SPI_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SPI_ALTERA                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_BITBANG                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_BUTTERFLY                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_CADENCE                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_DLN2                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_GPIO                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_IMX                                  policy<{'armhf-generic': 'm'}>
++CONFIG_SPI_LM70_LLP                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_FSL_SPI                              policy<{'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SPI_FSL_DSPI                             policy<{'armhf-generic': 'm'}>
++CONFIG_SPI_FSL_ESPI                             policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_SPI_MESON_SPIFC                          policy<{'armhf': 'm'}>
++CONFIG_SPI_MT65XX                               policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SPI_OC_TINY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_OMAP24XX                             policy<{'armhf': 'y'}>
++CONFIG_SPI_TI_QSPI                              policy<{'armhf': 'm'}>
++CONFIG_SPI_ORION                                policy<{'armhf': 'm'}>
++CONFIG_SPI_PL022                                policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SPI_PXA2XX                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_ROCKCHIP                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SPI_RSPI                                 policy<{'armhf': 'm'}>
++CONFIG_SPI_QUP                                  policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SPI_S3C64XX                              policy<{'armhf': 'm'}>
++CONFIG_SPI_SC18IS602                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_SH_MSIOF                             policy<{'armhf': 'm'}>
++CONFIG_SPI_SH_HSPI                              policy<{'armhf': 'm'}>
++CONFIG_SPI_TEGRA114                             policy<{'armhf-generic': 'm'}>
++CONFIG_SPI_TEGRA20_SFLASH                       policy<{'armhf-generic': 'm'}>
++CONFIG_SPI_TEGRA20_SLINK                        policy<{'armhf-generic': 'm'}>
++CONFIG_SPI_TOPCLIFF_PCH                         policy<{'i386': 'm'}>
++CONFIG_SPI_XCOMM                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_XILINX                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SPI_ZYNQMP_GQSPI                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_DESIGNWARE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_DW_PCI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_DW_MID_DMA                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SPI_DW_MMIO                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_SPIDEV                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPI_TLE62X0                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> SPMI support
++CONFIG_SPMI                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SPMI_MSM_PMIC_ARB                        policy<{'arm64': 'm', 'armhf': 'm'}>
++
++# Menu: Device Drivers >> Serial ATA and Parallel ATA drivers (libata)
++CONFIG_ATA                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATA_VERBOSE_ERROR                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATA_ACPI                                 policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_SATA_ZPODD                               policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_SATA_PMP                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SATA_AHCI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_AHCI_PLATFORM                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AHCI_IMX                                 policy<{'armhf-generic': 'y'}>
++CONFIG_AHCI_CEVA                                policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AHCI_MVEBU                               policy<{'armhf': 'm'}>
++CONFIG_AHCI_TEGRA                               policy<{'armhf-generic': 'm'}>
++CONFIG_AHCI_XGENE                               policy<{'arm64': 'm'}>
++CONFIG_SATA_FSL                                 policy<{'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_SATA_INIC162X                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_ACARD_AHCI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_SIL24                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_SATA_AHCI_PLATFORM                       note<boot essential on highbank>
++
++# Menu: Device Drivers >> Serial ATA and Parallel ATA drivers (libata) >> ATA SFF support (for legacy IDE and PATA)
++CONFIG_ATA_SFF                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PDC_ADMA                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_QSTOR                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_SX4                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_CMD640_PCI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_ISAPNP                              policy<{'i386': 'm'}>
++CONFIG_PATA_MPIIX                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_NS87410                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_OPTI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_PCMCIA                              policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_PATA_PLATFORM                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_OF_PLATFORM                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_QDI                                 policy<{'i386': 'm'}>
++CONFIG_PATA_RZ1000                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_WINBOND_VLB                         policy<{'i386': 'm'}>
++CONFIG_PATA_LEGACY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Serial ATA and Parallel ATA drivers (libata) >> ATA SFF support (for legacy IDE and PATA) >> ATA BMDMA support
++CONFIG_ATA_BMDMA                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ATA_PIIX                                 policy<{'amd64': 'y', 'arm64': 'm', 'armhf': 'm', 'i386': 'y', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_HIGHBANK                            policy<{'armhf': 'y'}>
++CONFIG_SATA_MV                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_NV                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_PROMISE                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_RCAR                                policy<{'armhf': 'm'}>
++CONFIG_SATA_SIL                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_SIS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_SVW                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'y', 'ppc64el': 'm'}>
++CONFIG_SATA_ULI                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_VIA                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SATA_VITESSE                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_ALI                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_AMD                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_ARTOP                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_ATIIXP                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_ATP867X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_CMD64X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_CS5520                              policy<{'i386': 'm'}>
++CONFIG_PATA_CS5530                              policy<{'i386': 'm'}>
++CONFIG_PATA_CS5535                              policy<{'i386': 'm'}>
++CONFIG_PATA_CS5536                              policy<{'i386': 'm'}>
++CONFIG_PATA_CYPRESS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_EFAR                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_HPT366                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_HPT37X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_HPT3X2N                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_HPT3X3                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_HPT3X3_DMA                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_PATA_IMX                                 policy<{'armhf-generic': 'm'}>
++CONFIG_PATA_IT8213                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_IT821X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_JMICRON                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_MACIO                               policy<{'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_PATA_MARVELL                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_NETCELL                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_NINJA32                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_NS87415                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_OLDPIIX                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_OPTIDMA                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_PDC2027X                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_PDC_OLD                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_RADISYS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_RDC                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_SC1200                              policy<{'i386': 'm'}>
++CONFIG_PATA_SCH                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_SERVERWORKS                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_SIL680                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_SIS                                 policy<{'amd64': 'y', 'arm64': 'm', 'armhf': 'm', 'i386': 'y', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_TOSHIBA                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_TRIFLEX                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_VIA                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_WINBOND                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PATA_ACPI                                policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_ATA_GENERIC                              policy<{'amd64': 'y', 'arm64': 'm', 'armhf': 'm', 'i386': 'y', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_SATA_HIGHBANK                            mark<ENFORCED> note<LP:1703430>
++CONFIG_PATA_HPT3X3_DMA                          note<DMA mode is documented problematic>
++
++# Menu: Device Drivers >> Sonics Silicon Backplane
++CONFIG_SSB_PCIHOST                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SSB_PCMCIAHOST                           policy<{'amd64': 'n', 'i386': 'n', 'powerpc': 'n'}>
++CONFIG_SSB_SDIOHOST                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SSB_DRIVER_PCICORE                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Sonics Silicon Backplane >> Sonics Silicon Backplane support
++CONFIG_SSB                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SSB_SILENT                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SSB_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SSB_DRIVER_GPIO                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Sony MemoryStick card support
++CONFIG_MEMSTICK                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MEMSTICK_DEBUG                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MEMSTICK_UNSAFE_RESUME                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MSPRO_BLOCK                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MS_BLOCK                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEMSTICK_TIFM_MS                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEMSTICK_JMICRON_38X                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEMSTICK_R592                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEMSTICK_REALTEK_PCI                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MEMSTICK_REALTEK_USB                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Sound card support
++CONFIG_SOUND                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SOUND_OSS_CORE_PRECLAIM                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_SOUND                                    note<not autoloadable on omap>
++CONFIG_SOUND_OSS_CORE_PRECLAIM                  mark<ENFORCED> note<LP#1105230 LP#1385510>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture
++CONFIG_SND                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SEQUENCER                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SEQ_DUMMY                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_MIXER_OSS                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_PCM_OSS                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SND_SEQUENCER_OSS                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SND_HRTIMER                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SEQ_HRTIMER_DEFAULT                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_DYNAMIC_MINORS                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_MAX_CARDS                            policy<{'amd64': '32', 'arm64': '32', 'armhf': '32', 'i386': '32', 'powerpc': '32', 'ppc64el': '32'}>
++CONFIG_SND_SUPPORT_OLD_API                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_PROC_FS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_VERBOSE_PROCFS                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_VERBOSE_PRINTK                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SND_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SND_HDA_PREALLOC_SIZE                    policy<{'amd64': '64', 'arm64': '64', 'armhf': '64', 'i386': '64', 'powerpc': '64', 'ppc64el': '64'}>
++#
++CONFIG_SND                                      note<not autoloadable on omap>
++CONFIG_SND_PCM_OSS                              note<deprecated in favour of pulseaudio emulation>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support
++CONFIG_SND_SOC                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_DESIGNWARE_I2S                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_SND_KIRKWOOD_SOC                         policy<{'armhf': 'm'}>
++CONFIG_SND_KIRKWOOD_SOC_ARMADA370_DB            policy<{'armhf': 'm'}>
++CONFIG_SND_MFLD_MACHINE                         policy<{'i386': 'm'}>
++CONFIG_SND_SOC_INTEL_HASWELL_MACH               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SND_SOC_INTEL_BYT_RT5640_MACH            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SND_SOC_INTEL_BYT_MAX98090_MACH          policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SND_SOC_INTEL_BROADWELL_MACH             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SND_SOC_INTEL_BYTCR_RT5640_MACH          policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SND_SOC_INTEL_CHT_BSW_RT5672_MACH        policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SND_SOC_INTEL_CHT_BSW_RT5645_MACH        policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SND_SOC_INTEL_CHT_BSW_MAX98090_TI_MACH   policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SND_SOC_MEDIATEK                         policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SND_SOC_MT8173_MAX98090                  policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SND_SOC_MT8173_RT5650_RT5676             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SND_SOC_QCOM                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SND_SOC_STORM                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SND_SOC_APQ8016_SBC                      policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_SND_SOC_XTFPGA_I2S                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ZX296702_SPDIF                           policy<{'armhf': 'm'}>
++CONFIG_ZX296702_I2S                             policy<{'armhf': 'm'}>
++CONFIG_SND_SIMPLE_CARD                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_SND_SOC                                  note<not autoloadable on omap>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> ASoC support for Rockchip
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> ASoC support for Samsung
++CONFIG_SND_SOC_SAMSUNG                          policy<{'armhf': 'm'}>
++CONFIG_SND_SOC_SAMSUNG_SMDK_WM8994              policy<{'armhf': 'm'}>
++CONFIG_SND_SOC_SAMSUNG_SMDK_SPDIF               policy<{'armhf': 'm'}>
++CONFIG_SND_SOC_SMDK_WM8994_PCM                  policy<{'armhf': 'm'}>
++CONFIG_SND_SOC_SNOW                             policy<{'armhf': 'm'}>
++CONFIG_SND_SOC_ODROIDX2                         policy<{'armhf': 'm'}>
++CONFIG_SND_SOC_ARNDALE_RT5631_ALC5631           policy<{'armhf': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> CODEC drivers
++CONFIG_SND_SOC_AC97_CODEC                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_ADAU1701                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_AK4104                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_AK4554                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_AK4642                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_AK5386                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_ALC5623                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_CS35L32                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_CS42L51_I2C                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_CS42L52                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_CS42L56                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_CS42L73                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_CS4265                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_CS4270                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_CS4271_I2C                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_CS4271_SPI                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_CS42XX8_I2C                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_CS4349                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_HDMI_CODEC                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_ES8328                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_GTM601                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_PCM1681                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_PCM1792A                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_PCM512x_I2C                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_PCM512x_SPI                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_RT5631                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_SGTL5000                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf-generic': 'y', 'armhf-generic-lpae': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_SIRF_AUDIO_CODEC                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_SPDIF                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_SSM2602_SPI                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_SSM2602_I2C                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_SSM4567                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_STA32X                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_STA350                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_STI_SAS                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_TAS2552                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_TAS5086                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_TAS571X                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_TFA9879                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_TLV320AIC23_I2C                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_TLV320AIC23_SPI                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_TLV320AIC31XX                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_TLV320AIC3X                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_TS3A227E                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8510                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8523                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8580                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8711                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8728                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8731                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8737                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8741                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8750                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8753                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8770                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8776                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8804_I2C                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8804_SPI                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8903                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8962                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_WM8978                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_TPA6130A2                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_SND_SOC_HDMI_CODEC                       flag<REVIEW>
++CONFIG_SND_SOC_SGTL5000                         flag<REVIEW>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC AC97 Audio for the ADI BF5xx chip
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio for Freescale CPUs
++CONFIG_SND_SOC_FSL_ASRC                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_FSL_SAI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_FSL_SSI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf-generic': 'y', 'armhf-generic-lpae': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_FSL_SPDIF                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_FSL_ESAI                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SOC_IMX_AUDMUX                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf-generic': 'y', 'armhf-generic-lpae': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_SND_SOC_FSL_SSI                          flag<REVIEW>
++CONFIG_SND_SOC_IMX_AUDMUX                       flag<REVIEW>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio for Freescale CPUs >> SoC Audio for Freescale PowerPC CPUs
++CONFIG_SND_POWERPC_SOC                          policy<{'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio for Freescale CPUs >> SoC Audio for Freescale i.MX CPUs
++CONFIG_SND_IMX_SOC                              policy<{'armhf-generic': 'y'}>
++CONFIG_SND_SOC_EUKREA_TLV320                    policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_IMX_WM8962                       policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_IMX_ES8328                       policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_IMX_SGTL5000                     policy<{'armhf-generic': 'y'}>
++CONFIG_SND_SOC_IMX_SPDIF                        policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_IMX_MC13783                      policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_FSL_ASOC_CARD                    policy<{'armhf-generic': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio for Freescale MXS CPUs
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio for Texas Instruments chips using eDMA
++CONFIG_SND_EDMA_SOC                             policy<{'armhf-generic': 'm'}>
++CONFIG_SND_DAVINCI_SOC_MCASP                    policy<{'armhf': 'm'}>
++CONFIG_SND_AM33XX_SOC_EVM                       policy<{'armhf-generic': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio for Texas Instruments chips using eDMA >> DM365 codec select
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio for the Atmel System-on-Chip
++CONFIG_SND_ATMEL_SOC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio for the Intel PXA2xx chip
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio for the Tegra System-on-Chip
++CONFIG_SND_SOC_TEGRA                            policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_TEGRA_RT5640                     policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_TEGRA_WM8753                     policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_TEGRA_WM8903                     policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_TEGRA_WM9712                     policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_TEGRA_TRIMSLICE                  policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_TEGRA_ALC5632                    policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_TEGRA_MAX98090                   policy<{'armhf-generic': 'm'}>
++CONFIG_SND_SOC_TEGRA_RT5677                     policy<{'armhf-generic': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio for the Texas Instruments OMAP chips
++CONFIG_SND_OMAP_SOC                             policy<{'armhf': 'y'}>
++CONFIG_SND_OMAP_SOC_HDMI_AUDIO                  policy<{'armhf': 'm'}>
++CONFIG_SND_OMAP_SOC_RX51                        policy<{'armhf': 'm'}>
++CONFIG_SND_OMAP_SOC_OMAP_TWL4030                policy<{'armhf': 'y'}>
++CONFIG_SND_OMAP_SOC_OMAP_ABE_TWL6040            policy<{'armhf-generic': 'm'}>
++CONFIG_SND_OMAP_SOC_OMAP3_PANDORA               policy<{'armhf-generic': 'm'}>
++#
++CONFIG_SND_OMAP_SOC                             note<required for omap3 sound>
++CONFIG_SND_OMAP_SOC_OMAP_TWL4030                note<not autoloadable on omap>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio support for SuperH
++CONFIG_SND_SOC_SH4_FSI                          policy<{'armhf': 'm'}>
++CONFIG_SND_SOC_RCAR                             policy<{'armhf': 'm'}>
++CONFIG_SND_SOC_RSRC_CARD                        policy<{'armhf': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio support for Ux500 platform
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC Audio support for the Cirrus Logic EP93xx series
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support >> SoC I2S Audio for the ADI Blackfin chip
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ARM sound devices
++CONFIG_SND_ARM                                  policy<{'armhf': 'y'}>
++CONFIG_SND_ARMAACI                              policy<{'armhf': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> Apple Onboard Audio driver
++CONFIG_SND_AOA                                  policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_SND_AOA_FABRIC_LAYOUT                    policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_SND_AOA_ONYX                             policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_SND_AOA_TAS                              policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_SND_AOA_TOONIE                           policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_SND_AOA_SOUNDBUS                         policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_SND_AOA_SOUNDBUS_I2S                     policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> Atmel devices (AVR32 and AT91)
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> FireWire sound devices
++CONFIG_SND_FIREWIRE                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_DICE                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_OXFW                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ISIGHT                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SCS1X                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_FIREWORKS                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_BEBOB                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> GSC sound devices
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> Generic sound devices
++CONFIG_SND_DRIVERS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_PCSP                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SND_DUMMY                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ALOOP                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_VIRMIDI                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_MTPAV                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_MTS64                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SERIAL_U16550                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_MPU401                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_PORTMAN2X4                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_AC97_POWER_SAVE                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_AC97_POWER_SAVE_DEFAULT              policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> HD-Audio
++CONFIG_SND_HDA_INTEL                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_TEGRA                            policy<{'armhf-generic': 'm'}>
++CONFIG_SND_HDA_HWDEP                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_HDA_RECONFIG                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_HDA_INPUT_BEEP                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_HDA_INPUT_BEEP_MODE                  policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++CONFIG_SND_HDA_PATCH_LOADER                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_HDA_CODEC_REALTEK                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_CODEC_ANALOG                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_CODEC_SIGMATEL                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_CODEC_VIA                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_CODEC_HDMI                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_CODEC_CIRRUS                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_CODEC_CONEXANT                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_CODEC_CA0110                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_CODEC_CA0132                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_CODEC_CA0132_DSP                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_HDA_CODEC_CMEDIA                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_CODEC_SI3054                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_GENERIC                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDA_POWER_SAVE_DEFAULT               policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++#
++CONFIG_SND_HDA_RECONFIG                         note<allows fixes to be tested live>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ISA sound devices
++CONFIG_SND_ISA                                  policy<{'i386': 'y'}>
++CONFIG_SND_ADLIB                                policy<{'i386': 'm'}>
++CONFIG_SND_AD1816A                              policy<{'i386': 'm'}>
++CONFIG_SND_AD1848                               policy<{'i386': 'm'}>
++CONFIG_SND_ALS100                               policy<{'i386': 'm'}>
++CONFIG_SND_AZT1605                              policy<{'i386': 'm'}>
++CONFIG_SND_AZT2316                              policy<{'i386': 'm'}>
++CONFIG_SND_AZT2320                              policy<{'i386': 'm'}>
++CONFIG_SND_CMI8328                              policy<{'i386': 'm'}>
++CONFIG_SND_CMI8330                              policy<{'i386': 'm'}>
++CONFIG_SND_CS4231                               policy<{'i386': 'm'}>
++CONFIG_SND_CS4236                               policy<{'i386': 'm'}>
++CONFIG_SND_ES1688                               policy<{'i386': 'm'}>
++CONFIG_SND_ES18XX                               policy<{'i386': 'm'}>
++CONFIG_SND_SC6000                               policy<{'i386': 'm'}>
++CONFIG_SND_GUSCLASSIC                           policy<{'i386': 'm'}>
++CONFIG_SND_GUSEXTREME                           policy<{'i386': 'm'}>
++CONFIG_SND_GUSMAX                               policy<{'i386': 'm'}>
++CONFIG_SND_INTERWAVE                            policy<{'i386': 'm'}>
++CONFIG_SND_INTERWAVE_STB                        policy<{'i386': 'm'}>
++CONFIG_SND_JAZZ16                               policy<{'i386': 'm'}>
++CONFIG_SND_OPL3SA2                              policy<{'i386': 'm'}>
++CONFIG_SND_OPTI92X_AD1848                       policy<{'i386': 'm'}>
++CONFIG_SND_OPTI92X_CS4231                       policy<{'i386': 'm'}>
++CONFIG_SND_OPTI93X                              policy<{'i386': 'm'}>
++CONFIG_SND_MIRO                                 policy<{'i386': 'm'}>
++CONFIG_SND_SB8                                  policy<{'i386': 'm'}>
++CONFIG_SND_SB16                                 policy<{'i386': 'm'}>
++CONFIG_SND_SBAWE                                policy<{'i386': 'm'}>
++CONFIG_SND_SB16_CSP                             policy<{'i386': 'y'}>
++CONFIG_SND_SSCAPE                               policy<{'i386': 'm'}>
++CONFIG_SND_WAVEFRONT                            policy<{'i386': 'm'}>
++CONFIG_SND_MSND_PINNACLE                        policy<{'i386': 'm'}>
++CONFIG_SND_MSND_CLASSIC                         policy<{'i386': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> MIPS sound devices
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> PCI sound devices
++CONFIG_SND_PCI                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_AD1889                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ALS300                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ALS4000                              policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ALI5451                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ASIHPI                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SND_ATIIXP                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ATIIXP_MODEM                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_AU8810                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_AU8820                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_AU8830                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_AW2                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_AZT3328                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_BT87X                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_BT87X_OVERCLOCK                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SND_CA0106                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_CMIPCI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_OXYGEN                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_CS4281                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_CS46XX                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_CS46XX_NEW_DSP                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_CS5530                               policy<{'i386': 'm'}>
++CONFIG_SND_CS5535AUDIO                          policy<{'i386': 'm'}>
++CONFIG_SND_CTXFI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_DARLA20                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_GINA20                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_LAYLA20                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_DARLA24                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_GINA24                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_LAYLA24                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_MONA                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_MIA                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ECHO3G                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_INDIGO                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_INDIGOIO                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_INDIGODJ                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_INDIGOIOX                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_INDIGODJX                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_EMU10K1                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_EMU10K1X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ENS1370                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ENS1371                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ES1938                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ES1968                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ES1968_INPUT                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_ES1968_RADIO                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_FM801                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_FM801_TEA575X_BOOL                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_HDSP                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_HDSPM                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ICE1712                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_ICE1724                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_INTEL8X0                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_INTEL8X0M                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_KORG1212                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_LOLA                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_LX6464ES                             policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_MAESTRO3                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_MAESTRO3_INPUT                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_MIXART                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_NM256                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_PCXHR                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_RIPTIDE                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_RME32                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_RME96                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_RME9652                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_SIS7019                              policy<{'i386': 'm'}>
++CONFIG_SND_SONICVIBES                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_TRIDENT                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_VIA82XX                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_VIA82XX_MODEM                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_VIRTUOSO                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_VX222                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_YMFPCI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> PCMCIA sound devices
++CONFIG_SND_PCMCIA                               policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y'}>
++CONFIG_SND_VXPOCKET                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_SND_PDAUDIOCF                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> PowerPC sound devices
++CONFIG_SND_PPC                                  policy<{'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_POWERMAC                             policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_SND_POWERMAC_AUTO_DRC                    policy<{'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_SND_PS3                                  policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_SND_PS3_DEFAULT_START_DELAY              policy<{'powerpc-powerpc64-smp': '2000'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> SPI sound devices
++CONFIG_SND_SPI                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> SUPERH sound devices
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> Sparc sound devices
++
++# Menu: Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> USB sound devices
++CONFIG_SND_USB                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_USB_AUDIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_USB_UA101                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_USB_USX2Y                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_USB_CAIAQ                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_USB_CAIAQ_INPUT                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SND_USB_US122L                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SND_USB_6FIRE                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_USB_HIFACE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_BCD2000                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_USB_POD                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_USB_PODHD                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_USB_TONEPORT                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SND_USB_VARIAX                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Sound card support >> Open Sound System (DEPRECATED)
++CONFIG_SOUND_PRIME                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Sound card support >> Open Sound System (DEPRECATED) >> OSS sound modules
++
++# Menu: Device Drivers >> Sound card support >> Open Sound System (DEPRECATED) >> Support for Turtle Beach MultiSound Classic, Tahiti, Monterey
++
++# Menu: Device Drivers >> Sound card support >> Open Sound System (DEPRECATED) >> Support for Turtle Beach MultiSound Pinnacle, Fiji
++
++# Menu: Device Drivers >> Staging drivers
++CONFIG_STAGING                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SLICOSS                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_PRISM2_USB                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8192U                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_R8712U                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_R8188EU                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_88EU_AP_MODE                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_R8723AU                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_8723AU_AP_MODE                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_8723AU_BT_COEXIST                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RTS5208                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VT6655                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VT6656                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_SM750                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_XGI                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_EMXX                                 policy<{'armhf': 'y'}>
++CONFIG_FT1000                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FT1000_USB                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FT1000_PCMCIA                            policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_TOUCHSCREEN_SYNAPTICS_I2C_RMI4           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_STAGING_BOARD                            policy<{'arm64': 'n', 'armhf': 'n', 'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_LTE_GDM724X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FIREWIRE_SERIAL                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FWTTY_MAX_TOTAL_PORTS                    policy<{'amd64': '64', 'arm64': '64', 'armhf': '64', 'i386': '64', 'powerpc': '64', 'ppc64el': '64'}>
++CONFIG_FWTTY_MAX_CARD_PORTS                     policy<{'amd64': '32', 'arm64': '32', 'armhf': '32', 'i386': '32', 'powerpc': '32', 'ppc64el': '32'}>
++CONFIG_MTD_SPINAND_MT29F                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MTD_SPINAND_ONDIEECC                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LNET                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LNET_MAX_PAYLOAD                         policy<{'amd64': '1048576', 'arm64': '1048576', 'armhf': '1048576', 'i386': '1048576', 'powerpc': '1048576', 'ppc64el': '1048576'}>
++CONFIG_LNET_SELFTEST                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LNET_XPRT_IB                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DGNC                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DGAP                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GS_FPGABOOT                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CRYPTO_SKEIN                             policy<{'amd64': 'y'}>
++CONFIG_COMMON_CLK_XLNX_CLKWZRD                  policy<{'arm64': 'n', 'armhf': 'n', 'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_FSL_MC_BUS                               policy<{'arm64': 'm'}>
++#
++CONFIG_STAGING                                  flag<REVIEW>
++
++# Menu: Device Drivers >> Staging drivers >> Android
++
++# Menu: Device Drivers >> Staging drivers >> Android >> Ion Memory Manager
++
++# Menu: Device Drivers >> Staging drivers >> Data acquisition support (comedi)
++CONFIG_COMEDI                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DEBUG                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_COMEDI_DEFAULT_BUF_SIZE_KB               policy<{'amd64': '2048', 'arm64': '2048', 'armhf': '2048', 'i386': '2048', 'powerpc': '2048', 'ppc64el': '2048'}>
++CONFIG_COMEDI_DEFAULT_BUF_MAXSIZE_KB            policy<{'amd64': '20480', 'arm64': '20480', 'armhf': '20480', 'i386': '20480', 'powerpc': '20480', 'ppc64el': '20480'}>
++CONFIG_COMEDI_8255_SA                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_KCOMEDILIB                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Data acquisition support (comedi) >> Comedi ISA and PC/104 drivers
++CONFIG_COMEDI_ISA_DRIVERS                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_COMEDI_PCL711                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PCL724                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PCL726                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PCL730                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PCL812                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PCL816                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PCL818                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PCM3724                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_AMPLC_DIO200_ISA                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_AMPLC_PC236_ISA                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_AMPLC_PC263_ISA                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_RTI800                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_RTI802                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DAC02                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DAS16M1                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DAS08_ISA                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DAS16                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DAS800                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DAS1800                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DAS6402                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DT2801                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DT2811                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DT2814                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DT2815                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DT2817                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DT282X                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DMM32AT                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_UNIOXX5                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_FL512                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_AIO_AIO12_8                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_AIO_IIRO_16                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_II_PCI20KC                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_C6XDIGIO                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_MPC624                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADQ12B                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_AT_A2150                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_AT_AO                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_ATMIO                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_ATMIO16D                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_LABPC_ISA                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PCMAD                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PCMDA12                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PCMMIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PCMUIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_MULTIQ3                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_S526                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Data acquisition support (comedi) >> Comedi PCI drivers
++CONFIG_COMEDI_PCI_DRIVERS                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_8255_PCI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADDI_APCI_1032                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADDI_APCI_1500                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADDI_APCI_1516                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADDI_APCI_1564                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADDI_APCI_16XX                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADDI_APCI_2032                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADDI_APCI_2200                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADDI_APCI_3120                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADDI_APCI_3501                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADDI_APCI_3XXX                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADL_PCI6208                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADL_PCI7X3X                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADL_PCI8164                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADL_PCI9111                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADL_PCI9118                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADV_PCI1710                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADV_PCI1723                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADV_PCI1724                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ADV_PCI_DIO                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_AMPLC_DIO200_PCI                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_AMPLC_PC236_PCI                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_AMPLC_PC263_PCI                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_AMPLC_PCI224                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_AMPLC_PCI230                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_CONTEC_PCI_DIO                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DAS08_PCI                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DT3000                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DYNA_PCI10XX                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_GSC_HPDI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_MF6X4                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ICP_MULTI                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DAQBOARD2000                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_JR3_PCI                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_KE_COUNTER                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_CB_PCIDAS64                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_CB_PCIDAS                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_CB_PCIDDA                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_CB_PCIMDAS                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_CB_PCIMDDA                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ME4000                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_ME_DAQ                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_6527                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_65XX                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_660X                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_670X                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_LABPC_PCI                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_PCIDIO                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_PCIMIO                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_RTD520                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_S626                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Data acquisition support (comedi) >> Comedi PCMCIA drivers
++CONFIG_COMEDI_PCMCIA_DRIVERS                    policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_COMEDI_CB_DAS16_CS                       policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_COMEDI_DAS08_CS                          policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_COMEDI_NI_DAQ_700_CS                     policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_COMEDI_NI_DAQ_DIO24_CS                   policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_COMEDI_NI_LABPC_CS                       policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_COMEDI_NI_MIO_CS                         policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_COMEDI_QUATECH_DAQP_CS                   policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Data acquisition support (comedi) >> Comedi USB drivers
++CONFIG_COMEDI_USB_DRIVERS                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_DT9812                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_NI_USB6501                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_USBDUX                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_USBDUXFAST                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_USBDUXSIGMA                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_VMK80XX                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Data acquisition support (comedi) >> Comedi misc drivers
++CONFIG_COMEDI_MISC_DRIVERS                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_COMEDI_BOND                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_TEST                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_PARPORT                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_SERIAL2002                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_COMEDI_SSV_DNP                           policy<{'i386': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> GCT GDM72xx WiMAX support
++CONFIG_WIMAX_GDM72XX                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WIMAX_GDM72XX_QOS                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_WIMAX_GDM72XX_K_MODE                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_WIMAX_GDM72XX_WIMAX2                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_WIMAX_GDM72XX_USB_PM                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> Staging drivers >> GCT GDM72xx WiMAX support >> Select interface
++CONFIG_WIMAX_GDM72XX_USB                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_WIMAX_GDM72XX_SDIO                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers
++CONFIG_IIO_PERIODIC_RTC_TRIGGER                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IIO_SIMPLE_DUMMY                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IIO_SIMPLE_DUMMY_EVENTS                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_IIO_SIMPLE_DUMMY_BUFFER                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_IIO_SIMPLE_DUMMY_EVENTS                  note<dummy driver>
++CONFIG_IIO_SIMPLE_DUMMY_BUFFER                  note<dummy driver>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers >> Accelerometers
++CONFIG_ADIS16201                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADIS16203                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADIS16204                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADIS16209                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADIS16220                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADIS16240                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIS3L02DQ                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SCA3000                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers >> Active energy metering IC
++CONFIG_ADE7753                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADE7754                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADE7758                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADE7759                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADE7854                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADE7854_I2C                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADE7854_SPI                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers >> Analog digital bi-direction converters
++CONFIG_ADT7316                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADT7316_SPI                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ADT7316_I2C                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers >> Analog to digital converters
++CONFIG_AD7606                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7606_IFACE_PARALLEL                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7606_IFACE_SPI                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7780                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7816                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7192                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7280                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers >> Capacitance to digital converters
++CONFIG_AD7150                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7152                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD7746                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers >> Digital gyroscope sensors
++CONFIG_ADIS16060                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers >> Direct Digital Synthesis
++CONFIG_AD9832                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD9834                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers >> Light sensors
++CONFIG_SENSORS_ISL29018                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_ISL29028                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TSL2583                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TSL2x7x                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers >> Magnetometer sensors
++CONFIG_SENSORS_HMC5843_I2C                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SENSORS_HMC5843_SPI                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers >> Network Analyzer, Impedance Converters
++CONFIG_AD5933                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> IIO staging drivers >> Resolver to digital converters
++CONFIG_AD2S90                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD2S1200                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AD2S1210                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Lustre file system client support
++CONFIG_LUSTRE_FS                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LUSTRE_OBD_MAX_IOCTL_BUFFER              policy<{'amd64': '8192', 'arm64': '8192', 'armhf': '8192', 'i386': '8192', 'powerpc': '8192', 'ppc64el': '8192'}>
++CONFIG_LUSTRE_DEBUG_EXPENSIVE_CHECK             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_LUSTRE_LLITE_LLOOP                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm'}>
++#
++CONFIG_LUSTRE_FS                                flag<REVIEW>
++
++# Menu: Device Drivers >> Staging drivers >> MOST driver
++CONFIG_MOST                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MOSTCORE                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AIM_CDEV                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AIM_NETWORK                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AIM_SOUND                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AIM_V4L2                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HDM_DIM2                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HDM_I2C                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HDM_USB                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Media staging drivers
++CONFIG_STAGING_MEDIA                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_I2C_BCM2048                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_CXD2099                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_MN88472                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DVB_MN88473                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Media staging drivers >> Linux Infrared Remote Control IR receiver/transmitter drivers
++CONFIG_LIRC_STAGING                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LIRC_BT829                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIRC_IMON                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIRC_PARALLEL                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIRC_SASEM                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIRC_SERIAL                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIRC_SERIAL_TRANSMITTER                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LIRC_SIR                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LIRC_ZILOG                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> NV Tegra Embedded Controller SMBus Interface
++CONFIG_MFD_NVEC                                 policy<{'armhf-generic': 'm'}>
++CONFIG_KEYBOARD_NVEC                            policy<{'armhf-generic': 'm'}>
++CONFIG_SERIO_NVEC_PS2                           policy<{'armhf-generic': 'm'}>
++CONFIG_NVEC_POWER                               policy<{'armhf-generic': 'm'}>
++CONFIG_NVEC_PAZ00                               policy<{'armhf-generic': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Parallel port LCD/Keypad Panel support
++CONFIG_PANEL                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PANEL_PARPORT                            policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++CONFIG_PANEL_PROFILE                            policy<{'amd64': '5', 'arm64': '5', 'armhf': '5', 'i386': '5', 'powerpc': '5', 'ppc64el': '5'}>
++CONFIG_PANEL_CHANGE_MESSAGE                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> Staging drivers >> Parallel port LCD/Keypad Panel support >> LCD type (0=none, 1=custom, 2=old //, 3=ks0074, 4=hantronix, 5=Nexcom)
++
++# Menu: Device Drivers >> Staging drivers >> Parallel port LCD/Keypad Panel support >> LCD type (0=none, 1=custom, 2=old //, 3=ks0074, 4=hantronix, 5=Nexcom) >> LCD communication mode (0=parallel 8 bits, 1=serial)
++
++# Menu: Device Drivers >> Staging drivers >> RDMA staging drivers
++CONFIG_STAGING_RDMA                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_INFINIBAND_AMSO1100                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_INFINIBAND_AMSO1100_DEBUG                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_INFINIBAND_EHCA                          policy<{'ppc64el': 'm'}>
++CONFIG_INFINIBAND_IPATH                         policy<{'amd64': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> RDMA staging drivers >> Intel OPA Gen1 support
++CONFIG_INFINIBAND_HFI1                          policy<{'amd64': 'm'}>
++CONFIG_HFI1_DEBUG_SDMA_ORDER                    policy<{'amd64': 'n'}>
++CONFIG_HFI1_VERBS_31BIT_PSN                     policy<{'amd64': 'y'}>
++CONFIG_SDMA_VERBOSITY                           policy<{'amd64': 'n'}>
++CONFIG_PRESCAN_RXQ                              policy<{'amd64': 'n'}>
++
++# Menu: Device Drivers >> Staging drivers >> Speakup console speech
++
++# Menu: Device Drivers >> Staging drivers >> Speakup console speech >> Speakup core
++CONFIG_SPEAKUP                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPEAKUP_SYNTH_ACNTSA                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPEAKUP_SYNTH_ACNTPC                     policy<{'i386': 'm'}>
++CONFIG_SPEAKUP_SYNTH_APOLLO                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPEAKUP_SYNTH_AUDPTR                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPEAKUP_SYNTH_BNS                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPEAKUP_SYNTH_DECTLK                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPEAKUP_SYNTH_DECEXT                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPEAKUP_SYNTH_DECPC                      policy<{'i386': 'm'}>
++CONFIG_SPEAKUP_SYNTH_DTLK                       policy<{'i386': 'm'}>
++CONFIG_SPEAKUP_SYNTH_KEYPC                      policy<{'i386': 'm'}>
++CONFIG_SPEAKUP_SYNTH_LTLK                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPEAKUP_SYNTH_SOFT                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPEAKUP_SYNTH_SPKOUT                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPEAKUP_SYNTH_TXPRT                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SPEAKUP_SYNTH_DUMMY                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Support for rtllib wireless devices
++CONFIG_RTLLIB                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTLLIB_CRYPTO_CCMP                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTLLIB_CRYPTO_TKIP                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTLLIB_CRYPTO_WEP                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RTL8192E                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Support for small TFT LCD display modules
++CONFIG_FB_TFT                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_AGM1264K_FL                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_BD663474                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_HX8340BN                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_HX8347D                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_HX8353D                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_HX8357D                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_ILI9163                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_ILI9320                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_ILI9325                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_ILI9340                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_ILI9341                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_ILI9481                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_ILI9486                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_PCD8544                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_RA8875                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_S6D02A1                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_S6D1121                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_SSD1289                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_SSD1306                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_SSD1331                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_SSD1351                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_ST7735R                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_TINYLCD                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_TLS8204                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_UC1611                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_UC1701                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_UPD161704                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_WATTEROTT                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_FLEX                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_FB_TFT_FBTFT_DEVICE                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> Unisys SPAR driver support
++CONFIG_UNISYSSPAR                               policy<{'amd64': 'y'}>
++CONFIG_UNISYS_VISORBUS                          policy<{'amd64': 'm'}>
++CONFIG_UNISYS_VISORNIC                          policy<{'amd64': 'm'}>
++
++# Menu: Device Drivers >> Staging drivers >> WILC1000 support (WiFi only)
++
++# Menu: Device Drivers >> Staging drivers >> WILC1000 support (WiFi only) >> Bus Type
++
++# Menu: Device Drivers >> Staging drivers >> WILC1000 support (WiFi only) >> Memory Allocation
++
++# Menu: Device Drivers >> TI VLYNQ
++
++# Menu: Device Drivers >> USB support
++CONFIG_USB_SUPPORT                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_USB_LED_TRIG                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> USB support >> ChipIdea Highspeed Dual Role Controller
++CONFIG_USB_CHIPIDEA                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_CHIPIDEA_UDC                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CHIPIDEA_HOST                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CHIPIDEA_DEBUG                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB
++#CONFIG_USB_MUSB_OMAP2PLUS			y
++CONFIG_USB                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_ANNOUNCE_NEW_DEVICES                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_DEFAULT_PERSIST                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_DYNAMIC_MINORS                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_OTG                                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_OTG_WHITELIST                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_OTG_BLACKLIST_HUB                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_OTG_FSM                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_ULPI_BUS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MON                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_WUSB                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_WUSB_CBAF                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_WUSB_CBAF_DEBUG                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_C67X00_HCD                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_OXU210HP_HCD                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_ISP116X_HCD                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_ISP1362_HCD                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_FUSBH200_HCD                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_FOTG210_HCD                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MAX3421_HCD                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_UHCI_HCD                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_U132_HCD                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SL811_HCD                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SL811_HCD_ISO                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SL811_CS                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_USB_R8A66597_HCD                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_RENESAS_USBHS_HCD                    policy<{'armhf': 'm'}>
++CONFIG_USB_WHCI_HCD                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_HWA_HCD                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_IMX21_HCD                            policy<{'armhf-generic': 'm'}>
++CONFIG_USB_HCD_BCMA                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'n', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_HCD_SSB                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'n', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_HCD_TEST_MODE                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_RENESAS_USBHS                        policy<{'armhf': 'm'}>
++CONFIG_USB_ACM                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_PRINTER                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_WDM                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_TMC                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MDC800                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MICROTEK                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_ISP1760                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_USS720                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_EMI62                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_EMI26                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_ADUTUX                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SEVSEG                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_RIO500                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_LEGOTOWER                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_LCD                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_LED                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_CYPRESS_CY7C63                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_CYTHERM                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_IDMOUSE                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_FTDI_ELAN                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_APPLEDISPLAY                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SISUSBVGA                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SISUSBVGA_CON                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_LD                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_TRANCEVIBRATOR                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_IOWARRIOR                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_TEST                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_EHSET_TEST_FIXTURE                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_ISIGHTFW                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_YUREX                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_EZUSB_FX2                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_HSIC_USB3503                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_LINK_LAYER_TEST                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_CHAOSKEY                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_USB_OTG                                  note<triggers breakage on x86 LP:1047527, LP:1411295>
++CONFIG_USB_OTG_WHITELIST                        note<OTG white/blacklists are disabled>
++CONFIG_USB_OTG_BLACKLIST_HUB                    note<OTG white/blacklists are disabled>
++CONFIG_USB_OTG_FSM                              note<selects USB_OTG LP:1047527, LP:1411295>>
++CONFIG_USB_UHCI_HCD                             note<ensures USB 2.0/1.1 probe ordering> flag<REVIEW>
++CONFIG_USB_HCD_BCMA                             note<USB_{O,E}HCI_HCD_PLATFORM must be off on omap>
++CONFIG_USB_HCD_SSB                              note<USB_{O,E}HCI_HCD_PLATFORM must be off on omap>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> DesignWare USB2 DRD Core Support
++CONFIG_USB_DWC2                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_DWC2_PCI                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_DWC2_DEBUG                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_DWC2_TRACK_MISSED_SOFS               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> DesignWare USB2 DRD Core Support >> DWC2 Mode Selection
++CONFIG_USB_DWC2_HOST                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_DWC2_PERIPHERAL                      policy<{'armhf': 'n'}>
++CONFIG_USB_DWC2_DUAL_ROLE                       policy<{'armhf': 'n'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> DesignWare USB3 DRD Core Support
++CONFIG_USB_DWC3                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_DWC3_ULPI                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_DWC3_OMAP                            policy<{'armhf': 'm'}>
++CONFIG_USB_DWC3_EXYNOS                          policy<{'armhf': 'm'}>
++CONFIG_USB_DWC3_PCI                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_DWC3_QCOM                            policy<{'arm64': 'm', 'armhf': 'm'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> DesignWare USB3 DRD Core Support >> DWC3 Mode Selection
++CONFIG_USB_DWC3_HOST                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_DWC3_GADGET                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_DWC3_DUAL_ROLE                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> EHCI HCD (USB 2.0) support
++CONFIG_USB_EHCI_HCD                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_EHCI_ROOT_HUB_TT                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_EHCI_TT_NEWSCHED                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_XPS_USB_HCD_XILINX                       policy<{'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_USB_EHCI_FSL                             policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_USB_EHCI_MXC                             policy<{'armhf-generic': 'm'}>
++CONFIG_USB_EHCI_HCD_OMAP                        policy<{'armhf': 'm'}>
++CONFIG_USB_EHCI_HCD_ORION                       policy<{'armhf': 'y'}>
++CONFIG_USB_EHCI_MSM                             policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_USB_EHCI_TEGRA                           policy<{'armhf-generic': 'm'}>
++CONFIG_USB_EHCI_HCD_PPC_OF                      policy<{'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_EHCI_EXYNOS                          policy<{'armhf': 'y'}>
++CONFIG_USB_EHCI_HCD_PLATFORM                    policy<{'amd64': 'y', 'arm64': 'm', 'armhf': 'n', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'm'}>
++#
++CONFIG_USB_EHCI_HCD_PLATFORM                    mark<ENFORCED> note<Don't use the generic ehci/ohci code on omap, it doesn't work> flag<REVIEW>
++CONFIG_USB_EHCI_HCD                             note<ensures USB 2.0/1.1 probe ordering> flag<REVIEW>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> ISP1760 Mode Selection
++CONFIG_USB_ISP1760_HOST_ROLE                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_ISP1760_GADGET_ROLE                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_ISP1760_DUAL_ROLE                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> Inventra Highspeed Dual Role Controller (TI, ADI, AW, ...)
++CONFIG_USB_MUSB_HDRC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MUSB_TUSB6010                        policy<{'armhf': 'm'}>
++CONFIG_USB_MUSB_OMAP2PLUS                       policy<{'armhf': 'm'}>
++CONFIG_USB_MUSB_AM35X                           policy<{'armhf': 'm'}>
++CONFIG_USB_MUSB_DSPS                            policy<{'armhf': 'm'}>
++#
++CONFIG_USB_MUSB_HDRC                            note<not autoloadable on omap> flag<REVIEW>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> Inventra Highspeed Dual Role Controller (TI, ADI, AW, ...) >> Disable DMA (always use PIO)
++CONFIG_USB_INVENTRA_DMA                         policy<{'armhf': 'n'}>
++CONFIG_USB_TI_CPPI41_DMA                        policy<{'armhf': 'n'}>
++CONFIG_MUSB_PIO_ONLY                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> Inventra Highspeed Dual Role Controller (TI, ADI, AW, ...) >> MUSB Mode Selection
++CONFIG_USB_MUSB_HOST                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_MUSB_GADGET                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_MUSB_DUAL_ROLE                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> OHCI HCD (USB 1.1) support
++CONFIG_USB_OHCI_HCD                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_OHCI_HCD_OMAP3                       policy<{'armhf-generic': 'm'}>
++CONFIG_USB_OHCI_HCD_PPC_OF_BE                   policy<{'powerpc': 'y', 'ppc64el': 'n'}>
++CONFIG_USB_OHCI_HCD_PPC_OF_LE                   policy<{'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_OHCI_HCD_PCI                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_OHCI_EXYNOS                          policy<{'armhf': 'y'}>
++CONFIG_USB_OHCI_HCD_PLATFORM                    policy<{'amd64': 'y', 'arm64': 'm', 'armhf': 'n', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'm'}>
++#
++CONFIG_USB_OHCI_HCD                             note<ensures USB 2.0/1.1 probe ordering>
++CONFIG_USB_OHCI_HCD_PPC_OF_LE                   flag<REVIEW>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> USB DSL modem support
++CONFIG_USB_ATM                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SPEEDTOUCH                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_CXACRU                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_UEAGLEATM                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_XUSBATM                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> USB Mass Storage support
++CONFIG_USB_STORAGE                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_DEBUG                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_STORAGE_REALTEK                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REALTEK_AUTOPM                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_STORAGE_DATAFAB                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_FREECOM                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_ISD200                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_USBAT                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_SDDR09                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_SDDR55                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_JUMPSHOT                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_ALAUDA                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_ONETOUCH                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_KARMA                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_CYPRESS_ATACB                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_STORAGE_ENE_UB6250                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_UAS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> USB Serial Converter support
++CONFIG_USB_SERIAL                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_GENERIC                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_SIMPLE                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_AIRCABLE                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_ARK3116                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_BELKIN                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_CH341                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_WHITEHEAT                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_DIGI_ACCELEPORT               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_CP210X                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_CYPRESS_M8                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_EMPEG                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_FTDI_SIO                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_VISOR                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_IPAQ                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_IR                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_EDGEPORT                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_EDGEPORT_TI                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_F81232                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_GARMIN                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_IPW                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_IUU                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_KEYSPAN_PDA                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_KLSI                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_KOBIL_SCT                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_MCT_U232                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_METRO                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_MOS7720                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_MOS7715_PARPORT               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_MOS7840                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_MXUPORT                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_NAVMAN                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_PL2303                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_OTI6858                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_QCAUX                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_QUALCOMM                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_SPCP8X5                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_SAFE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_SAFE_PADDED                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_SERIAL_SIERRAWIRELESS                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_SYMBOL                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_TI                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_CYBERJACK                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_XIRCOM                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_OPTION                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_OMNINET                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_OPTICON                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_XSENS_MT                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_WISHBONE                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_SSU100                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_QT2                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_DEBUG                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_USB_SERIAL_DEBUG                         note<not actually debug>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> USB Serial Converter support >> USB Keyspan USA-xxx Serial Driver
++CONFIG_USB_SERIAL_KEYSPAN                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_SERIAL_KEYSPAN_MPR                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_KEYSPAN_USA28                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_KEYSPAN_USA28X                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_KEYSPAN_USA28XA               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_KEYSPAN_USA28XB               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_KEYSPAN_USA19                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_KEYSPAN_USA18X                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_KEYSPAN_USA19W                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_KEYSPAN_USA19QW               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_KEYSPAN_USA19QI               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_KEYSPAN_USA49W                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_SERIAL_KEYSPAN_USA49WLC              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> USB/IP support
++CONFIG_USBIP_CORE                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USBIP_VHCI_HCD                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USBIP_HOST                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USBIP_DEBUG                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Device Drivers >> USB support >> Support for Host-side USB >> xHCI HCD (USB 3.0) support
++CONFIG_USB_XHCI_HCD                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_XHCI_PLATFORM                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_XHCI_MVEBU                           policy<{'armhf': 'm'}>
++CONFIG_USB_XHCI_RCAR                            policy<{'armhf': 'm'}>
++#
++CONFIG_USB_XHCI_HCD                             note<ensures USB 2.0/1.1 probe ordering> flag<REVIEW>
++
++# Menu: Device Drivers >> USB support >> USB Gadget Support
++CONFIG_USB_GADGET                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GADGET_DEBUG                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_GADGET_DEBUG_FILES                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_GADGET_DEBUG_FS                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_GADGET_VBUS_DRAW                     policy<{'amd64': '2', 'arm64': '2', 'armhf': '2', 'i386': '2', 'powerpc': '2', 'ppc64el': '2'}>
++CONFIG_USB_GADGET_STORAGE_NUM_BUFFERS           policy<{'amd64': '2', 'arm64': '2', 'armhf': '2', 'i386': '2', 'powerpc': '2', 'ppc64el': '2'}>
++
++# Menu: Device Drivers >> USB support >> USB Gadget Support >> USB Gadget Drivers
++CONFIG_USB_ZERO                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_AUDIO                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GADGET_UAC1                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_ETH                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_ETH_RNDIS                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_ETH_EEM                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_G_NCM                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GADGETFS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MASS_STORAGE                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GADGET_TARGET                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_G_SERIAL                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MIDI_GADGET                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_G_PRINTER                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_CDC_COMPOSITE                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_G_NOKIA                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_G_ACM_MS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_G_MULTI                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'm', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_G_MULTI_RNDIS                        policy<{'armhf': 'y'}>
++CONFIG_USB_G_MULTI_CDC                          policy<{'armhf': 'y'}>
++CONFIG_USB_G_HID                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_G_DBGP                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_G_WEBCAM                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> USB support >> USB Gadget Support >> USB Gadget Drivers >> EHCI Debug Device mode
++CONFIG_USB_G_DBGP_PRINTK                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_G_DBGP_SERIAL                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> USB support >> USB Gadget Support >> USB Gadget Drivers >> Function Filesystem
++CONFIG_USB_FUNCTIONFS                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_FUNCTIONFS_ETH                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_FUNCTIONFS_RNDIS                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_FUNCTIONFS_GENERIC                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> USB support >> USB Gadget Support >> USB Gadget Drivers >> USB functions configurable through configfs
++CONFIG_USB_CONFIGFS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_CONFIGFS_SERIAL                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_ACM                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_OBEX                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_NCM                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_ECM                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_ECM_SUBSET                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_RNDIS                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_EEM                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_PHONET                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_MASS_STORAGE                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_F_LB_SS                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_F_FS                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_F_UAC1                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_F_UAC2                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_F_MIDI                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_F_HID                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_F_UVC                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_CONFIGFS_F_PRINTER                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Device Drivers >> USB support >> USB Gadget Support >> USB Peripheral Controller
++CONFIG_USB_FSL_USB2                             policy<{'armhf-generic': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_USB_FUSB300                              policy<{'armhf-generic': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_USB_FOTG210_UDC                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GR_UDC                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_R8A66597                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_RENESAS_USBHS_UDC                    policy<{'armhf': 'm'}>
++CONFIG_USB_PXA27X                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MV_UDC                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MV_U3D                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_M66592                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_USB_BDC_UDC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_BDC_PCI                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_AMD5536UDC                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_FSL_QE                               policy<{'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_USB_NET2272                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_NET2272_DMA                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_NET2280                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GOKU                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_EG20T                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_GADGET_XILINX                        policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_DUMMY_HCD                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_USB_M66592                               note<gadget device>
++CONFIG_USB_DUMMY_HCD                            flag<TESTING>
++
++# Menu: Device Drivers >> USB support >> USB Physical Layer drivers
++CONFIG_NOP_USB_XCEIV                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_AM335X_PHY_USB                           policy<{'armhf': 'm'}>
++CONFIG_TWL6030_USB                              policy<{'armhf': 'm'}>
++CONFIG_USB_GPIO_VBUS                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TAHVO_USB                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TAHVO_USB_HOST_BY_DEFAULT                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_USB_ISP1301                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_MSM_OTG                              policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_USB_QCOM_8X16_PHY                        policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_USB_MXS_PHY                              policy<{'armhf-generic': 'y'}>
++CONFIG_USB_RCAR_PHY                             policy<{'armhf': 'm'}>
++CONFIG_USB_ULPI                                 policy<{'arm64': 'y', 'armhf': 'y'}>
++#
++CONFIG_NOP_USB_XCEIV                            note<boot essential on omap/highbank>
++
++# Menu: Device Drivers >> Ultra Wideband devices
++CONFIG_UWB                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_UWB_HWA                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UWB_WHCI                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UWB_I1480U                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Userspace I/O drivers
++CONFIG_UIO                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_UIO_CIF                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UIO_PDRV_GENIRQ                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UIO_DMEM_GENIRQ                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UIO_AEC                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UIO_SERCOS3                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UIO_PCI_GENERIC                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UIO_NETX                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UIO_FSL_ELBC_GPCM                        policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UIO_FSL_ELBC_GPCM_NETX5152               policy<{'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_UIO_PRUSS                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UIO_MF624                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> VFIO Non-Privileged userspace driver framework
++CONFIG_VFIO                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'y'}>
++CONFIG_VFIO_PCI                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'y'}>
++CONFIG_VFIO_PCI_VGA                             policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_VFIO_PLATFORM                            policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_VFIO_AMBA                                policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_VFIO_PLATFORM_CALXEDAXGMAC_RESET         policy<{'arm64': 'm', 'armhf': 'm'}>
++#
++CONFIG_VFIO					mark<ENFORCED>note<LP#1636733>
++CONFIG_VFIO_PCI					mark<ENFORCED>note<LP#1636733>
++
++# Menu: Device Drivers >> VME bridge support
++CONFIG_VME_BUS                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_VME_CA91CX42                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_VME_TSI148                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VMIVME_7805                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VME_USER                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VME_PIO2                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> Virtio drivers
++CONFIG_VIRTIO_PCI                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_VIRTIO_PCI_LEGACY                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_VIRTIO_BALLOON                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_VIRTIO_INPUT                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIRTIO_MMIO                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_VIRTIO_MMIO				note<LP#1557689 CONFIG_VIRTIO_MMIO=n for s390x>
++CONFIG_VIRTIO_MMIO_CMDLINE_DEVICES              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_VIRTIO_PCI                               mark<review>
++
++# Menu: Device Drivers >> Virtualization drivers
++CONFIG_VIRT_DRIVERS                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FSL_HV_MANAGER                           policy<{'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++
++# Menu: Device Drivers >> Voltage and Current Regulator Support
++CONFIG_REGULATOR                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_REGULATOR_DEBUG                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_REGULATOR_FIXED_VOLTAGE                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_VIRTUAL_CONSUMER               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_USERSPACE_CONSUMER             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_88PM800                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_88PM8607                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_ACT8865                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_AD5398                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_ANATOP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_AAT2870                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_AB3100                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_ARIZONA                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_AS3711                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_AS3722                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_AXP20X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_BCM590XX                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_DA903X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_DA9052                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_DA9055                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_DA9062                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_DA9063                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_DA9210                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_DA9211                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_FAN53555                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_GPIO                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_HI6421                         policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_ISL9305                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_ISL6271A                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_LP3971                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_LP3972                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_LP872X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_LP8755                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_LP8788                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_LTC3589                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX14577                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX1586                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX8649                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX8660                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX8907                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX8925                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX8952                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX8973                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX8997                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX8998                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX77686                       policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX77693                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MAX77802                       policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MC13783                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MC13892                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MT6311                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_MT6397                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_PALMAS                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_PBIAS                          policy<{'armhf': 'm'}>
++CONFIG_REGULATOR_PCAP                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_PCF50633                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_PFUZE100                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_PWM                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_QCOM_RPM                       policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_REGULATOR_QCOM_SMD_RPM                   policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_REGULATOR_QCOM_SPMI                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_RC5T583                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_RK808                          policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_RN5T618                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_RT5033                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_S2MPA01                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_S2MPS11                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_S5M8767                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_SKY81452                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TI_ABB                         policy<{'armhf': 'y'}>
++CONFIG_REGULATOR_TPS51632                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS6105X                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS62360                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS65023                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS6507X                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS65090                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS65217                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS65218                       policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS6524X                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS6586X                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS65910                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS65912                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TPS80031                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_TWL4030                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf-generic': 'y', 'armhf-generic-lpae': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_VEXPRESS                       policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_REGULATOR_WM831X                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_WM8350                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_WM8400                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_REGULATOR_WM8994                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++#
++CONFIG_REGULATOR_FIXED_VOLTAGE                  note<boot essential on arm>
++CONFIG_REGULATOR_TWL4030                        mark<ENFORCED> note<boot requisite for omap4>
++
++# Menu: Device Drivers >> Watchdog Timer Support
++CONFIG_WATCHDOG                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_WATCHDOG_CORE                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_WATCHDOG_NOWAYOUT                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SOFT_WATCHDOG                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DA9052_WATCHDOG                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DA9055_WATCHDOG                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DA9063_WATCHDOG                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DA9062_WATCHDOG                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GPIO_WATCHDOG                            policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MENF21BMC_WATCHDOG                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WM831X_WATCHDOG                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WM8350_WATCHDOG                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_XILINX_WATCHDOG                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_ARM_SP805_WATCHDOG                       policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_CADENCE_WATCHDOG                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_S3C2410_WATCHDOG                         policy<{'armhf': 'm'}>
++CONFIG_DW_WATCHDOG                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_OMAP_WATCHDOG                            policy<{'armhf': 'm'}>
++CONFIG_ORION_WATCHDOG                           policy<{'armhf': 'm'}>
++CONFIG_RN5T618_WATCHDOG                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TWL4030_WATCHDOG                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MAX63XX_WATCHDOG                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_IMX2_WDT                                 policy<{'armhf-generic': 'm'}>
++CONFIG_RETU_WATCHDOG                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TEGRA_WATCHDOG                           policy<{'armhf-generic': 'm'}>
++CONFIG_QCOM_WDT                                 policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_MESON_WATCHDOG                           policy<{'armhf': 'm'}>
++CONFIG_MEDIATEK_WATCHDOG                        policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_ACQUIRE_WDT                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ADVANTECH_WDT                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ALIM1535_WDT                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ALIM7101_WDT                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_F71808E_WDT                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SP5100_TCO                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SBC_FITPC2_WATCHDOG                      policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EUROTECH_WDT                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_IB700_WDT                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_IBMASR                                   policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_WAFER_WDT                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_I6300ESB_WDT                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_IE6XX_WDT                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_SCU_WATCHDOG                       policy<{'i386': 'y'}>
++CONFIG_INTEL_MID_WATCHDOG                       policy<{'i386': 'm'}>
++CONFIG_ITCO_WDT                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ITCO_VENDOR_SUPPORT                      policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_IT8712F_WDT                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_IT87_WDT                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_HP_WATCHDOG                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_KEMPLD_WDT                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_HPWDT_NMI_DECODING                       policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_SC1200_WDT                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SCx200_WDT                               policy<{'i386': 'm'}>
++CONFIG_PC87413_WDT                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_NV_TCO                                   policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_60XX_WDT                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SBC8360_WDT                              policy<{'i386': 'm'}>
++CONFIG_SBC7240_WDT                              policy<{'i386': 'm'}>
++CONFIG_CPU5_WDT                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SMSC_SCH311X_WDT                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SMSC37B787_WDT                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_VIA_WDT                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_W83627HF_WDT                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_W83877F_WDT                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_W83977F_WDT                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MACHZ_WDT                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SBC_EPX_C3_WATCHDOG                      policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_BOOKE_WDT                                policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_BOOKE_WDT_DEFAULT_TIMEOUT                policy<{'powerpc-powerpc64-emb': '38', 'powerpc-powerpc-e500mc': '38'}>
++CONFIG_MEN_A21_WDT                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WATCHDOG_RTAS                            policy<{'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_DIAG288_WATCHDOG                         policy<{'s390x': 'm'}>
++CONFIG_XEN_WDT                                  policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_PCWATCHDOG                               policy<{'i386': 'm'}>
++CONFIG_MIXCOMWD                                 policy<{'i386': 'm'}>
++CONFIG_WDT                                      policy<{'i386': 'm'}>
++CONFIG_PCIPCWATCHDOG                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_WDTPCI                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_USBPCWATCHDOG                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Device Drivers >> X86 Platform Specific Device Drivers
++CONFIG_X86_PLATFORM_DEVICES                     policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACER_WMI                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ACERHDF                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ALIENWARE_WMI                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ASUS_LAPTOP                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_DELL_LAPTOP                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_DELL_WMI                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_DELL_WMI_AIO                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_DELL_SMO8800                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_DELL_RBTN                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_FUJITSU_LAPTOP                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_FUJITSU_LAPTOP_DEBUG                     policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_FUJITSU_TABLET                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_AMILO_RFKILL                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_TC1100_WMI                               policy<{'i386': 'm'}>
++CONFIG_HP_ACCEL                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_HP_WIRELESS                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_HP_WMI                                   policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MSI_LAPTOP                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_PANASONIC_LAPTOP                         policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_COMPAL_LAPTOP                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SONY_LAPTOP                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SONYPI_COMPAT                            policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_IDEAPAD_LAPTOP                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SENSORS_HDAPS                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_MENLOW                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EEEPC_LAPTOP                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ASUS_WMI                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ASUS_NB_WMI                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_EEEPC_WMI                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_TOPSTAR_LAPTOP                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_TOSHIBA_BT_RFKILL                        policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_TOSHIBA_HAPS                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ACPI_CMPC                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_MFLD_THERMAL                       policy<{'i386': 'm'}>
++CONFIG_INTEL_IPS                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_IBM_RTL                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SAMSUNG_LAPTOP                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_OAKTRAIL                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SAMSUNG_Q10                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_APPLE_GMUX                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_RST                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_SMARTCONNECT                       policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_PVPANIC                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_INTEL_PMC_IPC                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_SURFACE_PRO3_BUTTON                      policy<{'amd64': 'm', 'i386': 'm'}>
++
++# Menu: Device Drivers >> X86 Platform Specific Device Drivers >> Intel SCU IPC Support
++CONFIG_INTEL_SCU_IPC                            policy<{'i386': 'y'}>
++CONFIG_INTEL_SCU_IPC_UTIL                       policy<{'i386': 'm'}>
++CONFIG_GPIO_INTEL_PMIC                          policy<{'i386': 'y'}>
++CONFIG_INTEL_MID_POWER_BUTTON                   policy<{'i386': 'm'}>
++
++# Menu: Device Drivers >> X86 Platform Specific Device Drivers >> ThinkPad ACPI Laptop Extras
++CONFIG_THINKPAD_ACPI                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_THINKPAD_ACPI_ALSA_SUPPORT               policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_THINKPAD_ACPI_DEBUGFACILITIES            policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_THINKPAD_ACPI_DEBUG                      policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_THINKPAD_ACPI_UNSAFE_LEDS                policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_THINKPAD_ACPI_VIDEO                      policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_THINKPAD_ACPI_HOTKEY_POLL                policy<{'amd64': 'y', 'i386': 'y'}>
++
++# Menu: Device Drivers >> X86 Platform Specific Device Drivers >> WMI
++CONFIG_ACPI_WMI                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MSI_WMI                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ACPI_TOSHIBA                             policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_MXM_WMI                                  policy<{'amd64': 'm', 'i386': 'm'}>
++
++# Menu: Device Drivers >> Xen driver support
++CONFIG_XEN_DEV_EVTCHN                           policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_XEN_BACKEND                              policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_XENFS                                    policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_XEN_COMPAT_XENFS                         policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_XEN_SYS_HYPERVISOR                       policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_XEN_GNTDEV                               policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_XEN_GRANT_DEV_ALLOC                      policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_XEN_PCIDEV_BACKEND                       policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_XEN_SCSI_BACKEND                         policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_XEN_ACPI_PROCESSOR                       policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_XEN_MCE_LOG                              policy<{'amd64': 'y'}>
++CONFIG_XEN_SYMS                                 policy<{'amd64': 'y', 'i386': 'y'}>
++#
++CONFIG_XEN_ACPI_PROCESSOR                       mark<ENFORCED> <boot essential on XEN host>
++
++# Menu: Device Drivers >> Xen driver support >> Xen memory balloon driver
++CONFIG_XEN_BALLOON                              policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_XEN_SELFBALLOONING                       policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_XEN_BALLOON_MEMORY_HOTPLUG               policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_XEN_BALLOON_MEMORY_HOTPLUG_LIMIT         policy<{'amd64': '512', 'i386': '4'}>
++CONFIG_XEN_SCRUB_PAGES                          policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++
++# Menu: Dump support
++#
++
++# Menu: Dump support >> Architecture: s390
++
++# Menu: Enable loadable module support
++CONFIG_MODULES                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MODULE_FORCE_LOAD                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_MODULE_UNLOAD                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MODULE_FORCE_UNLOAD                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_MODVERSIONS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MODULE_SRCVERSION_ALL                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MODULE_COMPRESS                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Enable loadable module support >> Compression algorithm
++
++# Menu: Enable loadable module support >> Module signature verification
++CONFIG_MODULE_SIG                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MODULE_SIG_FORCE                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_MODULE_SIG_ALL                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Enable loadable module support >> Module signature verification >> Which hash algorithm should modules be signed with?
++CONFIG_MODULE_SIG_SHA1                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_MODULE_SIG_SHA224                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_MODULE_SIG_SHA256                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_MODULE_SIG_SHA384                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_MODULE_SIG_SHA512                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Enable the block layer
++CONFIG_BLOCK                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_LBDAF                                    policy<{'armhf': 'y', 'i386': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_BLK_DEV_BSG                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_DEV_BSGLIB                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_DEV_INTEGRITY                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_DEV_THROTTLING                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_CMDLINE_PARSER                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_BLK_DEV_THROTTLING                       note<CGROUP disk consumption control>
++
++# Menu: Enable the block layer >> IO Schedulers
++CONFIG_IOSCHED_DEADLINE                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IOSCHED_CFQ                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CFQ_GROUP_IOSCHED                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Enable the block layer >> IO Schedulers >> Default I/O scheduler
++CONFIG_DEFAULT_DEADLINE                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEFAULT_CFQ                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEFAULT_NOOP                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Enable the block layer >> Partition Types
++
++# Menu: Enable the block layer >> Partition Types >> Advanced partition selection
++CONFIG_PARTITION_ADVANCED                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_AIX_PARTITION                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_OSF_PARTITION                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_AMIGA_PARTITION                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ATARI_PARTITION                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_IBM_PARTITION                            policy<{'s390x': 'y'}>
++CONFIG_MAC_PARTITION                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_LDM_PARTITION                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_LDM_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SGI_PARTITION                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ULTRIX_PARTITION                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SUN_PARTITION                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_KARMA_PARTITION                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_EFI_PARTITION                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SYSV68_PARTITION                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_CMDLINE_PARTITION                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++#
++CONFIG_PARTITION_ADVANCED                       flag<REVIEW>
++
++# Menu: Enable the block layer >> Partition Types >> Advanced partition selection >> Acorn partition support
++CONFIG_ACORN_PARTITION                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Enable the block layer >> Partition Types >> Advanced partition selection >> PC BIOS (MSDOS partition tables) support
++CONFIG_MSDOS_PARTITION                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BSD_DISKLABEL                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_MINIX_SUBPARTITION                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SOLARIS_X86_PARTITION                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_UNIXWARE_DISKLABEL                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++
++# Menu: Endianness selection
++CONFIG_CPU_BIG_ENDIAN                           policy<{'arm64': 'n', 'armhf': 'n', 'powerpc': 'y', 'ppc64el': 'n'}>
++
++# Menu: Endianness selection >> Architecture: powerpc
++CONFIG_CPU_LITTLE_ENDIAN                        policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'y'}>
++
++# Menu: Executable file formats / Emulations
++CONFIG_BINFMT_ELF                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BINFMT_SCRIPT                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BINFMT_AOUT                              policy<{'i386': 'm'}>
++CONFIG_BINFMT_MISC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_COREDUMP                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECCOMP                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_BINFMT_SCRIPT                            mark<ENFORCED> note<required if 'init' is a shell script such as in initramfs-tools>
++CONFIG_SECCOMP                                  mark<ENFORCED>
++
++# Menu: Executable file formats / Emulations >> Architecture: arm
++
++# Menu: Executable file formats / Emulations >> Architecture: s390
++
++# Menu: Executable file formats / Emulations >> Architecture: x86
++CONFIG_IA32_EMULATION                           policy<{'amd64': 'y'}>
++CONFIG_IA32_AOUT                                policy<{'amd64': 'n'}>
++CONFIG_X86_X32                                  policy<{'amd64': 'y'}>
++#
++CONFIG_IA32_AOUT                                note<AOUT is deprecated> mark<DEPRECATED>
++
++# Menu: File systems
++CONFIG_EXT2_FS                                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_EXT3_FS                                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_JBD2_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_GFS2_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_GFS2_FS_LOCKING_DLM                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NILFS2_FS                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_FS_DAX                                   policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FILE_LOCKING                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DNOTIFY                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_INOTIFY_USER                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FANOTIFY                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FANOTIFY_ACCESS_PERMISSIONS              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_QUOTA_NETLINK_INTERFACE                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_AUTOFS4_FS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'y'}>
++CONFIG_FUSE_FS                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CUSE                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_OVERLAY_FS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_OVERLAY_FS_V1                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_EXT2_FS                                  note<ext4 handling via EXT4_USE_FOR_EXT23>
++CONFIG_EXT3_FS                                  note<ext4 handling via EXT4_USE_FOR_EXT23>
++CONFIG_FUSE_FS                                  note<not autoloadable> flag<REVIEW>
++
++# Menu: File systems >> Btrfs filesystem support
++CONFIG_BTRFS_FS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BTRFS_FS_POSIX_ACL                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BTRFS_FS_CHECK_INTEGRITY                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_BTRFS_FS_RUN_SANITY_TESTS                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_BTRFS_DEBUG                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_BTRFS_ASSERT                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: File systems >> CD-ROM/DVD Filesystems
++CONFIG_ISO9660_FS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_JOLIET                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ZISOFS                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_UDF_FS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: File systems >> Caches
++CONFIG_CACHEFILES                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CACHEFILES_DEBUG                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_CACHEFILES_HISTOGRAM                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: File systems >> Caches >> General filesystem local caching manager
++CONFIG_FSCACHE                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_FSCACHE_STATS                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FSCACHE_HISTOGRAM                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_FSCACHE_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_FSCACHE_OBJECT_LIST                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: File systems >> DOS/FAT/NT Filesystems
++CONFIG_MSDOS_FS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_VFAT_FS                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FAT_DEFAULT_CODEPAGE                     policy<{'amd64': '437', 'arm64': '437', 'armhf': '437', 'i386': '437', 'powerpc': '437', 'ppc64el': '437', 's390x': '437'}>
++CONFIG_FAT_DEFAULT_IOCHARSET                    policy<{'amd64': '"iso8859-1"', 'arm64': '"iso8859-1"', 'armhf': '"iso8859-1"', 'i386': '"iso8859-1"', 'powerpc': '"iso8859-1"', 'ppc64el': '"iso8859-1"', 's390x': '"iso8859-1"'}>
++CONFIG_NTFS_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NTFS_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_NTFS_RW                                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'y'}>
++#
++CONFIG_VFAT_FS                                  mark<ENFORCED> note<needed on arm to ensure we can write the kernel when replacing>
++
++# Menu: File systems >> Distributed Lock Manager (DLM)
++CONFIG_DLM                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DLM_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: File systems >> F2FS filesystem support
++CONFIG_F2FS_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_F2FS_STAT_FS                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_F2FS_CHECK_FS                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_F2FS_IO_TRACE                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: File systems >> F2FS filesystem support >> F2FS extended attributes
++CONFIG_F2FS_FS_XATTR                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_F2FS_FS_POSIX_ACL                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_F2FS_FS_SECURITY                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_F2FS_FS_ENCRYPTION                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: File systems >> JFS filesystem support
++CONFIG_JFS_FS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_JFS_POSIX_ACL                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JFS_SECURITY                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JFS_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_JFS_STATISTICS                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: File systems >> Miscellaneous filesystems
++CONFIG_MISC_FILESYSTEMS                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ADFS_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_ADFS_FS_RW                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_AFFS_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_ECRYPT_FS                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ECRYPT_FS_MESSAGING                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_HFS_FS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_HFSPLUS_FS                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_HFSPLUS_FS_POSIX_ACL                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BEFS_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_BEFS_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_BFS_FS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_EFS_FS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_UBIFS_FS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_UBIFS_FS_ADVANCED_COMPR                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_UBIFS_FS_LZO                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_UBIFS_FS_ZLIB                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LOGFS                                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_CRAMFS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_VXFS_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MINIX_FS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_OMFS_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_HPFS_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_QNX4FS_FS                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_QNX6FS_FS                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_QNX6FS_DEBUG                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ROMFS_FS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_SYSV_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_UFS_FS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_UFS_FS_WRITE                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_UFS_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_EXOFS_FS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_EXOFS_DEBUG                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_ECRYPT_FS                                mark<ENFORCED> note<not autoloadable>
++CONFIG_LOGFS                                    note<highly discouraged for use>
++
++# Menu: File systems >> Miscellaneous filesystems >> Aufs (Advanced multi layered unification filesystem) support
++CONFIG_AUFS_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_AUFS_HNOTIFY                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_AUFS_EXPORT                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_AUFS_XATTR                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_AUFS_FHSM                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_AUFS_RDU                                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_AUFS_SHWH                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_AUFS_BR_RAMFS                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_AUFS_BR_FUSE                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_AUFS_BR_HFSPLUS                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_AUFS_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_AUFS_EXPORT                              note<LP:1121699>
++
++# Menu: File systems >> Miscellaneous filesystems >> Aufs (Advanced multi layered unification filesystem) support >> Maximum number of branches
++CONFIG_AUFS_BRANCH_MAX_127                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_AUFS_BRANCH_MAX_511                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_AUFS_BRANCH_MAX_1023                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_AUFS_BRANCH_MAX_32767                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: File systems >> Miscellaneous filesystems >> Aufs (Advanced multi layered unification filesystem) support >> method
++
++# Menu: File systems >> Miscellaneous filesystems >> Journalling Flash File System v2 (JFFS2) support
++CONFIG_JFFS2_FS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_JFFS2_FS_DEBUG                           policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++CONFIG_JFFS2_FS_WRITEBUFFER                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JFFS2_FS_WBUF_VERIFY                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_JFFS2_SUMMARY                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_JFFS2_FS_XATTR                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JFFS2_FS_POSIX_ACL                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JFFS2_FS_SECURITY                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: File systems >> Miscellaneous filesystems >> Journalling Flash File System v2 (JFFS2) support >> Advanced compression options for JFFS2
++CONFIG_JFFS2_COMPRESSION_OPTIONS                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JFFS2_ZLIB                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JFFS2_LZO                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JFFS2_RTIME                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_JFFS2_RUBIN                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: File systems >> Miscellaneous filesystems >> Journalling Flash File System v2 (JFFS2) support >> Advanced compression options for JFFS2 >> JFFS2 default compression mode
++CONFIG_JFFS2_CMODE_NONE                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_JFFS2_CMODE_PRIORITY                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_JFFS2_CMODE_SIZE                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_JFFS2_CMODE_FAVOURLZO                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: File systems >> Miscellaneous filesystems >> Persistent store support
++CONFIG_PSTORE                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_PSTORE_CONSOLE                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'y', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_PSTORE_PMSG                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_PSTORE_FTRACE                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_PSTORE_RAM                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'y', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: File systems >> Miscellaneous filesystems >> RomFS backing stores
++CONFIG_ROMFS_BACKED_BY_BLOCK                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ROMFS_BACKED_BY_MTD                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ROMFS_BACKED_BY_BOTH                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: File systems >> Miscellaneous filesystems >> SquashFS 4.0 - Squashed file system support
++CONFIG_SQUASHFS                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SQUASHFS_XATTR                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SQUASHFS_ZLIB                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SQUASHFS_LZ4                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SQUASHFS_LZO                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SQUASHFS_XZ                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SQUASHFS_4K_DEVBLK_SIZE                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SQUASHFS_EMBEDDED                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SQUASHFS_FRAGMENT_CACHE_SIZE             policy<{'amd64': '3', 'arm64': '3', 'armhf': '3', 'i386': '3', 'powerpc': '3', 'ppc64el': '3', 's390x': '3'}>
++#
++CONFIG_SQUASHFS_4K_DEVBLK_SIZE                  note<non-default block size>
++CONFIG_SQUASHFS					mark<ENFORCED> note<LP#1593134>
++
++# Menu: File systems >> Miscellaneous filesystems >> SquashFS 4.0 - Squashed file system support >> Decompressor parallelisation options
++CONFIG_SQUASHFS_DECOMP_SINGLE                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SQUASHFS_DECOMP_MULTI                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SQUASHFS_DECOMP_MULTI_PERCPU             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: File systems >> Miscellaneous filesystems >> SquashFS 4.0 - Squashed file system support >> File decompression options
++CONFIG_SQUASHFS_FILE_CACHE                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SQUASHFS_FILE_DIRECT                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: File systems >> Native language support
++CONFIG_NLS                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NLS_DEFAULT                              policy<{'amd64': '"utf8"', 'arm64': '"utf8"', 'armhf': '"utf8"', 'i386': '"utf8"', 'powerpc': '"utf8"', 'ppc64el': '"utf8"', 's390x': '"utf8"'}>
++CONFIG_NLS_CODEPAGE_437                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NLS_CODEPAGE_737                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_775                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_850                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_852                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_855                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_857                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_860                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_861                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_862                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_863                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_864                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_865                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_866                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_869                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_936                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_950                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_932                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_949                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_874                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_8                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_1250                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_CODEPAGE_1251                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ASCII                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_1                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_2                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_3                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_4                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_5                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_6                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_7                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_9                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_13                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_14                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_ISO8859_15                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_KOI8_R                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_KOI8_U                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_MAC_ROMAN                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_MAC_CELTIC                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_MAC_CENTEURO                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_MAC_CROATIAN                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_MAC_CYRILLIC                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_MAC_GAELIC                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_MAC_GREEK                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_MAC_ICELAND                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_MAC_INUIT                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_MAC_ROMANIAN                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_MAC_TURKISH                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NLS_UTF8                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++#
++CONFIG_NLS                                      note<dependancy of boot essential>
++
++# Menu: File systems >> Network File Systems
++CONFIG_NETWORK_FILESYSTEMS                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NFSD                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFSD_V3                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NFSD_V3_ACL                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_RPCSEC_GSS_KRB5                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SUNRPC_DEBUG                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SUNRPC_XPRT_RDMA                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CEPH_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CEPH_FSCACHE                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CEPH_FS_POSIX_ACL                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CODA_FS                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_AFS_FS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_AFS_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_AFS_FSCACHE                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: File systems >> Network File Systems >> CIFS support (advanced network filesystem, SMBFS successor)
++CONFIG_CIFS                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CIFS_STATS                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CIFS_STATS2                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_CIFS_WEAK_PW_HASH                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CIFS_UPCALL                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CIFS_XATTR                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CIFS_POSIX                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CIFS_ACL                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CIFS_DEBUG                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CIFS_DEBUG2                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_CIFS_DFS_UPCALL                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CIFS_SMB2                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CIFS_SMB311                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CIFS_FSCACHE                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: File systems >> Network File Systems >> NCP file system support (to mount NetWare volumes)
++CONFIG_NCP_FS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_NCPFS_PACKET_SIGNING                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_NCPFS_IOCTL_LOCKING                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_NCPFS_STRONG                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_NCPFS_NFS_NS                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_NCPFS_OS2_NS                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_NCPFS_SMALLDOS                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_NCPFS_NLS                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_NCPFS_EXTRAS                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: File systems >> Network File Systems >> NFS client support
++CONFIG_NFS_FS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFS_V2                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFS_V3                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFS_V3_ACL                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NFS_V4                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFS_SWAP                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NFS_FSCACHE                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NFS_USE_LEGACY_DNS                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: File systems >> Network File Systems >> NFS client support >> NFS client support for NFSv4.1
++CONFIG_NFS_V4_1                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NFS_V4_2                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NFS_V4_1_IMPLEMENTATION_ID_DOMAIN        policy<{'amd64': '"kernel.org"', 'arm64': '"kernel.org"', 'armhf': '"kernel.org"', 'i386': '"kernel.org"', 'powerpc': '"kernel.org"', 'ppc64el': '"kernel.org"', 's390x': '"kernel.org"'}>
++CONFIG_NFS_V4_1_MIGRATION                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: File systems >> Network File Systems >> NFS server support for NFS version 4
++CONFIG_NFSD_V4                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NFSD_PNFS                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NFSD_V4_SECURITY_LABEL                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NFSD_FAULT_INJECTION                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: File systems >> Network File Systems >> Plan 9 Resource Sharing Support (9P2000)
++CONFIG_9P_FS                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_9P_FSCACHE                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_9P_FS_POSIX_ACL                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_9P_FS_SECURITY                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: File systems >> OCFS2 file system support
++CONFIG_OCFS2_FS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_OCFS2_FS_O2CB                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_OCFS2_FS_USERSPACE_CLUSTER               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_OCFS2_FS_STATS                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_OCFS2_DEBUG_MASKLOG                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_OCFS2_DEBUG_FS                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: File systems >> Pseudo filesystems
++CONFIG_PROC_CHILDREN                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SYSFS                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TMPFS                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TMPFS_POSIX_ACL                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TMPFS_XATTR                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_HUGETLBFS                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf-generic-lpae': 'y', 'i386': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CONFIGFS_FS                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'y'}>
++CONFIG_EFIVAR_FS                                policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++#
++CONFIG_CONFIGFS_FS                              flag<REVIEW>
++CONFIG_EFIVAR_FS                                note<needed for variable EFI update>
++CONFIG_TMPFS_POSIX_ACL                          mark<ENFORCED> note<some /dev nodes require POSIX ACLs, like /dev/dsp>
++
++# Menu: File systems >> Pseudo filesystems >> /proc file system support
++CONFIG_PROC_FS                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PROC_KCORE                               policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PROC_VMCORE                              policy<{'amd64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PROC_SYSCTL                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PROC_PAGE_MONITOR                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: File systems >> Quota support
++CONFIG_QUOTA                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PRINT_QUOTA_WARNING                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_QUOTA_DEBUG                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_QFMT_V1                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_QFMT_V2                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: File systems >> Reiserfs support
++CONFIG_REISERFS_FS                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_REISERFS_CHECK                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_REISERFS_PROC_INFO                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_REISERFS_FS_XATTR                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_REISERFS_FS_POSIX_ACL                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_REISERFS_FS_SECURITY                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: File systems >> The Extended 4 (ext4) filesystem
++CONFIG_EXT4_FS                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_EXT4_USE_FOR_EXT2                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_EXT4_FS_POSIX_ACL                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_EXT4_FS_SECURITY                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_EXT4_ENCRYPTION                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_EXT4_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: File systems >> XFS filesystem support
++CONFIG_XFS_FS                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_XFS_QUOTA                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_XFS_POSIX_ACL                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_XFS_RT                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_XFS_WARN                                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_XFS_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Firmware Drivers
++CONFIG_EDD                                      policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_EDD_OFF                                  policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_FIRMWARE_MEMMAP                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y'}>
++CONFIG_DELL_RBU                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_DCDBAS                                   policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_DMIID                                    policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_DMI_SYSFS                                policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_ISCSI_IBFT_FIND                          policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ISCSI_IBFT                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_GOOGLE_FIRMWARE                          policy<{'amd64': 'n', 'i386': 'n'}>
++
++# Menu: Firmware Drivers >> EFI (Extensible Firmware Interface) Support
++CONFIG_EFI_VARS                                 policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_EFI_VARS_PSTORE                          policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE          policy<{'amd64': 'n', 'arm64': 'n', 'i386': 'n'}>
++CONFIG_EFI_RUNTIME_MAP                          policy<{'amd64': 'y', 'i386': 'y'}>
++#
++CONFIG_EFI_VARS                                 mark<ENFORCED> note<EFI boot requirement (d-i) LP:#837332>
++
++# Menu: Firmware Drivers >> Google Firmware Drivers
++
++# Menu: Floating point emulation >> Architecture: arm
++CONFIG_VFP                                      policy<{'armhf': 'y'}>
++CONFIG_NEON                                     policy<{'armhf': 'y'}>
++CONFIG_KERNEL_MODE_NEON                         policy<{'arm64': 'y', 'armhf': 'y'}>
++
++# Menu: General setup
++CONFIG_CROSS_COMPILE                            policy<{'amd64': '""', 'arm64': '""', 'armhf': '""', 'i386': '""', 'powerpc': '""', 'ppc64el': '""', 's390x': '""'}>
++CONFIG_COMPILE_TEST                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_LOCALVERSION                             policy<{'amd64': '""', 'arm64': '""', 'armhf': '""', 'i386': '""', 'powerpc': '""', 'ppc64el': '""', 's390x': '""'}>
++CONFIG_LOCALVERSION_AUTO                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEFAULT_HOSTNAME                         policy<{'amd64': '"(none)"', 'arm64': '"(none)"', 'armhf': '"(none)"', 'i386': '"(none)"', 'powerpc': '"(none)"', 'ppc64el': '"(none)"', 's390x': '"(none)"'}>
++CONFIG_VERSION_SIGNATURE                        policy<{'amd64': '""', 'arm64': '""', 'armhf': '""', 'i386': '""', 'powerpc': '""', 'ppc64el': '""', 's390x': '""'}>
++CONFIG_SWAP                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SYSVIPC                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_POSIX_MQUEUE                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CROSS_MEMORY_ATTACH                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FHANDLE                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_USELIB                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_AUDIT                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_AUDITSYSCALL                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IKCONFIG                                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_LOG_BUF_SHIFT                            policy<{'amd64': '18', 'arm64': '14', 'armhf': '17', 'i386': '17', 'powerpc': '17', 'ppc64el': '17', 's390x': '17'}>
++CONFIG_LOG_CPU_MAX_BUF_SHIFT                    policy<{'amd64': '12', 'arm64': '12', 'armhf': '12', 'i386': '12', 'powerpc': '12', 'ppc64el': '12', 's390x': '12'}>
++CONFIG_NUMA_BALANCING                           policy<{'amd64': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_NUMA_BALANCING_DEFAULT_ENABLED           policy<{'amd64': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_CHECKPOINT_RESTORE                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SCHED_AUTOGROUP                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SYSFS_DEPRECATED                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_RELAY                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CC_OPTIMIZE_FOR_SIZE                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_BPF_SYSCALL                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_USERFAULTFD                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_EMBEDDED                                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_COMPAT_BRK                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SLUB_CPU_PARTIAL                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PROFILING                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_OPROFILE                                 policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_OPROFILE_EVENT_MULTIPLEX                 policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_KPROBES                                  policy<{'amd64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_JUMP_LABEL                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'n', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_STATIC_KEYS_SELFTEST                     policy<{'amd64': 'n', 'arm64': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_FHANDLE                                  mark<ENFORCED> note<LP:1412543>
++CONFIG_SYSFS_DEPRECATED                         mark<ENFORCED> note<ensure nothing is using these deprecated interfaces>
++CONFIG_COMPAT_BRK                               mark<ENFORCED> note<disables brk ASLR>
++CONFIG_LOCALVERSION_AUTO                        mark<ENFORCED> note<triggers packaging failures>
++CONFIG_JUMP_LABEL                               flag<REVIEW>
++CONFIG_NUMA_BALANCING_DEFAULT_ENABLE            note<LP:1557690>
++
++# Menu: General setup >> CPU/Task time and stats accounting
++CONFIG_BSD_PROCESS_ACCT                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BSD_PROCESS_ACCT_V3                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TASKSTATS                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TASK_DELAY_ACCT                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TASK_XACCT                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TASK_IO_ACCOUNTING                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: General setup >> CPU/Task time and stats accounting >> Cputime accounting
++CONFIG_TICK_CPU_ACCOUNTING                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_VIRT_CPU_ACCOUNTING_NATIVE               policy<{'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc64-smp': 'n', 'ppc64el': 'n', 's390x': 'y'}>
++CONFIG_VIRT_CPU_ACCOUNTING_GEN                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'powerpc-powerpc64-smp': 'n', 'ppc64el': 'n'}>
++CONFIG_IRQ_TIME_ACCOUNTING                      policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n'}>
++
++# Menu: General setup >> Choose SLAB allocator
++CONFIG_SLAB                                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SLUB                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SLOB                                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: General setup >> Configure standard kernel features (expert users)
++CONFIG_EXPERT                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_UID16                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y'}>
++CONFIG_MULTIUSER                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SGETMASK_SYSCALL                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SYSFS_SYSCALL                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SYSCTL_SYSCALL                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_KALLSYMS                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_KALLSYMS_ALL                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PRINTK                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BUG                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ELF_CORE                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PCSPKR_PLATFORM                          policy<{'amd64': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_BASE_FULL                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FUTEX                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_EPOLL                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SIGNALFD                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TIMERFD                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_EVENTFD                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SHMEM                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_AIO                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ADVISE_SYSCALLS                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PCI_QUIRKS                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_MEMBARRIER                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_VM_EVENT_COUNTERS                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SLUB_DEBUG                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: General setup >> Control Group support
++CONFIG_CGROUPS                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CGROUP_DEBUG                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_CGROUP_FREEZER                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CGROUP_PIDS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CGROUP_DEVICE                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CPUSETS                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PROC_PID_CPUSET                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CGROUP_CPUACCT                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MEMCG                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MEMCG_SWAP                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MEMCG_SWAP_ENABLED                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_MEMCG_KMEM                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CGROUP_HUGETLB                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf-generic-lpae': 'y', 'i386': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CGROUP_PERF                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_CGROUP                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEBUG_BLK_CGROUP                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_DEBUG_BLK_CGROUP                         mark<DEBUG>
++
++# Menu: General setup >> Control Group support >> Group CPU scheduler
++CONFIG_CGROUP_SCHED                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FAIR_GROUP_SCHED                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CFS_BANDWIDTH                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_RT_GROUP_SCHED                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_RT_GROUP_SCHED                           note<LP#1284731>
++
++# Menu: General setup >> GCOV-based kernel profiling
++CONFIG_GCOV_KERNEL                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: General setup >> GCOV-based kernel profiling >> Specify GCOV format
++
++# Menu: General setup >> IRQ subsystem
++CONFIG_IRQ_DOMAIN_DEBUG                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_IRQ_FORCED_THREADING_DEFAULT             policy<{'amd64-generic': 'n', 'amd64-lowlatency': 'y', 'arm64': 'n', 'armhf': 'n', 'i386-generic': 'n', 'i386-lowlatency': 'y', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_SPARSE_IRQ                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: General setup >> Initial RAM filesystem and RAM disk (initramfs/initrd) support
++CONFIG_BLK_DEV_INITRD                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_INITRAMFS_SOURCE                         policy<{'amd64': '""', 'arm64': '""', 'armhf': '""', 'i386': '""', 'powerpc': '""', 'ppc64el': '""', 's390x': '""'}>
++CONFIG_RD_GZIP                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_RD_BZIP2                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_RD_LZMA                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_RD_XZ                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_RD_LZO                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_RD_LZ4                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: General setup >> Kernel Performance Events And Counters
++CONFIG_PERF_EVENTS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEBUG_PERF_USE_VMALLOC                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 's390x': 'n'}>
++
++# Menu: General setup >> Kernel compression mode
++CONFIG_KERNEL_GZIP                              policy<{'amd64': 'y', 'armhf': 'y', 'i386': 'y', 's390x': 'n'}>
++CONFIG_KERNEL_BZIP2                             policy<{'amd64': 'n', 'i386': 'n', 's390x': 'n'}>
++CONFIG_KERNEL_LZMA                              policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n', 's390x': 'n'}>
++CONFIG_KERNEL_XZ                                policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n', 's390x': 'y'}>
++CONFIG_KERNEL_LZO                               policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n', 's390x': 'n'}>
++CONFIG_KERNEL_LZ4                               policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n', 's390x': 'n'}>
++#
++CONFIG_KERNEL_GZIP                              flag<REVIEW> note<does s390x care the format here?>
++
++# Menu: General setup >> Namespaces support
++CONFIG_NAMESPACES                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_UTS_NS                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IPC_NS                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_USER_NS                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PID_NS                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_NS                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: General setup >> RCU Subsystem
++# XXX
++#
++CONFIG_CONTEXT_TRACKING_FORCE                   note<LP:1349028>
++
++# Menu: General setup >> RCU Subsystem >> Make expert-level adjustments to RCU configuration
++CONFIG_RCU_NOCB_CPU                             policy<{'amd64': 'y', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_RCU_EXPERT                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_RCU_EXPERT                               flag<REVIEW>
++
++# Menu: General setup >> RCU Subsystem >> Make expert-level adjustments to RCU configuration >> Build-forced no-CBs CPUs
++CONFIG_RCU_NOCB_CPU_NONE                        policy<{'amd64': 'n', 'powerpc-powerpc64-smp': 'n'}>
++CONFIG_RCU_NOCB_CPU_ZERO                        policy<{'amd64': 'n', 'powerpc-powerpc64-smp': 'n'}>
++CONFIG_RCU_NOCB_CPU_ALL                         policy<{'amd64': 'y', 'powerpc-powerpc64-smp': 'y'}>
++
++# Menu: General setup >> Stack Protector buffer overflow detection
++CONFIG_CC_STACKPROTECTOR_NONE                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n'}>
++CONFIG_CC_STACKPROTECTOR_REGULAR                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n'}>
++CONFIG_CC_STACKPROTECTOR_STRONG                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y'}>
++#
++CONFIG_CC_STACKPROTECTOR_STRONG			mark<ENFORCED>
++
++# Menu: General setup >> Stack Protector buffer overflow detection >> Architecture: arm
++
++# Menu: General setup >> Stack Protector buffer overflow detection >> Architecture: powerpc
++
++# Menu: General setup >> Stack Protector buffer overflow detection >> Architecture: s390
++
++# Menu: General setup >> Stack Protector buffer overflow detection >> Architecture: x86
++
++# Menu: General setup >> Timers subsystem
++CONFIG_NO_HZ                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_HIGH_RES_TIMERS                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: General setup >> Timers subsystem >> Timer tick handling
++CONFIG_HZ_PERIODIC                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_NO_HZ_IDLE                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NO_HZ_FULL                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'powerpc-powerpc64-smp': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_NO_HZ_IDLE                               note<LP:1413968>
++
++# Menu: Kernel hacking
++CONFIG_MAGIC_SYSRQ                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PANIC_ON_OOPS                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_PANIC_TIMEOUT                            policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '10', 's390x': '0'}>
++CONFIG_DEBUG_TIMEKEEPING                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_STACKTRACE                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PROVIDE_OHCI1394_DMA_INIT                policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_DMA_API_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_TEST_LKM                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TEST_USER_COPY                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TEST_BPF                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TEST_FIRMWARE                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TEST_UDELAY                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MEMTEST                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TEST_STATIC_KEYS                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_STRICT_DEVMEM                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_EARLY_PRINTK                             policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_DEBUG_RODATA                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y'}>
++CONFIG_DEBUG_SET_MODULE_RONX                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 's390x': 'y'}>
++#
++CONFIG_PANIC_ON_OOPS                            note<keep working if at all possible>
++CONFIG_STRICT_DEVMEM                            mark<ENFORCED>
++CONFIG_DEBUG_RODATA                             mark<ENFORCED>
++CONFIG_DEBUG_SET_MODULE_RONX                    mark<ENFORCED>
++
++# Menu: Kernel hacking >> Architecture: arm
++CONFIG_ARM_PTDUMP                               policy<{'armhf': 'n'}>
++CONFIG_ARM_UNWIND                               policy<{'armhf': 'y'}>
++CONFIG_DEBUG_USER                               policy<{'armhf': 'n'}>
++CONFIG_DEBUG_LL                                 policy<{'armhf': 'n'}>
++CONFIG_DEBUG_IMX_UART_PORT                      policy<{'armhf-generic': '1'}>
++CONFIG_DEBUG_VF_UART_PORT                       policy<{'armhf-generic': '1'}>
++CONFIG_ARM_KPROBES_TEST                         policy<{'armhf': 'm'}>
++CONFIG_PID_IN_CONTEXTIDR                        policy<{'arm64': 'n', 'armhf': 'n'}>
++
++# Menu: Kernel hacking >> Architecture: powerpc
++CONFIG_PPC_DISABLE_WERROR                       policy<{'powerpc': 'y', 'ppc64el': 'n'}>
++CONFIG_STRICT_MM_TYPECHECKS                     policy<{'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_PRINT_STACK_DEPTH                        policy<{'powerpc': '64', 'ppc64el': '64'}>
++CONFIG_HCALL_STATS                              policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'n'}>
++CONFIG_PPC_EMULATED_STATS                       policy<{'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CODE_PATCHING_SELFTEST                   policy<{'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_FTR_FIXUP_SELFTEST                       policy<{'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MSI_BITMAP_SELFTEST                      policy<{'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_XMON                                     policy<{'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_XMON_DEFAULT                             policy<{'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_XMON_DISASSEMBLY                         policy<{'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BDI_SWITCH                               policy<{'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_BOOTX_TEXT                               policy<{'powerpc-powerpc64-smp': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'n'}>
++CONFIG_PPC_EARLY_DEBUG                          policy<{'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_PPC_DISABLE_WERROR                       flag<REVIEW>
++
++# Menu: Kernel hacking >> Architecture: s390
++CONFIG_S390_PTDUMP                              policy<{'s390x': 'y'}>
++
++# Menu: Kernel hacking >> Architecture: x86
++CONFIG_X86_VERBOSE_BOOTUP                       policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_EARLY_PRINTK_DBGP                        policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_EARLY_PRINTK_EFI                         policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_PTDUMP                               policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_DEBUG_RODATA_TEST                        policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_DEBUG_NX_TEST                            policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_DOUBLEFAULT                              policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_DEBUG_TLBFLUSH                           policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_IOMMU_DEBUG                              policy<{'amd64': 'n'}>
++CONFIG_IOMMU_STRESS                             policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_X86_DECODER_SELFTEST                     policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_DEBUG_BOOT_PARAMS                        policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_CPA_DEBUG                                policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_OPTIMIZE_INLINING                        policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_DEBUG_ENTRY                              policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_DEBUG_NMI_SELFTEST                       policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_X86_DEBUG_STATIC_CPU_HAS                 policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_X86_DEBUG_FPU                            policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_PUNIT_ATOM_DEBUG                         policy<{'amd64': 'm', 'i386': 'm'}>
++#
++CONFIG_DEBUG_NX_TEST                            flag<TESTING>
++CONFIG_X86_DECODER_SELFTEST                     flag<TESTING>
++CONFIG_X86_DEBUG_FPU                            flag<REVIEW>
++CONFIG_PUNIT_ATOM_DEBUG                         flag<REVIEW>
++
++# Menu: Kernel hacking >> Compile-time checks and compiler options
++CONFIG_ENABLE_WARN_DEPRECATED                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_ENABLE_MUST_CHECK                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_FRAME_WARN                               policy<{'amd64': '1024', 'arm64': '1024', 'armhf': '1024', 'i386': '1024', 'powerpc': '1024', 'ppc64el': '2048', 's390x': '1024'}>
++CONFIG_STRIP_ASM_SYMS                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_READABLE_ASM                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_UNUSED_SYMBOLS                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PAGE_OWNER                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_FS                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_HEADERS_CHECK                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_SECTION_MISMATCH                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_FRAME_POINTER                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y'}>
++CONFIG_DEBUG_FORCE_WEAK_PER_CPU                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++
++# Menu: Kernel hacking >> Compile-time checks and compiler options >> Compile the kernel with debug info
++CONFIG_DEBUG_INFO                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEBUG_INFO_REDUCED                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_INFO_SPLIT                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_INFO_DWARF4                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_GDB_SCRIPTS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_DEBUG_INFO                               mark<ENFORCED> note<required for debug packages>
++CONFIG_DEBUG_INFO_SPLIT                         note<LP:1413646 and LP:1413664>
++
++# Menu: Kernel hacking >> CoreSight Tracing Support
++CONFIG_CORESIGHT                                policy<{'arm64': 'n', 'armhf': 'n'}>
++
++# Menu: Kernel hacking >> CoreSight Tracing Support >> CoreSight Link and Sink drivers
++
++# Menu: Kernel hacking >> Debug Lockups and Hangs
++CONFIG_LOCKUP_DETECTOR                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BOOTPARAM_HARDLOCKUP_PANIC               policy<{'amd64': 'n', 'i386': 'n', 'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc64-smp': 'n', 'ppc64el': 'n'}>
++CONFIG_BOOTPARAM_SOFTLOCKUP_PANIC               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_DETECT_HUNG_TASK                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEFAULT_HUNG_TASK_TIMEOUT                policy<{'amd64': '120', 'arm64': '120', 'armhf': '120', 'i386': '120', 'powerpc': '120', 'ppc64el': '120', 's390x': '120'}>
++CONFIG_BOOTPARAM_HUNG_TASK_PANIC                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Kernel hacking >> Early debugging console >> Architecture: powerpc
++
++# Menu: Kernel hacking >> IO delay type >> Architecture: x86
++CONFIG_IO_DELAY_0X80                            policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_IO_DELAY_0XED                            policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_IO_DELAY_UDELAY                          policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_IO_DELAY_NONE                            policy<{'amd64': 'n', 'i386': 'n'}>
++
++# Menu: Kernel hacking >> Kernel debugging
++CONFIG_DEBUG_KERNEL                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEBUG_SHIRQ                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SCHED_DEBUG                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SCHEDSTATS                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SCHED_STACK_END_CHECK                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TIMER_STATS                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEBUG_PREEMPT                            policy<{'amd64-lowlatency': 'n', 'i386-lowlatency': 'n'}>
++CONFIG_DEBUG_KOBJECT                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_BUGVERBOSE                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEBUG_LIST                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_PI_LIST                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_SG                                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_NOTIFIERS                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_CREDENTIALS                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_BLOCK_EXT_DEVT                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_LATENCYTOP                               policy<{'amd64': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_STRICT_USER_COPY_CHECKS            policy<{'amd64': 'n', 'i386': 'n', 's390x': 'n'}>
++#
++CONFIG_LATENCYTOP                               note<https://lists.ubuntu.com/archives/kernel-team/2014-July/045726.html>
++
++# Menu: Kernel hacking >> Kernel debugging >> Fault-injection framework
++CONFIG_FAULT_INJECTION                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Kernel hacking >> Kernel debugging >> KGDB: kernel debugger
++CONFIG_KGDB                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_KGDB_SERIAL_CONSOLE                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_KGDB_TESTS                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_KGDB_LOW_LEVEL_TRAP                      policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_KGDB_KDB                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_KDB_KEYBOARD                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_KDB_CONTINUE_CATASTROPHIC                policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++#
++CONFIG_KGDB                                     flag<REVIEW>
++CONFIG_KGDB_SERIAL_CONSOLE                      note<early debugging support>
++
++# Menu: Kernel hacking >> Kernel debugging >> Notifier error injection
++CONFIG_NOTIFIER_ERROR_INJECTION                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CPU_NOTIFIER_ERROR_INJECT                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc-powerpc64-smp': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_PM_NOTIFIER_ERROR_INJECT                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_OF_RECONFIG_NOTIFIER_ERROR_INJECT        policy<{'arm64': 'n', 'armhf': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Kernel hacking >> Kernel low-level debugging port >> Architecture: arm
++
++# Menu: Kernel hacking >> Lock Debugging (spinlocks, mutexes, etc...)
++CONFIG_DEBUG_RT_MUTEXES                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_SPINLOCK                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_MUTEXES                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_WW_MUTEX_SLOWPATH                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_LOCK_ALLOC                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_PROVE_LOCKING                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_LOCK_STAT                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_ATOMIC_SLEEP                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_LOCKING_API_SELFTESTS              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_LOCK_TORTURE_TEST                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Kernel hacking >> Memory Debugging
++CONFIG_PAGE_EXTENSION                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_PAGEALLOC                          policy<{'amd64': 'n', 'arm64': 'n', 'i386': 'n', 'powerpc-powerpc64-emb': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SLUB_DEBUG_ON                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SLUB_STATS                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_STACK_USAGE                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_VM                                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_VIRTUAL                            policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_DEBUG_MEMORY_INIT                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_MEMORY_NOTIFIER_ERROR_INJECT             policy<{'amd64': 'm', 'i386': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DEBUG_PER_CPU_MAPS                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEBUG_HIGHMEM                            policy<{'armhf': 'n', 'i386': 'n', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_DEBUG_STACKOVERFLOW                      policy<{'amd64': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_KASAN                                    policy<{'amd64': 'n'}>
++
++# Menu: Kernel hacking >> Memory Debugging >> Debug object operations
++CONFIG_DEBUG_OBJECTS                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Kernel hacking >> Memory Debugging >> Instrumentation type
++
++# Menu: Kernel hacking >> Memory Debugging >> Kernel memory leak detector
++CONFIG_DEBUG_KMEMLEAK                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Kernel hacking >> Memory Debugging >> kmemcheck: trap use of uninitialized memory
++
++# Menu: Kernel hacking >> Memory Debugging >> kmemcheck: trap use of uninitialized memory >> kmemcheck: default mode at boot
++
++# Menu: Kernel hacking >> RCU Debugging
++CONFIG_SPARSE_RCU_POINTER                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_RCU_CPU_STALL_TIMEOUT                    policy<{'amd64': '60', 'arm64': '60', 'armhf': '60', 'i386': '60', 'powerpc': '21', 'ppc64el': '21', 's390x': '21'}>
++CONFIG_RCU_TRACE                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_RCU_EQS_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_RCU_CPU_STALL_TIMEOUT                    flag<REVIEW>
++
++# Menu: Kernel hacking >> RCU Debugging >> torture tests for RCU
++CONFIG_RCU_TORTURE_TEST                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Kernel hacking >> Runtime Testing
++CONFIG_LKDTM                                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_TEST_LIST_SORT                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_KPROBES_SANITY_TEST                      policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_BACKTRACE_SELF_TEST                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_RBTREE_TEST                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INTERVAL_TREE_TEST                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_PERCPU_TEST                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_ATOMIC64_SELFTEST                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_ASYNC_RAID6_TEST                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TEST_HEXDUMP                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TEST_STRING_HELPERS                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TEST_KSTRTOX                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TEST_RHASHTABLE                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_LKDTM                                    flag<TESTING> flag<REVIEW>
++CONFIG_TEST_LIST_SORT                           flag<TESTING>
++CONFIG_KPROBES_SANITY_TEST                      flag<TESTING>
++CONFIG_BACKTRACE_SELF_TEST                      flag<TESTING>
++CONFIG_ATOMIC64_SELFTEST                        flag<TESTING>
++CONFIG_TEST_RHASHTABLE                          flag<TESTING>
++
++# Menu: Kernel hacking >> Sample kernel code
++CONFIG_SAMPLES                                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Kernel hacking >> Tracers
++CONFIG_FTRACE                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IRQSOFF_TRACER                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_PREEMPT_TRACER                           policy<{'amd64-lowlatency': 'n', 'i386-lowlatency': 'n'}>
++CONFIG_SCHED_TRACER                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FTRACE_SYSCALLS                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TRACER_SNAPSHOT                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TRACER_SNAPSHOT_PER_CPU_SWAP             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_STACK_TRACER                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BLK_DEV_IO_TRACE                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_KPROBE_EVENT                             policy<{'amd64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_UPROBE_EVENT                             policy<{'amd64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FTRACE_STARTUP_TEST                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_MMIOTRACE                                policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_MMIOTRACE_TEST                           policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_TRACEPOINT_BENCHMARK                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_RING_BUFFER_BENCHMARK                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_RING_BUFFER_STARTUP_TEST                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_TRACE_ENUM_MAP_FILE                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_FTRACE_STARTUP_TEST                      flag<TESTING>
++CONFIG_MMIOTRACE_TEST                           flag<TESTING>
++CONFIG_RING_BUFFER_BENCHMARK                    flag<TESTING>
++CONFIG_RING_BUFFER_STARTUP_TEST                 flag<TESTING>
++
++# Menu: Kernel hacking >> Tracers >> Branch Profiling
++CONFIG_BRANCH_PROFILE_NONE                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PROFILE_ANNOTATED_BRANCHES               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_PROFILE_ALL_BRANCHES                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Kernel hacking >> Tracers >> Kernel Function Tracer
++CONFIG_FUNCTION_TRACER                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FUNCTION_GRAPH_TRACER                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DYNAMIC_FTRACE                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FUNCTION_PROFILER                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Kernel hacking >> printk and dmesg options
++CONFIG_PRINTK_TIME                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MESSAGE_LOGLEVEL_DEFAULT                 policy<{'amd64': '4', 'arm64': '4', 'armhf': '4', 'i386': '4', 'powerpc': '4', 'ppc64el': '4', 's390x': '4'}>
++CONFIG_BOOT_PRINTK_DELAY                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y'}>
++CONFIG_DYNAMIC_DEBUG                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Library routines
++CONFIG_CRC_CCITT                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRC16                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRC_T10DIF                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRC_ITU_T                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRC32                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRC32_SELFTEST                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_CRC7                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_LIBCRC32C                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CRC8                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_RANDOM32_SELFTEST                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_GLOB_SELFTEST                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CORDIC                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_DDR                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Library routines >> CRC32 implementation
++CONFIG_CRC32_SLICEBY8                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CRC32_SLICEBY4                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_CRC32_SARWATE                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_CRC32_BIT                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Library routines >> Select compiled-in fonts
++CONFIG_FONTS                                    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'y', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_FONT_8x8                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FONT_8x16                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_FONT_6x11                                policy<{'armhf': 'n'}>
++CONFIG_FONT_7x14                                policy<{'armhf': 'n'}>
++CONFIG_FONT_PEARL_8x8                           policy<{'armhf': 'n'}>
++CONFIG_FONT_ACORN_8x8                           policy<{'armhf': 'y'}>
++CONFIG_FONT_MINI_4x6                            policy<{'armhf': 'n'}>
++CONFIG_FONT_6x10                                policy<{'armhf': 'y'}>
++CONFIG_FONT_SUN8x16                             policy<{'armhf': 'n'}>
++CONFIG_FONT_SUN12x22                            policy<{'armhf': 'n'}>
++CONFIG_FONT_10x18                               policy<{'armhf': 'n'}>
++
++# Menu: Library routines >> XZ decompression support
++CONFIG_XZ_DEC                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_XZ_DEC_X86                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_XZ_DEC_POWERPC                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_XZ_DEC_IA64                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_XZ_DEC_ARM                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_XZ_DEC_ARMTHUMB                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_XZ_DEC_SPARC                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_XZ_DEC_TEST                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++#
++CONFIG_XZ_DEC                                   note<boot essential -- initramfs decompressor> flag<REVIEW>
++
++# Menu: Networking support
++CONFIG_NET                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_AF_RXRPC                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_AF_RXRPC_DEBUG                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_RXKAD                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CEPH_LIB                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CEPH_LIB_PRETTYDEBUG                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_CEPH_LIB_USE_DNS_RESOLVER                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_LWTUNNEL                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Networking support >> Amateur Radio support
++CONFIG_HAMRADIO                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Networking support >> Amateur Radio support >> Amateur Radio AX.25 Level 2 protocol
++CONFIG_AX25                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_AX25_DAMA_SLAVE                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_NETROM                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ROSE                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> Amateur Radio support >> Amateur Radio AX.25 Level 2 protocol >> AX.25 network device drivers
++CONFIG_MKISS                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_6PACK                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BPQETHER                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SCC                                      policy<{'i386': 'm'}>
++CONFIG_SCC_DELAY                                policy<{'i386': 'n'}>
++CONFIG_SCC_TRXECHO                              policy<{'i386': 'n'}>
++CONFIG_BAYCOM_SER_FDX                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BAYCOM_SER_HDX                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BAYCOM_PAR                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BAYCOM_EPP                               policy<{'armhf': 'm', 'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_YAM                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> Bluetooth subsystem support
++CONFIG_BT                                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_LE                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_6LOWPAN                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_SELFTEST                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_BT_DEBUGFS                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Networking support >> Bluetooth subsystem support >> Bluetooth Classic (BR/EDR) features
++CONFIG_BT_BREDR                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_RFCOMM                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_RFCOMM_TTY                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_BNEP                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_BNEP_MC_FILTER                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_BNEP_PROTO_FILTER                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_CMTP                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_HIDP                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_HS                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Networking support >> Bluetooth subsystem support >> Bluetooth device drivers
++CONFIG_BT_HCIBTSDIO                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_HCIBCM203X                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_HCIBPA10X                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_HCIBFUSB                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_HCIDTL1                               policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_BT_HCIBT3C                               policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_BT_HCIBLUECARD                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_BT_HCIBTUART                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_BT_HCIVHCI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_MRVL                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_MRVL_SDIO                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_WILINK                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> Bluetooth subsystem support >> Bluetooth device drivers >> HCI UART driver
++CONFIG_BT_HCIUART                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_HCIUART_H4                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_HCIUART_BCSP                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_HCIUART_ATH3K                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_HCIUART_LL                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_HCIUART_3WIRE                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_HCIUART_INTEL                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_HCIUART_BCM                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_HCIUART_QCA                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Networking support >> Bluetooth subsystem support >> Bluetooth device drivers >> HCI USB driver
++CONFIG_BT_HCIBTUSB                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_BT_HCIBTUSB_BCM                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_HCIBTUSB_RTL                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BT_ATH3K                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> CAIF support
++CONFIG_CAIF                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_CAIF_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CAIF_NETDEV                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAIF_USB                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> CAN bus subsystem support
++CONFIG_CAN                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_CAN_RAW                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_BCM                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_GW                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> CAN bus subsystem support >> CAN Device Drivers
++CONFIG_CAN_VCAN                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_SLCAN                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_DEBUG_DEVICES                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Networking support >> CAN bus subsystem support >> CAN Device Drivers >> Platform CAN drivers with Netlink support
++CONFIG_CAN_DEV                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_CALC_BITTIMING                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CAN_LEDS                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CAN_TI_HECC                              policy<{'armhf': 'm'}>
++CONFIG_CAN_JANZ_ICAN3                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_FLEXCAN                              policy<{'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_PCH_CAN                                  policy<{'i386': 'm'}>
++CONFIG_CAN_GRCAN                                policy<{'arm64': 'm', 'armhf': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_RCAR                                 policy<{'armhf': 'm'}>
++CONFIG_CAN_XILINXCAN                            policy<{'arm64': 'm'}>
++CONFIG_CAN_MSCAN                                policy<{'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_M_CAN                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_SOFTING                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_SOFTING_CS                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++
++# Menu: Networking support >> CAN bus subsystem support >> CAN Device Drivers >> Platform CAN drivers with Netlink support >> Bosch CC770 and Intel AN82527 devices
++CONFIG_CAN_CC770                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_CC770_ISA                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_CC770_PLATFORM                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> CAN bus subsystem support >> CAN Device Drivers >> Platform CAN drivers with Netlink support >> Bosch C_CAN/D_CAN devices
++CONFIG_CAN_C_CAN                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_C_CAN_PLATFORM                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_C_CAN_PCI                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> CAN bus subsystem support >> CAN Device Drivers >> Platform CAN drivers with Netlink support >> CAN SPI interfaces
++CONFIG_CAN_MCP251X                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> CAN bus subsystem support >> CAN Device Drivers >> Platform CAN drivers with Netlink support >> CAN USB interfaces
++CONFIG_CAN_EMS_USB                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_ESD_USB2                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_GS_USB                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_KVASER_USB                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_PEAK_USB                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_8DEV_USB                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> CAN bus subsystem support >> CAN Device Drivers >> Platform CAN drivers with Netlink support >> Philips/NXP SJA1000 devices
++CONFIG_CAN_SJA1000                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_SJA1000_ISA                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_SJA1000_PLATFORM                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_EMS_PCMCIA                           policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_CAN_EMS_PCI                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_PEAK_PCMCIA                          policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm'}>
++CONFIG_CAN_PEAK_PCI                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_PEAK_PCIEC                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CAN_KVASER_PCI                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_PLX_PCI                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_CAN_TSCAN1                               policy<{'i386': 'm'}>
++
++# Menu: Networking support >> IrDA (infrared) subsystem support
++CONFIG_IRDA                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IRLAN                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IRNET                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IRCOMM                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IRDA_ULTRA                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IRDA_CACHE_LAST_LSAP                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IRDA_FAST_RR                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_IRDA_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Networking support >> IrDA (infrared) subsystem support >> Infrared-port device drivers
++CONFIG_IRTTY_SIR                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KINGSUN_DONGLE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KSDAZZLE_DONGLE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_KS959_DONGLE                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_USB_IRDA                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SIGMATEL_FIR                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NSC_FIR                                  policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_WINBOND_FIR                              policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOSHIBA_FIR                              policy<{'i386': 'm', 'powerpc-powerpc-e500mc': 'm', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_SMC_IRCC_FIR                             policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ALI_FIR                                  policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VLSI_FIR                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_VIA_FIR                                  policy<{'amd64': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MCS_FIR                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_SH_IRDA                                  policy<{'armhf': 'm'}>
++
++# Menu: Networking support >> IrDA (infrared) subsystem support >> Infrared-port device drivers >> Blackfin SIR on UART
++
++# Menu: Networking support >> IrDA (infrared) subsystem support >> Infrared-port device drivers >> Blackfin SIR on UART >> SIR Mode
++
++# Menu: Networking support >> IrDA (infrared) subsystem support >> Infrared-port device drivers >> Serial dongle support
++CONFIG_DONGLE                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_ESI_DONGLE                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ACTISYS_DONGLE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TEKRAM_DONGLE                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_TOIM3232_DONGLE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LITELINK_DONGLE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MA600_DONGLE                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_GIRBIL_DONGLE                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MCP2120_DONGLE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_OLD_BELKIN_DONGLE                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ACT200L_DONGLE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> NFC subsystem support
++CONFIG_NFC                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_NFC_DIGITAL                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_NCI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_NCI_SPI                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_NFC_NCI_UART                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_HCI                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_SHDLC                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Networking support >> NFC subsystem support >> Near Field Communication (NFC) devices
++CONFIG_NFC_PN533                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_WILINK                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_TRF7970A                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_MEI_PHY                              policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_NFC_SIM                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_PORT100                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_PN544                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_PN544_I2C                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_PN544_MEI                            policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_NFC_MICROREAD                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_MICROREAD_I2C                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_MICROREAD_MEI                        policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_NFC_MRVL                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_MRVL_USB                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_MRVL_UART                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_ST21NFCA                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_ST21NFCA_I2C                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_ST_NCI                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_ST_NCI_I2C                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_ST_NCI_SPI                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_NXP_NCI                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_NXP_NCI_I2C                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NFC_S3FWRN5_I2C                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> Networking options
++CONFIG_PACKET                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PACKET_DIAG                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_UNIX                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_UNIX_DIAG                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_XFRM_USER                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_XFRM_SUB_POLICY                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_XFRM_MIGRATE                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_XFRM_STATISTICS                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_KEY                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_KEY_MIGRATE                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_IUCV                                     policy<{'s390x': 'y'}>
++CONFIG_AFIUCV                                   policy<{'s390x': 'm'}>
++CONFIG_NETWORK_SECMARK                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NETWORK_PHY_TIMESTAMPING                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_BRIDGE                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_IGMP_SNOOPING                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BRIDGE_VLAN_FILTERING                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_VLAN_8021Q                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_VLAN_8021Q_GVRP                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_VLAN_8021Q_MVRP                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DECNET                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_DECNET_ROUTER                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_LLC2                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_IPX                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_IPX_INTERN                               policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATALK                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_X25                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_LAPB                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_PHONET                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_MAC802154                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_DCB                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DNS_RESOLVER                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_VSOCKETS                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_VMWARE_VMCI_VSOCKETS                     policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_NETLINK_MMAP                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NETLINK_DIAG                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_HSR                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_CGROUP_NET_PRIO                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CGROUP_NET_CLASSID                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BPF_JIT                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Networking support >> Networking options >> 6LoWPAN Support
++CONFIG_6LOWPAN                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++
++# Menu: Networking support >> Networking options >> 6LoWPAN Support >> Next Header Compression Support
++CONFIG_6LOWPAN_NHC                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_6LOWPAN_NHC_DEST                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_6LOWPAN_NHC_FRAGMENT                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_6LOWPAN_NHC_HOP                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_6LOWPAN_NHC_IPV6                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_6LOWPAN_NHC_MOBILITY                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_6LOWPAN_NHC_ROUTING                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_6LOWPAN_NHC_UDP                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> Networking options >> Appletalk interfaces support
++CONFIG_DEV_APPLETALK                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_LTPC                                     policy<{'i386': 'm'}>
++CONFIG_COPS                                     policy<{'i386': 'm'}>
++CONFIG_COPS_DAYNA                               policy<{'i386': 'y'}>
++CONFIG_COPS_TANGENT                             policy<{'i386': 'y'}>
++CONFIG_IPDDP                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IPDDP_ENCAP                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Networking support >> Networking options >> Asynchronous Transfer Mode (ATM)
++CONFIG_ATM                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_ATM_CLIP                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_CLIP_NO_ICMP                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_ATM_LANE                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_MPOA                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_BR2684                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_ATM_BR2684_IPFILTER                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Networking support >> Networking options >> B.A.T.M.A.N. Advanced Meshing Protocol
++CONFIG_BATMAN_ADV                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_BATMAN_ADV_BLA                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BATMAN_ADV_DAT                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BATMAN_ADV_NC                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BATMAN_ADV_MCAST                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_BATMAN_ADV_DEBUG                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Networking support >> Networking options >> IEEE Std 802.15.4 Low-Rate Wireless Personal Area Networks support
++CONFIG_IEEE802154                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_IEEE802154_SOCKET                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_IEEE802154_6LOWPAN                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> Networking options >> MultiProtocol Label Switching
++CONFIG_MPLS                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_MPLS_GSO                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MPLS_ROUTING                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_MPLS_IPTUNNEL                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter)
++CONFIG_NETFILTER                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NETFILTER_DEBUG                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_NETFILTER_ADVANCED                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BRIDGE_NETFILTER                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> Core Netfilter Configuration
++CONFIG_NETFILTER_INGRESS                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NETFILTER_NETLINK_ACCT                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_NETLINK_QUEUE                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_NETLINK_LOG                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> Core Netfilter Configuration >> Netfilter Xtables support (required for ip_tables)
++CONFIG_NETFILTER_XTABLES                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MARK                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_CONNMARK                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_SET                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_AUDIT                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_CHECKSUM             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_CLASSIFY             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_CONNMARK             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_CONNSECMARK          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_CT                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_DSCP                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_HL                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_HMARK                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_IDLETIMER            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_LED                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_LOG                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_MARK                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_NAT                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_NETMAP               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_NFLOG                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_NFQUEUE              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_NOTRACK              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_NETFILTER_XT_TARGET_RATEEST              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_REDIRECT             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_TEE                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_TPROXY               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_TRACE                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_SECMARK              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_TCPMSS               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_TARGET_TCPOPTSTRIP          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_ADDRTYPE              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_BPF                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_CGROUP                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_CLUSTER               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_COMMENT               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_CONNBYTES             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_CONNLABEL             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_CONNLIMIT             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_CONNMARK              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_CONNTRACK             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_CPU                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_DCCP                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_DEVGROUP              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_DSCP                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_ECN                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_ESP                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_HASHLIMIT             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_HELPER                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_HL                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_IPCOMP                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_IPRANGE               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_IPVS                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_L2TP                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_LENGTH                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_LIMIT                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_MAC                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_MARK                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_MULTIPORT             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_NFACCT                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_OSF                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_OWNER                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_POLICY                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_PHYSDEV               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_PKTTYPE               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_QUOTA                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_RATEEST               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_REALM                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_RECENT                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_SCTP                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_SOCKET                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_STATE                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_STATISTIC             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_STRING                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_TCPMSS                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_TIME                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_XT_MATCH_U32                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> Core Netfilter Configuration >> Netfilter connection tracking support
++CONFIG_NF_CONNTRACK                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CONNTRACK_MARK                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NF_CONNTRACK_SECMARK                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NF_CONNTRACK_ZONES                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NF_CONNTRACK_PROCFS                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_NF_CONNTRACK_EVENTS                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NF_CONNTRACK_TIMEOUT                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NF_CONNTRACK_TIMESTAMP                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NF_CT_PROTO_DCCP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CT_PROTO_SCTP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CT_PROTO_UDPLITE                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CONNTRACK_AMANDA                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CONNTRACK_FTP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CONNTRACK_H323                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CONNTRACK_IRC                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CONNTRACK_NETBIOS_NS                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CONNTRACK_SNMP                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CONNTRACK_PPTP                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CONNTRACK_SANE                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CONNTRACK_SIP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CONNTRACK_TFTP                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CT_NETLINK                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CT_NETLINK_TIMEOUT                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_CT_NETLINK_HELPER                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NETFILTER_NETLINK_QUEUE_CT               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NF_NAT_REDIRECT                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++#
++CONFIG_NF_CONNTRACK_PROCFS                      flag<DEPRECATED>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> Core Netfilter Configuration >> Netfilter nf_tables support
++CONFIG_NF_TABLES                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_TABLES_INET                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_TABLES_NETDEV                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_EXTHDR                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_META                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_CT                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_RBTREE                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_HASH                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_COUNTER                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_LOG                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_LIMIT                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_MASQ                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_REDIR                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_NAT                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_QUEUE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_REJECT                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_COMPAT                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> DECnet: Netfilter Configuration
++CONFIG_DECNET_NF_GRABULATOR                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> Ethernet Bridge nf_tables support
++CONFIG_NF_TABLES_BRIDGE                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_BRIDGE_META                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_BRIDGE_REJECT                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_LOG_BRIDGE                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> Ethernet Bridge tables (ebtables) support
++CONFIG_BRIDGE_NF_EBTABLES                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_BROUTE                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_T_FILTER                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_T_NAT                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_802_3                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_AMONG                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_ARP                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_IP                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_IP6                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_LIMIT                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_MARK                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_PKTTYPE                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_STP                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_VLAN                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_ARPREPLY                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_DNAT                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_MARK_T                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_REDIRECT                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_SNAT                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_LOG                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_BRIDGE_EBT_NFLOG                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IP set support
++CONFIG_IP_SET                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_MAX                               policy<{'amd64': '256', 'arm64': '256', 'armhf': '256', 'i386': '256', 'powerpc': '256', 'ppc64el': '256', 's390x': '256'}>
++CONFIG_IP_SET_BITMAP_IP                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_BITMAP_IPMAC                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_BITMAP_PORT                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_HASH_IP                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_HASH_IPMARK                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_HASH_IPPORT                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_HASH_IPPORTIP                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_HASH_IPPORTNET                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_HASH_MAC                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_HASH_NETPORTNET                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_HASH_NET                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_HASH_NETNET                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_HASH_NETPORT                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_HASH_NETIFACE                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_SET_LIST_SET                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IP virtual server support
++CONFIG_IP_VS                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_IPV6                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_VS_DEBUG                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_IP_VS_TAB_BITS                           policy<{'amd64': '12', 'arm64': '12', 'armhf': '12', 'i386': '12', 'powerpc': '12', 'ppc64el': '12', 's390x': '12'}>
++CONFIG_IP_VS_PROTO_TCP                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_VS_PROTO_UDP                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_VS_PROTO_ESP                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_VS_PROTO_AH                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_VS_PROTO_SCTP                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_VS_RR                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_WRR                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_LC                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_WLC                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_FO                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_OVF                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_LBLC                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_LBLCR                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_DH                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_SH                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_SED                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_NQ                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_SH_TAB_BITS                        policy<{'amd64': '8', 'arm64': '8', 'armhf': '8', 'i386': '8', 'powerpc': '8', 'ppc64el': '8', 's390x': '8'}>
++CONFIG_IP_VS_FTP                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_VS_NFCT                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_VS_PE_SIP                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IP: Netfilter Configuration
++CONFIG_NF_CONNTRACK_IPV4                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_TABLES_IPV4                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_CHAIN_ROUTE_IPV4                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_DUP_IPV4                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_TABLES_ARP                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_DUP_IPV4                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_LOG_ARP                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_LOG_IPV4                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_REJECT_IPV4                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_ARPTABLES                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_ARPFILTER                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_ARP_MANGLE                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IP: Netfilter Configuration >> IP tables support (required for filtering/masq/NAT)
++CONFIG_IP_NF_IPTABLES                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_MATCH_AH                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_MATCH_ECN                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_MATCH_RPFILTER                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_MATCH_TTL                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_FILTER                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_TARGET_REJECT                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_TARGET_SYNPROXY                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_RAW                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_SECURITY                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IP: Netfilter Configuration >> IP tables support (required for filtering/masq/NAT) >> Packet mangling
++CONFIG_IP_NF_MANGLE                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_TARGET_CLUSTERIP                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_TARGET_ECN                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_TARGET_TTL                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IP: Netfilter Configuration >> IP tables support (required for filtering/masq/NAT) >> iptables NAT support
++CONFIG_IP_NF_NAT                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_TARGET_MASQUERADE                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_TARGET_NETMAP                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP_NF_TARGET_REDIRECT                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IP: Netfilter Configuration >> IPv4 NAT
++CONFIG_NF_NAT_IPV4                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_CHAIN_NAT_IPV4                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_NAT_MASQUERADE_IPV4                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_MASQ_IPV4                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_REDIR_IPV4                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_NAT_SNMP_BASIC                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IPv6: Netfilter Configuration
++CONFIG_NF_CONNTRACK_IPV6                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_TABLES_IPV6                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_CHAIN_ROUTE_IPV6                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_DUP_IPV6                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_DUP_IPV6                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_REJECT_IPV6                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_LOG_IPV6                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IPv6: Netfilter Configuration >> IP6 tables support (required for filtering)
++CONFIG_IP6_NF_IPTABLES                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_MATCH_AH                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_MATCH_EUI64                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_MATCH_FRAG                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_MATCH_OPTS                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_MATCH_HL                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_MATCH_IPV6HEADER                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_MATCH_MH                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_MATCH_RPFILTER                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_MATCH_RT                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_TARGET_HL                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_FILTER                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_TARGET_REJECT                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_TARGET_SYNPROXY                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_MANGLE                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_RAW                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_SECURITY                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_NAT                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_TARGET_MASQUERADE                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IP6_NF_TARGET_NPT                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IPv6: Netfilter Configuration >> IPv6 NAT
++CONFIG_NF_NAT_IPV6                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_CHAIN_NAT_IPV6                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NF_NAT_MASQUERADE_IPV6                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_MASQ_IPV6                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NFT_REDIR_IPV6                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> Network testing
++CONFIG_NET_PKTGEN                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_TCPPROBE                             policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_DROP_MONITOR                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++#
++CONFIG_NET_DROP_MONITOR				note<LP #1660634>
++
++# Menu: Networking support >> Networking options >> QoS and/or fair queueing
++CONFIG_NET_SCHED                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_SCH_CBQ                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_HTB                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_HFSC                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_ATM                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_SCH_PRIO                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_MULTIQ                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_RED                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_SFB                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_SFQ                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_TEQL                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_TBF                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_GRED                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_DSMARK                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_NETEM                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_DRR                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_MQPRIO                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_CHOKE                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_QFQ                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_CODEL                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_FQ_CODEL                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_FQ                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_HHF                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_PIE                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_INGRESS                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCH_PLUG                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_CLS_BASIC                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_CLS_TCINDEX                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_CLS_ROUTE4                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_CLS_FW                               policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_CLS_RSVP                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_CLS_RSVP6                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_CLS_FLOW                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_CLS_CGROUP                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_CLS_BPF                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_CLS_FLOWER                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> QoS and/or fair queueing >> Actions
++CONFIG_NET_CLS_ACT                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_ACT_POLICE                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_ACT_GACT                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_GACT_PROB                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_ACT_MIRRED                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_ACT_IPT                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_ACT_NAT                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_ACT_PEDIT                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_ACT_SIMP                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_ACT_SKBEDIT                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_ACT_CSUM                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_ACT_VLAN                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_ACT_BPF                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_ACT_CONNMARK                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> QoS and/or fair queueing >> Extended Matches
++CONFIG_NET_EMATCH                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_EMATCH_STACK                         policy<{'amd64': '32', 'arm64': '32', 'armhf': '32', 'i386': '32', 'powerpc': '32', 'ppc64el': '32', 's390x': '32'}>
++CONFIG_NET_EMATCH_CMP                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_EMATCH_NBYTE                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_EMATCH_U32                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_EMATCH_META                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_EMATCH_TEXT                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_EMATCH_CANID                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NET_EMATCH_IPSET                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> QoS and/or fair queueing >> Universal 32bit comparisons w/ hashing (U32)
++CONFIG_NET_CLS_U32                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_CLS_U32_PERF                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_CLS_U32_MARK                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_CLS_IND                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_NET_CLS_IND                              flag<DEPRECATED>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking
++CONFIG_INET                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_MULTICAST                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_IPIP                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_IPGRE_DEMUX                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_IPGRE                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_IPGRE_BROADCAST                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SYN_COOKIES                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_IPVTI                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_FOU                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_FOU_IP_TUNNELS                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_INET_AH                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET_ESP                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET_IPCOMP                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET_XFRM_MODE_TRANSPORT                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET_XFRM_MODE_TUNNEL                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET_XFRM_MODE_BEET                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET_LRO                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_INET_DIAG                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET_UDP_DIAG                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_MD5SIG                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NETLABEL                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NET_SWITCHDEV                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_SYN_COOKIES                              mark<ENFORCED>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> IP: advanced router
++CONFIG_IP_ADVANCED_ROUTER                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_FIB_TRIE_STATS                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_MULTIPLE_TABLES                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_ROUTE_MULTIPATH                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_ROUTE_VERBOSE                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> IP: kernel level autoconfiguration
++CONFIG_IP_PNP                                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_IP_PNP					note<LP:1259861>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> IP: multicast routing
++CONFIG_IP_MROUTE                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_MROUTE_MULTIPLE_TABLES                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_IP_PIMSM_V1                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IP_PIMSM_V2                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> Layer Two Tunneling Protocol (L2TP)
++CONFIG_L2TP                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_L2TP_DEBUGFS                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_L2TP_V3                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_L2TP_IP                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_L2TP_ETH                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> Open vSwitch
++CONFIG_OPENVSWITCH                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_OPENVSWITCH_GRE                          policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_OPENVSWITCH_VXLAN                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_OPENVSWITCH_GENEVE                       policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> TCP: advanced congestion control
++CONFIG_TCP_CONG_ADVANCED                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TCP_CONG_BIC                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_CUBIC                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TCP_CONG_WESTWOOD                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_HTCP                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_HSTCP                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_HYBLA                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_VEGAS                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_SCALABLE                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_LP                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_VENO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_YEAH                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_ILLINOIS                        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_DCTCP                           policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TCP_CONG_CDG                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> TCP: advanced congestion control >> Default TCP congestion control
++CONFIG_DEFAULT_CUBIC                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEFAULT_RENO                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> The DCCP Protocol
++CONFIG_IP_DCCP                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> The DCCP Protocol >> DCCP CCIDs Configuration
++CONFIG_IP_DCCP_CCID2_DEBUG                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_IP_DCCP_CCID3                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'y'}>
++CONFIG_IP_DCCP_CCID3_DEBUG                      policy<{'s390x': 'n'}>
++#
++CONFIG_IP_DCCP_CCID3                            flag<REVIEW>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> The DCCP Protocol >> DCCP Kernel Hacking
++CONFIG_IP_DCCP_DEBUG                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_NET_DCCPPROBE                            policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> The IPv6 protocol
++CONFIG_IPV6                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IPV6_ROUTER_PREF                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IPV6_ROUTE_INFO                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IPV6_OPTIMISTIC_DAD                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_INET6_AH                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET6_ESP                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET6_IPCOMP                             policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IPV6_MIP6                                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IPV6_ILA                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET6_XFRM_MODE_TRANSPORT                policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET6_XFRM_MODE_TUNNEL                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET6_XFRM_MODE_BEET                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_INET6_XFRM_MODE_ROUTEOPTIMIZATION        policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IPV6_VTI                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IPV6_SIT                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IPV6_SIT_6RD                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IPV6_TUNNEL                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IPV6_GRE                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_IPV6_MULTIPLE_TABLES                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IPV6_SUBTREES                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IPV6_MROUTE                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IPV6_MROUTE_MULTIPLE_TABLES              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IPV6_PIMSM_V2                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_IPV6_OPTIMISTIC_DAD                      flag<EXPERIMENTAL>
++CONFIG_IPV6                                     mark<ENFORCED> note<if this is a module we get a module load for every ipv6 packet>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> The RDS Protocol
++CONFIG_RDS                                      policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_RDS_RDMA                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_RDS_TCP                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_RDS_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> The SCTP Protocol
++CONFIG_IP_SCTP                                  policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_SCTPPROBE                            policy<{'amd64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_SCTP_DBG_OBJCNT                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SCTP_COOKIE_HMAC_MD5                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SCTP_COOKIE_HMAC_SHA1                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_SCTP_DBG_OBJCNT                          flag<DEBUG>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> The SCTP Protocol >> Default SCTP cookie HMAC encoding
++CONFIG_SCTP_DEFAULT_COOKIE_HMAC_MD5             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SCTP_DEFAULT_COOKIE_HMAC_SHA1            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SCTP_DEFAULT_COOKIE_HMAC_NONE            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Networking support >> Networking options >> TCP/IP networking >> The TIPC Protocol
++CONFIG_TIPC                                     policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_TIPC_MEDIA_IB                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TIPC_MEDIA_UDP                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Networking support >> Plan 9 Resource Sharing Support (9P2000)
++CONFIG_NET_9P                                   policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_9P_VIRTIO                            policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_9P_RDMA                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'm'}>
++CONFIG_NET_9P_DEBUG                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_NET_9P                                   note<LP:1557994>
++
++# Menu: Networking support >> RF switch subsystem support
++CONFIG_RFKILL                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_RFKILL_INPUT                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_RFKILL_REGULATOR                         policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_RFKILL_GPIO                              policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++
++# Menu: Networking support >> WiMAX Wireless Broadband support
++CONFIG_WIMAX                                    policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm', 's390x': 'n'}>
++CONFIG_WIMAX_DEBUG_LEVEL                        policy<{'amd64': '8', 'arm64': '8', 'armhf': '8', 'i386': '8', 'powerpc': '8', 'ppc64el': '8'}>
++
++# Menu: Networking support >> Wireless
++CONFIG_WIRELESS                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_LIB80211_DEBUG                           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++
++# Menu: Networking support >> Wireless >> Generic IEEE 802.11 Networking Stack (mac80211)
++CONFIG_MAC80211                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_MAC80211_RC_MINSTREL                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MAC80211_RC_MINSTREL_HT                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MAC80211_RC_MINSTREL_VHT                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MAC80211_MESH                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MAC80211_LEDS                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MAC80211_DEBUGFS                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_MAC80211_MESSAGE_TRACING                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Networking support >> Wireless >> Generic IEEE 802.11 Networking Stack (mac80211) >> Default rate control algorithm
++CONFIG_MAC80211_RC_DEFAULT_MINSTREL             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Networking support >> Wireless >> Generic IEEE 802.11 Networking Stack (mac80211) >> Select mac80211 debugging features
++CONFIG_MAC80211_DEBUG_MENU                      policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_MAC80211_STA_HASH_MAX_SIZE               policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++
++# Menu: Networking support >> Wireless >> cfg80211 - wireless configuration API
++CONFIG_CFG80211                                 policy<{'amd64': 'm', 'arm64': 'm', 'armhf': 'm', 'i386': 'm', 'powerpc': 'm', 'ppc64el': 'm'}>
++CONFIG_NL80211_TESTMODE                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CFG80211_DEVELOPER_WARNINGS              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CFG80211_REG_DEBUG                       policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CFG80211_CERTIFICATION_ONUS              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CFG80211_DEFAULT_PS                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CFG80211_DEBUGFS                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CFG80211_INTERNAL_REGDB                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CFG80211_WEXT                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++#
++CONFIG_CFG80211_WEXT                            flag<REVIEW>
++
++# Menu: Power management and ACPI options
++CONFIG_SUSPEND                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_SUSPEND_FREEZER                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_HIBERNATION                              policy<{'amd64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'n', 's390x': 'y'}>
++CONFIG_PM_STD_PARTITION                         policy<{'amd64': '""', 'armhf': '""', 'i386': '""', 'powerpc-powerpc64-smp': '""', 'powerpc-powerpc-e500mc': '""', 'powerpc-powerpc-smp': '""', 's390x': '""'}>
++CONFIG_PM_AUTOSLEEP                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc-powerpc64-smp': 'n', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_PM_WAKELOCKS                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_PM_WAKELOCKS_LIMIT                       policy<{'amd64': '100', 'arm64': '100', 'armhf': '100', 'i386': '100', 'powerpc-powerpc64-smp': '100', 'powerpc-powerpc-e500mc': '100', 'powerpc-powerpc-smp': '100', 'ppc64el': '100'}>
++CONFIG_PM_WAKELOCKS_GC                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_PM_TRACE_RTC                             policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_KVM_GUEST                                policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_SFI                                      policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_INTEL_IDLE                               policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_SUSPEND_SKIP_SYNC                        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc-powerpc64-smp': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_HIBERNATION                              flag<REVIEW>
++
++# Menu: Power management and ACPI options >> 512x-based boards >> Architecture: powerpc
++CONFIG_PPC_MPC512x                              policy<{'powerpc-powerpc-smp': 'n'}>
++
++# Menu: Power management and ACPI options >> 52xx-based boards >> Architecture: powerpc
++CONFIG_PPC_MPC52xx                              policy<{'powerpc-powerpc-smp': 'n'}>
++
++# Menu: Power management and ACPI options >> 82xx-based boards (PQ II) >> Architecture: powerpc
++CONFIG_PPC_82xx                                 policy<{'powerpc-powerpc-smp': 'n'}>
++
++# Menu: Power management and ACPI options >> 83xx-based boards >> Architecture: powerpc
++CONFIG_PPC_83xx                                 policy<{'powerpc-powerpc-smp': 'n'}>
++
++# Menu: Power management and ACPI options >> 86xx-based boards >> Architecture: powerpc
++CONFIG_PPC_86xx                                 policy<{'powerpc-powerpc-smp': 'n'}>
++
++# Menu: Power management and ACPI options >> 8xx Machine Type >> Architecture: powerpc
++
++# Menu: Power management and ACPI options >> ACPI (Advanced Configuration and Power Interface) Support
++CONFIG_ACPI                                     policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_PROCFS_POWER                        policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_ACPI_REV_OVERRIDE_POSSIBLE               policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_EC_DEBUGFS                          policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_ACPI_AC                                  policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_BATTERY                             policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_BUTTON                              policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_VIDEO                               policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ACPI_FAN                                 policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_DOCK                                policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_PROCESSOR                           policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_IPMI                                policy<{'amd64': 'm', 'arm64': 'm', 'i386': 'm'}>
++CONFIG_ACPI_PROCESSOR_AGGREGATOR                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ACPI_THERMAL                             policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_NUMA                                policy<{'amd64': 'y'}>
++CONFIG_ACPI_CUSTOM_DSDT_FILE                    policy<{'amd64': '""', 'i386': '""'}>
++CONFIG_ACPI_INITRD_TABLE_OVERRIDE               policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_ACPI_DEBUG                               policy<{'amd64': 'n', 'arm64': 'n', 'i386': 'n'}>
++CONFIG_ACPI_PCI_SLOT                            policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_X86_PM_TIMER                             policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_CONTAINER                           policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_HOTPLUG_MEMORY                      policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_SBS                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ACPI_HED                                 policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_CUSTOM_METHOD                       policy<{'amd64': 'n', 'arm64': 'n', 'i386': 'n'}>
++CONFIG_ACPI_BGRT                                policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_REDUCED_HARDWARE_ONLY               policy<{'amd64': 'n', 'arm64': 'y', 'i386': 'n'}>
++CONFIG_ACPI_NFIT                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ACPI_NFIT_DEBUG                          policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_ACPI_EXTLOG                              policy<{'amd64': 'm', 'i386': 'm'}>
++#
++CONFIG_ACPI_PROCFS_POWER                        mark<DEPRECATED>
++CONFIG_ACPI_CUSTOM_METHOD                       mark<ENFORCED> note<SECURITY: allows arbitrary execution>
++CONFIG_ACPI_CUSTOM_DSDT_FILE                    note<might allow hardware damage>
++
++# Menu: Power management and ACPI options >> ACPI (Advanced Configuration and Power Interface) Support >> ACPI Platform Error Interface (APEI)
++CONFIG_ACPI_APEI                                policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_APEI_GHES                           policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_APEI_PCIEAER                        policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ACPI_APEI_MEMORY_FAILURE                 policy<{'amd64': 'y'}>
++CONFIG_ACPI_APEI_EINJ                           policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_ACPI_APEI_ERST_DEBUG                     policy<{'amd64': 'n', 'i386': 'n'}>
++
++# Menu: Power management and ACPI options >> ACPI (Advanced Configuration and Power Interface) Support >> PMIC (Power Management Integrated Circuit) operation region support
++CONFIG_PMIC_OPREGION                            policy<{'amd64': 'n', 'arm64': 'n', 'i386': 'n'}>
++
++# Menu: Power management and ACPI options >> APM (Advanced Power Management) BIOS support >> Architecture: x86
++CONFIG_APM                                      policy<{'i386': 'm'}>
++CONFIG_APM_IGNORE_USER_SUSPEND                  policy<{'i386': 'n'}>
++CONFIG_APM_DO_ENABLE                            policy<{'i386': 'n'}>
++CONFIG_APM_CPU_IDLE                             policy<{'i386': 'n'}>
++CONFIG_APM_DISPLAY_BLANK                        policy<{'i386': 'n'}>
++CONFIG_APM_ALLOW_INTS                           policy<{'i386': 'n'}>
++#
++CONFIG_APM                                      flag<REVIEW>
++
++# Menu: Power management and ACPI options >> Architecture: arm
++
++# Menu: Power management and ACPI options >> Architecture: powerpc
++CONFIG_PPC_POWERNV                              policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_OPAL_PRD                                 policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_PPC_CHRP                                 policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_PPC_PMAC                                 policy<{'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'n'}>
++CONFIG_PPC_PMAC32_PSURGE                        policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_PPC_MAPLE                                policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'n'}>
++CONFIG_PPC_PASEMI                               policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'n'}>
++CONFIG_PPC_PS3                                  policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'n'}>
++CONFIG_PPC_IBM_CELL_BLADE                       policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'n'}>
++CONFIG_PPC_CELL_QPACE                           policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'n'}>
++CONFIG_EPAPR_PARAVIRT                           policy<{'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PPC_OF_BOOT_TRAMPOLINE                   policy<{'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_UDBG_RTAS_CONSOLE                        policy<{'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'n'}>
++CONFIG_MPIC_TIMER                               policy<{'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_MPIC_MSGR                                policy<{'powerpc': 'y', 'ppc64el': 'n'}>
++CONFIG_RTAS_PROC                                policy<{'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_RTAS_FLASH                               policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_IBMEBUS                                  policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'y'}>
++CONFIG_PPC601_SYNC_FIX                          policy<{'powerpc-powerpc-smp': 'n'}>
++CONFIG_TAU                                      policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_TAU_INT                                  policy<{'powerpc-powerpc-smp': 'n'}>
++CONFIG_TAU_AVERAGE                              policy<{'powerpc-powerpc-smp': 'n'}>
++CONFIG_QUICC_ENGINE                             policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_CPM2                                     policy<{'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_SIMPLE_GPIO                              policy<{'powerpc': 'y', 'ppc64el': 'n'}>
++
++# Menu: Power management and ACPI options >> Architecture: s390
++
++# Menu: Power management and ACPI options >> Architecture: x86
++
++# Menu: Power management and ACPI options >> CPU Frequency scaling
++
++# Menu: Power management and ACPI options >> CPU Frequency scaling >> CPU Frequency scaling
++CONFIG_CPU_FREQ                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CPU_FREQ_STAT                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CPU_FREQ_STAT_DETAILS                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CPU_FREQ_GOV_PERFORMANCE                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CPU_FREQ_GOV_POWERSAVE                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CPU_FREQ_GOV_USERSPACE                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CPU_FREQ_GOV_ONDEMAND                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CPU_FREQ_GOV_CONSERVATIVE                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_X86_INTEL_PSTATE                         policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_PCC_CPUFREQ                          policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_SFI_CPUFREQ                          policy<{'i386': 'm'}>
++CONFIG_X86_POWERNOW_K6                          policy<{'i386': 'm'}>
++CONFIG_X86_POWERNOW_K7                          policy<{'i386': 'm'}>
++CONFIG_X86_GX_SUSPMOD                           policy<{'i386': 'm'}>
++CONFIG_X86_SPEEDSTEP_CENTRINO                   policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_SPEEDSTEP_CENTRINO_TABLE             policy<{'i386': 'y'}>
++CONFIG_X86_SPEEDSTEP_ICH                        policy<{'i386': 'y'}>
++CONFIG_X86_SPEEDSTEP_SMI                        policy<{'i386': 'y'}>
++CONFIG_X86_P4_CLOCKMOD                          policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_X86_CPUFREQ_NFORCE2                      policy<{'i386': 'y'}>
++CONFIG_X86_LONGRUN                              policy<{'i386': 'm'}>
++CONFIG_X86_LONGHAUL                             policy<{'i386': 'm'}>
++CONFIG_X86_E_POWERSAVER                         policy<{'i386': 'n'}>
++CONFIG_X86_SPEEDSTEP_RELAXED_CAP_CHECK          policy<{'i386': 'y'}>
++CONFIG_ARM_BIG_LITTLE_CPUFREQ                   policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_ARM_DT_BL_CPUFREQ                        policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_ARM_VEXPRESS_SPC_CPUFREQ                 policy<{'armhf': 'm'}>
++CONFIG_ARM_EXYNOS5440_CPUFREQ                   policy<{'armhf': 'n'}>
++CONFIG_ARM_IMX6Q_CPUFREQ                        policy<{'armhf-generic': 'm'}>
++CONFIG_ARM_MT8173_CPUFREQ                       policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_ARM_OMAP2PLUS_CPUFREQ                    policy<{'armhf': 'y'}>
++CONFIG_ARM_TEGRA20_CPUFREQ                      policy<{'armhf-generic': 'y'}>
++CONFIG_CPU_FREQ_MAPLE                           policy<{'powerpc-powerpc64-smp': 'y'}>
++CONFIG_CPU_FREQ_PMAC                            policy<{'powerpc-powerpc-smp': 'y'}>
++CONFIG_CPU_FREQ_PMAC64                          policy<{'powerpc-powerpc64-smp': 'y'}>
++CONFIG_PPC_PASEMI_CPUFREQ                       policy<{'powerpc-powerpc64-smp': 'y'}>
++CONFIG_POWERNV_CPUFREQ                          policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_QORIQ_CPUFREQ                            policy<{'armhf': 'm', 'powerpc-powerpc64-emb': 'm', 'powerpc-powerpc-e500mc': 'm'}>
++#
++CONFIG_CPU_FREQ_STAT                            note<dependancy of boot essential>
++CONFIG_CPU_FREQ_GOV_PERFORMANCE                 note<not autoloadable>
++CONFIG_CPU_FREQ_GOV_POWERSAVE                   note<not autoloadable>
++CONFIG_CPU_FREQ_GOV_USERSPACE                   note<not autoloadable>
++CONFIG_CPU_FREQ_GOV_ONDEMAND                    note<not autoloadable>
++CONFIG_CPU_FREQ_GOV_CONSERVATIVE                note<not autoloadable>
++CONFIG_X86_PCC_CPUFREQ                          note<not autoloadable>
++CONFIG_X86_SPEEDSTEP_CENTRINO                   note<not autoloadable>
++CONFIG_X86_SPEEDSTEP_ICH                        note<not autoloadable>
++CONFIG_X86_SPEEDSTEP_SMI                        note<not autoloadable>
++CONFIG_X86_CPUFREQ_NFORCE2                      note<not autoloadable>
++
++# Menu: Power management and ACPI options >> CPU Frequency scaling >> CPU Frequency scaling >> ACPI Processor P-States driver
++CONFIG_X86_ACPI_CPUFREQ                         policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_ACPI_CPUFREQ_CPB                     policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_POWERNOW_K8                          policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_AMD_FREQ_SENSITIVITY                 policy<{'amd64': 'm', 'i386': 'm'}>
++#
++CONFIG_X86_ACPI_CPUFREQ                         note<not autoloadable>
++CONFIG_X86_POWERNOW_K8                          note<not autoloadable>
++
++# Menu: Power management and ACPI options >> CPU Frequency scaling >> CPU Frequency scaling >> CPUfreq driver for Samsung S3C24XX series CPUs (EXPERIMENTAL)
++
++# Menu: Power management and ACPI options >> CPU Frequency scaling >> CPU Frequency scaling >> Default CPUFreq governor
++CONFIG_CPU_FREQ_DEFAULT_GOV_PERFORMANCE         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CPU_FREQ_DEFAULT_GOV_POWERSAVE           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CPU_FREQ_DEFAULT_GOV_USERSPACE           policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CPU_FREQ_DEFAULT_GOV_CONSERVATIVE        policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_CPU_FREQ_DEFAULT_GOV_PERFORMANCE         note<for bootspeed>
++
++# Menu: Power management and ACPI options >> CPU Frequency scaling >> CPU Frequency scaling >> Generic DT based cpufreq driver
++CONFIG_CPUFREQ_DT                               policy<{'arm64': 'y', 'armhf': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_ARM_HIGHBANK_CPUFREQ                     policy<{'armhf': 'm'}>
++CONFIG_ARM_HISI_ACPU_CPUFREQ                    policy<{'arm64': 'm', 'armhf': 'm'}>
++CONFIG_ARM_TEGRA124_CPUFREQ                     policy<{'armhf-generic': 'm'}>
++#
++CONFIG_CPUFREQ_DT                               note<not autoloadable>
++
++# Menu: Power management and ACPI options >> CPU Idle
++
++# Menu: Power management and ACPI options >> CPU Idle >> CPU idle PM support
++CONFIG_CPU_IDLE                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CPU_IDLE_GOV_LADDER                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_CPU_IDLE_GOV_MENU                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++
++# Menu: Power management and ACPI options >> CPU Idle >> CPU idle PM support >> ARM CPU Idle Drivers
++CONFIG_ARM_CPUIDLE                              policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_ARM_BIG_LITTLE_CPUIDLE                   policy<{'armhf': 'y'}>
++CONFIG_ARM_HIGHBANK_CPUIDLE                     policy<{'armhf-generic': 'n', 'armhf-generic-lpae': 'y'}>
++CONFIG_ARM_EXYNOS_CPUIDLE                       policy<{'armhf': 'y'}>
++CONFIG_ARM_MVEBU_V7_CPUIDLE                     policy<{'armhf': 'y'}>
++#
++CONFIG_ARM_HIGHBANK_CPUIDLE                     note<broken on ecx-1000>
++
++# Menu: Power management and ACPI options >> CPU Idle >> CPU idle PM support >> MIPS CPU Idle Drivers
++
++# Menu: Power management and ACPI options >> CPU Idle >> CPU idle PM support >> POWERPC CPU Idle Drivers
++CONFIG_PSERIES_CPUIDLE                          policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_POWERNV_CPUIDLE                          policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++
++# Menu: Power management and ACPI options >> CPUIdle driver >> Architecture: powerpc
++
++# Menu: Power management and ACPI options >> CPUIdle driver >> CPU Idle
++
++# Menu: Power management and ACPI options >> CPUIdle driver >> CPU Idle >> CPU idle PM support
++
++# Menu: Power management and ACPI options >> CPUIdle driver >> CPU Idle >> CPU idle PM support >> ARM CPU Idle Drivers
++#
++
++# Menu: Power management and ACPI options >> CPUIdle driver >> CPU Idle >> CPU idle PM support >> MIPS CPU Idle Drivers
++
++# Menu: Power management and ACPI options >> CPUIdle driver >> CPU Idle >> CPU idle PM support >> POWERPC CPU Idle Drivers
++
++# Menu: Power management and ACPI options >> Cell Broadband Engine options >> Architecture: powerpc
++CONFIG_SPU_FS                                   policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_CBE_CPUFREQ_SPU_GOVERNOR                 policy<{'powerpc-powerpc64-smp': 'm'}>
++
++# Menu: Power management and ACPI options >> Device power management core functionality
++CONFIG_PM                                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_APM_EMULATION                            policy<{'armhf': 'n', 'powerpc-powerpc-smp': 'm'}>
++CONFIG_WQ_POWER_EFFICIENT_DEFAULT               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Power management and ACPI options >> Device power management core functionality >> Power Management Debug Support
++CONFIG_PM_DEBUG                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_PM_ADVANCED_DEBUG                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PM_TEST_SUSPEND                          policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc-powerpc64-smp': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'n'}>
++CONFIG_DPM_WATCHDOG                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++#
++CONFIG_PM_DEBUG                                 flag<REVIEW>
++
++# Menu: Power management and ACPI options >> Embedded 6xx/7xx/7xxx-based boards >> Architecture: powerpc
++
++# Menu: Power management and ACPI options >> Freescale Book-E Machine Type >> Architecture: powerpc
++CONFIG_FSL_SOC_BOOKE                            policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_BSC9131_RDB                              policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_C293_PCIE                                policy<{'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_BSC9132_QDS                              policy<{'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_MPC8540_ADS                              policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_MPC8560_ADS                              policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_MPC85xx_CDS                              policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_MPC85xx_MDS                              policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_MPC8536_DS                               policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_MPC85xx_DS                               policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_MPC85xx_RDB                              policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_P1010_RDB                                policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_P1022_DS                                 policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_P1022_RDK                                policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_P1023_RDB                                policy<{'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_TWR_P102x                                policy<{'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_SOCRATES                                 policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_KSI8560                                  policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_XES_MPC85xx                              policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_STX_GP3                                  policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_TQM8540                                  policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_TQM8541                                  policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_TQM8548                                  policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_TQM8555                                  policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_TQM8560                                  policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_SBC8548                                  policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_PPA8548                                  policy<{'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_GE_IMP3A                                 policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_SGY_CTS1000                              policy<{'powerpc-powerpc-e500mc': 'm'}>
++CONFIG_MVME2500                                 policy<{'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_PPC_QEMU_E500                            policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_CORENET_GENERIC                          policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++
++# Menu: Power management and ACPI options >> Freescale Ethernet driver platform-specific options >> Architecture: powerpc
++
++# Menu: Power management and ACPI options >> Freescale Ethernet driver platform-specific options >> Second Ethernet channel >> Architecture: powerpc
++
++# Menu: Power management and ACPI options >> IBM pSeries & new (POWER5-based) iSeries
++CONFIG_CMM                                      policy<{'ppc64el': 'm', 's390x': 'y'}>
++#
++CONFIG_CMM                                      flag<REVIEW>
++
++# Menu: Power management and ACPI options >> IBM pSeries & new (POWER5-based) iSeries >> Architecture: powerpc
++CONFIG_PPC_PSERIES                              policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_PPC_SPLPAR                               policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'y'}>
++CONFIG_DTL                                      policy<{'ppc64el': 'y'}>
++CONFIG_PSERIES_ENERGY                           policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_SCANLOG                                  policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_IO_EVENT_IRQ                             policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_LPARCFG                                  policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'y'}>
++CONFIG_PPC_SMLPAR                               policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'y'}>
++CONFIG_HV_PERF_CTRS                             policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++
++# Menu: Power management and ACPI options >> MPC8xx CPM Options >> Architecture: powerpc
++
++# Menu: Power management and ACPI options >> MPC8xx CPM Options >> Microcode patch selection >> Architecture: powerpc
++
++# Menu: Power management and ACPI options >> Memory power savings
++CONFIG_I7300_IDLE                               policy<{'amd64': 'm'}>
++
++# Menu: Power management and ACPI options >> PA Semi PWRficient options >> Architecture: powerpc
++CONFIG_PPC_PASEMI_IOMMU                         policy<{'powerpc-powerpc64-smp': 'y'}>
++CONFIG_PPC_PASEMI_IOMMU_DMA_FORCE               policy<{'powerpc-powerpc64-smp': 'n'}>
++CONFIG_PPC_PASEMI_MDIO                          policy<{'powerpc-powerpc64-smp': 'm'}>
++
++# Menu: Power management and ACPI options >> PS3 Platform Options >> Architecture: powerpc
++CONFIG_PS3_DYNAMIC_DMA                          policy<{'powerpc-powerpc64-smp': 'n'}>
++CONFIG_PS3_DISK                                 policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_PS3_ROM                                  policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_PS3_FLASH                                policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_PS3_VRAM                                 policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_PS3_LPM                                  policy<{'powerpc-powerpc64-smp': 'm'}>
++CONFIG_PS3GELIC_UDBG                            policy<{'powerpc-powerpc64-smp': 'n'}>
++
++# Menu: Power management and ACPI options >> PS3 Platform Options >> PS3 Advanced configuration options >> Architecture: powerpc
++CONFIG_PS3_ADVANCED                             policy<{'powerpc-powerpc64-smp': 'n'}>
++CONFIG_PS3_HTAB_SIZE                            policy<{'powerpc-powerpc64-smp': '20'}>
++CONFIG_PS3_PS3AV                                policy<{'powerpc-powerpc64-smp': 'y'}>
++CONFIG_PS3_SYS_MANAGER                          policy<{'powerpc-powerpc64-smp': 'y'}>
++CONFIG_PS3_REPOSITORY_WRITE                     policy<{'powerpc-powerpc64-smp': 'n'}>
++
++# Menu: Processor support
++CONFIG_SMP                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NR_CPUS                                  policy<{'amd64': '512', 'arm64': '128', 'armhf': '4', 'i386': '8', 'powerpc-powerpc64-emb': '8', 'powerpc-powerpc64-smp': '1024', 'powerpc-powerpc-e500mc': '8', 'powerpc-powerpc-smp': '4', 'ppc64el': '2048', 's390x': '256'}>
++
++# Menu: Processor support >> Architecture: powerpc
++CONFIG_TUNE_CELL                                policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'n'}>
++CONFIG_PPC_E500MC                               policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_FSL_EMB_PERFMON                          policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_PHYS_64BIT                               policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_ALTIVEC                                  policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_VSX                                      policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_PPC_ICSWX                                policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'n'}>
++CONFIG_PPC_ICSWX_PID                            policy<{'powerpc-powerpc64-smp': 'y'}>
++CONFIG_PPC_ICSWX_USE_SIGILL                     policy<{'powerpc-powerpc64-smp': 'n'}>
++#
++CONFIG_PPC_ICSWX                                flag<REVIEW>
++
++# Menu: Processor support >> CPU selection
++CONFIG_GENERIC_CPU                              policy<{'amd64': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y'}>
++
++# Menu: Processor support >> CPU selection >> Architecture: powerpc
++CONFIG_CELL_CPU                                 policy<{'powerpc-powerpc64-smp': 'n'}>
++CONFIG_POWER4_CPU                               policy<{'powerpc-powerpc64-smp': 'n'}>
++CONFIG_POWER5_CPU                               policy<{'powerpc-powerpc64-smp': 'n'}>
++CONFIG_POWER6_CPU                               policy<{'powerpc-powerpc64-smp': 'n'}>
++CONFIG_POWER7_CPU                               policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'y'}>
++CONFIG_POWER8_CPU                               policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'n'}>
++CONFIG_E5500_CPU                                policy<{'powerpc-powerpc64-emb': 'n'}>
++CONFIG_E6500_CPU                                policy<{'powerpc-powerpc64-emb': 'n'}>
++
++# Menu: Processor support >> Processor Type >> Architecture: powerpc
++CONFIG_PPC_BOOK3S_32                            policy<{'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_PPC_85xx                                 policy<{'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_PPC_8xx                                  policy<{'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_40x                                      policy<{'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_44x                                      policy<{'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_E200                                     policy<{'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n'}>
++CONFIG_PPC_BOOK3S_64                            policy<{'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_PPC_BOOK3E_64                            policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'n', 'ppc64el': 'n'}>
++
++# Menu: Processor type and features
++CONFIG_SPARSEMEM_VMEMMAP                        policy<{'amd64': 'y', 'arm64': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MOVABLE_NODE                             policy<{'amd64': 'y'}>
++CONFIG_MEMORY_HOTPLUG                           policy<{'amd64': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MEMORY_HOTREMOVE                         policy<{'amd64': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BALLOON_COMPACTION                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_COMPACTION                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MIGRATION                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BOUNCE                                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_KSM                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEFAULT_MMAP_MIN_ADDR                    policy<{'amd64': '65536', 'arm64': '32768', 'armhf': '32768', 'i386': '65536', 'powerpc': '65536', 'ppc64el': '65536', 's390x': '65536'}>
++CONFIG_MEMORY_FAILURE                           policy<{'amd64': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_HWPOISON_INJECT                          policy<{'amd64': 'm', 'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_TRANSPARENT_HUGEPAGE                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf-generic-lpae': 'y', 'i386': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_CLEANCACHE                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FRONTSWAP                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_MEM_SOFT_DIRTY                           policy<{'amd64': 'y'}>
++CONFIG_ZSWAP                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ZPOOL                                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ZBUD                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ZSMALLOC                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PGTABLE_MAPPING                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_ZSMALLOC_STAT                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEFERRED_STRUCT_PAGE_INIT                policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_IDLE_PAGE_TRACKING                       policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_HIGHPTE                                  policy<{'armhf': 'y', 'i386': 'y'}>
++CONFIG_MATH_EMULATION                           policy<{'i386': 'n', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_CMDLINE_BOOL                             policy<{'amd64': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_HIGHMEM                                  policy<{'armhf': 'y', 'i386': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y'}>
++CONFIG_HOTPLUG_CPU                              policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_NUMA                                     policy<{'amd64': 'y', 'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_FORCE_MAX_ZONEORDER                      policy<{'arm64': '11', 'armhf-generic': '12', 'armhf-generic-lpae': '11', 'powerpc-powerpc64-emb': '13', 'powerpc-powerpc64-smp': '13', 'powerpc-powerpc-e500mc': '11', 'powerpc-powerpc-smp': '11', 'ppc64el': '9', 's390x': '9'}>
++CONFIG_SCHED_SMT                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'n', 'i386': 'y', 'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_XEN                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'n', 'i386': 'y'}>
++#
++CONFIG_DEFAULT_MMAP_MIN_ADDR                    mark<ENFORCED> note<LP:1418140>
++CONFIG_IDLE_PAGE_TRACKING			flag<REVIEW> note<is there a cost associated with this?>
++
++# Menu: Processor type and features >> Architecture: arm
++CONFIG_HAVE_ARM_ARCH_TIMER                      policy<{'armhf': 'y'}>
++CONFIG_ARM_PSCI                                 policy<{'armhf': 'y'}>
++CONFIG_THUMB2_KERNEL                            policy<{'armhf': 'n'}>
++CONFIG_AEABI                                    policy<{'armhf': 'y'}>
++CONFIG_OABI_COMPAT                              policy<{'armhf': 'n'}>
++CONFIG_CPU_SW_DOMAIN_PAN                        policy<{'armhf-generic': 'y'}>
++CONFIG_ARM_MODULE_PLTS                          policy<{'armhf': 'n'}>
++CONFIG_UACCESS_WITH_MEMCPY                      policy<{'armhf': 'n'}>
++
++# Menu: Processor type and features >> Architecture: powerpc
++CONFIG_PPC_TRANSACTIONAL_MEM                    policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_SWIOTLB                                  policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y'}>
++CONFIG_PPC64_SUPPORTS_MEMORY_FAILURE            policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_FA_DUMP                                  policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_IRQ_ALL_CPUS                             policy<{'powerpc': 'n', 'ppc64el': 'y'}>
++CONFIG_PPC_SUBPAGE_PROT                         policy<{'ppc64el': 'y'}>
++CONFIG_PPC_DENORMALISATION                      policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'y'}>
++CONFIG_EXTRA_TARGETS                            policy<{'powerpc': '""', 'ppc64el': '""'}>
++#
++CONFIG_FA_DUMP                                  note<LP:1415562>
++
++# Menu: Processor type and features >> Architecture: s390
++CONFIG_COMPAT                                   policy<{'amd64': 'y', 'arm64': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PACK_STACK                               policy<{'s390x': 'y'}>
++CONFIG_CHECK_STACK                              policy<{'s390x': 'y'}>
++CONFIG_STACK_GUARD                              policy<{'s390x': '256'}>
++CONFIG_WARN_DYNAMIC_STACK                       policy<{'s390x': 'n'}>
++
++# Menu: Processor type and features >> Architecture: x86
++CONFIG_ZONE_DMA                                 policy<{'amd64-generic': 'n', 'amd64-lowlatency': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_X86_FEATURE_NAMES                        policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_X2APIC                               policy<{'amd64': 'y'}>
++CONFIG_X86_MPPARSE                              policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_EXTENDED_PLATFORM                    policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_INTEL_LPSS                           policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_AMD_PLATFORM_DEVICE                  policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_IOSF_MBI                                 policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_IOSF_MBI_DEBUG                           policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_32_IRIS                              policy<{'i386': 'm'}>
++CONFIG_SCHED_OMIT_FRAME_POINTER                 policy<{'amd64': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_X86_GENERIC                              policy<{'i386': 'y'}>
++CONFIG_X86_PPRO_FENCE                           policy<{'i386': 'y'}>
++CONFIG_HPET_TIMER                               policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_DMI                                      policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_GART_IOMMU                               policy<{'amd64': 'y'}>
++CONFIG_CALGARY_IOMMU                            policy<{'amd64': 'y'}>
++CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT         policy<{'amd64': 'y'}>
++CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS         policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_LEGACY_VM86                          policy<{'i386': 'y'}>
++CONFIG_X86_16BIT                                policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_VSYSCALL_EMULATION                   policy<{'amd64': 'y'}>
++CONFIG_TOSHIBA                                  policy<{'i386': 'n'}>
++CONFIG_I8K                                      policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_X86_REBOOTFIXUPS                         policy<{'i386': 'y'}>
++CONFIG_X86_MSR                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_X86_CPUID                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_X86_PAE                                  policy<{'i386': 'y'}>
++CONFIG_ARCH_MEMORY_PROBE                        policy<{'amd64': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++CONFIG_X86_PMEM_LEGACY                          policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_CHECK_BIOS_CORRUPTION                policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_BOOTPARAM_MEMORY_CORRUPTION_CHECK    policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_RESERVE_LOW                          policy<{'amd64': '64', 'i386': '64'}>
++CONFIG_MTRR                                     policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_MTRR_SANITIZER                           policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT            policy<{'amd64': '1', 'i386': '1'}>
++CONFIG_MTRR_SANITIZER_SPARE_REG_NR_DEFAULT      policy<{'amd64': '1', 'i386': '1'}>
++CONFIG_X86_PAT                                  policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_ARCH_RANDOM                              policy<{'amd64': 'y', 'i386': 'y', 'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'y'}>
++CONFIG_X86_SMAP                                 policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_INTEL_MPX                            policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_EFI                                      policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_EFI_STUB                                 policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y'}>
++CONFIG_EFI_MIXED                                policy<{'amd64': 'y'}>
++CONFIG_KEXEC_FILE                               policy<{'amd64': 'y'}>
++CONFIG_KEXEC_VERIFY_SIG                         policy<{'amd64': 'y'}>
++CONFIG_KEXEC_BZIMAGE_VERIFY_SIG                 policy<{'amd64': 'y'}>
++CONFIG_KEXEC_JUMP                               policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_RANDOMIZE_BASE                           policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_COMPAT_VDSO                              policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_MODIFY_LDT_SYSCALL                       policy<{'amd64': 'y', 'i386': 'y'}>
++#
++CONFIG_COMPAT_VDSO                              mark<ENFORCED>
++CONFIG_X86_LEGACY_VM86				note<LP:1499089>
++CONFIG_KEXEC_BZIMAGE_VERIFY_SIG			flag<REVIEW> note<Q: check this is in sync with the kexec/kdump userspace>
++CONFIG_MODIFY_LDT_SYSCALL			flag<REVIEW> note<Q: check this with security>
++
++# Menu: Processor type and features >> CPU microcode loading support >> Architecture: x86
++CONFIG_MICROCODE                                policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_MICROCODE_INTEL                          policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_MICROCODE_AMD                            policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_MICROCODE_EARLY                          policy<{'amd64': 'y', 'i386': 'y'}>
++
++# Menu: Processor type and features >> Contiguous Memory Allocator
++CONFIG_CMA                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_CMA_DEBUG                                policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CMA_DEBUGFS                              policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n'}>
++CONFIG_CMA_AREAS                                policy<{'amd64': '7', 'arm64': '7', 'armhf': '7', 'i386': '7', 'powerpc': '7', 'ppc64el': '7'}>
++
++# Menu: Processor type and features >> Device power management core functionality
++
++# Menu: Processor type and features >> Device power management core functionality >> Power Management Debug Support
++#
++
++# Menu: Processor type and features >> High Memory Support >> Architecture: x86
++CONFIG_NOHIGHMEM                                policy<{'i386': 'n'}>
++CONFIG_HIGHMEM4G                                policy<{'i386': 'n'}>
++CONFIG_HIGHMEM64G                               policy<{'i386': 'y'}>
++
++# Menu: Processor type and features >> Linux guest support >> Architecture: x86
++CONFIG_HYPERVISOR_GUEST                         policy<{'amd64': 'y', 'i386': 'y'}>
++
++# Menu: Processor type and features >> Linux guest support >> Enable paravirtualization code
++
++# Menu: Processor type and features >> Linux guest support >> Enable paravirtualization code >> Architecture: x86
++CONFIG_PARAVIRT                                 policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_PARAVIRT_DEBUG                           policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_PARAVIRT_SPINLOCKS                       policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_KVM_DEBUG_FS                             policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_LGUEST_GUEST                             policy<{'i386': 'n'}>
++CONFIG_PARAVIRT_TIME_ACCOUNTING                 policy<{'amd64': 'n', 'i386': 'n'}>
++
++# Menu: Processor type and features >> Linux guest support >> Enable paravirtualization code >> Xen guest support
++
++# Menu: Processor type and features >> Linux guest support >> Enable paravirtualization code >> Xen guest support >> Architecture: x86
++CONFIG_XEN_512GB                                policy<{'amd64': 'y'}>
++CONFIG_XEN_DEBUG_FS                             policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_XEN_PVH                                  policy<{'amd64': 'y'}>
++#
++CONFIG_XEN_512GB				flag<REVIEW> note<Q: is this related to the utlemming questions on memory size?>
++
++# Menu: Processor type and features >> Machine Check / overheating reporting >> Architecture: x86
++CONFIG_X86_MCE                                  policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_MCE_INTEL                            policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_MCE_AMD                              policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_X86_ANCIENT_MCE                          policy<{'i386': 'n'}>
++CONFIG_X86_MCE_INJECT                           policy<{'amd64': 'm', 'i386': 'm'}>
++
++# Menu: Processor type and features >> Math emulation options >> Architecture: powerpc
++CONFIG_MATH_EMULATION_FULL                      policy<{'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_MATH_EMULATION_HW_UNIMPLEMENTED          policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++
++# Menu: Processor type and features >> Memory model
++CONFIG_FLATMEM_MANUAL                           policy<{'i386': 'n', 'powerpc-powerpc64-emb': 'n'}>
++CONFIG_SPARSEMEM_MANUAL                         policy<{'amd64': 'y', 'arm64': 'y', 'i386': 'y', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Processor type and features >> Memory split
++CONFIG_VMSPLIT_3G                               policy<{'armhf': 'y', 'i386': 'y'}>
++CONFIG_VMSPLIT_2G                               policy<{'armhf': 'n', 'i386': 'n'}>
++CONFIG_VMSPLIT_1G                               policy<{'armhf': 'n', 'i386': 'n'}>
++
++# Menu: Processor type and features >> Memory split >> Architecture: arm
++
++# Menu: Processor type and features >> Memory split >> Architecture: x86
++
++# Menu: Processor type and features >> Page size >> Architecture: powerpc
++CONFIG_PPC_4K_PAGES                             policy<{'powerpc': 'y', 'ppc64el': 'n'}>
++CONFIG_PPC_64K_PAGES                            policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'y'}>
++
++# Menu: Processor type and features >> Preemption Model
++CONFIG_PREEMPT_NONE                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'y'}>
++CONFIG_PREEMPT_VOLUNTARY                        policy<{'amd64-generic': 'y', 'amd64-lowlatency': 'n', 'arm64': 'y', 'armhf': 'y', 'i386-generic': 'y', 'i386-lowlatency': 'n', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_PREEMPT                                  policy<{'amd64-generic': 'n', 'amd64-lowlatency': 'y', 'arm64': 'n', 'armhf': 'n', 'i386-generic': 'n', 'i386-lowlatency': 'y', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Processor type and features >> Processor family
++
++# Menu: Processor type and features >> Processor family >> Architecture: x86
++CONFIG_M486                                     policy<{'i386': 'n'}>
++CONFIG_M586                                     policy<{'i386': 'n'}>
++CONFIG_M586TSC                                  policy<{'i386': 'n'}>
++CONFIG_M586MMX                                  policy<{'i386': 'n'}>
++CONFIG_M686                                     policy<{'i386': 'y'}>
++CONFIG_MPENTIUMII                               policy<{'i386': 'n'}>
++CONFIG_MPENTIUMIII                              policy<{'i386': 'n'}>
++CONFIG_MPENTIUMM                                policy<{'i386': 'n'}>
++CONFIG_MPENTIUM4                                policy<{'i386': 'n'}>
++CONFIG_MK6                                      policy<{'i386': 'n'}>
++CONFIG_MK7                                      policy<{'i386': 'n'}>
++CONFIG_MK8                                      policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_MCRUSOE                                  policy<{'i386': 'n'}>
++CONFIG_MEFFICEON                                policy<{'i386': 'n'}>
++CONFIG_MWINCHIPC6                               policy<{'i386': 'n'}>
++CONFIG_MWINCHIP3D                               policy<{'i386': 'n'}>
++CONFIG_MELAN                                    policy<{'i386': 'n'}>
++CONFIG_MGEODEGX1                                policy<{'i386': 'n'}>
++CONFIG_MGEODE_LX                                policy<{'i386': 'n'}>
++CONFIG_MCYRIXIII                                policy<{'i386': 'n'}>
++CONFIG_MVIAC3_2                                 policy<{'i386': 'n'}>
++CONFIG_MVIAC7                                   policy<{'i386': 'n'}>
++CONFIG_MPSC                                     policy<{'amd64': 'n'}>
++CONFIG_MCORE2                                   policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_MATOM                                    policy<{'amd64': 'n', 'i386': 'n'}>
++
++# Menu: Processor type and features >> Processor type >> Architecture: s390
++CONFIG_MARCH_Z900                               policy<{'s390x': 'n'}>
++CONFIG_MARCH_Z990                               policy<{'s390x': 'n'}>
++CONFIG_MARCH_Z9_109                             policy<{'s390x': 'n'}>
++CONFIG_MARCH_Z10                                policy<{'s390x': 'n'}>
++CONFIG_MARCH_Z196                               policy<{'s390x': 'n'}>
++CONFIG_MARCH_ZEC12                              policy<{'s390x': 'y'}>
++CONFIG_MARCH_Z13                                policy<{'s390x': 'n'}>
++
++# Menu: Processor type and features >> Support for extended (non-PC) x86 platforms >> Architecture: x86
++CONFIG_X86_NUMACHIP                             policy<{'amd64': 'y'}>
++CONFIG_X86_VSMP                                 policy<{'amd64': 'n'}>
++CONFIG_X86_UV                                   policy<{'amd64': 'n'}>
++CONFIG_X86_GOLDFISH                             policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_X86_INTEL_MID                            policy<{'i386': 'y'}>
++CONFIG_X86_INTEL_QUARK                          policy<{'i386': 'n'}>
++CONFIG_X86_RDC321X                              policy<{'i386': 'n'}>
++CONFIG_X86_32_NON_STANDARD                      policy<{'i386': 'n'}>
++CONFIG_APB_TIMER                                policy<{'i386': 'y'}>
++
++# Menu: Processor type and features >> Supported processor vendors >> Architecture: x86
++CONFIG_PROCESSOR_SELECT                         policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_CPU_SUP_INTEL                            policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_CPU_SUP_CYRIX_32                         policy<{'i386': 'y'}>
++CONFIG_CPU_SUP_AMD                              policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_CPU_SUP_CENTAUR                          policy<{'amd64': 'y', 'i386': 'y'}>
++CONFIG_CPU_SUP_TRANSMETA_32                     policy<{'i386': 'y'}>
++CONFIG_CPU_SUP_UMC_32                           policy<{'i386': 'y'}>
++
++# Menu: Processor type and features >> Symmetric Multi-Processing
++CONFIG_SCHED_MC                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 's390x': 'y'}>
++
++# Menu: Processor type and features >> Symmetric Multi-Processing >> Architecture: arm
++CONFIG_SMP_ON_UP                                policy<{'armhf': 'y'}>
++CONFIG_ARM_CPU_TOPOLOGY                         policy<{'armhf': 'y'}>
++CONFIG_MCPM                                     policy<{'armhf': 'y'}>
++CONFIG_BIG_LITTLE                               policy<{'armhf': 'y'}>
++CONFIG_BL_SWITCHER                              policy<{'armhf': 'y'}>
++CONFIG_BL_SWITCHER_DUMMY_IF                     policy<{'armhf': 'm'}>
++
++# Menu: Processor type and features >> Symmetric multi-processing support
++CONFIG_NODES_SHIFT                              policy<{'amd64': '6', 'powerpc-powerpc64-smp': '8', 'ppc64el': '8', 's390x': '4'}>
++
++# Menu: Processor type and features >> Symmetric multi-processing support >> Architecture: s390
++CONFIG_SCHED_TOPOLOGY                           policy<{'s390x': 'y'}>
++
++# Menu: Processor type and features >> Symmetric multi-processing support >> Architecture: x86
++CONFIG_X86_BIGSMP                               policy<{'i386': 'n'}>
++CONFIG_MAXSMP                                   policy<{'amd64': 'n'}>
++CONFIG_BOOTPARAM_HOTPLUG_CPU0                   policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_DEBUG_HOTPLUG_CPU0                       policy<{'amd64': 'n', 'i386': 'n'}>
++
++# Menu: Processor type and features >> Symmetric multi-processing support >> Numa Memory Allocation and Scheduler Support
++CONFIG_NUMA_EMU                                 policy<{'amd64': 'n', 's390x': 'y'}>
++CONFIG_NUMA_EMU                                 note<LP:1557690>
++
++# Menu: Processor type and features >> Symmetric multi-processing support >> Numa Memory Allocation and Scheduler Support >> Architecture: x86
++CONFIG_AMD_NUMA                                 policy<{'amd64': 'y'}>
++CONFIG_X86_64_ACPI_NUMA                         policy<{'amd64': 'y'}>
++
++# Menu: Processor type and features >> Symmetric multi-processing support >> Select NUMA modes
++
++# Menu: Processor type and features >> Symmetric multi-processing support >> Select NUMA modes >> Architecture: s390
++
++# Menu: Processor type and features >> Timer frequency
++CONFIG_HZ_100                                   policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'y'}>
++CONFIG_HZ_250                                   policy<{'amd64-generic': 'y', 'amd64-lowlatency': 'n', 'armhf': 'y', 'i386-generic': 'y', 'i386-lowlatency': 'n', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_HZ_300                                   policy<{'amd64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_HZ_1000                                  policy<{'amd64-generic': 'n', 'amd64-lowlatency': 'y', 'armhf': 'n', 'i386-generic': 'n', 'i386-lowlatency': 'y', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Processor type and features >> Timer frequency >> Architecture: arm
++CONFIG_HZ_200                                   policy<{'armhf': 'n'}>
++CONFIG_HZ_500                                   policy<{'armhf': 'n'}>
++
++# Menu: Processor type and features >> Transparent Hugepage Support sysfs defaults
++CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS              policy<{'amd64': 'y', 'arm64': 'y', 'armhf-generic-lpae': 'y', 'i386': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TRANSPARENT_HUGEPAGE_MADVISE             policy<{'amd64': 'n', 'arm64': 'n', 'armhf-generic-lpae': 'n', 'i386': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Processor type and features >> Tune code generation >> Architecture: s390
++CONFIG_TUNE_DEFAULT                             policy<{'s390x': 'n'}>
++CONFIG_TUNE_Z900                                policy<{'s390x': 'n'}>
++CONFIG_TUNE_Z990                                policy<{'s390x': 'n'}>
++CONFIG_TUNE_Z9_109                              policy<{'s390x': 'n'}>
++CONFIG_TUNE_Z10                                 policy<{'s390x': 'n'}>
++CONFIG_TUNE_Z196                                policy<{'s390x': 'n'}>
++CONFIG_TUNE_ZEC12                               policy<{'s390x': 'y'}>
++CONFIG_TUNE_Z13                                 policy<{'s390x': 'n'}>
++
++# Menu: Security options
++CONFIG_SECURITY_DMESG_RESTRICT                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SECURITYFS                               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_INTEL_TXT                                policy<{'amd64': 'y', 'i386': 'y'}>
++
++# Menu: Security options >> Default security module
++CONFIG_DEFAULT_SECURITY_SELINUX                 policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEFAULT_SECURITY_SMACK                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEFAULT_SECURITY_TOMOYO                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_DEFAULT_SECURITY_APPARMOR                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_DEFAULT_SECURITY_DAC                     policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_DEFAULT_SECURITY_APPARMOR                mark<ENFORCED>
++
++# Menu: Security options >> Enable access key retention support
++CONFIG_KEYS                                     policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_PERSISTENT_KEYRINGS                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_BIG_KEYS                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_TRUSTED_KEYS                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ENCRYPTED_KEYS                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Security options >> Enable different security models
++CONFIG_SECURITY                                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_NETWORK                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_NETWORK_XFRM                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_PATH                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_LSM_MMAP_MIN_ADDR                        policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0', 's390x': '0'}>
++CONFIG_SECURITY_SMACK                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_SMACK_BRINGUP                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SECURITY_SMACK_NETFILTER                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_YAMA                            policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++#
++CONFIG_SECURITY                                 mark<ENFORCED>
++CONFIG_LSM_MMAP_MIN_ADDR                        mark<ENFORCED> flag<REVIEW>
++CONFIG_SECURITY_SMACK                           mark<ENFORCED>
++CONFIG_SECURITY_YAMA                            mark<ENFORCED>
++
++# Menu: Security options >> Enable different security models >> AppArmor support
++CONFIG_SECURITY_APPARMOR                        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_APPARMOR_BOOTPARAM_VALUE        policy<{'amd64': '1', 'arm64': '1', 'armhf': '1', 'i386': '1', 'powerpc': '1', 'ppc64el': '1', 's390x': '1'}>
++CONFIG_SECURITY_APPARMOR_STATS                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SECURITY_APPARMOR_UNCONFINED_INIT        policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_APPARMOR_HASH                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_APPARMOR_HASH_DEFAULT           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Security options >> Enable different security models >> Integrity subsystem
++CONFIG_INTEGRITY                                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_INTEGRITY_SIGNATURE                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_INTEGRITY_ASYMMETRIC_KEYS                policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_INTEGRITY_AUDIT                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_EVM                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_EVM_ATTR_FSUUID                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_EVM_EXTRA_SMACK_XATTRS                   policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++
++# Menu: Security options >> Enable different security models >> Integrity subsystem >> Integrity Measurement Architecture(IMA)
++CONFIG_IMA                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IMA_APPRAISE                             policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IMA_TRUSTED_KEYRING                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IMA_LOAD_X509                            policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc-powerpc64-smp': 'n', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Security options >> Enable different security models >> Integrity subsystem >> Integrity Measurement Architecture(IMA) >> Default integrity hash algorithm
++CONFIG_IMA_DEFAULT_HASH_SHA1                    policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IMA_DEFAULT_HASH_SHA256                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc-powerpc64-smp': 'n', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_IMA_DEFAULT_HASH_SHA512                  policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc-powerpc64-smp': 'n', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_IMA_DEFAULT_HASH_WP512                   policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc-powerpc64-smp': 'n', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Security options >> Enable different security models >> Integrity subsystem >> Integrity Measurement Architecture(IMA) >> Default template
++CONFIG_IMA_TEMPLATE                             policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc-powerpc64-smp': 'n', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_IMA_NG_TEMPLATE                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'powerpc-powerpc-smp': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_IMA_SIG_TEMPLATE                         policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc-powerpc64-smp': 'n', 'powerpc-powerpc-e500mc': 'n', 'powerpc-powerpc-smp': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++
++# Menu: Security options >> Enable different security models >> NSA SELinux Support
++CONFIG_SECURITY_SELINUX                         policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_SELINUX_BOOTPARAM               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SECURITY_SELINUX_BOOTPARAM_VALUE         policy<{'amd64': '0', 'arm64': '0', 'armhf': '0', 'i386': '0', 'powerpc': '0', 'ppc64el': '0'}>
++CONFIG_SECURITY_SELINUX_DISABLE                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'n'}>
++CONFIG_SECURITY_SELINUX_DEVELOP                 policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_SELINUX_AVC_STATS               policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_SELINUX_CHECKREQPROT_VALUE      policy<{'amd64': '1', 'arm64': '1', 'armhf': '1', 'i386': '1', 'powerpc': '1', 'ppc64el': '1', 's390x': '1'}>
++CONFIG_SECURITY_SELINUX_POLICYDB_VERSION_MAX    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++#
++CONFIG_SECURITY_SELINUX                         mark<ENFORCED>
++
++# Menu: Security options >> Enable different security models >> TOMOYO Linux Support
++CONFIG_SECURITY_TOMOYO                          policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_SECURITY_TOMOYO_MAX_ACCEPT_ENTRY         policy<{'amd64': '2048', 'arm64': '2048', 'armhf': '2048', 'i386': '2048', 'powerpc': '2048', 'ppc64el': '2048', 's390x': '2048'}>
++CONFIG_SECURITY_TOMOYO_MAX_AUDIT_LOG            policy<{'amd64': '1024', 'arm64': '1024', 'armhf': '1024', 'i386': '1024', 'powerpc': '1024', 'ppc64el': '1024', 's390x': '1024'}>
++CONFIG_SECURITY_TOMOYO_OMIT_USERSPACE_LOADER    policy<{'amd64': 'n', 'arm64': 'n', 'armhf': 'n', 'i386': 'n', 'powerpc': 'n', 'ppc64el': 'n', 's390x': 'n'}>
++CONFIG_SECURITY_TOMOYO_POLICY_LOADER            policy<{'amd64': '"/sbin/tomoyo-init"', 'arm64': '"/sbin/tomoyo-init"', 'armhf': '"/sbin/tomoyo-init"', 'i386': '"/sbin/tomoyo-init"', 'powerpc': '"/sbin/tomoyo-init"', 'ppc64el': '"/sbin/tomoyo-init"', 's390x': '"/sbin/tomoyo-init"'}>
++CONFIG_SECURITY_TOMOYO_ACTIVATION_TRIGGER       policy<{'amd64': '"/sbin/init"', 'arm64': '"/sbin/init"', 'armhf': '"/sbin/init"', 'i386': '"/sbin/init"', 'powerpc': '"/sbin/init"', 'ppc64el': '"/sbin/init"', 's390x': '"/sbin/init"'}>
++
++# Menu: System Type
++
++# Menu: System Type >> ARM Ltd. Versatile Express family >> Architecture: arm
++CONFIG_ARCH_VEXPRESS                            policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_ARCH_VEXPRESS_CORTEX_A5_A9_ERRATA        policy<{'armhf': 'y'}>
++CONFIG_ARCH_VEXPRESS_DCSCB                      policy<{'armhf': 'y'}>
++CONFIG_ARCH_VEXPRESS_SPC                        policy<{'armhf': 'y'}>
++CONFIG_ARCH_VEXPRESS_TC2_PM                     policy<{'armhf': 'y'}>
++
++# Menu: System Type >> ARM system type >> Architecture: arm
++CONFIG_ARCH_MULTIPLATFORM                       policy<{'armhf': 'y'}>
++CONFIG_ARCH_REALVIEW                            policy<{'armhf': 'n'}>
++CONFIG_ARCH_VERSATILE                           policy<{'armhf': 'n'}>
++CONFIG_ARCH_CLPS711X                            policy<{'armhf': 'n'}>
++CONFIG_ARCH_GEMINI                              policy<{'armhf': 'n'}>
++CONFIG_ARCH_EBSA110                             policy<{'armhf': 'n'}>
++CONFIG_ARCH_EP93XX                              policy<{'armhf': 'n'}>
++CONFIG_ARCH_FOOTBRIDGE                          policy<{'armhf': 'n'}>
++CONFIG_ARCH_NETX                                policy<{'armhf': 'n'}>
++CONFIG_ARCH_IOP13XX                             policy<{'armhf': 'n'}>
++CONFIG_ARCH_IOP32X                              policy<{'armhf': 'n'}>
++CONFIG_ARCH_IOP33X                              policy<{'armhf': 'n'}>
++CONFIG_ARCH_IXP4XX                              policy<{'armhf': 'n'}>
++CONFIG_ARCH_DOVE                                policy<{'armhf': 'n'}>
++CONFIG_ARCH_MV78XX0                             policy<{'armhf': 'n'}>
++CONFIG_ARCH_ORION5X                             policy<{'armhf': 'n'}>
++CONFIG_ARCH_MMP                                 policy<{'armhf': 'n'}>
++CONFIG_ARCH_KS8695                              policy<{'armhf': 'n'}>
++CONFIG_ARCH_W90X900                             policy<{'armhf': 'n'}>
++CONFIG_ARCH_LPC32XX                             policy<{'armhf': 'n'}>
++CONFIG_ARCH_PXA                                 policy<{'armhf': 'n'}>
++CONFIG_ARCH_SHMOBILE_LEGACY                     policy<{'armhf': 'n'}>
++CONFIG_ARCH_RPC                                 policy<{'armhf': 'n'}>
++CONFIG_ARCH_SA1100                              policy<{'armhf': 'n'}>
++CONFIG_ARCH_S3C24XX                             policy<{'armhf': 'n'}>
++CONFIG_ARCH_S3C64XX                             policy<{'armhf': 'n'}>
++CONFIG_ARCH_DAVINCI                             policy<{'armhf': 'n'}>
++CONFIG_ARCH_OMAP1                               policy<{'armhf': 'n'}>
++
++# Menu: System Type >> Allwinner SoCs >> Architecture: arm
++CONFIG_ARCH_SUNXI                               policy<{'armhf': 'n'}>
++
++# Menu: System Type >> Altera SOCFPGA family >> Architecture: arm
++CONFIG_ARCH_SOCFPGA                             policy<{'armhf': 'n'}>
++
++# Menu: System Type >> Amlogic Meson SoCs >> Architecture: arm
++CONFIG_ARCH_MESON                               policy<{'armhf': 'y'}>
++CONFIG_MACH_MESON6                              policy<{'armhf': 'y'}>
++CONFIG_MACH_MESON8                              policy<{'armhf': 'y'}>
++
++# Menu: System Type >> Architecture: arm
++CONFIG_ARCH_VIRT                                policy<{'armhf': 'y'}>
++CONFIG_ARCH_ALPINE                              policy<{'armhf': 'y'}>
++CONFIG_ARCH_AXXIA                               policy<{'armhf-generic-lpae': 'y'}>
++CONFIG_ARCH_DIGICOLOR                           policy<{'armhf': 'n'}>
++CONFIG_ARCH_HIGHBANK                            policy<{'armhf': 'y'}>
++CONFIG_ARCH_HISI                                policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_ARCH_KEYSTONE                            policy<{'armhf': 'n'}>
++CONFIG_ARCH_ROCKCHIP                            policy<{'arm64': 'n', 'armhf': 'y'}>
++CONFIG_ARCH_S5PV210                             policy<{'armhf': 'n'}>
++CONFIG_ARCH_R8A7778                             policy<{'armhf': 'y'}>
++CONFIG_ARCH_R8A7779                             policy<{'armhf': 'y'}>
++CONFIG_ARCH_UNIPHIER                            policy<{'armhf': 'y'}>
++CONFIG_ARCH_WM8850                              policy<{'armhf': 'n'}>
++CONFIG_ARCH_ZX                                  policy<{'armhf': 'y'}>
++CONFIG_ARCH_ZYNQ                                policy<{'armhf': 'n'}>
++CONFIG_ARM_THUMB                                policy<{'armhf': 'y'}>
++CONFIG_CACHE_FEROCEON_L2                        policy<{'armhf': 'y'}>
++CONFIG_CACHE_FEROCEON_L2_WRITETHROUGH           policy<{'armhf': 'n'}>
++CONFIG_CACHE_TAUROS2                            policy<{'armhf': 'y'}>
++CONFIG_IWMMXT                                   policy<{'armhf': 'y'}>
++CONFIG_PJ4B_ERRATA_4742                         policy<{'armhf': 'y'}>
++CONFIG_ARM_ERRATA_430973                        policy<{'armhf': 'y'}>
++CONFIG_ARM_ERRATA_643719                        policy<{'armhf': 'y'}>
++CONFIG_ARM_ERRATA_720789                        policy<{'armhf': 'y'}>
++CONFIG_ARM_ERRATA_754322                        policy<{'armhf': 'y'}>
++CONFIG_ARM_ERRATA_754327                        policy<{'armhf': 'y'}>
++CONFIG_ARM_ERRATA_764369                        policy<{'armhf': 'y'}>
++CONFIG_ARM_ERRATA_775420                        policy<{'armhf': 'y'}>
++CONFIG_ARM_ERRATA_798181                        policy<{'armhf': 'y'}>
++CONFIG_ARM_ERRATA_773022                        policy<{'armhf': 'y'}>
++#
++CONFIG_ARCH_ROCKCHIP				note<LP:1566283>
++
++# Menu: System Type >> Atmel SoCs >> Architecture: arm
++CONFIG_ARCH_AT91                                policy<{'armhf': 'n'}>
++
++# Menu: System Type >> Broadcom SoC Support >> Architecture: arm
++CONFIG_ARCH_BCM                                 policy<{'armhf': 'n'}>
++
++# Menu: System Type >> CLPS711X/EP721X/EP731X Implementations >> Architecture: arm
++
++# Menu: System Type >> CSR SiRF >> Architecture: arm
++CONFIG_ARCH_SIRF                                policy<{'armhf': 'n'}>
++
++# Menu: System Type >> Cavium Networks CNS3XXX family >> Architecture: arm
++
++# Menu: System Type >> Cirrus EP93xx Implementation Options >> Architecture: arm
++
++# Menu: System Type >> Cortina Systems Gemini Implementations >> Architecture: arm
++
++# Menu: System Type >> Enable the L2x0 outer cache controller >> Architecture: arm
++CONFIG_CACHE_L2X0                               policy<{'armhf': 'y'}>
++CONFIG_PL310_ERRATA_588369                      policy<{'armhf': 'y'}>
++CONFIG_PL310_ERRATA_727915                      policy<{'armhf': 'y'}>
++CONFIG_PL310_ERRATA_753970                      policy<{'armhf': 'y'}>
++CONFIG_PL310_ERRATA_769419                      policy<{'armhf': 'y'}>
++
++# Menu: System Type >> Firmware options >> Architecture: arm
++CONFIG_TRUSTED_FOUNDATIONS                      policy<{'armhf-generic': 'y'}>
++
++# Menu: System Type >> Footbridge Implementations >> Architecture: arm
++
++# Menu: System Type >> Freescale i.MX family >> Architecture: arm
++CONFIG_ARCH_MXC                                 policy<{'armhf-generic': 'y', 'armhf-generic-lpae': 'n'}>
++CONFIG_SOC_IMX50                                policy<{'armhf-generic': 'y'}>
++CONFIG_SOC_IMX51                                policy<{'armhf-generic': 'y'}>
++CONFIG_SOC_IMX53                                policy<{'armhf-generic': 'n'}>
++CONFIG_SOC_IMX6Q                                policy<{'armhf-generic': 'y'}>
++CONFIG_SOC_IMX6SL                               policy<{'armhf-generic': 'y'}>
++CONFIG_SOC_IMX6SX                               policy<{'armhf-generic': 'y'}>
++CONFIG_SOC_IMX6UL                               policy<{'armhf-generic': 'y'}>
++CONFIG_SOC_IMX7D                                policy<{'armhf-generic': 'y'}>
++CONFIG_SOC_LS1021A                              policy<{'armhf-generic': 'n'}>
++CONFIG_SOC_VF610                                policy<{'armhf-generic': 'y'}>
++
++# Menu: System Type >> Freescale i.MX family >> Clocksource for scheduler clock >> Architecture: arm
++CONFIG_VF_USE_ARM_GLOBAL_TIMER                  policy<{'armhf-generic': 'y'}>
++CONFIG_VF_USE_PIT_TIMER                         policy<{'armhf-generic': 'n'}>
++
++# Menu: System Type >> Hisilicon platform type >> Architecture: arm
++CONFIG_ARCH_HI3xxx                              policy<{'armhf': 'y'}>
++CONFIG_ARCH_HIP01                               policy<{'armhf': 'n'}>
++CONFIG_ARCH_HIP04                               policy<{'armhf': 'y'}>
++CONFIG_ARCH_HIX5HD2                             policy<{'armhf': 'y'}>
++
++# Menu: System Type >> IOP13XX Implementation Options >> Architecture: arm
++
++# Menu: System Type >> IOP32x Implementation Options >> Architecture: arm
++
++# Menu: System Type >> IOP33x Implementation Options >> Architecture: arm
++
++# Menu: System Type >> Integrator Options >> Architecture: arm
++
++# Menu: System Type >> Intel IXP4xx Implementation Options >> Architecture: arm
++
++# Menu: System Type >> Intel PXA2xx/PXA3xx Implementations >> Architecture: arm
++
++# Menu: System Type >> Intel PXA2xx/PXA3xx Implementations >> Gumstix Carrier/Expansion Board >> Architecture: arm
++
++# Menu: System Type >> Intel PXA2xx/PXA3xx Implementations >> Motorola EZX Platform >> Architecture: arm
++
++# Menu: System Type >> Intel PXA2xx/PXA3xx Implementations >> PXA based Keith und Koep Trizeps DIMM-Modules >> Architecture: arm
++
++# Menu: System Type >> Intel PXA2xx/PXA3xx Implementations >> PXA based Keith und Koep Trizeps DIMM-Modules >> Select base board for Trizeps module >> Architecture: arm
++
++# Menu: System Type >> Intel PXA2xx/PXA3xx Implementations >> PXA based Palm PDAs >> Architecture: arm
++
++# Menu: System Type >> Intel PXA2xx/PXA3xx Implementations >> PXA based Toshiba e-series PDAs >> Architecture: arm
++
++# Menu: System Type >> Intel PXA2xx/PXA3xx Implementations >> SHARP Zaurus SL-5600, SL-C7xx and SL-Cxx00 Models >> Architecture: arm
++
++# Menu: System Type >> Intel PXA2xx/PXA3xx Implementations >> display on pcm990 >> Architecture: arm
++
++# Menu: System Type >> Kendin/Micrel KS8695 Implementations >> Architecture: arm
++
++# Menu: System Type >> MMU-based Paged Memory Management Support
++#
++
++# Menu: System Type >> MMU-based Paged Memory Management Support >> Architecture: arm
++CONFIG_MMU                                      policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_ARM_LPAE                                 policy<{'armhf-generic': 'n', 'armhf-generic-lpae': 'y'}>
++CONFIG_CPU_ICACHE_DISABLE                       policy<{'armhf': 'n'}>
++CONFIG_KUSER_HELPERS                            policy<{'armhf': 'y'}>
++CONFIG_ARM_KERNMEM_PERMS                        policy<{'armhf': 'y'}>
++#
++CONFIG_ARM_KERNMEM_PERMS                        flag<REVIEW>
++
++# Menu: System Type >> MMU-based Paged Memory Management Support >> Renesas ARM SoCs >> Architecture: arm
++CONFIG_ARCH_SHMOBILE_MULTI                      policy<{'armhf': 'y'}>
++CONFIG_ARCH_EMEV2                               policy<{'armhf': 'y'}>
++CONFIG_ARCH_R7S72100                            policy<{'armhf': 'y'}>
++CONFIG_ARCH_R8A73A4                             policy<{'armhf': 'n'}>
++CONFIG_ARCH_R8A7740                             policy<{'armhf': 'y'}>
++CONFIG_ARCH_R8A7790                             policy<{'armhf': 'y'}>
++CONFIG_ARCH_R8A7791                             policy<{'armhf': 'y'}>
++CONFIG_ARCH_R8A7793                             policy<{'armhf': 'y'}>
++CONFIG_ARCH_R8A7794                             policy<{'armhf': 'y'}>
++CONFIG_ARCH_SH73A0                              policy<{'armhf': 'y'}>
++#
++CONFIG_ARCH_R8A73A4                             flag<REVIEW>
++
++# Menu: System Type >> MMU-based Paged Memory Management Support >> ST-Ericsson U300 Series >> Architecture: arm
++
++# Menu: System Type >> MMU-based Paged Memory Management Support >> ST-Ericsson U8500 Series >> Architecture: arm
++CONFIG_ARCH_U8500                               policy<{'armhf': 'n'}>
++
++# Menu: System Type >> MOXA ART SoC >> Architecture: arm
++
++# Menu: System Type >> Marvell Berlin SoCs >> Architecture: arm
++CONFIG_ARCH_BERLIN                              policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_MACH_BERLIN_BG2                          policy<{'armhf': 'y'}>
++CONFIG_MACH_BERLIN_BG2CD                        policy<{'armhf': 'y'}>
++CONFIG_MACH_BERLIN_BG2Q                         policy<{'armhf': 'y'}>
++
++# Menu: System Type >> Marvell Dove Implementations >> Architecture: arm
++
++# Menu: System Type >> Marvell Engineering Business Unit (MVEBU) SoCs >> Architecture: arm
++CONFIG_ARCH_MVEBU                               policy<{'armhf': 'y'}>
++CONFIG_MACH_ARMADA_370                          policy<{'armhf': 'y'}>
++CONFIG_MACH_ARMADA_375                          policy<{'armhf': 'y'}>
++CONFIG_MACH_ARMADA_38X                          policy<{'armhf': 'y'}>
++CONFIG_MACH_ARMADA_39X                          policy<{'armhf': 'y'}>
++CONFIG_MACH_ARMADA_XP                           policy<{'armhf': 'y'}>
++CONFIG_MACH_DOVE                                policy<{'armhf': 'y'}>
++
++# Menu: System Type >> Marvell MV78xx0 Implementations >> Architecture: arm
++
++# Menu: System Type >> Marvell PXA168/910/MMP2 Implmentations >> Architecture: arm
++
++# Menu: System Type >> Mediatek MT65xx & MT81xx SoC >> Architecture: arm
++CONFIG_ARCH_MEDIATEK                            policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_MACH_MT6589                              policy<{'armhf': 'y'}>
++CONFIG_MACH_MT6592                              policy<{'armhf': 'y'}>
++CONFIG_MACH_MT8127                              policy<{'armhf': 'y'}>
++CONFIG_MACH_MT8135                              policy<{'armhf': 'y'}>
++
++# Menu: System Type >> Multiple platform selection >> Architecture: arm
++CONFIG_ARCH_MULTI_V6                            policy<{'armhf': 'n'}>
++CONFIG_ARCH_MULTI_V7                            policy<{'armhf': 'y'}>
++
++# Menu: System Type >> NUC950 Machines >> Architecture: arm
++
++# Menu: System Type >> NUC960 Machines >> Architecture: arm
++
++# Menu: System Type >> NVIDIA Tegra >> Architecture: arm
++CONFIG_ARCH_TEGRA                               policy<{'arm64': 'n', 'armhf-generic': 'y', 'armhf-generic-lpae': 'n'}>
++CONFIG_ARCH_TEGRA_2x_SOC                        policy<{'armhf-generic': 'y'}>
++CONFIG_ARCH_TEGRA_3x_SOC                        policy<{'armhf-generic': 'y'}>
++CONFIG_ARCH_TEGRA_114_SOC                       policy<{'armhf-generic': 'y'}>
++CONFIG_ARCH_TEGRA_124_SOC                       policy<{'armhf-generic': 'y'}>
++
++# Menu: System Type >> NetX Implementations >> Architecture: arm
++
++# Menu: System Type >> Orion Implementations >> Architecture: arm
++
++# Menu: System Type >> Qualcomm Support >> Architecture: arm
++CONFIG_ARCH_QCOM                                policy<{'arm64': 'y', 'armhf': 'y'}>
++CONFIG_ARCH_MSM8X60                             policy<{'armhf': 'y'}>
++CONFIG_ARCH_MSM8960                             policy<{'armhf': 'y'}>
++CONFIG_ARCH_MSM8974                             policy<{'armhf': 'y'}>
++
++# Menu: System Type >> RealView platform type >> Architecture: arm
++
++# Menu: System Type >> SA11x0 Implementations >> Architecture: arm
++
++# Menu: System Type >> SA11x0 Implementations >> Cerf Flash available >> Architecture: arm
++
++# Menu: System Type >> SAMSUNG S3C24XX SoCs Support >> Architecture: arm
++
++# Menu: System Type >> SAMSUNG S3C24XX SoCs Support >> SAMSUNG S3C2410 >> Architecture: arm
++
++# Menu: System Type >> SAMSUNG S3C24XX SoCs Support >> SAMSUNG S3C2412 >> Architecture: arm
++
++# Menu: System Type >> SAMSUNG S3C24XX SoCs Support >> SAMSUNG S3C2440 >> Architecture: arm
++
++# Menu: System Type >> SMDK6410 >> Architecture: arm
++
++# Menu: System Type >> SMDK6410 >> SMDK6410 MMC/SD slot setup >> Architecture: arm
++
++# Menu: System Type >> ST SPEAr Family >> Architecture: arm
++CONFIG_PLAT_SPEAR                               policy<{'armhf': 'n'}>
++
++# Menu: System Type >> ST SPEAr Family >> ST SPEAr13xx >> Architecture: arm
++
++# Menu: System Type >> ST SPEAr Family >> ST SPEAr13xx >> ST SPEAr3xx >> Architecture: arm
++
++# Menu: System Type >> ST-Ericsson Nomadik >> Architecture: arm
++
++# Menu: System Type >> STMicroelectronics Consumer Electronics SOCs >> Architecture: arm
++CONFIG_ARCH_STI                                 policy<{'armhf': 'n'}>
++
++# Menu: System Type >> Samsung Common options >> Architecture: arm
++CONFIG_SAMSUNG_PM_CHECK                         policy<{'armhf': 'n'}>
++
++# Menu: System Type >> Samsung EXYNOS >> Architecture: arm
++CONFIG_ARCH_EXYNOS                              policy<{'armhf': 'y'}>
++CONFIG_ARCH_EXYNOS3                             policy<{'armhf': 'n'}>
++
++# Menu: System Type >> Samsung EXYNOS >> SAMSUNG EXYNOS4 >> Architecture: arm
++CONFIG_ARCH_EXYNOS4                             policy<{'armhf': 'n'}>
++
++# Menu: System Type >> Samsung EXYNOS >> SAMSUNG EXYNOS5 >> Architecture: arm
++CONFIG_ARCH_EXYNOS5                             policy<{'armhf': 'y'}>
++CONFIG_SOC_EXYNOS5250                           policy<{'armhf': 'y'}>
++CONFIG_SOC_EXYNOS5260                           policy<{'armhf': 'y'}>
++CONFIG_SOC_EXYNOS5410                           policy<{'armhf': 'y'}>
++CONFIG_SOC_EXYNOS5420                           policy<{'armhf': 'y'}>
++CONFIG_SOC_EXYNOS5440                           policy<{'armhf': 'y'}>
++CONFIG_SOC_EXYNOS5800                           policy<{'armhf': 'y'}>
++CONFIG_EXYNOS5420_MCPM                          policy<{'armhf': 'y'}>
++
++# Menu: System Type >> SuperH / SH-Mobile Driver Options
++
++# Menu: System Type >> Support ARM V7 processor >> Architecture: arm
++CONFIG_CPU_V7                                   policy<{'armhf': 'y'}>
++CONFIG_ARM_THUMBEE                              policy<{'armhf': 'y'}>
++CONFIG_SWP_EMULATE                              policy<{'armhf': 'y'}>
++CONFIG_CPU_BPREDICT_DISABLE                     policy<{'armhf': 'n'}>
++CONFIG_VDSO                                     policy<{'armhf': 'y'}>
++CONFIG_ARM_DMA_MEM_BUFFERABLE                   policy<{'armhf': 'y'}>
++
++# Menu: System Type >> TI DaVinci Implementations >> Architecture: arm
++
++# Menu: System Type >> TI DaVinci Implementations >> DA850/OMAP-L138/AM18x based system >> Architecture: arm
++
++# Menu: System Type >> TI DaVinci Implementations >> DA850/OMAP-L138/AM18x based system >> Select peripherals connected to expander on UI board >> Architecture: arm
++
++# Menu: System Type >> TI DaVinci Implementations >> DaVinci 644x based system >> Architecture: arm
++
++# Menu: System Type >> TI DaVinci Implementations >> Select DA830/OMAP-L137/AM17x UI board peripheral >> Architecture: arm
++
++# Menu: System Type >> TI OMAP Common Features >> Architecture: arm
++CONFIG_POWER_AVS_OMAP                           policy<{'armhf-generic': 'y'}>
++CONFIG_POWER_AVS_OMAP_CLASS3                    policy<{'armhf-generic': 'y'}>
++CONFIG_OMAP_RESET_CLOCKS                        policy<{'armhf': 'y'}>
++CONFIG_OMAP_32K_TIMER                           policy<{'armhf': 'y'}>
++CONFIG_OMAP3_L2_AUX_SECURE_SAVE_RESTORE         policy<{'armhf-generic': 'n'}>
++CONFIG_OMAP_DM_TIMER                            policy<{'armhf': 'y'}>
++
++# Menu: System Type >> TI OMAP Common Features >> OMAP PM layer selection >> Architecture: arm
++CONFIG_OMAP_PM_NOOP                             policy<{'armhf': 'y'}>
++
++# Menu: System Type >> TI OMAP Common Features >> OMAP multiplexing support >> Architecture: arm
++CONFIG_OMAP_MUX                                 policy<{'armhf': 'y'}>
++CONFIG_OMAP_MUX_DEBUG                           policy<{'armhf': 'n'}>
++CONFIG_OMAP_MUX_WARNINGS                        policy<{'armhf': 'y'}>
++
++# Menu: System Type >> TI OMAP/AM/DM/DRA Family >> Architecture: arm
++CONFIG_ARCH_OMAP3                               policy<{'armhf-generic': 'y', 'armhf-generic-lpae': 'n'}>
++CONFIG_ARCH_OMAP4                               policy<{'armhf-generic': 'y', 'armhf-generic-lpae': 'n'}>
++CONFIG_SOC_OMAP5                                policy<{'armhf': 'n'}>
++CONFIG_SOC_AM33XX                               policy<{'armhf-generic': 'y', 'armhf-generic-lpae': 'n'}>
++CONFIG_SOC_AM43XX                               policy<{'armhf': 'n'}>
++CONFIG_SOC_DRA7XX                               policy<{'armhf': 'y'}>
++
++# Menu: System Type >> TI OMAP/AM/DM/DRA Family >> TI OMAP2/3/4 Specific Features >> Architecture: arm
++CONFIG_ARCH_OMAP2PLUS_TYPICAL                   policy<{'armhf': 'y'}>
++CONFIG_SOC_HAS_OMAP2_SDRC                       policy<{'armhf': 'y'}>
++CONFIG_SOC_HAS_REALTIME_COUNTER                 policy<{'armhf': 'y'}>
++CONFIG_SOC_OMAP3430                             policy<{'armhf-generic': 'y'}>
++CONFIG_SOC_TI81XX                               policy<{'armhf-generic': 'y'}>
++CONFIG_MACH_OMAP_LDP                            policy<{'armhf-generic': 'y'}>
++CONFIG_MACH_OMAP3517EVM                         policy<{'armhf-generic': 'n'}>
++CONFIG_MACH_OMAP3_PANDORA                       policy<{'armhf-generic': 'y'}>
++CONFIG_MACH_NOKIA_RX51                          policy<{'armhf-generic': 'n'}>
++CONFIG_OMAP3_SDRC_AC_TIMING                     policy<{'armhf-generic': 'n'}>
++
++# Menu: System Type >> TI OMAP1 specific features >> Architecture: arm
++
++# Menu: System Type >> TI OMAP1 specific features >> OMAP15xx Based System >> Architecture: arm
++
++# Menu: System Type >> TI OMAP1 specific features >> OMAP16xx Based System >> Architecture: arm
++CONFIG_MACH_OMAP_GENERIC                        policy<{'armhf': 'y'}>
++
++# Menu: System Type >> Timer and clock configuration >> Architecture: arm
++CONFIG_SHMOBILE_TIMER_HZ                        policy<{'armhf': '128'}>
++
++# Menu: System Type >> Versatile platform type >> Architecture: arm
++
++# Menu: System Type >> W90P910 Machines >> Architecture: arm
++
++# Menu: Ubuntu Supplied Third-Party Device Drivers
++
++# Menu: Virtualization
++CONFIG_VIRTUALIZATION                           policy<{'amd64': 'y', 'arm64': 'y', 'armhf': 'y', 'i386': 'y', 'powerpc': 'y', 'ppc64el': 'y', 's390x': 'y'}>
++CONFIG_KVM                                      policy<{'amd64': 'm', 'arm64': 'y', 'armhf-generic-lpae': 'y', 'i386': 'm', 'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc64-smp': 'y', 'powerpc-powerpc-e500mc': 'y', 'ppc64el': 'y', 's390x': 'm'}>
++CONFIG_LGUEST                                   policy<{'i386': 'n'}>
++#
++
++# Menu: Virtualization >> Architecture: powerpc
++CONFIG_KVM_BOOK3S_64                            policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_KVM_BOOK3S_64_HV                         policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_KVM_BOOK3S_64_PR                         policy<{'powerpc-powerpc64-smp': 'm', 'ppc64el': 'm'}>
++CONFIG_KVM_BOOK3S_HV_EXIT_TIMING                policy<{'powerpc-powerpc64-smp': 'n', 'ppc64el': 'n'}>
++CONFIG_KVM_EXIT_TIMING                          policy<{'powerpc-powerpc64-emb': 'n', 'powerpc-powerpc-e500mc': 'n'}>
++CONFIG_KVM_E500MC                               policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_KVM_MPIC                                 policy<{'powerpc-powerpc64-emb': 'y', 'powerpc-powerpc-e500mc': 'y'}>
++CONFIG_KVM_XICS                                 policy<{'powerpc-powerpc64-smp': 'y', 'ppc64el': 'y'}>
++
++# Menu: Virtualization >> Architecture: s390
++CONFIG_PFAULT                                   policy<{'s390x': 'y'}>
++CONFIG_CMM_IUCV                                 policy<{'s390x': 'y'}>
++CONFIG_S390_HYPFS_FS                            policy<{'s390x': 'y'}>
++CONFIG_S390_GUEST                               policy<{'s390x': 'y'}>
++
++# Menu: Virtualization >> KVM
++
++# Menu: Virtualization >> KVM >> Architecture: s390
++CONFIG_KVM_S390_UCONTROL                        policy<{'s390x': 'n'}>
++
++# Menu: Virtualization >> Kernel-based Virtual Machine (KVM) support
++
++# Menu: Virtualization >> Kernel-based Virtual Machine (KVM) support >> Architecture: x86
++CONFIG_KVM_INTEL                                policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_KVM_AMD                                  policy<{'amd64': 'm', 'i386': 'm'}>
++CONFIG_KVM_MMU_AUDIT                            policy<{'amd64': 'n', 'i386': 'n'}>
++CONFIG_KVM_DEVICE_ASSIGNMENT                    policy<{'amd64': 'y', 'i386': 'y'}>
++
++# Menu: Virtualization >> Linux - VM Monitor Stream, base infrastructure >> Architecture: s390
++CONFIG_APPLDATA_BASE                            policy<{'s390x': 'y'}>
++CONFIG_APPLDATA_MEM                             policy<{'s390x': 'm'}>
++CONFIG_APPLDATA_OS                              policy<{'s390x': 'm'}>
++CONFIG_APPLDATA_NET_SUM                         policy<{'s390x': 'm'}>
++
++# Menu: FOOTER
++
++# temporarily disabled options -- build failures.
++#CONFIG_TI_CPSW					p policy<(arch armel armhf &/ value n) | value m> flag<BUILD FAILURE>
++#CONFIG_USB_MUSB_DSPS				p policy<(arch armel armhf &/ value n) | value m> flag<BUILD FAILURE>
++#CONFIG_LIS3L02DQ				p policy<(arch armhf &/ value n) | value m> flag<BUILD FAILURE>
++#CONFIG_EZX_PCAP					p policy<(arch armhf &/ value n) | value y> flag<BUILD FAILURE>
++#CONFIG_TOUCHSCREEN_EGALAX			p policy<(arch armel armhf &/ value n) | value m> flag<BUILD FAILURE> note<FTBS on ti-omap4>
++#CONFIG_TOUCHSCREEN_EETI				p policy<(arch armel armhf &/ value n) | value m> flag<BUILD FAILURE> note<FTBS on ti-omap4>
++#CONFIG_SENSORS_AK8975				p policy<(arch armel armhf &/ value n) | value m> flag<BUILD FAILURE> note<FTBS on ti-omap4>
++#CONFIG_PPC_EPAPR_HV_BYTECHAN			n flag<BUILD FAILURE> note<FTBFS on ppc64el>
+diff --git a/debian.master/config/arm64/config.common.arm64 b/debian.master/config/arm64/config.common.arm64
+new file mode 100644
+index 0000000..06c6881
+--- /dev/null
++++ b/debian.master/config/arm64/config.common.arm64
+@@ -0,0 +1,476 @@
++#
++# Config options for config.common.arm64 automatically generated by splitconfig.pl
++#
++CONFIG_64BIT=y
++CONFIG_6LOWPAN=m
++CONFIG_ABX500_CORE=y
++CONFIG_AC97_BUS=m
++CONFIG_ACPI_REDUCED_HARDWARE_ONLY=y
++CONFIG_ADFS_FS=m
++CONFIG_AFFS_FS=m
++CONFIG_AIX_PARTITION=y
++CONFIG_ALIM7101_WDT=m
++CONFIG_ALTERA_TSE=m
++CONFIG_AMIGA_PARTITION=y
++CONFIG_APPLICOM=m
++CONFIG_ARCH_DMA_ADDR_T_64BIT=y
++# CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
++CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
++# CONFIG_ARCH_ROCKCHIP is not set
++CONFIG_ARCH_SELECT_MEMORY_MODEL=y
++CONFIG_ARCH_SPARSEMEM_DEFAULT=y
++# CONFIG_ARCH_TEGRA is not set
++CONFIG_ARCNET=m
++CONFIG_ARM_SMMU=y
++CONFIG_ATALK=m
++CONFIG_ATARI_PARTITION=y
++CONFIG_ATA_GENERIC=m
++# CONFIG_ATA_NONSTANDARD is not set
++CONFIG_ATA_OVER_ETH=m
++CONFIG_ATA_PIIX=m
++CONFIG_ATM=m
++CONFIG_AUDIT_ARCH_COMPAT_GENERIC=y
++CONFIG_AUTOFS4_FS=m
++CONFIG_AUXDISPLAY=y
++CONFIG_BACKLIGHT_LCD_SUPPORT=y
++CONFIG_BATMAN_ADV=m
++CONFIG_BCH=m
++CONFIG_BCMA=m
++CONFIG_BCM_KONA_USB2_PHY=m
++CONFIG_BE2ISCSI=m
++CONFIG_BEFS_FS=m
++CONFIG_BFS_FS=m
++CONFIG_BLK_CPQ_CISS_DA=m
++CONFIG_BLK_DEV_3W_XXXX_RAID=m
++CONFIG_BLK_DEV_CRYPTOLOOP=m
++CONFIG_BLK_DEV_DAC960=m
++CONFIG_BLK_DEV_NVME=m
++CONFIG_BLK_DEV_PCIESSD_MTIP32XX=m
++CONFIG_BLK_DEV_RSXX=m
++CONFIG_BLK_DEV_SKD=m
++# CONFIG_BLK_DEV_SR_VENDOR is not set
++CONFIG_BLK_DEV_SX8=m
++CONFIG_BLK_DEV_UMEM=m
++CONFIG_BOUNCE=y
++CONFIG_BSD_DISKLABEL=y
++CONFIG_C2PORT=m
++CONFIG_CADENCE_WATCHDOG=m
++CONFIG_CAIF=m
++CONFIG_CAN=m
++CONFIG_CB710_CORE=m
++CONFIG_CC_STACKPROTECTOR=y
++CONFIG_CDROM_PKTCDVD=m
++CONFIG_CMA=y
++CONFIG_CMDLINE="console=ttyAMA0"
++CONFIG_CMDLINE_PARTITION=y
++CONFIG_CONFIGFS_FS=m
++# CONFIG_CPU_BIG_ENDIAN is not set
++CONFIG_CRAMFS=m
++# CONFIG_CXL_BASE is not set
++# CONFIG_CXL_EEH is not set
++# CONFIG_CXL_KERNEL_API is not set
++CONFIG_DECNET=m
++CONFIG_DEFAULT_MMAP_MIN_ADDR=32768
++CONFIG_DMADEVICES=y
++CONFIG_DMA_SHARED_BUFFER=y
++CONFIG_DMA_VIRTUAL_CHANNELS=y
++# CONFIG_DM_DEBUG is not set
++CONFIG_DNET=m
++CONFIG_DRM=m
++CONFIG_DUMMY_IRQ=m
++CONFIG_DW_WATCHDOG=m
++CONFIG_ECHO=m
++CONFIG_EEPROM_93CX6=m
++CONFIG_EFS_FS=m
++# CONFIG_EM_TIMER_STI is not set
++CONFIG_ENCLOSURE_SERVICES=m
++CONFIG_ETHOC=m
++CONFIG_EXOFS_FS=m
++CONFIG_EXTCON=y
++CONFIG_F2FS_FS=m
++CONFIG_FB=y
++CONFIG_FB_ATY128=m
++# CONFIG_FB_BOOT_VESA_SUPPORT is not set
++# CONFIG_FB_CFB_REV_PIXELS_IN_BYTE is not set
++CONFIG_FB_IBM_GXT4500=m
++# CONFIG_FB_MACMODES is not set
++CONFIG_FB_SYS_COPYAREA=m
++CONFIG_FB_SYS_FILLRECT=m
++CONFIG_FB_SYS_FOPS=m
++CONFIG_FB_SYS_IMAGEBLIT=m
++CONFIG_FB_UDL=m
++CONFIG_FB_VOODOO1=m
++CONFIG_FDDI=y
++CONFIG_FEALNX=m
++CONFIG_FIREWIRE=m
++CONFIG_FIREWIRE_NOSY=m
++CONFIG_FIRMWARE_IN_KERNEL=y
++CONFIG_FIXED_PHY=y
++CONFIG_FMC=m
++# CONFIG_FONTS is not set
++CONFIG_FORCE_MAX_ZONEORDER=13
++CONFIG_FRAME_WARN=1024
++CONFIG_FUSION=y
++CONFIG_GAMEPORT=m
++CONFIG_GENERIC_CSUM=y
++CONFIG_GENERIC_PHY=y
++CONFIG_GPIO_GENERIC=y
++CONFIG_GPIO_GENERIC_PLATFORM=y
++CONFIG_GPIO_TWL4030=m
++CONFIG_GPIO_TWL6040=m
++# CONFIG_HAVE_64BIT_ALIGNED_ACCESS is not set
++# CONFIG_HAVE_AOUT is not set
++CONFIG_HAVE_ARCH_BITREVERSE=y
++# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
++CONFIG_HAVE_GENERIC_DMA_COHERENT=y
++CONFIG_HFSPLUS_FS=m
++CONFIG_HFS_FS=m
++# CONFIG_HIO is not set
++CONFIG_HOTPLUG_PCI_PCIE=y
++CONFIG_HOTPLUG_PCI_SHPC=m
++# CONFIG_HPET is not set
++CONFIG_HPFS_FS=m
++CONFIG_HP_ILO=m
++CONFIG_HSI=m
++CONFIG_HSR=m
++CONFIG_HTC_PASIC3=m
++CONFIG_HUGETLB_PAGE=y
++CONFIG_HWMON=y
++CONFIG_HW_RANDOM_TIMERIOMEM=m
++CONFIG_HZ=250
++# CONFIG_HZ_100 is not set
++# CONFIG_HZ_1000 is not set
++CONFIG_HZ_250=y
++CONFIG_I2C=y
++# CONFIG_I2C_SLAVE is not set
++CONFIG_I6300ESB_WDT=m
++CONFIG_IEEE802154=m
++CONFIG_IIO=m
++CONFIG_ILLEGAL_POINTER_VALUE=0xdead000000000000
++CONFIG_IMA=y
++CONFIG_INFINIBAND_NES=m
++CONFIG_INFINIBAND_OCRDMA=m
++CONFIG_INFINIBAND_QIB=m
++CONFIG_INPUT=y
++CONFIG_IOMMU_IO_PGTABLE_LPAE=y
++CONFIG_IPACK_BUS=m
++CONFIG_IPMI_HANDLER=m
++# CONFIG_IPMI_SI_PROBE_DEFAULTS is not set
++CONFIG_IPX=m
++# CONFIG_IP_DCCP_CCID3 is not set
++CONFIG_IRQ_BYPASS_MANAGER=m
++# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
++CONFIG_JFS_FS=m
++CONFIG_JME=m
++CONFIG_JUMP_LABEL=y
++CONFIG_KARMA_PARTITION=y
++CONFIG_KVM=y
++CONFIG_LAPB=m
++CONFIG_LDM_PARTITION=y
++CONFIG_LIBNVDIMM=y
++CONFIG_LLC2=m
++CONFIG_LOG_BUF_SHIFT=14
++CONFIG_LPC_ICH=m
++CONFIG_LPC_SCH=m
++CONFIG_MAC_PARTITION=y
++CONFIG_MAGIC_SYSRQ_DEFAULT_ENABLE=0x1
++CONFIG_MAILBOX=y
++CONFIG_MAX63XX_WATCHDOG=m
++CONFIG_MCB=m
++CONFIG_MD_MULTIPATH=m
++CONFIG_MEDIA_SUPPORT=m
++CONFIG_MEGARAID_LEGACY=m
++CONFIG_MEGARAID_NEWGEN=y
++CONFIG_MEGARAID_SAS=m
++CONFIG_MEMORY=y
++CONFIG_MEMSTICK=m
++CONFIG_MFD_CORE=y
++CONFIG_MFD_JANZ_CMODIO=m
++CONFIG_MFD_KEMPLD=m
++CONFIG_MFD_MT6397=m
++CONFIG_MFD_RDC321X=m
++CONFIG_MFD_RTSX_PCI=m
++CONFIG_MFD_SM501=m
++CONFIG_MFD_SYSCON=y
++CONFIG_MFD_TI_AM335X_TSCADC=m
++# CONFIG_MFD_TMIO is not set
++CONFIG_MFD_VX855=m
++CONFIG_MII=y
++CONFIG_MINIX_FS=m
++CONFIG_MINIX_SUBPARTITION=y
++CONFIG_MMC=y
++CONFIG_MMC_BLOCK=y
++CONFIG_MMC_SDHCI=m
++CONFIG_MMC_SDHCI_PLTFM=m
++CONFIG_MTD=m
++CONFIG_MTD_BLKDEVS=m
++CONFIG_MTD_BLOCK=m
++CONFIG_MTD_CMDLINE_PARTS=m
++CONFIG_MTD_NAND=m
++CONFIG_MTD_NAND_BCH=m
++CONFIG_MTD_NAND_ECC=m
++CONFIG_MTD_NAND_IDS=m
++# CONFIG_MTD_NAND_OMAP_BCH_BUILD is not set
++CONFIG_MTD_OF_PARTS=m
++CONFIG_NCP_FS=m
++CONFIG_NEED_DMA_MAP_STATE=y
++CONFIG_NET_CADENCE=y
++CONFIG_NET_PACKET_ENGINE=y
++CONFIG_NET_VENDOR_3COM=y
++CONFIG_NET_VENDOR_ADAPTEC=y
++CONFIG_NET_VENDOR_AGERE=y
++CONFIG_NET_VENDOR_ALTEON=y
++CONFIG_NET_VENDOR_AMD=y
++CONFIG_NET_VENDOR_ARC=y
++CONFIG_NET_VENDOR_ATHEROS=y
++CONFIG_NET_VENDOR_BROADCOM=y
++CONFIG_NET_VENDOR_BROCADE=y
++CONFIG_NET_VENDOR_CAVIUM=y
++CONFIG_NET_VENDOR_CHELSIO=y
++CONFIG_NET_VENDOR_CISCO=y
++CONFIG_NET_VENDOR_DEC=y
++CONFIG_NET_VENDOR_DLINK=y
++CONFIG_NET_VENDOR_EMULEX=y
++CONFIG_NET_VENDOR_EXAR=y
++CONFIG_NET_VENDOR_EZCHIP=y
++CONFIG_NET_VENDOR_HP=y
++CONFIG_NET_VENDOR_INTEL=y
++CONFIG_NET_VENDOR_MARVELL=y
++CONFIG_NET_VENDOR_MICREL=y
++CONFIG_NET_VENDOR_MYRI=y
++CONFIG_NET_VENDOR_NATSEMI=y
++CONFIG_NET_VENDOR_NVIDIA=y
++CONFIG_NET_VENDOR_OKI=y
++CONFIG_NET_VENDOR_QLOGIC=y
++CONFIG_NET_VENDOR_QUALCOMM=y
++CONFIG_NET_VENDOR_RDC=y
++CONFIG_NET_VENDOR_REALTEK=y
++CONFIG_NET_VENDOR_RENESAS=y
++CONFIG_NET_VENDOR_ROCKER=y
++CONFIG_NET_VENDOR_SAMSUNG=y
++CONFIG_NET_VENDOR_SEEQ=y
++CONFIG_NET_VENDOR_SILAN=y
++CONFIG_NET_VENDOR_SIS=y
++CONFIG_NET_VENDOR_SMSC=y
++CONFIG_NET_VENDOR_STMICRO=y
++CONFIG_NET_VENDOR_SUN=y
++CONFIG_NET_VENDOR_SYNOPSYS=y
++CONFIG_NET_VENDOR_TEHUTI=y
++CONFIG_NET_VENDOR_TI=y
++CONFIG_NET_VENDOR_VIA=y
++CONFIG_NET_VENDOR_WIZNET=y
++CONFIG_NEW_LEDS=y
++CONFIG_NFC=m
++CONFIG_NODES_SHIFT=2
++CONFIG_NOZOMI=m
++CONFIG_NR_CPUS=128
++CONFIG_NTB=m
++# CONFIG_NTFS_RW is not set
++CONFIG_NUMA=y
++CONFIG_NUMA_BALANCING_DEFAULT_ENABLED=y
++CONFIG_NVMEM=m
++CONFIG_N_GSM=m
++CONFIG_OF=y
++CONFIG_OMFS_FS=m
++# CONFIG_OPENNSL is not set
++CONFIG_OSF_PARTITION=y
++# CONFIG_PAGE_EXTENSION is not set
++CONFIG_PANIC_TIMEOUT=0
++CONFIG_PARPORT=m
++CONFIG_PATA_SIS=m
++CONFIG_PCIPCWATCHDOG=m
++CONFIG_PCI_PASID=y
++CONFIG_PCI_PRI=y
++CONFIG_PCI_QUIRKS=y
++CONFIG_PGTABLE_LEVELS=4
++CONFIG_PGTABLE_MAPPING=y
++CONFIG_PHANTOM=m
++CONFIG_PHONET=m
++CONFIG_PHYLIB=y
++CONFIG_PHYS_ADDR_T_64BIT=y
++# CONFIG_PHY_EXYNOS5250_USB2 is not set
++CONFIG_PHY_PXA_28NM_HSIC=m
++CONFIG_PHY_PXA_28NM_USB2=m
++# CONFIG_PINCTRL_BERLIN_BG2 is not set
++# CONFIG_PINCTRL_BERLIN_BG2CD is not set
++# CONFIG_PINCTRL_BERLIN_BG2Q is not set
++# CONFIG_PINCTRL_MT8127 is not set
++# CONFIG_PINCTRL_MT8135 is not set
++CONFIG_PM_DEBUG=y
++CONFIG_PM_DEVFREQ=y
++CONFIG_PM_WAKELOCKS=y
++CONFIG_POWERCAP=y
++CONFIG_POWER_AVS=y
++CONFIG_POWER_SUPPLY=y
++CONFIG_PPP=y
++CONFIG_PPS=m
++CONFIG_PPS_CLIENT_GPIO=m
++CONFIG_PPS_CLIENT_LDISC=m
++# CONFIG_PREEMPT is not set
++# CONFIG_PREEMPT_NONE is not set
++CONFIG_PREEMPT_VOLUNTARY=y
++# CONFIG_PROBE_EVENTS is not set
++CONFIG_PSTORE=y
++# CONFIG_PSTORE_CONSOLE is not set
++CONFIG_PSTORE_RAM=m
++CONFIG_PTP_1588_CLOCK=m
++CONFIG_PWM=y
++CONFIG_QNX4FS_FS=m
++CONFIG_QNX6FS_FS=m
++CONFIG_R3964=m
++CONFIG_RAW_DRIVER=m
++CONFIG_RCU_CPU_STALL_TIMEOUT=60
++CONFIG_REED_SOLOMON=m
++CONFIG_REGULATOR=y
++CONFIG_REGULATOR_FIXED_VOLTAGE=m
++CONFIG_REGULATOR_TWL4030=m
++CONFIG_REISERFS_FS=m
++CONFIG_RESET_CONTROLLER=y
++CONFIG_RFKILL=y
++CONFIG_ROMFS_FS=m
++CONFIG_RTC_DRV_DS3232=m
++CONFIG_RTC_DRV_PCF8523=m
++CONFIG_RTC_DRV_PL031=m
++CONFIG_RTC_DRV_TWL4030=m
++CONFIG_SATA_AHCI_PLATFORM=m
++CONFIG_SATA_SVW=m
++CONFIG_SCHED_SMT=y
++CONFIG_SCSI_3W_9XXX=m
++CONFIG_SCSI_3W_SAS=m
++CONFIG_SCSI_AACRAID=m
++CONFIG_SCSI_ACARD=m
++CONFIG_SCSI_ADVANSYS=m
++CONFIG_SCSI_AIC79XX=m
++CONFIG_SCSI_AIC7XXX=m
++CONFIG_SCSI_AIC94XX=m
++CONFIG_SCSI_AM53C974=m
++CONFIG_SCSI_ARCMSR=m
++CONFIG_SCSI_BFA_FC=m
++CONFIG_SCSI_BNX2X_FCOE=m
++CONFIG_SCSI_BNX2_ISCSI=m
++CONFIG_SCSI_CHELSIO_FCOE=m
++CONFIG_SCSI_CXGB3_ISCSI=m
++CONFIG_SCSI_CXGB4_ISCSI=m
++CONFIG_SCSI_DC395x=m
++CONFIG_SCSI_DMX3191D=m
++CONFIG_SCSI_ESAS2R=m
++CONFIG_SCSI_FUTURE_DOMAIN=m
++CONFIG_SCSI_HPSA=m
++CONFIG_SCSI_HPTIOP=m
++CONFIG_SCSI_INIA100=m
++CONFIG_SCSI_INITIO=m
++CONFIG_SCSI_IPS=m
++CONFIG_SCSI_LPFC=m
++CONFIG_SCSI_MVSAS=m
++CONFIG_SCSI_MVUMI=m
++CONFIG_SCSI_PM8001=m
++CONFIG_SCSI_PMCRAID=m
++CONFIG_SCSI_QLA_FC=m
++CONFIG_SCSI_QLA_ISCSI=m
++CONFIG_SCSI_QLOGIC_1280=m
++CONFIG_SCSI_SNIC=m
++CONFIG_SCSI_SRP_ATTRS=m
++CONFIG_SCSI_STEX=m
++CONFIG_SCSI_SYM53C8XX_2=m
++CONFIG_SCSI_UFSHCD=m
++CONFIG_SCSI_WD719X=m
++CONFIG_SECURITY_SELINUX_BOOTPARAM=y
++CONFIG_SECURITY_SELINUX_DISABLE=y
++CONFIG_SENSORS_SCH56XX_COMMON=m
++CONFIG_SERIAL_8250=y
++CONFIG_SERIAL_8250_DW=y
++CONFIG_SERIAL_8250_FSL=y
++CONFIG_SERIAL_ALTERA_JTAGUART=m
++CONFIG_SERIAL_ALTERA_UART=m
++CONFIG_SERIAL_ARC=m
++CONFIG_SERIAL_CORE=y
++CONFIG_SERIAL_FSL_LPUART=m
++CONFIG_SERIAL_JSM=m
++CONFIG_SERIAL_NONSTANDARD=y
++CONFIG_SERIAL_RP2=m
++CONFIG_SERIAL_SCCNXP=y
++CONFIG_SERIO=y
++CONFIG_SFC=m
++CONFIG_SGI_IOC4=m
++CONFIG_SGI_PARTITION=y
++# CONFIG_SH_TIMER_CMT is not set
++# CONFIG_SH_TIMER_MTU2 is not set
++# CONFIG_SH_TIMER_TMU is not set
++CONFIG_SLIP=m
++CONFIG_SMC91X=y
++CONFIG_SND=m
++CONFIG_SND_DMAENGINE_PCM=m
++CONFIG_SND_EMU10K1_SEQ=m
++# CONFIG_SND_OPL4_LIB_SEQ is not set
++CONFIG_SND_PCM=m
++# CONFIG_SND_SBAWE_SEQ is not set
++CONFIG_SND_SOC=m
++CONFIG_SND_SOC_FSL_SSI=m
++CONFIG_SND_SOC_I2C_AND_SPI=m
++CONFIG_SND_SOC_IMX_AUDMUX=m
++CONFIG_SND_SOC_RT5677_SPI=m
++CONFIG_SND_SOC_SGTL5000=m
++CONFIG_SND_TIMER=m
++CONFIG_SOC_TI=y
++CONFIG_SOLARIS_X86_PARTITION=y
++CONFIG_SOUND=m
++CONFIG_SPI=y
++CONFIG_SPI_PXA2XX_PCI=m
++CONFIG_SPMI=m
++CONFIG_SRAM=y
++CONFIG_SSB=m
++CONFIG_STAGING=y
++CONFIG_STANDALONE=y
++CONFIG_STE_MODEM_RPROC=m
++CONFIG_SUN_PARTITION=y
++CONFIG_SYSV68_PARTITION=y
++CONFIG_SYSV_FS=m
++CONFIG_SYS_HYPERVISOR=y
++CONFIG_THERMAL=y
++CONFIG_THUNDERBOLT=m
++CONFIG_TIFM_CORE=m
++CONFIG_TIGON3=m
++CONFIG_TI_CPSW_ALE=m
++CONFIG_TRACE_SINK=m
++CONFIG_TTY_PRINTK=y
++CONFIG_UFS_FS=m
++CONFIG_UIO=m
++CONFIG_ULTRIX_PARTITION=y
++CONFIG_UNIXWARE_DISKLABEL=y
++# CONFIG_UPROBES is not set
++CONFIG_USB_EHCI_HCD_PLATFORM=m
++CONFIG_USB_GADGET=m
++# CONFIG_USB_G_MULTI is not set
++CONFIG_USB_HCD_BCMA=m
++CONFIG_USB_HCD_SSB=m
++CONFIG_USB_MUSB_HDRC=m
++CONFIG_USB_OHCI_HCD_PLATFORM=m
++CONFIG_USB_SUPPORT=y
++CONFIG_UWB=m
++CONFIG_VFIO=m
++CONFIG_VFIO_IOMMU_TYPE1=m
++CONFIG_VFIO_PCI=m
++CONFIG_VFIO_VIRQFD=m
++CONFIG_VGASTATE=m
++CONFIG_VIRTIO_MMIO=y
++CONFIG_VME_BUS=y
++CONFIG_VMXNET3=m
++CONFIG_VXFS_FS=m
++CONFIG_W1=m
++CONFIG_WAN=y
++CONFIG_WDTPCI=m
++CONFIG_WIMAX=m
++CONFIG_X25=m
++CONFIG_XEN=y
++CONFIG_XILINX_WATCHDOG=m
++CONFIG_XILLYBUS=m
++CONFIG_XZ_DEC_ARM=y
++CONFIG_XZ_DEC_ARMTHUMB=y
++CONFIG_XZ_DEC_BCJ=y
++CONFIG_XZ_DEC_IA64=y
++CONFIG_XZ_DEC_POWERPC=y
++CONFIG_XZ_DEC_SPARC=y
++CONFIG_XZ_DEC_TEST=m
++CONFIG_XZ_DEC_X86=y
++CONFIG_ZLIB_DEFLATE=y
++CONFIG_ZONE_DMA_FLAG=1
+diff --git a/debian.master/config/arm64/config.flavour.generic b/debian.master/config/arm64/config.flavour.generic
+new file mode 100644
+index 0000000..bb7773a
+--- /dev/null
++++ b/debian.master/config/arm64/config.flavour.generic
+@@ -0,0 +1,3 @@
++#
++# Config options for config.flavour.generic automatically generated by splitconfig.pl
++#
+diff --git a/debian.master/config/armhf/config.common.armhf b/debian.master/config/armhf/config.common.armhf
+new file mode 100644
+index 0000000..ff5a338
+--- /dev/null
++++ b/debian.master/config/armhf/config.common.armhf
+@@ -0,0 +1,461 @@
++#
++# Config options for config.common.armhf automatically generated by splitconfig.pl
++#
++CONFIG_6LOWPAN=m
++CONFIG_ABX500_CORE=y
++CONFIG_AC97_BUS=y
++CONFIG_ADFS_FS=m
++CONFIG_AFFS_FS=m
++CONFIG_AIX_PARTITION=y
++CONFIG_ALIM7101_WDT=m
++CONFIG_ALTERA_TSE=m
++CONFIG_AMIGA_PARTITION=y
++# CONFIG_APM_EMULATION is not set
++CONFIG_APPLICOM=m
++CONFIG_ARCH_DMA_ADDR_T_64BIT=y
++CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED=y
++CONFIG_ARCH_ROCKCHIP=y
++# CONFIG_ARCH_SELECT_MEMORY_MODEL is not set
++# CONFIG_ARCH_SPARSEMEM_DEFAULT is not set
++CONFIG_ARCNET=m
++# CONFIG_ARM_SMMU is not set
++CONFIG_ATALK=m
++CONFIG_ATARI_PARTITION=y
++CONFIG_ATA_GENERIC=m
++# CONFIG_ATA_NONSTANDARD is not set
++CONFIG_ATA_OVER_ETH=m
++CONFIG_ATA_PIIX=m
++CONFIG_ATM=m
++# CONFIG_AUDIT_ARCH_COMPAT_GENERIC is not set
++CONFIG_AUTOFS4_FS=m
++CONFIG_AUXDISPLAY=y
++CONFIG_BACKLIGHT_LCD_SUPPORT=y
++CONFIG_BATMAN_ADV=m
++CONFIG_BCH=y
++CONFIG_BCMA=m
++CONFIG_BCM_KONA_USB2_PHY=m
++CONFIG_BE2ISCSI=m
++CONFIG_BEFS_FS=m
++CONFIG_BFS_FS=m
++CONFIG_BLK_CPQ_CISS_DA=m
++CONFIG_BLK_DEV_3W_XXXX_RAID=m
++CONFIG_BLK_DEV_CRYPTOLOOP=m
++CONFIG_BLK_DEV_DAC960=m
++CONFIG_BLK_DEV_NVME=m
++CONFIG_BLK_DEV_PCIESSD_MTIP32XX=m
++CONFIG_BLK_DEV_RSXX=m
++# CONFIG_BLK_DEV_SR_VENDOR is not set
++CONFIG_BLK_DEV_SX8=m
++CONFIG_BLK_DEV_UMEM=m
++CONFIG_BOUNCE=y
++CONFIG_BSD_DISKLABEL=y
++CONFIG_C2PORT=m
++CONFIG_CADENCE_WATCHDOG=m
++CONFIG_CAIF=m
++CONFIG_CAN=m
++CONFIG_CB710_CORE=m
++CONFIG_CC_STACKPROTECTOR=y
++CONFIG_CDROM_PKTCDVD=m
++CONFIG_CMA=y
++CONFIG_CMDLINE=""
++CONFIG_CMDLINE_PARTITION=y
++CONFIG_CONFIGFS_FS=m
++# CONFIG_CPU_BIG_ENDIAN is not set
++CONFIG_CRAMFS=m
++CONFIG_CRASH_DUMP=y
++CONFIG_CRYPTO_DEV_FSL_CAAM_IMX=y
++CONFIG_CRYPTO_DEV_FSL_CAAM_LE=y
++# CONFIG_CXL_BASE is not set
++# CONFIG_CXL_EEH is not set
++# CONFIG_CXL_KERNEL_API is not set
++CONFIG_DECNET=m
++CONFIG_DEFAULT_MMAP_MIN_ADDR=32768
++CONFIG_DMADEVICES=y
++CONFIG_DMA_SHARED_BUFFER=y
++CONFIG_DMA_VIRTUAL_CHANNELS=y
++# CONFIG_DM_DEBUG is not set
++CONFIG_DNET=m
++CONFIG_DRM=m
++CONFIG_DUMMY_IRQ=m
++CONFIG_DW_WATCHDOG=m
++CONFIG_ECHO=m
++CONFIG_EEPROM_93CX6=m
++CONFIG_EFS_FS=m
++CONFIG_EM_TIMER_STI=y
++CONFIG_ENCLOSURE_SERVICES=m
++CONFIG_ETHOC=m
++CONFIG_EXOFS_FS=m
++CONFIG_EXTCON=y
++CONFIG_F2FS_FS=m
++CONFIG_FB=y
++CONFIG_FB_ATY128=m
++# CONFIG_FB_BOOT_VESA_SUPPORT is not set
++CONFIG_FB_IBM_GXT4500=m
++# CONFIG_FB_MACMODES is not set
++CONFIG_FB_SYS_COPYAREA=m
++CONFIG_FB_SYS_FILLRECT=m
++CONFIG_FB_SYS_FOPS=m
++CONFIG_FB_SYS_IMAGEBLIT=m
++CONFIG_FB_UDL=m
++CONFIG_FB_VOODOO1=m
++CONFIG_FDDI=y
++CONFIG_FEALNX=m
++CONFIG_FIREWIRE=m
++CONFIG_FIREWIRE_NOSY=m
++CONFIG_FIRMWARE_IN_KERNEL=y
++CONFIG_FIXED_PHY=y
++CONFIG_FMC=m
++CONFIG_FONTS=y
++CONFIG_FRAME_WARN=1024
++CONFIG_FUSION=y
++CONFIG_GAMEPORT=m
++CONFIG_GENERIC_PHY=y
++CONFIG_GPIO_GENERIC=y
++CONFIG_GPIO_GENERIC_PLATFORM=y
++CONFIG_GPIO_TWL4030=y
++CONFIG_GPIO_TWL6040=y
++# CONFIG_HAVE_64BIT_ALIGNED_ACCESS is not set
++# CONFIG_HAVE_AOUT is not set
++CONFIG_HAVE_ARCH_BITREVERSE=y
++# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
++CONFIG_HAVE_GENERIC_DMA_COHERENT=y
++CONFIG_HFSPLUS_FS=m
++CONFIG_HFS_FS=m
++CONFIG_HIBERNATION=y
++# CONFIG_HIO is not set
++CONFIG_HPFS_FS=m
++CONFIG_HP_ILO=m
++CONFIG_HSI=m
++CONFIG_HSR=m
++CONFIG_HTC_PASIC3=m
++CONFIG_HWMON=y
++CONFIG_HW_RANDOM_TIMERIOMEM=m
++CONFIG_HZ=250
++# CONFIG_HZ_100 is not set
++# CONFIG_HZ_1000 is not set
++CONFIG_HZ_250=y
++CONFIG_I2C=y
++CONFIG_I2C_SLAVE=y
++CONFIG_I6300ESB_WDT=m
++CONFIG_IEEE802154=m
++CONFIG_IIO=m
++CONFIG_IMA=y
++CONFIG_INFINIBAND_NES=m
++CONFIG_INFINIBAND_OCRDMA=m
++CONFIG_INPUT=y
++CONFIG_IPACK_BUS=m
++CONFIG_IPMI_HANDLER=m
++# CONFIG_IPMI_SI_PROBE_DEFAULTS is not set
++CONFIG_IPX=m
++# CONFIG_IP_DCCP_CCID3 is not set
++CONFIG_IRQ_BYPASS_MANAGER=m
++# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
++CONFIG_JFS_FS=m
++CONFIG_JME=m
++# CONFIG_JUMP_LABEL is not set
++CONFIG_KARMA_PARTITION=y
++CONFIG_KERNEL_GZIP=y
++# CONFIG_KERNEL_XZ is not set
++CONFIG_KVM=y
++CONFIG_LAPB=m
++CONFIG_LDM_PARTITION=y
++CONFIG_LIBNVDIMM=y
++CONFIG_LLC2=m
++CONFIG_LOG_BUF_SHIFT=17
++CONFIG_LPC_ICH=m
++CONFIG_LPC_SCH=m
++CONFIG_MAC_PARTITION=y
++CONFIG_MAGIC_SYSRQ_DEFAULT_ENABLE=0x1
++CONFIG_MAILBOX=y
++CONFIG_MAX63XX_WATCHDOG=m
++CONFIG_MCB=m
++CONFIG_MD_MULTIPATH=m
++CONFIG_MEDIA_SUPPORT=m
++CONFIG_MEGARAID_LEGACY=m
++CONFIG_MEGARAID_NEWGEN=y
++CONFIG_MEGARAID_SAS=m
++CONFIG_MEMORY=y
++CONFIG_MEMSTICK=m
++CONFIG_MFD_CORE=y
++CONFIG_MFD_JANZ_CMODIO=m
++CONFIG_MFD_KEMPLD=m
++CONFIG_MFD_MT6397=m
++CONFIG_MFD_RDC321X=m
++CONFIG_MFD_RTSX_PCI=m
++CONFIG_MFD_SM501=y
++CONFIG_MFD_SYSCON=y
++CONFIG_MFD_TI_AM335X_TSCADC=m
++CONFIG_MFD_TMIO=y
++CONFIG_MFD_VX855=m
++CONFIG_MII=m
++CONFIG_MINIX_FS=m
++CONFIG_MINIX_SUBPARTITION=y
++CONFIG_MMC=y
++CONFIG_MMC_BLOCK=y
++CONFIG_MMC_SDHCI=y
++CONFIG_MMC_SDHCI_PLTFM=y
++CONFIG_MTD=y
++CONFIG_MTD_BLKDEVS=y
++CONFIG_MTD_BLOCK=y
++CONFIG_MTD_CMDLINE_PARTS=y
++CONFIG_MTD_NAND=y
++CONFIG_MTD_NAND_BCH=y
++CONFIG_MTD_NAND_ECC=y
++CONFIG_MTD_NAND_IDS=y
++CONFIG_MTD_NAND_OMAP_BCH_BUILD=y
++CONFIG_MTD_OF_PARTS=y
++CONFIG_NCP_FS=m
++CONFIG_NEED_DMA_MAP_STATE=y
++CONFIG_NET_CADENCE=y
++CONFIG_NET_PACKET_ENGINE=y
++CONFIG_NET_VENDOR_3COM=y
++CONFIG_NET_VENDOR_ADAPTEC=y
++CONFIG_NET_VENDOR_AGERE=y
++CONFIG_NET_VENDOR_ALTEON=y
++CONFIG_NET_VENDOR_AMD=y
++CONFIG_NET_VENDOR_ARC=y
++CONFIG_NET_VENDOR_ATHEROS=y
++CONFIG_NET_VENDOR_BROADCOM=y
++CONFIG_NET_VENDOR_BROCADE=y
++CONFIG_NET_VENDOR_CAVIUM=y
++CONFIG_NET_VENDOR_CHELSIO=y
++CONFIG_NET_VENDOR_CISCO=y
++CONFIG_NET_VENDOR_DEC=y
++CONFIG_NET_VENDOR_DLINK=y
++CONFIG_NET_VENDOR_EMULEX=y
++CONFIG_NET_VENDOR_EXAR=y
++CONFIG_NET_VENDOR_EZCHIP=y
++CONFIG_NET_VENDOR_HP=y
++CONFIG_NET_VENDOR_INTEL=y
++CONFIG_NET_VENDOR_MARVELL=y
++CONFIG_NET_VENDOR_MICREL=y
++CONFIG_NET_VENDOR_MYRI=y
++CONFIG_NET_VENDOR_NATSEMI=y
++CONFIG_NET_VENDOR_NVIDIA=y
++CONFIG_NET_VENDOR_OKI=y
++CONFIG_NET_VENDOR_QLOGIC=y
++CONFIG_NET_VENDOR_QUALCOMM=y
++CONFIG_NET_VENDOR_RDC=y
++CONFIG_NET_VENDOR_REALTEK=y
++CONFIG_NET_VENDOR_RENESAS=y
++CONFIG_NET_VENDOR_ROCKER=y
++CONFIG_NET_VENDOR_SAMSUNG=y
++CONFIG_NET_VENDOR_SEEQ=y
++CONFIG_NET_VENDOR_SILAN=y
++CONFIG_NET_VENDOR_SIS=y
++CONFIG_NET_VENDOR_SMSC=y
++CONFIG_NET_VENDOR_STMICRO=y
++CONFIG_NET_VENDOR_SUN=y
++CONFIG_NET_VENDOR_SYNOPSYS=y
++CONFIG_NET_VENDOR_TEHUTI=y
++CONFIG_NET_VENDOR_TI=y
++CONFIG_NET_VENDOR_VIA=y
++CONFIG_NET_VENDOR_WIZNET=y
++CONFIG_NEW_LEDS=y
++CONFIG_NFC=m
++CONFIG_NOZOMI=m
++CONFIG_NR_CPUS=4
++CONFIG_NTB=m
++# CONFIG_NTFS_RW is not set
++CONFIG_NVMEM=m
++CONFIG_NVRAM=m
++CONFIG_N_GSM=m
++CONFIG_OF=y
++CONFIG_OMFS_FS=m
++# CONFIG_OPENNSL is not set
++CONFIG_OSF_PARTITION=y
++CONFIG_PAGE_EXTENSION=y
++CONFIG_PAGE_OFFSET=0xC0000000
++CONFIG_PANIC_TIMEOUT=0
++CONFIG_PARPORT=m
++CONFIG_PATA_SIS=m
++# CONFIG_PCCARD is not set
++CONFIG_PCIPCWATCHDOG=m
++CONFIG_PCI_PASID=y
++CONFIG_PCI_PRI=y
++CONFIG_PCI_QUIRKS=y
++CONFIG_PGTABLE_MAPPING=y
++CONFIG_PHANTOM=m
++CONFIG_PHONET=m
++CONFIG_PHYLIB=y
++CONFIG_PHY_EXYNOS5250_USB2=y
++CONFIG_PHY_PXA_28NM_HSIC=m
++CONFIG_PHY_PXA_28NM_USB2=m
++CONFIG_PINCTRL_BERLIN_BG2=y
++CONFIG_PINCTRL_BERLIN_BG2CD=y
++CONFIG_PINCTRL_BERLIN_BG2Q=y
++CONFIG_PINCTRL_MT8127=y
++CONFIG_PINCTRL_MT8135=y
++CONFIG_PM_DEBUG=y
++CONFIG_PM_DEVFREQ=y
++CONFIG_PM_WAKELOCKS=y
++CONFIG_POWERCAP=y
++CONFIG_POWER_AVS=y
++CONFIG_POWER_SUPPLY=y
++CONFIG_PPP=y
++CONFIG_PPS=y
++CONFIG_PPS_CLIENT_GPIO=m
++CONFIG_PPS_CLIENT_LDISC=m
++# CONFIG_PREEMPT is not set
++# CONFIG_PREEMPT_NONE is not set
++CONFIG_PREEMPT_VOLUNTARY=y
++CONFIG_PROBE_EVENTS=y
++CONFIG_PSTORE=y
++CONFIG_PSTORE_CONSOLE=y
++CONFIG_PSTORE_RAM=y
++CONFIG_PTP_1588_CLOCK=y
++CONFIG_PWM=y
++CONFIG_QNX4FS_FS=m
++CONFIG_QNX6FS_FS=m
++CONFIG_R3964=m
++CONFIG_RAW_DRIVER=m
++CONFIG_RCU_CPU_STALL_TIMEOUT=60
++CONFIG_REED_SOLOMON=y
++CONFIG_REGULATOR=y
++CONFIG_REGULATOR_FIXED_VOLTAGE=y
++CONFIG_REISERFS_FS=m
++CONFIG_RESET_CONTROLLER=y
++CONFIG_RFKILL=y
++CONFIG_ROMFS_FS=m
++CONFIG_RTC_DRV_CMOS=m
++CONFIG_RTC_DRV_DS3232=m
++CONFIG_RTC_DRV_PL031=y
++CONFIG_RTC_DRV_TWL4030=y
++CONFIG_SATA_AHCI_PLATFORM=y
++CONFIG_SATA_SVW=m
++# CONFIG_SCHED_SMT is not set
++CONFIG_SCSI_3W_9XXX=m
++CONFIG_SCSI_3W_SAS=m
++CONFIG_SCSI_AACRAID=m
++CONFIG_SCSI_ACARD=m
++CONFIG_SCSI_ADVANSYS=m
++CONFIG_SCSI_AIC79XX=m
++CONFIG_SCSI_AIC7XXX=m
++CONFIG_SCSI_AIC94XX=m
++CONFIG_SCSI_AM53C974=m
++CONFIG_SCSI_ARCMSR=m
++CONFIG_SCSI_BFA_FC=m
++CONFIG_SCSI_BNX2X_FCOE=m
++CONFIG_SCSI_BNX2_ISCSI=m
++CONFIG_SCSI_CHELSIO_FCOE=m
++CONFIG_SCSI_CXGB3_ISCSI=m
++CONFIG_SCSI_CXGB4_ISCSI=m
++CONFIG_SCSI_DC395x=m
++CONFIG_SCSI_DMX3191D=m
++CONFIG_SCSI_ESAS2R=m
++CONFIG_SCSI_FUTURE_DOMAIN=m
++CONFIG_SCSI_HPSA=m
++CONFIG_SCSI_HPTIOP=m
++CONFIG_SCSI_INIA100=m
++CONFIG_SCSI_INITIO=m
++CONFIG_SCSI_IPS=m
++CONFIG_SCSI_LPFC=m
++CONFIG_SCSI_MVSAS=m
++CONFIG_SCSI_MVUMI=m
++CONFIG_SCSI_PM8001=m
++CONFIG_SCSI_PMCRAID=m
++CONFIG_SCSI_QLA_FC=m
++CONFIG_SCSI_QLA_ISCSI=m
++CONFIG_SCSI_QLOGIC_1280=m
++CONFIG_SCSI_SNIC=m
++CONFIG_SCSI_SRP_ATTRS=m
++CONFIG_SCSI_STEX=m
++CONFIG_SCSI_SYM53C8XX_2=m
++CONFIG_SCSI_UFSHCD=m
++CONFIG_SCSI_WD719X=m
++CONFIG_SECURITY_SELINUX_BOOTPARAM=y
++CONFIG_SECURITY_SELINUX_DISABLE=y
++CONFIG_SENSORS_SCH56XX_COMMON=m
++CONFIG_SERIAL_8250=y
++CONFIG_SERIAL_8250_DW=m
++CONFIG_SERIAL_8250_FSL=y
++CONFIG_SERIAL_ALTERA_JTAGUART=m
++CONFIG_SERIAL_ALTERA_UART=m
++CONFIG_SERIAL_ARC=m
++CONFIG_SERIAL_CORE=y
++CONFIG_SERIAL_FSL_LPUART=m
++CONFIG_SERIAL_JSM=m
++CONFIG_SERIAL_NONSTANDARD=y
++CONFIG_SERIAL_RP2=m
++CONFIG_SERIAL_SCCNXP=y
++CONFIG_SERIO=y
++CONFIG_SFC=m
++CONFIG_SGI_IOC4=m
++CONFIG_SGI_PARTITION=y
++CONFIG_SH_TIMER_CMT=y
++CONFIG_SH_TIMER_MTU2=y
++CONFIG_SH_TIMER_TMU=y
++CONFIG_SLIP=m
++CONFIG_SMC91X=m
++CONFIG_SND=y
++CONFIG_SND_DMAENGINE_PCM=y
++# CONFIG_SND_OPL4_LIB_SEQ is not set
++CONFIG_SND_PCM=y
++# CONFIG_SND_SBAWE_SEQ is not set
++CONFIG_SND_SOC=y
++CONFIG_SND_SOC_I2C_AND_SPI=y
++CONFIG_SND_SOC_RT5677_SPI=m
++CONFIG_SND_TIMER=y
++CONFIG_SOC_TI=y
++CONFIG_SOLARIS_X86_PARTITION=y
++CONFIG_SOUND=y
++CONFIG_SPI=y
++CONFIG_SPI_PXA2XX_PCI=m
++CONFIG_SPMI=m
++CONFIG_SRAM=y
++CONFIG_SSB=m
++CONFIG_STAGING=y
++CONFIG_STANDALONE=y
++CONFIG_STE_MODEM_RPROC=m
++CONFIG_SUN_PARTITION=y
++CONFIG_SYSV68_PARTITION=y
++CONFIG_SYSV_FS=m
++# CONFIG_SYS_HYPERVISOR is not set
++CONFIG_THERMAL=y
++CONFIG_THUNDERBOLT=m
++CONFIG_TIFM_CORE=m
++CONFIG_TIGON3=m
++CONFIG_TI_CPSW_ALE=y
++CONFIG_TRACE_SINK=m
++CONFIG_TTY_PRINTK=y
++CONFIG_UFS_FS=m
++CONFIG_UIO=m
++CONFIG_ULTRIX_PARTITION=y
++CONFIG_UNIXWARE_DISKLABEL=y
++CONFIG_UPROBES=y
++# CONFIG_USB_EHCI_HCD_PLATFORM is not set
++CONFIG_USB_FSL_MPH_DR_OF=m
++CONFIG_USB_GADGET=y
++CONFIG_USB_G_MULTI=m
++# CONFIG_USB_HCD_BCMA is not set
++# CONFIG_USB_HCD_SSB is not set
++CONFIG_USB_MUSB_HDRC=y
++# CONFIG_USB_OHCI_HCD_PLATFORM is not set
++CONFIG_USB_SUPPORT=y
++CONFIG_UWB=m
++CONFIG_VFIO=m
++# CONFIG_VFIO_IOMMU_TYPE1 is not set
++CONFIG_VFIO_PCI=m
++CONFIG_VFIO_VIRQFD=m
++CONFIG_VGASTATE=m
++CONFIG_VIRTIO_MMIO=y
++CONFIG_VME_BUS=y
++CONFIG_VMXNET3=m
++CONFIG_VXFS_FS=m
++CONFIG_W1=m
++CONFIG_WAN=y
++CONFIG_WDTPCI=m
++CONFIG_WIMAX=m
++CONFIG_X25=m
++# CONFIG_XEN is not set
++CONFIG_XILINX_WATCHDOG=m
++CONFIG_XILLYBUS=m
++CONFIG_XZ_DEC_ARM=y
++CONFIG_XZ_DEC_ARMTHUMB=y
++CONFIG_XZ_DEC_BCJ=y
++CONFIG_XZ_DEC_IA64=y
++CONFIG_XZ_DEC_POWERPC=y
++CONFIG_XZ_DEC_SPARC=y
++CONFIG_XZ_DEC_TEST=m
++CONFIG_XZ_DEC_X86=y
++CONFIG_ZLIB_DEFLATE=y
+diff --git a/debian.master/config/armhf/config.flavour.generic b/debian.master/config/armhf/config.flavour.generic
+new file mode 100644
+index 0000000..3cb6d65
+--- /dev/null
++++ b/debian.master/config/armhf/config.flavour.generic
+@@ -0,0 +1,25 @@
++#
++# Config options for config.flavour.generic automatically generated by splitconfig.pl
++#
++CONFIG_ARCH_MXC=y
++CONFIG_ARCH_OMAP3=y
++CONFIG_ARCH_OMAP4=y
++# CONFIG_ARCH_PHYS_ADDR_T_64BIT is not set
++CONFIG_ARCH_TEGRA=y
++CONFIG_ARM_ATAG_DTB_COMPAT=y
++# CONFIG_ARM_HIGHBANK_CPUIDLE is not set
++# CONFIG_ARM_LPAE is not set
++CONFIG_FB_CFB_REV_PIXELS_IN_BYTE=y
++CONFIG_FORCE_MAX_ZONEORDER=12
++# CONFIG_HUGETLB_PAGE is not set
++# CONFIG_IOMMU_IO_PGTABLE_LPAE is not set
++CONFIG_PGTABLE_LEVELS=2
++# CONFIG_PHYS_ADDR_T_64BIT is not set
++CONFIG_REGULATOR_TWL4030=y
++CONFIG_RTC_DRV_PCF8523=y
++# CONFIG_SND_EMU10K1_SEQ is not set
++CONFIG_SND_SOC_FSL_SSI=y
++CONFIG_SND_SOC_IMX_AUDMUX=y
++CONFIG_SND_SOC_SGTL5000=y
++CONFIG_SOC_AM33XX=y
++CONFIG_ZONE_DMA_FLAG=0
+diff --git a/debian.master/config/armhf/config.flavour.generic-lpae b/debian.master/config/armhf/config.flavour.generic-lpae
+new file mode 100644
+index 0000000..f9ab7fb
+--- /dev/null
++++ b/debian.master/config/armhf/config.flavour.generic-lpae
+@@ -0,0 +1,25 @@
++#
++# Config options for config.flavour.generic-lpae automatically generated by splitconfig.pl
++#
++# CONFIG_ARCH_MXC is not set
++# CONFIG_ARCH_OMAP3 is not set
++# CONFIG_ARCH_OMAP4 is not set
++CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
++# CONFIG_ARCH_TEGRA is not set
++# CONFIG_ARM_ATAG_DTB_COMPAT is not set
++CONFIG_ARM_HIGHBANK_CPUIDLE=y
++CONFIG_ARM_LPAE=y
++# CONFIG_FB_CFB_REV_PIXELS_IN_BYTE is not set
++CONFIG_FORCE_MAX_ZONEORDER=11
++CONFIG_HUGETLB_PAGE=y
++CONFIG_IOMMU_IO_PGTABLE_LPAE=y
++CONFIG_PGTABLE_LEVELS=3
++CONFIG_PHYS_ADDR_T_64BIT=y
++CONFIG_REGULATOR_TWL4030=m
++CONFIG_RTC_DRV_PCF8523=m
++CONFIG_SND_EMU10K1_SEQ=m
++CONFIG_SND_SOC_FSL_SSI=m
++CONFIG_SND_SOC_IMX_AUDMUX=m
++CONFIG_SND_SOC_SGTL5000=m
++# CONFIG_SOC_AM33XX is not set
++CONFIG_ZONE_DMA_FLAG=1
+diff --git a/debian.master/config/config.common.ports b/debian.master/config/config.common.ports
+new file mode 100644
+index 0000000..4574947
+--- /dev/null
++++ b/debian.master/config/config.common.ports
+@@ -0,0 +1,3 @@
++#
++# Common config options automatically generated by splitconfig.pl
++#
+diff --git a/debian.master/config/config.common.ubuntu b/debian.master/config/config.common.ubuntu
+new file mode 100644
+index 0000000..72734ae
+--- /dev/null
++++ b/debian.master/config/config.common.ubuntu
+@@ -0,0 +1,9121 @@
++#
++# Common config options automatically generated by splitconfig.pl
++#
++CONFIG_32BIT=y
++CONFIG_3C515=m
++# CONFIG_40x is not set
++# CONFIG_44x is not set
++CONFIG_60XX_WDT=m
++CONFIG_6LOWPAN_NHC=m
++CONFIG_6LOWPAN_NHC_DEST=m
++CONFIG_6LOWPAN_NHC_FRAGMENT=m
++CONFIG_6LOWPAN_NHC_HOP=m
++CONFIG_6LOWPAN_NHC_IPV6=m
++CONFIG_6LOWPAN_NHC_MOBILITY=m
++CONFIG_6LOWPAN_NHC_ROUTING=m
++CONFIG_6LOWPAN_NHC_UDP=m
++CONFIG_6PACK=m
++CONFIG_6xx=y
++CONFIG_8139CP=m
++CONFIG_8139TOO=m
++CONFIG_8139TOO_8129=y
++CONFIG_8139TOO_PIO=y
++# CONFIG_8139TOO_TUNE_TWISTER is not set
++# CONFIG_8139_OLD_RX_RESET is not set
++CONFIG_842_COMPRESS=m
++CONFIG_842_DECOMPRESS=m
++CONFIG_8723AU_AP_MODE=y
++CONFIG_8723AU_BT_COEXIST=y
++CONFIG_88EU_AP_MODE=y
++CONFIG_9P_FS=m
++CONFIG_9P_FSCACHE=y
++CONFIG_9P_FS_POSIX_ACL=y
++CONFIG_9P_FS_SECURITY=y
++CONFIG_AB3100_CORE=y
++CONFIG_AB3100_OTP=m
++# CONFIG_ACCESSIBILITY is not set
++CONFIG_ACENIC=m
++# CONFIG_ACENIC_OMIT_TIGON_I is not set
++CONFIG_ACERHDF=m
++CONFIG_ACER_WMI=m
++# CONFIG_ACORN_PARTITION is not set
++CONFIG_ACPI=y
++CONFIG_ACPI_AC=y
++CONFIG_ACPI_ALS=m
++CONFIG_ACPI_APEI=y
++CONFIG_ACPI_APEI_EINJ=m
++# CONFIG_ACPI_APEI_ERST_DEBUG is not set
++CONFIG_ACPI_APEI_GHES=y
++CONFIG_ACPI_APEI_MEMORY_FAILURE=y
++CONFIG_ACPI_APEI_PCIEAER=y
++CONFIG_ACPI_BATTERY=y
++CONFIG_ACPI_BGRT=y
++CONFIG_ACPI_BUTTON=y
++CONFIG_ACPI_CCA_REQUIRED=y
++CONFIG_ACPI_CMPC=m
++CONFIG_ACPI_CONTAINER=y
++CONFIG_ACPI_CPPC_CPUFREQ=m
++CONFIG_ACPI_CPPC_LIB=y
++CONFIG_ACPI_CPU_FREQ_PSS=y
++# CONFIG_ACPI_CUSTOM_DSDT is not set
++CONFIG_ACPI_CUSTOM_DSDT_FILE=""
++# CONFIG_ACPI_CUSTOM_METHOD is not set
++# CONFIG_ACPI_DEBUG is not set
++# CONFIG_ACPI_DEBUGGER is not set
++CONFIG_ACPI_DOCK=y
++CONFIG_ACPI_EC_DEBUGFS=m
++CONFIG_ACPI_EXTLOG=m
++CONFIG_ACPI_FAN=y
++CONFIG_ACPI_GENERIC_GSI=y
++CONFIG_ACPI_HED=y
++CONFIG_ACPI_HOTPLUG_CPU=y
++CONFIG_ACPI_HOTPLUG_IOAPIC=y
++CONFIG_ACPI_HOTPLUG_MEMORY=y
++CONFIG_ACPI_I2C_OPREGION=y
++# CONFIG_ACPI_INITRD_TABLE_OVERRIDE is not set
++CONFIG_ACPI_IPMI=m
++CONFIG_ACPI_LEGACY_TABLES_LOOKUP=y
++CONFIG_ACPI_NFIT=m
++# CONFIG_ACPI_NFIT_DEBUG is not set
++CONFIG_ACPI_NUMA=y
++CONFIG_ACPI_PCI_SLOT=y
++CONFIG_ACPI_PROCESSOR=y
++CONFIG_ACPI_PROCESSOR_AGGREGATOR=m
++CONFIG_ACPI_PROCESSOR_IDLE=y
++# CONFIG_ACPI_PROCFS_POWER is not set
++CONFIG_ACPI_REV_OVERRIDE_POSSIBLE=y
++CONFIG_ACPI_SBS=m
++CONFIG_ACPI_SLEEP=y
++CONFIG_ACPI_SYSTEM_POWER_STATES_SUPPORT=y
++CONFIG_ACPI_THERMAL=y
++CONFIG_ACPI_THERMAL_REL=m
++CONFIG_ACPI_TOSHIBA=m
++CONFIG_ACPI_VIDEO=m
++CONFIG_ACPI_WMI=m
++CONFIG_ACQUIRE_WDT=m
++CONFIG_ACT200L_DONGLE=m
++CONFIG_ACTISYS_DONGLE=m
++CONFIG_AD2S1200=m
++CONFIG_AD2S1210=m
++CONFIG_AD2S90=m
++CONFIG_AD5064=m
++CONFIG_AD525X_DPOT=m
++CONFIG_AD525X_DPOT_I2C=m
++CONFIG_AD525X_DPOT_SPI=m
++CONFIG_AD5360=m
++CONFIG_AD5380=m
++CONFIG_AD5421=m
++CONFIG_AD5446=m
++CONFIG_AD5449=m
++CONFIG_AD5504=m
++CONFIG_AD5592R=m
++CONFIG_AD5592R_BASE=m
++CONFIG_AD5593R=m
++CONFIG_AD5624R_SPI=m
++CONFIG_AD5686=m
++CONFIG_AD5755=m
++CONFIG_AD5764=m
++CONFIG_AD5791=m
++CONFIG_AD5933=m
++CONFIG_AD7150=m
++CONFIG_AD7152=m
++CONFIG_AD7192=m
++CONFIG_AD7266=m
++CONFIG_AD7280=m
++CONFIG_AD7291=m
++CONFIG_AD7298=m
++CONFIG_AD7303=m
++CONFIG_AD7476=m
++CONFIG_AD7606=m
++CONFIG_AD7606_IFACE_PARALLEL=m
++CONFIG_AD7606_IFACE_SPI=m
++CONFIG_AD7746=m
++CONFIG_AD7780=m
++CONFIG_AD7791=m
++CONFIG_AD7793=m
++CONFIG_AD7816=m
++CONFIG_AD7887=m
++CONFIG_AD7923=m
++CONFIG_AD799X=m
++CONFIG_AD8366=m
++CONFIG_AD9523=m
++CONFIG_AD9832=m
++CONFIG_AD9834=m
++CONFIG_ADAPTEC_STARFIRE=m
++CONFIG_ADB=y
++CONFIG_ADB_CUDA=y
++CONFIG_ADB_MACIO=y
++CONFIG_ADB_PMU=y
++CONFIG_ADB_PMU_LED=y
++CONFIG_ADE7753=m
++CONFIG_ADE7754=m
++CONFIG_ADE7758=m
++CONFIG_ADE7759=m
++CONFIG_ADE7854=m
++CONFIG_ADE7854_I2C=m
++CONFIG_ADE7854_SPI=m
++CONFIG_ADF4350=m
++# CONFIG_ADFS_FS_RW is not set
++CONFIG_ADIS16060=m
++CONFIG_ADIS16080=m
++CONFIG_ADIS16130=m
++CONFIG_ADIS16136=m
++CONFIG_ADIS16201=m
++CONFIG_ADIS16203=m
++CONFIG_ADIS16204=m
++CONFIG_ADIS16209=m
++CONFIG_ADIS16220=m
++CONFIG_ADIS16240=m
++CONFIG_ADIS16260=m
++CONFIG_ADIS16400=m
++CONFIG_ADIS16480=m
++CONFIG_ADJD_S311=m
++CONFIG_ADM8211=m
++CONFIG_ADT7316=m
++CONFIG_ADT7316_I2C=m
++CONFIG_ADT7316_SPI=m
++# CONFIG_ADVANCED_OPTIONS is not set
++CONFIG_ADVANTECH_WDT=m
++CONFIG_ADVISE_SYSCALLS=y
++CONFIG_ADXRS450=m
++CONFIG_AD_SIGMA_DELTA=m
++CONFIG_AEABI=y
++CONFIG_AFIUCV=m
++# CONFIG_AFS_DEBUG is not set
++CONFIG_AFS_FS=m
++CONFIG_AFS_FSCACHE=y
++CONFIG_AF_RXRPC=m
++# CONFIG_AF_RXRPC_DEBUG is not set
++CONFIG_AGP=y
++CONFIG_AGP_ALI=m
++CONFIG_AGP_AMD=y
++CONFIG_AGP_AMD64=y
++CONFIG_AGP_ATI=m
++CONFIG_AGP_EFFICEON=m
++CONFIG_AGP_INTEL=y
++CONFIG_AGP_NVIDIA=y
++CONFIG_AGP_SIS=m
++CONFIG_AGP_SWORKS=m
++CONFIG_AGP_UNINORTH=m
++CONFIG_AGP_VIA=y
++CONFIG_AHCI_CEVA=m
++CONFIG_AHCI_IMX=y
++CONFIG_AHCI_MVEBU=m
++CONFIG_AHCI_QORIQ=m
++CONFIG_AHCI_TEGRA=m
++CONFIG_AHCI_XGENE=m
++CONFIG_AIC79XX_CMDS_PER_DEVICE=32
++# CONFIG_AIC79XX_DEBUG_ENABLE is not set
++CONFIG_AIC79XX_DEBUG_MASK=0
++CONFIG_AIC79XX_REG_PRETTY_PRINT=y
++CONFIG_AIC79XX_RESET_DELAY_MS=5000
++CONFIG_AIC7XXX_CMDS_PER_DEVICE=8
++# CONFIG_AIC7XXX_DEBUG_ENABLE is not set
++CONFIG_AIC7XXX_DEBUG_MASK=0
++CONFIG_AIC7XXX_REG_PRETTY_PRINT=y
++CONFIG_AIC7XXX_RESET_DELAY_MS=5000
++# CONFIG_AIC94XX_DEBUG is not set
++CONFIG_AIM_CDEV=m
++CONFIG_AIM_NETWORK=m
++CONFIG_AIM_SOUND=m
++CONFIG_AIM_V4L2=m
++CONFIG_AIO=y
++CONFIG_AIRO=m
++CONFIG_AIRO_CS=m
++CONFIG_AK09911=m
++CONFIG_AK8975=m
++CONFIG_AL3320A=m
++CONFIG_ALIENWARE_WMI=m
++CONFIG_ALIGNMENT_TRAP=y
++CONFIG_ALIM1535_WDT=m
++CONFIG_ALIX=y
++CONFIG_ALI_FIR=m
++CONFIG_ALLOW_DEV_COREDUMP=y
++CONFIG_ALTERA_MBOX=m
++CONFIG_ALTERA_STAPL=m
++CONFIG_ALTIVEC=y
++CONFIG_ALX=m
++CONFIG_AM335X_CONTROL_USB=m
++CONFIG_AM335X_PHY_USB=m
++CONFIG_AMBA_PL08X=y
++CONFIG_AMD8111_ETH=m
++CONFIG_AMD_IOMMU=y
++CONFIG_AMD_IOMMU_STATS=y
++CONFIG_AMD_IOMMU_V2=m
++CONFIG_AMD_MCE_INJ=m
++CONFIG_AMD_NB=y
++CONFIG_AMD_NUMA=y
++CONFIG_AMD_PHY=m
++CONFIG_AMD_XGBE=m
++CONFIG_AMD_XGBE_DCB=y
++CONFIG_AMILO_RFKILL=m
++# CONFIG_ANDROID is not set
++CONFIG_ANON_INODES=y
++CONFIG_ANSLCD=m
++CONFIG_APB_TIMER=y
++CONFIG_APDS9300=m
++CONFIG_APDS9802ALS=m
++CONFIG_APDS9960=m
++CONFIG_APM=m
++# CONFIG_APM_ALLOW_INTS is not set
++# CONFIG_APM_CPU_IDLE is not set
++# CONFIG_APM_DISPLAY_BLANK is not set
++# CONFIG_APM_DO_ENABLE is not set
++# CONFIG_APM_IGNORE_USER_SUSPEND is not set
++CONFIG_APM_POWER=m
++CONFIG_APPLDATA_BASE=y
++CONFIG_APPLDATA_MEM=m
++CONFIG_APPLDATA_NET_SUM=m
++CONFIG_APPLDATA_OS=m
++CONFIG_APPLE_AIRPORT=m
++CONFIG_APPLE_GMUX=m
++CONFIG_APQ_GCC_8084=m
++CONFIG_APQ_MMCC_8084=m
++CONFIG_AQUANTIA_PHY=m
++CONFIG_AR5523=m
++CONFIG_ARCH_ALPINE=y
++# CONFIG_ARCH_AT91 is not set
++CONFIG_ARCH_AXXIA=y
++# CONFIG_ARCH_BCM is not set
++CONFIG_ARCH_BCM_IPROC=y
++CONFIG_ARCH_BERLIN=y
++CONFIG_ARCH_CLOCKSOURCE_DATA=y
++# CONFIG_ARCH_CLPS711X is not set
++CONFIG_ARCH_CPU_PROBE_RELEASE=y
++# CONFIG_ARCH_DAVINCI is not set
++# CONFIG_ARCH_DIGICOLOR is not set
++CONFIG_ARCH_DISCARD_MEMBLOCK=y
++# CONFIG_ARCH_DOVE is not set
++# CONFIG_ARCH_EBSA110 is not set
++CONFIG_ARCH_EMEV2=y
++CONFIG_ARCH_ENABLE_HUGEPAGE_MIGRATION=y
++CONFIG_ARCH_ENABLE_MEMORY_HOTPLUG=y
++CONFIG_ARCH_ENABLE_MEMORY_HOTREMOVE=y
++CONFIG_ARCH_ENABLE_SPLIT_PMD_PTLOCK=y
++# CONFIG_ARCH_EP93XX is not set
++CONFIG_ARCH_EXYNOS=y
++# CONFIG_ARCH_EXYNOS3 is not set
++# CONFIG_ARCH_EXYNOS4 is not set
++CONFIG_ARCH_EXYNOS5=y
++# CONFIG_ARCH_EXYNOS7 is not set
++CONFIG_ARCH_FLATMEM_ENABLE=y
++# CONFIG_ARCH_FOOTBRIDGE is not set
++# CONFIG_ARCH_GEMINI is not set
++CONFIG_ARCH_HAS_ATOMIC64_DEC_IF_POSITIVE=y
++CONFIG_ARCH_HAS_BANDGAP=y
++CONFIG_ARCH_HAS_CACHE_LINE_SIZE=y
++CONFIG_ARCH_HAS_CPU_RELAX=y
++CONFIG_ARCH_HAS_DEBUG_STRICT_USER_COPY_CHECKS=y
++CONFIG_ARCH_HAS_DMA_SET_COHERENT_MASK=y
++CONFIG_ARCH_HAS_ELF_RANDOMIZE=y
++CONFIG_ARCH_HAS_FAST_MULTIPLIER=y
++CONFIG_ARCH_HAS_GCOV_PROFILE_ALL=y
++CONFIG_ARCH_HAS_HOLES_MEMORYMODEL=y
++CONFIG_ARCH_HAS_MMIO_FLUSH=y
++CONFIG_ARCH_HAS_PMEM_API=y
++CONFIG_ARCH_HAS_RESET_CONTROLLER=y
++CONFIG_ARCH_HAS_SG_CHAIN=y
++CONFIG_ARCH_HAS_TICK_BROADCAST=y
++CONFIG_ARCH_HAS_WALK_MEMORY=y
++CONFIG_ARCH_HAVE_CUSTOM_GPIO_H=y
++CONFIG_ARCH_HAVE_NMI_SAFE_CMPXCHG=y
++CONFIG_ARCH_HI3xxx=y
++CONFIG_ARCH_HIBERNATION_HEADER=y
++CONFIG_ARCH_HIBERNATION_POSSIBLE=y
++CONFIG_ARCH_HIGHBANK=y
++# CONFIG_ARCH_HIP01 is not set
++CONFIG_ARCH_HIP04=y
++CONFIG_ARCH_HISI=y
++CONFIG_ARCH_HIX5HD2=y
++CONFIG_ARCH_INLINE_READ_LOCK=y
++CONFIG_ARCH_INLINE_READ_LOCK_BH=y
++CONFIG_ARCH_INLINE_READ_LOCK_IRQ=y
++CONFIG_ARCH_INLINE_READ_LOCK_IRQSAVE=y
++CONFIG_ARCH_INLINE_READ_TRYLOCK=y
++CONFIG_ARCH_INLINE_READ_UNLOCK=y
++CONFIG_ARCH_INLINE_READ_UNLOCK_BH=y
++CONFIG_ARCH_INLINE_READ_UNLOCK_IRQ=y
++CONFIG_ARCH_INLINE_READ_UNLOCK_IRQRESTORE=y
++CONFIG_ARCH_INLINE_SPIN_LOCK=y
++CONFIG_ARCH_INLINE_SPIN_LOCK_BH=y
++CONFIG_ARCH_INLINE_SPIN_LOCK_IRQ=y
++CONFIG_ARCH_INLINE_SPIN_LOCK_IRQSAVE=y
++CONFIG_ARCH_INLINE_SPIN_TRYLOCK=y
++CONFIG_ARCH_INLINE_SPIN_TRYLOCK_BH=y
++CONFIG_ARCH_INLINE_SPIN_UNLOCK=y
++CONFIG_ARCH_INLINE_SPIN_UNLOCK_BH=y
++CONFIG_ARCH_INLINE_SPIN_UNLOCK_IRQ=y
++CONFIG_ARCH_INLINE_SPIN_UNLOCK_IRQRESTORE=y
++CONFIG_ARCH_INLINE_WRITE_LOCK=y
++CONFIG_ARCH_INLINE_WRITE_LOCK_BH=y
++CONFIG_ARCH_INLINE_WRITE_LOCK_IRQ=y
++CONFIG_ARCH_INLINE_WRITE_LOCK_IRQSAVE=y
++CONFIG_ARCH_INLINE_WRITE_TRYLOCK=y
++CONFIG_ARCH_INLINE_WRITE_UNLOCK=y
++CONFIG_ARCH_INLINE_WRITE_UNLOCK_BH=y
++CONFIG_ARCH_INLINE_WRITE_UNLOCK_IRQ=y
++CONFIG_ARCH_INLINE_WRITE_UNLOCK_IRQRESTORE=y
++# CONFIG_ARCH_IOP13XX is not set
++# CONFIG_ARCH_IOP32X is not set
++# CONFIG_ARCH_IOP33X is not set
++# CONFIG_ARCH_IXP4XX is not set
++# CONFIG_ARCH_KEYSTONE is not set
++# CONFIG_ARCH_KS8695 is not set
++CONFIG_ARCH_LAYERSCAPE=y
++# CONFIG_ARCH_LPC32XX is not set
++CONFIG_ARCH_MAY_HAVE_PC_FDC=y
++CONFIG_ARCH_MEDIATEK=y
++CONFIG_ARCH_MEMORY_PROBE=y
++CONFIG_ARCH_MESON=y
++CONFIG_ARCH_MIGHT_HAVE_ACPI_PDC=y
++CONFIG_ARCH_MIGHT_HAVE_PC_PARPORT=y
++CONFIG_ARCH_MIGHT_HAVE_PC_SERIO=y
++# CONFIG_ARCH_MMP is not set
++CONFIG_ARCH_MSM8960=y
++CONFIG_ARCH_MSM8974=y
++CONFIG_ARCH_MSM8X60=y
++CONFIG_ARCH_MULTIPLATFORM=y
++# CONFIG_ARCH_MULTI_CPU_AUTO is not set
++# CONFIG_ARCH_MULTI_V6 is not set
++CONFIG_ARCH_MULTI_V6_V7=y
++CONFIG_ARCH_MULTI_V7=y
++# CONFIG_ARCH_MV78XX0 is not set
++CONFIG_ARCH_MVEBU=y
++# CONFIG_ARCH_NETX is not set
++CONFIG_ARCH_NR_GPIO=1024
++CONFIG_ARCH_OMAP=y
++# CONFIG_ARCH_OMAP1 is not set
++CONFIG_ARCH_OMAP2PLUS=y
++CONFIG_ARCH_OMAP2PLUS_TYPICAL=y
++# CONFIG_ARCH_ORION5X is not set
++CONFIG_ARCH_PROC_KCORE_TEXT=y
++# CONFIG_ARCH_PXA is not set
++CONFIG_ARCH_QCOM=y
++CONFIG_ARCH_R7S72100=y
++# CONFIG_ARCH_R8A73A4 is not set
++CONFIG_ARCH_R8A7740=y
++CONFIG_ARCH_R8A7778=y
++CONFIG_ARCH_R8A7779=y
++CONFIG_ARCH_R8A7790=y
++CONFIG_ARCH_R8A7791=y
++CONFIG_ARCH_R8A7793=y
++CONFIG_ARCH_R8A7794=y
++CONFIG_ARCH_RCAR_GEN1=y
++CONFIG_ARCH_RCAR_GEN2=y
++# CONFIG_ARCH_REALVIEW is not set
++CONFIG_ARCH_REQUIRE_GPIOLIB=y
++CONFIG_ARCH_RMOBILE=y
++# CONFIG_ARCH_RPC is not set
++# CONFIG_ARCH_S3C24XX is not set
++# CONFIG_ARCH_S3C64XX is not set
++# CONFIG_ARCH_S5PV210 is not set
++# CONFIG_ARCH_SA1100 is not set
++CONFIG_ARCH_SAVE_PAGE_KEYS=y
++CONFIG_ARCH_SEATTLE=y
++CONFIG_ARCH_SH73A0=y
++CONFIG_ARCH_SHMOBILE=y
++CONFIG_ARCH_SHMOBILE_MULTI=y
++# CONFIG_ARCH_SIRF is not set
++# CONFIG_ARCH_SOCFPGA is not set
++CONFIG_ARCH_SPARSEMEM_ENABLE=y
++CONFIG_ARCH_SPRD=y
++# CONFIG_ARCH_STI is not set
++CONFIG_ARCH_STRATIX10=y
++# CONFIG_ARCH_SUNXI is not set
++CONFIG_ARCH_SUPPORTS_ATOMIC_RMW=y
++CONFIG_ARCH_SUPPORTS_BIG_ENDIAN=y
++CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC=y
++CONFIG_ARCH_SUPPORTS_DEFERRED_STRUCT_PAGE_INIT=y
++CONFIG_ARCH_SUPPORTS_FIRMWARE=y
++CONFIG_ARCH_SUPPORTS_INT128=y
++CONFIG_ARCH_SUPPORTS_MEMORY_FAILURE=y
++CONFIG_ARCH_SUPPORTS_NUMA_BALANCING=y
++CONFIG_ARCH_SUPPORTS_OPTIMIZED_INLINING=y
++CONFIG_ARCH_SUPPORTS_TRUSTED_FOUNDATIONS=y
++CONFIG_ARCH_SUPPORTS_UPROBES=y
++CONFIG_ARCH_SUSPEND_POSSIBLE=y
++CONFIG_ARCH_TEGRA_114_SOC=y
++CONFIG_ARCH_TEGRA_124_SOC=y
++CONFIG_ARCH_TEGRA_2x_SOC=y
++CONFIG_ARCH_TEGRA_3x_SOC=y
++CONFIG_ARCH_THUNDER=y
++# CONFIG_ARCH_U8500 is not set
++CONFIG_ARCH_UNIPHIER=y
++CONFIG_ARCH_USES_PG_UNCACHED=y
++CONFIG_ARCH_USE_BUILTIN_BSWAP=y
++CONFIG_ARCH_USE_CMPXCHG_LOCKREF=y
++CONFIG_ARCH_USE_QUEUED_RWLOCKS=y
++CONFIG_ARCH_USE_QUEUED_SPINLOCKS=y
++# CONFIG_ARCH_VERSATILE is not set
++CONFIG_ARCH_VEXPRESS=y
++CONFIG_ARCH_VEXPRESS_CORTEX_A5_A9_ERRATA=y
++CONFIG_ARCH_VEXPRESS_DCSCB=y
++CONFIG_ARCH_VEXPRESS_SPC=y
++CONFIG_ARCH_VEXPRESS_TC2_PM=y
++CONFIG_ARCH_VIRT=y
++# CONFIG_ARCH_W90X900 is not set
++CONFIG_ARCH_WANTS_DYNAMIC_TASK_STRUCT=y
++CONFIG_ARCH_WANTS_FREEZER_CONTROL=y
++CONFIG_ARCH_WANT_BATCHED_UNMAP_TLB_FLUSH=y
++CONFIG_ARCH_WANT_COMPAT_IPC_PARSE_VERSION=y
++CONFIG_ARCH_WANT_FRAME_POINTERS=y
++CONFIG_ARCH_WANT_GENERAL_HUGETLB=y
++CONFIG_ARCH_WANT_HUGE_PMD_SHARE=y
++CONFIG_ARCH_WANT_IPC_PARSE_VERSION=y
++CONFIG_ARCH_WANT_OLD_COMPAT_IPC=y
++CONFIG_ARCH_WANT_OPTIONAL_GPIOLIB=y
++# CONFIG_ARCH_WM8850 is not set
++CONFIG_ARCH_XGENE=y
++# CONFIG_ARCH_ZX is not set
++# CONFIG_ARCH_ZYNQ is not set
++CONFIG_ARCH_ZYNQMP=y
++CONFIG_ARCNET_1051=m
++CONFIG_ARCNET_1201=m
++CONFIG_ARCNET_CAP=m
++CONFIG_ARCNET_COM20020=m
++CONFIG_ARCNET_COM20020_CS=m
++CONFIG_ARCNET_COM20020_ISA=m
++CONFIG_ARCNET_COM20020_PCI=m
++CONFIG_ARCNET_COM90xx=m
++CONFIG_ARCNET_COM90xxIO=m
++CONFIG_ARCNET_RAW=m
++CONFIG_ARCNET_RIM_I=m
++CONFIG_ARC_EMAC=m
++CONFIG_ARC_EMAC_CORE=m
++CONFIG_ARM=y
++CONFIG_ARM64=y
++# CONFIG_ARM64_16K_PAGES is not set
++CONFIG_ARM64_4K_PAGES=y
++# CONFIG_ARM64_64K_PAGES is not set
++CONFIG_ARM64_ACPI_PARKING_PROTOCOL=y
++CONFIG_ARM64_CRYPTO=y
++CONFIG_ARM64_ERRATUM_819472=y
++CONFIG_ARM64_ERRATUM_824069=y
++CONFIG_ARM64_ERRATUM_826319=y
++CONFIG_ARM64_ERRATUM_827319=y
++CONFIG_ARM64_ERRATUM_832075=y
++CONFIG_ARM64_ERRATUM_834220=y
++CONFIG_ARM64_ERRATUM_843419=y
++CONFIG_ARM64_ERRATUM_845719=y
++CONFIG_ARM64_HW_AFDBM=y
++# CONFIG_ARM64_LSE_ATOMICS is not set
++CONFIG_ARM64_PAN=y
++# CONFIG_ARM64_PTDUMP is not set
++# CONFIG_ARM64_RANDOMIZE_TEXT_OFFSET is not set
++CONFIG_ARM64_VA_BITS=48
++# CONFIG_ARM64_VA_BITS_39 is not set
++CONFIG_ARM64_VA_BITS_48=y
++CONFIG_ARMADA375_USBCLUSTER_PHY=y
++CONFIG_ARMADA_370_CLK=y
++CONFIG_ARMADA_370_XP_TIMER=y
++CONFIG_ARMADA_375_CLK=y
++CONFIG_ARMADA_38X_CLK=y
++CONFIG_ARMADA_39X_CLK=y
++CONFIG_ARMADA_THERMAL=y
++CONFIG_ARMADA_XP_CLK=y
++CONFIG_ARMV8_DEPRECATED=y
++CONFIG_ARM_AMBA=y
++CONFIG_ARM_APPENDED_DTB=y
++CONFIG_ARM_ARCH_TIMER=y
++CONFIG_ARM_ARCH_TIMER_EVTSTREAM=y
++CONFIG_ARM_ATAG_DTB_COMPAT_CMDLINE_EXTEND=y
++# CONFIG_ARM_ATAG_DTB_COMPAT_CMDLINE_FROM_BOOTLOADER is not set
++CONFIG_ARM_BIG_LITTLE_CPUFREQ=m
++CONFIG_ARM_BIG_LITTLE_CPUIDLE=y
++CONFIG_ARM_CCI=y
++CONFIG_ARM_CCI400_COMMON=y
++CONFIG_ARM_CCI400_PMU=y
++CONFIG_ARM_CCI400_PORT_CTRL=y
++CONFIG_ARM_CCI500_PMU=y
++CONFIG_ARM_CCI_PMU=y
++CONFIG_ARM_CCN=y
++CONFIG_ARM_CHARLCD=y
++CONFIG_ARM_CPUIDLE=y
++CONFIG_ARM_CPU_SUSPEND=y
++CONFIG_ARM_CPU_TOPOLOGY=y
++CONFIG_ARM_CRYPTO=y
++CONFIG_ARM_DMA_IOMMU_ALIGNMENT=8
++CONFIG_ARM_DMA_MEM_BUFFERABLE=y
++CONFIG_ARM_DMA_USE_IOMMU=y
++CONFIG_ARM_DT_BL_CPUFREQ=m
++CONFIG_ARM_ERRATA_430973=y
++CONFIG_ARM_ERRATA_643719=y
++CONFIG_ARM_ERRATA_720789=y
++CONFIG_ARM_ERRATA_754322=y
++CONFIG_ARM_ERRATA_754327=y
++CONFIG_ARM_ERRATA_764369=y
++CONFIG_ARM_ERRATA_773022=y
++CONFIG_ARM_ERRATA_775420=y
++CONFIG_ARM_ERRATA_798181=y
++# CONFIG_ARM_EXYNOS5440_CPUFREQ is not set
++# CONFIG_ARM_EXYNOS5_BUS_DEVFREQ is not set
++CONFIG_ARM_EXYNOS_CPUIDLE=y
++CONFIG_ARM_GIC=y
++CONFIG_ARM_GIC_V2M=y
++CONFIG_ARM_GIC_V3=y
++CONFIG_ARM_GIC_V3_ITS=y
++CONFIG_ARM_GLOBAL_TIMER=y
++CONFIG_ARM_HAS_SG_CHAIN=y
++CONFIG_ARM_HEAVY_MB=y
++CONFIG_ARM_HIGHBANK_CPUFREQ=m
++CONFIG_ARM_HISI_ACPU_CPUFREQ=m
++CONFIG_ARM_IMX6Q_CPUFREQ=m
++CONFIG_ARM_KERNMEM_PERMS=y
++# CONFIG_ARM_KIRKWOOD_CPUFREQ is not set
++CONFIG_ARM_KPROBES_TEST=m
++CONFIG_ARM_L1_CACHE_SHIFT=6
++CONFIG_ARM_L1_CACHE_SHIFT_6=y
++CONFIG_ARM_MHU=m
++# CONFIG_ARM_MODULE_PLTS is not set
++CONFIG_ARM_MT8173_CPUFREQ=y
++CONFIG_ARM_MVEBU_V7_CPUIDLE=y
++CONFIG_ARM_OMAP2PLUS_CPUFREQ=y
++CONFIG_ARM_PATCH_PHYS_VIRT=y
++CONFIG_ARM_PL172_MPMC=m
++CONFIG_ARM_PMU=y
++CONFIG_ARM_PSCI=y
++CONFIG_ARM_PSCI_FW=y
++# CONFIG_ARM_PTDUMP is not set
++CONFIG_ARM_SCPI_CPUFREQ=m
++CONFIG_ARM_SCPI_PROTOCOL=m
++CONFIG_ARM_SMMU_V3=y
++CONFIG_ARM_SP805_WATCHDOG=m
++CONFIG_ARM_TEGRA124_CPUFREQ=m
++CONFIG_ARM_TEGRA20_CPUFREQ=y
++CONFIG_ARM_TEGRA_DEVFREQ=m
++CONFIG_ARM_THUMB=y
++CONFIG_ARM_THUMBEE=y
++CONFIG_ARM_TIMER_SP804=y
++CONFIG_ARM_UNWIND=y
++CONFIG_ARM_VEXPRESS_SPC_CPUFREQ=m
++CONFIG_ARM_VIRT_EXT=y
++CONFIG_AS3935=m
++CONFIG_ASN1=y
++CONFIG_ASSOCIATIVE_ARRAY=y
++CONFIG_ASUS_LAPTOP=m
++CONFIG_ASUS_NB_WMI=m
++CONFIG_ASUS_WMI=m
++CONFIG_ASYMMETRIC_KEY_TYPE=y
++CONFIG_ASYMMETRIC_PUBLIC_KEY_SUBTYPE=y
++CONFIG_ASYNC_CORE=m
++CONFIG_ASYNC_MEMCPY=m
++CONFIG_ASYNC_PQ=m
++CONFIG_ASYNC_RAID6_RECOV=m
++CONFIG_ASYNC_RAID6_TEST=m
++CONFIG_ASYNC_TX_DMA=y
++CONFIG_ASYNC_TX_ENABLE_CHANNEL_SWITCH=y
++CONFIG_ASYNC_XOR=m
++CONFIG_AT76C50X_USB=m
++CONFIG_AT803X_PHY=m
++CONFIG_ATA=y
++CONFIG_ATAGS=y
++CONFIG_ATAGS_PROC=y
++CONFIG_ATA_ACPI=y
++CONFIG_ATA_BMDMA=y
++CONFIG_ATA_SFF=y
++CONFIG_ATA_VERBOSE_ERROR=y
++CONFIG_ATH10K=m
++# CONFIG_ATH10K_DEBUG is not set
++CONFIG_ATH10K_DEBUGFS=y
++CONFIG_ATH10K_PCI=m
++CONFIG_ATH10K_TRACING=y
++CONFIG_ATH5K=m
++# CONFIG_ATH5K_DEBUG is not set
++CONFIG_ATH5K_PCI=y
++# CONFIG_ATH5K_TRACER is not set
++CONFIG_ATH6KL=m
++# CONFIG_ATH6KL_DEBUG is not set
++CONFIG_ATH6KL_SDIO=m
++# CONFIG_ATH6KL_TRACING is not set
++CONFIG_ATH6KL_USB=m
++CONFIG_ATH9K=m
++CONFIG_ATH9K_AHB=y
++CONFIG_ATH9K_BTCOEX_SUPPORT=y
++CONFIG_ATH9K_CHANNEL_CONTEXT=y
++CONFIG_ATH9K_COMMON=m
++CONFIG_ATH9K_DEBUGFS=y
++# CONFIG_ATH9K_DYNACK is not set
++CONFIG_ATH9K_HTC=m
++CONFIG_ATH9K_HTC_DEBUGFS=y
++CONFIG_ATH9K_HW=m
++CONFIG_ATH9K_PCI=y
++CONFIG_ATH9K_PCOEM=y
++CONFIG_ATH9K_RFKILL=y
++CONFIG_ATH9K_STATION_STATISTICS=y
++CONFIG_ATH9K_WOW=y
++CONFIG_ATH_CARDS=m
++CONFIG_ATH_COMMON=m
++# CONFIG_ATH_DEBUG is not set
++CONFIG_ATL1=m
++CONFIG_ATL1C=m
++CONFIG_ATL1E=m
++CONFIG_ATL2=m
++CONFIG_ATMEL=m
++# CONFIG_ATMEL_PIT is not set
++CONFIG_ATM_AMBASSADOR=m
++# CONFIG_ATM_AMBASSADOR_DEBUG is not set
++CONFIG_ATM_BR2684=m
++# CONFIG_ATM_BR2684_IPFILTER is not set
++CONFIG_ATM_CLIP=m
++# CONFIG_ATM_CLIP_NO_ICMP is not set
++CONFIG_ATM_DRIVERS=y
++CONFIG_ATM_DUMMY=m
++CONFIG_ATM_ENI=m
++# CONFIG_ATM_ENI_DEBUG is not set
++# CONFIG_ATM_ENI_TUNE_BURST is not set
++CONFIG_ATM_FIRESTREAM=m
++CONFIG_ATM_FORE200E=m
++CONFIG_ATM_FORE200E_DEBUG=0
++CONFIG_ATM_FORE200E_TX_RETRY=16
++# CONFIG_ATM_FORE200E_USE_TASKLET is not set
++CONFIG_ATM_HE=m
++CONFIG_ATM_HE_USE_SUNI=y
++CONFIG_ATM_HORIZON=m
++# CONFIG_ATM_HORIZON_DEBUG is not set
++CONFIG_ATM_IA=m
++# CONFIG_ATM_IA_DEBUG is not set
++CONFIG_ATM_IDT77252=m
++# CONFIG_ATM_IDT77252_DEBUG is not set
++# CONFIG_ATM_IDT77252_RCV_ALL is not set
++CONFIG_ATM_IDT77252_USE_SUNI=y
++CONFIG_ATM_LANAI=m
++CONFIG_ATM_LANE=m
++CONFIG_ATM_MPOA=m
++CONFIG_ATM_NICSTAR=m
++# CONFIG_ATM_NICSTAR_USE_IDT77105 is not set
++# CONFIG_ATM_NICSTAR_USE_SUNI is not set
++CONFIG_ATM_SOLOS=m
++CONFIG_ATM_TCP=m
++CONFIG_ATM_ZATM=m
++# CONFIG_ATM_ZATM_DEBUG is not set
++# CONFIG_ATOMIC64_SELFTEST is not set
++CONFIG_ATP=m
++CONFIG_AUDIT=y
++CONFIG_AUDITSYSCALL=y
++CONFIG_AUDIT_ARCH=y
++CONFIG_AUDIT_COMPAT_GENERIC=y
++CONFIG_AUDIT_GENERIC=y
++CONFIG_AUDIT_TREE=y
++CONFIG_AUDIT_WATCH=y
++CONFIG_AUFS_BDEV_LOOP=y
++# CONFIG_AUFS_BRANCH_MAX_1023 is not set
++CONFIG_AUFS_BRANCH_MAX_127=y
++# CONFIG_AUFS_BRANCH_MAX_32767 is not set
++# CONFIG_AUFS_BRANCH_MAX_511 is not set
++# CONFIG_AUFS_BR_FUSE is not set
++CONFIG_AUFS_BR_HFSPLUS=y
++# CONFIG_AUFS_BR_RAMFS is not set
++# CONFIG_AUFS_DEBUG is not set
++CONFIG_AUFS_EXPORT=y
++# CONFIG_AUFS_FHSM is not set
++CONFIG_AUFS_FS=m
++# CONFIG_AUFS_HNOTIFY is not set
++CONFIG_AUFS_INO_T_64=y
++# CONFIG_AUFS_RDU is not set
++CONFIG_AUFS_SBILIST=y
++# CONFIG_AUFS_SHWH is not set
++CONFIG_AUFS_XATTR=y
++CONFIG_AURORA_NB8800=m
++CONFIG_AUTO_ZRELADDR=y
++CONFIG_AX25=m
++CONFIG_AX25_DAMA_SLAVE=y
++CONFIG_AX88796=m
++# CONFIG_AX88796_93CX6 is not set
++CONFIG_AXP20X_POWER=m
++CONFIG_AXP288_ADC=m
++CONFIG_AXP288_CHARGER=m
++CONFIG_AXP288_FUEL_GAUGE=m
++CONFIG_B43=m
++CONFIG_B43LEGACY=m
++# CONFIG_B43LEGACY_DEBUG is not set
++CONFIG_B43LEGACY_DMA=y
++CONFIG_B43LEGACY_DMA_AND_PIO_MODE=y
++# CONFIG_B43LEGACY_DMA_MODE is not set
++CONFIG_B43LEGACY_HWRNG=y
++CONFIG_B43LEGACY_LEDS=y
++CONFIG_B43LEGACY_PCICORE_AUTOSELECT=y
++CONFIG_B43LEGACY_PCI_AUTOSELECT=y
++CONFIG_B43LEGACY_PIO=y
++# CONFIG_B43LEGACY_PIO_MODE is not set
++CONFIG_B43_BCMA=y
++CONFIG_B43_BCMA_PIO=y
++# CONFIG_B43_BUSES_BCMA is not set
++CONFIG_B43_BUSES_BCMA_AND_SSB=y
++# CONFIG_B43_BUSES_SSB is not set
++# CONFIG_B43_DEBUG is not set
++CONFIG_B43_HWRNG=y
++CONFIG_B43_LEDS=y
++CONFIG_B43_PCICORE_AUTOSELECT=y
++CONFIG_B43_PCI_AUTOSELECT=y
++CONFIG_B43_PHY_G=y
++CONFIG_B43_PHY_HT=y
++CONFIG_B43_PHY_LP=y
++CONFIG_B43_PHY_N=y
++CONFIG_B43_PIO=y
++# CONFIG_B43_SDIO is not set
++CONFIG_B43_SSB=y
++CONFIG_B44=m
++CONFIG_B44_PCI=y
++CONFIG_B44_PCICORE_AUTOSELECT=y
++CONFIG_B44_PCI_AUTOSELECT=y
++CONFIG_BACKLIGHT_88PM860X=m
++CONFIG_BACKLIGHT_AAT2870=m
++CONFIG_BACKLIGHT_ADP5520=m
++CONFIG_BACKLIGHT_ADP8860=m
++CONFIG_BACKLIGHT_ADP8870=m
++CONFIG_BACKLIGHT_APPLE=m
++CONFIG_BACKLIGHT_AS3711=m
++CONFIG_BACKLIGHT_BD6107=m
++CONFIG_BACKLIGHT_CARILLO_RANCH=m
++CONFIG_BACKLIGHT_CLASS_DEVICE=y
++CONFIG_BACKLIGHT_DA903X=m
++CONFIG_BACKLIGHT_DA9052=m
++CONFIG_BACKLIGHT_GENERIC=m
++CONFIG_BACKLIGHT_GPIO=m
++CONFIG_BACKLIGHT_LM3533=m
++CONFIG_BACKLIGHT_LM3630A=m
++CONFIG_BACKLIGHT_LM3639=m
++CONFIG_BACKLIGHT_LP855X=m
++CONFIG_BACKLIGHT_LP8788=m
++CONFIG_BACKLIGHT_LV5207LP=m
++CONFIG_BACKLIGHT_MAX8925=m
++CONFIG_BACKLIGHT_PANDORA=m
++CONFIG_BACKLIGHT_PCF50633=m
++CONFIG_BACKLIGHT_PM8941_WLED=m
++CONFIG_BACKLIGHT_PWM=m
++CONFIG_BACKLIGHT_SAHARA=m
++CONFIG_BACKLIGHT_SKY81452=m
++CONFIG_BACKLIGHT_TPS65217=m
++CONFIG_BACKLIGHT_WM831X=m
++# CONFIG_BACKTRACE_SELF_TEST is not set
++CONFIG_BALLOON_COMPACTION=y
++CONFIG_BASE_FULL=y
++CONFIG_BASE_SMALL=0
++CONFIG_BATMAN_ADV_BLA=y
++CONFIG_BATMAN_ADV_DAT=y
++# CONFIG_BATMAN_ADV_DEBUG is not set
++CONFIG_BATMAN_ADV_MCAST=y
++CONFIG_BATMAN_ADV_NC=y
++CONFIG_BATTERY_88PM860X=m
++CONFIG_BATTERY_BQ27XXX=m
++CONFIG_BATTERY_BQ27XXX_I2C=y
++CONFIG_BATTERY_BQ27XXX_PLATFORM=y
++CONFIG_BATTERY_DA9030=m
++CONFIG_BATTERY_DA9052=m
++CONFIG_BATTERY_DA9150=m
++CONFIG_BATTERY_DS2760=m
++CONFIG_BATTERY_DS2780=m
++CONFIG_BATTERY_DS2781=m
++CONFIG_BATTERY_DS2782=m
++CONFIG_BATTERY_GAUGE_LTC2941=m
++CONFIG_BATTERY_INTEL_MID=m
++CONFIG_BATTERY_MAX17040=m
++CONFIG_BATTERY_MAX17042=m
++CONFIG_BATTERY_PMU=m
++CONFIG_BATTERY_RT5033=m
++CONFIG_BATTERY_RX51=m
++CONFIG_BATTERY_SBS=m
++CONFIG_BATTERY_TWL4030_MADC=m
++CONFIG_BAYCOM_EPP=m
++CONFIG_BAYCOM_PAR=m
++CONFIG_BAYCOM_SER_FDX=m
++CONFIG_BAYCOM_SER_HDX=m
++CONFIG_BCACHE=m
++# CONFIG_BCACHE_CLOSURES_DEBUG is not set
++# CONFIG_BCACHE_DEBUG is not set
++CONFIG_BCH_CONST_M=14
++CONFIG_BCH_CONST_PARAMS=y
++CONFIG_BCH_CONST_T=4
++CONFIG_BCM7038_WDT=m
++CONFIG_BCM7XXX_PHY=m
++CONFIG_BCM87XX_PHY=m
++CONFIG_BCMA_BLOCKIO=y
++# CONFIG_BCMA_DEBUG is not set
++CONFIG_BCMA_DRIVER_GMAC_CMN=y
++CONFIG_BCMA_DRIVER_GPIO=y
++CONFIG_BCMA_DRIVER_PCI=y
++CONFIG_BCMA_HOST_PCI=y
++CONFIG_BCMA_HOST_PCI_POSSIBLE=y
++CONFIG_BCMA_HOST_SOC=y
++CONFIG_BCMA_POSSIBLE=y
++CONFIG_BCMGENET=m
++CONFIG_BCM_NET_PHYLIB=m
++# CONFIG_BDI_SWITCH is not set
++CONFIG_BE2NET=m
++CONFIG_BE2NET_HWMON=y
++CONFIG_BE2NET_VXLAN=y
++# CONFIG_BEFS_DEBUG is not set
++CONFIG_BERLIN2_ADC=m
++CONFIG_BH1750=m
++CONFIG_BIG_KEYS=y
++CONFIG_BIG_LITTLE=y
++CONFIG_BINARY_PRINTF=y
++CONFIG_BINFMT_AOUT=m
++CONFIG_BINFMT_ELF=y
++CONFIG_BINFMT_MISC=m
++CONFIG_BINFMT_SCRIPT=y
++CONFIG_BITREVERSE=y
++CONFIG_BLK_CGROUP=y
++CONFIG_BLK_CMDLINE_PARSER=y
++CONFIG_BLK_DEV=y
++CONFIG_BLK_DEV_BSG=y
++CONFIG_BLK_DEV_BSGLIB=y
++# CONFIG_BLK_DEV_COW_COMMON is not set
++CONFIG_BLK_DEV_DM=y
++CONFIG_BLK_DEV_DM_BUILTIN=y
++CONFIG_BLK_DEV_DRBD=m
++CONFIG_BLK_DEV_FD=m
++# CONFIG_BLK_DEV_HD is not set
++CONFIG_BLK_DEV_INITRD=y
++CONFIG_BLK_DEV_INTEGRITY=y
++CONFIG_BLK_DEV_IO_TRACE=y
++CONFIG_BLK_DEV_LOOP=y
++CONFIG_BLK_DEV_LOOP_MIN_COUNT=8
++CONFIG_BLK_DEV_MD=y
++CONFIG_BLK_DEV_NBD=m
++CONFIG_BLK_DEV_NULL_BLK=m
++CONFIG_BLK_DEV_NVME_SCSI=y
++CONFIG_BLK_DEV_OSD=m
++CONFIG_BLK_DEV_PMEM=m
++CONFIG_BLK_DEV_RAM=m
++CONFIG_BLK_DEV_RAM_COUNT=16
++CONFIG_BLK_DEV_RAM_DAX=y
++CONFIG_BLK_DEV_RAM_SIZE=65536
++CONFIG_BLK_DEV_RBD=m
++CONFIG_BLK_DEV_SD=y
++CONFIG_BLK_DEV_SR=y
++CONFIG_BLK_DEV_THROTTLING=y
++# CONFIG_BLK_DEV_XPRAM is not set
++CONFIG_BLOCK=y
++CONFIG_BLOCK_COMPAT=y
++CONFIG_BL_SWITCHER=y
++CONFIG_BL_SWITCHER_DUMMY_IF=m
++CONFIG_BMA180=m
++CONFIG_BMAC=m
++CONFIG_BMC150_ACCEL=m
++CONFIG_BMC150_ACCEL_I2C=m
++CONFIG_BMC150_ACCEL_SPI=m
++CONFIG_BMC150_MAGN=m
++CONFIG_BMG160=m
++CONFIG_BMG160_I2C=m
++CONFIG_BMG160_SPI=m
++CONFIG_BMP085=m
++CONFIG_BMP085_I2C=m
++CONFIG_BMP085_SPI=m
++CONFIG_BMP280=m
++CONFIG_BNA=m
++CONFIG_BNX2=m
++CONFIG_BNX2X=m
++CONFIG_BNX2X_SRIOV=y
++CONFIG_BNX2X_VXLAN=y
++CONFIG_BNXT=m
++CONFIG_BNXT_BPO=m
++CONFIG_BNXT_BPO_DCB=y
++CONFIG_BNXT_BPO_SRIOV=y
++CONFIG_BNXT_SRIOV=y
++CONFIG_BOARD_TPCI200=m
++CONFIG_BONDING=m
++CONFIG_BOOKE=y
++CONFIG_BOOKE_WDT=y
++CONFIG_BOOKE_WDT_DEFAULT_TIMEOUT=38
++# CONFIG_BOOTPARAM_HARDLOCKUP_PANIC is not set
++CONFIG_BOOTPARAM_HARDLOCKUP_PANIC_VALUE=0
++# CONFIG_BOOTPARAM_HOTPLUG_CPU0 is not set
++# CONFIG_BOOTPARAM_HUNG_TASK_PANIC is not set
++CONFIG_BOOTPARAM_HUNG_TASK_PANIC_VALUE=0
++# CONFIG_BOOTPARAM_SOFTLOCKUP_PANIC is not set
++CONFIG_BOOTPARAM_SOFTLOCKUP_PANIC_VALUE=0
++# CONFIG_BOOTX_TEXT is not set
++CONFIG_BOOT_PRINTK_DELAY=y
++CONFIG_BPF=y
++CONFIG_BPF_EVENTS=y
++CONFIG_BPF_JIT=y
++CONFIG_BPF_SYSCALL=y
++CONFIG_BPQETHER=m
++CONFIG_BQL=y
++CONFIG_BRANCH_PROFILE_NONE=y
++# CONFIG_BRCMDBG is not set
++CONFIG_BRCMFMAC=m
++CONFIG_BRCMFMAC_PCIE=y
++CONFIG_BRCMFMAC_PROTO_BCDC=y
++CONFIG_BRCMFMAC_PROTO_MSGBUF=y
++CONFIG_BRCMFMAC_SDIO=y
++CONFIG_BRCMFMAC_USB=y
++CONFIG_BRCMSMAC=m
++CONFIG_BRCMSTB_GISB_ARB=y
++CONFIG_BRCMUTIL=m
++CONFIG_BRCM_TRACING=y
++CONFIG_BRIDGE=m
++CONFIG_BRIDGE_EBT_802_3=m
++CONFIG_BRIDGE_EBT_AMONG=m
++CONFIG_BRIDGE_EBT_ARP=m
++CONFIG_BRIDGE_EBT_ARPREPLY=m
++CONFIG_BRIDGE_EBT_BROUTE=m
++CONFIG_BRIDGE_EBT_DNAT=m
++CONFIG_BRIDGE_EBT_IP=m
++CONFIG_BRIDGE_EBT_IP6=m
++CONFIG_BRIDGE_EBT_LIMIT=m
++CONFIG_BRIDGE_EBT_LOG=m
++CONFIG_BRIDGE_EBT_MARK=m
++CONFIG_BRIDGE_EBT_MARK_T=m
++CONFIG_BRIDGE_EBT_NFLOG=m
++CONFIG_BRIDGE_EBT_PKTTYPE=m
++CONFIG_BRIDGE_EBT_REDIRECT=m
++CONFIG_BRIDGE_EBT_SNAT=m
++CONFIG_BRIDGE_EBT_STP=m
++CONFIG_BRIDGE_EBT_T_FILTER=m
++CONFIG_BRIDGE_EBT_T_NAT=m
++CONFIG_BRIDGE_EBT_VLAN=m
++CONFIG_BRIDGE_IGMP_SNOOPING=y
++CONFIG_BRIDGE_NETFILTER=m
++CONFIG_BRIDGE_NF_EBTABLES=m
++CONFIG_BRIDGE_VLAN_FILTERING=y
++CONFIG_BROADCOM_PHY=m
++# CONFIG_BSC9131_RDB is not set
++CONFIG_BSC9132_QDS=y
++CONFIG_BSD_PROCESS_ACCT=y
++CONFIG_BSD_PROCESS_ACCT_V3=y
++CONFIG_BT=m
++CONFIG_BTREE=y
++# CONFIG_BTRFS_ASSERT is not set
++# CONFIG_BTRFS_DEBUG is not set
++CONFIG_BTRFS_FS=m
++# CONFIG_BTRFS_FS_CHECK_INTEGRITY is not set
++CONFIG_BTRFS_FS_POSIX_ACL=y
++# CONFIG_BTRFS_FS_RUN_SANITY_TESTS is not set
++CONFIG_BTT=y
++CONFIG_BT_6LOWPAN=m
++CONFIG_BT_ATH3K=m
++CONFIG_BT_BCM=m
++CONFIG_BT_BNEP=m
++CONFIG_BT_BNEP_MC_FILTER=y
++CONFIG_BT_BNEP_PROTO_FILTER=y
++CONFIG_BT_BREDR=y
++CONFIG_BT_CMTP=m
++CONFIG_BT_DEBUGFS=y
++CONFIG_BT_HCIBCM203X=m
++CONFIG_BT_HCIBFUSB=m
++CONFIG_BT_HCIBLUECARD=m
++CONFIG_BT_HCIBPA10X=m
++CONFIG_BT_HCIBT3C=m
++CONFIG_BT_HCIBTSDIO=m
++CONFIG_BT_HCIBTUART=m
++CONFIG_BT_HCIBTUSB=m
++CONFIG_BT_HCIBTUSB_BCM=y
++CONFIG_BT_HCIBTUSB_RTL=y
++CONFIG_BT_HCIDTL1=m
++CONFIG_BT_HCIUART=m
++CONFIG_BT_HCIUART_3WIRE=y
++CONFIG_BT_HCIUART_ATH3K=y
++CONFIG_BT_HCIUART_BCM=y
++CONFIG_BT_HCIUART_BCSP=y
++CONFIG_BT_HCIUART_H4=y
++CONFIG_BT_HCIUART_INTEL=y
++CONFIG_BT_HCIUART_LL=y
++CONFIG_BT_HCIUART_QCA=y
++CONFIG_BT_HCIVHCI=m
++CONFIG_BT_HIDP=m
++CONFIG_BT_HS=y
++CONFIG_BT_INTEL=m
++CONFIG_BT_LE=y
++CONFIG_BT_MRVL=m
++CONFIG_BT_MRVL_SDIO=m
++CONFIG_BT_QCA=m
++CONFIG_BT_RFCOMM=m
++CONFIG_BT_RFCOMM_TTY=y
++CONFIG_BT_RTL=m
++# CONFIG_BT_SELFTEST is not set
++CONFIG_BT_WILINK=m
++CONFIG_BUG=y
++CONFIG_BUILDTIME_EXTABLE_SORT=y
++CONFIG_BUILD_BIN2C=y
++CONFIG_C101=m
++CONFIG_C293_PCIE=y
++CONFIG_C2PORT_DURAMAR_2150=m
++CONFIG_CACHEFILES=m
++# CONFIG_CACHEFILES_DEBUG is not set
++# CONFIG_CACHEFILES_HISTOGRAM is not set
++CONFIG_CACHE_FEROCEON_L2=y
++# CONFIG_CACHE_FEROCEON_L2_WRITETHROUGH is not set
++CONFIG_CACHE_L2X0=y
++CONFIG_CACHE_TAUROS2=y
++CONFIG_CACHE_UNIPHIER=y
++# CONFIG_CAIF_DEBUG is not set
++CONFIG_CAIF_HSI=m
++CONFIG_CAIF_NETDEV=m
++CONFIG_CAIF_SPI_SLAVE=m
++# CONFIG_CAIF_SPI_SYNC is not set
++CONFIG_CAIF_TTY=m
++CONFIG_CAIF_USB=m
++CONFIG_CAIF_VIRTIO=m
++CONFIG_CALGARY_IOMMU=y
++CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT=y
++CONFIG_CAN_8DEV_USB=m
++CONFIG_CAN_BCM=m
++CONFIG_CAN_CALC_BITTIMING=y
++CONFIG_CAN_CC770=m
++CONFIG_CAN_CC770_ISA=m
++CONFIG_CAN_CC770_PLATFORM=m
++CONFIG_CAN_C_CAN=m
++CONFIG_CAN_C_CAN_PCI=m
++CONFIG_CAN_C_CAN_PLATFORM=m
++# CONFIG_CAN_DEBUG_DEVICES is not set
++CONFIG_CAN_DEV=m
++CONFIG_CAN_EMS_PCI=m
++CONFIG_CAN_EMS_PCMCIA=m
++CONFIG_CAN_EMS_USB=m
++CONFIG_CAN_ESD_USB2=m
++CONFIG_CAN_FLEXCAN=m
++CONFIG_CAN_GRCAN=m
++CONFIG_CAN_GS_USB=m
++CONFIG_CAN_GW=m
++CONFIG_CAN_JANZ_ICAN3=m
++CONFIG_CAN_KVASER_PCI=m
++CONFIG_CAN_KVASER_USB=m
++CONFIG_CAN_LEDS=y
++CONFIG_CAN_MCP251X=m
++CONFIG_CAN_MSCAN=m
++CONFIG_CAN_M_CAN=m
++CONFIG_CAN_PEAK_PCI=m
++CONFIG_CAN_PEAK_PCIEC=y
++CONFIG_CAN_PEAK_PCMCIA=m
++CONFIG_CAN_PEAK_USB=m
++CONFIG_CAN_PLX_PCI=m
++CONFIG_CAN_RAW=m
++CONFIG_CAN_RCAR=m
++CONFIG_CAN_SJA1000=m
++CONFIG_CAN_SJA1000_ISA=m
++CONFIG_CAN_SJA1000_PLATFORM=m
++CONFIG_CAN_SLCAN=m
++CONFIG_CAN_SOFTING=m
++CONFIG_CAN_SOFTING_CS=m
++CONFIG_CAN_TI_HECC=m
++CONFIG_CAN_TSCAN1=m
++CONFIG_CAN_VCAN=m
++CONFIG_CAN_XILINXCAN=m
++CONFIG_CAPI_AVM=y
++CONFIG_CAPI_EICON=y
++CONFIG_CAPI_TRACE=y
++CONFIG_CARACALLA_BOARD=y
++CONFIG_CARDBUS=y
++CONFIG_CARDMAN_4000=m
++CONFIG_CARDMAN_4040=m
++CONFIG_CARL9170=m
++# CONFIG_CARL9170_DEBUGFS is not set
++CONFIG_CARL9170_HWRNG=y
++CONFIG_CARL9170_LEDS=y
++CONFIG_CARL9170_WPC=y
++# CONFIG_CARMINE_DRAM_CUSTOM is not set
++CONFIG_CASSINI=m
++CONFIG_CAVIUM_ERRATUM_22375=y
++CONFIG_CAVIUM_ERRATUM_23144=y
++CONFIG_CAVIUM_ERRATUM_23154=y
++CONFIG_CAVIUM_ERRATUM_27456=y
++# CONFIG_CB710_DEBUG is not set
++CONFIG_CB710_DEBUG_ASSUMPTIONS=y
++CONFIG_CBE_CPUFREQ_SPU_GOVERNOR=m
++CONFIG_CC10001_ADC=m
++CONFIG_CCW=y
++CONFIG_CCWGROUP=m
++CONFIG_CCW_CONSOLE=y
++# CONFIG_CC_OPTIMIZE_FOR_SIZE is not set
++# CONFIG_CC_STACKPROTECTOR_NONE is not set
++# CONFIG_CC_STACKPROTECTOR_REGULAR is not set
++CONFIG_CC_STACKPROTECTOR_STRONG=y
++CONFIG_CDROM_PKTCDVD_BUFFERS=8
++# CONFIG_CDROM_PKTCDVD_WCACHE is not set
++# CONFIG_CELL_CPU is not set
++CONFIG_CEPH_FS=m
++CONFIG_CEPH_FSCACHE=y
++CONFIG_CEPH_FS_POSIX_ACL=y
++CONFIG_CEPH_LIB=m
++# CONFIG_CEPH_LIB_PRETTYDEBUG is not set
++CONFIG_CEPH_LIB_USE_DNS_RESOLVER=y
++CONFIG_CFAG12864B=m
++CONFIG_CFAG12864B_RATE=20
++CONFIG_CFG80211=m
++# CONFIG_CFG80211_CERTIFICATION_ONUS is not set
++CONFIG_CFG80211_CRDA_SUPPORT=y
++CONFIG_CFG80211_DEBUGFS=y
++CONFIG_CFG80211_DEFAULT_PS=y
++# CONFIG_CFG80211_DEVELOPER_WARNINGS is not set
++# CONFIG_CFG80211_INTERNAL_REGDB is not set
++# CONFIG_CFG80211_REG_DEBUG is not set
++CONFIG_CFG80211_WEXT=y
++CONFIG_CFG80211_WEXT_EXPORT=y
++CONFIG_CFQ_GROUP_IOSCHED=y
++CONFIG_CFS_BANDWIDTH=y
++CONFIG_CGROUPS=y
++CONFIG_CGROUP_CPUACCT=y
++# CONFIG_CGROUP_DEBUG is not set
++CONFIG_CGROUP_DEVICE=y
++CONFIG_CGROUP_FREEZER=y
++CONFIG_CGROUP_HUGETLB=y
++CONFIG_CGROUP_NET_CLASSID=y
++CONFIG_CGROUP_NET_PRIO=y
++CONFIG_CGROUP_PERF=y
++CONFIG_CGROUP_PIDS=y
++CONFIG_CGROUP_SCHED=y
++CONFIG_CGROUP_WRITEBACK=y
++CONFIG_CHARGER_88PM860X=m
++CONFIG_CHARGER_BQ2415X=m
++CONFIG_CHARGER_BQ24190=m
++CONFIG_CHARGER_BQ24257=m
++CONFIG_CHARGER_BQ24735=m
++CONFIG_CHARGER_BQ25890=m
++CONFIG_CHARGER_DA9150=m
++CONFIG_CHARGER_GPIO=m
++CONFIG_CHARGER_ISP1704=m
++CONFIG_CHARGER_LP8727=m
++CONFIG_CHARGER_LP8788=m
++CONFIG_CHARGER_MANAGER=y
++CONFIG_CHARGER_MAX14577=m
++CONFIG_CHARGER_MAX77693=m
++CONFIG_CHARGER_MAX8903=m
++CONFIG_CHARGER_MAX8997=m
++CONFIG_CHARGER_MAX8998=m
++CONFIG_CHARGER_PCF50633=m
++CONFIG_CHARGER_QCOM_SMBB=m
++CONFIG_CHARGER_RT9455=m
++CONFIG_CHARGER_SMB347=m
++CONFIG_CHARGER_TPS65090=m
++CONFIG_CHARGER_TPS65217=m
++CONFIG_CHARGER_TWL4030=m
++CONFIG_CHECKPOINT_RESTORE=y
++CONFIG_CHECK_SIGNATURE=y
++CONFIG_CHECK_STACK=y
++CONFIG_CHELSIO_T1=m
++CONFIG_CHELSIO_T1_1G=y
++CONFIG_CHELSIO_T3=m
++CONFIG_CHELSIO_T4=m
++CONFIG_CHELSIO_T4VF=m
++CONFIG_CHELSIO_T4_DCB=y
++CONFIG_CHELSIO_T4_FCOE=y
++CONFIG_CHROMEOS_LAPTOP=m
++CONFIG_CHROMEOS_PSTORE=m
++CONFIG_CHROME_PLATFORMS=y
++CONFIG_CHR_DEV_OSST=m
++CONFIG_CHR_DEV_SCH=m
++CONFIG_CHR_DEV_SG=y
++CONFIG_CHR_DEV_ST=m
++CONFIG_CHSC_SCH=m
++CONFIG_CICADA_PHY=m
++CONFIG_CIFS=m
++CONFIG_CIFS_ACL=y
++CONFIG_CIFS_DEBUG=y
++# CONFIG_CIFS_DEBUG2 is not set
++CONFIG_CIFS_DFS_UPCALL=y
++CONFIG_CIFS_FSCACHE=y
++CONFIG_CIFS_POSIX=y
++CONFIG_CIFS_SMB2=y
++CONFIG_CIFS_SMB311=y
++CONFIG_CIFS_STATS=y
++# CONFIG_CIFS_STATS2 is not set
++CONFIG_CIFS_UPCALL=y
++CONFIG_CIFS_WEAK_PW_HASH=y
++CONFIG_CIFS_XATTR=y
++CONFIG_CISS_SCSI_TAPE=y
++CONFIG_CLEANCACHE=y
++CONFIG_CLKBLD_I8253=y
++CONFIG_CLKDEV_LOOKUP=y
++CONFIG_CLKEVT_I8253=y
++CONFIG_CLKSRC_ACPI=y
++CONFIG_CLKSRC_ARM_GLOBAL_TIMER_SCHED_CLOCK=y
++CONFIG_CLKSRC_EXYNOS_MCT=y
++CONFIG_CLKSRC_I8253=y
++CONFIG_CLKSRC_IMX_GPT=y
++CONFIG_CLKSRC_MMIO=y
++CONFIG_CLKSRC_OF=y
++CONFIG_CLKSRC_PROBE=y
++CONFIG_CLKSRC_QCOM=y
++CONFIG_CLKSRC_TI_32K=y
++CONFIG_CLKSRC_VERSATILE=y
++CONFIG_CLK_QORIQ=y
++CONFIG_CLK_SP810=y
++CONFIG_CLK_TWL6040=m
++CONFIG_CLK_VEXPRESS_OSC=y
++CONFIG_CLOCKSOURCE_VALIDATE_LAST_CYCLE=y
++CONFIG_CLOCKSOURCE_WATCHDOG=y
++# CONFIG_CLOCK_THERMAL is not set
++CONFIG_CLONE_BACKWARDS=y
++CONFIG_CLONE_BACKWARDS2=y
++CONFIG_CLS_U32_MARK=y
++# CONFIG_CLS_U32_PERF is not set
++CONFIG_CLZ_TAB=y
++CONFIG_CM32181=m
++CONFIG_CM3232=m
++CONFIG_CM3323=m
++CONFIG_CM36651=m
++CONFIG_CMA_AREAS=7
++# CONFIG_CMA_DEBUG is not set
++# CONFIG_CMA_DEBUGFS is not set
++# CONFIG_CMDLINE_BOOL is not set
++# CONFIG_CMDLINE_FORCE is not set
++CONFIG_CMM_IUCV=y
++CONFIG_CMT_SPEECH=m
++CONFIG_CNIC=m
++CONFIG_CODA_FS=m
++# CONFIG_CODE_PATCHING_SELFTEST is not set
++CONFIG_COMEDI=m
++CONFIG_COMEDI_8254=m
++CONFIG_COMEDI_8255=m
++CONFIG_COMEDI_8255_PCI=m
++CONFIG_COMEDI_8255_SA=m
++CONFIG_COMEDI_ADDI_APCI_1032=m
++CONFIG_COMEDI_ADDI_APCI_1500=m
++CONFIG_COMEDI_ADDI_APCI_1516=m
++CONFIG_COMEDI_ADDI_APCI_1564=m
++CONFIG_COMEDI_ADDI_APCI_16XX=m
++CONFIG_COMEDI_ADDI_APCI_2032=m
++CONFIG_COMEDI_ADDI_APCI_2200=m
++CONFIG_COMEDI_ADDI_APCI_3120=m
++CONFIG_COMEDI_ADDI_APCI_3501=m
++CONFIG_COMEDI_ADDI_APCI_3XXX=m
++CONFIG_COMEDI_ADDI_WATCHDOG=m
++CONFIG_COMEDI_ADL_PCI6208=m
++CONFIG_COMEDI_ADL_PCI7X3X=m
++CONFIG_COMEDI_ADL_PCI8164=m
++CONFIG_COMEDI_ADL_PCI9111=m
++CONFIG_COMEDI_ADL_PCI9118=m
++CONFIG_COMEDI_ADQ12B=m
++CONFIG_COMEDI_ADV_PCI1710=m
++CONFIG_COMEDI_ADV_PCI1723=m
++CONFIG_COMEDI_ADV_PCI1724=m
++CONFIG_COMEDI_ADV_PCI_DIO=m
++CONFIG_COMEDI_AIO_AIO12_8=m
++CONFIG_COMEDI_AIO_IIRO_16=m
++CONFIG_COMEDI_AMPLC_DIO200=m
++CONFIG_COMEDI_AMPLC_DIO200_ISA=m
++CONFIG_COMEDI_AMPLC_DIO200_PCI=m
++CONFIG_COMEDI_AMPLC_PC236=m
++CONFIG_COMEDI_AMPLC_PC236_ISA=m
++CONFIG_COMEDI_AMPLC_PC236_PCI=m
++CONFIG_COMEDI_AMPLC_PC263_ISA=m
++CONFIG_COMEDI_AMPLC_PC263_PCI=m
++CONFIG_COMEDI_AMPLC_PCI224=m
++CONFIG_COMEDI_AMPLC_PCI230=m
++CONFIG_COMEDI_BOND=m
++CONFIG_COMEDI_C6XDIGIO=m
++CONFIG_COMEDI_CB_DAS16_CS=m
++CONFIG_COMEDI_CB_PCIDAS=m
++CONFIG_COMEDI_CB_PCIDAS64=m
++CONFIG_COMEDI_CB_PCIDDA=m
++CONFIG_COMEDI_CB_PCIMDAS=m
++CONFIG_COMEDI_CB_PCIMDDA=m
++CONFIG_COMEDI_CONTEC_PCI_DIO=m
++CONFIG_COMEDI_DAC02=m
++CONFIG_COMEDI_DAQBOARD2000=m
++CONFIG_COMEDI_DAS08=m
++CONFIG_COMEDI_DAS08_CS=m
++CONFIG_COMEDI_DAS08_ISA=m
++CONFIG_COMEDI_DAS08_PCI=m
++CONFIG_COMEDI_DAS16=m
++CONFIG_COMEDI_DAS16M1=m
++CONFIG_COMEDI_DAS1800=m
++CONFIG_COMEDI_DAS6402=m
++CONFIG_COMEDI_DAS800=m
++# CONFIG_COMEDI_DEBUG is not set
++CONFIG_COMEDI_DEFAULT_BUF_MAXSIZE_KB=20480
++CONFIG_COMEDI_DEFAULT_BUF_SIZE_KB=2048
++CONFIG_COMEDI_DMM32AT=m
++CONFIG_COMEDI_DT2801=m
++CONFIG_COMEDI_DT2811=m
++CONFIG_COMEDI_DT2814=m
++CONFIG_COMEDI_DT2815=m
++CONFIG_COMEDI_DT2817=m
++CONFIG_COMEDI_DT282X=m
++CONFIG_COMEDI_DT3000=m
++CONFIG_COMEDI_DT9812=m
++CONFIG_COMEDI_DYNA_PCI10XX=m
++CONFIG_COMEDI_FL512=m
++CONFIG_COMEDI_GSC_HPDI=m
++CONFIG_COMEDI_ICP_MULTI=m
++CONFIG_COMEDI_II_PCI20KC=m
++CONFIG_COMEDI_ISADMA=m
++CONFIG_COMEDI_ISA_DRIVERS=y
++CONFIG_COMEDI_JR3_PCI=m
++CONFIG_COMEDI_KCOMEDILIB=m
++CONFIG_COMEDI_KE_COUNTER=m
++CONFIG_COMEDI_ME4000=m
++CONFIG_COMEDI_ME_DAQ=m
++CONFIG_COMEDI_MF6X4=m
++CONFIG_COMEDI_MISC_DRIVERS=y
++CONFIG_COMEDI_MITE=m
++CONFIG_COMEDI_MPC624=m
++CONFIG_COMEDI_MULTIQ3=m
++CONFIG_COMEDI_NI_6527=m
++CONFIG_COMEDI_NI_65XX=m
++CONFIG_COMEDI_NI_660X=m
++CONFIG_COMEDI_NI_670X=m
++CONFIG_COMEDI_NI_ATMIO=m
++CONFIG_COMEDI_NI_ATMIO16D=m
++CONFIG_COMEDI_NI_AT_A2150=m
++CONFIG_COMEDI_NI_AT_AO=m
++CONFIG_COMEDI_NI_DAQ_700_CS=m
++CONFIG_COMEDI_NI_DAQ_DIO24_CS=m
++CONFIG_COMEDI_NI_LABPC=m
++CONFIG_COMEDI_NI_LABPC_CS=m
++CONFIG_COMEDI_NI_LABPC_ISA=m
++CONFIG_COMEDI_NI_LABPC_ISADMA=m
++CONFIG_COMEDI_NI_LABPC_PCI=m
++CONFIG_COMEDI_NI_MIO_CS=m
++CONFIG_COMEDI_NI_PCIDIO=m
++CONFIG_COMEDI_NI_PCIMIO=m
++CONFIG_COMEDI_NI_TIO=m
++CONFIG_COMEDI_NI_TIOCMD=m
++CONFIG_COMEDI_NI_USB6501=m
++CONFIG_COMEDI_PARPORT=m
++CONFIG_COMEDI_PCI_DRIVERS=m
++CONFIG_COMEDI_PCL711=m
++CONFIG_COMEDI_PCL724=m
++CONFIG_COMEDI_PCL726=m
++CONFIG_COMEDI_PCL730=m
++CONFIG_COMEDI_PCL812=m
++CONFIG_COMEDI_PCL816=m
++CONFIG_COMEDI_PCL818=m
++CONFIG_COMEDI_PCM3724=m
++CONFIG_COMEDI_PCMAD=m
++CONFIG_COMEDI_PCMCIA_DRIVERS=m
++CONFIG_COMEDI_PCMDA12=m
++CONFIG_COMEDI_PCMMIO=m
++CONFIG_COMEDI_PCMUIO=m
++CONFIG_COMEDI_QUATECH_DAQP_CS=m
++CONFIG_COMEDI_RTD520=m
++CONFIG_COMEDI_RTI800=m
++CONFIG_COMEDI_RTI802=m
++CONFIG_COMEDI_S526=m
++CONFIG_COMEDI_S626=m
++CONFIG_COMEDI_SERIAL2002=m
++CONFIG_COMEDI_SSV_DNP=m
++CONFIG_COMEDI_TEST=m
++CONFIG_COMEDI_USBDUX=m
++CONFIG_COMEDI_USBDUXFAST=m
++CONFIG_COMEDI_USBDUXSIGMA=m
++CONFIG_COMEDI_USB_DRIVERS=m
++CONFIG_COMEDI_VMK80XX=m
++CONFIG_COMMON_CLK=y
++CONFIG_COMMON_CLK_CDCE706=m
++CONFIG_COMMON_CLK_CDCE925=m
++CONFIG_COMMON_CLK_HI6220=y
++CONFIG_COMMON_CLK_MAX77686=m
++CONFIG_COMMON_CLK_MAX77802=m
++CONFIG_COMMON_CLK_MAX_GEN=y
++CONFIG_COMMON_CLK_PALMAS=m
++CONFIG_COMMON_CLK_PWM=m
++# CONFIG_COMMON_CLK_PXA is not set
++CONFIG_COMMON_CLK_QCOM=m
++CONFIG_COMMON_CLK_RK808=m
++CONFIG_COMMON_CLK_S2MPS11=m
++CONFIG_COMMON_CLK_SAMSUNG=y
++CONFIG_COMMON_CLK_SCPI=m
++CONFIG_COMMON_CLK_SI514=m
++CONFIG_COMMON_CLK_SI5351=m
++CONFIG_COMMON_CLK_SI570=m
++CONFIG_COMMON_CLK_VERSATILE=y
++CONFIG_COMMON_CLK_WM831X=m
++CONFIG_COMMON_CLK_XGENE=y
++# CONFIG_COMMON_CLK_XLNX_CLKWZRD is not set
++CONFIG_COMPACTION=y
++CONFIG_COMPAL_LAPTOP=m
++CONFIG_COMPAT=y
++CONFIG_COMPAT_BINFMT_ELF=y
++# CONFIG_COMPAT_BRK is not set
++CONFIG_COMPAT_FOR_U64_ALIGNMENT=y
++CONFIG_COMPAT_NETLINK_MESSAGES=y
++CONFIG_COMPAT_OLD_SIGACTION=y
++# CONFIG_COMPAT_VDSO is not set
++# CONFIG_COMPILE_TEST is not set
++CONFIG_CONNECTOR=y
++CONFIG_CONSOLE_POLL=y
++CONFIG_CONSOLE_TRANSLATIONS=y
++CONFIG_CONTEXT_SWITCH_TRACER=y
++CONFIG_COPS=m
++CONFIG_COPS_DAYNA=y
++CONFIG_COPS_TANGENT=y
++CONFIG_CORDIC=m
++CONFIG_COREDUMP=y
++CONFIG_CORENET_GENERIC=y
++# CONFIG_CORESIGHT is not set
++CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS=y
++CONFIG_COSA=m
++CONFIG_CP15_BARRIER_EMULATION=y
++# CONFIG_CPA_DEBUG is not set
++CONFIG_CPM=y
++CONFIG_CPM2=y
++CONFIG_CPU5_WDT=m
++CONFIG_CPUFREQ_DT=y
++CONFIG_CPUSETS=y
++CONFIG_CPU_32v6K=y
++CONFIG_CPU_32v7=y
++CONFIG_CPU_ABRT_EV7=y
++# CONFIG_CPU_BPREDICT_DISABLE is not set
++CONFIG_CPU_CACHE_V7=y
++CONFIG_CPU_CACHE_VIPT=y
++CONFIG_CPU_COPY_V6=y
++CONFIG_CPU_CP15=y
++CONFIG_CPU_CP15_MMU=y
++CONFIG_CPU_FREQ=y
++# CONFIG_CPU_FREQ_DEFAULT_GOV_CONSERVATIVE is not set
++# CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND is not set
++CONFIG_CPU_FREQ_DEFAULT_GOV_PERFORMANCE=y
++# CONFIG_CPU_FREQ_DEFAULT_GOV_POWERSAVE is not set
++# CONFIG_CPU_FREQ_DEFAULT_GOV_USERSPACE is not set
++CONFIG_CPU_FREQ_GOV_COMMON=y
++CONFIG_CPU_FREQ_GOV_CONSERVATIVE=y
++CONFIG_CPU_FREQ_GOV_ONDEMAND=y
++CONFIG_CPU_FREQ_GOV_PERFORMANCE=y
++CONFIG_CPU_FREQ_GOV_POWERSAVE=y
++CONFIG_CPU_FREQ_GOV_USERSPACE=y
++CONFIG_CPU_FREQ_MAPLE=y
++CONFIG_CPU_FREQ_PMAC=y
++CONFIG_CPU_FREQ_PMAC64=y
++CONFIG_CPU_FREQ_STAT=y
++CONFIG_CPU_FREQ_STAT_DETAILS=y
++CONFIG_CPU_HAS_ASID=y
++# CONFIG_CPU_ICACHE_DISABLE is not set
++CONFIG_CPU_IDLE=y
++CONFIG_CPU_IDLE_GOV_LADDER=y
++CONFIG_CPU_IDLE_GOV_MENU=y
++CONFIG_CPU_IDLE_MULTIPLE_DRIVERS=y
++CONFIG_CPU_NOTIFIER_ERROR_INJECT=m
++CONFIG_CPU_PABRT_V7=y
++CONFIG_CPU_PJ4=y
++CONFIG_CPU_PJ4B=y
++CONFIG_CPU_PM=y
++CONFIG_CPU_RMAP=y
++CONFIG_CPU_SUP_AMD=y
++CONFIG_CPU_SUP_CENTAUR=y
++CONFIG_CPU_SUP_CYRIX_32=y
++CONFIG_CPU_SUP_INTEL=y
++CONFIG_CPU_SUP_TRANSMETA_32=y
++CONFIG_CPU_SUP_UMC_32=y
++CONFIG_CPU_SW_DOMAIN_PAN=y
++CONFIG_CPU_THERMAL=y
++CONFIG_CPU_TLB_V7=y
++CONFIG_CPU_V7=y
++CONFIG_CRC16=y
++CONFIG_CRC32=y
++# CONFIG_CRC32_BIT is not set
++# CONFIG_CRC32_SARWATE is not set
++# CONFIG_CRC32_SELFTEST is not set
++# CONFIG_CRC32_SLICEBY4 is not set
++CONFIG_CRC32_SLICEBY8=y
++CONFIG_CRC7=m
++CONFIG_CRC8=m
++CONFIG_CRC_CCITT=m
++CONFIG_CRC_ITU_T=m
++CONFIG_CRC_T10DIF=y
++CONFIG_CROSS_COMPILE=""
++CONFIG_CROSS_MEMORY_ATTACH=y
++CONFIG_CROS_EC_CHARDEV=m
++CONFIG_CROS_EC_LPC=m
++CONFIG_CROS_EC_PROTO=y
++CONFIG_CRYPTO=y
++CONFIG_CRYPTO_842=m
++CONFIG_CRYPTO_ABLK_HELPER=m
++CONFIG_CRYPTO_AEAD=m
++CONFIG_CRYPTO_AEAD2=y
++CONFIG_CRYPTO_AES=y
++CONFIG_CRYPTO_AES_586=m
++CONFIG_CRYPTO_AES_ARM=m
++CONFIG_CRYPTO_AES_ARM64_CE=m
++CONFIG_CRYPTO_AES_ARM64_CE_BLK=m
++CONFIG_CRYPTO_AES_ARM64_CE_CCM=m
++CONFIG_CRYPTO_AES_ARM64_NEON_BLK=m
++CONFIG_CRYPTO_AES_ARM_BS=m
++CONFIG_CRYPTO_AES_ARM_CE=m
++CONFIG_CRYPTO_AES_NI_INTEL=m
++CONFIG_CRYPTO_AES_S390=m
++CONFIG_CRYPTO_AES_X86_64=m
++CONFIG_CRYPTO_AKCIPHER=y
++CONFIG_CRYPTO_AKCIPHER2=y
++CONFIG_CRYPTO_ALGAPI=y
++CONFIG_CRYPTO_ALGAPI2=y
++CONFIG_CRYPTO_ANSI_CPRNG=m
++CONFIG_CRYPTO_ANUBIS=m
++CONFIG_CRYPTO_ARC4=m
++CONFIG_CRYPTO_AUTHENC=m
++CONFIG_CRYPTO_BLKCIPHER=y
++CONFIG_CRYPTO_BLKCIPHER2=y
++CONFIG_CRYPTO_BLOWFISH=m
++CONFIG_CRYPTO_BLOWFISH_COMMON=m
++CONFIG_CRYPTO_BLOWFISH_X86_64=m
++CONFIG_CRYPTO_CAMELLIA=m
++CONFIG_CRYPTO_CAMELLIA_AESNI_AVX2_X86_64=m
++CONFIG_CRYPTO_CAMELLIA_AESNI_AVX_X86_64=m
++CONFIG_CRYPTO_CAMELLIA_X86_64=m
++CONFIG_CRYPTO_CAST5=m
++CONFIG_CRYPTO_CAST5_AVX_X86_64=m
++CONFIG_CRYPTO_CAST6=m
++CONFIG_CRYPTO_CAST6_AVX_X86_64=m
++CONFIG_CRYPTO_CAST_COMMON=m
++CONFIG_CRYPTO_CBC=y
++CONFIG_CRYPTO_CCM=m
++CONFIG_CRYPTO_CHACHA20=m
++CONFIG_CRYPTO_CHACHA20POLY1305=m
++CONFIG_CRYPTO_CHACHA20_X86_64=m
++CONFIG_CRYPTO_CMAC=m
++CONFIG_CRYPTO_CRC32=m
++CONFIG_CRYPTO_CRC32C=y
++CONFIG_CRYPTO_CRC32C_INTEL=y
++CONFIG_CRYPTO_CRC32_ARM64=m
++CONFIG_CRYPTO_CRC32_PCLMUL=m
++CONFIG_CRYPTO_CRCT10DIF=y
++CONFIG_CRYPTO_CRCT10DIF_PCLMUL=m
++CONFIG_CRYPTO_CRYPTD=m
++CONFIG_CRYPTO_CTR=m
++CONFIG_CRYPTO_CTS=m
++CONFIG_CRYPTO_DEFLATE=m
++CONFIG_CRYPTO_DES=m
++CONFIG_CRYPTO_DES3_EDE_X86_64=m
++CONFIG_CRYPTO_DES_S390=m
++CONFIG_CRYPTO_DEV_CCP=y
++CONFIG_CRYPTO_DEV_CCP_CRYPTO=m
++CONFIG_CRYPTO_DEV_CCP_DD=m
++CONFIG_CRYPTO_DEV_FSL_CAAM=m
++CONFIG_CRYPTO_DEV_FSL_CAAM_AHASH_API=m
++CONFIG_CRYPTO_DEV_FSL_CAAM_CRYPTO_API=m
++# CONFIG_CRYPTO_DEV_FSL_CAAM_DEBUG is not set
++CONFIG_CRYPTO_DEV_FSL_CAAM_INTC=y
++CONFIG_CRYPTO_DEV_FSL_CAAM_INTC_COUNT_THLD=255
++CONFIG_CRYPTO_DEV_FSL_CAAM_INTC_TIME_THLD=2048
++CONFIG_CRYPTO_DEV_FSL_CAAM_JR=m
++CONFIG_CRYPTO_DEV_FSL_CAAM_RINGSIZE=9
++CONFIG_CRYPTO_DEV_FSL_CAAM_RNG_API=m
++CONFIG_CRYPTO_DEV_GEODE=m
++CONFIG_CRYPTO_DEV_HIFN_795X=m
++CONFIG_CRYPTO_DEV_HIFN_795X_RNG=y
++CONFIG_CRYPTO_DEV_MARVELL_CESA=m
++CONFIG_CRYPTO_DEV_MV_CESA=m
++CONFIG_CRYPTO_DEV_MXS_DCP=m
++CONFIG_CRYPTO_DEV_NX=y
++CONFIG_CRYPTO_DEV_NX_COMPRESS=m
++CONFIG_CRYPTO_DEV_NX_COMPRESS_POWERNV=m
++CONFIG_CRYPTO_DEV_NX_COMPRESS_PSERIES=m
++CONFIG_CRYPTO_DEV_NX_ENCRYPT=m
++CONFIG_CRYPTO_DEV_OMAP_AES=m
++CONFIG_CRYPTO_DEV_OMAP_DES=m
++CONFIG_CRYPTO_DEV_OMAP_SHAM=m
++CONFIG_CRYPTO_DEV_PADLOCK=y
++CONFIG_CRYPTO_DEV_PADLOCK_AES=m
++CONFIG_CRYPTO_DEV_PADLOCK_SHA=m
++CONFIG_CRYPTO_DEV_QAT=m
++CONFIG_CRYPTO_DEV_QAT_DH895xCC=m
++CONFIG_CRYPTO_DEV_QAT_DH895xCCVF=m
++CONFIG_CRYPTO_DEV_QCE=m
++CONFIG_CRYPTO_DEV_S5P=m
++CONFIG_CRYPTO_DEV_SAHARA=m
++CONFIG_CRYPTO_DEV_TALITOS=m
++CONFIG_CRYPTO_DEV_TALITOS2=y
++CONFIG_CRYPTO_DEV_VMX=y
++CONFIG_CRYPTO_DEV_VMX_ENCRYPT=m
++CONFIG_CRYPTO_DRBG=m
++CONFIG_CRYPTO_DRBG_CTR=y
++CONFIG_CRYPTO_DRBG_HASH=y
++CONFIG_CRYPTO_DRBG_HMAC=y
++CONFIG_CRYPTO_DRBG_MENU=m
++CONFIG_CRYPTO_ECB=y
++CONFIG_CRYPTO_ECHAINIV=m
++CONFIG_CRYPTO_FCRYPT=m
++CONFIG_CRYPTO_GCM=m
++CONFIG_CRYPTO_GF128MUL=m
++CONFIG_CRYPTO_GHASH=m
++CONFIG_CRYPTO_GHASH_ARM64_CE=m
++CONFIG_CRYPTO_GHASH_ARM_CE=m
++CONFIG_CRYPTO_GHASH_CLMUL_NI_INTEL=m
++CONFIG_CRYPTO_GHASH_S390=m
++CONFIG_CRYPTO_GLUE_HELPER_X86=m
++CONFIG_CRYPTO_HASH=y
++CONFIG_CRYPTO_HASH2=y
++CONFIG_CRYPTO_HASH_INFO=y
++CONFIG_CRYPTO_HMAC=y
++CONFIG_CRYPTO_HW=y
++CONFIG_CRYPTO_JITTERENTROPY=m
++CONFIG_CRYPTO_KEYWRAP=m
++CONFIG_CRYPTO_KHAZAD=m
++CONFIG_CRYPTO_LRW=m
++CONFIG_CRYPTO_LZ4=m
++CONFIG_CRYPTO_LZ4HC=m
++CONFIG_CRYPTO_LZO=y
++CONFIG_CRYPTO_MANAGER=y
++CONFIG_CRYPTO_MANAGER2=y
++CONFIG_CRYPTO_MANAGER_DISABLE_TESTS=y
++CONFIG_CRYPTO_MCRYPTD=m
++CONFIG_CRYPTO_MD4=m
++CONFIG_CRYPTO_MD5=y
++CONFIG_CRYPTO_MD5_PPC=m
++CONFIG_CRYPTO_MICHAEL_MIC=m
++CONFIG_CRYPTO_NULL=m
++CONFIG_CRYPTO_NULL2=y
++CONFIG_CRYPTO_PCBC=m
++CONFIG_CRYPTO_PCOMP=m
++CONFIG_CRYPTO_PCOMP2=y
++CONFIG_CRYPTO_PCRYPT=m
++CONFIG_CRYPTO_POLY1305=m
++CONFIG_CRYPTO_POLY1305_X86_64=m
++CONFIG_CRYPTO_RMD128=m
++CONFIG_CRYPTO_RMD160=m
++CONFIG_CRYPTO_RMD256=m
++CONFIG_CRYPTO_RMD320=m
++CONFIG_CRYPTO_RNG=y
++CONFIG_CRYPTO_RNG2=y
++CONFIG_CRYPTO_RNG_DEFAULT=m
++CONFIG_CRYPTO_RSA=y
++CONFIG_CRYPTO_SALSA20=m
++CONFIG_CRYPTO_SALSA20_586=m
++CONFIG_CRYPTO_SALSA20_X86_64=m
++CONFIG_CRYPTO_SEED=m
++CONFIG_CRYPTO_SEQIV=m
++CONFIG_CRYPTO_SERPENT=m
++CONFIG_CRYPTO_SERPENT_AVX2_X86_64=m
++CONFIG_CRYPTO_SERPENT_AVX_X86_64=m
++CONFIG_CRYPTO_SERPENT_SSE2_586=m
++CONFIG_CRYPTO_SERPENT_SSE2_X86_64=m
++CONFIG_CRYPTO_SHA1=y
++CONFIG_CRYPTO_SHA1_ARM=m
++CONFIG_CRYPTO_SHA1_ARM64_CE=m
++CONFIG_CRYPTO_SHA1_ARM_CE=m
++CONFIG_CRYPTO_SHA1_ARM_NEON=m
++CONFIG_CRYPTO_SHA1_MB=m
++CONFIG_CRYPTO_SHA1_PPC=m
++CONFIG_CRYPTO_SHA1_S390=m
++CONFIG_CRYPTO_SHA1_SSSE3=m
++CONFIG_CRYPTO_SHA256=y
++CONFIG_CRYPTO_SHA256_ARM=m
++CONFIG_CRYPTO_SHA256_S390=m
++CONFIG_CRYPTO_SHA256_SSSE3=m
++CONFIG_CRYPTO_SHA2_ARM64_CE=m
++CONFIG_CRYPTO_SHA2_ARM_CE=m
++CONFIG_CRYPTO_SHA512=y
++CONFIG_CRYPTO_SHA512_ARM=m
++CONFIG_CRYPTO_SHA512_S390=m
++CONFIG_CRYPTO_SHA512_SSSE3=m
++CONFIG_CRYPTO_SKEIN=y
++CONFIG_CRYPTO_TEA=m
++CONFIG_CRYPTO_TEST=m
++CONFIG_CRYPTO_TGR192=m
++CONFIG_CRYPTO_TWOFISH=m
++CONFIG_CRYPTO_TWOFISH_586=m
++CONFIG_CRYPTO_TWOFISH_AVX_X86_64=m
++CONFIG_CRYPTO_TWOFISH_COMMON=m
++CONFIG_CRYPTO_TWOFISH_X86_64=m
++CONFIG_CRYPTO_TWOFISH_X86_64_3WAY=m
++CONFIG_CRYPTO_USER=m
++CONFIG_CRYPTO_USER_API=m
++CONFIG_CRYPTO_USER_API_AEAD=m
++CONFIG_CRYPTO_USER_API_HASH=m
++CONFIG_CRYPTO_USER_API_RNG=m
++CONFIG_CRYPTO_USER_API_SKCIPHER=m
++CONFIG_CRYPTO_VMAC=m
++CONFIG_CRYPTO_WORKQUEUE=y
++CONFIG_CRYPTO_WP512=m
++CONFIG_CRYPTO_XCBC=m
++CONFIG_CRYPTO_XTS=m
++CONFIG_CRYPTO_ZLIB=m
++# CONFIG_CS5535_MFGPT is not set
++CONFIG_CS89x0=m
++CONFIG_CS89x0_PLATFORM=y
++CONFIG_CTCM=m
++CONFIG_CUSE=m
++CONFIG_CW1200=m
++CONFIG_CW1200_WLAN_SDIO=m
++CONFIG_CW1200_WLAN_SPI=m
++CONFIG_CXL=m
++CONFIG_CXLFLASH=m
++CONFIG_CX_ECAT=m
++CONFIG_CYCLADES=m
++CONFIG_CYPRESS_FIRMWARE=m
++# CONFIG_CYZ_INTR is not set
++CONFIG_DA9052_WATCHDOG=m
++CONFIG_DA9055_WATCHDOG=m
++CONFIG_DA9062_WATCHDOG=m
++CONFIG_DA9063_WATCHDOG=m
++CONFIG_DA9150_GPADC=m
++CONFIG_DASD=m
++CONFIG_DASD_DIAG=m
++CONFIG_DASD_ECKD=m
++CONFIG_DASD_EER=y
++CONFIG_DASD_FBA=m
++CONFIG_DASD_PROFILE=y
++CONFIG_DAVICOM_PHY=m
++CONFIG_DCA=m
++CONFIG_DCACHE_WORD_ACCESS=y
++CONFIG_DCB=y
++CONFIG_DCDBAS=m
++CONFIG_DCSSBLK=m
++CONFIG_DDR=y
++CONFIG_DE2104X=m
++CONFIG_DE2104X_DSL=0
++CONFIG_DE4X5=m
++CONFIG_DEBUGGER=y
++# CONFIG_DEBUG_ALIGN_RODATA is not set
++# CONFIG_DEBUG_ATOMIC_SLEEP is not set
++# CONFIG_DEBUG_BLK_CGROUP is not set
++# CONFIG_DEBUG_BLOCK_EXT_DEVT is not set
++# CONFIG_DEBUG_BOOT_PARAMS is not set
++CONFIG_DEBUG_BUGVERBOSE=y
++# CONFIG_DEBUG_CREDENTIALS is not set
++# CONFIG_DEBUG_DEVRES is not set
++# CONFIG_DEBUG_DRIVER is not set
++# CONFIG_DEBUG_ENTRY is not set
++# CONFIG_DEBUG_FORCE_WEAK_PER_CPU is not set
++CONFIG_DEBUG_FS=y
++# CONFIG_DEBUG_GPIO is not set
++# CONFIG_DEBUG_HIGHMEM is not set
++# CONFIG_DEBUG_HOTPLUG_CPU0 is not set
++CONFIG_DEBUG_IMX_UART_PORT=1
++CONFIG_DEBUG_INFO=y
++CONFIG_DEBUG_INFO_DWARF4=y
++# CONFIG_DEBUG_INFO_REDUCED is not set
++# CONFIG_DEBUG_INFO_SPLIT is not set
++CONFIG_DEBUG_KERNEL=y
++# CONFIG_DEBUG_KMEMLEAK is not set
++# CONFIG_DEBUG_KOBJECT is not set
++# CONFIG_DEBUG_LIST is not set
++# CONFIG_DEBUG_LL is not set
++CONFIG_DEBUG_LL_INCLUDE="mach/debug-macro.S"
++# CONFIG_DEBUG_LOCKING_API_SELFTESTS is not set
++# CONFIG_DEBUG_LOCK_ALLOC is not set
++# CONFIG_DEBUG_MEMORY_INIT is not set
++# CONFIG_DEBUG_MUTEXES is not set
++# CONFIG_DEBUG_NMI_SELFTEST is not set
++# CONFIG_DEBUG_NOTIFIERS is not set
++# CONFIG_DEBUG_NX_TEST is not set
++# CONFIG_DEBUG_OBJECTS is not set
++# CONFIG_DEBUG_PAGEALLOC is not set
++# CONFIG_DEBUG_PERF_USE_VMALLOC is not set
++# CONFIG_DEBUG_PER_CPU_MAPS is not set
++# CONFIG_DEBUG_PINCTRL is not set
++# CONFIG_DEBUG_PI_LIST is not set
++# CONFIG_DEBUG_PREEMPT is not set
++CONFIG_DEBUG_RODATA=y
++# CONFIG_DEBUG_RODATA_TEST is not set
++# CONFIG_DEBUG_RT_MUTEXES is not set
++# CONFIG_DEBUG_SECTION_MISMATCH is not set
++CONFIG_DEBUG_SET_MODULE_RONX=y
++# CONFIG_DEBUG_SG is not set
++# CONFIG_DEBUG_SHIRQ is not set
++# CONFIG_DEBUG_SPINLOCK is not set
++# CONFIG_DEBUG_STACKOVERFLOW is not set
++# CONFIG_DEBUG_STACK_USAGE is not set
++# CONFIG_DEBUG_STRICT_USER_COPY_CHECKS is not set
++# CONFIG_DEBUG_TIMEKEEPING is not set
++# CONFIG_DEBUG_TLBFLUSH is not set
++# CONFIG_DEBUG_UART_8250 is not set
++# CONFIG_DEBUG_USER is not set
++CONFIG_DEBUG_VF_UART_PORT=1
++# CONFIG_DEBUG_VIRTUAL is not set
++# CONFIG_DEBUG_VM is not set
++# CONFIG_DEBUG_WW_MUTEX_SLOWPATH is not set
++# CONFIG_DEBUG_WX is not set
++CONFIG_DECNET_NF_GRABULATOR=m
++# CONFIG_DECNET_ROUTER is not set
++CONFIG_DECOMPRESS_BZIP2=y
++CONFIG_DECOMPRESS_GZIP=y
++CONFIG_DECOMPRESS_LZ4=y
++CONFIG_DECOMPRESS_LZMA=y
++CONFIG_DECOMPRESS_LZO=y
++CONFIG_DECOMPRESS_XZ=y
++# CONFIG_DEFAULT_CFQ is not set
++CONFIG_DEFAULT_CUBIC=y
++CONFIG_DEFAULT_DEADLINE=y
++CONFIG_DEFAULT_HOSTNAME="(none)"
++CONFIG_DEFAULT_HUNG_TASK_TIMEOUT=120
++CONFIG_DEFAULT_IOSCHED="deadline"
++CONFIG_DEFAULT_IO_DELAY_TYPE=1
++# CONFIG_DEFAULT_NOOP is not set
++# CONFIG_DEFAULT_RENO is not set
++CONFIG_DEFAULT_SECURITY="apparmor"
++CONFIG_DEFAULT_SECURITY_APPARMOR=y
++# CONFIG_DEFAULT_SECURITY_DAC is not set
++# CONFIG_DEFAULT_SECURITY_SELINUX is not set
++# CONFIG_DEFAULT_SECURITY_SMACK is not set
++# CONFIG_DEFAULT_SECURITY_TOMOYO is not set
++CONFIG_DEFAULT_TCP_CONG="cubic"
++CONFIG_DEFCONFIG_LIST="/lib/modules/$UNAME_RELEASE/.config"
++# CONFIG_DEFERRED_STRUCT_PAGE_INIT is not set
++CONFIG_DEFXX=m
++# CONFIG_DEFXX_MMIO is not set
++CONFIG_DELL_LAPTOP=m
++CONFIG_DELL_RBTN=m
++CONFIG_DELL_RBU=m
++CONFIG_DELL_SMO8800=m
++CONFIG_DELL_WMI=m
++CONFIG_DELL_WMI_AIO=m
++# CONFIG_DEPRECATED_PARAM_STRUCT is not set
++CONFIG_DETECT_HUNG_TASK=y
++# CONFIG_DEVFREQ_EVENT_EXYNOS_PPMU is not set
++CONFIG_DEVFREQ_GOV_PERFORMANCE=y
++CONFIG_DEVFREQ_GOV_POWERSAVE=y
++CONFIG_DEVFREQ_GOV_SIMPLE_ONDEMAND=y
++CONFIG_DEVFREQ_GOV_USERSPACE=y
++CONFIG_DEVFREQ_THERMAL=y
++# CONFIG_DEVKMEM is not set
++CONFIG_DEVMEM=y
++CONFIG_DEVPORT=y
++CONFIG_DEVPTS_MULTIPLE_INSTANCES=y
++CONFIG_DEVTMPFS=y
++CONFIG_DEVTMPFS_MOUNT=y
++CONFIG_DEV_APPLETALK=m
++CONFIG_DEV_COREDUMP=y
++CONFIG_DE_AOC=y
++CONFIG_DGAP=m
++CONFIG_DGNC=m
++CONFIG_DHT11=m
++CONFIG_DIAG288_WATCHDOG=m
++CONFIG_DISPLAY_CONNECTOR_ANALOG_TV=m
++CONFIG_DISPLAY_CONNECTOR_DVI=m
++CONFIG_DISPLAY_CONNECTOR_HDMI=y
++CONFIG_DISPLAY_ENCODER_OPA362=m
++CONFIG_DISPLAY_ENCODER_TFP410=m
++CONFIG_DISPLAY_ENCODER_TPD12S015=y
++CONFIG_DISPLAY_PANEL_DPI=m
++CONFIG_DISPLAY_PANEL_DSI_CM=m
++CONFIG_DISPLAY_PANEL_LGPHILIPS_LB035Q02=m
++CONFIG_DISPLAY_PANEL_NEC_NL8048HL11=m
++CONFIG_DISPLAY_PANEL_SHARP_LS037V7DW01=m
++CONFIG_DISPLAY_PANEL_SONY_ACX565AKM=m
++CONFIG_DISPLAY_PANEL_TPO_TD028TTEC1=m
++CONFIG_DISPLAY_PANEL_TPO_TD043MTEA1=m
++CONFIG_DL2K=m
++CONFIG_DLCI=m
++CONFIG_DLCI_MAX=8
++CONFIG_DLM=m
++# CONFIG_DLM_DEBUG is not set
++CONFIG_DM9000=m
++# CONFIG_DM9000_FORCE_SIMPLE_PHY_POLL is not set
++CONFIG_DM9102=m
++# CONFIG_DMADEVICES_DEBUG is not set
++CONFIG_DMAR_TABLE=y
++# CONFIG_DMATEST is not set
++CONFIG_DMA_ACPI=y
++# CONFIG_DMA_API_DEBUG is not set
++# CONFIG_DMA_CMA is not set
++CONFIG_DMA_ENGINE=y
++CONFIG_DMA_ENGINE_RAID=y
++CONFIG_DMA_OF=y
++CONFIG_DMA_OMAP=y
++CONFIG_DMI=y
++CONFIG_DMIID=y
++CONFIG_DMI_SCAN_MACHINE_NON_EFI_FALLBACK=y
++CONFIG_DMI_SYSFS=m
++CONFIG_DM_BIO_PRISON=m
++CONFIG_DM_BUFIO=m
++CONFIG_DM_CACHE=m
++CONFIG_DM_CACHE_CLEANER=m
++CONFIG_DM_CACHE_MQ=m
++CONFIG_DM_CACHE_SMQ=m
++CONFIG_DM_CRYPT=m
++# CONFIG_DM_DEBUG_BLOCK_STACK_TRACING is not set
++CONFIG_DM_DELAY=m
++CONFIG_DM_ERA=m
++CONFIG_DM_FLAKEY=m
++CONFIG_DM_LOG_USERSPACE=m
++CONFIG_DM_LOG_WRITES=m
++CONFIG_DM_MIRROR=m
++# CONFIG_DM_MQ_DEFAULT is not set
++CONFIG_DM_MULTIPATH=m
++CONFIG_DM_MULTIPATH_QL=m
++CONFIG_DM_MULTIPATH_ST=m
++CONFIG_DM_PERSISTENT_DATA=m
++CONFIG_DM_RAID=m
++CONFIG_DM_SNAPSHOT=m
++CONFIG_DM_SWITCH=m
++CONFIG_DM_THIN_PROVISIONING=m
++CONFIG_DM_UEVENT=y
++CONFIG_DM_VERITY=m
++CONFIG_DM_ZERO=m
++CONFIG_DNOTIFY=y
++CONFIG_DNS_RESOLVER=y
++CONFIG_DONGLE=y
++CONFIG_DOUBLEFAULT=y
++CONFIG_DOVE_CLK=y
++CONFIG_DOVE_THERMAL=m
++CONFIG_DP83848_PHY=m
++CONFIG_DP83867_PHY=m
++# CONFIG_DPM_WATCHDOG is not set
++CONFIG_DQL=y
++CONFIG_DRA752_THERMAL=y
++CONFIG_DRAGONRISE_FF=y
++# CONFIG_DRBD_FAULT_INJECTION is not set
++CONFIG_DRM_AMDGPU=m
++# CONFIG_DRM_AMDGPU_CIK is not set
++CONFIG_DRM_AMDGPU_USERPTR=y
++CONFIG_DRM_AMD_POWERPLAY=y
++CONFIG_DRM_ARMADA=m
++CONFIG_DRM_AST=m
++CONFIG_DRM_ATMEL_HLCDC=m
++# CONFIG_DRM_BOCHS is not set
++CONFIG_DRM_BRIDGE=y
++CONFIG_DRM_CIRRUS_QEMU=m
++CONFIG_DRM_DP_AUX_CHARDEV=y
++CONFIG_DRM_DW_HDMI=m
++CONFIG_DRM_DW_HDMI_AHB_AUDIO=m
++CONFIG_DRM_EXYNOS=m
++CONFIG_DRM_EXYNOS5433_DECON=y
++# CONFIG_DRM_EXYNOS7_DECON is not set
++CONFIG_DRM_EXYNOS_DSI=y
++# CONFIG_DRM_EXYNOS_FIMD is not set
++# CONFIG_DRM_EXYNOS_G2D is not set
++CONFIG_DRM_EXYNOS_IOMMU=y
++# CONFIG_DRM_EXYNOS_IPP is not set
++CONFIG_DRM_EXYNOS_MIC=y
++# CONFIG_DRM_EXYNOS_VIDI is not set
++CONFIG_DRM_FBDEV_EMULATION=y
++CONFIG_DRM_FSL_DCU=m
++CONFIG_DRM_GEM_CMA_HELPER=y
++CONFIG_DRM_GMA3600=y
++CONFIG_DRM_GMA500=m
++CONFIG_DRM_GMA600=y
++CONFIG_DRM_I2C_ADV7511=m
++CONFIG_DRM_I2C_CH7006=m
++CONFIG_DRM_I2C_NXP_TDA998X=m
++CONFIG_DRM_I2C_SIL164=m
++CONFIG_DRM_I810=m
++CONFIG_DRM_I915=m
++CONFIG_DRM_I915_BPO=m
++# CONFIG_DRM_I915_BPO_DEBUG is not set
++# CONFIG_DRM_I915_BPO_PRELIMINARY_HW_SUPPORT is not set
++CONFIG_DRM_I915_BPO_USERPTR=y
++# CONFIG_DRM_I915_BPO_WERROR is not set
++# CONFIG_DRM_I915_PRELIMINARY_HW_SUPPORT is not set
++CONFIG_DRM_IMX=m
++CONFIG_DRM_IMX_FB_HELPER=m
++CONFIG_DRM_IMX_HDMI=m
++CONFIG_DRM_IMX_IPUV3=m
++CONFIG_DRM_IMX_LDB=m
++CONFIG_DRM_IMX_PARALLEL_DISPLAY=m
++CONFIG_DRM_IMX_TVE=m
++CONFIG_DRM_KMS_CMA_HELPER=y
++CONFIG_DRM_KMS_FB_HELPER=y
++CONFIG_DRM_KMS_HELPER=m
++CONFIG_DRM_LOAD_EDID_FIRMWARE=y
++CONFIG_DRM_MEDFIELD=y
++CONFIG_DRM_MGA=m
++# CONFIG_DRM_MGAG200 is not set
++CONFIG_DRM_MIPI_DSI=y
++CONFIG_DRM_MSM=m
++CONFIG_DRM_MSM_DSI=y
++CONFIG_DRM_MSM_DSI_20NM_PHY=y
++CONFIG_DRM_MSM_DSI_28NM_PHY=y
++CONFIG_DRM_MSM_DSI_PLL=y
++CONFIG_DRM_MSM_REGISTER_LOGGING=y
++CONFIG_DRM_NOUVEAU=m
++CONFIG_DRM_NOUVEAU_BACKLIGHT=y
++CONFIG_DRM_NXP_PTN3460=m
++# CONFIG_DRM_OMAP is not set
++CONFIG_DRM_PANEL=y
++CONFIG_DRM_PANEL_LG_LG4573=m
++CONFIG_DRM_PANEL_SAMSUNG_LD9040=m
++CONFIG_DRM_PANEL_SAMSUNG_S6E8AA0=m
++CONFIG_DRM_PANEL_SHARP_LQ101R1SX01=m
++CONFIG_DRM_PANEL_SIMPLE=m
++CONFIG_DRM_PARADE_PS8622=m
++CONFIG_DRM_QXL=m
++CONFIG_DRM_R128=m
++CONFIG_DRM_RADEON=m
++# CONFIG_DRM_RADEON_UMS is not set
++# CONFIG_DRM_RADEON_USERPTR is not set
++CONFIG_DRM_RCAR_DU=m
++CONFIG_DRM_RCAR_HDMI=y
++CONFIG_DRM_RCAR_LVDS=y
++CONFIG_DRM_ROCKCHIP=m
++CONFIG_DRM_SAVAGE=m
++CONFIG_DRM_SHMOBILE=m
++CONFIG_DRM_SIS=m
++# CONFIG_DRM_STI is not set
++CONFIG_DRM_TDFX=m
++CONFIG_DRM_TEGRA=m
++# CONFIG_DRM_TEGRA_DEBUG is not set
++CONFIG_DRM_TEGRA_FBDEV=y
++CONFIG_DRM_TEGRA_STAGING=y
++CONFIG_DRM_TILCDC=m
++CONFIG_DRM_TILCDC_SLAVE_COMPAT=y
++CONFIG_DRM_TTM=m
++CONFIG_DRM_UDL=m
++CONFIG_DRM_VGEM=m
++CONFIG_DRM_VIA=m
++CONFIG_DRM_VIRTIO_GPU=m
++CONFIG_DRM_VMWGFX=m
++CONFIG_DRM_VMWGFX_FBCON=y
++CONFIG_DS1682=m
++CONFIG_DSCC4=m
++CONFIG_DSCC4_PCISYNC=y
++CONFIG_DSCC4_PCI_RST=y
++CONFIG_DTC=y
++CONFIG_DTL=y
++CONFIG_DTLK=m
++CONFIG_DT_IDLE_STATES=y
++CONFIG_DUMMY=m
++CONFIG_DUMMY_CONSOLE=y
++CONFIG_DUMMY_CONSOLE_COLUMNS=80
++CONFIG_DUMMY_CONSOLE_ROWS=25
++CONFIG_DVB_A8293=m
++CONFIG_DVB_AF9013=m
++CONFIG_DVB_AF9033=m
++CONFIG_DVB_AS102=m
++CONFIG_DVB_AS102_FE=m
++CONFIG_DVB_ASCOT2E=m
++CONFIG_DVB_ATBM8830=m
++CONFIG_DVB_AU8522=m
++CONFIG_DVB_AU8522_DTV=m
++CONFIG_DVB_AU8522_V4L=m
++CONFIG_DVB_AV7110=m
++CONFIG_DVB_AV7110_IR=y
++CONFIG_DVB_AV7110_OSD=y
++CONFIG_DVB_B2C2_FLEXCOP=m
++CONFIG_DVB_B2C2_FLEXCOP_PCI=m
++# CONFIG_DVB_B2C2_FLEXCOP_PCI_DEBUG is not set
++CONFIG_DVB_B2C2_FLEXCOP_USB=m
++# CONFIG_DVB_B2C2_FLEXCOP_USB_DEBUG is not set
++CONFIG_DVB_BCM3510=m
++CONFIG_DVB_BT8XX=m
++CONFIG_DVB_BUDGET=m
++CONFIG_DVB_BUDGET_AV=m
++CONFIG_DVB_BUDGET_CI=m
++CONFIG_DVB_BUDGET_CORE=m
++CONFIG_DVB_BUDGET_PATCH=m
++# CONFIG_DVB_C8SECTPFE is not set
++CONFIG_DVB_CORE=m
++CONFIG_DVB_CX22700=m
++CONFIG_DVB_CX22702=m
++CONFIG_DVB_CX24110=m
++CONFIG_DVB_CX24116=m
++CONFIG_DVB_CX24117=m
++CONFIG_DVB_CX24120=m
++CONFIG_DVB_CX24123=m
++CONFIG_DVB_CXD2099=m
++CONFIG_DVB_CXD2820R=m
++CONFIG_DVB_CXD2841ER=m
++CONFIG_DVB_DDBRIDGE=m
++CONFIG_DVB_DIB3000MB=m
++CONFIG_DVB_DIB3000MC=m
++CONFIG_DVB_DIB7000M=m
++CONFIG_DVB_DIB7000P=m
++CONFIG_DVB_DIB8000=m
++CONFIG_DVB_DM1105=m
++CONFIG_DVB_DRX39XYJ=m
++CONFIG_DVB_DRXD=m
++CONFIG_DVB_DRXK=m
++CONFIG_DVB_DS3000=m
++# CONFIG_DVB_DUMMY_FE is not set
++CONFIG_DVB_DYNAMIC_MINORS=y
++CONFIG_DVB_EC100=m
++CONFIG_DVB_FIREDTV=m
++CONFIG_DVB_FIREDTV_INPUT=y
++CONFIG_DVB_HOPPER=m
++CONFIG_DVB_HORUS3A=m
++CONFIG_DVB_ISL6405=m
++CONFIG_DVB_ISL6421=m
++CONFIG_DVB_ISL6423=m
++CONFIG_DVB_IX2505V=m
++CONFIG_DVB_L64781=m
++CONFIG_DVB_LG2160=m
++CONFIG_DVB_LGDT3305=m
++CONFIG_DVB_LGDT3306A=m
++CONFIG_DVB_LGDT330X=m
++CONFIG_DVB_LGS8GXX=m
++CONFIG_DVB_LNBH25=m
++CONFIG_DVB_LNBP21=m
++CONFIG_DVB_LNBP22=m
++CONFIG_DVB_M88DS3103=m
++CONFIG_DVB_M88RS2000=m
++CONFIG_DVB_MANTIS=m
++CONFIG_DVB_MAX_ADAPTERS=8
++CONFIG_DVB_MB86A16=m
++CONFIG_DVB_MB86A20S=m
++CONFIG_DVB_MN88472=m
++CONFIG_DVB_MN88473=m
++CONFIG_DVB_MT312=m
++CONFIG_DVB_MT352=m
++CONFIG_DVB_NET=y
++CONFIG_DVB_NETUP_UNIDVB=m
++CONFIG_DVB_NGENE=m
++CONFIG_DVB_NXT200X=m
++CONFIG_DVB_NXT6000=m
++CONFIG_DVB_OR51132=m
++CONFIG_DVB_OR51211=m
++CONFIG_DVB_PLATFORM_DRIVERS=y
++CONFIG_DVB_PLL=m
++CONFIG_DVB_PLUTO2=m
++CONFIG_DVB_PT1=m
++CONFIG_DVB_PT3=m
++CONFIG_DVB_RTL2830=m
++CONFIG_DVB_RTL2832=m
++CONFIG_DVB_RTL2832_SDR=m
++CONFIG_DVB_S5H1409=m
++CONFIG_DVB_S5H1411=m
++CONFIG_DVB_S5H1420=m
++CONFIG_DVB_S921=m
++CONFIG_DVB_SI2165=m
++CONFIG_DVB_SI2168=m
++CONFIG_DVB_SI21XX=m
++CONFIG_DVB_SMIPCIE=m
++CONFIG_DVB_SP2=m
++CONFIG_DVB_SP8870=m
++CONFIG_DVB_SP887X=m
++CONFIG_DVB_STB0899=m
++CONFIG_DVB_STB6000=m
++CONFIG_DVB_STB6100=m
++CONFIG_DVB_STV0288=m
++CONFIG_DVB_STV0297=m
++CONFIG_DVB_STV0299=m
++CONFIG_DVB_STV0367=m
++CONFIG_DVB_STV0900=m
++CONFIG_DVB_STV090x=m
++CONFIG_DVB_STV6110=m
++CONFIG_DVB_STV6110x=m
++CONFIG_DVB_TC90522=m
++CONFIG_DVB_TDA10021=m
++CONFIG_DVB_TDA10023=m
++CONFIG_DVB_TDA10048=m
++CONFIG_DVB_TDA1004X=m
++CONFIG_DVB_TDA10071=m
++CONFIG_DVB_TDA10086=m
++CONFIG_DVB_TDA18271C2DD=m
++CONFIG_DVB_TDA665x=m
++CONFIG_DVB_TDA8083=m
++CONFIG_DVB_TDA8261=m
++CONFIG_DVB_TDA826X=m
++CONFIG_DVB_TS2020=m
++CONFIG_DVB_TTUSB_BUDGET=m
++CONFIG_DVB_TTUSB_DEC=m
++CONFIG_DVB_TUA6100=m
++CONFIG_DVB_TUNER_CX24113=m
++CONFIG_DVB_TUNER_DIB0070=m
++CONFIG_DVB_TUNER_DIB0090=m
++CONFIG_DVB_TUNER_ITD1000=m
++CONFIG_DVB_USB=m
++CONFIG_DVB_USB_A800=m
++CONFIG_DVB_USB_AF9005=m
++CONFIG_DVB_USB_AF9005_REMOTE=m
++CONFIG_DVB_USB_AF9015=m
++CONFIG_DVB_USB_AF9035=m
++CONFIG_DVB_USB_ANYSEE=m
++CONFIG_DVB_USB_AU6610=m
++CONFIG_DVB_USB_AZ6007=m
++CONFIG_DVB_USB_AZ6027=m
++CONFIG_DVB_USB_CE6230=m
++CONFIG_DVB_USB_CINERGY_T2=m
++CONFIG_DVB_USB_CXUSB=m
++# CONFIG_DVB_USB_DEBUG is not set
++CONFIG_DVB_USB_DIB0700=m
++CONFIG_DVB_USB_DIBUSB_MB=m
++# CONFIG_DVB_USB_DIBUSB_MB_FAULTY is not set
++CONFIG_DVB_USB_DIBUSB_MC=m
++CONFIG_DVB_USB_DIGITV=m
++CONFIG_DVB_USB_DTT200U=m
++CONFIG_DVB_USB_DTV5100=m
++CONFIG_DVB_USB_DVBSKY=m
++CONFIG_DVB_USB_DW2102=m
++CONFIG_DVB_USB_EC168=m
++CONFIG_DVB_USB_FRIIO=m
++CONFIG_DVB_USB_GL861=m
++CONFIG_DVB_USB_GP8PSK=m
++CONFIG_DVB_USB_LME2510=m
++CONFIG_DVB_USB_M920X=m
++CONFIG_DVB_USB_MXL111SF=m
++CONFIG_DVB_USB_NOVA_T_USB2=m
++CONFIG_DVB_USB_OPERA1=m
++CONFIG_DVB_USB_PCTV452E=m
++CONFIG_DVB_USB_RTL28XXU=m
++CONFIG_DVB_USB_TECHNISAT_USB2=m
++CONFIG_DVB_USB_TTUSB2=m
++CONFIG_DVB_USB_UMT_010=m
++CONFIG_DVB_USB_V2=m
++CONFIG_DVB_USB_VP702X=m
++CONFIG_DVB_USB_VP7045=m
++CONFIG_DVB_VES1820=m
++CONFIG_DVB_VES1X93=m
++CONFIG_DVB_ZL10036=m
++CONFIG_DVB_ZL10039=m
++CONFIG_DVB_ZL10353=m
++CONFIG_DWMAC_GENERIC=m
++CONFIG_DWMAC_IPQ806X=m
++CONFIG_DWMAC_LPC18XX=m
++CONFIG_DWMAC_MESON=m
++CONFIG_DWMAC_ROCKCHIP=m
++CONFIG_DWMAC_SOCFPGA=m
++CONFIG_DWMAC_STI=m
++CONFIG_DWMAC_SUNXI=m
++CONFIG_DW_APB_ICTL=y
++CONFIG_DW_APB_TIMER=y
++CONFIG_DW_APB_TIMER_OF=y
++CONFIG_DW_DMAC=m
++CONFIG_DW_DMAC_CORE=m
++CONFIG_DW_DMAC_PCI=m
++CONFIG_DYNAMIC_DEBUG=y
++CONFIG_DYNAMIC_FTRACE=y
++CONFIG_DYNAMIC_FTRACE_WITH_REGS=y
++CONFIG_E100=m
++CONFIG_E1000=m
++CONFIG_E1000E=m
++CONFIG_E1000E_HWTS=y
++# CONFIG_E200 is not set
++CONFIG_E500=y
++# CONFIG_E5500_CPU is not set
++# CONFIG_E6500_CPU is not set
++CONFIG_EADM_SCH=m
++CONFIG_EARLY_PRINTK=y
++CONFIG_EARLY_PRINTK_DBGP=y
++CONFIG_EARLY_PRINTK_EFI=y
++CONFIG_ECRYPT_FS=y
++CONFIG_ECRYPT_FS_MESSAGING=y
++CONFIG_EDAC=y
++CONFIG_EDAC_AMD64=m
++# CONFIG_EDAC_AMD64_ERROR_INJECTION is not set
++CONFIG_EDAC_AMD76X=m
++CONFIG_EDAC_AMD8111=m
++CONFIG_EDAC_AMD8131=m
++CONFIG_EDAC_ATOMIC_SCRUB=y
++CONFIG_EDAC_CPC925=m
++# CONFIG_EDAC_DEBUG is not set
++CONFIG_EDAC_DECODE_MCE=m
++CONFIG_EDAC_E752X=m
++CONFIG_EDAC_E7XXX=m
++CONFIG_EDAC_HIGHBANK_L2=m
++CONFIG_EDAC_HIGHBANK_MC=m
++CONFIG_EDAC_I3000=m
++CONFIG_EDAC_I3200=m
++CONFIG_EDAC_I5000=m
++CONFIG_EDAC_I5100=m
++CONFIG_EDAC_I5400=m
++CONFIG_EDAC_I7300=m
++CONFIG_EDAC_I7CORE=m
++CONFIG_EDAC_I82860=m
++CONFIG_EDAC_I82875P=m
++CONFIG_EDAC_I82975X=m
++CONFIG_EDAC_IE31200=m
++# CONFIG_EDAC_LEGACY_SYSFS is not set
++CONFIG_EDAC_MM_EDAC=m
++CONFIG_EDAC_MPC85XX=m
++CONFIG_EDAC_PASEMI=m
++CONFIG_EDAC_R82600=m
++CONFIG_EDAC_SBRIDGE=m
++CONFIG_EDAC_SKX=m
++CONFIG_EDAC_SUPPORT=y
++CONFIG_EDAC_X38=m
++CONFIG_EDAC_XGENE=m
++CONFIG_EDD=y
++CONFIG_EDD_OFF=y
++CONFIG_EEEPC_LAPTOP=m
++CONFIG_EEEPC_WMI=m
++CONFIG_EEH=y
++CONFIG_EEPROM_93XX46=m
++CONFIG_EEPROM_AT24=m
++CONFIG_EEPROM_AT25=m
++CONFIG_EEPROM_LEGACY=m
++CONFIG_EEPROM_MAX6875=m
++CONFIG_EFI=y
++CONFIG_EFIVAR_FS=y
++CONFIG_EFI_ARMSTUB=y
++CONFIG_EFI_ESRT=y
++# CONFIG_EFI_FAKE_MEMMAP is not set
++CONFIG_EFI_MIXED=y
++CONFIG_EFI_PARAMS_FROM_FDT=y
++CONFIG_EFI_PARTITION=y
++# CONFIG_EFI_PGT_DUMP is not set
++CONFIG_EFI_RUNTIME_MAP=y
++CONFIG_EFI_RUNTIME_WRAPPERS=y
++CONFIG_EFI_SECURE_BOOT_SIG_ENFORCE=y
++CONFIG_EFI_SIGNATURE_LIST_PARSER=y
++CONFIG_EFI_STUB=y
++CONFIG_EFI_TEST=m
++CONFIG_EFI_VARS=y
++CONFIG_EFI_VARS_PSTORE=m
++# CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE is not set
++CONFIG_EHEA=y
++CONFIG_EISA=y
++CONFIG_EISA_NAMES=y
++CONFIG_EISA_PCI_EISA=y
++CONFIG_EISA_VIRTUAL_ROOT=y
++CONFIG_EISA_VLB_PRIMING=y
++CONFIG_EL3=m
++CONFIG_ELECTRA_CF=m
++CONFIG_ELF_CORE=y
++CONFIG_EMAC_ROCKCHIP=m
++# CONFIG_EMBEDDED is not set
++CONFIG_EMU_SIZE=0x10000000
++# CONFIG_ENABLE_MUST_CHECK is not set
++# CONFIG_ENABLE_WARN_DEPRECATED is not set
++CONFIG_ENA_ETHERNET=m
++CONFIG_ENC28J60=m
++# CONFIG_ENC28J60_WRITEVERIFY is not set
++CONFIG_ENCRYPTED_KEYS=y
++CONFIG_ENCX24J600=m
++CONFIG_ENIC=m
++CONFIG_EPAPR_PARAVIRT=y
++CONFIG_EPIC100=m
++CONFIG_EPOLL=y
++CONFIG_EQUALIZER=m
++CONFIG_ESI_DONGLE=m
++CONFIG_ET131X=m
++CONFIG_ETHERNET=y
++CONFIG_EUROTECH_WDT=m
++CONFIG_EVENTFD=y
++CONFIG_EVENT_TRACING=y
++CONFIG_EVM=y
++CONFIG_EVM_ATTR_FSUUID=y
++CONFIG_EVM_EXTRA_SMACK_XATTRS=y
++# CONFIG_EXOFS_DEBUG is not set
++CONFIG_EXPERT=y
++CONFIG_EXPORTFS=y
++# CONFIG_EXT2_FS is not set
++# CONFIG_EXT3_FS is not set
++# CONFIG_EXT4_DEBUG is not set
++CONFIG_EXT4_ENCRYPTION=m
++CONFIG_EXT4_FS=y
++CONFIG_EXT4_FS_ENCRYPTION=y
++CONFIG_EXT4_FS_POSIX_ACL=y
++CONFIG_EXT4_FS_SECURITY=y
++CONFIG_EXT4_USE_FOR_EXT2=y
++CONFIG_EXTCON_ADC_JACK=m
++CONFIG_EXTCON_ARIZONA=m
++CONFIG_EXTCON_AXP288=m
++CONFIG_EXTCON_GPIO=m
++CONFIG_EXTCON_MAX14577=m
++CONFIG_EXTCON_MAX77693=m
++CONFIG_EXTCON_MAX77843=m
++CONFIG_EXTCON_MAX8997=m
++CONFIG_EXTCON_PALMAS=m
++CONFIG_EXTCON_RT8973A=m
++CONFIG_EXTCON_SM5502=m
++CONFIG_EXTCON_USB_GPIO=m
++CONFIG_EXTRA_FIRMWARE=""
++CONFIG_EXTRA_TARGETS=""
++CONFIG_EXYNOS5420_MCPM=y
++CONFIG_EXYNOS_ADC=m
++CONFIG_EXYNOS_CPU_SUSPEND=y
++CONFIG_EXYNOS_IOMMU=y
++# CONFIG_EXYNOS_IOMMU_DEBUG is not set
++CONFIG_EXYNOS_MIPI_DSI=y
++CONFIG_EXYNOS_THERMAL=y
++CONFIG_EXYNOS_VIDEO=y
++CONFIG_EZCHIP_NPS_MANAGEMENT_ENET=m
++CONFIG_EZX_PCAP=y
++# CONFIG_F2FS_CHECK_FS is not set
++CONFIG_F2FS_FS_ENCRYPTION=y
++CONFIG_F2FS_FS_POSIX_ACL=y
++CONFIG_F2FS_FS_SECURITY=y
++CONFIG_F2FS_FS_XATTR=y
++# CONFIG_F2FS_IO_TRACE is not set
++CONFIG_F2FS_STAT_FS=y
++CONFIG_F71808E_WDT=m
++CONFIG_FAIR_GROUP_SCHED=y
++CONFIG_FANOTIFY=y
++CONFIG_FANOTIFY_ACCESS_PERMISSIONS=y
++CONFIG_FARSYNC=m
++CONFIG_FAT_DEFAULT_CODEPAGE=437
++CONFIG_FAT_DEFAULT_IOCHARSET="iso8859-1"
++CONFIG_FAT_FS=y
++# CONFIG_FAULT_INJECTION is not set
++CONFIG_FA_DUMP=y
++CONFIG_FB_3DFX=m
++# CONFIG_FB_3DFX_ACCEL is not set
++# CONFIG_FB_3DFX_I2C is not set
++CONFIG_FB_ARC=m
++CONFIG_FB_ARK=m
++CONFIG_FB_ARMCLCD=y
++CONFIG_FB_ASILIANT=y
++CONFIG_FB_ATY=m
++CONFIG_FB_ATY128_BACKLIGHT=y
++CONFIG_FB_ATY_BACKLIGHT=y
++CONFIG_FB_ATY_CT=y
++# CONFIG_FB_ATY_GENERIC_LCD is not set
++CONFIG_FB_ATY_GX=y
++CONFIG_FB_AUO_K1900=m
++CONFIG_FB_AUO_K1901=m
++CONFIG_FB_AUO_K190X=m
++CONFIG_FB_BACKLIGHT=y
++CONFIG_FB_BROADSHEET=m
++CONFIG_FB_CARILLO_RANCH=m
++CONFIG_FB_CARMINE=m
++CONFIG_FB_CARMINE_DRAM_EVAL=y
++CONFIG_FB_CFB_COPYAREA=y
++CONFIG_FB_CFB_FILLRECT=y
++CONFIG_FB_CFB_IMAGEBLIT=y
++CONFIG_FB_CIRRUS=m
++CONFIG_FB_CMDLINE=y
++CONFIG_FB_CONTROL=y
++CONFIG_FB_CT65550=y
++CONFIG_FB_CYBER2000=m
++CONFIG_FB_CYBER2000_DDC=y
++CONFIG_FB_DA8XX=m
++CONFIG_FB_DDC=m
++CONFIG_FB_DEFERRED_IO=y
++CONFIG_FB_EFI=y
++CONFIG_FB_FLEX=m
++# CONFIG_FB_FOREIGN_ENDIAN is not set
++CONFIG_FB_FSL_DIU=m
++CONFIG_FB_GEODE=y
++CONFIG_FB_GEODE_GX=m
++CONFIG_FB_GEODE_GX1=m
++CONFIG_FB_GEODE_LX=m
++CONFIG_FB_HECUBA=m
++CONFIG_FB_HGA=m
++CONFIG_FB_HYPERV=m
++CONFIG_FB_I740=m
++CONFIG_FB_I810=m
++# CONFIG_FB_I810_GTF is not set
++CONFIG_FB_IMSTT=y
++CONFIG_FB_IMX=m
++CONFIG_FB_INTEL=m
++# CONFIG_FB_INTEL_DEBUG is not set
++CONFIG_FB_INTEL_I2C=y
++CONFIG_FB_KYRO=m
++CONFIG_FB_LE80578=m
++CONFIG_FB_MATROX=m
++CONFIG_FB_MATROX_G=y
++CONFIG_FB_MATROX_I2C=m
++CONFIG_FB_MATROX_MAVEN=m
++CONFIG_FB_MATROX_MILLENIUM=y
++CONFIG_FB_MATROX_MYSTIQUE=y
++CONFIG_FB_MB862XX=m
++CONFIG_FB_MB862XX_I2C=y
++# CONFIG_FB_MB862XX_LIME is not set
++CONFIG_FB_MB862XX_PCI_GDC=y
++CONFIG_FB_METRONOME=m
++CONFIG_FB_MODE_HELPERS=y
++CONFIG_FB_MX3=y
++CONFIG_FB_MXS=m
++CONFIG_FB_N411=m
++CONFIG_FB_NEOMAGIC=m
++CONFIG_FB_NVIDIA=m
++CONFIG_FB_NVIDIA_BACKLIGHT=y
++# CONFIG_FB_NVIDIA_DEBUG is not set
++CONFIG_FB_NVIDIA_I2C=y
++CONFIG_FB_OF=y
++CONFIG_FB_OMAP2=m
++# CONFIG_FB_OMAP2_DEBUG_SUPPORT is not set
++CONFIG_FB_OMAP2_NUM_FBS=3
++CONFIG_FB_OPENCORES=m
++CONFIG_FB_PLATINUM=y
++CONFIG_FB_PM2=m
++CONFIG_FB_PM2_FIFO_DISCONNECT=y
++CONFIG_FB_PM3=m
++CONFIG_FB_PS3=y
++CONFIG_FB_PS3_DEFAULT_SIZE_M=9
++CONFIG_FB_RADEON=m
++CONFIG_FB_RADEON_BACKLIGHT=y
++# CONFIG_FB_RADEON_DEBUG is not set
++CONFIG_FB_RADEON_I2C=y
++CONFIG_FB_RIVA=m
++CONFIG_FB_RIVA_BACKLIGHT=y
++# CONFIG_FB_RIVA_DEBUG is not set
++CONFIG_FB_RIVA_I2C=y
++CONFIG_FB_S1D13XXX=m
++CONFIG_FB_S3=m
++CONFIG_FB_S3C=m
++# CONFIG_FB_S3C_DEBUG_REGWRITE is not set
++CONFIG_FB_S3_DDC=y
++CONFIG_FB_SAVAGE=m
++# CONFIG_FB_SAVAGE_ACCEL is not set
++CONFIG_FB_SAVAGE_I2C=y
++CONFIG_FB_SH_MOBILE_HDMI=m
++CONFIG_FB_SH_MOBILE_LCDC=m
++CONFIG_FB_SH_MOBILE_MERAM=m
++CONFIG_FB_SIMPLE=y
++CONFIG_FB_SIS=m
++CONFIG_FB_SIS_300=y
++CONFIG_FB_SIS_315=y
++CONFIG_FB_SM501=m
++CONFIG_FB_SM712=m
++CONFIG_FB_SM750=m
++CONFIG_FB_SMSCUFX=m
++CONFIG_FB_SSD1307=m
++CONFIG_FB_SVGALIB=m
++CONFIG_FB_TFT=m
++CONFIG_FB_TFT_AGM1264K_FL=m
++CONFIG_FB_TFT_BD663474=m
++CONFIG_FB_TFT_FBTFT_DEVICE=m
++CONFIG_FB_TFT_HX8340BN=m
++CONFIG_FB_TFT_HX8347D=m
++CONFIG_FB_TFT_HX8353D=m
++CONFIG_FB_TFT_HX8357D=m
++CONFIG_FB_TFT_ILI9163=m
++CONFIG_FB_TFT_ILI9320=m
++CONFIG_FB_TFT_ILI9325=m
++CONFIG_FB_TFT_ILI9340=m
++CONFIG_FB_TFT_ILI9341=m
++CONFIG_FB_TFT_ILI9481=m
++CONFIG_FB_TFT_ILI9486=m
++CONFIG_FB_TFT_PCD8544=m
++CONFIG_FB_TFT_RA8875=m
++CONFIG_FB_TFT_S6D02A1=m
++CONFIG_FB_TFT_S6D1121=m
++CONFIG_FB_TFT_SSD1289=m
++CONFIG_FB_TFT_SSD1306=m
++CONFIG_FB_TFT_SSD1331=m
++CONFIG_FB_TFT_SSD1351=m
++CONFIG_FB_TFT_ST7735R=m
++CONFIG_FB_TFT_ST7789V=m
++CONFIG_FB_TFT_TINYLCD=m
++CONFIG_FB_TFT_TLS8204=m
++CONFIG_FB_TFT_UC1611=m
++CONFIG_FB_TFT_UC1701=m
++CONFIG_FB_TFT_UPD161704=m
++CONFIG_FB_TFT_WATTEROTT=m
++CONFIG_FB_TILEBLITTING=y
++CONFIG_FB_TMIO=m
++CONFIG_FB_TMIO_ACCELL=y
++CONFIG_FB_TRIDENT=m
++CONFIG_FB_UVESA=m
++CONFIG_FB_VALKYRIE=y
++CONFIG_FB_VESA=y
++CONFIG_FB_VGA16=m
++CONFIG_FB_VIA=m
++# CONFIG_FB_VIA_DIRECT_PROCFS is not set
++CONFIG_FB_VIA_X_COMPATIBILITY=y
++# CONFIG_FB_VIRTUAL is not set
++CONFIG_FB_VT8623=m
++CONFIG_FB_XGI=m
++CONFIG_FCOE=m
++CONFIG_FCOE_FNIC=m
++CONFIG_FEC=y
++# CONFIG_FENCE_TRACE is not set
++CONFIG_FHANDLE=y
++CONFIG_FIB_RULES=y
++CONFIG_FILE_LOCKING=y
++CONFIG_FIQ=y
++CONFIG_FIREWIRE_NET=m
++CONFIG_FIREWIRE_OHCI=m
++CONFIG_FIREWIRE_SBP2=m
++CONFIG_FIREWIRE_SERIAL=m
++CONFIG_FIRMWARE_EDID=y
++CONFIG_FIRMWARE_MEMMAP=y
++CONFIG_FIX_EARLYCON_MEM=y
++CONFIG_FLATMEM=y
++# CONFIG_FLATMEM_MANUAL is not set
++CONFIG_FLAT_NODE_MEM_MAP=y
++CONFIG_FM10K=m
++CONFIG_FM10K_VXLAN=y
++CONFIG_FMC_CHARDEV=m
++CONFIG_FMC_FAKEDEV=m
++CONFIG_FMC_TRIVIAL=m
++CONFIG_FMC_WRITE_EEPROM=m
++# CONFIG_FONT_10x18 is not set
++CONFIG_FONT_6x10=y
++# CONFIG_FONT_6x11 is not set
++# CONFIG_FONT_7x14 is not set
++CONFIG_FONT_8x16=y
++CONFIG_FONT_8x8=y
++CONFIG_FONT_ACORN_8x8=y
++# CONFIG_FONT_MINI_4x6 is not set
++# CONFIG_FONT_PEARL_8x8 is not set
++# CONFIG_FONT_SUN12x22 is not set
++# CONFIG_FONT_SUN8x16 is not set
++CONFIG_FONT_SUPPORT=y
++CONFIG_FORCEDETH=m
++CONFIG_FPGA=m
++CONFIG_FPGA_MGR_ZYNQ_FPGA=m
++CONFIG_FRAMEBUFFER_CONSOLE=y
++CONFIG_FRAMEBUFFER_CONSOLE_DETECT_PRIMARY=y
++CONFIG_FRAMEBUFFER_CONSOLE_ROTATION=y
++CONFIG_FRAME_POINTER=y
++CONFIG_FRAME_VECTOR=y
++CONFIG_FREEZER=y
++CONFIG_FRONTSWAP=y
++CONFIG_FSCACHE=m
++# CONFIG_FSCACHE_DEBUG is not set
++# CONFIG_FSCACHE_HISTOGRAM is not set
++# CONFIG_FSCACHE_OBJECT_LIST is not set
++CONFIG_FSCACHE_STATS=y
++CONFIG_FSL_BOOKE=y
++CONFIG_FSL_CORENET_CF=m
++CONFIG_FSL_DMA=m
++CONFIG_FSL_EDMA=m
++CONFIG_FSL_EMB_PERFMON=y
++CONFIG_FSL_EMB_PERF_EVENT=y
++CONFIG_FSL_EMB_PERF_EVENT_E500=y
++CONFIG_FSL_HV_MANAGER=m
++CONFIG_FSL_IFC=y
++CONFIG_FSL_LBC=y
++CONFIG_FSL_MC_BUS=m
++# CONFIG_FSL_PAMU is not set
++CONFIG_FSL_PCI=y
++CONFIG_FSL_PQ_MDIO=m
++CONFIG_FSL_RIO=y
++CONFIG_FSL_SOC=y
++CONFIG_FSL_SOC_BOOKE=y
++# CONFIG_FSL_ULI1575 is not set
++CONFIG_FSL_XGMAC_MDIO=y
++CONFIG_FSNOTIFY=y
++CONFIG_FS_DAX=y
++CONFIG_FS_ENET=m
++CONFIG_FS_ENET_HAS_FCC=y
++CONFIG_FS_ENET_HAS_SCC=y
++CONFIG_FS_ENET_MDIO_FCC=m
++CONFIG_FS_MBCACHE=y
++CONFIG_FS_POSIX_ACL=y
++CONFIG_FTGMAC100=m
++CONFIG_FTL=m
++CONFIG_FTMAC100=m
++CONFIG_FTRACE=y
++CONFIG_FTRACE_MCOUNT_RECORD=y
++# CONFIG_FTRACE_STARTUP_TEST is not set
++CONFIG_FTRACE_SYSCALLS=y
++# CONFIG_FTR_FIXUP_SELFTEST is not set
++CONFIG_FUJITSU_ES=m
++CONFIG_FUJITSU_LAPTOP=m
++# CONFIG_FUJITSU_LAPTOP_DEBUG is not set
++CONFIG_FUJITSU_TABLET=m
++CONFIG_FUNCTION_GRAPH_TRACER=y
++CONFIG_FUNCTION_PROFILER=y
++CONFIG_FUNCTION_TRACER=y
++CONFIG_FUSE_FS=y
++CONFIG_FUSION_CTL=m
++CONFIG_FUSION_FC=m
++CONFIG_FUSION_LAN=m
++CONFIG_FUSION_LOGGING=y
++CONFIG_FUSION_MAX_SGE=128
++CONFIG_FUSION_SAS=m
++CONFIG_FUSION_SPI=m
++CONFIG_FUTEX=y
++CONFIG_FWTTY_MAX_CARD_PORTS=32
++CONFIG_FWTTY_MAX_TOTAL_PORTS=64
++CONFIG_FW_LOADER=y
++CONFIG_FW_LOADER_USER_HELPER=y
++# CONFIG_FW_LOADER_USER_HELPER_FALLBACK is not set
++CONFIG_GACT_PROB=y
++CONFIG_GADGET_UAC1=y
++CONFIG_GAMEPORT_EMU10K1=m
++CONFIG_GAMEPORT_FM801=m
++CONFIG_GAMEPORT_L4=m
++CONFIG_GAMEPORT_NS558=m
++CONFIG_GARP=m
++CONFIG_GART_IOMMU=y
++# CONFIG_GCOV_KERNEL is not set
++CONFIG_GDB_SCRIPTS=y
++CONFIG_GELIC_NET=m
++CONFIG_GELIC_WIRELESS=y
++CONFIG_GENERIC_ADC_BATTERY=m
++CONFIG_GENERIC_ALLOCATOR=y
++CONFIG_GENERIC_ATOMIC64=y
++CONFIG_GENERIC_BUG=y
++CONFIG_GENERIC_BUG_RELATIVE_POINTERS=y
++CONFIG_GENERIC_CALIBRATE_DELAY=y
++CONFIG_GENERIC_CLOCKEVENTS=y
++CONFIG_GENERIC_CLOCKEVENTS_BROADCAST=y
++CONFIG_GENERIC_CLOCKEVENTS_MIN_ADJUST=y
++CONFIG_GENERIC_CMOS_UPDATE=y
++CONFIG_GENERIC_CPU=y
++CONFIG_GENERIC_CPU_AUTOPROBE=y
++# CONFIG_GENERIC_CPU_DEVICES is not set
++CONFIG_GENERIC_EARLY_IOREMAP=y
++CONFIG_GENERIC_FIND_FIRST_BIT=y
++CONFIG_GENERIC_HWEIGHT=y
++CONFIG_GENERIC_IDLE_POLL_SETUP=y
++CONFIG_GENERIC_IO=y
++CONFIG_GENERIC_IOMAP=y
++CONFIG_GENERIC_IRQ_CHIP=y
++CONFIG_GENERIC_IRQ_MIGRATION=y
++CONFIG_GENERIC_IRQ_PROBE=y
++CONFIG_GENERIC_IRQ_SHOW=y
++CONFIG_GENERIC_IRQ_SHOW_LEVEL=y
++CONFIG_GENERIC_ISA_DMA=y
++CONFIG_GENERIC_MSI_IRQ=y
++CONFIG_GENERIC_MSI_IRQ_DOMAIN=y
++CONFIG_GENERIC_NET_UTILS=y
++CONFIG_GENERIC_NVRAM=y
++CONFIG_GENERIC_PCI_IOMAP=y
++CONFIG_GENERIC_PENDING_IRQ=y
++CONFIG_GENERIC_PINCONF=y
++CONFIG_GENERIC_SCHED_CLOCK=y
++CONFIG_GENERIC_SMP_IDLE_THREAD=y
++CONFIG_GENERIC_STRNCPY_FROM_USER=y
++CONFIG_GENERIC_STRNLEN_USER=y
++CONFIG_GENERIC_TIME_VSYSCALL=y
++CONFIG_GENERIC_TIME_VSYSCALL_OLD=y
++CONFIG_GENERIC_TRACER=y
++CONFIG_GENEVE=m
++CONFIG_GENWQE=m
++CONFIG_GENWQE_PLATFORM_ERROR_RECOVERY=0
++CONFIG_GEOS=y
++# CONFIG_GE_FPGA is not set
++# CONFIG_GE_IMP3A is not set
++CONFIG_GFS2_FS=m
++CONFIG_GFS2_FS_LOCKING_DLM=y
++CONFIG_GIANFAR=m
++CONFIG_GIGASET_BASE=m
++# CONFIG_GIGASET_CAPI is not set
++# CONFIG_GIGASET_DEBUG is not set
++# CONFIG_GIGASET_DUMMYLL is not set
++CONFIG_GIGASET_I4L=y
++CONFIG_GIGASET_M101=m
++CONFIG_GIGASET_M105=m
++CONFIG_GIRBIL_DONGLE=m
++CONFIG_GLOB=y
++# CONFIG_GLOB_SELFTEST is not set
++# CONFIG_GOOGLE_FIRMWARE is not set
++CONFIG_GP2AP020A00F=m
++CONFIG_GPIOLIB=y
++CONFIG_GPIOLIB_IRQCHIP=y
++CONFIG_GPIO_104_IDIO_16=m
++CONFIG_GPIO_74X164=m
++CONFIG_GPIO_74XX_MMIO=m
++CONFIG_GPIO_ACPI=y
++CONFIG_GPIO_ADNP=m
++CONFIG_GPIO_ADP5520=m
++CONFIG_GPIO_ADP5588=m
++CONFIG_GPIO_ALTERA=m
++CONFIG_GPIO_AMD8111=m
++CONFIG_GPIO_AMDPT=m
++CONFIG_GPIO_ARIZONA=m
++CONFIG_GPIO_CRYSTAL_COVE=m
++CONFIG_GPIO_CS5535=m
++CONFIG_GPIO_DA9052=m
++CONFIG_GPIO_DA9055=m
++CONFIG_GPIO_DEVRES=y
++CONFIG_GPIO_DLN2=m
++CONFIG_GPIO_DWAPB=m
++# CONFIG_GPIO_EM is not set
++CONFIG_GPIO_F7188X=m
++CONFIG_GPIO_GRGPIO=m
++CONFIG_GPIO_ICH=m
++CONFIG_GPIO_INTEL_MID=y
++CONFIG_GPIO_INTEL_PMIC=y
++CONFIG_GPIO_IT87=m
++CONFIG_GPIO_JANZ_TTL=m
++CONFIG_GPIO_KEMPLD=m
++CONFIG_GPIO_LP3943=m
++CONFIG_GPIO_LYNXPOINT=y
++CONFIG_GPIO_MAX7300=m
++CONFIG_GPIO_MAX7301=m
++CONFIG_GPIO_MAX730X=m
++CONFIG_GPIO_MAX732X=m
++CONFIG_GPIO_MC33880=m
++CONFIG_GPIO_MCP23S08=m
++CONFIG_GPIO_ML_IOH=m
++CONFIG_GPIO_MPC8XXX=y
++CONFIG_GPIO_MSIC=y
++CONFIG_GPIO_MVEBU=y
++CONFIG_GPIO_MXC=y
++CONFIG_GPIO_OMAP=y
++CONFIG_GPIO_PALMAS=y
++CONFIG_GPIO_PCA953X=m
++CONFIG_GPIO_PCF857X=m
++CONFIG_GPIO_PCH=m
++CONFIG_GPIO_PL061=y
++CONFIG_GPIO_RC5T583=y
++CONFIG_GPIO_RCAR=m
++CONFIG_GPIO_RDC321X=m
++CONFIG_GPIO_SCH=m
++CONFIG_GPIO_SCH311X=m
++CONFIG_GPIO_SH_PFC=y
++CONFIG_GPIO_STMPE=y
++CONFIG_GPIO_SX150X=y
++CONFIG_GPIO_SYSCON=m
++CONFIG_GPIO_SYSFS=y
++CONFIG_GPIO_TC3589X=y
++CONFIG_GPIO_TIMBERDALE=y
++CONFIG_GPIO_TPS6586X=y
++CONFIG_GPIO_TPS65910=y
++CONFIG_GPIO_TPS65912=m
++CONFIG_GPIO_UCB1400=m
++CONFIG_GPIO_VF610=y
++CONFIG_GPIO_VIPERBOARD=m
++CONFIG_GPIO_VX855=m
++CONFIG_GPIO_WATCHDOG=m
++CONFIG_GPIO_WM831X=m
++CONFIG_GPIO_WM8350=m
++CONFIG_GPIO_WM8994=m
++CONFIG_GPIO_XGENE=y
++CONFIG_GPIO_XGENE_SB=m
++CONFIG_GPIO_XILINX=y
++CONFIG_GPIO_ZEVIO=y
++CONFIG_GPIO_ZX=y
++CONFIG_GPIO_ZYNQ=m
++CONFIG_GRACE_PERIOD=m
++CONFIG_GREENASIA_FF=y
++CONFIG_GS_FPGABOOT=m
++CONFIG_HAMACHI=m
++CONFIG_HAMRADIO=y
++CONFIG_HANDLE_DOMAIN_IRQ=y
++CONFIG_HANGCHECK_TIMER=m
++CONFIG_HAPPYMEAL=m
++CONFIG_HARDIRQS_SW_RESEND=y
++CONFIG_HARDLOCKUP_DETECTOR=y
++CONFIG_HAS_DMA=y
++CONFIG_HAS_IOMEM=y
++CONFIG_HAS_IOPORT_MAP=y
++CONFIG_HAVE_ACPI_APEI=y
++CONFIG_HAVE_ACPI_APEI_NMI=y
++CONFIG_HAVE_ALIGNED_STRUCT_PAGE=y
++CONFIG_HAVE_ARCH_AUDITSYSCALL=y
++CONFIG_HAVE_ARCH_HUGE_VMAP=y
++CONFIG_HAVE_ARCH_JUMP_LABEL=y
++CONFIG_HAVE_ARCH_KASAN=y
++CONFIG_HAVE_ARCH_KGDB=y
++CONFIG_HAVE_ARCH_KMEMCHECK=y
++CONFIG_HAVE_ARCH_PFN_VALID=y
++CONFIG_HAVE_ARCH_SECCOMP_FILTER=y
++CONFIG_HAVE_ARCH_SOFT_DIRTY=y
++CONFIG_HAVE_ARCH_TRACEHOOK=y
++CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE=y
++CONFIG_HAVE_ARM_ARCH_TIMER=y
++CONFIG_HAVE_ARM_SCU=y
++CONFIG_HAVE_ARM_TWD=y
++CONFIG_HAVE_ATOMIC_IOMAP=y
++CONFIG_HAVE_BPF_JIT=y
++CONFIG_HAVE_CC_STACKPROTECTOR=y
++CONFIG_HAVE_CLK=y
++CONFIG_HAVE_CLK_PREPARE=y
++CONFIG_HAVE_CMPXCHG_DOUBLE=y
++CONFIG_HAVE_CMPXCHG_LOCAL=y
++CONFIG_HAVE_CONTEXT_TRACKING=y
++CONFIG_HAVE_COPY_THREAD_TLS=y
++CONFIG_HAVE_C_RECORDMCOUNT=y
++CONFIG_HAVE_DEBUG_BUGVERBOSE=y
++CONFIG_HAVE_DEBUG_KMEMLEAK=y
++CONFIG_HAVE_DEBUG_STACKOVERFLOW=y
++CONFIG_HAVE_DMA_API_DEBUG=y
++CONFIG_HAVE_DMA_ATTRS=y
++CONFIG_HAVE_DMA_CONTIGUOUS=y
++CONFIG_HAVE_DYNAMIC_FTRACE=y
++CONFIG_HAVE_DYNAMIC_FTRACE_WITH_REGS=y
++CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS=y
++CONFIG_HAVE_FENTRY=y
++CONFIG_HAVE_FTRACE_MCOUNT_RECORD=y
++CONFIG_HAVE_FUNCTION_GRAPH_FP_TEST=y
++CONFIG_HAVE_FUNCTION_GRAPH_TRACER=y
++CONFIG_HAVE_FUNCTION_TRACER=y
++CONFIG_HAVE_FUTEX_CMPXCHG=y
++CONFIG_HAVE_GENERIC_RCU_GUP=y
++CONFIG_HAVE_HW_BREAKPOINT=y
++CONFIG_HAVE_IDE=y
++CONFIG_HAVE_IMX_ANATOP=y
++CONFIG_HAVE_IMX_GPC=y
++CONFIG_HAVE_IMX_MMDC=y
++CONFIG_HAVE_IMX_SRC=y
++CONFIG_HAVE_INTEL_TXT=y
++CONFIG_HAVE_IOREMAP_PROT=y
++CONFIG_HAVE_IRQ_EXIT_ON_IRQ_STACK=y
++CONFIG_HAVE_IRQ_TIME_ACCOUNTING=y
++CONFIG_HAVE_KERNEL_BZIP2=y
++CONFIG_HAVE_KERNEL_GZIP=y
++CONFIG_HAVE_KERNEL_LZ4=y
++CONFIG_HAVE_KERNEL_LZMA=y
++CONFIG_HAVE_KERNEL_LZO=y
++CONFIG_HAVE_KERNEL_XZ=y
++CONFIG_HAVE_KPROBES=y
++CONFIG_HAVE_KPROBES_ON_FTRACE=y
++CONFIG_HAVE_KRETPROBES=y
++CONFIG_HAVE_KVM=y
++CONFIG_HAVE_KVM_ARCH_TLB_FLUSH_ALL=y
++CONFIG_HAVE_KVM_CPU_RELAX_INTERCEPT=y
++CONFIG_HAVE_KVM_EVENTFD=y
++CONFIG_HAVE_KVM_IRQCHIP=y
++CONFIG_HAVE_KVM_IRQFD=y
++CONFIG_HAVE_KVM_IRQ_BYPASS=y
++CONFIG_HAVE_KVM_IRQ_ROUTING=y
++CONFIG_HAVE_KVM_MSI=y
++CONFIG_HAVE_LATENCYTOP_SUPPORT=y
++CONFIG_HAVE_LIVEPATCH=y
++CONFIG_HAVE_MARCH_Z10_FEATURES=y
++# CONFIG_HAVE_MARCH_Z13_FEATURES is not set
++CONFIG_HAVE_MARCH_Z196_FEATURES=y
++CONFIG_HAVE_MARCH_Z900_FEATURES=y
++CONFIG_HAVE_MARCH_Z990_FEATURES=y
++CONFIG_HAVE_MARCH_Z9_109_FEATURES=y
++CONFIG_HAVE_MARCH_ZEC12_FEATURES=y
++CONFIG_HAVE_MEMBLOCK=y
++CONFIG_HAVE_MEMBLOCK_NODE_MAP=y
++CONFIG_HAVE_MEMBLOCK_PHYS_MAP=y
++CONFIG_HAVE_MEMORYLESS_NODES=y
++CONFIG_HAVE_MEMORY_PRESENT=y
++CONFIG_HAVE_MIXED_BREAKPOINTS_REGS=y
++CONFIG_HAVE_MMIOTRACE_SUPPORT=y
++CONFIG_HAVE_MOD_ARCH_SPECIFIC=y
++CONFIG_HAVE_NET_DSA=y
++CONFIG_HAVE_OPROFILE=y
++CONFIG_HAVE_OPTPROBES=y
++CONFIG_HAVE_PATA_PLATFORM=y
++CONFIG_HAVE_PCSPKR_PLATFORM=y
++CONFIG_HAVE_PERF_EVENTS=y
++CONFIG_HAVE_PERF_EVENTS_NMI=y
++CONFIG_HAVE_PERF_REGS=y
++CONFIG_HAVE_PERF_USER_STACK_DUMP=y
++CONFIG_HAVE_PROC_CPU=y
++CONFIG_HAVE_RCU_TABLE_FREE=y
++CONFIG_HAVE_REGS_AND_STACK_ACCESS_API=y
++CONFIG_HAVE_S3C2410_I2C=y
++CONFIG_HAVE_S3C2410_WATCHDOG=y
++CONFIG_HAVE_S3C_RTC=y
++CONFIG_HAVE_SMP=y
++CONFIG_HAVE_SYSCALL_TRACEPOINTS=y
++CONFIG_HAVE_UID16=y
++CONFIG_HAVE_UNSTABLE_SCHED_CLOCK=y
++CONFIG_HAVE_USER_RETURN_NOTIFIER=y
++CONFIG_HAVE_VIRT_CPU_ACCOUNTING=y
++CONFIG_HAVE_VIRT_CPU_ACCOUNTING_GEN=y
++# CONFIG_HCALL_STATS is not set
++CONFIG_HDC100X=m
++CONFIG_HDLC=m
++CONFIG_HDLC_CISCO=m
++CONFIG_HDLC_FR=m
++CONFIG_HDLC_PPP=m
++CONFIG_HDLC_RAW=m
++CONFIG_HDLC_RAW_ETH=m
++CONFIG_HDLC_X25=m
++CONFIG_HDMI=y
++CONFIG_HDM_DIM2=m
++CONFIG_HDM_I2C=m
++CONFIG_HDM_USB=m
++CONFIG_HDQ_MASTER_OMAP=m
++# CONFIG_HEADERS_CHECK is not set
++CONFIG_HERMES=m
++CONFIG_HERMES_CACHE_FW_ON_INIT=y
++# CONFIG_HERMES_PRISM is not set
++# CONFIG_HFI1_DEBUG_SDMA_ORDER is not set
++CONFIG_HFI1_VERBS_31BIT_PSN=y
++CONFIG_HFSPLUS_FS_POSIX_ACL=y
++CONFIG_HI8435=m
++CONFIG_HIBERNATE_CALLBACKS=y
++CONFIG_HID=m
++CONFIG_HIDRAW=y
++CONFIG_HID_A4TECH=m
++CONFIG_HID_ACRUX=m
++CONFIG_HID_ACRUX_FF=y
++CONFIG_HID_ALPS=m
++CONFIG_HID_APPLE=m
++CONFIG_HID_APPLEIR=m
++CONFIG_HID_AUREAL=m
++CONFIG_HID_BATTERY_STRENGTH=y
++CONFIG_HID_BELKIN=m
++CONFIG_HID_BETOP_FF=m
++CONFIG_HID_CHERRY=m
++CONFIG_HID_CHICONY=m
++CONFIG_HID_CORSAIR=m
++CONFIG_HID_CP2112=m
++CONFIG_HID_CYPRESS=m
++CONFIG_HID_DRAGONRISE=m
++CONFIG_HID_ELECOM=m
++CONFIG_HID_ELO=m
++CONFIG_HID_EMS_FF=m
++CONFIG_HID_EZKEY=m
++CONFIG_HID_GEMBIRD=m
++CONFIG_HID_GENERIC=m
++CONFIG_HID_GFRM=m
++CONFIG_HID_GREENASIA=m
++CONFIG_HID_GT683R=m
++CONFIG_HID_GYRATION=m
++CONFIG_HID_HOLTEK=m
++CONFIG_HID_HYPERV_MOUSE=m
++CONFIG_HID_ICADE=m
++CONFIG_HID_KENSINGTON=m
++CONFIG_HID_KEYTOUCH=m
++CONFIG_HID_KYE=m
++CONFIG_HID_LCPOWER=m
++CONFIG_HID_LENOVO=m
++CONFIG_HID_LOGITECH=m
++CONFIG_HID_LOGITECH_DJ=m
++CONFIG_HID_LOGITECH_HIDPP=m
++CONFIG_HID_MAGICMOUSE=m
++CONFIG_HID_MICROSOFT=m
++CONFIG_HID_MONTEREY=m
++CONFIG_HID_MULTITOUCH=m
++CONFIG_HID_NTRIG=m
++CONFIG_HID_ORTEK=m
++CONFIG_HID_PANTHERLORD=m
++CONFIG_HID_PENMOUNT=m
++CONFIG_HID_PETALYNX=m
++CONFIG_HID_PICOLCD=m
++CONFIG_HID_PICOLCD_BACKLIGHT=y
++CONFIG_HID_PICOLCD_CIR=y
++CONFIG_HID_PICOLCD_FB=y
++CONFIG_HID_PICOLCD_LCD=y
++CONFIG_HID_PICOLCD_LEDS=y
++CONFIG_HID_PID=y
++CONFIG_HID_PLANTRONICS=m
++CONFIG_HID_PRIMAX=m
++CONFIG_HID_PRODIKEYS=m
++CONFIG_HID_RMI=m
++CONFIG_HID_ROCCAT=m
++CONFIG_HID_SAITEK=m
++CONFIG_HID_SAMSUNG=m
++CONFIG_HID_SENSOR_ACCEL_3D=m
++CONFIG_HID_SENSOR_ALS=m
++CONFIG_HID_SENSOR_CUSTOM_SENSOR=m
++CONFIG_HID_SENSOR_DEVICE_ROTATION=m
++CONFIG_HID_SENSOR_GYRO_3D=m
++CONFIG_HID_SENSOR_HUB=m
++CONFIG_HID_SENSOR_IIO_COMMON=m
++CONFIG_HID_SENSOR_IIO_TRIGGER=m
++CONFIG_HID_SENSOR_INCLINOMETER_3D=m
++CONFIG_HID_SENSOR_MAGNETOMETER_3D=m
++CONFIG_HID_SENSOR_PRESS=m
++CONFIG_HID_SENSOR_PROX=m
++CONFIG_HID_SMARTJOYPLUS=m
++CONFIG_HID_SONY=m
++CONFIG_HID_SPEEDLINK=m
++CONFIG_HID_STEELSERIES=m
++CONFIG_HID_SUNPLUS=m
++CONFIG_HID_THINGM=m
++CONFIG_HID_THRUSTMASTER=m
++CONFIG_HID_TIVO=m
++CONFIG_HID_TOPSEED=m
++CONFIG_HID_TWINHAN=m
++CONFIG_HID_UCLOGIC=m
++CONFIG_HID_WACOM=m
++CONFIG_HID_WALTOP=m
++CONFIG_HID_WIIMOTE=m
++CONFIG_HID_XINMO=m
++CONFIG_HID_ZEROPLUS=m
++CONFIG_HID_ZYDACRON=m
++CONFIG_HIGHMEM=y
++# CONFIG_HIGHMEM4G is not set
++CONFIG_HIGHMEM64G=y
++CONFIG_HIGHPTE=y
++CONFIG_HIGH_RES_TIMERS=y
++CONFIG_HIP04_ETH=m
++# CONFIG_HIPPI is not set
++CONFIG_HISAX_16_0=y
++CONFIG_HISAX_16_3=y
++CONFIG_HISAX_1TR6=y
++CONFIG_HISAX_ASUSCOM=y
++CONFIG_HISAX_AVM_A1=y
++CONFIG_HISAX_AVM_A1_CS=m
++CONFIG_HISAX_AVM_A1_PCMCIA=y
++CONFIG_HISAX_BKM_A4T=y
++# CONFIG_HISAX_DEBUG is not set
++CONFIG_HISAX_DIEHLDIVA=y
++CONFIG_HISAX_ELSA=y
++CONFIG_HISAX_ELSA_CS=m
++CONFIG_HISAX_ENTERNOW_PCI=y
++CONFIG_HISAX_EURO=y
++CONFIG_HISAX_FRITZPCI=y
++CONFIG_HISAX_FRITZ_PCIPNP=m
++CONFIG_HISAX_GAZEL=y
++CONFIG_HISAX_HFC4S8S=m
++CONFIG_HISAX_HFCS=y
++CONFIG_HISAX_HFCUSB=m
++CONFIG_HISAX_HFC_PCI=y
++CONFIG_HISAX_HFC_SX=y
++CONFIG_HISAX_HSTSAPHIR=y
++CONFIG_HISAX_ISURF=y
++CONFIG_HISAX_IX1MICROR2=y
++CONFIG_HISAX_MAX_CARDS=8
++CONFIG_HISAX_MIC=y
++CONFIG_HISAX_NETJET=y
++CONFIG_HISAX_NETJET_U=y
++CONFIG_HISAX_NI1=y
++CONFIG_HISAX_NICCY=y
++# CONFIG_HISAX_NO_KEYPAD is not set
++# CONFIG_HISAX_NO_LLC is not set
++# CONFIG_HISAX_NO_SENDCOMPLETE is not set
++CONFIG_HISAX_S0BOX=y
++CONFIG_HISAX_SCT_QUADRO=y
++CONFIG_HISAX_SEDLBAUER=y
++CONFIG_HISAX_SEDLBAUER_CS=m
++CONFIG_HISAX_SPORTSTER=y
++CONFIG_HISAX_ST5481=m
++CONFIG_HISAX_TELEINT=y
++CONFIG_HISAX_TELESPCI=y
++CONFIG_HISAX_TELES_CS=m
++CONFIG_HISAX_W6692=y
++CONFIG_HISI_THERMAL=m
++CONFIG_HIX5HD2_GMAC=m
++CONFIG_HMC6352=m
++CONFIG_HMC_DRV=m
++CONFIG_HNS=m
++CONFIG_HNS_DSAF=m
++CONFIG_HNS_ENET=m
++CONFIG_HNS_MDIO=m
++CONFIG_HOLTEK_FF=y
++CONFIG_HOSTAP=m
++CONFIG_HOSTAP_CS=m
++CONFIG_HOSTAP_FIRMWARE=y
++CONFIG_HOSTAP_FIRMWARE_NVRAM=y
++CONFIG_HOSTAP_PCI=m
++CONFIG_HOSTAP_PLX=m
++CONFIG_HOSTESS_SV11=m
++CONFIG_HOTPLUG_CPU=y
++CONFIG_HOTPLUG_PCI=y
++CONFIG_HOTPLUG_PCI_ACPI=y
++CONFIG_HOTPLUG_PCI_ACPI_IBM=m
++CONFIG_HOTPLUG_PCI_COMPAQ=m
++CONFIG_HOTPLUG_PCI_COMPAQ_NVRAM=y
++CONFIG_HOTPLUG_PCI_CPCI=y
++CONFIG_HOTPLUG_PCI_CPCI_GENERIC=m
++CONFIG_HOTPLUG_PCI_CPCI_ZT5550=m
++CONFIG_HOTPLUG_PCI_IBM=m
++CONFIG_HOTPLUG_PCI_RPA=m
++CONFIG_HOTPLUG_PCI_RPA_DLPAR=m
++CONFIG_HOTPLUG_PCI_S390=y
++CONFIG_HP100=m
++CONFIG_HPET_EMULATE_RTC=y
++CONFIG_HPET_MMAP=y
++CONFIG_HPET_MMAP_DEFAULT=y
++CONFIG_HPET_TIMER=y
++CONFIG_HPWDT_NMI_DECODING=y
++CONFIG_HP_ACCEL=m
++CONFIG_HP_WATCHDOG=m
++CONFIG_HP_WIRELESS=m
++CONFIG_HP_WMI=m
++CONFIG_HSA_AMD=m
++CONFIG_HSI_BOARDINFO=y
++CONFIG_HSI_CHAR=m
++CONFIG_HSU_DMA=m
++CONFIG_HSU_DMA_PCI=m
++CONFIG_HTC_EGPIO=y
++CONFIG_HTC_I2CPLD=y
++CONFIG_HTS221=m
++CONFIG_HTS221_I2C=m
++CONFIG_HTS221_SPI=m
++CONFIG_HTU21=m
++CONFIG_HT_IRQ=y
++CONFIG_HUGETLBFS=y
++CONFIG_HUGETLB_PAGE_SIZE_VARIABLE=y
++CONFIG_HVCS=m
++CONFIG_HVC_CONSOLE=y
++# CONFIG_HVC_DCC is not set
++CONFIG_HVC_DRIVER=y
++CONFIG_HVC_IRQ=y
++CONFIG_HVC_IUCV=y
++CONFIG_HVC_OLD_HVSI=y
++CONFIG_HVC_OPAL=y
++CONFIG_HVC_RTAS=y
++CONFIG_HVC_UDBG=y
++CONFIG_HVC_XEN=y
++CONFIG_HVC_XEN_FRONTEND=y
++CONFIG_HV_PERF_CTRS=y
++# CONFIG_HWMON_DEBUG_CHIP is not set
++CONFIG_HWMON_VID=m
++CONFIG_HWPOISON_INJECT=m
++CONFIG_HWSPINLOCK=m
++CONFIG_HWSPINLOCK_OMAP=m
++CONFIG_HWSPINLOCK_QCOM=m
++CONFIG_HW_CONSOLE=y
++CONFIG_HW_PERF_EVENTS=y
++CONFIG_HW_RANDOM=y
++CONFIG_HW_RANDOM_AMD=m
++CONFIG_HW_RANDOM_EXYNOS=m
++CONFIG_HW_RANDOM_GEODE=m
++CONFIG_HW_RANDOM_INTEL=m
++CONFIG_HW_RANDOM_IPROC_RNG200=m
++CONFIG_HW_RANDOM_MSM=m
++CONFIG_HW_RANDOM_OMAP=m
++CONFIG_HW_RANDOM_OMAP3_ROM=m
++CONFIG_HW_RANDOM_PASEMI=m
++CONFIG_HW_RANDOM_POWERNV=m
++CONFIG_HW_RANDOM_PSERIES=m
++CONFIG_HW_RANDOM_TPM=m
++CONFIG_HW_RANDOM_VIA=m
++CONFIG_HW_RANDOM_VIRTIO=m
++CONFIG_HW_RANDOM_XGENE=m
++CONFIG_HW_SCAN_OFFLOAD=y
++CONFIG_HYPERV=m
++CONFIG_HYPERVISOR_GUEST=y
++CONFIG_HYPERV_BALLOON=m
++CONFIG_HYPERV_KEYBOARD=m
++CONFIG_HYPERV_NET=m
++CONFIG_HYPERV_STORAGE=m
++CONFIG_HYPERV_UTILS=m
++CONFIG_HYSDN=m
++CONFIG_HYSDN_CAPI=y
++# CONFIG_HZ_200 is not set
++# CONFIG_HZ_300 is not set
++# CONFIG_HZ_500 is not set
++CONFIG_HZ_FIXED=0
++# CONFIG_HZ_PERIODIC is not set
++CONFIG_I2C_ALGOBIT=m
++CONFIG_I2C_ALGOPCA=m
++CONFIG_I2C_ALI1535=m
++CONFIG_I2C_ALI1563=m
++CONFIG_I2C_ALI15X3=m
++CONFIG_I2C_AMD756=m
++CONFIG_I2C_AMD756_S4882=m
++CONFIG_I2C_AMD8111=m
++CONFIG_I2C_ARB_GPIO_CHALLENGE=m
++CONFIG_I2C_AXXIA=m
++CONFIG_I2C_BCM2048=m
++CONFIG_I2C_BCM_IPROC=m
++CONFIG_I2C_BOARDINFO=y
++CONFIG_I2C_CADENCE=m
++CONFIG_I2C_CBUS_GPIO=m
++CONFIG_I2C_CHARDEV=y
++CONFIG_I2C_COMPAT=y
++CONFIG_I2C_CPM=m
++CONFIG_I2C_CROS_EC_TUNNEL=m
++# CONFIG_I2C_DEBUG_ALGO is not set
++# CONFIG_I2C_DEBUG_BUS is not set
++# CONFIG_I2C_DEBUG_CORE is not set
++CONFIG_I2C_DESIGNWARE_BAYTRAIL=y
++CONFIG_I2C_DESIGNWARE_CORE=m
++CONFIG_I2C_DESIGNWARE_PCI=m
++CONFIG_I2C_DESIGNWARE_PLATFORM=m
++CONFIG_I2C_DIOLAN_U2C=m
++CONFIG_I2C_DLN2=m
++CONFIG_I2C_EG20T=m
++CONFIG_I2C_EMEV2=m
++CONFIG_I2C_EXYNOS5=m
++CONFIG_I2C_GPIO=m
++CONFIG_I2C_HELPER_AUTO=y
++CONFIG_I2C_HID=m
++CONFIG_I2C_HIX5HD2=m
++CONFIG_I2C_HYDRA=m
++CONFIG_I2C_I801=m
++CONFIG_I2C_IMX=y
++CONFIG_I2C_ISCH=m
++CONFIG_I2C_ISMT=m
++CONFIG_I2C_KEMPLD=m
++CONFIG_I2C_MESON=m
++CONFIG_I2C_MPC=m
++CONFIG_I2C_MT65XX=m
++CONFIG_I2C_MUX=m
++CONFIG_I2C_MUX_GPIO=m
++CONFIG_I2C_MUX_PCA9541=m
++CONFIG_I2C_MUX_PCA954x=m
++CONFIG_I2C_MUX_PINCTRL=m
++CONFIG_I2C_MUX_REG=m
++CONFIG_I2C_MV64XXX=m
++CONFIG_I2C_NFORCE2=m
++CONFIG_I2C_NFORCE2_S4985=m
++CONFIG_I2C_NOMADIK=m
++CONFIG_I2C_OCORES=m
++CONFIG_I2C_OMAP=y
++CONFIG_I2C_OPAL=y
++CONFIG_I2C_PARPORT=m
++CONFIG_I2C_PARPORT_LIGHT=m
++CONFIG_I2C_PASEMI=m
++CONFIG_I2C_PCA_ISA=m
++CONFIG_I2C_PCA_PLATFORM=m
++CONFIG_I2C_PIIX4=m
++CONFIG_I2C_POWERMAC=y
++# CONFIG_I2C_PXA_PCI is not set
++CONFIG_I2C_QUP=m
++CONFIG_I2C_RCAR=m
++CONFIG_I2C_RIIC=m
++CONFIG_I2C_RK3X=m
++CONFIG_I2C_ROBOTFUZZ_OSIF=m
++CONFIG_I2C_S3C2410=y
++CONFIG_I2C_SCMI=m
++CONFIG_I2C_SH_MOBILE=m
++CONFIG_I2C_SI470X=m
++CONFIG_I2C_SI4713=m
++CONFIG_I2C_SIMTEC=m
++CONFIG_I2C_SIS5595=m
++CONFIG_I2C_SIS630=m
++CONFIG_I2C_SIS96X=m
++CONFIG_I2C_SLAVE_EEPROM=m
++CONFIG_I2C_SMBUS=m
++CONFIG_I2C_STUB=m
++CONFIG_I2C_TAOS_EVM=m
++CONFIG_I2C_TEGRA=m
++CONFIG_I2C_THUNDERX=m
++CONFIG_I2C_TINY_USB=m
++CONFIG_I2C_UNIPHIER=m
++CONFIG_I2C_UNIPHIER_F=m
++CONFIG_I2C_VERSATILE=m
++CONFIG_I2C_VIA=m
++CONFIG_I2C_VIAPRO=m
++CONFIG_I2C_VIPERBOARD=m
++CONFIG_I2C_XGENE_SLIMPRO=m
++CONFIG_I2C_XILINX=m
++CONFIG_I40E=m
++CONFIG_I40EVF=m
++CONFIG_I40E_DCB=y
++CONFIG_I40E_FCOE=y
++CONFIG_I40E_VXLAN=y
++CONFIG_I7300_IDLE=m
++CONFIG_I7300_IDLE_IOAT_CHANNEL=y
++CONFIG_I82092=m
++CONFIG_I82365=m
++CONFIG_I8253_LOCK=y
++CONFIG_I8K=m
++# CONFIG_IA32_AOUT is not set
++CONFIG_IA32_EMULATION=y
++CONFIG_IB700_WDT=m
++CONFIG_IBMASR=m
++CONFIG_IBMEBUS=y
++CONFIG_IBMVETH=m
++CONFIG_IBMVIO=y
++CONFIG_IBMVNIC=m
++CONFIG_IBM_ASM=m
++CONFIG_IBM_BSR=m
++# CONFIG_IBM_EMAC_EMAC4 is not set
++# CONFIG_IBM_EMAC_MAL_CLR_ICINTSTAT is not set
++# CONFIG_IBM_EMAC_MAL_COMMON_ERR is not set
++# CONFIG_IBM_EMAC_NO_FLOW_CTRL is not set
++# CONFIG_IBM_EMAC_RGMII is not set
++# CONFIG_IBM_EMAC_TAH is not set
++# CONFIG_IBM_EMAC_ZMII is not set
++CONFIG_IBM_PARTITION=y
++CONFIG_IBM_RTL=m
++CONFIG_ICPLUS_PHY=m
++CONFIG_ICS932S401=m
++CONFIG_ICST=y
++# CONFIG_IDE is not set
++CONFIG_IDEAPAD_LAPTOP=m
++CONFIG_IDLE_PAGE_TRACKING=y
++CONFIG_IE6XX_WDT=m
++CONFIG_IEEE802154_6LOWPAN=m
++CONFIG_IEEE802154_AT86RF230=m
++CONFIG_IEEE802154_AT86RF230_DEBUGFS=y
++CONFIG_IEEE802154_ATUSB=m
++CONFIG_IEEE802154_CC2520=m
++CONFIG_IEEE802154_DRIVERS=m
++CONFIG_IEEE802154_FAKELB=m
++CONFIG_IEEE802154_MRF24J40=m
++CONFIG_IEEE802154_NL802154_EXPERIMENTAL=y
++CONFIG_IEEE802154_SOCKET=m
++CONFIG_IFB=m
++CONFIG_IGB=m
++CONFIG_IGBVF=m
++CONFIG_IGB_DCA=y
++CONFIG_IGB_HWMON=y
++CONFIG_IIO_ADIS_LIB=m
++CONFIG_IIO_ADIS_LIB_BUFFER=y
++CONFIG_IIO_BUFFER=y
++CONFIG_IIO_BUFFER_CB=m
++CONFIG_IIO_CONSUMERS_PER_TRIGGER=2
++CONFIG_IIO_INTERRUPT_TRIGGER=m
++CONFIG_IIO_KFIFO_BUF=m
++CONFIG_IIO_MS_SENSORS_I2C=m
++CONFIG_IIO_PERIODIC_RTC_TRIGGER=m
++CONFIG_IIO_SIMPLE_DUMMY=m
++# CONFIG_IIO_SIMPLE_DUMMY_BUFFER is not set
++# CONFIG_IIO_SIMPLE_DUMMY_EVENTS is not set
++CONFIG_IIO_SSP_SENSORHUB=m
++CONFIG_IIO_SSP_SENSORS_COMMONS=m
++CONFIG_IIO_ST_ACCEL_3AXIS=m
++CONFIG_IIO_ST_ACCEL_I2C_3AXIS=m
++CONFIG_IIO_ST_ACCEL_SPI_3AXIS=m
++CONFIG_IIO_ST_GYRO_3AXIS=m
++CONFIG_IIO_ST_GYRO_I2C_3AXIS=m
++CONFIG_IIO_ST_GYRO_SPI_3AXIS=m
++CONFIG_IIO_ST_MAGN_3AXIS=m
++CONFIG_IIO_ST_MAGN_I2C_3AXIS=m
++CONFIG_IIO_ST_MAGN_SPI_3AXIS=m
++CONFIG_IIO_ST_PRESS=m
++CONFIG_IIO_ST_PRESS_I2C=m
++CONFIG_IIO_ST_PRESS_SPI=m
++CONFIG_IIO_ST_SENSORS_CORE=m
++CONFIG_IIO_ST_SENSORS_I2C=m
++CONFIG_IIO_ST_SENSORS_SPI=m
++CONFIG_IIO_SYSFS_TRIGGER=m
++CONFIG_IIO_TRIGGER=y
++CONFIG_IIO_TRIGGERED_BUFFER=m
++CONFIG_IIO_TRIGGERED_EVENT=m
++# CONFIG_IKCONFIG is not set
++CONFIG_IMA_APPRAISE=y
++CONFIG_IMA_DEFAULT_HASH="sha1"
++CONFIG_IMA_DEFAULT_HASH_SHA1=y
++# CONFIG_IMA_DEFAULT_HASH_SHA256 is not set
++# CONFIG_IMA_DEFAULT_HASH_SHA512 is not set
++# CONFIG_IMA_DEFAULT_HASH_WP512 is not set
++CONFIG_IMA_DEFAULT_TEMPLATE="ima-ng"
++# CONFIG_IMA_LOAD_X509 is not set
++CONFIG_IMA_LSM_RULES=y
++CONFIG_IMA_MEASURE_PCR_IDX=10
++CONFIG_IMA_MOK_KEYRING=y
++CONFIG_IMA_NG_TEMPLATE=y
++# CONFIG_IMA_SIG_TEMPLATE is not set
++# CONFIG_IMA_TEMPLATE is not set
++CONFIG_IMA_TRUSTED_KEYRING=y
++CONFIG_IMX2_WDT=m
++CONFIG_IMX_DMA=m
++CONFIG_IMX_IPUV3_CORE=m
++CONFIG_IMX_SDMA=m
++CONFIG_IMX_THERMAL=m
++CONFIG_IMX_WEIM=y
++CONFIG_INET=y
++CONFIG_INET6_AH=m
++CONFIG_INET6_ESP=m
++CONFIG_INET6_IPCOMP=m
++CONFIG_INET6_TUNNEL=m
++CONFIG_INET6_XFRM_MODE_BEET=m
++CONFIG_INET6_XFRM_MODE_ROUTEOPTIMIZATION=m
++CONFIG_INET6_XFRM_MODE_TRANSPORT=m
++CONFIG_INET6_XFRM_MODE_TUNNEL=m
++CONFIG_INET6_XFRM_TUNNEL=m
++CONFIG_INET_AH=m
++CONFIG_INET_DCCP_DIAG=m
++CONFIG_INET_DIAG=m
++CONFIG_INET_ESP=m
++CONFIG_INET_IPCOMP=m
++CONFIG_INET_LRO=y
++CONFIG_INET_TCP_DIAG=m
++CONFIG_INET_TUNNEL=m
++CONFIG_INET_UDP_DIAG=m
++CONFIG_INET_XFRM_MODE_BEET=m
++CONFIG_INET_XFRM_MODE_TRANSPORT=m
++CONFIG_INET_XFRM_MODE_TUNNEL=m
++CONFIG_INET_XFRM_TUNNEL=m
++CONFIG_INFINIBAND=m
++CONFIG_INFINIBAND_ADDR_TRANS=y
++CONFIG_INFINIBAND_AMSO1100=m
++# CONFIG_INFINIBAND_AMSO1100_DEBUG is not set
++CONFIG_INFINIBAND_CXGB3=m
++# CONFIG_INFINIBAND_CXGB3_DEBUG is not set
++CONFIG_INFINIBAND_CXGB4=m
++CONFIG_INFINIBAND_EHCA=m
++CONFIG_INFINIBAND_HFI1=m
++CONFIG_INFINIBAND_IPATH=m
++CONFIG_INFINIBAND_IPOIB=m
++CONFIG_INFINIBAND_IPOIB_CM=y
++# CONFIG_INFINIBAND_IPOIB_DEBUG is not set
++CONFIG_INFINIBAND_ISER=m
++CONFIG_INFINIBAND_ISERT=m
++CONFIG_INFINIBAND_MTHCA=m
++# CONFIG_INFINIBAND_MTHCA_DEBUG is not set
++# CONFIG_INFINIBAND_NES_DEBUG is not set
++CONFIG_INFINIBAND_ON_DEMAND_PAGING=y
++CONFIG_INFINIBAND_QIB_DCA=y
++CONFIG_INFINIBAND_SRP=m
++CONFIG_INFINIBAND_SRPT=m
++CONFIG_INFINIBAND_USER_ACCESS=m
++CONFIG_INFINIBAND_USER_MAD=m
++CONFIG_INFINIBAND_USER_MEM=y
++CONFIG_INFINIBAND_USNIC=m
++CONFIG_INFTL=m
++CONFIG_INITRAMFS_SOURCE=""
++CONFIG_INIT_ENV_ARG_LIMIT=32
++CONFIG_INLINE_READ_LOCK=y
++CONFIG_INLINE_READ_LOCK_BH=y
++CONFIG_INLINE_READ_LOCK_IRQ=y
++CONFIG_INLINE_READ_LOCK_IRQSAVE=y
++CONFIG_INLINE_READ_TRYLOCK=y
++CONFIG_INLINE_READ_UNLOCK=y
++CONFIG_INLINE_READ_UNLOCK_BH=y
++CONFIG_INLINE_READ_UNLOCK_IRQ=y
++CONFIG_INLINE_READ_UNLOCK_IRQRESTORE=y
++CONFIG_INLINE_SPIN_LOCK=y
++CONFIG_INLINE_SPIN_LOCK_BH=y
++CONFIG_INLINE_SPIN_LOCK_IRQ=y
++CONFIG_INLINE_SPIN_LOCK_IRQSAVE=y
++CONFIG_INLINE_SPIN_TRYLOCK=y
++CONFIG_INLINE_SPIN_TRYLOCK_BH=y
++CONFIG_INLINE_SPIN_UNLOCK_BH=y
++CONFIG_INLINE_SPIN_UNLOCK_IRQ=y
++CONFIG_INLINE_SPIN_UNLOCK_IRQRESTORE=y
++CONFIG_INLINE_WRITE_LOCK=y
++CONFIG_INLINE_WRITE_LOCK_BH=y
++CONFIG_INLINE_WRITE_LOCK_IRQ=y
++CONFIG_INLINE_WRITE_LOCK_IRQSAVE=y
++CONFIG_INLINE_WRITE_TRYLOCK=y
++CONFIG_INLINE_WRITE_UNLOCK=y
++CONFIG_INLINE_WRITE_UNLOCK_BH=y
++CONFIG_INLINE_WRITE_UNLOCK_IRQ=y
++CONFIG_INLINE_WRITE_UNLOCK_IRQRESTORE=y
++CONFIG_INOTIFY_USER=y
++CONFIG_INPUT_88PM80X_ONKEY=m
++CONFIG_INPUT_88PM860X_ONKEY=m
++CONFIG_INPUT_AD714X=m
++CONFIG_INPUT_AD714X_I2C=m
++CONFIG_INPUT_AD714X_SPI=m
++CONFIG_INPUT_ADBHID=y
++CONFIG_INPUT_ADXL34X=m
++CONFIG_INPUT_ADXL34X_I2C=m
++CONFIG_INPUT_ADXL34X_SPI=m
++CONFIG_INPUT_APANEL=m
++CONFIG_INPUT_APMPOWER=m
++CONFIG_INPUT_ARIZONA_HAPTICS=m
++CONFIG_INPUT_ATI_REMOTE2=m
++CONFIG_INPUT_ATLAS_BTNS=m
++CONFIG_INPUT_AXP20X_PEK=m
++CONFIG_INPUT_BMA150=m
++CONFIG_INPUT_CM109=m
++CONFIG_INPUT_CMA3000=m
++CONFIG_INPUT_CMA3000_I2C=m
++CONFIG_INPUT_DA9052_ONKEY=m
++CONFIG_INPUT_DA9055_ONKEY=m
++CONFIG_INPUT_DA9063_ONKEY=m
++CONFIG_INPUT_DRV260X_HAPTICS=m
++CONFIG_INPUT_DRV2665_HAPTICS=m
++CONFIG_INPUT_DRV2667_HAPTICS=m
++CONFIG_INPUT_E3X0_BUTTON=m
++CONFIG_INPUT_EVBUG=m
++CONFIG_INPUT_EVDEV=y
++CONFIG_INPUT_FF_MEMLESS=m
++CONFIG_INPUT_GP2A=m
++CONFIG_INPUT_GPIO_BEEPER=m
++CONFIG_INPUT_GPIO_ROTARY_ENCODER=m
++CONFIG_INPUT_GPIO_TILT_POLLED=m
++CONFIG_INPUT_IDEAPAD_SLIDEBAR=m
++CONFIG_INPUT_IMS_PCU=m
++CONFIG_INPUT_JOYDEV=m
++CONFIG_INPUT_JOYSTICK=y
++CONFIG_INPUT_KEYBOARD=y
++CONFIG_INPUT_KEYSPAN_REMOTE=m
++CONFIG_INPUT_KXTJ9=m
++# CONFIG_INPUT_KXTJ9_POLLED_MODE is not set
++CONFIG_INPUT_LEDS=m
++CONFIG_INPUT_MATRIXKMAP=m
++CONFIG_INPUT_MAX77693_HAPTIC=m
++CONFIG_INPUT_MAX8925_ONKEY=m
++CONFIG_INPUT_MAX8997_HAPTIC=m
++CONFIG_INPUT_MC13783_PWRBUTTON=m
++CONFIG_INPUT_MISC=y
++CONFIG_INPUT_MMA8450=m
++CONFIG_INPUT_MOUSE=y
++CONFIG_INPUT_MOUSEDEV=y
++CONFIG_INPUT_MOUSEDEV_PSAUX=y
++CONFIG_INPUT_MOUSEDEV_SCREEN_X=1024
++CONFIG_INPUT_MOUSEDEV_SCREEN_Y=768
++CONFIG_INPUT_MPU3050=m
++CONFIG_INPUT_PALMAS_PWRBUTTON=m
++CONFIG_INPUT_PCAP=m
++CONFIG_INPUT_PCF50633_PMU=m
++CONFIG_INPUT_PCF8574=m
++CONFIG_INPUT_PCSPKR=m
++CONFIG_INPUT_PM8941_PWRKEY=m
++CONFIG_INPUT_PM8XXX_VIBRATOR=m
++CONFIG_INPUT_PMIC8XXX_PWRKEY=m
++CONFIG_INPUT_POLLDEV=m
++CONFIG_INPUT_POWERMATE=m
++CONFIG_INPUT_PWM_BEEPER=m
++CONFIG_INPUT_REGULATOR_HAPTIC=m
++CONFIG_INPUT_RETU_PWRBUTTON=m
++CONFIG_INPUT_SOC_BUTTON_ARRAY=m
++CONFIG_INPUT_SPARSEKMAP=m
++CONFIG_INPUT_TABLET=y
++CONFIG_INPUT_TOUCHSCREEN=y
++CONFIG_INPUT_TPS65218_PWRBUTTON=m
++CONFIG_INPUT_TWL4030_PWRBUTTON=m
++CONFIG_INPUT_TWL4030_VIBRA=m
++CONFIG_INPUT_TWL6040_VIBRA=m
++CONFIG_INPUT_UINPUT=y
++CONFIG_INPUT_WISTRON_BTNS=m
++CONFIG_INPUT_WM831X_ON=m
++CONFIG_INPUT_XEN_KBDDEV_FRONTEND=m
++CONFIG_INPUT_YEALINK=m
++CONFIG_INSTRUCTION_DECODER=y
++CONFIG_INT340X_THERMAL=m
++CONFIG_INTEGRITY=y
++CONFIG_INTEGRITY_ASYMMETRIC_KEYS=y
++CONFIG_INTEGRITY_AUDIT=y
++CONFIG_INTEGRITY_SIGNATURE=y
++CONFIG_INTEL_GTT=y
++CONFIG_INTEL_HID_EVENT=m
++CONFIG_INTEL_IDLE=y
++CONFIG_INTEL_IDMA64=m
++CONFIG_INTEL_IOATDMA=m
++CONFIG_INTEL_IOMMU=y
++# CONFIG_INTEL_IOMMU_DEFAULT_ON is not set
++CONFIG_INTEL_IOMMU_FLOPPY_WA=y
++CONFIG_INTEL_IOMMU_SVM=y
++CONFIG_INTEL_IPS=m
++CONFIG_INTEL_MEI=m
++CONFIG_INTEL_MEI_ME=m
++CONFIG_INTEL_MEI_TXE=m
++CONFIG_INTEL_MENLOW=m
++CONFIG_INTEL_MFLD_THERMAL=m
++CONFIG_INTEL_MIC_BUS=m
++CONFIG_INTEL_MIC_CARD=m
++CONFIG_INTEL_MIC_HOST=m
++CONFIG_INTEL_MIC_X100_DMA=m
++CONFIG_INTEL_MID_POWER_BUTTON=m
++CONFIG_INTEL_MID_PTI=m
++CONFIG_INTEL_MID_WATCHDOG=m
++CONFIG_INTEL_OAKTRAIL=m
++CONFIG_INTEL_PCH_THERMAL=m
++CONFIG_INTEL_PMC_IPC=m
++CONFIG_INTEL_POWERCLAMP=m
++CONFIG_INTEL_PUNIT_IPC=m
++CONFIG_INTEL_RAPL=m
++CONFIG_INTEL_RST=m
++CONFIG_INTEL_SCU_IPC=y
++CONFIG_INTEL_SCU_IPC_UTIL=m
++CONFIG_INTEL_SCU_WATCHDOG=y
++CONFIG_INTEL_SMARTCONNECT=m
++CONFIG_INTEL_SOC_DTS_IOSF_CORE=m
++CONFIG_INTEL_SOC_DTS_THERMAL=m
++CONFIG_INTEL_SOC_PMIC=y
++CONFIG_INTEL_TELEMETRY=m
++CONFIG_INTEL_TH=m
++# CONFIG_INTEL_TH_DEBUG is not set
++CONFIG_INTEL_TH_GTH=m
++CONFIG_INTEL_TH_MSU=m
++CONFIG_INTEL_TH_PCI=m
++CONFIG_INTEL_TH_PTI=m
++CONFIG_INTEL_TH_STH=m
++CONFIG_INTEL_TXT=y
++CONFIG_INTEL_VBTN=m
++CONFIG_INTERVAL_TREE=y
++CONFIG_INTERVAL_TREE_TEST=m
++CONFIG_INV_MPU6050_IIO=m
++CONFIG_IOMMU_API=y
++# CONFIG_IOMMU_DEBUG is not set
++CONFIG_IOMMU_DMA=y
++CONFIG_IOMMU_HELPER=y
++CONFIG_IOMMU_IOVA=y
++CONFIG_IOMMU_IO_PGTABLE=y
++# CONFIG_IOMMU_IO_PGTABLE_LPAE_SELFTEST is not set
++# CONFIG_IOMMU_STRESS is not set
++CONFIG_IOMMU_SUPPORT=y
++CONFIG_IOSCHED_CFQ=y
++CONFIG_IOSCHED_DEADLINE=y
++CONFIG_IOSCHED_NOOP=y
++CONFIG_IOSF_MBI=y
++CONFIG_IOSF_MBI_DEBUG=y
++# CONFIG_IO_DELAY_0X80 is not set
++CONFIG_IO_DELAY_0XED=y
++# CONFIG_IO_DELAY_NONE is not set
++CONFIG_IO_DELAY_TYPE_0X80=0
++CONFIG_IO_DELAY_TYPE_0XED=1
++CONFIG_IO_DELAY_TYPE_NONE=3
++CONFIG_IO_DELAY_TYPE_UDELAY=2
++# CONFIG_IO_DELAY_UDELAY is not set
++CONFIG_IO_EVENT_IRQ=y
++CONFIG_IP6_NF_FILTER=m
++CONFIG_IP6_NF_IPTABLES=m
++CONFIG_IP6_NF_MANGLE=m
++CONFIG_IP6_NF_MATCH_AH=m
++CONFIG_IP6_NF_MATCH_EUI64=m
++CONFIG_IP6_NF_MATCH_FRAG=m
++CONFIG_IP6_NF_MATCH_HL=m
++CONFIG_IP6_NF_MATCH_IPV6HEADER=m
++CONFIG_IP6_NF_MATCH_MH=m
++CONFIG_IP6_NF_MATCH_OPTS=m
++CONFIG_IP6_NF_MATCH_RPFILTER=m
++CONFIG_IP6_NF_MATCH_RT=m
++CONFIG_IP6_NF_NAT=m
++CONFIG_IP6_NF_RAW=m
++CONFIG_IP6_NF_SECURITY=m
++CONFIG_IP6_NF_TARGET_HL=m
++CONFIG_IP6_NF_TARGET_MASQUERADE=m
++CONFIG_IP6_NF_TARGET_NPT=m
++CONFIG_IP6_NF_TARGET_REJECT=m
++CONFIG_IP6_NF_TARGET_SYNPROXY=m
++CONFIG_IPC_NS=y
++CONFIG_IPDDP=m
++CONFIG_IPDDP_ENCAP=y
++# CONFIG_IPIC is not set
++CONFIG_IPMI_DEVICE_INTERFACE=m
++# CONFIG_IPMI_PANIC_EVENT is not set
++CONFIG_IPMI_POWERNV=m
++CONFIG_IPMI_POWEROFF=m
++CONFIG_IPMI_SI=m
++CONFIG_IPMI_SSIF=m
++CONFIG_IPMI_WATCHDOG=m
++CONFIG_IPMMU_VMSA=y
++CONFIG_IPPP_FILTER=y
++CONFIG_IPQ_GCC_806X=m
++CONFIG_IPQ_LCC_806X=m
++CONFIG_IPV6=y
++CONFIG_IPV6_GRE=m
++CONFIG_IPV6_ILA=m
++CONFIG_IPV6_MIP6=m
++CONFIG_IPV6_MROUTE=y
++CONFIG_IPV6_MROUTE_MULTIPLE_TABLES=y
++CONFIG_IPV6_MULTIPLE_TABLES=y
++CONFIG_IPV6_NDISC_NODETYPE=y
++# CONFIG_IPV6_OPTIMISTIC_DAD is not set
++CONFIG_IPV6_PIMSM_V2=y
++CONFIG_IPV6_ROUTER_PREF=y
++CONFIG_IPV6_ROUTE_INFO=y
++CONFIG_IPV6_SIT=m
++CONFIG_IPV6_SIT_6RD=y
++CONFIG_IPV6_SUBTREES=y
++CONFIG_IPV6_TUNNEL=m
++CONFIG_IPV6_VTI=m
++CONFIG_IPVLAN=m
++CONFIG_IPW2100=m
++# CONFIG_IPW2100_DEBUG is not set
++CONFIG_IPW2100_MONITOR=y
++CONFIG_IPW2200=m
++# CONFIG_IPW2200_DEBUG is not set
++CONFIG_IPW2200_MONITOR=y
++CONFIG_IPW2200_PROMISCUOUS=y
++CONFIG_IPW2200_QOS=y
++CONFIG_IPW2200_RADIOTAP=y
++CONFIG_IPWIRELESS=m
++# CONFIG_IPX_INTERN is not set
++CONFIG_IP_ADVANCED_ROUTER=y
++CONFIG_IP_DCCP=m
++# CONFIG_IP_DCCP_CCID2_DEBUG is not set
++# CONFIG_IP_DCCP_CCID3_DEBUG is not set
++# CONFIG_IP_DCCP_DEBUG is not set
++CONFIG_IP_DCCP_TFRC_LIB=y
++CONFIG_IP_FIB_TRIE_STATS=y
++CONFIG_IP_MROUTE=y
++# CONFIG_IP_MROUTE_MULTIPLE_TABLES is not set
++CONFIG_IP_MULTICAST=y
++CONFIG_IP_MULTIPLE_TABLES=y
++CONFIG_IP_NF_ARPFILTER=m
++CONFIG_IP_NF_ARPTABLES=m
++CONFIG_IP_NF_ARP_MANGLE=m
++CONFIG_IP_NF_FILTER=m
++CONFIG_IP_NF_IPTABLES=m
++CONFIG_IP_NF_MANGLE=m
++CONFIG_IP_NF_MATCH_AH=m
++CONFIG_IP_NF_MATCH_ECN=m
++CONFIG_IP_NF_MATCH_RPFILTER=m
++CONFIG_IP_NF_MATCH_TTL=m
++CONFIG_IP_NF_NAT=m
++CONFIG_IP_NF_RAW=m
++CONFIG_IP_NF_SECURITY=m
++CONFIG_IP_NF_TARGET_CLUSTERIP=m
++CONFIG_IP_NF_TARGET_ECN=m
++CONFIG_IP_NF_TARGET_MASQUERADE=m
++CONFIG_IP_NF_TARGET_NETMAP=m
++CONFIG_IP_NF_TARGET_REDIRECT=m
++CONFIG_IP_NF_TARGET_REJECT=m
++CONFIG_IP_NF_TARGET_SYNPROXY=m
++CONFIG_IP_NF_TARGET_TTL=m
++CONFIG_IP_PIMSM_V1=y
++CONFIG_IP_PIMSM_V2=y
++# CONFIG_IP_PNP is not set
++CONFIG_IP_ROUTE_CLASSID=y
++CONFIG_IP_ROUTE_MULTIPATH=y
++CONFIG_IP_ROUTE_VERBOSE=y
++CONFIG_IP_SCTP=m
++CONFIG_IP_SET=m
++CONFIG_IP_SET_BITMAP_IP=m
++CONFIG_IP_SET_BITMAP_IPMAC=m
++CONFIG_IP_SET_BITMAP_PORT=m
++CONFIG_IP_SET_HASH_IP=m
++CONFIG_IP_SET_HASH_IPMARK=m
++CONFIG_IP_SET_HASH_IPPORT=m
++CONFIG_IP_SET_HASH_IPPORTIP=m
++CONFIG_IP_SET_HASH_IPPORTNET=m
++CONFIG_IP_SET_HASH_MAC=m
++CONFIG_IP_SET_HASH_NET=m
++CONFIG_IP_SET_HASH_NETIFACE=m
++CONFIG_IP_SET_HASH_NETNET=m
++CONFIG_IP_SET_HASH_NETPORT=m
++CONFIG_IP_SET_HASH_NETPORTNET=m
++CONFIG_IP_SET_LIST_SET=m
++CONFIG_IP_SET_MAX=256
++CONFIG_IP_VS=m
++# CONFIG_IP_VS_DEBUG is not set
++CONFIG_IP_VS_DH=m
++CONFIG_IP_VS_FO=m
++CONFIG_IP_VS_FTP=m
++CONFIG_IP_VS_IPV6=y
++CONFIG_IP_VS_LBLC=m
++CONFIG_IP_VS_LBLCR=m
++CONFIG_IP_VS_LC=m
++CONFIG_IP_VS_NFCT=y
++CONFIG_IP_VS_NQ=m
++CONFIG_IP_VS_OVF=m
++CONFIG_IP_VS_PE_SIP=m
++CONFIG_IP_VS_PROTO_AH=y
++CONFIG_IP_VS_PROTO_AH_ESP=y
++CONFIG_IP_VS_PROTO_ESP=y
++CONFIG_IP_VS_PROTO_SCTP=y
++CONFIG_IP_VS_PROTO_TCP=y
++CONFIG_IP_VS_PROTO_UDP=y
++CONFIG_IP_VS_RR=m
++CONFIG_IP_VS_SED=m
++CONFIG_IP_VS_SH=m
++CONFIG_IP_VS_SH_TAB_BITS=8
++CONFIG_IP_VS_TAB_BITS=12
++CONFIG_IP_VS_WLC=m
++CONFIG_IP_VS_WRR=m
++CONFIG_IRCOMM=m
++CONFIG_IRDA=m
++CONFIG_IRDA_CACHE_LAST_LSAP=y
++# CONFIG_IRDA_DEBUG is not set
++CONFIG_IRDA_FAST_RR=y
++CONFIG_IRDA_ULTRA=y
++CONFIG_IRLAN=m
++CONFIG_IRNET=m
++CONFIG_IRQCHIP=y
++# CONFIG_IRQSOFF_TRACER is not set
++CONFIG_IRQ_CROSSBAR=y
++CONFIG_IRQ_DOMAIN=y
++# CONFIG_IRQ_DOMAIN_DEBUG is not set
++CONFIG_IRQ_DOMAIN_HIERARCHY=y
++CONFIG_IRQ_FORCED_THREADING=y
++CONFIG_IRQ_REMAP=y
++# CONFIG_IRQ_TIME_ACCOUNTING is not set
++CONFIG_IRQ_WORK=y
++CONFIG_IRTTY_SIR=m
++CONFIG_IR_ENE=m
++CONFIG_IR_FINTEK=m
++CONFIG_IR_GPIO_CIR=m
++CONFIG_IR_HIX5HD2=m
++CONFIG_IR_IGORPLUGUSB=m
++CONFIG_IR_IGUANA=m
++CONFIG_IR_IMON=m
++CONFIG_IR_ITE_CIR=m
++CONFIG_IR_JVC_DECODER=m
++CONFIG_IR_LIRC_CODEC=m
++CONFIG_IR_MCEUSB=m
++CONFIG_IR_MCE_KBD_DECODER=m
++CONFIG_IR_MESON=m
++CONFIG_IR_NEC_DECODER=m
++CONFIG_IR_NUVOTON=m
++CONFIG_IR_RC5_DECODER=m
++CONFIG_IR_RC6_DECODER=m
++CONFIG_IR_REDRAT3=m
++CONFIG_IR_SANYO_DECODER=m
++CONFIG_IR_SHARP_DECODER=m
++CONFIG_IR_SONY_DECODER=m
++CONFIG_IR_STREAMZAP=m
++CONFIG_IR_TTUSBIR=m
++CONFIG_IR_WINBOND_CIR=m
++CONFIG_IR_XMP_DECODER=m
++CONFIG_ISAPNP=y
++CONFIG_ISA_DMA_API=y
++CONFIG_ISCSI_BOOT_SYSFS=m
++CONFIG_ISCSI_IBFT=m
++CONFIG_ISCSI_IBFT_FIND=y
++CONFIG_ISCSI_TARGET=m
++CONFIG_ISCSI_TCP=m
++CONFIG_ISDN=y
++CONFIG_ISDN_AUDIO=y
++CONFIG_ISDN_CAPI=m
++CONFIG_ISDN_CAPI_CAPI20=m
++CONFIG_ISDN_CAPI_CAPIDRV=m
++# CONFIG_ISDN_CAPI_CAPIDRV_VERBOSE is not set
++CONFIG_ISDN_CAPI_MIDDLEWARE=y
++CONFIG_ISDN_DIVAS=m
++CONFIG_ISDN_DIVAS_BRIPCI=y
++CONFIG_ISDN_DIVAS_DIVACAPI=m
++CONFIG_ISDN_DIVAS_MAINT=m
++CONFIG_ISDN_DIVAS_PRIPCI=y
++CONFIG_ISDN_DIVAS_USERIDI=m
++CONFIG_ISDN_DIVERSION=m
++CONFIG_ISDN_DRV_ACT2000=m
++CONFIG_ISDN_DRV_AVMB1_AVM_CS=m
++CONFIG_ISDN_DRV_AVMB1_B1ISA=m
++CONFIG_ISDN_DRV_AVMB1_B1PCI=m
++CONFIG_ISDN_DRV_AVMB1_B1PCIV4=y
++CONFIG_ISDN_DRV_AVMB1_B1PCMCIA=m
++CONFIG_ISDN_DRV_AVMB1_C4=m
++CONFIG_ISDN_DRV_AVMB1_T1ISA=m
++CONFIG_ISDN_DRV_AVMB1_T1PCI=m
++CONFIG_ISDN_DRV_GIGASET=m
++CONFIG_ISDN_DRV_HISAX=m
++CONFIG_ISDN_DRV_ICN=m
++CONFIG_ISDN_DRV_PCBIT=m
++CONFIG_ISDN_DRV_SC=m
++CONFIG_ISDN_HDLC=m
++CONFIG_ISDN_I4L=m
++CONFIG_ISDN_MPP=y
++CONFIG_ISDN_PPP=y
++CONFIG_ISDN_PPP_BSDCOMP=m
++CONFIG_ISDN_PPP_VJ=y
++CONFIG_ISDN_TTY_FAX=y
++CONFIG_ISDN_X25=y
++CONFIG_ISI=m
++CONFIG_ISL29003=m
++CONFIG_ISL29020=m
++CONFIG_ISL29125=m
++CONFIG_ISO9660_FS=m
++CONFIG_IT8712F_WDT=m
++CONFIG_IT87_WDT=m
++CONFIG_ITCO_VENDOR_SUPPORT=y
++CONFIG_ITCO_WDT=m
++CONFIG_ITG3200=m
++CONFIG_IUCV=y
++CONFIG_IWL3945=m
++CONFIG_IWL4965=m
++CONFIG_IWLDVM=m
++CONFIG_IWLEGACY=m
++# CONFIG_IWLEGACY_DEBUG is not set
++CONFIG_IWLEGACY_DEBUGFS=y
++CONFIG_IWLMVM=m
++CONFIG_IWLWIFI=m
++# CONFIG_IWLWIFI_BCAST_FILTERING is not set
++# CONFIG_IWLWIFI_DEBUG is not set
++CONFIG_IWLWIFI_DEBUGFS=y
++CONFIG_IWLWIFI_DEVICE_TRACING=y
++CONFIG_IWLWIFI_LEDS=y
++CONFIG_IWLWIFI_OPMODE_MODULAR=y
++# CONFIG_IWLWIFI_UAPSD is not set
++CONFIG_IWMMXT=y
++CONFIG_IXGB=m
++CONFIG_IXGBE=m
++CONFIG_IXGBEVF=m
++CONFIG_IXGBE_DCA=y
++CONFIG_IXGBE_DCB=y
++CONFIG_IXGBE_HWMON=y
++CONFIG_IXGBE_VXLAN=y
++CONFIG_JBD2=y
++# CONFIG_JBD2_DEBUG is not set
++CONFIG_JFFS2_CMODE_FAVOURLZO=y
++# CONFIG_JFFS2_CMODE_NONE is not set
++# CONFIG_JFFS2_CMODE_PRIORITY is not set
++# CONFIG_JFFS2_CMODE_SIZE is not set
++CONFIG_JFFS2_COMPRESSION_OPTIONS=y
++CONFIG_JFFS2_FS=m
++CONFIG_JFFS2_FS_DEBUG=0
++CONFIG_JFFS2_FS_POSIX_ACL=y
++CONFIG_JFFS2_FS_SECURITY=y
++# CONFIG_JFFS2_FS_WBUF_VERIFY is not set
++CONFIG_JFFS2_FS_WRITEBUFFER=y
++CONFIG_JFFS2_FS_XATTR=y
++CONFIG_JFFS2_LZO=y
++CONFIG_JFFS2_RTIME=y
++# CONFIG_JFFS2_RUBIN is not set
++# CONFIG_JFFS2_SUMMARY is not set
++CONFIG_JFFS2_ZLIB=y
++# CONFIG_JFS_DEBUG is not set
++CONFIG_JFS_POSIX_ACL=y
++CONFIG_JFS_SECURITY=y
++CONFIG_JFS_STATISTICS=y
++CONFIG_JOLIET=y
++CONFIG_JOYSTICK_A3D=m
++CONFIG_JOYSTICK_ADI=m
++CONFIG_JOYSTICK_ANALOG=m
++CONFIG_JOYSTICK_AS5011=m
++CONFIG_JOYSTICK_COBRA=m
++CONFIG_JOYSTICK_DB9=m
++CONFIG_JOYSTICK_GAMECON=m
++CONFIG_JOYSTICK_GF2K=m
++CONFIG_JOYSTICK_GRIP=m
++CONFIG_JOYSTICK_GRIP_MP=m
++CONFIG_JOYSTICK_GUILLEMOT=m
++CONFIG_JOYSTICK_IFORCE=m
++CONFIG_JOYSTICK_IFORCE_232=y
++CONFIG_JOYSTICK_IFORCE_USB=y
++CONFIG_JOYSTICK_INTERACT=m
++CONFIG_JOYSTICK_JOYDUMP=m
++CONFIG_JOYSTICK_MAGELLAN=m
++CONFIG_JOYSTICK_SIDEWINDER=m
++CONFIG_JOYSTICK_SPACEBALL=m
++CONFIG_JOYSTICK_SPACEORB=m
++CONFIG_JOYSTICK_STINGER=m
++CONFIG_JOYSTICK_TMDC=m
++CONFIG_JOYSTICK_TURBOGRAFX=m
++CONFIG_JOYSTICK_TWIDJOY=m
++CONFIG_JOYSTICK_WALKERA0701=m
++CONFIG_JOYSTICK_WARRIOR=m
++CONFIG_JOYSTICK_XPAD=m
++CONFIG_JOYSTICK_XPAD_FF=y
++CONFIG_JOYSTICK_XPAD_LEDS=y
++CONFIG_JOYSTICK_ZHENHUA=m
++CONFIG_JSA1212=m
++CONFIG_K3_DMA=m
++CONFIG_KAISER=y
++CONFIG_KALLSYMS=y
++CONFIG_KALLSYMS_ALL=y
++# CONFIG_KASAN is not set
++CONFIG_KDB_CONTINUE_CATASTROPHIC=0
++CONFIG_KDB_DEFAULT_ENABLE=0x1
++CONFIG_KDB_KEYBOARD=y
++CONFIG_KEMPLD_WDT=m
++# CONFIG_KERNEL_BZIP2 is not set
++# CONFIG_KERNEL_LZ4 is not set
++# CONFIG_KERNEL_LZMA is not set
++# CONFIG_KERNEL_LZO is not set
++CONFIG_KERNEL_MODE_NEON=y
++CONFIG_KERNEL_NOBP=y
++CONFIG_KERNFS=y
++CONFIG_KEXEC=y
++CONFIG_KEXEC_BZIMAGE_VERIFY_SIG=y
++CONFIG_KEXEC_CORE=y
++CONFIG_KEXEC_FILE=y
++CONFIG_KEXEC_JUMP=y
++CONFIG_KEXEC_VERIFY_SIG=y
++CONFIG_KEYBOARD_ADP5520=m
++CONFIG_KEYBOARD_ADP5588=m
++CONFIG_KEYBOARD_ADP5589=m
++CONFIG_KEYBOARD_ATKBD=y
++CONFIG_KEYBOARD_BCM=m
++CONFIG_KEYBOARD_CAP11XX=m
++CONFIG_KEYBOARD_CROS_EC=m
++CONFIG_KEYBOARD_GPIO=m
++CONFIG_KEYBOARD_GPIO_POLLED=m
++CONFIG_KEYBOARD_IMX=m
++CONFIG_KEYBOARD_LKKBD=m
++CONFIG_KEYBOARD_LM8323=m
++CONFIG_KEYBOARD_LM8333=m
++CONFIG_KEYBOARD_MATRIX=m
++CONFIG_KEYBOARD_MAX7359=m
++CONFIG_KEYBOARD_MCS=m
++CONFIG_KEYBOARD_MPR121=m
++CONFIG_KEYBOARD_NEWTON=m
++CONFIG_KEYBOARD_NVEC=m
++CONFIG_KEYBOARD_OMAP4=m
++CONFIG_KEYBOARD_OPENCORES=m
++CONFIG_KEYBOARD_PMIC8XXX=m
++CONFIG_KEYBOARD_QT1070=m
++CONFIG_KEYBOARD_QT2160=m
++CONFIG_KEYBOARD_SAMSUNG=m
++CONFIG_KEYBOARD_SH_KEYSC=m
++CONFIG_KEYBOARD_SNVS_PWRKEY=m
++CONFIG_KEYBOARD_STMPE=m
++CONFIG_KEYBOARD_STOWAWAY=m
++CONFIG_KEYBOARD_SUNKBD=m
++CONFIG_KEYBOARD_TC3589X=m
++CONFIG_KEYBOARD_TCA6416=m
++CONFIG_KEYBOARD_TCA8418=m
++CONFIG_KEYBOARD_TEGRA=m
++CONFIG_KEYBOARD_TWL4030=m
++CONFIG_KEYBOARD_XTKBD=m
++CONFIG_KEYS=y
++CONFIG_KEYS_COMPAT=y
++CONFIG_KGDB=y
++CONFIG_KGDB_KDB=y
++CONFIG_KGDB_LOW_LEVEL_TRAP=y
++CONFIG_KGDB_SERIAL_CONSOLE=y
++# CONFIG_KGDB_TESTS is not set
++CONFIG_KINGSUN_DONGLE=m
++CONFIG_KMX61=m
++CONFIG_KPROBES=y
++CONFIG_KPROBES_ON_FTRACE=y
++# CONFIG_KPROBES_SANITY_TEST is not set
++CONFIG_KPROBE_EVENT=y
++CONFIG_KRETPROBES=y
++CONFIG_KS0108=m
++CONFIG_KS0108_DELAY=2
++CONFIG_KS0108_PORT=0x378
++CONFIG_KS8842=m
++CONFIG_KS8851=m
++CONFIG_KS8851_MLL=m
++CONFIG_KS959_DONGLE=m
++CONFIG_KSDAZZLE_DONGLE=m
++# CONFIG_KSI8560 is not set
++CONFIG_KSM=y
++CONFIG_KSZ884X_PCI=m
++CONFIG_KUSER_HELPERS=y
++CONFIG_KVM_AMD=m
++CONFIG_KVM_APIC_ARCHITECTURE=y
++CONFIG_KVM_ARM_HOST=y
++CONFIG_KVM_ARM_VGIC_V3=y
++CONFIG_KVM_ASYNC_PF=y
++CONFIG_KVM_ASYNC_PF_SYNC=y
++CONFIG_KVM_BOOK3S_64=m
++CONFIG_KVM_BOOK3S_64_HANDLER=y
++CONFIG_KVM_BOOK3S_64_HV=m
++CONFIG_KVM_BOOK3S_64_PR=m
++CONFIG_KVM_BOOK3S_HANDLER=y
++# CONFIG_KVM_BOOK3S_HV_EXIT_TIMING is not set
++CONFIG_KVM_BOOK3S_HV_POSSIBLE=y
++CONFIG_KVM_BOOK3S_PR_POSSIBLE=y
++CONFIG_KVM_BOOKE_HV=y
++CONFIG_KVM_COMPAT=y
++CONFIG_KVM_DEBUG_FS=y
++CONFIG_KVM_DEVICE_ASSIGNMENT=y
++CONFIG_KVM_E500MC=y
++# CONFIG_KVM_EXIT_TIMING is not set
++CONFIG_KVM_GENERIC_DIRTYLOG_READ_PROTECT=y
++CONFIG_KVM_GUEST=y
++CONFIG_KVM_INTEL=m
++CONFIG_KVM_MMIO=y
++# CONFIG_KVM_MMU_AUDIT is not set
++CONFIG_KVM_MPIC=y
++# CONFIG_KVM_S390_UCONTROL is not set
++CONFIG_KVM_VFIO=y
++CONFIG_KVM_XICS=y
++CONFIG_KXCJK1013=m
++CONFIG_KXSD9=m
++CONFIG_L2TP=m
++CONFIG_L2TP_DEBUGFS=m
++CONFIG_L2TP_ETH=m
++CONFIG_L2TP_IP=m
++CONFIG_L2TP_V3=y
++CONFIG_LANCE=m
++CONFIG_LANMEDIA=m
++CONFIG_LAPBETHER=m
++# CONFIG_LATENCYTOP is not set
++CONFIG_LATTICE_ECP3_CONFIG=m
++CONFIG_LBDAF=y
++CONFIG_LCD_AMS369FG06=m
++CONFIG_LCD_CLASS_DEVICE=m
++CONFIG_LCD_HX8357=m
++CONFIG_LCD_ILI922X=m
++CONFIG_LCD_ILI9320=m
++CONFIG_LCD_L4F00242T03=m
++CONFIG_LCD_LD9040=m
++CONFIG_LCD_LMS283GF05=m
++CONFIG_LCD_LMS501KF03=m
++CONFIG_LCD_LTV350QV=m
++CONFIG_LCD_PLATFORM=m
++CONFIG_LCD_S6E63M0=m
++CONFIG_LCD_TDO24M=m
++CONFIG_LCD_VGG2432A4=m
++CONFIG_LCS=m
++# CONFIG_LDM_DEBUG is not set
++CONFIG_LEDS_88PM860X=m
++CONFIG_LEDS_AAT1290=m
++CONFIG_LEDS_ADP5520=m
++CONFIG_LEDS_ASIC3=y
++CONFIG_LEDS_BCM6328=m
++CONFIG_LEDS_BCM6358=m
++CONFIG_LEDS_BD2802=m
++CONFIG_LEDS_BLINKM=m
++CONFIG_LEDS_CLASS=y
++CONFIG_LEDS_CLASS_FLASH=m
++CONFIG_LEDS_CLEVO_MAIL=m
++CONFIG_LEDS_DA903X=m
++CONFIG_LEDS_DA9052=m
++CONFIG_LEDS_DAC124S085=m
++CONFIG_LEDS_DELL_NETBOOKS=m
++CONFIG_LEDS_GPIO=m
++CONFIG_LEDS_INTEL_SS4200=m
++CONFIG_LEDS_KTD2692=m
++CONFIG_LEDS_LM3530=m
++CONFIG_LEDS_LM3533=m
++CONFIG_LEDS_LM355x=m
++CONFIG_LEDS_LM3642=m
++CONFIG_LEDS_LP3944=m
++CONFIG_LEDS_LP5521=m
++CONFIG_LEDS_LP5523=m
++CONFIG_LEDS_LP5562=m
++CONFIG_LEDS_LP55XX_COMMON=m
++CONFIG_LEDS_LP8501=m
++CONFIG_LEDS_LP8788=m
++CONFIG_LEDS_LP8860=m
++CONFIG_LEDS_LT3593=m
++CONFIG_LEDS_MAX77693=m
++CONFIG_LEDS_MAX8997=m
++CONFIG_LEDS_MC13783=m
++CONFIG_LEDS_MENF21BMC=m
++CONFIG_LEDS_NET48XX=m
++CONFIG_LEDS_NS2=m
++CONFIG_LEDS_OT200=m
++CONFIG_LEDS_PCA9532=m
++CONFIG_LEDS_PCA9532_GPIO=y
++CONFIG_LEDS_PCA955X=m
++CONFIG_LEDS_PCA963X=m
++CONFIG_LEDS_POWERNV=m
++CONFIG_LEDS_PWM=m
++CONFIG_LEDS_REGULATOR=m
++CONFIG_LEDS_SYSCON=y
++CONFIG_LEDS_TCA6507=m
++CONFIG_LEDS_TLC591XX=m
++CONFIG_LEDS_TRIGGERS=y
++CONFIG_LEDS_TRIGGER_BACKLIGHT=m
++CONFIG_LEDS_TRIGGER_CAMERA=m
++CONFIG_LEDS_TRIGGER_CPU=y
++CONFIG_LEDS_TRIGGER_DEFAULT_ON=m
++CONFIG_LEDS_TRIGGER_GPIO=m
++CONFIG_LEDS_TRIGGER_HEARTBEAT=m
++CONFIG_LEDS_TRIGGER_ONESHOT=m
++CONFIG_LEDS_TRIGGER_TIMER=m
++CONFIG_LEDS_TRIGGER_TRANSIENT=m
++CONFIG_LEDS_WM831X_STATUS=m
++CONFIG_LEDS_WM8350=m
++CONFIG_LEDS_WRAP=m
++CONFIG_LEGACY_PTYS=y
++CONFIG_LEGACY_PTY_COUNT=0
++CONFIG_LEGACY_VSYSCALL_EMULATE=y
++# CONFIG_LEGACY_VSYSCALL_NATIVE is not set
++# CONFIG_LEGACY_VSYSCALL_NONE is not set
++# CONFIG_LGUEST is not set
++# CONFIG_LGUEST_GUEST is not set
++CONFIG_LIB80211=m
++CONFIG_LIB80211_CRYPT_CCMP=m
++CONFIG_LIB80211_CRYPT_TKIP=m
++CONFIG_LIB80211_CRYPT_WEP=m
++# CONFIG_LIB80211_DEBUG is not set
++CONFIG_LIBCRC32C=m
++CONFIG_LIBERTAS=m
++CONFIG_LIBERTAS_CS=m
++# CONFIG_LIBERTAS_DEBUG is not set
++CONFIG_LIBERTAS_MESH=y
++CONFIG_LIBERTAS_SDIO=m
++CONFIG_LIBERTAS_SPI=m
++CONFIG_LIBERTAS_THINFIRM=m
++# CONFIG_LIBERTAS_THINFIRM_DEBUG is not set
++CONFIG_LIBERTAS_THINFIRM_USB=m
++CONFIG_LIBERTAS_USB=m
++CONFIG_LIBFC=m
++CONFIG_LIBFCOE=m
++CONFIG_LIBFDT=y
++CONFIG_LIBIPW=m
++# CONFIG_LIBIPW_DEBUG is not set
++CONFIG_LIDAR_LITE_V2=m
++CONFIG_LIQUIDIO=m
++CONFIG_LIRC=m
++CONFIG_LIRC_BT829=m
++CONFIG_LIRC_IMON=m
++CONFIG_LIRC_PARALLEL=m
++CONFIG_LIRC_SASEM=m
++CONFIG_LIRC_SERIAL=m
++CONFIG_LIRC_SERIAL_TRANSMITTER=y
++CONFIG_LIRC_SIR=m
++CONFIG_LIRC_STAGING=y
++CONFIG_LIRC_ZILOG=m
++CONFIG_LIS3L02DQ=m
++CONFIG_LITELINK_DONGLE=m
++CONFIG_LIVEPATCH=y
++# CONFIG_LKDTM is not set
++CONFIG_LLC=m
++CONFIG_LOCALVERSION=""
++# CONFIG_LOCALVERSION_AUTO is not set
++CONFIG_LOCKD=m
++CONFIG_LOCKDEP_SUPPORT=y
++CONFIG_LOCKD_V4=y
++CONFIG_LOCKUP_DETECTOR=y
++CONFIG_LOCK_SPIN_ON_OWNER=y
++# CONFIG_LOCK_STAT is not set
++CONFIG_LOCK_TORTURE_TEST=m
++# CONFIG_LOGFS is not set
++CONFIG_LOGIG940_FF=y
++CONFIG_LOGIRUMBLEPAD2_FF=y
++CONFIG_LOGITECH_FF=y
++CONFIG_LOGIWHEELS_FF=y
++# CONFIG_LOGO is not set
++CONFIG_LOG_CPU_MAX_BUF_SHIFT=12
++CONFIG_LOOPBACK_TARGET=m
++CONFIG_LOWMEM_CAM_NUM=3
++CONFIG_LOWMEM_SIZE=0x30000000
++CONFIG_LP8788_ADC=m
++# CONFIG_LP_CONSOLE is not set
++CONFIG_LRU_CACHE=m
++CONFIG_LSI_ET1011C_PHY=m
++CONFIG_LSM_MMAP_MIN_ADDR=0
++CONFIG_LTE_GDM724X=m
++CONFIG_LTPC=m
++CONFIG_LTR501=m
++# CONFIG_LUSTRE_FS is not set
++CONFIG_LWTUNNEL=y
++CONFIG_LXT_PHY=m
++CONFIG_LZ4HC_COMPRESS=m
++CONFIG_LZ4_COMPRESS=m
++CONFIG_LZ4_DECOMPRESS=y
++CONFIG_LZO_COMPRESS=y
++CONFIG_LZO_DECOMPRESS=y
++# CONFIG_M486 is not set
++# CONFIG_M586 is not set
++# CONFIG_M586MMX is not set
++# CONFIG_M586TSC is not set
++CONFIG_M62332=m
++CONFIG_M686=y
++CONFIG_MA600_DONGLE=m
++CONFIG_MAC80211=m
++CONFIG_MAC80211_DEBUGFS=y
++# CONFIG_MAC80211_DEBUG_MENU is not set
++CONFIG_MAC80211_HAS_RC=y
++CONFIG_MAC80211_HWSIM=m
++CONFIG_MAC80211_LEDS=y
++CONFIG_MAC80211_MESH=y
++CONFIG_MAC80211_MESSAGE_TRACING=y
++CONFIG_MAC80211_RC_DEFAULT="minstrel_ht"
++CONFIG_MAC80211_RC_DEFAULT_MINSTREL=y
++CONFIG_MAC80211_RC_MINSTREL=y
++CONFIG_MAC80211_RC_MINSTREL_HT=y
++CONFIG_MAC80211_RC_MINSTREL_VHT=y
++CONFIG_MAC80211_STA_HASH_MAX_SIZE=0
++CONFIG_MAC802154=m
++CONFIG_MACB=m
++CONFIG_MACE=m
++# CONFIG_MACE_AAUI_PORT is not set
++CONFIG_MACHZ_WDT=m
++CONFIG_MACH_ARMADA_370=y
++CONFIG_MACH_ARMADA_375=y
++CONFIG_MACH_ARMADA_38X=y
++CONFIG_MACH_ARMADA_39X=y
++CONFIG_MACH_ARMADA_XP=y
++CONFIG_MACH_BERLIN_BG2=y
++CONFIG_MACH_BERLIN_BG2CD=y
++CONFIG_MACH_BERLIN_BG2Q=y
++CONFIG_MACH_DOVE=y
++CONFIG_MACH_MESON6=y
++CONFIG_MACH_MESON8=y
++CONFIG_MACH_MESON8B=y
++CONFIG_MACH_MT6589=y
++CONFIG_MACH_MT6592=y
++CONFIG_MACH_MT8127=y
++CONFIG_MACH_MT8135=y
++CONFIG_MACH_MVEBU_ANY=y
++CONFIG_MACH_MVEBU_V7=y
++# CONFIG_MACH_NOKIA_RX51 is not set
++# CONFIG_MACH_OMAP3517EVM is not set
++CONFIG_MACH_OMAP3_PANDORA=y
++CONFIG_MACH_OMAP_GENERIC=y
++CONFIG_MACH_OMAP_LDP=y
++CONFIG_MACINTOSH_DRIVERS=y
++CONFIG_MACVLAN=m
++CONFIG_MACVTAP=m
++CONFIG_MAC_EMUMOUSEBTN=m
++CONFIG_MAC_FLOPPY=m
++CONFIG_MAG3110=m
++CONFIG_MAGIC_SYSRQ=y
++CONFIG_MAILBOX_TEST=m
++CONFIG_MANTIS_CORE=m
++# CONFIG_MARCH_Z10 is not set
++# CONFIG_MARCH_Z10_TUNE is not set
++# CONFIG_MARCH_Z13 is not set
++# CONFIG_MARCH_Z13_TUNE is not set
++# CONFIG_MARCH_Z196 is not set
++# CONFIG_MARCH_Z196_TUNE is not set
++# CONFIG_MARCH_Z900 is not set
++# CONFIG_MARCH_Z900_TUNE is not set
++# CONFIG_MARCH_Z990 is not set
++# CONFIG_MARCH_Z990_TUNE is not set
++# CONFIG_MARCH_Z9_109 is not set
++# CONFIG_MARCH_Z9_109_TUNE is not set
++CONFIG_MARCH_ZEC12=y
++CONFIG_MARCH_ZEC12_TUNE=y
++CONFIG_MARVELL_PHY=m
++# CONFIG_MATH_EMULATION_FULL is not set
++CONFIG_MATH_EMULATION_HW_UNIMPLEMENTED=y
++# CONFIG_MATOM is not set
++CONFIG_MAX1027=m
++CONFIG_MAX1363=m
++CONFIG_MAX517=m
++CONFIG_MAX5821=m
++CONFIG_MAX8925_POWER=m
++# CONFIG_MAXSMP is not set
++CONFIG_MAX_RAW_DEVS=256
++CONFIG_MCB_PCI=m
++# CONFIG_MCORE2 is not set
++CONFIG_MCP2120_DONGLE=m
++CONFIG_MCP320X=m
++CONFIG_MCP3422=m
++CONFIG_MCP4531=m
++CONFIG_MCP4725=m
++CONFIG_MCP4922=m
++CONFIG_MCPM=y
++CONFIG_MCPM_QUAD_CLUSTER=y
++# CONFIG_MCRUSOE is not set
++CONFIG_MCS_FIR=m
++# CONFIG_MCYRIXIII is not set
++CONFIG_MD=y
++CONFIG_MDA_CONSOLE=m
++CONFIG_MDIO=m
++CONFIG_MDIO_BCM_IPROC=m
++CONFIG_MDIO_BCM_UNIMAC=m
++CONFIG_MDIO_BITBANG=m
++CONFIG_MDIO_BUS_MUX=m
++CONFIG_MDIO_BUS_MUX_GPIO=m
++CONFIG_MDIO_BUS_MUX_MMIOREG=m
++CONFIG_MDIO_CAVIUM=m
++CONFIG_MDIO_GPIO=m
++CONFIG_MDIO_OCTEON=m
++CONFIG_MDIO_THUNDER=m
++CONFIG_MDIO_XGENE=m
++CONFIG_MD_AUTODETECT=y
++CONFIG_MD_CLUSTER=m
++CONFIG_MD_FAULTY=m
++CONFIG_MD_LINEAR=m
++CONFIG_MD_RAID0=m
++CONFIG_MD_RAID1=m
++CONFIG_MD_RAID10=m
++CONFIG_MD_RAID456=m
++CONFIG_MEDIATEK_WATCHDOG=m
++CONFIG_MEDIA_ALTERA_CI=m
++CONFIG_MEDIA_ANALOG_TV_SUPPORT=y
++CONFIG_MEDIA_ATTACH=y
++CONFIG_MEDIA_CAMERA_SUPPORT=y
++CONFIG_MEDIA_COMMON_OPTIONS=y
++CONFIG_MEDIA_CONTROLLER=y
++CONFIG_MEDIA_DIGITAL_TV_SUPPORT=y
++CONFIG_MEDIA_PCI_SUPPORT=y
++CONFIG_MEDIA_RADIO_SUPPORT=y
++CONFIG_MEDIA_RC_SUPPORT=y
++CONFIG_MEDIA_SDR_SUPPORT=y
++CONFIG_MEDIA_SUBDRV_AUTOSELECT=y
++CONFIG_MEDIA_TUNER=m
++CONFIG_MEDIA_TUNER_E4000=m
++CONFIG_MEDIA_TUNER_FC0011=m
++CONFIG_MEDIA_TUNER_FC0012=m
++CONFIG_MEDIA_TUNER_FC0013=m
++CONFIG_MEDIA_TUNER_FC2580=m
++CONFIG_MEDIA_TUNER_IT913X=m
++CONFIG_MEDIA_TUNER_M88RS6000T=m
++CONFIG_MEDIA_TUNER_MAX2165=m
++CONFIG_MEDIA_TUNER_MC44S803=m
++CONFIG_MEDIA_TUNER_MSI001=m
++CONFIG_MEDIA_TUNER_MT2060=m
++CONFIG_MEDIA_TUNER_MT2063=m
++CONFIG_MEDIA_TUNER_MT20XX=m
++CONFIG_MEDIA_TUNER_MT2131=m
++CONFIG_MEDIA_TUNER_MT2266=m
++CONFIG_MEDIA_TUNER_MXL301RF=m
++CONFIG_MEDIA_TUNER_MXL5005S=m
++CONFIG_MEDIA_TUNER_MXL5007T=m
++CONFIG_MEDIA_TUNER_QM1D1C0042=m
++CONFIG_MEDIA_TUNER_QT1010=m
++CONFIG_MEDIA_TUNER_R820T=m
++CONFIG_MEDIA_TUNER_SI2157=m
++CONFIG_MEDIA_TUNER_SIMPLE=m
++CONFIG_MEDIA_TUNER_TDA18212=m
++CONFIG_MEDIA_TUNER_TDA18218=m
++CONFIG_MEDIA_TUNER_TDA18271=m
++CONFIG_MEDIA_TUNER_TDA827X=m
++CONFIG_MEDIA_TUNER_TDA8290=m
++CONFIG_MEDIA_TUNER_TDA9887=m
++CONFIG_MEDIA_TUNER_TEA5761=m
++CONFIG_MEDIA_TUNER_TEA5767=m
++CONFIG_MEDIA_TUNER_TUA9001=m
++CONFIG_MEDIA_TUNER_XC2028=m
++CONFIG_MEDIA_TUNER_XC4000=m
++CONFIG_MEDIA_TUNER_XC5000=m
++CONFIG_MEDIA_USB_SUPPORT=y
++# CONFIG_MEFFICEON is not set
++CONFIG_MEGARAID_MAILBOX=m
++CONFIG_MEGARAID_MM=m
++# CONFIG_MELAN is not set
++CONFIG_MEMBARRIER=y
++CONFIG_MEMCG=y
++CONFIG_MEMCG_KMEM=y
++CONFIG_MEMCG_SWAP=y
++# CONFIG_MEMCG_SWAP_ENABLED is not set
++CONFIG_MEMORY_BALLOON=y
++CONFIG_MEMORY_FAILURE=y
++CONFIG_MEMORY_HOTPLUG=y
++CONFIG_MEMORY_HOTPLUG_SPARSE=y
++CONFIG_MEMORY_HOTREMOVE=y
++CONFIG_MEMORY_ISOLATION=y
++CONFIG_MEMORY_NOTIFIER_ERROR_INJECT=m
++# CONFIG_MEMSTICK_DEBUG is not set
++CONFIG_MEMSTICK_JMICRON_38X=m
++CONFIG_MEMSTICK_R592=m
++CONFIG_MEMSTICK_REALTEK_PCI=m
++CONFIG_MEMSTICK_REALTEK_USB=m
++CONFIG_MEMSTICK_TIFM_MS=m
++# CONFIG_MEMSTICK_UNSAFE_RESUME is not set
++CONFIG_MEMTEST=y
++CONFIG_MEM_SOFT_DIRTY=y
++CONFIG_MENF21BMC_WATCHDOG=m
++CONFIG_MEN_A21_WDT=m
++CONFIG_MEN_Z188_ADC=m
++CONFIG_MESON6_TIMER=y
++CONFIG_MESON_WATCHDOG=m
++CONFIG_MESSAGE_LOGLEVEL_DEFAULT=4
++CONFIG_MFD_88PM800=m
++CONFIG_MFD_88PM805=m
++CONFIG_MFD_88PM860X=y
++CONFIG_MFD_AAT2870_CORE=y
++CONFIG_MFD_ARIZONA=y
++CONFIG_MFD_ARIZONA_I2C=m
++CONFIG_MFD_ARIZONA_SPI=m
++CONFIG_MFD_AS3711=y
++CONFIG_MFD_AS3722=y
++CONFIG_MFD_ASIC3=y
++CONFIG_MFD_ATMEL_FLEXCOM=m
++CONFIG_MFD_ATMEL_HLCDC=m
++CONFIG_MFD_AXP20X=y
++CONFIG_MFD_BCM590XX=m
++CONFIG_MFD_CROS_EC=m
++CONFIG_MFD_CROS_EC_I2C=m
++CONFIG_MFD_CROS_EC_SPI=m
++CONFIG_MFD_CS5535=m
++CONFIG_MFD_DA9052_I2C=y
++CONFIG_MFD_DA9052_SPI=y
++CONFIG_MFD_DA9055=y
++CONFIG_MFD_DA9062=m
++CONFIG_MFD_DA9063=y
++CONFIG_MFD_DA9150=m
++CONFIG_MFD_DLN2=m
++CONFIG_MFD_HI6421_PMIC=m
++CONFIG_MFD_INTEL_LPSS=m
++CONFIG_MFD_INTEL_LPSS_ACPI=m
++CONFIG_MFD_INTEL_LPSS_PCI=m
++CONFIG_MFD_INTEL_MSIC=y
++CONFIG_MFD_INTEL_QUARK_I2C_GPIO=m
++CONFIG_MFD_LM3533=m
++CONFIG_MFD_LP3943=m
++CONFIG_MFD_LP8788=y
++CONFIG_MFD_MAX14577=y
++CONFIG_MFD_MAX77686=y
++CONFIG_MFD_MAX77693=y
++CONFIG_MFD_MAX77843=y
++CONFIG_MFD_MAX8907=m
++CONFIG_MFD_MAX8925=y
++CONFIG_MFD_MAX8997=y
++CONFIG_MFD_MAX8998=y
++CONFIG_MFD_MC13XXX=m
++CONFIG_MFD_MC13XXX_I2C=m
++CONFIG_MFD_MC13XXX_SPI=m
++CONFIG_MFD_MENF21BMC=m
++CONFIG_MFD_NVEC=m
++CONFIG_MFD_OMAP_USB_HOST=y
++CONFIG_MFD_PALMAS=y
++CONFIG_MFD_PCF50633=m
++CONFIG_MFD_PM8921_CORE=m
++CONFIG_MFD_PM8XXX=m
++CONFIG_MFD_QCOM_RPM=m
++CONFIG_MFD_RC5T583=y
++CONFIG_MFD_RETU=m
++CONFIG_MFD_RK808=m
++CONFIG_MFD_RN5T618=m
++CONFIG_MFD_RT5033=m
++CONFIG_MFD_RTSX_USB=m
++CONFIG_MFD_SEC_CORE=y
++CONFIG_MFD_SI476X_CORE=m
++CONFIG_MFD_SKY81452=m
++CONFIG_MFD_SM501_GPIO=y
++CONFIG_MFD_SMSC=y
++CONFIG_MFD_SPMI_PMIC=m
++CONFIG_MFD_STMPE=y
++CONFIG_MFD_T7L66XB=y
++CONFIG_MFD_TC3589X=y
++CONFIG_MFD_TC6387XB=y
++CONFIG_MFD_TC6393XB=y
++CONFIG_MFD_TIMBERDALE=m
++CONFIG_MFD_TPS65090=y
++CONFIG_MFD_TPS65217=y
++CONFIG_MFD_TPS65218=m
++CONFIG_MFD_TPS6586X=y
++CONFIG_MFD_TPS65910=y
++CONFIG_MFD_TPS65912=y
++CONFIG_MFD_TPS65912_I2C=y
++CONFIG_MFD_TPS65912_SPI=y
++CONFIG_MFD_TPS80031=y
++CONFIG_MFD_TWL4030_AUDIO=y
++CONFIG_MFD_VEXPRESS_SYSREG=y
++CONFIG_MFD_VIPERBOARD=m
++CONFIG_MFD_WL1273_CORE=m
++CONFIG_MFD_WM5102=y
++CONFIG_MFD_WM5110=y
++CONFIG_MFD_WM831X=y
++CONFIG_MFD_WM831X_I2C=y
++CONFIG_MFD_WM831X_SPI=y
++CONFIG_MFD_WM8350=y
++CONFIG_MFD_WM8350_I2C=y
++CONFIG_MFD_WM8400=y
++CONFIG_MFD_WM8994=m
++CONFIG_MFD_WM8997=y
++CONFIG_MFD_WM8998=y
++# CONFIG_MGEODEGX1 is not set
++# CONFIG_MGEODE_LX is not set
++CONFIG_MG_DISK=m
++CONFIG_MG_DISK_RES=0
++CONFIG_MICREL_KS8995MA=m
++CONFIG_MICREL_PHY=m
++CONFIG_MICROCHIP_PHY=m
++CONFIG_MICROCODE=y
++CONFIG_MICROCODE_AMD=y
++CONFIG_MICROCODE_INTEL=y
++CONFIG_MICROCODE_OLD_INTERFACE=y
++CONFIG_MIC_COSM=m
++CONFIG_MIGHT_HAVE_CACHE_L2X0=y
++CONFIG_MIGHT_HAVE_PCI=y
++CONFIG_MIGRATION=y
++# CONFIG_MINIX_FS_NATIVE_ENDIAN is not set
++CONFIG_MISC_FILESYSTEMS=y
++CONFIG_MISDN=m
++CONFIG_MISDN_AVMFRITZ=m
++CONFIG_MISDN_DSP=m
++CONFIG_MISDN_HFCMULTI=m
++CONFIG_MISDN_HFCPCI=m
++CONFIG_MISDN_HFCUSB=m
++CONFIG_MISDN_INFINEON=m
++CONFIG_MISDN_IPAC=m
++CONFIG_MISDN_ISAR=m
++CONFIG_MISDN_L1OIP=m
++CONFIG_MISDN_NETJET=m
++CONFIG_MISDN_SPEEDFAX=m
++CONFIG_MISDN_W6692=m
++CONFIG_MIXCOMWD=m
++# CONFIG_MK6 is not set
++# CONFIG_MK7 is not set
++# CONFIG_MK8 is not set
++CONFIG_MKISS=m
++CONFIG_MLX4_CORE=m
++CONFIG_MLX4_DEBUG=y
++CONFIG_MLX4_EN=m
++CONFIG_MLX4_EN_DCB=y
++CONFIG_MLX4_EN_VXLAN=y
++CONFIG_MLX4_INFINIBAND=m
++CONFIG_MLX5_CORE=m
++CONFIG_MLX5_CORE_EN=y
++CONFIG_MLX5_INFINIBAND=m
++CONFIG_MLX90614=m
++CONFIG_MLXSW_CORE=m
++CONFIG_MLXSW_PCI=m
++CONFIG_MMA8452=m
++CONFIG_MMA9551=m
++CONFIG_MMA9551_CORE=m
++CONFIG_MMA9553=m
++CONFIG_MMC35240=m
++CONFIG_MMC_ARMMMCI=y
++CONFIG_MMC_BLOCK_BOUNCE=y
++CONFIG_MMC_BLOCK_MINORS=8
++CONFIG_MMC_CB710=m
++# CONFIG_MMC_DEBUG is not set
++CONFIG_MMC_DW=m
++CONFIG_MMC_DW_EXYNOS=m
++CONFIG_MMC_DW_K3=m
++CONFIG_MMC_DW_PCI=m
++CONFIG_MMC_DW_PLTFM=m
++CONFIG_MMC_DW_ROCKCHIP=m
++CONFIG_MMC_MTK=m
++CONFIG_MMC_MVSDIO=m
++CONFIG_MMC_MXC=m
++CONFIG_MMC_OMAP=m
++CONFIG_MMC_OMAP_HS=y
++CONFIG_MMC_QCOM_DML=m
++CONFIG_MMC_REALTEK_PCI=m
++CONFIG_MMC_REALTEK_USB=m
++CONFIG_MMC_RICOH_MMC=y
++CONFIG_MMC_SDHCI_ACPI=m
++CONFIG_MMC_SDHCI_BIG_ENDIAN_32BIT_BYTE_SWAPPER=y
++CONFIG_MMC_SDHCI_DOVE=m
++CONFIG_MMC_SDHCI_ESDHC_IMX=y
++CONFIG_MMC_SDHCI_F_SDH30=m
++CONFIG_MMC_SDHCI_IO_ACCESSORS=y
++CONFIG_MMC_SDHCI_IPROC=m
++CONFIG_MMC_SDHCI_MSM=m
++CONFIG_MMC_SDHCI_OF_ARASAN=m
++CONFIG_MMC_SDHCI_OF_AT91=m
++CONFIG_MMC_SDHCI_OF_ESDHC=m
++CONFIG_MMC_SDHCI_OF_HLWD=m
++CONFIG_MMC_SDHCI_PCI=m
++CONFIG_MMC_SDHCI_PXAV3=m
++CONFIG_MMC_SDHCI_S3C=m
++CONFIG_MMC_SDHCI_S3C_DMA=y
++CONFIG_MMC_SDHCI_TEGRA=m
++CONFIG_MMC_SDHI=m
++CONFIG_MMC_SDRICOH_CS=m
++CONFIG_MMC_SH_MMCIF=m
++CONFIG_MMC_SPI=m
++# CONFIG_MMC_TEST is not set
++CONFIG_MMC_TIFM_SD=m
++CONFIG_MMC_TMIO=m
++CONFIG_MMC_TMIO_CORE=m
++CONFIG_MMC_TOSHIBA_PCI=m
++CONFIG_MMC_USDHI6ROL0=m
++CONFIG_MMC_USHC=m
++CONFIG_MMC_VIA_SDMMC=m
++CONFIG_MMC_VUB300=m
++CONFIG_MMC_WBSD=m
++CONFIG_MMIOTRACE=y
++# CONFIG_MMIOTRACE_TEST is not set
++CONFIG_MMU=y
++CONFIG_MMU_NOTIFIER=y
++CONFIG_MODIFY_LDT_SYSCALL=y
++CONFIG_MODULES=y
++CONFIG_MODULES_TREE_LOOKUP=y
++CONFIG_MODULES_USE_ELF_REL=y
++CONFIG_MODULES_USE_ELF_RELA=y
++# CONFIG_MODULE_COMPRESS is not set
++# CONFIG_MODULE_FORCE_LOAD is not set
++# CONFIG_MODULE_FORCE_UNLOAD is not set
++CONFIG_MODULE_SIG=y
++CONFIG_MODULE_SIG_ALL=y
++# CONFIG_MODULE_SIG_FORCE is not set
++CONFIG_MODULE_SIG_HASH="sha512"
++CONFIG_MODULE_SIG_KEY="certs/signing_key.pem"
++# CONFIG_MODULE_SIG_SHA1 is not set
++# CONFIG_MODULE_SIG_SHA224 is not set
++# CONFIG_MODULE_SIG_SHA256 is not set
++# CONFIG_MODULE_SIG_SHA384 is not set
++CONFIG_MODULE_SIG_SHA512=y
++CONFIG_MODULE_SIG_UEFI=y
++CONFIG_MODULE_SRCVERSION_ALL=y
++CONFIG_MODULE_UNLOAD=y
++CONFIG_MODVERSIONS=y
++CONFIG_MONREADER=m
++CONFIG_MONWRITER=m
++CONFIG_MOST=m
++CONFIG_MOSTCORE=m
++CONFIG_MOUSE_APPLETOUCH=m
++CONFIG_MOUSE_BCM5974=m
++CONFIG_MOUSE_CYAPA=m
++CONFIG_MOUSE_ELAN_I2C=m
++CONFIG_MOUSE_ELAN_I2C_I2C=y
++CONFIG_MOUSE_ELAN_I2C_SMBUS=y
++CONFIG_MOUSE_GPIO=m
++# CONFIG_MOUSE_INPORT is not set
++CONFIG_MOUSE_LOGIBM=m
++CONFIG_MOUSE_PC110PAD=m
++CONFIG_MOUSE_PS2=m
++CONFIG_MOUSE_PS2_ALPS=y
++CONFIG_MOUSE_PS2_CYPRESS=y
++CONFIG_MOUSE_PS2_ELANTECH=y
++CONFIG_MOUSE_PS2_FOCALTECH=y
++CONFIG_MOUSE_PS2_LIFEBOOK=y
++CONFIG_MOUSE_PS2_LOGIPS2PP=y
++CONFIG_MOUSE_PS2_SENTELIC=y
++CONFIG_MOUSE_PS2_SYNAPTICS=y
++CONFIG_MOUSE_PS2_TOUCHKIT=y
++CONFIG_MOUSE_PS2_TRACKPOINT=y
++CONFIG_MOUSE_PS2_VMMOUSE=y
++CONFIG_MOUSE_SERIAL=m
++CONFIG_MOUSE_SYNAPTICS_I2C=m
++CONFIG_MOUSE_SYNAPTICS_USB=m
++CONFIG_MOUSE_VSXXXAA=m
++CONFIG_MOVABLE_NODE=y
++CONFIG_MOXA_INTELLIO=m
++CONFIG_MOXA_SMARTIO=m
++# CONFIG_MPC8536_DS is not set
++# CONFIG_MPC8540_ADS is not set
++# CONFIG_MPC8560_ADS is not set
++# CONFIG_MPC85xx_CDS is not set
++# CONFIG_MPC85xx_DS is not set
++# CONFIG_MPC85xx_MDS is not set
++# CONFIG_MPC85xx_RDB is not set
++# CONFIG_MPENTIUM4 is not set
++# CONFIG_MPENTIUMII is not set
++# CONFIG_MPENTIUMIII is not set
++# CONFIG_MPENTIUMM is not set
++CONFIG_MPIC=y
++CONFIG_MPIC_BROKEN_REGREAD=y
++# CONFIG_MPIC_TIMER is not set
++# CONFIG_MPIC_WEIRD is not set
++CONFIG_MPILIB=y
++CONFIG_MPL115=m
++CONFIG_MPL3115=m
++CONFIG_MPLS=y
++CONFIG_MPLS_IPTUNNEL=m
++CONFIG_MPLS_ROUTING=m
++# CONFIG_MPSC is not set
++CONFIG_MRP=m
++CONFIG_MS5611=m
++CONFIG_MS5611_I2C=m
++CONFIG_MS5611_SPI=m
++CONFIG_MS5637=m
++CONFIG_MSDOS_FS=m
++CONFIG_MSDOS_PARTITION=y
++# CONFIG_MSI_BITMAP_SELFTEST is not set
++CONFIG_MSI_LAPTOP=m
++CONFIG_MSI_WMI=m
++CONFIG_MSM_GCC_8660=m
++CONFIG_MSM_GCC_8916=m
++CONFIG_MSM_GCC_8960=m
++CONFIG_MSM_GCC_8974=m
++CONFIG_MSM_LCC_8960=m
++CONFIG_MSM_MMCC_8960=m
++CONFIG_MSM_MMCC_8974=m
++CONFIG_MSPRO_BLOCK=m
++CONFIG_MS_BLOCK=m
++CONFIG_MT7601U=m
++CONFIG_MTDRAM_ERASE_SIZE=128
++CONFIG_MTDRAM_TOTAL_SIZE=4096
++CONFIG_MTD_ABSENT=m
++CONFIG_MTD_AFS_PARTS=m
++CONFIG_MTD_AMD76XROM=m
++CONFIG_MTD_AR7_PARTS=m
++CONFIG_MTD_BLOCK2MTD=m
++CONFIG_MTD_BLOCK_RO=m
++CONFIG_MTD_CFI=m
++# CONFIG_MTD_CFI_ADV_OPTIONS is not set
++CONFIG_MTD_CFI_AMDSTD=m
++CONFIG_MTD_CFI_I1=y
++CONFIG_MTD_CFI_I2=y
++# CONFIG_MTD_CFI_I4 is not set
++# CONFIG_MTD_CFI_I8 is not set
++CONFIG_MTD_CFI_INTELEXT=m
++CONFIG_MTD_CFI_STAA=m
++CONFIG_MTD_CFI_UTIL=m
++CONFIG_MTD_CK804XROM=m
++CONFIG_MTD_COMPLEX_MAPPINGS=y
++CONFIG_MTD_DATAFLASH=m
++CONFIG_MTD_DATAFLASH_OTP=y
++# CONFIG_MTD_DATAFLASH_WRITE_VERIFY is not set
++CONFIG_MTD_DOCG3=m
++CONFIG_MTD_ESB2ROM=m
++CONFIG_MTD_GEN_PROBE=m
++CONFIG_MTD_GPIO_ADDR=m
++CONFIG_MTD_ICHXROM=m
++CONFIG_MTD_IMPA7=m
++CONFIG_MTD_INTEL_VR_NOR=m
++CONFIG_MTD_JEDECPROBE=m
++CONFIG_MTD_L440GX=m
++CONFIG_MTD_LATCH_ADDR=m
++CONFIG_MTD_LPDDR=m
++CONFIG_MTD_LPDDR2_NVM=m
++CONFIG_MTD_M25P80=m
++CONFIG_MTD_MAP_BANK_WIDTH_1=y
++# CONFIG_MTD_MAP_BANK_WIDTH_16 is not set
++CONFIG_MTD_MAP_BANK_WIDTH_2=y
++# CONFIG_MTD_MAP_BANK_WIDTH_32 is not set
++CONFIG_MTD_MAP_BANK_WIDTH_4=y
++# CONFIG_MTD_MAP_BANK_WIDTH_8 is not set
++CONFIG_MTD_MTDRAM=m
++CONFIG_MTD_NAND_BRCMNAND=m
++CONFIG_MTD_NAND_CAFE=m
++CONFIG_MTD_NAND_CS553X=m
++CONFIG_MTD_NAND_DENALI=m
++CONFIG_MTD_NAND_DENALI_DT=m
++CONFIG_MTD_NAND_DENALI_PCI=m
++CONFIG_MTD_NAND_DENALI_SCRATCH_REG_ADDR=0xFF108018
++CONFIG_MTD_NAND_DISKONCHIP=m
++# CONFIG_MTD_NAND_DISKONCHIP_BBTWRITE is not set
++CONFIG_MTD_NAND_DISKONCHIP_PROBE_ADDRESS=0
++# CONFIG_MTD_NAND_DISKONCHIP_PROBE_ADVANCED is not set
++CONFIG_MTD_NAND_DOCG4=m
++CONFIG_MTD_NAND_ECC_BCH=y
++# CONFIG_MTD_NAND_ECC_SMC is not set
++CONFIG_MTD_NAND_FSL_ELBC=m
++CONFIG_MTD_NAND_FSL_IFC=m
++CONFIG_MTD_NAND_FSL_UPM=m
++CONFIG_MTD_NAND_GPIO=m
++CONFIG_MTD_NAND_GPMI_NAND=m
++CONFIG_MTD_NAND_HISI504=m
++CONFIG_MTD_NAND_MXC=m
++CONFIG_MTD_NAND_NANDSIM=m
++CONFIG_MTD_NAND_OMAP2=y
++CONFIG_MTD_NAND_OMAP_BCH=y
++CONFIG_MTD_NAND_ORION=m
++CONFIG_MTD_NAND_PASEMI=m
++CONFIG_MTD_NAND_PLATFORM=m
++CONFIG_MTD_NAND_PXA3xx=m
++CONFIG_MTD_NAND_RICOH=m
++CONFIG_MTD_NAND_SH_FLCTL=m
++CONFIG_MTD_NAND_TMIO=m
++CONFIG_MTD_NAND_VF610_NFC=m
++CONFIG_MTD_NETtel=m
++CONFIG_MTD_ONENAND=m
++CONFIG_MTD_ONENAND_2X_PROGRAM=y
++CONFIG_MTD_ONENAND_GENERIC=m
++CONFIG_MTD_ONENAND_OMAP2=m
++# CONFIG_MTD_ONENAND_OTP is not set
++CONFIG_MTD_ONENAND_VERIFY_WRITE=y
++CONFIG_MTD_OOPS=m
++# CONFIG_MTD_PARTITIONED_MASTER is not set
++CONFIG_MTD_PCI=m
++CONFIG_MTD_PCMCIA=m
++# CONFIG_MTD_PCMCIA_ANONYMOUS is not set
++CONFIG_MTD_PHRAM=m
++CONFIG_MTD_PHYSMAP=m
++# CONFIG_MTD_PHYSMAP_COMPAT is not set
++CONFIG_MTD_PHYSMAP_OF=m
++CONFIG_MTD_PLATRAM=m
++CONFIG_MTD_PMC551=m
++# CONFIG_MTD_PMC551_BUGFIX is not set
++# CONFIG_MTD_PMC551_DEBUG is not set
++CONFIG_MTD_POWERNV_FLASH=m
++CONFIG_MTD_QINFO_PROBE=m
++CONFIG_MTD_RAM=m
++CONFIG_MTD_REDBOOT_DIRECTORY_BLOCK=-1
++CONFIG_MTD_REDBOOT_PARTS=m
++# CONFIG_MTD_REDBOOT_PARTS_READONLY is not set
++# CONFIG_MTD_REDBOOT_PARTS_UNALLOCATED is not set
++CONFIG_MTD_ROM=m
++CONFIG_MTD_SBC_GXX=m
++CONFIG_MTD_SCB2_FLASH=m
++CONFIG_MTD_SCx200_DOCFLASH=m
++CONFIG_MTD_SLRAM=m
++CONFIG_MTD_SM_COMMON=m
++CONFIG_MTD_SPINAND_MT29F=m
++CONFIG_MTD_SPINAND_ONDIEECC=y
++CONFIG_MTD_SPI_NOR=m
++CONFIG_MTD_SPI_NOR_USE_4K_SECTORS=y
++CONFIG_MTD_SST25L=m
++CONFIG_MTD_SWAP=m
++# CONFIG_MTD_TESTS is not set
++CONFIG_MTD_UBI=m
++CONFIG_MTD_UBI_BEB_LIMIT=20
++CONFIG_MTD_UBI_BLOCK=y
++CONFIG_MTD_UBI_FASTMAP=y
++CONFIG_MTD_UBI_GLUEBI=m
++CONFIG_MTD_UBI_WL_THRESHOLD=4096
++CONFIG_MTK_INFRACFG=y
++CONFIG_MTK_PMIC_WRAP=m
++CONFIG_MTK_SCPSYS=y
++CONFIG_MTK_TIMER=y
++CONFIG_MTRR=y
++CONFIG_MTRR_SANITIZER=y
++CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT=1
++CONFIG_MTRR_SANITIZER_SPARE_REG_NR_DEFAULT=1
++CONFIG_MULTIUSER=y
++CONFIG_MULTI_IRQ_HANDLER=y
++CONFIG_MUSB_PIO_ONLY=y
++CONFIG_MUTEX_SPIN_ON_OWNER=y
++CONFIG_MV643XX_ETH=m
++CONFIG_MVEBU_CLK_COMMON=y
++CONFIG_MVEBU_CLK_COREDIV=y
++CONFIG_MVEBU_CLK_CPU=y
++CONFIG_MVEBU_DEVBUS=y
++CONFIG_MVEBU_MBUS=y
++# CONFIG_MVIAC3_2 is not set
++# CONFIG_MVIAC7 is not set
++CONFIG_MVMDIO=m
++# CONFIG_MVME2500 is not set
++CONFIG_MVNETA=m
++CONFIG_MVPP2=m
++CONFIG_MV_XOR=y
++CONFIG_MWAVE=m
++CONFIG_MWIFIEX=m
++CONFIG_MWIFIEX_PCIE=m
++CONFIG_MWIFIEX_SDIO=m
++CONFIG_MWIFIEX_USB=m
++# CONFIG_MWINCHIP3D is not set
++# CONFIG_MWINCHIPC6 is not set
++CONFIG_MWL8K=m
++CONFIG_MX3_IPU=y
++CONFIG_MX3_IPU_IRQS=4
++CONFIG_MXC4005=m
++CONFIG_MXC_TZIC=y
++CONFIG_MXM_WMI=m
++CONFIG_MXS_DMA=y
++CONFIG_MYRI10GE=m
++CONFIG_MYRI10GE_DCA=y
++CONFIG_N2=m
++CONFIG_NAMESPACES=y
++CONFIG_NATIONAL_PHY=m
++CONFIG_NATSEMI=m
++CONFIG_NAU7802=m
++CONFIG_NBPFAXI_DMA=m
++CONFIG_NCPFS_EXTRAS=y
++CONFIG_NCPFS_IOCTL_LOCKING=y
++CONFIG_NCPFS_NFS_NS=y
++CONFIG_NCPFS_NLS=y
++CONFIG_NCPFS_OS2_NS=y
++CONFIG_NCPFS_PACKET_SIGNING=y
++# CONFIG_NCPFS_SMALLDOS is not set
++CONFIG_NCPFS_STRONG=y
++CONFIG_ND_BLK=m
++CONFIG_ND_BTT=m
++CONFIG_ND_CLAIM=y
++CONFIG_ND_PFN=m
++CONFIG_NE2000=m
++CONFIG_NE2K_PCI=m
++CONFIG_NEED_MULTIPLE_NODES=y
++CONFIG_NEED_NODE_MEMMAP_SIZE=y
++CONFIG_NEED_PER_CPU_PAGE_FIRST_CHUNK=y
++CONFIG_NEED_SG_DMA_LENGTH=y
++CONFIG_NEON=y
++CONFIG_NET=y
++CONFIG_NET5501=y
++CONFIG_NETCONSOLE=m
++CONFIG_NETCONSOLE_DYNAMIC=y
++CONFIG_NETDEVICES=y
++CONFIG_NETFILTER=y
++CONFIG_NETFILTER_ADVANCED=y
++# CONFIG_NETFILTER_DEBUG is not set
++CONFIG_NETFILTER_INGRESS=y
++CONFIG_NETFILTER_NETLINK=m
++CONFIG_NETFILTER_NETLINK_ACCT=m
++CONFIG_NETFILTER_NETLINK_GLUE_CT=y
++CONFIG_NETFILTER_NETLINK_LOG=m
++CONFIG_NETFILTER_NETLINK_QUEUE=m
++CONFIG_NETFILTER_SYNPROXY=m
++CONFIG_NETFILTER_XTABLES=m
++CONFIG_NETFILTER_XT_CONNMARK=m
++CONFIG_NETFILTER_XT_MARK=m
++CONFIG_NETFILTER_XT_MATCH_ADDRTYPE=m
++CONFIG_NETFILTER_XT_MATCH_BPF=m
++CONFIG_NETFILTER_XT_MATCH_CGROUP=m
++CONFIG_NETFILTER_XT_MATCH_CLUSTER=m
++CONFIG_NETFILTER_XT_MATCH_COMMENT=m
++CONFIG_NETFILTER_XT_MATCH_CONNBYTES=m
++CONFIG_NETFILTER_XT_MATCH_CONNLABEL=m
++CONFIG_NETFILTER_XT_MATCH_CONNLIMIT=m
++CONFIG_NETFILTER_XT_MATCH_CONNMARK=m
++CONFIG_NETFILTER_XT_MATCH_CONNTRACK=m
++CONFIG_NETFILTER_XT_MATCH_CPU=m
++CONFIG_NETFILTER_XT_MATCH_DCCP=m
++CONFIG_NETFILTER_XT_MATCH_DEVGROUP=m
++CONFIG_NETFILTER_XT_MATCH_DSCP=m
++CONFIG_NETFILTER_XT_MATCH_ECN=m
++CONFIG_NETFILTER_XT_MATCH_ESP=m
++CONFIG_NETFILTER_XT_MATCH_HASHLIMIT=m
++CONFIG_NETFILTER_XT_MATCH_HELPER=m
++CONFIG_NETFILTER_XT_MATCH_HL=m
++CONFIG_NETFILTER_XT_MATCH_IPCOMP=m
++CONFIG_NETFILTER_XT_MATCH_IPRANGE=m
++CONFIG_NETFILTER_XT_MATCH_IPVS=m
++CONFIG_NETFILTER_XT_MATCH_L2TP=m
++CONFIG_NETFILTER_XT_MATCH_LENGTH=m
++CONFIG_NETFILTER_XT_MATCH_LIMIT=m
++CONFIG_NETFILTER_XT_MATCH_MAC=m
++CONFIG_NETFILTER_XT_MATCH_MARK=m
++CONFIG_NETFILTER_XT_MATCH_MULTIPORT=m
++CONFIG_NETFILTER_XT_MATCH_NFACCT=m
++CONFIG_NETFILTER_XT_MATCH_OSF=m
++CONFIG_NETFILTER_XT_MATCH_OWNER=m
++CONFIG_NETFILTER_XT_MATCH_PHYSDEV=m
++CONFIG_NETFILTER_XT_MATCH_PKTTYPE=m
++CONFIG_NETFILTER_XT_MATCH_POLICY=m
++CONFIG_NETFILTER_XT_MATCH_QUOTA=m
++CONFIG_NETFILTER_XT_MATCH_RATEEST=m
++CONFIG_NETFILTER_XT_MATCH_REALM=m
++CONFIG_NETFILTER_XT_MATCH_RECENT=m
++CONFIG_NETFILTER_XT_MATCH_SCTP=m
++CONFIG_NETFILTER_XT_MATCH_SOCKET=m
++CONFIG_NETFILTER_XT_MATCH_STATE=m
++CONFIG_NETFILTER_XT_MATCH_STATISTIC=m
++CONFIG_NETFILTER_XT_MATCH_STRING=m
++CONFIG_NETFILTER_XT_MATCH_TCPMSS=m
++CONFIG_NETFILTER_XT_MATCH_TIME=m
++CONFIG_NETFILTER_XT_MATCH_U32=m
++CONFIG_NETFILTER_XT_NAT=m
++CONFIG_NETFILTER_XT_SET=m
++CONFIG_NETFILTER_XT_TARGET_AUDIT=m
++CONFIG_NETFILTER_XT_TARGET_CHECKSUM=m
++CONFIG_NETFILTER_XT_TARGET_CLASSIFY=m
++CONFIG_NETFILTER_XT_TARGET_CONNMARK=m
++CONFIG_NETFILTER_XT_TARGET_CONNSECMARK=m
++CONFIG_NETFILTER_XT_TARGET_CT=m
++CONFIG_NETFILTER_XT_TARGET_DSCP=m
++CONFIG_NETFILTER_XT_TARGET_HL=m
++CONFIG_NETFILTER_XT_TARGET_HMARK=m
++CONFIG_NETFILTER_XT_TARGET_IDLETIMER=m
++CONFIG_NETFILTER_XT_TARGET_LED=m
++CONFIG_NETFILTER_XT_TARGET_LOG=m
++CONFIG_NETFILTER_XT_TARGET_MARK=m
++CONFIG_NETFILTER_XT_TARGET_NETMAP=m
++CONFIG_NETFILTER_XT_TARGET_NFLOG=m
++CONFIG_NETFILTER_XT_TARGET_NFQUEUE=m
++# CONFIG_NETFILTER_XT_TARGET_NOTRACK is not set
++CONFIG_NETFILTER_XT_TARGET_RATEEST=m
++CONFIG_NETFILTER_XT_TARGET_REDIRECT=m
++CONFIG_NETFILTER_XT_TARGET_SECMARK=m
++CONFIG_NETFILTER_XT_TARGET_TCPMSS=m
++CONFIG_NETFILTER_XT_TARGET_TCPOPTSTRIP=m
++CONFIG_NETFILTER_XT_TARGET_TEE=m
++CONFIG_NETFILTER_XT_TARGET_TPROXY=m
++CONFIG_NETFILTER_XT_TARGET_TRACE=m
++CONFIG_NETIUCV=m
++CONFIG_NETLABEL=y
++CONFIG_NETLINK_DIAG=m
++CONFIG_NETPOLL=y
++CONFIG_NETROM=m
++CONFIG_NETWORK_FILESYSTEMS=y
++# CONFIG_NETWORK_PHY_TIMESTAMPING is not set
++CONFIG_NETWORK_SECMARK=y
++CONFIG_NETXEN_NIC=m
++CONFIG_NET_9P=m
++# CONFIG_NET_9P_DEBUG is not set
++CONFIG_NET_9P_RDMA=m
++CONFIG_NET_9P_VIRTIO=m
++CONFIG_NET_ACT_BPF=m
++CONFIG_NET_ACT_CONNMARK=m
++CONFIG_NET_ACT_CSUM=m
++CONFIG_NET_ACT_GACT=m
++CONFIG_NET_ACT_IPT=m
++CONFIG_NET_ACT_MIRRED=m
++CONFIG_NET_ACT_NAT=m
++CONFIG_NET_ACT_PEDIT=m
++CONFIG_NET_ACT_POLICE=m
++CONFIG_NET_ACT_SIMP=m
++CONFIG_NET_ACT_SKBEDIT=m
++CONFIG_NET_ACT_VLAN=m
++CONFIG_NET_CALXEDA_XGMAC=m
++CONFIG_NET_CLS=y
++CONFIG_NET_CLS_ACT=y
++CONFIG_NET_CLS_BASIC=m
++CONFIG_NET_CLS_BPF=m
++CONFIG_NET_CLS_CGROUP=m
++CONFIG_NET_CLS_FLOW=m
++CONFIG_NET_CLS_FLOWER=m
++CONFIG_NET_CLS_FW=m
++# CONFIG_NET_CLS_IND is not set
++CONFIG_NET_CLS_MATCHALL=m
++CONFIG_NET_CLS_ROUTE4=m
++CONFIG_NET_CLS_RSVP=m
++CONFIG_NET_CLS_RSVP6=m
++CONFIG_NET_CLS_TCINDEX=m
++CONFIG_NET_CLS_U32=m
++CONFIG_NET_CORE=y
++CONFIG_NET_DCCPPROBE=m
++CONFIG_NET_DROP_MONITOR=m
++# CONFIG_NET_DSA is not set
++# CONFIG_NET_DSA_MV88E6XXX is not set
++# CONFIG_NET_DSA_MV88E6XXX_NEED_PPU is not set
++CONFIG_NET_EMATCH=y
++CONFIG_NET_EMATCH_CANID=m
++CONFIG_NET_EMATCH_CMP=m
++CONFIG_NET_EMATCH_IPSET=m
++CONFIG_NET_EMATCH_META=m
++CONFIG_NET_EMATCH_NBYTE=m
++CONFIG_NET_EMATCH_STACK=32
++CONFIG_NET_EMATCH_TEXT=m
++CONFIG_NET_EMATCH_U32=m
++CONFIG_NET_FC=y
++CONFIG_NET_FLOW_LIMIT=y
++CONFIG_NET_FOU=m
++CONFIG_NET_FOU_IP_TUNNELS=y
++CONFIG_NET_INGRESS=y
++CONFIG_NET_IPGRE=m
++CONFIG_NET_IPGRE_BROADCAST=y
++CONFIG_NET_IPGRE_DEMUX=m
++CONFIG_NET_IPIP=m
++CONFIG_NET_IPVTI=m
++CONFIG_NET_IP_TUNNEL=m
++CONFIG_NET_KEY=m
++# CONFIG_NET_KEY_MIGRATE is not set
++CONFIG_NET_L3_MASTER_DEV=y
++CONFIG_NET_MPLS_GSO=m
++CONFIG_NET_NS=y
++CONFIG_NET_PKTGEN=m
++CONFIG_NET_POLL_CONTROLLER=y
++CONFIG_NET_PTP_CLASSIFY=y
++CONFIG_NET_RX_BUSY_POLL=y
++CONFIG_NET_SB1000=m
++CONFIG_NET_SCHED=y
++CONFIG_NET_SCH_ATM=m
++CONFIG_NET_SCH_CBQ=m
++CONFIG_NET_SCH_CHOKE=m
++CONFIG_NET_SCH_CODEL=m
++CONFIG_NET_SCH_DRR=m
++CONFIG_NET_SCH_DSMARK=m
++CONFIG_NET_SCH_FIFO=y
++CONFIG_NET_SCH_FQ=m
++CONFIG_NET_SCH_FQ_CODEL=m
++CONFIG_NET_SCH_GRED=m
++CONFIG_NET_SCH_HFSC=m
++CONFIG_NET_SCH_HHF=m
++CONFIG_NET_SCH_HTB=m
++CONFIG_NET_SCH_INGRESS=m
++CONFIG_NET_SCH_MQPRIO=m
++CONFIG_NET_SCH_MULTIQ=m
++CONFIG_NET_SCH_NETEM=m
++CONFIG_NET_SCH_PIE=m
++CONFIG_NET_SCH_PLUG=m
++CONFIG_NET_SCH_PRIO=m
++CONFIG_NET_SCH_QFQ=m
++CONFIG_NET_SCH_RED=m
++CONFIG_NET_SCH_SFB=m
++CONFIG_NET_SCH_SFQ=m
++CONFIG_NET_SCH_TBF=m
++CONFIG_NET_SCH_TEQL=m
++CONFIG_NET_SCTPPROBE=m
++# CONFIG_NET_SWITCHDEV is not set
++CONFIG_NET_TCPPROBE=m
++CONFIG_NET_TEAM=m
++CONFIG_NET_TEAM_MODE_ACTIVEBACKUP=m
++CONFIG_NET_TEAM_MODE_BROADCAST=m
++CONFIG_NET_TEAM_MODE_LOADBALANCE=m
++CONFIG_NET_TEAM_MODE_RANDOM=m
++CONFIG_NET_TEAM_MODE_ROUNDROBIN=m
++CONFIG_NET_TULIP=y
++CONFIG_NET_UDP_TUNNEL=m
++CONFIG_NET_VENDOR_8390=y
++CONFIG_NET_VENDOR_AMAZON=y
++CONFIG_NET_VENDOR_APPLE=y
++CONFIG_NET_VENDOR_AURORA=y
++CONFIG_NET_VENDOR_CIRRUS=y
++CONFIG_NET_VENDOR_FARADAY=y
++CONFIG_NET_VENDOR_FREESCALE=y
++CONFIG_NET_VENDOR_FUJITSU=y
++CONFIG_NET_VENDOR_HISILICON=y
++CONFIG_NET_VENDOR_I825XX=y
++CONFIG_NET_VENDOR_IBM=y
++CONFIG_NET_VENDOR_MELLANOX=y
++CONFIG_NET_VENDOR_MICROCHIP=y
++CONFIG_NET_VENDOR_PASEMI=y
++CONFIG_NET_VENDOR_TOSHIBA=y
++CONFIG_NET_VENDOR_XILINX=y
++CONFIG_NET_VENDOR_XIRCOM=y
++CONFIG_NET_VRF=m
++CONFIG_NET_XGENE=m
++CONFIG_NFC_DIGITAL=m
++CONFIG_NFC_FDP=m
++CONFIG_NFC_FDP_I2C=m
++CONFIG_NFC_HCI=m
++CONFIG_NFC_MEI_PHY=m
++CONFIG_NFC_MICROREAD=m
++CONFIG_NFC_MICROREAD_I2C=m
++CONFIG_NFC_MICROREAD_MEI=m
++CONFIG_NFC_MRVL=m
++CONFIG_NFC_MRVL_I2C=m
++CONFIG_NFC_MRVL_SPI=m
++CONFIG_NFC_MRVL_UART=m
++CONFIG_NFC_MRVL_USB=m
++CONFIG_NFC_NCI=m
++CONFIG_NFC_NCI_SPI=m
++CONFIG_NFC_NCI_UART=m
++CONFIG_NFC_NXP_NCI=m
++CONFIG_NFC_NXP_NCI_I2C=m
++CONFIG_NFC_PN533=m
++CONFIG_NFC_PN544=m
++CONFIG_NFC_PN544_I2C=m
++CONFIG_NFC_PN544_MEI=m
++CONFIG_NFC_PORT100=m
++CONFIG_NFC_S3FWRN5=m
++CONFIG_NFC_S3FWRN5_I2C=m
++CONFIG_NFC_SHDLC=y
++CONFIG_NFC_SIM=m
++CONFIG_NFC_ST21NFCA=m
++CONFIG_NFC_ST21NFCA_I2C=m
++CONFIG_NFC_ST_NCI=m
++CONFIG_NFC_ST_NCI_I2C=m
++CONFIG_NFC_ST_NCI_SPI=m
++CONFIG_NFC_TRF7970A=m
++CONFIG_NFC_WILINK=m
++CONFIG_NFSD=m
++# CONFIG_NFSD_FAULT_INJECTION is not set
++CONFIG_NFSD_PNFS=y
++CONFIG_NFSD_V2_ACL=y
++CONFIG_NFSD_V3=y
++CONFIG_NFSD_V3_ACL=y
++CONFIG_NFSD_V4=y
++CONFIG_NFSD_V4_SECURITY_LABEL=y
++CONFIG_NFS_ACL_SUPPORT=m
++CONFIG_NFS_COMMON=y
++CONFIG_NFS_DEBUG=y
++CONFIG_NFS_FS=m
++CONFIG_NFS_FSCACHE=y
++CONFIG_NFS_SWAP=y
++CONFIG_NFS_USE_KERNEL_DNS=y
++# CONFIG_NFS_USE_LEGACY_DNS is not set
++CONFIG_NFS_V2=m
++CONFIG_NFS_V3=m
++CONFIG_NFS_V3_ACL=y
++CONFIG_NFS_V4=m
++CONFIG_NFS_V4_1=y
++CONFIG_NFS_V4_1_IMPLEMENTATION_ID_DOMAIN="kernel.org"
++CONFIG_NFS_V4_1_MIGRATION=y
++CONFIG_NFS_V4_2=y
++CONFIG_NFS_V4_SECURITY_LABEL=y
++CONFIG_NFTL=m
++CONFIG_NFTL_RW=y
++CONFIG_NFT_BRIDGE_META=m
++CONFIG_NFT_BRIDGE_REJECT=m
++CONFIG_NFT_CHAIN_NAT_IPV4=m
++CONFIG_NFT_CHAIN_NAT_IPV6=m
++CONFIG_NFT_CHAIN_ROUTE_IPV4=m
++CONFIG_NFT_CHAIN_ROUTE_IPV6=m
++CONFIG_NFT_COMPAT=m
++CONFIG_NFT_COUNTER=m
++CONFIG_NFT_CT=m
++CONFIG_NFT_DUP_IPV4=m
++CONFIG_NFT_DUP_IPV6=m
++CONFIG_NFT_EXTHDR=m
++CONFIG_NFT_HASH=m
++CONFIG_NFT_LIMIT=m
++CONFIG_NFT_LOG=m
++CONFIG_NFT_MASQ=m
++CONFIG_NFT_MASQ_IPV4=m
++CONFIG_NFT_MASQ_IPV6=m
++CONFIG_NFT_META=m
++CONFIG_NFT_NAT=m
++CONFIG_NFT_QUEUE=m
++CONFIG_NFT_RBTREE=m
++CONFIG_NFT_REDIR=m
++CONFIG_NFT_REDIR_IPV4=m
++CONFIG_NFT_REDIR_IPV6=m
++CONFIG_NFT_REJECT=m
++CONFIG_NFT_REJECT_INET=m
++CONFIG_NFT_REJECT_IPV4=m
++CONFIG_NFT_REJECT_IPV6=m
++CONFIG_NF_CONNTRACK=m
++CONFIG_NF_CONNTRACK_AMANDA=m
++CONFIG_NF_CONNTRACK_BROADCAST=m
++CONFIG_NF_CONNTRACK_EVENTS=y
++CONFIG_NF_CONNTRACK_FTP=m
++CONFIG_NF_CONNTRACK_H323=m
++CONFIG_NF_CONNTRACK_IPV4=m
++CONFIG_NF_CONNTRACK_IPV6=m
++CONFIG_NF_CONNTRACK_IRC=m
++CONFIG_NF_CONNTRACK_LABELS=y
++CONFIG_NF_CONNTRACK_MARK=y
++CONFIG_NF_CONNTRACK_NETBIOS_NS=m
++CONFIG_NF_CONNTRACK_PPTP=m
++# CONFIG_NF_CONNTRACK_PROCFS is not set
++CONFIG_NF_CONNTRACK_SANE=m
++CONFIG_NF_CONNTRACK_SECMARK=y
++CONFIG_NF_CONNTRACK_SIP=m
++CONFIG_NF_CONNTRACK_SNMP=m
++CONFIG_NF_CONNTRACK_TFTP=m
++CONFIG_NF_CONNTRACK_TIMEOUT=y
++CONFIG_NF_CONNTRACK_TIMESTAMP=y
++CONFIG_NF_CONNTRACK_ZONES=y
++CONFIG_NF_CT_NETLINK=m
++CONFIG_NF_CT_NETLINK_HELPER=m
++CONFIG_NF_CT_NETLINK_TIMEOUT=m
++CONFIG_NF_CT_PROTO_DCCP=m
++CONFIG_NF_CT_PROTO_GRE=m
++CONFIG_NF_CT_PROTO_SCTP=m
++CONFIG_NF_CT_PROTO_UDPLITE=m
++CONFIG_NF_DEFRAG_IPV4=m
++CONFIG_NF_DEFRAG_IPV6=m
++CONFIG_NF_DUP_IPV4=m
++CONFIG_NF_DUP_IPV6=m
++CONFIG_NF_LOG_ARP=m
++CONFIG_NF_LOG_BRIDGE=m
++CONFIG_NF_LOG_COMMON=m
++CONFIG_NF_LOG_IPV4=m
++CONFIG_NF_LOG_IPV6=m
++CONFIG_NF_NAT=m
++CONFIG_NF_NAT_AMANDA=m
++CONFIG_NF_NAT_FTP=m
++CONFIG_NF_NAT_H323=m
++CONFIG_NF_NAT_IPV4=m
++CONFIG_NF_NAT_IPV6=m
++CONFIG_NF_NAT_IRC=m
++CONFIG_NF_NAT_MASQUERADE_IPV4=m
++CONFIG_NF_NAT_MASQUERADE_IPV6=m
++CONFIG_NF_NAT_NEEDED=y
++CONFIG_NF_NAT_PPTP=m
++CONFIG_NF_NAT_PROTO_DCCP=m
++CONFIG_NF_NAT_PROTO_GRE=m
++CONFIG_NF_NAT_PROTO_SCTP=m
++CONFIG_NF_NAT_PROTO_UDPLITE=m
++CONFIG_NF_NAT_REDIRECT=m
++CONFIG_NF_NAT_SIP=m
++CONFIG_NF_NAT_SNMP_BASIC=m
++CONFIG_NF_NAT_TFTP=m
++CONFIG_NF_REJECT_IPV4=m
++CONFIG_NF_REJECT_IPV6=m
++CONFIG_NF_TABLES=m
++CONFIG_NF_TABLES_ARP=m
++CONFIG_NF_TABLES_BRIDGE=m
++CONFIG_NF_TABLES_INET=m
++CONFIG_NF_TABLES_IPV4=m
++CONFIG_NF_TABLES_IPV6=m
++CONFIG_NF_TABLES_NETDEV=m
++CONFIG_NI65=m
++CONFIG_NILFS2_FS=m
++CONFIG_NIU=m
++# CONFIG_NL80211_TESTMODE is not set
++CONFIG_NLATTR=y
++CONFIG_NLMON=m
++CONFIG_NLS=y
++CONFIG_NLS_ASCII=m
++CONFIG_NLS_CODEPAGE_1250=m
++CONFIG_NLS_CODEPAGE_1251=m
++CONFIG_NLS_CODEPAGE_437=y
++CONFIG_NLS_CODEPAGE_737=m
++CONFIG_NLS_CODEPAGE_775=m
++CONFIG_NLS_CODEPAGE_850=m
++CONFIG_NLS_CODEPAGE_852=m
++CONFIG_NLS_CODEPAGE_855=m
++CONFIG_NLS_CODEPAGE_857=m
++CONFIG_NLS_CODEPAGE_860=m
++CONFIG_NLS_CODEPAGE_861=m
++CONFIG_NLS_CODEPAGE_862=m
++CONFIG_NLS_CODEPAGE_863=m
++CONFIG_NLS_CODEPAGE_864=m
++CONFIG_NLS_CODEPAGE_865=m
++CONFIG_NLS_CODEPAGE_866=m
++CONFIG_NLS_CODEPAGE_869=m
++CONFIG_NLS_CODEPAGE_874=m
++CONFIG_NLS_CODEPAGE_932=m
++CONFIG_NLS_CODEPAGE_936=m
++CONFIG_NLS_CODEPAGE_949=m
++CONFIG_NLS_CODEPAGE_950=m
++CONFIG_NLS_DEFAULT="utf8"
++CONFIG_NLS_ISO8859_1=y
++CONFIG_NLS_ISO8859_13=m
++CONFIG_NLS_ISO8859_14=m
++CONFIG_NLS_ISO8859_15=m
++CONFIG_NLS_ISO8859_2=m
++CONFIG_NLS_ISO8859_3=m
++CONFIG_NLS_ISO8859_4=m
++CONFIG_NLS_ISO8859_5=m
++CONFIG_NLS_ISO8859_6=m
++CONFIG_NLS_ISO8859_7=m
++CONFIG_NLS_ISO8859_8=m
++CONFIG_NLS_ISO8859_9=m
++CONFIG_NLS_KOI8_R=m
++CONFIG_NLS_KOI8_U=m
++CONFIG_NLS_MAC_CELTIC=m
++CONFIG_NLS_MAC_CENTEURO=m
++CONFIG_NLS_MAC_CROATIAN=m
++CONFIG_NLS_MAC_CYRILLIC=m
++CONFIG_NLS_MAC_GAELIC=m
++CONFIG_NLS_MAC_GREEK=m
++CONFIG_NLS_MAC_ICELAND=m
++CONFIG_NLS_MAC_INUIT=m
++CONFIG_NLS_MAC_ROMAN=m
++CONFIG_NLS_MAC_ROMANIAN=m
++CONFIG_NLS_MAC_TURKISH=m
++CONFIG_NLS_UTF8=m
++CONFIG_NODES_SPAN_OTHER_NODES=y
++# CONFIG_NOHIGHMEM is not set
++CONFIG_NOKIA_MODEM=m
++CONFIG_NOP_TRACER=y
++CONFIG_NOP_USB_XCEIV=y
++CONFIG_NORTEL_HERMES=m
++CONFIG_NOTIFIER_ERROR_INJECTION=m
++CONFIG_NOUVEAU_DEBUG=5
++CONFIG_NOUVEAU_DEBUG_DEFAULT=3
++CONFIG_NOUVEAU_PLATFORM_DRIVER=y
++CONFIG_NO_BOOTMEM=y
++CONFIG_NO_HZ=y
++CONFIG_NO_HZ_COMMON=y
++# CONFIG_NO_HZ_FULL is not set
++CONFIG_NO_HZ_IDLE=y
++CONFIG_NO_IOPORT_MAP=y
++CONFIG_NR_IRQS=512
++CONFIG_NS83820=m
++CONFIG_NSC_FIR=m
++CONFIG_NSC_GPIO=m
++CONFIG_NTB_AMD=m
++CONFIG_NTB_INTEL=m
++CONFIG_NTB_NETDEV=m
++CONFIG_NTB_PINGPONG=m
++CONFIG_NTB_TOOL=m
++CONFIG_NTB_TRANSPORT=m
++# CONFIG_NTFS_DEBUG is not set
++CONFIG_NTFS_FS=m
++CONFIG_NUMA_BALANCING=y
++CONFIG_NVDIMM_PFN=y
++CONFIG_NVEC_PAZ00=m
++CONFIG_NVEC_POWER=m
++CONFIG_NVM=y
++CONFIG_NVMEM_IMX_OCOTP=m
++CONFIG_NVMEM_VF610_OCOTP=m
++CONFIG_NVME_VENDOR_EXT_GOOGLE=y
++# CONFIG_NVM_DEBUG is not set
++CONFIG_NVM_GENNVM=m
++CONFIG_NVM_RRPC=m
++CONFIG_NV_TCO=m
++CONFIG_N_HDLC=m
++# CONFIG_OABI_COMPAT is not set
++# CONFIG_OCFS2_DEBUG_FS is not set
++CONFIG_OCFS2_DEBUG_MASKLOG=y
++CONFIG_OCFS2_FS=m
++CONFIG_OCFS2_FS_O2CB=m
++CONFIG_OCFS2_FS_STATS=y
++CONFIG_OCFS2_FS_USERSPACE_CLUSTER=m
++CONFIG_OF_ADDRESS=y
++CONFIG_OF_ADDRESS_PCI=y
++CONFIG_OF_DYNAMIC=y
++CONFIG_OF_EARLY_FLATTREE=y
++CONFIG_OF_FLATTREE=y
++CONFIG_OF_GPIO=y
++CONFIG_OF_IOMMU=y
++CONFIG_OF_IRQ=y
++CONFIG_OF_MDIO=y
++CONFIG_OF_MTD=y
++CONFIG_OF_NET=y
++CONFIG_OF_NUMA=y
++CONFIG_OF_OVERLAY=y
++CONFIG_OF_PCI=y
++CONFIG_OF_PCI_IRQ=y
++# CONFIG_OF_RECONFIG_NOTIFIER_ERROR_INJECT is not set
++CONFIG_OF_RESERVED_MEM=y
++CONFIG_OF_RESOLVE=y
++# CONFIG_OF_UNITTEST is not set
++CONFIG_OID_REGISTRY=y
++CONFIG_OLD_BELKIN_DONGLE=m
++CONFIG_OLD_MCOUNT=y
++CONFIG_OLD_SIGACTION=y
++CONFIG_OLD_SIGSUSPEND=y
++CONFIG_OLD_SIGSUSPEND3=y
++CONFIG_OMAP2PLUS_MBOX=m
++CONFIG_OMAP2_DSS=y
++# CONFIG_OMAP2_DSS_DEBUG is not set
++# CONFIG_OMAP2_DSS_DEBUGFS is not set
++CONFIG_OMAP2_DSS_DPI=y
++# CONFIG_OMAP2_DSS_DSI is not set
++CONFIG_OMAP2_DSS_HDMI_COMMON=y
++CONFIG_OMAP2_DSS_INIT=y
++CONFIG_OMAP2_DSS_MIN_FCK_PER_PCK=0
++CONFIG_OMAP2_DSS_SDI=y
++CONFIG_OMAP2_DSS_SLEEP_AFTER_VENC_RESET=y
++CONFIG_OMAP2_DSS_VENC=y
++CONFIG_OMAP2_VRFB=y
++# CONFIG_OMAP3_L2_AUX_SECURE_SAVE_RESTORE is not set
++# CONFIG_OMAP3_SDRC_AC_TIMING is not set
++CONFIG_OMAP3_THERMAL=y
++CONFIG_OMAP4_DSS_HDMI=y
++CONFIG_OMAP4_THERMAL=y
++CONFIG_OMAP5_DSS_HDMI=y
++CONFIG_OMAP_32K_TIMER=y
++CONFIG_OMAP_CONTROL_PHY=m
++CONFIG_OMAP_DM_TIMER=y
++CONFIG_OMAP_GPMC=y
++# CONFIG_OMAP_GPMC_DEBUG is not set
++CONFIG_OMAP_INTERCONNECT=y
++CONFIG_OMAP_INTERCONNECT_BARRIER=y
++CONFIG_OMAP_IOMMU=y
++# CONFIG_OMAP_IOMMU_DEBUG is not set
++CONFIG_OMAP_IRQCHIP=y
++CONFIG_OMAP_MBOX_KFIFO_SIZE=256
++CONFIG_OMAP_MUX=y
++# CONFIG_OMAP_MUX_DEBUG is not set
++CONFIG_OMAP_MUX_WARNINGS=y
++CONFIG_OMAP_OCP2SCP=m
++CONFIG_OMAP_PACKAGE_CBB=y
++CONFIG_OMAP_PM_NOOP=y
++CONFIG_OMAP_REMOTEPROC=m
++CONFIG_OMAP_RESET_CLOCKS=y
++CONFIG_OMAP_SSI=m
++CONFIG_OMAP_SSI_PORT=m
++CONFIG_OMAP_USB2=m
++CONFIG_OMAP_WATCHDOG=m
++CONFIG_OPAL_PRD=m
++CONFIG_OPENNSL_BCM_KNET=m
++CONFIG_OPENNSL_KERNEL_BDE=m
++CONFIG_OPENNSL_USER_BDE=m
++CONFIG_OPENVSWITCH=m
++CONFIG_OPENVSWITCH_GENEVE=m
++CONFIG_OPENVSWITCH_GRE=m
++CONFIG_OPENVSWITCH_VXLAN=m
++CONFIG_OPROFILE=m
++# CONFIG_OPROFILE_EVENT_MULTIPLEX is not set
++CONFIG_OPROFILE_NMI_TIMER=y
++CONFIG_OPT3001=m
++CONFIG_OPTIMIZE_INLINING=y
++CONFIG_OPTPROBES=y
++CONFIG_ORE=m
++CONFIG_ORINOCO_USB=m
++CONFIG_ORION_IRQCHIP=y
++CONFIG_ORION_TIMER=y
++CONFIG_ORION_WATCHDOG=m
++CONFIG_OUTER_CACHE=y
++CONFIG_OUTER_CACHE_SYNC=y
++CONFIG_OVERLAY_FS=m
++CONFIG_OVERLAY_FS_V1=y
++# CONFIG_P1010_RDB is not set
++# CONFIG_P1022_DS is not set
++# CONFIG_P1022_RDK is not set
++CONFIG_P1023_RDB=y
++CONFIG_P54_COMMON=m
++CONFIG_P54_LEDS=y
++CONFIG_P54_PCI=m
++CONFIG_P54_SPI=m
++# CONFIG_P54_SPI_DEFAULT_EEPROM is not set
++CONFIG_P54_USB=m
++CONFIG_PA12203001=m
++CONFIG_PACKET=y
++CONFIG_PACKET_DIAG=m
++CONFIG_PACK_STACK=y
++CONFIG_PADATA=y
++CONFIG_PAGE_COUNTER=y
++# CONFIG_PAGE_OWNER is not set
++CONFIG_PANASONIC_LAPTOP=m
++CONFIG_PANEL=m
++# CONFIG_PANEL_CHANGE_MESSAGE is not set
++CONFIG_PANEL_PARPORT=0
++CONFIG_PANEL_PROFILE=5
++# CONFIG_PANIC_ON_OOPS is not set
++CONFIG_PANIC_ON_OOPS_VALUE=0
++CONFIG_PANTHERLORD_FF=y
++CONFIG_PARAVIRT=y
++CONFIG_PARAVIRT_CLOCK=y
++# CONFIG_PARAVIRT_DEBUG is not set
++CONFIG_PARAVIRT_SPINLOCKS=y
++# CONFIG_PARAVIRT_TIME_ACCOUNTING is not set
++CONFIG_PARIDE=m
++CONFIG_PARIDE_ATEN=m
++CONFIG_PARIDE_BPCK=m
++CONFIG_PARIDE_BPCK6=m
++CONFIG_PARIDE_COMM=m
++CONFIG_PARIDE_DSTR=m
++CONFIG_PARIDE_EPAT=m
++CONFIG_PARIDE_EPATC8=y
++CONFIG_PARIDE_EPIA=m
++CONFIG_PARIDE_FIT2=m
++CONFIG_PARIDE_FIT3=m
++CONFIG_PARIDE_FRIQ=m
++CONFIG_PARIDE_FRPW=m
++CONFIG_PARIDE_KBIC=m
++CONFIG_PARIDE_KTTI=m
++CONFIG_PARIDE_ON20=m
++CONFIG_PARIDE_ON26=m
++CONFIG_PARIDE_PCD=m
++CONFIG_PARIDE_PD=m
++CONFIG_PARIDE_PF=m
++CONFIG_PARIDE_PG=m
++CONFIG_PARIDE_PT=m
++CONFIG_PARPORT_1284=y
++CONFIG_PARPORT_AX88796=m
++# CONFIG_PARPORT_GSC is not set
++CONFIG_PARPORT_NOT_PC=y
++CONFIG_PARPORT_PC=m
++CONFIG_PARPORT_PC_FIFO=y
++CONFIG_PARPORT_PC_PCMCIA=m
++# CONFIG_PARPORT_PC_SUPERIO is not set
++CONFIG_PARPORT_SERIAL=m
++CONFIG_PARTITION_ADVANCED=y
++# CONFIG_PASEMI_MAC is not set
++CONFIG_PATA_ACPI=m
++CONFIG_PATA_ALI=m
++CONFIG_PATA_AMD=m
++CONFIG_PATA_ARTOP=m
++CONFIG_PATA_ATIIXP=m
++CONFIG_PATA_ATP867X=m
++CONFIG_PATA_CMD640_PCI=m
++CONFIG_PATA_CMD64X=m
++CONFIG_PATA_CS5520=m
++CONFIG_PATA_CS5530=m
++CONFIG_PATA_CS5535=m
++CONFIG_PATA_CS5536=m
++CONFIG_PATA_CYPRESS=m
++CONFIG_PATA_EFAR=m
++CONFIG_PATA_HPT366=m
++CONFIG_PATA_HPT37X=m
++CONFIG_PATA_HPT3X2N=m
++CONFIG_PATA_HPT3X3=m
++# CONFIG_PATA_HPT3X3_DMA is not set
++CONFIG_PATA_IMX=m
++CONFIG_PATA_ISAPNP=m
++CONFIG_PATA_IT8213=m
++CONFIG_PATA_IT821X=m
++CONFIG_PATA_JMICRON=m
++CONFIG_PATA_LEGACY=m
++CONFIG_PATA_MACIO=y
++CONFIG_PATA_MARVELL=m
++CONFIG_PATA_MPIIX=m
++CONFIG_PATA_NETCELL=m
++CONFIG_PATA_NINJA32=m
++CONFIG_PATA_NS87410=m
++CONFIG_PATA_NS87415=m
++CONFIG_PATA_OF_PLATFORM=m
++CONFIG_PATA_OLDPIIX=m
++CONFIG_PATA_OPTI=m
++CONFIG_PATA_OPTIDMA=m
++CONFIG_PATA_PCMCIA=m
++CONFIG_PATA_PDC2027X=m
++CONFIG_PATA_PDC_OLD=m
++CONFIG_PATA_PLATFORM=m
++CONFIG_PATA_QDI=m
++CONFIG_PATA_RADISYS=m
++CONFIG_PATA_RDC=m
++CONFIG_PATA_RZ1000=m
++CONFIG_PATA_SC1200=m
++CONFIG_PATA_SCH=m
++CONFIG_PATA_SERVERWORKS=m
++CONFIG_PATA_SIL680=m
++CONFIG_PATA_TOSHIBA=m
++CONFIG_PATA_TRIFLEX=m
++CONFIG_PATA_VIA=m
++CONFIG_PATA_WINBOND=m
++CONFIG_PATA_WINBOND_VLB=m
++CONFIG_PC300TOO=m
++CONFIG_PC8736x_GPIO=m
++CONFIG_PC87413_WDT=m
++CONFIG_PCC=y
++CONFIG_PCCARD_NONSTATIC=y
++CONFIG_PCF50633_ADC=m
++CONFIG_PCF50633_GPIO=m
++CONFIG_PCH_CAN=m
++CONFIG_PCH_DMA=m
++CONFIG_PCH_GBE=m
++CONFIG_PCH_PHUB=m
++CONFIG_PCI=y
++CONFIG_PCI200SYN=m
++CONFIG_PCIEAER=y
++# CONFIG_PCIEAER_INJECT is not set
++CONFIG_PCIEASPM=y
++CONFIG_PCIEASPM_DEBUG=y
++CONFIG_PCIEASPM_DEFAULT=y
++# CONFIG_PCIEASPM_PERFORMANCE is not set
++# CONFIG_PCIEASPM_POWERSAVE is not set
++CONFIG_PCIEPORTBUS=y
++CONFIG_PCIE_ALTERA=y
++CONFIG_PCIE_ALTERA_MSI=y
++CONFIG_PCIE_DW=y
++# CONFIG_PCIE_ECRC is not set
++CONFIG_PCIE_IPROC=m
++CONFIG_PCIE_IPROC_PLATFORM=m
++CONFIG_PCIE_PME=y
++CONFIG_PCI_ATMEL=m
++CONFIG_PCI_ATS=y
++CONFIG_PCI_BIOS=y
++CONFIG_PCI_BUS_ADDR_T_64BIT=y
++# CONFIG_PCI_CNB20LE_QUIRK is not set
++# CONFIG_PCI_DEBUG is not set
++CONFIG_PCI_DIRECT=y
++CONFIG_PCI_DOMAINS=y
++CONFIG_PCI_DOMAINS_GENERIC=y
++CONFIG_PCI_EXYNOS=y
++CONFIG_PCI_GOANY=y
++# CONFIG_PCI_GOBIOS is not set
++# CONFIG_PCI_GODIRECT is not set
++# CONFIG_PCI_GOMMCONFIG is not set
++CONFIG_PCI_HISI=y
++CONFIG_PCI_HOST_COMMON=y
++CONFIG_PCI_HOST_GENERIC=y
++CONFIG_PCI_HOST_THUNDER_ECAM=y
++CONFIG_PCI_HOST_THUNDER_PEM=y
++CONFIG_PCI_HYPERV=m
++CONFIG_PCI_IMX6=y
++CONFIG_PCI_IOV=y
++CONFIG_PCI_LABEL=y
++# CONFIG_PCI_LAYERSCAPE is not set
++CONFIG_PCI_MMCONFIG=y
++CONFIG_PCI_MSI=y
++CONFIG_PCI_MSI_IRQ_DOMAIN=y
++CONFIG_PCI_MVEBU=y
++CONFIG_PCI_NR_FUNCTIONS=64
++CONFIG_PCI_NR_MSI=256
++CONFIG_PCI_RCAR_GEN2=y
++CONFIG_PCI_RCAR_GEN2_PCIE=y
++CONFIG_PCI_REALLOC_ENABLE_AUTO=y
++CONFIG_PCI_STUB=m
++CONFIG_PCI_SYSCALL=y
++CONFIG_PCI_TEGRA=y
++CONFIG_PCI_XEN=y
++CONFIG_PCI_XGENE=y
++CONFIG_PCI_XGENE_MSI=y
++CONFIG_PCMCIA_3C574=m
++CONFIG_PCMCIA_3C589=m
++CONFIG_PCMCIA_AHA152X=m
++CONFIG_PCMCIA_ATMEL=m
++CONFIG_PCMCIA_AXNET=m
++CONFIG_PCMCIA_FDOMAIN=m
++CONFIG_PCMCIA_FMVJ18X=m
++CONFIG_PCMCIA_HERMES=m
++CONFIG_PCMCIA_LOAD_CIS=y
++CONFIG_PCMCIA_NINJA_SCSI=m
++CONFIG_PCMCIA_NMCLAN=m
++CONFIG_PCMCIA_PCNET=m
++CONFIG_PCMCIA_PROBE=y
++CONFIG_PCMCIA_QLOGIC=m
++CONFIG_PCMCIA_RAYCS=m
++CONFIG_PCMCIA_SMC91C92=m
++CONFIG_PCMCIA_SPECTRUM=m
++CONFIG_PCMCIA_SYM53C500=m
++CONFIG_PCMCIA_WL3501=m
++CONFIG_PCMCIA_XIRC2PS=m
++CONFIG_PCMCIA_XIRCOM=m
++CONFIG_PCNET32=m
++CONFIG_PCSPKR_PLATFORM=y
++CONFIG_PCWATCHDOG=m
++CONFIG_PD6729=m
++CONFIG_PDA_POWER=m
++CONFIG_PDC_ADMA=m
++CONFIG_PERCPU_TEST=m
++CONFIG_PERF_EVENTS=y
++CONFIG_PERF_EVENTS_INTEL_UNCORE=y
++CONFIG_PERF_USE_VMALLOC=y
++CONFIG_PERSISTENT_KEYRINGS=y
++CONFIG_PFAULT=y
++CONFIG_PGSTE=y
++CONFIG_PHYS_64BIT=y
++CONFIG_PHY_BERLIN_SATA=m
++CONFIG_PHY_BERLIN_USB=m
++CONFIG_PHY_DM816X_USB=m
++# CONFIG_PHY_EXYNOS4210_USB2 is not set
++# CONFIG_PHY_EXYNOS4X12_USB2 is not set
++CONFIG_PHY_EXYNOS5250_SATA=y
++CONFIG_PHY_EXYNOS5_USBDRD=m
++CONFIG_PHY_EXYNOS_DP_VIDEO=y
++CONFIG_PHY_EXYNOS_MIPI_VIDEO=y
++CONFIG_PHY_HIX5HD2_SATA=m
++CONFIG_PHY_MT65XX_USB3=m
++CONFIG_PHY_MVEBU_SATA=y
++CONFIG_PHY_QCOM_APQ8064_SATA=m
++CONFIG_PHY_QCOM_IPQ806X_SATA=m
++CONFIG_PHY_QCOM_UFS=m
++CONFIG_PHY_RCAR_GEN2=m
++CONFIG_PHY_ROCKCHIP_USB=m
++CONFIG_PHY_SAMSUNG_USB2=m
++CONFIG_PHY_TUSB1210=m
++CONFIG_PHY_XGENE=y
++# CONFIG_PID_IN_CONTEXTIDR is not set
++CONFIG_PID_NS=y
++CONFIG_PINCONF=y
++CONFIG_PINCTRL=y
++CONFIG_PINCTRL_AMD=y
++CONFIG_PINCTRL_APQ8064=m
++CONFIG_PINCTRL_APQ8084=m
++CONFIG_PINCTRL_ARMADA_370=y
++CONFIG_PINCTRL_ARMADA_375=y
++CONFIG_PINCTRL_ARMADA_38X=y
++CONFIG_PINCTRL_ARMADA_39X=y
++CONFIG_PINCTRL_ARMADA_XP=y
++CONFIG_PINCTRL_AS3722=y
++CONFIG_PINCTRL_BAYTRAIL=y
++CONFIG_PINCTRL_BERLIN=y
++CONFIG_PINCTRL_BERLIN_BG4CT=y
++CONFIG_PINCTRL_BROXTON=m
++CONFIG_PINCTRL_CHERRYVIEW=y
++CONFIG_PINCTRL_DOVE=y
++CONFIG_PINCTRL_EXYNOS=y
++CONFIG_PINCTRL_EXYNOS5440=y
++CONFIG_PINCTRL_IMX=y
++CONFIG_PINCTRL_IMX50=y
++CONFIG_PINCTRL_IMX51=y
++CONFIG_PINCTRL_IMX6Q=y
++CONFIG_PINCTRL_IMX6SL=y
++CONFIG_PINCTRL_IMX6SX=y
++CONFIG_PINCTRL_IMX6UL=y
++CONFIG_PINCTRL_IMX7D=y
++CONFIG_PINCTRL_INTEL=m
++CONFIG_PINCTRL_IPQ8064=m
++CONFIG_PINCTRL_MESON=y
++CONFIG_PINCTRL_MSM=y
++CONFIG_PINCTRL_MSM8660=m
++CONFIG_PINCTRL_MSM8916=m
++CONFIG_PINCTRL_MSM8960=m
++CONFIG_PINCTRL_MSM8X74=m
++CONFIG_PINCTRL_MT6397=y
++CONFIG_PINCTRL_MT8173=y
++CONFIG_PINCTRL_MTK_COMMON=y
++CONFIG_PINCTRL_MVEBU=y
++CONFIG_PINCTRL_PALMAS=y
++CONFIG_PINCTRL_PFC_EMEV2=y
++CONFIG_PINCTRL_PFC_R8A7740=y
++CONFIG_PINCTRL_PFC_R8A7778=y
++CONFIG_PINCTRL_PFC_R8A7779=y
++CONFIG_PINCTRL_PFC_R8A7790=y
++CONFIG_PINCTRL_PFC_R8A7791=y
++CONFIG_PINCTRL_PFC_R8A7793=y
++CONFIG_PINCTRL_PFC_R8A7794=y
++CONFIG_PINCTRL_PFC_SH73A0=y
++CONFIG_PINCTRL_QCOM_SPMI_PMIC=m
++CONFIG_PINCTRL_QCOM_SSBI_PMIC=m
++CONFIG_PINCTRL_QDF2XXX=m
++CONFIG_PINCTRL_ROCKCHIP=y
++CONFIG_PINCTRL_SAMSUNG=y
++CONFIG_PINCTRL_SH_PFC=y
++CONFIG_PINCTRL_SINGLE=y
++CONFIG_PINCTRL_SUNRISEPOINT=m
++CONFIG_PINCTRL_TEGRA=y
++CONFIG_PINCTRL_TEGRA114=y
++CONFIG_PINCTRL_TEGRA124=y
++CONFIG_PINCTRL_TEGRA20=y
++CONFIG_PINCTRL_TEGRA30=y
++CONFIG_PINCTRL_TEGRA_XUSB=y
++CONFIG_PINCTRL_UNIPHIER=y
++CONFIG_PINCTRL_UNIPHIER_PH1_LD4=m
++CONFIG_PINCTRL_UNIPHIER_PH1_LD6B=m
++CONFIG_PINCTRL_UNIPHIER_PH1_PRO4=m
++CONFIG_PINCTRL_UNIPHIER_PH1_PRO5=m
++CONFIG_PINCTRL_UNIPHIER_PH1_SLD8=m
++CONFIG_PINCTRL_UNIPHIER_PROXSTREAM2=m
++CONFIG_PINCTRL_VF610=y
++CONFIG_PINMUX=y
++CONFIG_PJ4B_ERRATA_4742=y
++CONFIG_PKCS7_MESSAGE_PARSER=y
++CONFIG_PKCS7_TEST_KEY=m
++CONFIG_PL310_ERRATA_588369=y
++CONFIG_PL310_ERRATA_727915=y
++CONFIG_PL310_ERRATA_753970=y
++CONFIG_PL310_ERRATA_769419=y
++CONFIG_PL320_MBOX=y
++CONFIG_PL330_DMA=m
++CONFIG_PLATFORM_SI4713=m
++CONFIG_PLAT_ORION=y
++CONFIG_PLAT_SAMSUNG=y
++# CONFIG_PLAT_SPEAR is not set
++CONFIG_PLAT_VERSATILE=y
++CONFIG_PLAT_VERSATILE_CLCD=y
++CONFIG_PLIP=m
++CONFIG_PLX_HERMES=m
++CONFIG_PM=y
++CONFIG_PMAC_APM_EMU=m
++CONFIG_PMAC_BACKLIGHT=y
++CONFIG_PMAC_BACKLIGHT_LEGACY=y
++CONFIG_PMAC_MEDIABAY=y
++CONFIG_PMAC_RACKMETER=m
++CONFIG_PMAC_SMU=y
++CONFIG_PMBUS=m
++CONFIG_PMC_ATOM=y
++CONFIG_PMIC_ADP5520=y
++CONFIG_PMIC_DA903X=y
++CONFIG_PMIC_DA9052=y
++# CONFIG_PMIC_OPREGION is not set
++CONFIG_PM_ADVANCED_DEBUG=y
++# CONFIG_PM_AUTOSLEEP is not set
++CONFIG_PM_CLK=y
++CONFIG_PM_DEVFREQ_EVENT=y
++CONFIG_PM_GENERIC_DOMAINS=y
++CONFIG_PM_GENERIC_DOMAINS_OF=y
++CONFIG_PM_GENERIC_DOMAINS_SLEEP=y
++CONFIG_PM_NOTIFIER_ERROR_INJECT=m
++CONFIG_PM_OPP=y
++CONFIG_PM_RCAR=y
++CONFIG_PM_RMOBILE=y
++CONFIG_PM_SLEEP=y
++CONFIG_PM_SLEEP_DEBUG=y
++CONFIG_PM_SLEEP_SMP=y
++CONFIG_PM_STD_PARTITION=""
++# CONFIG_PM_TEST_SUSPEND is not set
++CONFIG_PM_TRACE=y
++CONFIG_PM_TRACE_RTC=y
++CONFIG_PM_WAKELOCKS_GC=y
++CONFIG_PM_WAKELOCKS_LIMIT=100
++CONFIG_PNFS_BLOCK=m
++CONFIG_PNFS_FILE_LAYOUT=m
++CONFIG_PNFS_FLEXFILE_LAYOUT=m
++CONFIG_PNFS_OBJLAYOUT=m
++CONFIG_PNP=y
++CONFIG_PNPACPI=y
++CONFIG_PNPBIOS=y
++CONFIG_PNPBIOS_PROC_FS=y
++# CONFIG_PNP_DEBUG_MESSAGES is not set
++CONFIG_POSIX_MQUEUE=y
++CONFIG_POSIX_MQUEUE_SYSCTL=y
++# CONFIG_POWER4_CPU is not set
++# CONFIG_POWER5_CPU is not set
++# CONFIG_POWER6_CPU is not set
++# CONFIG_POWER8_CPU is not set
++CONFIG_POWERNV_CPUFREQ=y
++CONFIG_POWERNV_CPUIDLE=y
++CONFIG_POWER_AVS_OMAP=y
++CONFIG_POWER_AVS_OMAP_CLASS3=y
++CONFIG_POWER_RESET=y
++CONFIG_POWER_RESET_AS3722=y
++CONFIG_POWER_RESET_AXXIA=y
++# CONFIG_POWER_RESET_BRCMSTB is not set
++CONFIG_POWER_RESET_GPIO=y
++CONFIG_POWER_RESET_GPIO_RESTART=y
++CONFIG_POWER_RESET_HISI=y
++# CONFIG_POWER_RESET_IMX is not set
++CONFIG_POWER_RESET_LTC2952=y
++CONFIG_POWER_RESET_MSM=y
++# CONFIG_POWER_RESET_QNAP is not set
++CONFIG_POWER_RESET_RESTART=y
++CONFIG_POWER_RESET_RMOBILE=m
++CONFIG_POWER_RESET_SYSCON=y
++CONFIG_POWER_RESET_SYSCON_POWEROFF=y
++CONFIG_POWER_RESET_VERSATILE=y
++CONFIG_POWER_RESET_VEXPRESS=y
++# CONFIG_POWER_RESET_XGENE is not set
++# CONFIG_POWER_SUPPLY_DEBUG is not set
++CONFIG_PPA8548=y
++CONFIG_PPC=y
++CONFIG_PPC32=y
++# CONFIG_PPC601_SYNC_FIX is not set
++CONFIG_PPC64_BOOT_WRAPPER=y
++CONFIG_PPC64_SUPPORTS_MEMORY_FAILURE=y
++# CONFIG_PPC_82xx is not set
++# CONFIG_PPC_83xx is not set
++# CONFIG_PPC_86xx is not set
++# CONFIG_PPC_8xx is not set
++CONFIG_PPC_ADV_DEBUG_DACS=2
++CONFIG_PPC_ADV_DEBUG_DVCS=0
++CONFIG_PPC_ADV_DEBUG_IACS=2
++CONFIG_PPC_ADV_DEBUG_REGS=y
++CONFIG_PPC_BOOK3E=y
++CONFIG_PPC_BOOK3E_MMU=y
++CONFIG_PPC_BOOK3S=y
++# CONFIG_PPC_CELL_NATIVE is not set
++# CONFIG_PPC_CELL_QPACE is not set
++CONFIG_PPC_CHRP=y
++# CONFIG_PPC_DCR_MMIO is not set
++# CONFIG_PPC_DCR_NATIVE is not set
++# CONFIG_PPC_DEBUG_RFI is not set
++CONFIG_PPC_E500MC=y
++# CONFIG_PPC_EARLY_DEBUG is not set
++# CONFIG_PPC_EMULATED_STATS is not set
++CONFIG_PPC_EMULATE_SSTEP=y
++# CONFIG_PPC_EPAPR_HV_BYTECHAN is not set
++CONFIG_PPC_FPU=y
++CONFIG_PPC_FSL_BOOK3E=y
++CONFIG_PPC_HAVE_PMU_SUPPORT=y
++# CONFIG_PPC_IBM_CELL_BLADE is not set
++CONFIG_PPC_ICSWX_PID=y
++# CONFIG_PPC_ICSWX_USE_SIGILL is not set
++CONFIG_PPC_INDIRECT_PIO=y
++CONFIG_PPC_LIB_RHEAP=y
++CONFIG_PPC_MAPLE=y
++CONFIG_PPC_MMU_NOHASH=y
++# CONFIG_PPC_MPC512x is not set
++# CONFIG_PPC_MPC52xx is not set
++CONFIG_PPC_MSI_BITMAP=y
++CONFIG_PPC_NATIVE=y
++# CONFIG_PPC_OF_PLATFORM_PCI is not set
++CONFIG_PPC_PASEMI=y
++CONFIG_PPC_PASEMI_CPUFREQ=y
++CONFIG_PPC_PASEMI_IOMMU=y
++# CONFIG_PPC_PASEMI_IOMMU_DMA_FORCE is not set
++CONFIG_PPC_PASEMI_MDIO=m
++CONFIG_PPC_PCI_CHOICE=y
++CONFIG_PPC_PERF_CTRS=y
++CONFIG_PPC_PMAC=y
++CONFIG_PPC_PMAC32_PSURGE=y
++CONFIG_PPC_PMAC64=y
++CONFIG_PPC_POWERNV=y
++CONFIG_PPC_PS3=y
++CONFIG_PPC_PSERIES=y
++CONFIG_PPC_QEMU_E500=y
++CONFIG_PPC_RTAS_DAEMON=y
++CONFIG_PPC_SCOM=y
++CONFIG_PPC_SMP_MUXED_IPI=y
++CONFIG_PPC_STD_MMU=y
++CONFIG_PPC_STD_MMU_32=y
++CONFIG_PPC_STD_MMU_64=y
++CONFIG_PPC_SUBPAGE_PROT=y
++CONFIG_PPC_TRANSACTIONAL_MEM=y
++CONFIG_PPC_UDBG_16550=y
++CONFIG_PPC_WERROR=y
++CONFIG_PPDEV=m
++CONFIG_PPPOATM=m
++CONFIG_PPPOE=m
++CONFIG_PPPOL2TP=m
++CONFIG_PPP_ASYNC=m
++CONFIG_PPP_BSDCOMP=m
++CONFIG_PPP_DEFLATE=m
++CONFIG_PPP_FILTER=y
++CONFIG_PPP_MPPE=m
++CONFIG_PPP_MULTILINK=y
++CONFIG_PPP_SYNC_TTY=m
++# CONFIG_PPS_CLIENT_KTIMER is not set
++CONFIG_PPS_CLIENT_PARPORT=m
++# CONFIG_PPS_DEBUG is not set
++CONFIG_PPTP=m
++# CONFIG_PQ2ADS is not set
++CONFIG_PREEMPT_COUNT=y
++CONFIG_PREEMPT_NOTIFIERS=y
++CONFIG_PREEMPT_RCU=y
++# CONFIG_PREEMPT_TRACER is not set
++# CONFIG_PRESCAN_RXQ is not set
++CONFIG_PREVENT_FIRMWARE_BUILD=y
++CONFIG_PRINTER=m
++CONFIG_PRINTK=y
++CONFIG_PRINTK_TIME=y
++# CONFIG_PRINT_QUOTA_WARNING is not set
++CONFIG_PRINT_STACK_DEPTH=64
++CONFIG_PRISM2_USB=m
++# CONFIG_PRISM54 is not set
++CONFIG_PROCESSOR_SELECT=y
++CONFIG_PROC_CHILDREN=y
++CONFIG_PROC_EVENTS=y
++CONFIG_PROC_FS=y
++CONFIG_PROC_KCORE=y
++CONFIG_PROC_PAGE_MONITOR=y
++CONFIG_PROC_PID_CPUSET=y
++CONFIG_PROC_SYSCTL=y
++CONFIG_PROC_VMCORE=y
++# CONFIG_PROFILE_ALL_BRANCHES is not set
++# CONFIG_PROFILE_ANNOTATED_BRANCHES is not set
++CONFIG_PROFILING=y
++# CONFIG_PROVE_LOCKING is not set
++# CONFIG_PROVE_RCU is not set
++# CONFIG_PROVIDE_OHCI1394_DMA_INIT is not set
++# CONFIG_PS3GELIC_UDBG is not set
++# CONFIG_PS3_ADVANCED is not set
++CONFIG_PS3_DISK=m
++# CONFIG_PS3_DYNAMIC_DMA is not set
++CONFIG_PS3_FLASH=m
++CONFIG_PS3_HTAB_SIZE=20
++CONFIG_PS3_LPM=m
++CONFIG_PS3_PS3AV=y
++# CONFIG_PS3_REPOSITORY_WRITE is not set
++CONFIG_PS3_ROM=m
++CONFIG_PS3_STORAGE=m
++CONFIG_PS3_SYS_MANAGER=y
++CONFIG_PS3_VRAM=m
++CONFIG_PS3_VUART=y
++CONFIG_PSERIES_CPUIDLE=y
++CONFIG_PSERIES_ENERGY=m
++# CONFIG_PSTORE_FTRACE is not set
++# CONFIG_PSTORE_PMSG is not set
++CONFIG_PTE_64BIT=y
++CONFIG_PTP_1588_CLOCK_GIANFAR=m
++CONFIG_PTP_1588_CLOCK_PCH=m
++CONFIG_PUBLIC_KEY_ALGO_RSA=y
++CONFIG_PUNIT_ATOM_DEBUG=m
++CONFIG_PVPANIC=m
++CONFIG_PWM_ATMEL_HLCDC_PWM=m
++CONFIG_PWM_BERLIN=m
++CONFIG_PWM_CRC=y
++CONFIG_PWM_FSL_FTM=m
++CONFIG_PWM_IMX=m
++CONFIG_PWM_LP3943=m
++CONFIG_PWM_LPSS=m
++CONFIG_PWM_LPSS_PCI=m
++CONFIG_PWM_LPSS_PLATFORM=m
++CONFIG_PWM_MTK_DISP=m
++CONFIG_PWM_OMAP_DMTIMER=m
++CONFIG_PWM_PCA9685=m
++CONFIG_PWM_RCAR=m
++CONFIG_PWM_RENESAS_TPU=m
++CONFIG_PWM_ROCKCHIP=m
++CONFIG_PWM_SAMSUNG=m
++CONFIG_PWM_SYSFS=y
++CONFIG_PWM_TEGRA=m
++CONFIG_PWM_TIECAP=m
++CONFIG_PWM_TIEHRPWM=m
++CONFIG_PWM_TIPWMSS=y
++CONFIG_PWM_TWL=m
++CONFIG_PWM_TWL_LED=m
++CONFIG_PXA168_ETH=m
++CONFIG_QCA7000=m
++CONFIG_QCOM_BAM_DMA=m
++CONFIG_QCOM_COINCELL=m
++CONFIG_QCOM_GDSC=y
++CONFIG_QCOM_GSBI=m
++CONFIG_QCOM_PM=y
++CONFIG_QCOM_QFPROM=m
++CONFIG_QCOM_SCM=y
++CONFIG_QCOM_SCM_32=y
++CONFIG_QCOM_SCM_64=y
++CONFIG_QCOM_SMD=m
++CONFIG_QCOM_SMD_RPM=m
++CONFIG_QCOM_SMEM=m
++CONFIG_QCOM_SPMI_IADC=m
++CONFIG_QCOM_SPMI_TEMP_ALARM=m
++CONFIG_QCOM_SPMI_VADC=m
++CONFIG_QCOM_WDT=m
++CONFIG_QDIO=m
++CONFIG_QED=m
++CONFIG_QEDE=m
++CONFIG_QETH=m
++CONFIG_QETH_IPV6=y
++CONFIG_QETH_L2=m
++CONFIG_QETH_L3=m
++CONFIG_QE_USB=y
++CONFIG_QFMT_V1=m
++CONFIG_QFMT_V2=m
++CONFIG_QLA3XXX=m
++CONFIG_QLCNIC=m
++CONFIG_QLCNIC_DCB=y
++CONFIG_QLCNIC_HWMON=y
++CONFIG_QLCNIC_SRIOV=y
++CONFIG_QLCNIC_VXLAN=y
++CONFIG_QLGE=m
++# CONFIG_QNX6FS_DEBUG is not set
++CONFIG_QORIQ_CPUFREQ=m
++CONFIG_QSEMI_PHY=m
++CONFIG_QUEUED_RWLOCKS=y
++CONFIG_QUEUED_SPINLOCKS=y
++# CONFIG_QUICC_ENGINE is not set
++CONFIG_QUOTA=y
++CONFIG_QUOTACTL=y
++CONFIG_QUOTACTL_COMPAT=y
++# CONFIG_QUOTA_DEBUG is not set
++CONFIG_QUOTA_NETLINK_INTERFACE=y
++CONFIG_QUOTA_TREE=m
++CONFIG_R6040=m
++CONFIG_R8169=m
++CONFIG_R8188EU=m
++CONFIG_R8712U=m
++CONFIG_R8723AU=m
++CONFIG_RADIO_ADAPTERS=y
++CONFIG_RADIO_AZTECH=m
++CONFIG_RADIO_CADET=m
++CONFIG_RADIO_GEMTEK=m
++CONFIG_RADIO_ISA=m
++CONFIG_RADIO_MAXIRADIO=m
++CONFIG_RADIO_MIROPCM20=m
++CONFIG_RADIO_RTRACK=m
++CONFIG_RADIO_RTRACK2=m
++CONFIG_RADIO_SAA7706H=m
++CONFIG_RADIO_SF16FMI=m
++CONFIG_RADIO_SF16FMR2=m
++CONFIG_RADIO_SHARK=m
++CONFIG_RADIO_SHARK2=m
++CONFIG_RADIO_SI470X=y
++CONFIG_RADIO_SI4713=m
++CONFIG_RADIO_SI476X=m
++CONFIG_RADIO_TEA575X=m
++CONFIG_RADIO_TEA5764=m
++CONFIG_RADIO_TEF6862=m
++CONFIG_RADIO_TERRATEC=m
++CONFIG_RADIO_TIMBERDALE=m
++CONFIG_RADIO_TRUST=m
++CONFIG_RADIO_TYPHOON=m
++CONFIG_RADIO_WL1273=m
++CONFIG_RADIO_WL128X=m
++CONFIG_RADIO_ZOLTRIX=m
++CONFIG_RAID6_PQ=m
++CONFIG_RAID_ATTRS=m
++# CONFIG_RANDOM32_SELFTEST is not set
++CONFIG_RANDOMIZE_BASE=y
++CONFIG_RAPIDIO=y
++CONFIG_RAPIDIO_CPS_GEN2=m
++CONFIG_RAPIDIO_CPS_XX=m
++# CONFIG_RAPIDIO_DEBUG is not set
++CONFIG_RAPIDIO_DISC_TIMEOUT=30
++CONFIG_RAPIDIO_DMA_ENGINE=y
++# CONFIG_RAPIDIO_ENABLE_RX_TX_PORTS is not set
++CONFIG_RAPIDIO_ENUM_BASIC=m
++CONFIG_RAPIDIO_TSI568=m
++CONFIG_RAPIDIO_TSI57X=m
++CONFIG_RAPIDIO_TSI721=m
++CONFIG_RAS=y
++CONFIG_RATIONAL=y
++CONFIG_RAVB=m
++CONFIG_RBTREE_TEST=m
++CONFIG_RCAR_DMAC=m
++CONFIG_RCAR_HPB_DMAE=m
++CONFIG_RCAR_THERMAL=m
++# CONFIG_RCU_EQS_DEBUG is not set
++# CONFIG_RCU_EXPEDITE_BOOT is not set
++# CONFIG_RCU_EXPERT is not set
++CONFIG_RCU_STALL_COMMON=y
++# CONFIG_RCU_TORTURE_TEST is not set
++# CONFIG_RCU_TRACE is not set
++CONFIG_RC_ATI_REMOTE=m
++CONFIG_RC_CORE=m
++CONFIG_RC_DECODERS=y
++CONFIG_RC_DEVICES=y
++CONFIG_RC_LOOPBACK=m
++CONFIG_RC_MAP=m
++CONFIG_RDS=m
++# CONFIG_RDS_DEBUG is not set
++CONFIG_RDS_RDMA=m
++CONFIG_RDS_TCP=m
++CONFIG_RD_BZIP2=y
++CONFIG_RD_GZIP=y
++CONFIG_RD_LZ4=y
++CONFIG_RD_LZMA=y
++CONFIG_RD_LZO=y
++CONFIG_RD_XZ=y
++# CONFIG_READABLE_ASM is not set
++CONFIG_REALTEK_AUTOPM=y
++CONFIG_REALTEK_PHY=m
++CONFIG_REED_SOLOMON_DEC16=y
++CONFIG_REED_SOLOMON_DEC8=y
++CONFIG_REED_SOLOMON_ENC8=y
++CONFIG_REGMAP=y
++CONFIG_REGMAP_I2C=y
++CONFIG_REGMAP_IRQ=y
++CONFIG_REGMAP_MMIO=y
++CONFIG_REGMAP_SPI=y
++CONFIG_REGMAP_SPMI=m
++CONFIG_REGULATOR_88PM800=m
++CONFIG_REGULATOR_88PM8607=m
++CONFIG_REGULATOR_AAT2870=m
++CONFIG_REGULATOR_AB3100=m
++CONFIG_REGULATOR_ACT8865=m
++CONFIG_REGULATOR_AD5398=m
++CONFIG_REGULATOR_ANATOP=m
++CONFIG_REGULATOR_ARIZONA=m
++CONFIG_REGULATOR_AS3711=m
++CONFIG_REGULATOR_AS3722=m
++CONFIG_REGULATOR_AXP20X=m
++CONFIG_REGULATOR_BCM590XX=m
++CONFIG_REGULATOR_DA903X=m
++CONFIG_REGULATOR_DA9052=m
++CONFIG_REGULATOR_DA9055=m
++CONFIG_REGULATOR_DA9062=m
++CONFIG_REGULATOR_DA9063=m
++CONFIG_REGULATOR_DA9210=m
++CONFIG_REGULATOR_DA9211=m
++# CONFIG_REGULATOR_DEBUG is not set
++CONFIG_REGULATOR_FAN53555=m
++CONFIG_REGULATOR_GPIO=m
++CONFIG_REGULATOR_HI6421=m
++CONFIG_REGULATOR_ISL6271A=m
++CONFIG_REGULATOR_ISL9305=m
++CONFIG_REGULATOR_LP3971=m
++CONFIG_REGULATOR_LP3972=m
++CONFIG_REGULATOR_LP872X=m
++CONFIG_REGULATOR_LP8755=m
++CONFIG_REGULATOR_LP8788=m
++CONFIG_REGULATOR_LTC3589=m
++CONFIG_REGULATOR_MAX14577=m
++CONFIG_REGULATOR_MAX1586=m
++CONFIG_REGULATOR_MAX77686=m
++CONFIG_REGULATOR_MAX77693=m
++CONFIG_REGULATOR_MAX77802=m
++CONFIG_REGULATOR_MAX8649=m
++CONFIG_REGULATOR_MAX8660=m
++CONFIG_REGULATOR_MAX8907=m
++CONFIG_REGULATOR_MAX8925=m
++CONFIG_REGULATOR_MAX8952=m
++CONFIG_REGULATOR_MAX8973=m
++CONFIG_REGULATOR_MAX8997=m
++CONFIG_REGULATOR_MAX8998=m
++CONFIG_REGULATOR_MC13783=m
++CONFIG_REGULATOR_MC13892=m
++CONFIG_REGULATOR_MC13XXX_CORE=m
++CONFIG_REGULATOR_MT6311=m
++CONFIG_REGULATOR_MT6397=m
++CONFIG_REGULATOR_PALMAS=m
++CONFIG_REGULATOR_PBIAS=m
++CONFIG_REGULATOR_PCAP=m
++CONFIG_REGULATOR_PCF50633=m
++CONFIG_REGULATOR_PFUZE100=m
++CONFIG_REGULATOR_PWM=m
++CONFIG_REGULATOR_QCOM_RPM=m
++CONFIG_REGULATOR_QCOM_SMD_RPM=m
++CONFIG_REGULATOR_QCOM_SPMI=m
++CONFIG_REGULATOR_RC5T583=m
++CONFIG_REGULATOR_RK808=m
++CONFIG_REGULATOR_RN5T618=m
++CONFIG_REGULATOR_RT5033=m
++CONFIG_REGULATOR_S2MPA01=m
++CONFIG_REGULATOR_S2MPS11=m
++CONFIG_REGULATOR_S5M8767=m
++CONFIG_REGULATOR_SKY81452=m
++CONFIG_REGULATOR_TI_ABB=y
++CONFIG_REGULATOR_TPS51632=m
++CONFIG_REGULATOR_TPS6105X=m
++CONFIG_REGULATOR_TPS62360=m
++CONFIG_REGULATOR_TPS65023=m
++CONFIG_REGULATOR_TPS6507X=m
++CONFIG_REGULATOR_TPS65090=m
++CONFIG_REGULATOR_TPS65217=y
++CONFIG_REGULATOR_TPS65218=m
++CONFIG_REGULATOR_TPS6524X=m
++CONFIG_REGULATOR_TPS6586X=m
++CONFIG_REGULATOR_TPS65910=m
++CONFIG_REGULATOR_TPS65912=m
++CONFIG_REGULATOR_TPS80031=m
++CONFIG_REGULATOR_USERSPACE_CONSUMER=m
++CONFIG_REGULATOR_VEXPRESS=m
++CONFIG_REGULATOR_VIRTUAL_CONSUMER=m
++CONFIG_REGULATOR_WM831X=m
++CONFIG_REGULATOR_WM8350=m
++CONFIG_REGULATOR_WM8400=m
++CONFIG_REGULATOR_WM8994=m
++# CONFIG_REISERFS_CHECK is not set
++CONFIG_REISERFS_FS_POSIX_ACL=y
++CONFIG_REISERFS_FS_SECURITY=y
++CONFIG_REISERFS_FS_XATTR=y
++# CONFIG_REISERFS_PROC_INFO is not set
++CONFIG_RELAY=y
++CONFIG_RELOCATABLE=y
++CONFIG_REMOTEPROC=m
++CONFIG_RENESAS_DMA=y
++CONFIG_RENESAS_INTC_IRQPIN=y
++CONFIG_RENESAS_IRQC=y
++CONFIG_RENESAS_USB_DMAC=m
++CONFIG_RETU_WATCHDOG=m
++CONFIG_RFD_FTL=m
++CONFIG_RFKILL_GPIO=m
++CONFIG_RFKILL_INPUT=y
++CONFIG_RFKILL_LEDS=y
++CONFIG_RFKILL_REGULATOR=m
++CONFIG_RFS_ACCEL=y
++CONFIG_RING_BUFFER=y
++CONFIG_RING_BUFFER_ALLOW_SWAP=y
++# CONFIG_RING_BUFFER_BENCHMARK is not set
++# CONFIG_RING_BUFFER_STARTUP_TEST is not set
++CONFIG_RIONET=m
++CONFIG_RIONET_RX_SIZE=128
++CONFIG_RIONET_TX_SIZE=128
++CONFIG_RN5T618_WATCHDOG=m
++CONFIG_ROCKCHIP_DW_HDMI=m
++CONFIG_ROCKCHIP_EFUSE=m
++CONFIG_ROCKCHIP_IODOMAIN=m
++CONFIG_ROCKCHIP_IOMMU=y
++CONFIG_ROCKCHIP_PM_DOMAINS=y
++CONFIG_ROCKCHIP_SARADC=m
++CONFIG_ROCKCHIP_THERMAL=m
++CONFIG_ROCKCHIP_TIMER=y
++CONFIG_ROCKETPORT=m
++CONFIG_ROMFS_BACKED_BY_BLOCK=y
++# CONFIG_ROMFS_BACKED_BY_BOTH is not set
++# CONFIG_ROMFS_BACKED_BY_MTD is not set
++CONFIG_ROMFS_ON_BLOCK=y
++CONFIG_ROSE=m
++CONFIG_RPCSEC_GSS_KRB5=m
++CONFIG_RPMSG=m
++CONFIG_RPR0521=m
++CONFIG_RPS=y
++CONFIG_RSI_91X=m
++# CONFIG_RSI_DEBUGFS is not set
++CONFIG_RSI_SDIO=m
++CONFIG_RSI_USB=m
++CONFIG_RT2400PCI=m
++CONFIG_RT2500PCI=m
++CONFIG_RT2500USB=m
++CONFIG_RT2800PCI=m
++CONFIG_RT2800PCI_RT3290=y
++CONFIG_RT2800PCI_RT33XX=y
++CONFIG_RT2800PCI_RT35XX=y
++CONFIG_RT2800PCI_RT53XX=y
++CONFIG_RT2800USB=m
++CONFIG_RT2800USB_RT33XX=y
++CONFIG_RT2800USB_RT3573=y
++CONFIG_RT2800USB_RT35XX=y
++CONFIG_RT2800USB_RT53XX=y
++CONFIG_RT2800USB_RT55XX=y
++CONFIG_RT2800USB_UNKNOWN=y
++CONFIG_RT2800_LIB=m
++CONFIG_RT2800_LIB_MMIO=m
++CONFIG_RT2X00=m
++# CONFIG_RT2X00_DEBUG is not set
++CONFIG_RT2X00_LIB=m
++CONFIG_RT2X00_LIB_CRYPTO=y
++# CONFIG_RT2X00_LIB_DEBUGFS is not set
++CONFIG_RT2X00_LIB_FIRMWARE=y
++CONFIG_RT2X00_LIB_LEDS=y
++CONFIG_RT2X00_LIB_MMIO=m
++CONFIG_RT2X00_LIB_PCI=m
++CONFIG_RT2X00_LIB_USB=m
++CONFIG_RT61PCI=m
++CONFIG_RT73USB=m
++CONFIG_RTAS_ERROR_LOGGING=y
++CONFIG_RTAS_FLASH=m
++CONFIG_RTAS_PROC=y
++CONFIG_RTC_CLASS=y
++# CONFIG_RTC_DEBUG is not set
++CONFIG_RTC_DRV_88PM80X=m
++CONFIG_RTC_DRV_88PM860X=m
++CONFIG_RTC_DRV_AB3100=m
++CONFIG_RTC_DRV_ABB5ZES3=m
++CONFIG_RTC_DRV_ABX80X=m
++CONFIG_RTC_DRV_ARMADA38X=m
++CONFIG_RTC_DRV_AS3722=m
++CONFIG_RTC_DRV_BQ32K=m
++CONFIG_RTC_DRV_BQ4802=m
++CONFIG_RTC_DRV_DA9052=m
++CONFIG_RTC_DRV_DA9055=m
++CONFIG_RTC_DRV_DA9063=m
++CONFIG_RTC_DRV_DS1286=m
++CONFIG_RTC_DRV_DS1305=m
++CONFIG_RTC_DRV_DS1307=m
++CONFIG_RTC_DRV_DS1343=m
++CONFIG_RTC_DRV_DS1347=m
++CONFIG_RTC_DRV_DS1374=m
++CONFIG_RTC_DRV_DS1374_WDT=y
++CONFIG_RTC_DRV_DS1390=m
++CONFIG_RTC_DRV_DS1511=m
++CONFIG_RTC_DRV_DS1553=m
++CONFIG_RTC_DRV_DS1672=m
++CONFIG_RTC_DRV_DS1685=y
++CONFIG_RTC_DRV_DS1685_FAMILY=m
++# CONFIG_RTC_DRV_DS1689 is not set
++# CONFIG_RTC_DRV_DS17285 is not set
++CONFIG_RTC_DRV_DS1742=m
++# CONFIG_RTC_DRV_DS17485 is not set
++# CONFIG_RTC_DRV_DS17885 is not set
++CONFIG_RTC_DRV_DS2404=m
++CONFIG_RTC_DRV_DS3234=m
++CONFIG_RTC_DRV_EFI=y
++CONFIG_RTC_DRV_EM3027=m
++CONFIG_RTC_DRV_FM3130=m
++CONFIG_RTC_DRV_GENERIC=m
++CONFIG_RTC_DRV_HID_SENSOR_TIME=m
++CONFIG_RTC_DRV_HYM8563=m
++CONFIG_RTC_DRV_IMXDI=m
++CONFIG_RTC_DRV_ISL12022=m
++CONFIG_RTC_DRV_ISL12057=m
++CONFIG_RTC_DRV_ISL1208=m
++CONFIG_RTC_DRV_LP8788=m
++CONFIG_RTC_DRV_M41T80=m
++CONFIG_RTC_DRV_M41T80_WDT=y
++CONFIG_RTC_DRV_M41T93=m
++CONFIG_RTC_DRV_M41T94=m
++CONFIG_RTC_DRV_M48T35=m
++CONFIG_RTC_DRV_M48T59=m
++CONFIG_RTC_DRV_M48T86=m
++CONFIG_RTC_DRV_MAX6900=m
++CONFIG_RTC_DRV_MAX6902=m
++CONFIG_RTC_DRV_MAX77686=m
++CONFIG_RTC_DRV_MAX77802=m
++CONFIG_RTC_DRV_MAX8907=m
++CONFIG_RTC_DRV_MAX8925=m
++CONFIG_RTC_DRV_MAX8997=m
++CONFIG_RTC_DRV_MAX8998=m
++CONFIG_RTC_DRV_MC13XXX=m
++CONFIG_RTC_DRV_MCP795=m
++CONFIG_RTC_DRV_MSM6242=m
++CONFIG_RTC_DRV_MT6397=m
++CONFIG_RTC_DRV_MV=y
++CONFIG_RTC_DRV_MXC=m
++CONFIG_RTC_DRV_OMAP=y
++CONFIG_RTC_DRV_OPAL=y
++CONFIG_RTC_DRV_PALMAS=m
++CONFIG_RTC_DRV_PCAP=m
++CONFIG_RTC_DRV_PCF2123=m
++CONFIG_RTC_DRV_PCF2127=m
++CONFIG_RTC_DRV_PCF50633=m
++CONFIG_RTC_DRV_PCF85063=m
++CONFIG_RTC_DRV_PCF8563=m
++CONFIG_RTC_DRV_PCF8583=m
++CONFIG_RTC_DRV_PL030=m
++CONFIG_RTC_DRV_PM8XXX=m
++CONFIG_RTC_DRV_PS3=m
++CONFIG_RTC_DRV_R9701=m
++CONFIG_RTC_DRV_RC5T583=m
++CONFIG_RTC_DRV_RK808=m
++CONFIG_RTC_DRV_RP5C01=m
++CONFIG_RTC_DRV_RS5C348=m
++CONFIG_RTC_DRV_RS5C372=m
++CONFIG_RTC_DRV_RV3029C2=m
++CONFIG_RTC_DRV_RV8803=m
++CONFIG_RTC_DRV_RX4581=m
++CONFIG_RTC_DRV_RX8025=m
++CONFIG_RTC_DRV_RX8581=m
++CONFIG_RTC_DRV_S35390A=m
++CONFIG_RTC_DRV_S3C=y
++CONFIG_RTC_DRV_S5M=m
++CONFIG_RTC_DRV_SNVS=m
++CONFIG_RTC_DRV_STK17TA8=m
++CONFIG_RTC_DRV_TEGRA=m
++# CONFIG_RTC_DRV_TEST is not set
++CONFIG_RTC_DRV_TPS6586X=m
++CONFIG_RTC_DRV_TPS65910=m
++CONFIG_RTC_DRV_TPS80031=m
++CONFIG_RTC_DRV_V3020=m
++CONFIG_RTC_DRV_VRTC=m
++CONFIG_RTC_DRV_WM831X=m
++CONFIG_RTC_DRV_WM8350=m
++CONFIG_RTC_DRV_X1205=m
++CONFIG_RTC_DRV_XGENE=y
++CONFIG_RTC_DRV_ZYNQMP=m
++# CONFIG_RTC_DS1685_PROC_REGS is not set
++# CONFIG_RTC_DS1685_SYSFS_REGS is not set
++CONFIG_RTC_HCTOSYS=y
++CONFIG_RTC_HCTOSYS_DEVICE="rtc0"
++CONFIG_RTC_INTF_DEV=y
++# CONFIG_RTC_INTF_DEV_UIE_EMUL is not set
++CONFIG_RTC_INTF_PROC=y
++CONFIG_RTC_INTF_SYSFS=y
++CONFIG_RTC_LIB=y
++CONFIG_RTC_SYSTOHC=y
++CONFIG_RTC_SYSTOHC_DEVICE="rtc0"
++CONFIG_RTL8180=m
++CONFIG_RTL8187=m
++CONFIG_RTL8187_LEDS=y
++CONFIG_RTL8188EE=m
++CONFIG_RTL8192CE=m
++CONFIG_RTL8192CU=m
++CONFIG_RTL8192C_COMMON=m
++CONFIG_RTL8192DE=m
++CONFIG_RTL8192E=m
++CONFIG_RTL8192EE=m
++CONFIG_RTL8192SE=m
++CONFIG_RTL8192U=m
++CONFIG_RTL8723AE=m
++CONFIG_RTL8723BE=m
++CONFIG_RTL8723_COMMON=m
++CONFIG_RTL8821AE=m
++CONFIG_RTL8XXXU=m
++CONFIG_RTL8XXXU_UNTESTED=y
++CONFIG_RTLBTCOEXIST=m
++CONFIG_RTLLIB=m
++CONFIG_RTLLIB_CRYPTO_CCMP=m
++CONFIG_RTLLIB_CRYPTO_TKIP=m
++CONFIG_RTLLIB_CRYPTO_WEP=m
++CONFIG_RTLWIFI=m
++# CONFIG_RTLWIFI_DEBUG is not set
++CONFIG_RTLWIFI_PCI=m
++CONFIG_RTLWIFI_USB=m
++CONFIG_RTL_CARDS=m
++CONFIG_RTS5208=m
++# CONFIG_RT_GROUP_SCHED is not set
++CONFIG_RT_MUTEXES=y
++CONFIG_RWSEM_SPIN_ON_OWNER=y
++CONFIG_RWSEM_XCHGADD_ALGORITHM=y
++CONFIG_RXKAD=m
++CONFIG_S2IO=m
++CONFIG_S390=y
++CONFIG_S390_GUEST=y
++CONFIG_S390_HYPFS_FS=y
++CONFIG_S390_IOMMU=y
++CONFIG_S390_PRNG=m
++CONFIG_S390_PTDUMP=y
++CONFIG_S390_TAPE=m
++CONFIG_S390_TAPE_34XX=m
++CONFIG_S390_TAPE_3590=m
++CONFIG_S390_VMUR=m
++CONFIG_S3C2410_WATCHDOG=m
++CONFIG_S5P_DEV_MFC=y
++# CONFIG_SAMPLES is not set
++CONFIG_SAMSUNG_LAPTOP=m
++# CONFIG_SAMSUNG_PM_CHECK is not set
++CONFIG_SAMSUNG_Q10=m
++CONFIG_SATA_ACARD_AHCI=m
++CONFIG_SATA_AHCI=m
++CONFIG_SATA_FSL=m
++CONFIG_SATA_HIGHBANK=y
++CONFIG_SATA_INIC162X=m
++CONFIG_SATA_MV=m
++CONFIG_SATA_NV=m
++CONFIG_SATA_PMP=y
++CONFIG_SATA_PROMISE=m
++CONFIG_SATA_QSTOR=m
++CONFIG_SATA_RCAR=m
++CONFIG_SATA_SIL=m
++CONFIG_SATA_SIL24=m
++CONFIG_SATA_SIS=m
++CONFIG_SATA_SX4=m
++CONFIG_SATA_ULI=m
++CONFIG_SATA_VIA=m
++CONFIG_SATA_VITESSE=m
++CONFIG_SATA_ZPODD=y
++CONFIG_SBC7240_WDT=m
++CONFIG_SBC8360_WDT=m
++# CONFIG_SBC8548 is not set
++CONFIG_SBC_EPX_C3_WATCHDOG=m
++CONFIG_SBC_FITPC2_WATCHDOG=m
++CONFIG_SBNI=m
++# CONFIG_SBNI_MULTILINE is not set
++CONFIG_SBP_TARGET=m
++CONFIG_SC1200_WDT=m
++CONFIG_SC92031=m
++CONFIG_SCA3000=m
++CONFIG_SCANLOG=m
++CONFIG_SCC=m
++# CONFIG_SCC_DELAY is not set
++# CONFIG_SCC_TRXECHO is not set
++CONFIG_SCHEDSTATS=y
++CONFIG_SCHED_AUTOGROUP=y
++CONFIG_SCHED_BOOK=y
++CONFIG_SCHED_DEBUG=y
++CONFIG_SCHED_HRTICK=y
++CONFIG_SCHED_INFO=y
++CONFIG_SCHED_MC=y
++CONFIG_SCHED_OMIT_FRAME_POINTER=y
++CONFIG_SCHED_STACK_END_CHECK=y
++CONFIG_SCHED_TOPOLOGY=y
++CONFIG_SCHED_TRACER=y
++CONFIG_SCIF=m
++CONFIG_SCIF_BUS=m
++CONFIG_SCLP_ASYNC=m
++CONFIG_SCLP_ASYNC_ID="000000000"
++CONFIG_SCLP_CONSOLE=y
++CONFIG_SCLP_CPI=m
++CONFIG_SCLP_TTY=y
++CONFIG_SCLP_VT220_CONSOLE=y
++CONFIG_SCLP_VT220_TTY=y
++CONFIG_SCM_BLOCK=m
++CONFIG_SCM_BLOCK_CLUSTER_WRITE=y
++CONFIG_SCM_BUS=y
++CONFIG_SCOM_DEBUGFS=y
++CONFIG_SCSI=y
++CONFIG_SCSI_7000FASST=m
++CONFIG_SCSI_AHA152X=m
++CONFIG_SCSI_AHA1542=m
++CONFIG_SCSI_AHA1740=m
++CONFIG_SCSI_BUSLOGIC=m
++CONFIG_SCSI_CONSTANTS=y
++CONFIG_SCSI_DEBUG=m
++CONFIG_SCSI_DH=y
++CONFIG_SCSI_DH_ALUA=m
++CONFIG_SCSI_DH_EMC=m
++CONFIG_SCSI_DH_HP_SW=m
++CONFIG_SCSI_DH_RDAC=m
++CONFIG_SCSI_DMA=y
++CONFIG_SCSI_DTC3280=m
++CONFIG_SCSI_EATA=m
++CONFIG_SCSI_EATA_LINKED_COMMANDS=y
++CONFIG_SCSI_EATA_MAX_TAGS=16
++CONFIG_SCSI_EATA_TAGGED_QUEUE=y
++CONFIG_SCSI_ENCLOSURE=m
++CONFIG_SCSI_FC_ATTRS=m
++CONFIG_SCSI_FLASHPOINT=y
++CONFIG_SCSI_GDTH=m
++CONFIG_SCSI_GENERIC_NCR5380=m
++CONFIG_SCSI_GENERIC_NCR5380_MMIO=m
++CONFIG_SCSI_GENERIC_NCR53C400=y
++CONFIG_SCSI_IBMVFC=m
++CONFIG_SCSI_IBMVFC_TRACE=y
++CONFIG_SCSI_IBMVSCSI=m
++CONFIG_SCSI_IBMVSCSIS=m
++CONFIG_SCSI_IMM=m
++CONFIG_SCSI_IN2000=m
++CONFIG_SCSI_IPR=m
++CONFIG_SCSI_IPR_DUMP=y
++CONFIG_SCSI_IPR_TRACE=y
++CONFIG_SCSI_ISCI=m
++CONFIG_SCSI_ISCSI_ATTRS=m
++# CONFIG_SCSI_IZIP_EPP16 is not set
++# CONFIG_SCSI_IZIP_SLOW_CTR is not set
++CONFIG_SCSI_LOGGING=y
++CONFIG_SCSI_LOWLEVEL=y
++CONFIG_SCSI_LOWLEVEL_PCMCIA=y
++# CONFIG_SCSI_LPFC_DEBUG_FS is not set
++CONFIG_SCSI_MAC53C94=m
++CONFIG_SCSI_MESH=m
++CONFIG_SCSI_MESH_RESET_DELAY_MS=4000
++CONFIG_SCSI_MESH_SYNC_RATE=5
++CONFIG_SCSI_MOD=y
++CONFIG_SCSI_MPT2SAS=m
++CONFIG_SCSI_MPT2SAS_MAX_SGE=128
++CONFIG_SCSI_MPT3SAS=m
++CONFIG_SCSI_MPT3SAS_MAX_SGE=128
++# CONFIG_SCSI_MQ_DEFAULT is not set
++# CONFIG_SCSI_MVSAS_DEBUG is not set
++# CONFIG_SCSI_MVSAS_TASKLET is not set
++CONFIG_SCSI_NCR53C406A=m
++CONFIG_SCSI_NETLINK=y
++CONFIG_SCSI_NSP32=m
++# CONFIG_SCSI_OSD_DEBUG is not set
++CONFIG_SCSI_OSD_DPRINT_SENSE=1
++CONFIG_SCSI_OSD_INITIATOR=m
++CONFIG_SCSI_OSD_ULD=m
++CONFIG_SCSI_PAS16=m
++CONFIG_SCSI_PPA=m
++CONFIG_SCSI_PROC_FS=y
++CONFIG_SCSI_QLOGIC_FAS=m
++CONFIG_SCSI_SAS_ATA=y
++CONFIG_SCSI_SAS_ATTRS=m
++CONFIG_SCSI_SAS_HOST_SMP=y
++CONFIG_SCSI_SAS_LIBSAS=m
++CONFIG_SCSI_SCAN_ASYNC=y
++CONFIG_SCSI_SIM710=m
++# CONFIG_SCSI_SNIC_DEBUG_FS is not set
++CONFIG_SCSI_SPI_ATTRS=m
++CONFIG_SCSI_SYM53C416=m
++CONFIG_SCSI_SYM53C8XX_DEFAULT_TAGS=16
++CONFIG_SCSI_SYM53C8XX_DMA_ADDRESSING_MODE=1
++CONFIG_SCSI_SYM53C8XX_MAX_TAGS=64
++CONFIG_SCSI_SYM53C8XX_MMIO=y
++CONFIG_SCSI_T128=m
++CONFIG_SCSI_U14_34F=m
++CONFIG_SCSI_U14_34F_LINKED_COMMANDS=y
++CONFIG_SCSI_U14_34F_MAX_TAGS=8
++CONFIG_SCSI_U14_34F_TAGGED_QUEUE=y
++CONFIG_SCSI_UFSHCD_PCI=m
++CONFIG_SCSI_UFSHCD_PLATFORM=m
++# CONFIG_SCSI_UFS_QCOM is not set
++CONFIG_SCSI_ULTRASTOR=m
++CONFIG_SCSI_VIRTIO=m
++CONFIG_SCTP_COOKIE_HMAC_MD5=y
++CONFIG_SCTP_COOKIE_HMAC_SHA1=y
++# CONFIG_SCTP_DBG_OBJCNT is not set
++# CONFIG_SCTP_DEFAULT_COOKIE_HMAC_MD5 is not set
++# CONFIG_SCTP_DEFAULT_COOKIE_HMAC_NONE is not set
++CONFIG_SCTP_DEFAULT_COOKIE_HMAC_SHA1=y
++CONFIG_SCx200=m
++CONFIG_SCx200HR_TIMER=m
++CONFIG_SCx200_ACB=m
++CONFIG_SCx200_GPIO=m
++CONFIG_SCx200_WDT=m
++CONFIG_SDIO_UART=m
++CONFIG_SDLA=m
++# CONFIG_SDMA_VERBOSITY is not set
++CONFIG_SEALEVEL_4021=m
++CONFIG_SECCOMP=y
++CONFIG_SECCOMP_FILTER=y
++CONFIG_SECTION_MISMATCH_WARN_ONLY=y
++CONFIG_SECURITY=y
++CONFIG_SECURITYFS=y
++CONFIG_SECURITY_APPARMOR=y
++CONFIG_SECURITY_APPARMOR_BOOTPARAM_VALUE=1
++CONFIG_SECURITY_APPARMOR_HASH=y
++CONFIG_SECURITY_APPARMOR_HASH_DEFAULT=y
++# CONFIG_SECURITY_APPARMOR_STATS is not set
++CONFIG_SECURITY_APPARMOR_UNCONFINED_INIT=y
++# CONFIG_SECURITY_DMESG_RESTRICT is not set
++CONFIG_SECURITY_NETWORK=y
++CONFIG_SECURITY_NETWORK_XFRM=y
++CONFIG_SECURITY_PATH=y
++CONFIG_SECURITY_SELINUX=y
++CONFIG_SECURITY_SELINUX_AVC_STATS=y
++CONFIG_SECURITY_SELINUX_BOOTPARAM_VALUE=0
++CONFIG_SECURITY_SELINUX_CHECKREQPROT_VALUE=1
++CONFIG_SECURITY_SELINUX_DEVELOP=y
++# CONFIG_SECURITY_SELINUX_POLICYDB_VERSION_MAX is not set
++CONFIG_SECURITY_SMACK=y
++# CONFIG_SECURITY_SMACK_BRINGUP is not set
++CONFIG_SECURITY_SMACK_NETFILTER=y
++CONFIG_SECURITY_TOMOYO=y
++CONFIG_SECURITY_TOMOYO_ACTIVATION_TRIGGER="/sbin/init"
++CONFIG_SECURITY_TOMOYO_MAX_ACCEPT_ENTRY=2048
++CONFIG_SECURITY_TOMOYO_MAX_AUDIT_LOG=1024
++# CONFIG_SECURITY_TOMOYO_OMIT_USERSPACE_LOADER is not set
++CONFIG_SECURITY_TOMOYO_POLICY_LOADER="/sbin/tomoyo-init"
++CONFIG_SECURITY_YAMA=y
++CONFIG_SELECT_MEMORY_MODEL=y
++CONFIG_SENSORS_ABITUGURU=m
++CONFIG_SENSORS_ABITUGURU3=m
++CONFIG_SENSORS_ACPI_POWER=m
++CONFIG_SENSORS_AD7314=m
++CONFIG_SENSORS_AD7414=m
++CONFIG_SENSORS_AD7418=m
++CONFIG_SENSORS_ADC128D818=m
++CONFIG_SENSORS_ADCXX=m
++CONFIG_SENSORS_ADM1021=m
++CONFIG_SENSORS_ADM1025=m
++CONFIG_SENSORS_ADM1026=m
++CONFIG_SENSORS_ADM1029=m
++CONFIG_SENSORS_ADM1031=m
++CONFIG_SENSORS_ADM1275=m
++CONFIG_SENSORS_ADM9240=m
++CONFIG_SENSORS_ADS1015=m
++CONFIG_SENSORS_ADS7828=m
++CONFIG_SENSORS_ADS7871=m
++CONFIG_SENSORS_ADT7310=m
++CONFIG_SENSORS_ADT7410=m
++CONFIG_SENSORS_ADT7411=m
++CONFIG_SENSORS_ADT7462=m
++CONFIG_SENSORS_ADT7470=m
++CONFIG_SENSORS_ADT7475=m
++CONFIG_SENSORS_ADT7X10=m
++CONFIG_SENSORS_AMC6821=m
++CONFIG_SENSORS_AMS=m
++# CONFIG_SENSORS_AMS_I2C is not set
++# CONFIG_SENSORS_AMS_PMU is not set
++CONFIG_SENSORS_APDS990X=m
++CONFIG_SENSORS_APPLESMC=m
++CONFIG_SENSORS_ARM_SCPI=m
++CONFIG_SENSORS_ASB100=m
++CONFIG_SENSORS_ASC7621=m
++CONFIG_SENSORS_ATK0110=m
++CONFIG_SENSORS_ATXP1=m
++CONFIG_SENSORS_BH1770=m
++CONFIG_SENSORS_BH1780=m
++CONFIG_SENSORS_CORETEMP=m
++CONFIG_SENSORS_DA9052_ADC=m
++CONFIG_SENSORS_DA9055=m
++CONFIG_SENSORS_DELL_SMM=m
++CONFIG_SENSORS_DME1737=m
++CONFIG_SENSORS_DS1621=m
++CONFIG_SENSORS_DS620=m
++CONFIG_SENSORS_EMC1403=m
++CONFIG_SENSORS_EMC2103=m
++CONFIG_SENSORS_EMC6W201=m
++CONFIG_SENSORS_F71805F=m
++CONFIG_SENSORS_F71882FG=m
++CONFIG_SENSORS_F75375S=m
++CONFIG_SENSORS_FAM15H_POWER=m
++CONFIG_SENSORS_FSCHMD=m
++CONFIG_SENSORS_G760A=m
++CONFIG_SENSORS_G762=m
++CONFIG_SENSORS_GL518SM=m
++CONFIG_SENSORS_GL520SM=m
++CONFIG_SENSORS_GPIO_FAN=m
++CONFIG_SENSORS_HDAPS=m
++CONFIG_SENSORS_HIH6130=m
++CONFIG_SENSORS_HMC5843=m
++CONFIG_SENSORS_HMC5843_I2C=m
++CONFIG_SENSORS_HMC5843_SPI=m
++CONFIG_SENSORS_HTU21=m
++CONFIG_SENSORS_I5500=m
++CONFIG_SENSORS_I5K_AMB=m
++CONFIG_SENSORS_IBMAEM=m
++CONFIG_SENSORS_IBMPEX=m
++CONFIG_SENSORS_IBMPOWERNV=m
++CONFIG_SENSORS_IIO_HWMON=m
++CONFIG_SENSORS_INA209=m
++CONFIG_SENSORS_INA2XX=m
++CONFIG_SENSORS_ISL29018=m
++CONFIG_SENSORS_ISL29028=m
++CONFIG_SENSORS_IT87=m
++CONFIG_SENSORS_JC42=m
++CONFIG_SENSORS_K10TEMP=m
++CONFIG_SENSORS_K8TEMP=m
++CONFIG_SENSORS_LINEAGE=m
++CONFIG_SENSORS_LIS3LV02D=m
++CONFIG_SENSORS_LIS3_I2C=m
++CONFIG_SENSORS_LIS3_SPI=m
++CONFIG_SENSORS_LM25066=m
++CONFIG_SENSORS_LM3533=m
++CONFIG_SENSORS_LM63=m
++CONFIG_SENSORS_LM70=m
++CONFIG_SENSORS_LM73=m
++CONFIG_SENSORS_LM75=m
++CONFIG_SENSORS_LM77=m
++CONFIG_SENSORS_LM78=m
++CONFIG_SENSORS_LM80=m
++CONFIG_SENSORS_LM83=m
++CONFIG_SENSORS_LM85=m
++CONFIG_SENSORS_LM87=m
++CONFIG_SENSORS_LM90=m
++CONFIG_SENSORS_LM92=m
++CONFIG_SENSORS_LM93=m
++CONFIG_SENSORS_LM95234=m
++CONFIG_SENSORS_LM95241=m
++CONFIG_SENSORS_LM95245=m
++CONFIG_SENSORS_LTC2945=m
++CONFIG_SENSORS_LTC2978=m
++CONFIG_SENSORS_LTC2978_REGULATOR=y
++CONFIG_SENSORS_LTC4151=m
++CONFIG_SENSORS_LTC4215=m
++CONFIG_SENSORS_LTC4222=m
++CONFIG_SENSORS_LTC4245=m
++CONFIG_SENSORS_LTC4260=m
++CONFIG_SENSORS_LTC4261=m
++CONFIG_SENSORS_MAX1111=m
++CONFIG_SENSORS_MAX16064=m
++CONFIG_SENSORS_MAX16065=m
++CONFIG_SENSORS_MAX1619=m
++CONFIG_SENSORS_MAX1668=m
++CONFIG_SENSORS_MAX197=m
++CONFIG_SENSORS_MAX20751=m
++CONFIG_SENSORS_MAX31790=m
++CONFIG_SENSORS_MAX34440=m
++CONFIG_SENSORS_MAX6639=m
++CONFIG_SENSORS_MAX6642=m
++CONFIG_SENSORS_MAX6650=m
++CONFIG_SENSORS_MAX6697=m
++CONFIG_SENSORS_MAX8688=m
++CONFIG_SENSORS_MC13783_ADC=m
++CONFIG_SENSORS_MCP3021=m
++CONFIG_SENSORS_MENF21BMC_HWMON=m
++CONFIG_SENSORS_NCT6683=m
++CONFIG_SENSORS_NCT6775=m
++CONFIG_SENSORS_NCT7802=m
++CONFIG_SENSORS_NCT7904=m
++CONFIG_SENSORS_NTC_THERMISTOR=m
++CONFIG_SENSORS_PC87360=m
++CONFIG_SENSORS_PC87427=m
++CONFIG_SENSORS_PCF8591=m
++CONFIG_SENSORS_PMBUS=m
++CONFIG_SENSORS_POWR1220=m
++CONFIG_SENSORS_PWM_FAN=m
++CONFIG_SENSORS_SCH5627=m
++CONFIG_SENSORS_SCH5636=m
++CONFIG_SENSORS_SHT15=m
++CONFIG_SENSORS_SHT21=m
++CONFIG_SENSORS_SHTC1=m
++CONFIG_SENSORS_SIS5595=m
++CONFIG_SENSORS_SMM665=m
++CONFIG_SENSORS_SMSC47B397=m
++CONFIG_SENSORS_SMSC47M1=m
++CONFIG_SENSORS_SMSC47M192=m
++CONFIG_SENSORS_TC74=m
++CONFIG_SENSORS_THMC50=m
++CONFIG_SENSORS_TMP102=m
++CONFIG_SENSORS_TMP103=m
++CONFIG_SENSORS_TMP401=m
++CONFIG_SENSORS_TMP421=m
++CONFIG_SENSORS_TPS40422=m
++CONFIG_SENSORS_TSL2550=m
++CONFIG_SENSORS_TSL2563=m
++CONFIG_SENSORS_TWL4030_MADC=m
++CONFIG_SENSORS_UCD9000=m
++CONFIG_SENSORS_UCD9200=m
++CONFIG_SENSORS_VEXPRESS=m
++CONFIG_SENSORS_VIA686A=m
++CONFIG_SENSORS_VIA_CPUTEMP=m
++CONFIG_SENSORS_VT1211=m
++CONFIG_SENSORS_VT8231=m
++CONFIG_SENSORS_W83627EHF=m
++CONFIG_SENSORS_W83627HF=m
++CONFIG_SENSORS_W83781D=m
++CONFIG_SENSORS_W83791D=m
++CONFIG_SENSORS_W83792D=m
++CONFIG_SENSORS_W83793=m
++CONFIG_SENSORS_W83795=m
++# CONFIG_SENSORS_W83795_FANCTRL is not set
++CONFIG_SENSORS_W83L785TS=m
++CONFIG_SENSORS_W83L786NG=m
++CONFIG_SENSORS_WM831X=m
++CONFIG_SENSORS_WM8350=m
++CONFIG_SENSORS_ZL6100=m
++CONFIG_SERIAL_8250_ACCENT=m
++CONFIG_SERIAL_8250_BOCA=m
++CONFIG_SERIAL_8250_CONSOLE=y
++CONFIG_SERIAL_8250_CS=m
++# CONFIG_SERIAL_8250_DEPRECATED_OPTIONS is not set
++# CONFIG_SERIAL_8250_DETECT_IRQ is not set
++CONFIG_SERIAL_8250_DMA=y
++# CONFIG_SERIAL_8250_EM is not set
++CONFIG_SERIAL_8250_EXAR_ST16C554=m
++CONFIG_SERIAL_8250_EXTENDED=y
++CONFIG_SERIAL_8250_FINTEK=m
++CONFIG_SERIAL_8250_FOURPORT=m
++CONFIG_SERIAL_8250_HUB6=m
++CONFIG_SERIAL_8250_INGENIC=y
++CONFIG_SERIAL_8250_MANY_PORTS=y
++CONFIG_SERIAL_8250_MID=m
++CONFIG_SERIAL_8250_MT6577=y
++CONFIG_SERIAL_8250_NR_UARTS=48
++CONFIG_SERIAL_8250_OMAP=m
++CONFIG_SERIAL_8250_PCI=y
++CONFIG_SERIAL_8250_PNP=y
++CONFIG_SERIAL_8250_RSA=y
++CONFIG_SERIAL_8250_RT288X=y
++CONFIG_SERIAL_8250_RUNTIME_UARTS=32
++CONFIG_SERIAL_8250_SHARE_IRQ=y
++CONFIG_SERIAL_8250_UNIPHIER=m
++CONFIG_SERIAL_ALTERA_UART_BAUDRATE=115200
++CONFIG_SERIAL_ALTERA_UART_MAXPORTS=4
++CONFIG_SERIAL_AMBA_PL010=m
++CONFIG_SERIAL_AMBA_PL011=y
++CONFIG_SERIAL_AMBA_PL011_CONSOLE=y
++CONFIG_SERIAL_ARC_NR_PORTS=1
++CONFIG_SERIAL_BCM63XX=m
++CONFIG_SERIAL_CONEXANT_DIGICOLOR=m
++CONFIG_SERIAL_CORE_CONSOLE=y
++CONFIG_SERIAL_CPM=m
++CONFIG_SERIAL_EARLYCON=y
++CONFIG_SERIAL_EARLYCON_ARM_SEMIHOST=y
++CONFIG_SERIAL_ICOM=m
++# CONFIG_SERIAL_IFX6X60 is not set
++CONFIG_SERIAL_IMX=y
++CONFIG_SERIAL_IMX_CONSOLE=y
++CONFIG_SERIAL_IPOCTAL=m
++CONFIG_SERIAL_KGDB_NMI=y
++CONFIG_SERIAL_MAX3100=m
++CONFIG_SERIAL_MAX310X=y
++CONFIG_SERIAL_MEN_Z135=m
++CONFIG_SERIAL_MESON=m
++CONFIG_SERIAL_MSM=y
++CONFIG_SERIAL_MSM_CONSOLE=y
++CONFIG_SERIAL_OF_PLATFORM=y
++CONFIG_SERIAL_OMAP=y
++CONFIG_SERIAL_OMAP_CONSOLE=y
++CONFIG_SERIAL_PCH_UART=m
++CONFIG_SERIAL_PMACZILOG=y
++CONFIG_SERIAL_PMACZILOG_CONSOLE=y
++# CONFIG_SERIAL_PMACZILOG_TTYS is not set
++CONFIG_SERIAL_RP2_NR_UARTS=32
++CONFIG_SERIAL_SAMSUNG=m
++CONFIG_SERIAL_SAMSUNG_UARTS=4
++CONFIG_SERIAL_SAMSUNG_UARTS_4=y
++CONFIG_SERIAL_SC16IS7XX=m
++CONFIG_SERIAL_SC16IS7XX_CORE=m
++CONFIG_SERIAL_SC16IS7XX_I2C=y
++CONFIG_SERIAL_SC16IS7XX_SPI=y
++CONFIG_SERIAL_SCCNXP_CONSOLE=y
++CONFIG_SERIAL_SH_SCI=m
++CONFIG_SERIAL_SH_SCI_DMA=y
++CONFIG_SERIAL_SH_SCI_NR_UARTS=2
++CONFIG_SERIAL_SPRD=m
++CONFIG_SERIAL_STM32=m
++CONFIG_SERIAL_ST_ASC=m
++CONFIG_SERIAL_TEGRA=m
++CONFIG_SERIAL_TIMBERDALE=m
++CONFIG_SERIAL_UARTLITE=m
++CONFIG_SERIAL_XILINX_PS_UART=m
++CONFIG_SERIO_ALTERA_PS2=m
++CONFIG_SERIO_AMBAKMI=m
++CONFIG_SERIO_APBPS2=m
++CONFIG_SERIO_ARC_PS2=m
++CONFIG_SERIO_CT82C710=m
++CONFIG_SERIO_I8042=y
++CONFIG_SERIO_LIBPS2=y
++CONFIG_SERIO_NVEC_PS2=m
++CONFIG_SERIO_PARKBD=m
++CONFIG_SERIO_PCIPS2=m
++CONFIG_SERIO_PS2MULT=m
++CONFIG_SERIO_RAW=m
++CONFIG_SERIO_SERPORT=m
++CONFIG_SERIO_XILINX_XPS_PS2=m
++CONFIG_SETEND_EMULATION=y
++CONFIG_SFC_MCDI_LOGGING=y
++CONFIG_SFC_MCDI_MON=y
++CONFIG_SFC_MTD=y
++CONFIG_SFC_SRIOV=y
++CONFIG_SFI=y
++CONFIG_SGETMASK_SYSCALL=y
++CONFIG_SGY_CTS1000=m
++# CONFIG_SG_SPLIT is not set
++CONFIG_SHMEM=y
++CONFIG_SHMOBILE_IOMMU=y
++# CONFIG_SHMOBILE_IOMMU_ADDRSIZE_1024MB is not set
++# CONFIG_SHMOBILE_IOMMU_ADDRSIZE_128MB is not set
++CONFIG_SHMOBILE_IOMMU_ADDRSIZE_2048MB=y
++# CONFIG_SHMOBILE_IOMMU_ADDRSIZE_256MB is not set
++# CONFIG_SHMOBILE_IOMMU_ADDRSIZE_32MB is not set
++# CONFIG_SHMOBILE_IOMMU_ADDRSIZE_512MB is not set
++# CONFIG_SHMOBILE_IOMMU_ADDRSIZE_64MB is not set
++CONFIG_SHMOBILE_IOMMU_L1SIZE=8192
++CONFIG_SHMOBILE_IPMMU=y
++CONFIG_SHMOBILE_IPMMU_TLB=y
++CONFIG_SH_DMAE=m
++CONFIG_SH_DMAE_BASE=y
++CONFIG_SH_ETH=m
++CONFIG_SH_IRDA=m
++CONFIG_SI7005=m
++CONFIG_SI7020=m
++CONFIG_SIGMATEL_FIR=m
++CONFIG_SIGNALFD=y
++CONFIG_SIGNATURE=y
++CONFIG_SIGNED_PE_FILE_VERIFICATION=y
++CONFIG_SIMPLE_PM_BUS=y
++CONFIG_SIS190=m
++CONFIG_SIS900=m
++CONFIG_SKFP=m
++CONFIG_SKGE=m
++# CONFIG_SKGE_DEBUG is not set
++CONFIG_SKGE_GENESIS=y
++CONFIG_SKY2=m
++# CONFIG_SKY2_DEBUG is not set
++# CONFIG_SLAB is not set
++CONFIG_SLABINFO=y
++CONFIG_SLHC=y
++CONFIG_SLICOSS=m
++CONFIG_SLIP_COMPRESSED=y
++CONFIG_SLIP_MODE_SLIP6=y
++CONFIG_SLIP_SMART=y
++# CONFIG_SLOB is not set
++CONFIG_SLUB=y
++CONFIG_SLUB_CPU_PARTIAL=y
++CONFIG_SLUB_DEBUG=y
++# CONFIG_SLUB_DEBUG_ON is not set
++# CONFIG_SLUB_STATS is not set
++CONFIG_SMARTJOYPLUS_FF=y
++CONFIG_SMC911X=m
++CONFIG_SMC9194=m
++CONFIG_SMC_IRCC_FIR=m
++CONFIG_SMP=y
++CONFIG_SMP_ON_UP=y
++CONFIG_SMSC37B787_WDT=m
++CONFIG_SMSC911X=m
++# CONFIG_SMSC911X_ARCH_HOOKS is not set
++CONFIG_SMSC9420=m
++CONFIG_SMSC_PHY=m
++CONFIG_SMSC_SCH311X_WDT=m
++CONFIG_SMSGIUCV=y
++CONFIG_SMSGIUCV_EVENT=m
++CONFIG_SMS_SDIO_DRV=m
++CONFIG_SMS_SIANO_DEBUGFS=y
++CONFIG_SMS_SIANO_MDTV=m
++CONFIG_SMS_SIANO_RC=y
++CONFIG_SMS_USB_DRV=m
++CONFIG_SM_FTL=m
++CONFIG_SND_AC97_CODEC=m
++CONFIG_SND_AC97_POWER_SAVE=y
++CONFIG_SND_AC97_POWER_SAVE_DEFAULT=0
++CONFIG_SND_AD1816A=m
++CONFIG_SND_AD1848=m
++CONFIG_SND_AD1889=m
++CONFIG_SND_ADLIB=m
++CONFIG_SND_ALI5451=m
++CONFIG_SND_ALOOP=m
++CONFIG_SND_ALS100=m
++CONFIG_SND_ALS300=m
++CONFIG_SND_ALS4000=m
++CONFIG_SND_AM33XX_SOC_EVM=m
++CONFIG_SND_AOA=m
++CONFIG_SND_AOA_FABRIC_LAYOUT=m
++CONFIG_SND_AOA_ONYX=m
++CONFIG_SND_AOA_SOUNDBUS=m
++CONFIG_SND_AOA_SOUNDBUS_I2S=m
++CONFIG_SND_AOA_TAS=m
++CONFIG_SND_AOA_TOONIE=m
++CONFIG_SND_ARM=y
++CONFIG_SND_ARMAACI=m
++CONFIG_SND_ASIHPI=m
++CONFIG_SND_ATIIXP=m
++CONFIG_SND_ATIIXP_MODEM=m
++CONFIG_SND_ATMEL_SOC=m
++CONFIG_SND_AU8810=m
++CONFIG_SND_AU8820=m
++CONFIG_SND_AU8830=m
++CONFIG_SND_AW2=m
++CONFIG_SND_AZT1605=m
++CONFIG_SND_AZT2316=m
++CONFIG_SND_AZT2320=m
++CONFIG_SND_AZT3328=m
++CONFIG_SND_BCD2000=m
++CONFIG_SND_BEBOB=m
++CONFIG_SND_BT87X=m
++# CONFIG_SND_BT87X_OVERCLOCK is not set
++CONFIG_SND_CA0106=m
++CONFIG_SND_CMI8328=m
++CONFIG_SND_CMI8330=m
++CONFIG_SND_CMIPCI=m
++CONFIG_SND_COMPRESS_OFFLOAD=m
++CONFIG_SND_CS4231=m
++CONFIG_SND_CS4236=m
++CONFIG_SND_CS4281=m
++CONFIG_SND_CS46XX=m
++CONFIG_SND_CS46XX_NEW_DSP=y
++CONFIG_SND_CS5530=m
++CONFIG_SND_CS5535AUDIO=m
++CONFIG_SND_CTXFI=m
++CONFIG_SND_DARLA20=m
++CONFIG_SND_DARLA24=m
++CONFIG_SND_DAVINCI_SOC_GENERIC_EVM=m
++CONFIG_SND_DAVINCI_SOC_MCASP=m
++# CONFIG_SND_DEBUG is not set
++CONFIG_SND_DESIGNWARE_I2S=m
++CONFIG_SND_DICE=m
++CONFIG_SND_DMA_SGBUF=y
++CONFIG_SND_DRIVERS=y
++CONFIG_SND_DUMMY=m
++CONFIG_SND_DYNAMIC_MINORS=y
++CONFIG_SND_ECHO3G=m
++CONFIG_SND_EDMA_SOC=m
++CONFIG_SND_EMU10K1=m
++CONFIG_SND_EMU10K1X=m
++CONFIG_SND_ENS1370=m
++CONFIG_SND_ENS1371=m
++CONFIG_SND_ES1688=m
++CONFIG_SND_ES18XX=m
++CONFIG_SND_ES1938=m
++CONFIG_SND_ES1968=m
++CONFIG_SND_ES1968_INPUT=y
++CONFIG_SND_ES1968_RADIO=y
++CONFIG_SND_FIREWIRE=y
++CONFIG_SND_FIREWIRE_DIGI00X=m
++CONFIG_SND_FIREWIRE_LIB=m
++CONFIG_SND_FIREWIRE_TASCAM=m
++CONFIG_SND_FIREWORKS=m
++CONFIG_SND_FM801=m
++CONFIG_SND_FM801_TEA575X_BOOL=y
++CONFIG_SND_GINA20=m
++CONFIG_SND_GINA24=m
++CONFIG_SND_GUSCLASSIC=m
++CONFIG_SND_GUSEXTREME=m
++CONFIG_SND_GUSMAX=m
++CONFIG_SND_HDA=m
++CONFIG_SND_HDA_CODEC_ANALOG=m
++CONFIG_SND_HDA_CODEC_CA0110=m
++CONFIG_SND_HDA_CODEC_CA0132=m
++CONFIG_SND_HDA_CODEC_CA0132_DSP=y
++CONFIG_SND_HDA_CODEC_CIRRUS=m
++CONFIG_SND_HDA_CODEC_CMEDIA=m
++CONFIG_SND_HDA_CODEC_CONEXANT=m
++CONFIG_SND_HDA_CODEC_HDMI=m
++CONFIG_SND_HDA_CODEC_REALTEK=m
++CONFIG_SND_HDA_CODEC_SI3054=m
++CONFIG_SND_HDA_CODEC_SIGMATEL=m
++CONFIG_SND_HDA_CODEC_VIA=m
++CONFIG_SND_HDA_CORE=m
++CONFIG_SND_HDA_DSP_LOADER=y
++CONFIG_SND_HDA_EXT_CORE=m
++CONFIG_SND_HDA_GENERIC=m
++CONFIG_SND_HDA_HWDEP=y
++CONFIG_SND_HDA_I915=y
++CONFIG_SND_HDA_INPUT_BEEP=y
++CONFIG_SND_HDA_INPUT_BEEP_MODE=0
++CONFIG_SND_HDA_INTEL=m
++CONFIG_SND_HDA_PATCH_LOADER=y
++CONFIG_SND_HDA_POWER_SAVE_DEFAULT=0
++CONFIG_SND_HDA_PREALLOC_SIZE=64
++CONFIG_SND_HDA_RECONFIG=y
++CONFIG_SND_HDA_TEGRA=m
++CONFIG_SND_HDSP=m
++CONFIG_SND_HDSPM=m
++CONFIG_SND_HRTIMER=m
++CONFIG_SND_HWDEP=m
++CONFIG_SND_ICE1712=m
++CONFIG_SND_ICE1724=m
++CONFIG_SND_IMX_SOC=y
++CONFIG_SND_INDIGO=m
++CONFIG_SND_INDIGODJ=m
++CONFIG_SND_INDIGODJX=m
++CONFIG_SND_INDIGOIO=m
++CONFIG_SND_INDIGOIOX=m
++CONFIG_SND_INTEL8X0=m
++CONFIG_SND_INTEL8X0M=m
++CONFIG_SND_INTERWAVE=m
++CONFIG_SND_INTERWAVE_STB=m
++CONFIG_SND_ISA=y
++CONFIG_SND_ISIGHT=m
++CONFIG_SND_JACK=y
++CONFIG_SND_JAZZ16=m
++CONFIG_SND_KIRKWOOD_SOC=m
++CONFIG_SND_KIRKWOOD_SOC_ARMADA370_DB=m
++CONFIG_SND_KORG1212=m
++CONFIG_SND_LAYLA20=m
++CONFIG_SND_LAYLA24=m
++CONFIG_SND_LOLA=m
++CONFIG_SND_LX6464ES=m
++CONFIG_SND_MAESTRO3=m
++CONFIG_SND_MAESTRO3_INPUT=y
++CONFIG_SND_MAX_CARDS=32
++CONFIG_SND_MFLD_MACHINE=m
++CONFIG_SND_MIA=m
++CONFIG_SND_MIRO=m
++CONFIG_SND_MIXART=m
++CONFIG_SND_MIXER_OSS=m
++CONFIG_SND_MONA=m
++CONFIG_SND_MPU401=m
++CONFIG_SND_MPU401_UART=m
++CONFIG_SND_MSND_CLASSIC=m
++CONFIG_SND_MSND_PINNACLE=m
++CONFIG_SND_MTPAV=m
++CONFIG_SND_MTS64=m
++CONFIG_SND_NM256=m
++CONFIG_SND_OMAP_SOC=y
++CONFIG_SND_OMAP_SOC_DMIC=m
++CONFIG_SND_OMAP_SOC_HDMI_AUDIO=m
++CONFIG_SND_OMAP_SOC_MCBSP=y
++CONFIG_SND_OMAP_SOC_MCPDM=m
++CONFIG_SND_OMAP_SOC_OMAP3_PANDORA=m
++CONFIG_SND_OMAP_SOC_OMAP_ABE_TWL6040=m
++CONFIG_SND_OMAP_SOC_OMAP_TWL4030=y
++CONFIG_SND_OMAP_SOC_RX51=m
++CONFIG_SND_OPL3SA2=m
++CONFIG_SND_OPL3_LIB=m
++CONFIG_SND_OPL3_LIB_SEQ=m
++CONFIG_SND_OPL4_LIB=m
++CONFIG_SND_OPTI92X_AD1848=m
++CONFIG_SND_OPTI92X_CS4231=m
++CONFIG_SND_OPTI93X=m
++CONFIG_SND_OSSEMUL=y
++CONFIG_SND_OXFW=m
++CONFIG_SND_OXYGEN=m
++CONFIG_SND_OXYGEN_LIB=m
++CONFIG_SND_PCI=y
++CONFIG_SND_PCMCIA=y
++CONFIG_SND_PCM_ELD=y
++CONFIG_SND_PCM_IEC958=y
++CONFIG_SND_PCM_OSS=m
++CONFIG_SND_PCM_OSS_PLUGINS=y
++CONFIG_SND_PCM_TIMER=y
++CONFIG_SND_PCSP=m
++CONFIG_SND_PCXHR=m
++CONFIG_SND_PDAUDIOCF=m
++CONFIG_SND_PORTMAN2X4=m
++CONFIG_SND_POWERMAC=m
++CONFIG_SND_POWERMAC_AUTO_DRC=y
++CONFIG_SND_POWERPC_SOC=m
++CONFIG_SND_PPC=y
++CONFIG_SND_PROC_FS=y
++CONFIG_SND_PS3=m
++CONFIG_SND_PS3_DEFAULT_START_DELAY=2000
++CONFIG_SND_RAWMIDI=m
++CONFIG_SND_RAWMIDI_SEQ=m
++CONFIG_SND_RIPTIDE=m
++CONFIG_SND_RME32=m
++CONFIG_SND_RME96=m
++CONFIG_SND_RME9652=m
++CONFIG_SND_SAMSUNG_I2S=m
++CONFIG_SND_SAMSUNG_PCM=m
++CONFIG_SND_SAMSUNG_SPDIF=m
++CONFIG_SND_SB16=m
++CONFIG_SND_SB16_CSP=y
++CONFIG_SND_SB16_DSP=m
++CONFIG_SND_SB8=m
++CONFIG_SND_SB8_DSP=m
++CONFIG_SND_SBAWE=m
++CONFIG_SND_SB_COMMON=m
++CONFIG_SND_SC6000=m
++CONFIG_SND_SCS1X=m
++CONFIG_SND_SEQUENCER=m
++# CONFIG_SND_SEQUENCER_OSS is not set
++CONFIG_SND_SEQ_DUMMY=m
++CONFIG_SND_SEQ_HRTIMER_DEFAULT=y
++CONFIG_SND_SERIAL_U16550=m
++CONFIG_SND_SIMPLE_CARD=m
++CONFIG_SND_SIS7019=m
++CONFIG_SND_SOC_AC97_BUS=y
++CONFIG_SND_SOC_AC97_CODEC=m
++CONFIG_SND_SOC_ADAU1701=m
++CONFIG_SND_SOC_AK4104=m
++CONFIG_SND_SOC_AK4554=m
++CONFIG_SND_SOC_AK4613=m
++CONFIG_SND_SOC_AK4642=m
++CONFIG_SND_SOC_AK5386=m
++CONFIG_SND_SOC_ALC5623=m
++CONFIG_SND_SOC_ALC5632=m
++CONFIG_SND_SOC_APQ8016_SBC=m
++CONFIG_SND_SOC_ARNDALE_RT5631_ALC5631=m
++CONFIG_SND_SOC_COMPRESS=y
++CONFIG_SND_SOC_CS35L32=m
++CONFIG_SND_SOC_CS4265=m
++CONFIG_SND_SOC_CS4270=m
++CONFIG_SND_SOC_CS4271=m
++CONFIG_SND_SOC_CS4271_I2C=m
++CONFIG_SND_SOC_CS4271_SPI=m
++CONFIG_SND_SOC_CS42L51=m
++CONFIG_SND_SOC_CS42L51_I2C=m
++CONFIG_SND_SOC_CS42L52=m
++CONFIG_SND_SOC_CS42L56=m
++CONFIG_SND_SOC_CS42L73=m
++CONFIG_SND_SOC_CS42XX8=m
++CONFIG_SND_SOC_CS42XX8_I2C=m
++CONFIG_SND_SOC_CS4349=m
++CONFIG_SND_SOC_DMIC=m
++CONFIG_SND_SOC_ES8328=m
++CONFIG_SND_SOC_ES8328_I2C=m
++CONFIG_SND_SOC_ES8328_SPI=m
++CONFIG_SND_SOC_EUKREA_TLV320=m
++CONFIG_SND_SOC_FSL_ASOC_CARD=m
++CONFIG_SND_SOC_FSL_ASRC=m
++CONFIG_SND_SOC_FSL_ESAI=m
++CONFIG_SND_SOC_FSL_SAI=m
++CONFIG_SND_SOC_FSL_SPDIF=m
++CONFIG_SND_SOC_FSL_UTILS=m
++CONFIG_SND_SOC_GENERIC_DMAENGINE_PCM=y
++CONFIG_SND_SOC_GTM601=m
++CONFIG_SND_SOC_IMX_ES8328=m
++CONFIG_SND_SOC_IMX_MC13783=m
++CONFIG_SND_SOC_IMX_PCM_DMA=y
++CONFIG_SND_SOC_IMX_PCM_FIQ=y
++CONFIG_SND_SOC_IMX_SGTL5000=y
++CONFIG_SND_SOC_IMX_SPDIF=m
++CONFIG_SND_SOC_IMX_SSI=m
++CONFIG_SND_SOC_IMX_WM8962=m
++CONFIG_SND_SOC_INTEL_BAYTRAIL=m
++CONFIG_SND_SOC_INTEL_BROADWELL_MACH=m
++CONFIG_SND_SOC_INTEL_BYTCR_RT5640_MACH=m
++CONFIG_SND_SOC_INTEL_BYTCR_RT5660_MACH=m
++CONFIG_SND_SOC_INTEL_BYT_MAX98090_MACH=m
++CONFIG_SND_SOC_INTEL_BYT_RT5640_MACH=m
++CONFIG_SND_SOC_INTEL_CHT_BSW_MAX98090_TI_MACH=m
++CONFIG_SND_SOC_INTEL_CHT_BSW_RT5645_MACH=m
++CONFIG_SND_SOC_INTEL_CHT_BSW_RT5672_MACH=m
++CONFIG_SND_SOC_INTEL_HASWELL=m
++CONFIG_SND_SOC_INTEL_HASWELL_MACH=m
++CONFIG_SND_SOC_INTEL_SKL_RT286_MACH=m
++CONFIG_SND_SOC_INTEL_SKYLAKE=m
++CONFIG_SND_SOC_INTEL_SST=m
++CONFIG_SND_SOC_INTEL_SST_ACPI=m
++CONFIG_SND_SOC_LPASS_APQ8016=m
++CONFIG_SND_SOC_LPASS_CPU=m
++CONFIG_SND_SOC_LPASS_IPQ806X=m
++CONFIG_SND_SOC_LPASS_PLATFORM=m
++CONFIG_SND_SOC_MAX98090=m
++CONFIG_SND_SOC_MAX98095=m
++CONFIG_SND_SOC_MAX98357A=m
++CONFIG_SND_SOC_MC13783=m
++CONFIG_SND_SOC_MEDIATEK=m
++CONFIG_SND_SOC_MT8173_MAX98090=m
++CONFIG_SND_SOC_MT8173_RT5650_RT5676=m
++CONFIG_SND_SOC_ODROIDX2=m
++CONFIG_SND_SOC_PCM1681=m
++CONFIG_SND_SOC_PCM1792A=m
++CONFIG_SND_SOC_PCM512x=m
++CONFIG_SND_SOC_PCM512x_I2C=m
++CONFIG_SND_SOC_PCM512x_SPI=m
++CONFIG_SND_SOC_QCOM=m
++CONFIG_SND_SOC_RCAR=m
++CONFIG_SND_SOC_RL6231=m
++CONFIG_SND_SOC_RL6347A=m
++CONFIG_SND_SOC_ROCKCHIP=m
++CONFIG_SND_SOC_ROCKCHIP_I2S=m
++CONFIG_SND_SOC_ROCKCHIP_MAX98090=m
++CONFIG_SND_SOC_ROCKCHIP_RT5645=m
++CONFIG_SND_SOC_ROCKCHIP_SPDIF=m
++CONFIG_SND_SOC_RSRC_CARD=m
++CONFIG_SND_SOC_RT286=m
++CONFIG_SND_SOC_RT5631=m
++CONFIG_SND_SOC_RT5640=m
++CONFIG_SND_SOC_RT5645=m
++CONFIG_SND_SOC_RT5660=m
++CONFIG_SND_SOC_RT5670=m
++CONFIG_SND_SOC_RT5677=m
++CONFIG_SND_SOC_SAMSUNG=m
++CONFIG_SND_SOC_SAMSUNG_SMDK_SPDIF=m
++CONFIG_SND_SOC_SAMSUNG_SMDK_WM8994=m
++CONFIG_SND_SOC_SH4_FSI=m
++CONFIG_SND_SOC_SI476X=m
++CONFIG_SND_SOC_SIGMADSP=m
++CONFIG_SND_SOC_SIGMADSP_I2C=m
++CONFIG_SND_SOC_SIRF_AUDIO_CODEC=m
++CONFIG_SND_SOC_SMDK_WM8994_PCM=m
++CONFIG_SND_SOC_SN95031=m
++CONFIG_SND_SOC_SNOW=m
++CONFIG_SND_SOC_SPDIF=m
++CONFIG_SND_SOC_SSM2602=m
++CONFIG_SND_SOC_SSM2602_I2C=m
++CONFIG_SND_SOC_SSM2602_SPI=m
++CONFIG_SND_SOC_SSM4567=m
++CONFIG_SND_SOC_STA32X=m
++CONFIG_SND_SOC_STA350=m
++CONFIG_SND_SOC_STI_SAS=m
++CONFIG_SND_SOC_STORM=m
++CONFIG_SND_SOC_TAS2552=m
++CONFIG_SND_SOC_TAS5086=m
++CONFIG_SND_SOC_TAS571X=m
++CONFIG_SND_SOC_TEGRA=m
++CONFIG_SND_SOC_TEGRA20_AC97=m
++CONFIG_SND_SOC_TEGRA20_DAS=m
++CONFIG_SND_SOC_TEGRA20_I2S=m
++CONFIG_SND_SOC_TEGRA20_SPDIF=m
++CONFIG_SND_SOC_TEGRA30_AHUB=m
++CONFIG_SND_SOC_TEGRA30_I2S=m
++CONFIG_SND_SOC_TEGRA_ALC5632=m
++CONFIG_SND_SOC_TEGRA_MAX98090=m
++CONFIG_SND_SOC_TEGRA_RT5640=m
++CONFIG_SND_SOC_TEGRA_RT5677=m
++CONFIG_SND_SOC_TEGRA_TRIMSLICE=m
++CONFIG_SND_SOC_TEGRA_WM8753=m
++CONFIG_SND_SOC_TEGRA_WM8903=m
++CONFIG_SND_SOC_TEGRA_WM9712=m
++CONFIG_SND_SOC_TFA9879=m
++CONFIG_SND_SOC_TLV320AIC23=m
++CONFIG_SND_SOC_TLV320AIC23_I2C=m
++CONFIG_SND_SOC_TLV320AIC23_SPI=m
++CONFIG_SND_SOC_TLV320AIC31XX=m
++CONFIG_SND_SOC_TLV320AIC3X=m
++CONFIG_SND_SOC_TOPOLOGY=y
++CONFIG_SND_SOC_TPA6130A2=m
++CONFIG_SND_SOC_TS3A227E=m
++CONFIG_SND_SOC_TWL4030=y
++CONFIG_SND_SOC_TWL6040=m
++CONFIG_SND_SOC_WM8510=m
++CONFIG_SND_SOC_WM8523=m
++CONFIG_SND_SOC_WM8580=m
++CONFIG_SND_SOC_WM8711=m
++CONFIG_SND_SOC_WM8728=m
++CONFIG_SND_SOC_WM8731=m
++CONFIG_SND_SOC_WM8737=m
++CONFIG_SND_SOC_WM8741=m
++CONFIG_SND_SOC_WM8750=m
++CONFIG_SND_SOC_WM8753=m
++CONFIG_SND_SOC_WM8770=m
++CONFIG_SND_SOC_WM8776=m
++CONFIG_SND_SOC_WM8804=m
++CONFIG_SND_SOC_WM8804_I2C=m
++CONFIG_SND_SOC_WM8804_SPI=m
++CONFIG_SND_SOC_WM8903=m
++CONFIG_SND_SOC_WM8962=m
++CONFIG_SND_SOC_WM8978=m
++CONFIG_SND_SOC_WM8994=m
++CONFIG_SND_SOC_WM9712=m
++CONFIG_SND_SOC_WM_HUBS=m
++CONFIG_SND_SOC_XTFPGA_I2S=m
++CONFIG_SND_SONICVIBES=m
++CONFIG_SND_SPI=y
++CONFIG_SND_SSCAPE=m
++CONFIG_SND_SST_IPC=m
++CONFIG_SND_SST_IPC_ACPI=m
++CONFIG_SND_SST_IPC_PCI=m
++CONFIG_SND_SST_MFLD_PLATFORM=m
++CONFIG_SND_SUN4I_CODEC=m
++CONFIG_SND_SUPPORT_OLD_API=y
++CONFIG_SND_TRIDENT=m
++CONFIG_SND_USB=y
++CONFIG_SND_USB_6FIRE=m
++CONFIG_SND_USB_AUDIO=m
++CONFIG_SND_USB_CAIAQ=m
++CONFIG_SND_USB_CAIAQ_INPUT=y
++CONFIG_SND_USB_HIFACE=m
++CONFIG_SND_USB_LINE6=m
++CONFIG_SND_USB_POD=m
++CONFIG_SND_USB_PODHD=m
++CONFIG_SND_USB_TONEPORT=m
++CONFIG_SND_USB_UA101=m
++CONFIG_SND_USB_US122L=m
++CONFIG_SND_USB_USX2Y=m
++CONFIG_SND_USB_VARIAX=m
++# CONFIG_SND_VERBOSE_PRINTK is not set
++CONFIG_SND_VERBOSE_PROCFS=y
++CONFIG_SND_VIA82XX=m
++CONFIG_SND_VIA82XX_MODEM=m
++CONFIG_SND_VIRMIDI=m
++CONFIG_SND_VIRTUOSO=m
++CONFIG_SND_VMASTER=y
++CONFIG_SND_VX222=m
++CONFIG_SND_VXPOCKET=m
++CONFIG_SND_VX_LIB=m
++CONFIG_SND_WAVEFRONT=m
++CONFIG_SND_WSS_LIB=m
++CONFIG_SND_YMFPCI=m
++# CONFIG_SOCRATES is not set
++# CONFIG_SOC_AM43XX is not set
++CONFIG_SOC_BRCMSTB=y
++CONFIG_SOC_BUS=y
++CONFIG_SOC_CAMERA=m
++CONFIG_SOC_CAMERA_IMX074=m
++CONFIG_SOC_CAMERA_MT9M001=m
++CONFIG_SOC_CAMERA_MT9M111=m
++CONFIG_SOC_CAMERA_MT9T031=m
++CONFIG_SOC_CAMERA_MT9T112=m
++CONFIG_SOC_CAMERA_MT9V022=m
++CONFIG_SOC_CAMERA_OV2640=m
++CONFIG_SOC_CAMERA_OV5642=m
++CONFIG_SOC_CAMERA_OV6650=m
++CONFIG_SOC_CAMERA_OV772X=m
++CONFIG_SOC_CAMERA_OV9640=m
++CONFIG_SOC_CAMERA_OV9740=m
++CONFIG_SOC_CAMERA_PLATFORM=m
++CONFIG_SOC_CAMERA_RJ54N1=m
++CONFIG_SOC_CAMERA_SCALE_CROP=m
++CONFIG_SOC_CAMERA_TW9910=m
++CONFIG_SOC_DRA7XX=y
++CONFIG_SOC_EXYNOS5250=y
++CONFIG_SOC_EXYNOS5260=y
++CONFIG_SOC_EXYNOS5410=y
++CONFIG_SOC_EXYNOS5420=y
++CONFIG_SOC_EXYNOS5440=y
++CONFIG_SOC_EXYNOS5800=y
++CONFIG_SOC_HAS_OMAP2_SDRC=y
++CONFIG_SOC_HAS_REALTIME_COUNTER=y
++CONFIG_SOC_IMX5=y
++CONFIG_SOC_IMX50=y
++CONFIG_SOC_IMX51=y
++# CONFIG_SOC_IMX53 is not set
++CONFIG_SOC_IMX6=y
++CONFIG_SOC_IMX6Q=y
++CONFIG_SOC_IMX6SL=y
++CONFIG_SOC_IMX6SX=y
++CONFIG_SOC_IMX6UL=y
++CONFIG_SOC_IMX7D=y
++# CONFIG_SOC_LS1021A is not set
++CONFIG_SOC_OMAP3430=y
++# CONFIG_SOC_OMAP5 is not set
++CONFIG_SOC_TI81XX=y
++CONFIG_SOC_VF610=y
++CONFIG_SOFT_WATCHDOG=m
++CONFIG_SONYPI=m
++CONFIG_SONYPI_COMPAT=y
++CONFIG_SONY_FF=y
++CONFIG_SONY_LAPTOP=m
++CONFIG_SOUND_OSS_CORE=y
++# CONFIG_SOUND_OSS_CORE_PRECLAIM is not set
++# CONFIG_SOUND_PRIME is not set
++CONFIG_SP5100_TCO=m
++CONFIG_SPAPR_TCE_IOMMU=y
++CONFIG_SPARSEMEM=y
++CONFIG_SPARSEMEM_ALLOC_MEM_MAP_TOGETHER=y
++CONFIG_SPARSEMEM_EXTREME=y
++CONFIG_SPARSEMEM_MANUAL=y
++CONFIG_SPARSEMEM_STATIC=y
++CONFIG_SPARSEMEM_VMEMMAP=y
++CONFIG_SPARSEMEM_VMEMMAP_ENABLE=y
++CONFIG_SPARSE_IRQ=y
++# CONFIG_SPARSE_RCU_POINTER is not set
++CONFIG_SPEAKUP=m
++CONFIG_SPEAKUP_SYNTH_ACNTPC=m
++CONFIG_SPEAKUP_SYNTH_ACNTSA=m
++CONFIG_SPEAKUP_SYNTH_APOLLO=m
++CONFIG_SPEAKUP_SYNTH_AUDPTR=m
++CONFIG_SPEAKUP_SYNTH_BNS=m
++CONFIG_SPEAKUP_SYNTH_DECEXT=m
++CONFIG_SPEAKUP_SYNTH_DECPC=m
++CONFIG_SPEAKUP_SYNTH_DECTLK=m
++CONFIG_SPEAKUP_SYNTH_DTLK=m
++CONFIG_SPEAKUP_SYNTH_DUMMY=m
++CONFIG_SPEAKUP_SYNTH_KEYPC=m
++CONFIG_SPEAKUP_SYNTH_LTLK=m
++CONFIG_SPEAKUP_SYNTH_SOFT=m
++CONFIG_SPEAKUP_SYNTH_SPKOUT=m
++CONFIG_SPEAKUP_SYNTH_TXPRT=m
++CONFIG_SPI_ALTERA=m
++CONFIG_SPI_BITBANG=m
++CONFIG_SPI_BUTTERFLY=m
++CONFIG_SPI_CADENCE=m
++# CONFIG_SPI_DEBUG is not set
++CONFIG_SPI_DESIGNWARE=m
++CONFIG_SPI_DLN2=m
++CONFIG_SPI_DW_MID_DMA=y
++CONFIG_SPI_DW_MMIO=m
++CONFIG_SPI_DW_PCI=m
++CONFIG_SPI_FSL_CPM=y
++CONFIG_SPI_FSL_DSPI=m
++CONFIG_SPI_FSL_ESPI=y
++CONFIG_SPI_FSL_LIB=y
++CONFIG_SPI_FSL_QUADSPI=m
++CONFIG_SPI_FSL_SPI=y
++CONFIG_SPI_GPIO=m
++CONFIG_SPI_IMX=m
++CONFIG_SPI_LM70_LLP=m
++CONFIG_SPI_MASTER=y
++CONFIG_SPI_MESON_SPIFC=m
++CONFIG_SPI_MT65XX=m
++CONFIG_SPI_OC_TINY=m
++CONFIG_SPI_OMAP24XX=y
++CONFIG_SPI_ORION=m
++CONFIG_SPI_PL022=m
++CONFIG_SPI_PXA2XX=m
++CONFIG_SPI_PXA2XX_DMA=y
++CONFIG_SPI_QUP=m
++CONFIG_SPI_ROCKCHIP=m
++CONFIG_SPI_RSPI=m
++CONFIG_SPI_S3C64XX=m
++CONFIG_SPI_SC18IS602=m
++CONFIG_SPI_SH_HSPI=m
++CONFIG_SPI_SH_MSIOF=m
++CONFIG_SPI_SPIDEV=m
++CONFIG_SPI_TEGRA114=m
++CONFIG_SPI_TEGRA20_SFLASH=m
++CONFIG_SPI_TEGRA20_SLINK=m
++CONFIG_SPI_TI_QSPI=m
++CONFIG_SPI_TLE62X0=m
++CONFIG_SPI_TOPCLIFF_PCH=m
++CONFIG_SPI_XCOMM=m
++# CONFIG_SPI_XILINX is not set
++CONFIG_SPI_ZYNQMP_GQSPI=m
++CONFIG_SPLIT_PTLOCK_CPUS=4
++CONFIG_SPMI_MSM_PMIC_ARB=m
++CONFIG_SPU_BASE=y
++CONFIG_SPU_FS=m
++CONFIG_SQUASHFS=y
++# CONFIG_SQUASHFS_4K_DEVBLK_SIZE is not set
++# CONFIG_SQUASHFS_DECOMP_MULTI is not set
++# CONFIG_SQUASHFS_DECOMP_MULTI_PERCPU is not set
++CONFIG_SQUASHFS_DECOMP_SINGLE=y
++# CONFIG_SQUASHFS_EMBEDDED is not set
++# CONFIG_SQUASHFS_FILE_CACHE is not set
++CONFIG_SQUASHFS_FILE_DIRECT=y
++CONFIG_SQUASHFS_FRAGMENT_CACHE_SIZE=3
++CONFIG_SQUASHFS_LZ4=y
++CONFIG_SQUASHFS_LZO=y
++CONFIG_SQUASHFS_XATTR=y
++CONFIG_SQUASHFS_XZ=y
++CONFIG_SQUASHFS_ZLIB=y
++CONFIG_SRCU=y
++CONFIG_SSB_B43_PCI_BRIDGE=y
++CONFIG_SSB_BLOCKIO=y
++# CONFIG_SSB_DEBUG is not set
++CONFIG_SSB_DRIVER_GPIO=y
++CONFIG_SSB_DRIVER_PCICORE=y
++CONFIG_SSB_DRIVER_PCICORE_POSSIBLE=y
++CONFIG_SSB_HOST_SOC=y
++CONFIG_SSB_PCIHOST=y
++CONFIG_SSB_PCIHOST_POSSIBLE=y
++# CONFIG_SSB_PCMCIAHOST is not set
++CONFIG_SSB_PCMCIAHOST_POSSIBLE=y
++CONFIG_SSB_POSSIBLE=y
++CONFIG_SSB_SDIOHOST=y
++CONFIG_SSB_SDIOHOST_POSSIBLE=y
++# CONFIG_SSB_SILENT is not set
++CONFIG_SSB_SPROM=y
++CONFIG_SSFDC=m
++CONFIG_SSI_PROTOCOL=m
++CONFIG_STACKTRACE=y
++CONFIG_STACKTRACE_SUPPORT=y
++CONFIG_STACK_GUARD=256
++CONFIG_STACK_TRACER=y
++# CONFIG_STAGING_BOARD is not set
++CONFIG_STAGING_MEDIA=y
++CONFIG_STAGING_RDMA=m
++# CONFIG_STATIC_KEYS_SELFTEST is not set
++CONFIG_STE10XP=m
++CONFIG_STK3310=m
++CONFIG_STK8312=m
++CONFIG_STK8BA50=m
++CONFIG_STM=m
++CONFIG_STMMAC_ETH=m
++# CONFIG_STMMAC_PCI is not set
++CONFIG_STMMAC_PLATFORM=m
++CONFIG_STMPE_I2C=y
++CONFIG_STMPE_SPI=y
++CONFIG_STMP_DEVICE=y
++CONFIG_STM_DUMMY=m
++CONFIG_STM_SOURCE_CONSOLE=m
++CONFIG_STP=m
++CONFIG_STRICT_DEVMEM=y
++# CONFIG_STRICT_MM_TYPECHECKS is not set
++# CONFIG_STRIP_ASM_SYMS is not set
++CONFIG_STUB_CLK_HI6220=y
++# CONFIG_STX_GP3 is not set
++CONFIG_SUDMAC=m
++CONFIG_SUNDANCE=m
++# CONFIG_SUNDANCE_MMIO is not set
++CONFIG_SUNGEM=m
++CONFIG_SUNGEM_PHY=m
++CONFIG_SUNRPC=m
++CONFIG_SUNRPC_BACKCHANNEL=y
++CONFIG_SUNRPC_DEBUG=y
++CONFIG_SUNRPC_GSS=m
++CONFIG_SUNRPC_SWAP=y
++CONFIG_SUNRPC_XPRT_RDMA=m
++# CONFIG_SUNXI_SRAM is not set
++CONFIG_SURFACE_PRO3_BUTTON=m
++CONFIG_SUSPEND=y
++CONFIG_SUSPEND_FREEZER=y
++# CONFIG_SUSPEND_SKIP_SYNC is not set
++CONFIG_SWAP=y
++CONFIG_SWIOTLB=y
++CONFIG_SWIOTLB_XEN=y
++CONFIG_SWP_EMULATE=y
++CONFIG_SWP_EMULATION=y
++CONFIG_SX9500=m
++CONFIG_SXGBE_ETH=m
++CONFIG_SYNCLINK=m
++CONFIG_SYNCLINKMP=m
++CONFIG_SYNCLINK_CS=m
++CONFIG_SYNCLINK_GT=m
++CONFIG_SYNOPSYS_DWC_ETH_QOS=m
++CONFIG_SYN_COOKIES=y
++CONFIG_SYSCTL=y
++CONFIG_SYSCTL_EXCEPTION_TRACE=y
++CONFIG_SYSCTL_SYSCALL=y
++CONFIG_SYSFS=y
++# CONFIG_SYSFS_DEPRECATED is not set
++CONFIG_SYSFS_SYSCALL=y
++CONFIG_SYSTEMPORT=m
++CONFIG_SYSTEM_BLACKLIST_KEYRING=y
++CONFIG_SYSTEM_DATA_VERIFICATION=y
++CONFIG_SYSTEM_EXTRA_CERTIFICATE=y
++CONFIG_SYSTEM_EXTRA_CERTIFICATE_SIZE=4096
++CONFIG_SYSTEM_TRUSTED_KEYRING=y
++CONFIG_SYSTEM_TRUSTED_KEYS=""
++CONFIG_SYSVIPC=y
++CONFIG_SYSVIPC_COMPAT=y
++CONFIG_SYSVIPC_SYSCTL=y
++CONFIG_SYS_SUPPORTS_APM_EMULATION=y
++CONFIG_SYS_SUPPORTS_EM_STI=y
++CONFIG_SYS_SUPPORTS_HUGETLBFS=y
++CONFIG_SYS_SUPPORTS_SH_CMT=y
++CONFIG_SYS_SUPPORTS_SH_MTU2=y
++CONFIG_SYS_SUPPORTS_SH_TMU=y
++CONFIG_T5403=m
++CONFIG_TABLET_SERIAL_WACOM4=m
++CONFIG_TABLET_USB_ACECAD=m
++CONFIG_TABLET_USB_AIPTEK=m
++CONFIG_TABLET_USB_GTCO=m
++CONFIG_TABLET_USB_HANWANG=m
++CONFIG_TABLET_USB_KBTAB=m
++CONFIG_TAHVO_USB=m
++CONFIG_TAHVO_USB_HOST_BY_DEFAULT=y
++CONFIG_TARGET_CORE=m
++CONFIG_TASKSTATS=y
++# CONFIG_TASKS_RCU is not set
++CONFIG_TASK_DELAY_ACCT=y
++CONFIG_TASK_IO_ACCOUNTING=y
++CONFIG_TASK_SIZE=0xc0000000
++CONFIG_TASK_XACCT=y
++CONFIG_TAU=y
++# CONFIG_TAU_AVERAGE is not set
++# CONFIG_TAU_INT is not set
++CONFIG_TC1100_WMI=m
++CONFIG_TCG_ATMEL=m
++CONFIG_TCG_CRB=m
++CONFIG_TCG_IBMVTPM=y
++CONFIG_TCG_INFINEON=m
++CONFIG_TCG_NSC=m
++CONFIG_TCG_TIS=y
++CONFIG_TCG_TIS_I2C_ATMEL=m
++CONFIG_TCG_TIS_I2C_INFINEON=m
++CONFIG_TCG_TIS_I2C_NUVOTON=m
++CONFIG_TCG_TIS_ST33ZP24=m
++CONFIG_TCG_TIS_ST33ZP24_I2C=m
++CONFIG_TCG_TIS_ST33ZP24_SPI=m
++CONFIG_TCG_TPM=y
++CONFIG_TCG_XEN=m
++CONFIG_TCIC=m
++CONFIG_TCM_FC=m
++CONFIG_TCM_FILEIO=m
++CONFIG_TCM_IBLOCK=m
++CONFIG_TCM_PSCSI=m
++CONFIG_TCM_QLA2XXX=m
++CONFIG_TCM_USER2=m
++CONFIG_TCP_CONG_ADVANCED=y
++CONFIG_TCP_CONG_BIC=m
++CONFIG_TCP_CONG_CDG=m
++CONFIG_TCP_CONG_CUBIC=y
++CONFIG_TCP_CONG_DCTCP=m
++CONFIG_TCP_CONG_HSTCP=m
++CONFIG_TCP_CONG_HTCP=m
++CONFIG_TCP_CONG_HYBLA=m
++CONFIG_TCP_CONG_ILLINOIS=m
++CONFIG_TCP_CONG_LP=m
++CONFIG_TCP_CONG_SCALABLE=m
++CONFIG_TCP_CONG_VEGAS=m
++CONFIG_TCP_CONG_VENO=m
++CONFIG_TCP_CONG_WESTWOOD=m
++CONFIG_TCP_CONG_YEAH=m
++CONFIG_TCP_MD5SIG=y
++CONFIG_TCS3414=m
++CONFIG_TCS3472=m
++CONFIG_TEGRA124_EMC=y
++CONFIG_TEGRA20_APB_DMA=y
++CONFIG_TEGRA20_MC=y
++CONFIG_TEGRA_AHB=y
++CONFIG_TEGRA_CLK_EMC=y
++CONFIG_TEGRA_HOST1X=m
++CONFIG_TEGRA_HOST1X_FIREWALL=y
++CONFIG_TEGRA_IOMMU_GART=y
++CONFIG_TEGRA_IOMMU_SMMU=y
++CONFIG_TEGRA_MC=y
++# CONFIG_TEGRA_SOCTHERM is not set
++CONFIG_TEGRA_TIMER=y
++CONFIG_TEGRA_WATCHDOG=m
++CONFIG_TEHUTI=m
++CONFIG_TEKRAM_DONGLE=m
++CONFIG_TELCLOCK=m
++CONFIG_TERANETICS_PHY=m
++CONFIG_TEST_BPF=m
++CONFIG_TEST_FIRMWARE=m
++CONFIG_TEST_HEXDUMP=m
++CONFIG_TEST_KSTRTOX=m
++# CONFIG_TEST_LIST_SORT is not set
++CONFIG_TEST_LKM=m
++CONFIG_TEST_POWER=m
++CONFIG_TEST_PRINTF=m
++# CONFIG_TEST_RHASHTABLE is not set
++CONFIG_TEST_STATIC_KEYS=m
++CONFIG_TEST_STRING_HELPERS=m
++CONFIG_TEST_UDELAY=m
++CONFIG_TEST_USER_COPY=m
++CONFIG_TEXTSEARCH=y
++CONFIG_TEXTSEARCH_BM=m
++CONFIG_TEXTSEARCH_FSM=m
++CONFIG_TEXTSEARCH_KMP=m
++# CONFIG_THERMAL_DEFAULT_GOV_FAIR_SHARE is not set
++# CONFIG_THERMAL_DEFAULT_GOV_POWER_ALLOCATOR is not set
++CONFIG_THERMAL_DEFAULT_GOV_STEP_WISE=y
++# CONFIG_THERMAL_DEFAULT_GOV_USER_SPACE is not set
++CONFIG_THERMAL_EMULATION=y
++CONFIG_THERMAL_GOV_BANG_BANG=y
++CONFIG_THERMAL_GOV_FAIR_SHARE=y
++CONFIG_THERMAL_GOV_POWER_ALLOCATOR=y
++CONFIG_THERMAL_GOV_STEP_WISE=y
++CONFIG_THERMAL_GOV_USER_SPACE=y
++CONFIG_THERMAL_HWMON=y
++CONFIG_THERMAL_OF=y
++CONFIG_THERMAL_WRITABLE_TRIPS=y
++CONFIG_THERM_ADT746X=y
++CONFIG_THERM_WINDTUNNEL=m
++CONFIG_THINKPAD_ACPI=m
++CONFIG_THINKPAD_ACPI_ALSA_SUPPORT=y
++# CONFIG_THINKPAD_ACPI_DEBUG is not set
++CONFIG_THINKPAD_ACPI_DEBUGFACILITIES=y
++CONFIG_THINKPAD_ACPI_HOTKEY_POLL=y
++# CONFIG_THINKPAD_ACPI_UNSAFE_LEDS is not set
++CONFIG_THINKPAD_ACPI_VIDEO=y
++CONFIG_THRUSTMASTER_FF=y
++# CONFIG_THUMB2_KERNEL is not set
++CONFIG_THUNDER_NIC_BGX=m
++CONFIG_THUNDER_NIC_PF=m
++CONFIG_THUNDER_NIC_VF=m
++CONFIG_TICK_CPU_ACCOUNTING=y
++CONFIG_TICK_ONESHOT=y
++CONFIG_TIFM_7XX1=m
++CONFIG_TIMB_DMA=m
++CONFIG_TIMERFD=y
++CONFIG_TIMER_STATS=y
++CONFIG_TIPC=m
++CONFIG_TIPC_MEDIA_IB=y
++CONFIG_TIPC_MEDIA_UDP=y
++CONFIG_TI_ADC081C=m
++CONFIG_TI_ADC128S052=m
++CONFIG_TI_AM335X_ADC=m
++CONFIG_TI_CPPI41=m
++CONFIG_TI_CPSW=y
++CONFIG_TI_CPSW_PHY_SEL=y
++CONFIG_TI_CPTS=y
++CONFIG_TI_DAC7512=m
++CONFIG_TI_DAVINCI_CPDMA=y
++CONFIG_TI_DAVINCI_EMAC=m
++CONFIG_TI_DAVINCI_MDIO=y
++CONFIG_TI_DMA_CROSSBAR=y
++CONFIG_TI_EDMA=y
++CONFIG_TI_EMIF=m
++CONFIG_TI_PIPE3=m
++CONFIG_TI_SOC_THERMAL=m
++CONFIG_TI_ST=m
++CONFIG_TI_THERMAL=y
++CONFIG_TLAN=m
++CONFIG_TMD_HERMES=m
++CONFIG_TMP006=m
++CONFIG_TMPFS=y
++CONFIG_TMPFS_POSIX_ACL=y
++CONFIG_TMPFS_XATTR=y
++CONFIG_TN3215=y
++CONFIG_TN3215_CONSOLE=y
++CONFIG_TN3270=y
++CONFIG_TN3270_CONSOLE=y
++CONFIG_TN3270_FS=m
++CONFIG_TN3270_TTY=y
++CONFIG_TOIM3232_DONGLE=m
++CONFIG_TOPSTAR_LAPTOP=m
++CONFIG_TORTURE_TEST=m
++# CONFIG_TOSHIBA is not set
++CONFIG_TOSHIBA_BT_RFKILL=m
++CONFIG_TOSHIBA_FIR=m
++CONFIG_TOSHIBA_HAPS=m
++CONFIG_TOSHIBA_WMI=m
++CONFIG_TOUCHSCREEN_88PM860X=m
++CONFIG_TOUCHSCREEN_AD7877=m
++CONFIG_TOUCHSCREEN_AD7879=m
++CONFIG_TOUCHSCREEN_AD7879_I2C=m
++CONFIG_TOUCHSCREEN_AD7879_SPI=m
++CONFIG_TOUCHSCREEN_ADS7846=m
++CONFIG_TOUCHSCREEN_AR1021_I2C=m
++CONFIG_TOUCHSCREEN_ATMEL_MXT=m
++CONFIG_TOUCHSCREEN_AUO_PIXCIR=m
++CONFIG_TOUCHSCREEN_BU21013=m
++CONFIG_TOUCHSCREEN_CHIPONE_ICN8318=m
++CONFIG_TOUCHSCREEN_COLIBRI_VF50=m
++CONFIG_TOUCHSCREEN_CY8CTMG110=m
++CONFIG_TOUCHSCREEN_CYTTSP4_CORE=m
++CONFIG_TOUCHSCREEN_CYTTSP4_I2C=m
++CONFIG_TOUCHSCREEN_CYTTSP4_SPI=m
++CONFIG_TOUCHSCREEN_CYTTSP_CORE=m
++CONFIG_TOUCHSCREEN_CYTTSP_I2C=m
++CONFIG_TOUCHSCREEN_CYTTSP_SPI=m
++CONFIG_TOUCHSCREEN_DA9034=m
++CONFIG_TOUCHSCREEN_DA9052=m
++CONFIG_TOUCHSCREEN_DYNAPRO=m
++CONFIG_TOUCHSCREEN_EDT_FT5X06=m
++CONFIG_TOUCHSCREEN_EETI=m
++CONFIG_TOUCHSCREEN_EGALAX=m
++CONFIG_TOUCHSCREEN_ELAN=y
++CONFIG_TOUCHSCREEN_ELO=m
++CONFIG_TOUCHSCREEN_FT6236=m
++CONFIG_TOUCHSCREEN_FUJITSU=m
++CONFIG_TOUCHSCREEN_GOODIX=m
++CONFIG_TOUCHSCREEN_GUNZE=m
++CONFIG_TOUCHSCREEN_HAMPSHIRE=m
++CONFIG_TOUCHSCREEN_HTCPEN=m
++CONFIG_TOUCHSCREEN_ILI210X=m
++CONFIG_TOUCHSCREEN_IMX6UL_TSC=m
++CONFIG_TOUCHSCREEN_INEXIO=m
++CONFIG_TOUCHSCREEN_INTEL_MID=m
++CONFIG_TOUCHSCREEN_IPROC=m
++CONFIG_TOUCHSCREEN_MAX11801=m
++CONFIG_TOUCHSCREEN_MC13783=m
++CONFIG_TOUCHSCREEN_MCS5000=m
++CONFIG_TOUCHSCREEN_MK712=m
++CONFIG_TOUCHSCREEN_MMS114=m
++CONFIG_TOUCHSCREEN_MTOUCH=m
++CONFIG_TOUCHSCREEN_PCAP=m
++CONFIG_TOUCHSCREEN_PENMOUNT=m
++CONFIG_TOUCHSCREEN_PIXCIR=m
++CONFIG_TOUCHSCREEN_PROPERTIES=y
++CONFIG_TOUCHSCREEN_ROHM_BU21023=m
++CONFIG_TOUCHSCREEN_ST1232=m
++CONFIG_TOUCHSCREEN_STMPE=m
++CONFIG_TOUCHSCREEN_SUR40=m
++CONFIG_TOUCHSCREEN_SX8654=m
++CONFIG_TOUCHSCREEN_SYNAPTICS_I2C_RMI4=m
++CONFIG_TOUCHSCREEN_TI_AM335X_TSC=m
++CONFIG_TOUCHSCREEN_TOUCHIT213=m
++CONFIG_TOUCHSCREEN_TOUCHRIGHT=m
++CONFIG_TOUCHSCREEN_TOUCHWIN=m
++CONFIG_TOUCHSCREEN_TPS6507X=m
++CONFIG_TOUCHSCREEN_TSC2004=m
++CONFIG_TOUCHSCREEN_TSC2005=m
++CONFIG_TOUCHSCREEN_TSC2007=m
++CONFIG_TOUCHSCREEN_TSC200X_CORE=m
++CONFIG_TOUCHSCREEN_TSC_SERIO=m
++CONFIG_TOUCHSCREEN_UCB1400=m
++CONFIG_TOUCHSCREEN_USB_3M=y
++CONFIG_TOUCHSCREEN_USB_COMPOSITE=m
++CONFIG_TOUCHSCREEN_USB_DMC_TSC10=y
++CONFIG_TOUCHSCREEN_USB_E2I=y
++CONFIG_TOUCHSCREEN_USB_EASYTOUCH=y
++CONFIG_TOUCHSCREEN_USB_EGALAX=y
++CONFIG_TOUCHSCREEN_USB_ELO=y
++CONFIG_TOUCHSCREEN_USB_ETT_TC45USB=y
++CONFIG_TOUCHSCREEN_USB_ETURBO=y
++CONFIG_TOUCHSCREEN_USB_GENERAL_TOUCH=y
++CONFIG_TOUCHSCREEN_USB_GOTOP=y
++CONFIG_TOUCHSCREEN_USB_GUNZE=y
++CONFIG_TOUCHSCREEN_USB_IDEALTEK=y
++CONFIG_TOUCHSCREEN_USB_IRTOUCH=y
++CONFIG_TOUCHSCREEN_USB_ITM=y
++CONFIG_TOUCHSCREEN_USB_JASTEC=y
++CONFIG_TOUCHSCREEN_USB_NEXIO=y
++CONFIG_TOUCHSCREEN_USB_PANJIT=y
++CONFIG_TOUCHSCREEN_USB_ZYTRONIC=y
++CONFIG_TOUCHSCREEN_WACOM_I2C=m
++CONFIG_TOUCHSCREEN_WACOM_W8001=m
++CONFIG_TOUCHSCREEN_WDT87XX_I2C=m
++CONFIG_TOUCHSCREEN_WM831X=m
++CONFIG_TOUCHSCREEN_WM9705=y
++CONFIG_TOUCHSCREEN_WM9712=y
++CONFIG_TOUCHSCREEN_WM9713=y
++CONFIG_TOUCHSCREEN_WM97XX=m
++CONFIG_TOUCHSCREEN_ZFORCE=m
++CONFIG_TPS6105X=m
++CONFIG_TPS65010=m
++CONFIG_TPS6507X=m
++# CONFIG_TQM8540 is not set
++# CONFIG_TQM8541 is not set
++# CONFIG_TQM8548 is not set
++# CONFIG_TQM8555 is not set
++# CONFIG_TQM8560 is not set
++CONFIG_TRACEPOINTS=y
++# CONFIG_TRACEPOINT_BENCHMARK is not set
++CONFIG_TRACER_MAX_TRACE=y
++CONFIG_TRACER_SNAPSHOT=y
++# CONFIG_TRACER_SNAPSHOT_PER_CPU_SWAP is not set
++CONFIG_TRACE_CLOCK=y
++# CONFIG_TRACE_ENUM_MAP_FILE is not set
++CONFIG_TRACE_IRQFLAGS_SUPPORT=y
++CONFIG_TRACE_ROUTER=m
++CONFIG_TRACING=y
++CONFIG_TRACING_EVENTS_GPIO=y
++CONFIG_TRACING_SUPPORT=y
++CONFIG_TRANSPARENT_HUGEPAGE=y
++CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS=y
++# CONFIG_TRANSPARENT_HUGEPAGE_MADVISE is not set
++CONFIG_TREE_RCU=y
++# CONFIG_TREE_RCU_TRACE is not set
++CONFIG_TRUSTED_FOUNDATIONS=y
++CONFIG_TRUSTED_KEYS=y
++CONFIG_TSL2583=m
++CONFIG_TSL2x7x=m
++CONFIG_TSL4531=m
++CONFIG_TSYS01=m
++CONFIG_TSYS02D=m
++CONFIG_TTPCI_EEPROM=m
++CONFIG_TTY=y
++CONFIG_TULIP=m
++# CONFIG_TULIP_MMIO is not set
++# CONFIG_TULIP_MWI is not set
++# CONFIG_TULIP_NAPI is not set
++CONFIG_TUN=y
++# CONFIG_TUNE_DEFAULT is not set
++# CONFIG_TUNE_Z10 is not set
++# CONFIG_TUNE_Z13 is not set
++# CONFIG_TUNE_Z196 is not set
++# CONFIG_TUNE_Z900 is not set
++# CONFIG_TUNE_Z990 is not set
++# CONFIG_TUNE_Z9_109 is not set
++CONFIG_TUNE_ZEC12=y
++# CONFIG_TUN_VNET_CROSS_LE is not set
++CONFIG_TWL4030_CORE=y
++CONFIG_TWL4030_MADC=m
++CONFIG_TWL4030_POWER=y
++CONFIG_TWL4030_USB=m
++CONFIG_TWL4030_WATCHDOG=m
++CONFIG_TWL6030_GPADC=m
++CONFIG_TWL6030_USB=m
++CONFIG_TWL6040_CORE=y
++CONFIG_TWR_P102x=y
++CONFIG_TYPHOON=m
++# CONFIG_UACCESS_WITH_MEMCPY is not set
++CONFIG_UBIFS_ATIME_SUPPORT=y
++CONFIG_UBIFS_FS=m
++# CONFIG_UBIFS_FS_ADVANCED_COMPR is not set
++CONFIG_UBIFS_FS_LZO=y
++CONFIG_UBIFS_FS_ZLIB=y
++CONFIG_UCB1400_CORE=m
++CONFIG_UCS2_STRING=y
++CONFIG_UDF_FS=m
++CONFIG_UDF_NLS=y
++CONFIG_UEFI_CPER=y
++CONFIG_UEVENT_HELPER=y
++CONFIG_UEVENT_HELPER_PATH=""
++# CONFIG_UFS_DEBUG is not set
++# CONFIG_UFS_FS_WRITE is not set
++CONFIG_UHID=m
++CONFIG_UID16=y
++CONFIG_UIO_AEC=m
++CONFIG_UIO_CIF=m
++CONFIG_UIO_DMEM_GENIRQ=m
++CONFIG_UIO_FSL_ELBC_GPCM=m
++# CONFIG_UIO_FSL_ELBC_GPCM_NETX5152 is not set
++CONFIG_UIO_MF624=m
++CONFIG_UIO_NETX=m
++CONFIG_UIO_PCI_GENERIC=m
++CONFIG_UIO_PDRV_GENIRQ=m
++CONFIG_UIO_PRUSS=m
++CONFIG_UIO_SERCOS3=m
++CONFIG_ULI526X=m
++CONFIG_ULTRA=m
++CONFIG_UNCOMPRESS_INCLUDE="debug/uncompress.h"
++CONFIG_UNINLINE_SPIN_UNLOCK=y
++CONFIG_UNISYSSPAR=y
++CONFIG_UNISYS_VISORBUS=m
++CONFIG_UNISYS_VISORHBA=m
++CONFIG_UNISYS_VISORINPUT=m
++CONFIG_UNISYS_VISORNIC=m
++CONFIG_UNIX=y
++CONFIG_UNIX98_PTYS=y
++CONFIG_UNIX_DIAG=m
++CONFIG_UNUSED_SYMBOLS=y
++CONFIG_UPROBE_EVENT=y
++CONFIG_US5182D=m
++CONFIG_USB=y
++CONFIG_USBIP_CORE=m
++# CONFIG_USBIP_DEBUG is not set
++CONFIG_USBIP_HOST=m
++CONFIG_USBIP_VHCI_HCD=m
++CONFIG_USBPCWATCHDOG=m
++CONFIG_USB_ACM=m
++CONFIG_USB_ADUTUX=m
++CONFIG_USB_AIRSPY=m
++CONFIG_USB_ALI_M5632=y
++CONFIG_USB_AMD5536UDC=m
++CONFIG_USB_AN2720=y
++CONFIG_USB_ANNOUNCE_NEW_DEVICES=y
++CONFIG_USB_APPLEDISPLAY=m
++CONFIG_USB_ARCH_HAS_HCD=y
++CONFIG_USB_ARMLINUX=y
++CONFIG_USB_ATM=m
++CONFIG_USB_AUDIO=m
++CONFIG_USB_BDC_PCI=m
++CONFIG_USB_BDC_UDC=m
++CONFIG_USB_BELKIN=y
++CONFIG_USB_C67X00_HCD=m
++CONFIG_USB_CATC=m
++CONFIG_USB_CDC_COMPOSITE=m
++CONFIG_USB_CDC_PHONET=m
++CONFIG_USB_CHAOSKEY=m
++CONFIG_USB_CHIPIDEA=m
++# CONFIG_USB_CHIPIDEA_DEBUG is not set
++CONFIG_USB_CHIPIDEA_HOST=y
++CONFIG_USB_CHIPIDEA_OF=m
++CONFIG_USB_CHIPIDEA_PCI=m
++CONFIG_USB_CHIPIDEA_UDC=y
++CONFIG_USB_COMMON=y
++CONFIG_USB_CONFIGFS=m
++CONFIG_USB_CONFIGFS_ACM=y
++CONFIG_USB_CONFIGFS_ECM=y
++CONFIG_USB_CONFIGFS_ECM_SUBSET=y
++CONFIG_USB_CONFIGFS_EEM=y
++CONFIG_USB_CONFIGFS_F_FS=y
++CONFIG_USB_CONFIGFS_F_HID=y
++CONFIG_USB_CONFIGFS_F_LB_SS=y
++CONFIG_USB_CONFIGFS_F_MIDI=y
++CONFIG_USB_CONFIGFS_F_PRINTER=y
++CONFIG_USB_CONFIGFS_F_UAC1=y
++CONFIG_USB_CONFIGFS_F_UAC2=y
++CONFIG_USB_CONFIGFS_F_UVC=y
++CONFIG_USB_CONFIGFS_MASS_STORAGE=y
++CONFIG_USB_CONFIGFS_NCM=y
++CONFIG_USB_CONFIGFS_OBEX=y
++CONFIG_USB_CONFIGFS_PHONET=y
++CONFIG_USB_CONFIGFS_RNDIS=y
++CONFIG_USB_CONFIGFS_SERIAL=y
++CONFIG_USB_CXACRU=m
++CONFIG_USB_CYPRESS_CY7C63=m
++CONFIG_USB_CYTHERM=m
++CONFIG_USB_DEFAULT_PERSIST=y
++CONFIG_USB_DSBR=m
++# CONFIG_USB_DUMMY_HCD is not set
++CONFIG_USB_DWC2=y
++# CONFIG_USB_DWC2_DEBUG is not set
++# CONFIG_USB_DWC2_DUAL_ROLE is not set
++CONFIG_USB_DWC2_HOST=y
++CONFIG_USB_DWC2_PCI=y
++# CONFIG_USB_DWC2_PERIPHERAL is not set
++# CONFIG_USB_DWC2_TRACK_MISSED_SOFS is not set
++CONFIG_USB_DWC3=m
++CONFIG_USB_DWC3_DUAL_ROLE=y
++CONFIG_USB_DWC3_EXYNOS=m
++# CONFIG_USB_DWC3_GADGET is not set
++# CONFIG_USB_DWC3_HOST is not set
++CONFIG_USB_DWC3_OMAP=m
++CONFIG_USB_DWC3_PCI=m
++CONFIG_USB_DWC3_QCOM=m
++CONFIG_USB_DWC3_ULPI=y
++CONFIG_USB_DYNAMIC_MINORS=y
++CONFIG_USB_EG20T=m
++CONFIG_USB_EHCI_BIG_ENDIAN_DESC=y
++CONFIG_USB_EHCI_BIG_ENDIAN_MMIO=y
++CONFIG_USB_EHCI_EXYNOS=y
++CONFIG_USB_EHCI_FSL=y
++CONFIG_USB_EHCI_HCD=y
++CONFIG_USB_EHCI_HCD_OMAP=m
++CONFIG_USB_EHCI_HCD_ORION=y
++CONFIG_USB_EHCI_HCD_PPC_OF=y
++CONFIG_USB_EHCI_MSM=m
++CONFIG_USB_EHCI_MXC=m
++CONFIG_USB_EHCI_PCI=y
++CONFIG_USB_EHCI_ROOT_HUB_TT=y
++CONFIG_USB_EHCI_TEGRA=m
++CONFIG_USB_EHCI_TT_NEWSCHED=y
++CONFIG_USB_EHSET_TEST_FIXTURE=m
++CONFIG_USB_EMI26=m
++CONFIG_USB_EMI62=m
++CONFIG_USB_EMXX=y
++CONFIG_USB_EPSON2888=y
++CONFIG_USB_ETH=m
++CONFIG_USB_ETH_EEM=y
++CONFIG_USB_ETH_RNDIS=y
++CONFIG_USB_EZUSB_FX2=m
++CONFIG_USB_FOTG210_HCD=m
++CONFIG_USB_FOTG210_UDC=m
++CONFIG_USB_FSL_QE=m
++CONFIG_USB_FSL_USB2=m
++CONFIG_USB_FTDI_ELAN=m
++CONFIG_USB_FUNCTIONFS=m
++CONFIG_USB_FUNCTIONFS_ETH=y
++CONFIG_USB_FUNCTIONFS_GENERIC=y
++CONFIG_USB_FUNCTIONFS_RNDIS=y
++CONFIG_USB_FUSB300=m
++CONFIG_USB_F_ACM=m
++CONFIG_USB_F_ECM=m
++CONFIG_USB_F_EEM=m
++CONFIG_USB_F_FS=m
++CONFIG_USB_F_HID=m
++CONFIG_USB_F_MASS_STORAGE=m
++CONFIG_USB_F_MIDI=m
++CONFIG_USB_F_NCM=m
++CONFIG_USB_F_OBEX=m
++CONFIG_USB_F_PHONET=m
++CONFIG_USB_F_PRINTER=m
++CONFIG_USB_F_RNDIS=m
++CONFIG_USB_F_SERIAL=m
++CONFIG_USB_F_SS_LB=m
++CONFIG_USB_F_SUBSET=m
++CONFIG_USB_F_UAC1=m
++CONFIG_USB_F_UAC2=m
++CONFIG_USB_F_UVC=m
++CONFIG_USB_GADGETFS=m
++# CONFIG_USB_GADGET_DEBUG is not set
++# CONFIG_USB_GADGET_DEBUG_FILES is not set
++# CONFIG_USB_GADGET_DEBUG_FS is not set
++CONFIG_USB_GADGET_STORAGE_NUM_BUFFERS=2
++CONFIG_USB_GADGET_TARGET=m
++CONFIG_USB_GADGET_VBUS_DRAW=2
++CONFIG_USB_GADGET_XILINX=m
++CONFIG_USB_GL860=m
++CONFIG_USB_GOKU=m
++CONFIG_USB_GPIO_VBUS=m
++CONFIG_USB_GR_UDC=m
++CONFIG_USB_GSPCA=m
++CONFIG_USB_GSPCA_BENQ=m
++CONFIG_USB_GSPCA_CONEX=m
++CONFIG_USB_GSPCA_CPIA1=m
++CONFIG_USB_GSPCA_DTCS033=m
++CONFIG_USB_GSPCA_ETOMS=m
++CONFIG_USB_GSPCA_FINEPIX=m
++CONFIG_USB_GSPCA_JEILINJ=m
++CONFIG_USB_GSPCA_JL2005BCD=m
++CONFIG_USB_GSPCA_KINECT=m
++CONFIG_USB_GSPCA_KONICA=m
++CONFIG_USB_GSPCA_MARS=m
++CONFIG_USB_GSPCA_MR97310A=m
++CONFIG_USB_GSPCA_NW80X=m
++CONFIG_USB_GSPCA_OV519=m
++CONFIG_USB_GSPCA_OV534=m
++CONFIG_USB_GSPCA_OV534_9=m
++CONFIG_USB_GSPCA_PAC207=m
++CONFIG_USB_GSPCA_PAC7302=m
++CONFIG_USB_GSPCA_PAC7311=m
++CONFIG_USB_GSPCA_SE401=m
++CONFIG_USB_GSPCA_SN9C2028=m
++CONFIG_USB_GSPCA_SN9C20X=m
++CONFIG_USB_GSPCA_SONIXB=m
++CONFIG_USB_GSPCA_SONIXJ=m
++CONFIG_USB_GSPCA_SPCA1528=m
++CONFIG_USB_GSPCA_SPCA500=m
++CONFIG_USB_GSPCA_SPCA501=m
++CONFIG_USB_GSPCA_SPCA505=m
++CONFIG_USB_GSPCA_SPCA506=m
++CONFIG_USB_GSPCA_SPCA508=m
++CONFIG_USB_GSPCA_SPCA561=m
++CONFIG_USB_GSPCA_SQ905=m
++CONFIG_USB_GSPCA_SQ905C=m
++CONFIG_USB_GSPCA_SQ930X=m
++CONFIG_USB_GSPCA_STK014=m
++CONFIG_USB_GSPCA_STK1135=m
++CONFIG_USB_GSPCA_STV0680=m
++CONFIG_USB_GSPCA_SUNPLUS=m
++CONFIG_USB_GSPCA_T613=m
++CONFIG_USB_GSPCA_TOPRO=m
++CONFIG_USB_GSPCA_TOUPTEK=m
++CONFIG_USB_GSPCA_TV8532=m
++CONFIG_USB_GSPCA_VC032X=m
++CONFIG_USB_GSPCA_VICAM=m
++CONFIG_USB_GSPCA_XIRLINK_CIT=m
++CONFIG_USB_GSPCA_ZC3XX=m
++CONFIG_USB_G_ACM_MS=m
++CONFIG_USB_G_DBGP=m
++# CONFIG_USB_G_DBGP_PRINTK is not set
++CONFIG_USB_G_DBGP_SERIAL=y
++CONFIG_USB_G_HID=m
++CONFIG_USB_G_MULTI_CDC=y
++CONFIG_USB_G_MULTI_RNDIS=y
++CONFIG_USB_G_NCM=m
++CONFIG_USB_G_NOKIA=m
++CONFIG_USB_G_PRINTER=m
++CONFIG_USB_G_SERIAL=m
++CONFIG_USB_G_WEBCAM=m
++CONFIG_USB_HACKRF=m
++# CONFIG_USB_HCD_TEST_MODE is not set
++CONFIG_USB_HID=m
++CONFIG_USB_HIDDEV=y
++CONFIG_USB_HSIC_USB3503=m
++CONFIG_USB_HSO=m
++CONFIG_USB_HWA_HCD=m
++CONFIG_USB_IDMOUSE=m
++CONFIG_USB_IMX21_HCD=m
++CONFIG_USB_IOWARRIOR=m
++CONFIG_USB_IPHETH=m
++CONFIG_USB_IRDA=m
++CONFIG_USB_ISIGHTFW=m
++CONFIG_USB_ISP116X_HCD=m
++CONFIG_USB_ISP1301=m
++CONFIG_USB_ISP1362_HCD=m
++CONFIG_USB_ISP1760=m
++CONFIG_USB_ISP1760_DUAL_ROLE=y
++# CONFIG_USB_ISP1760_GADGET_ROLE is not set
++CONFIG_USB_ISP1760_HCD=y
++# CONFIG_USB_ISP1760_HOST_ROLE is not set
++CONFIG_USB_ISP1761_UDC=y
++CONFIG_USB_KAWETH=m
++CONFIG_USB_KBD=m
++CONFIG_USB_KC2190=y
++CONFIG_USB_KEENE=m
++CONFIG_USB_LAN78XX=m
++CONFIG_USB_LCD=m
++CONFIG_USB_LD=m
++CONFIG_USB_LED=m
++CONFIG_USB_LED_TRIG=y
++CONFIG_USB_LEGOTOWER=m
++CONFIG_USB_LIBCOMPOSITE=m
++CONFIG_USB_LINK_LAYER_TEST=m
++CONFIG_USB_M5602=m
++# CONFIG_USB_M66592 is not set
++CONFIG_USB_MA901=m
++CONFIG_USB_MASS_STORAGE=m
++CONFIG_USB_MAX3421_HCD=m
++CONFIG_USB_MDC800=m
++CONFIG_USB_MICROTEK=m
++CONFIG_USB_MIDI_GADGET=m
++CONFIG_USB_MON=m
++CONFIG_USB_MOUSE=m
++CONFIG_USB_MR800=m
++CONFIG_USB_MSI2500=m
++CONFIG_USB_MSM_OTG=m
++CONFIG_USB_MUSB_AM335X_CHILD=m
++CONFIG_USB_MUSB_AM35X=m
++CONFIG_USB_MUSB_DSPS=m
++CONFIG_USB_MUSB_DUAL_ROLE=y
++# CONFIG_USB_MUSB_GADGET is not set
++# CONFIG_USB_MUSB_HOST is not set
++CONFIG_USB_MUSB_OMAP2PLUS=m
++CONFIG_USB_MUSB_TUSB6010=m
++CONFIG_USB_MV_U3D=m
++CONFIG_USB_MV_UDC=m
++CONFIG_USB_MXS_PHY=y
++CONFIG_USB_NET2272=m
++CONFIG_USB_NET2272_DMA=y
++CONFIG_USB_NET2280=m
++CONFIG_USB_NET_AX88179_178A=m
++CONFIG_USB_NET_AX8817X=m
++CONFIG_USB_NET_CDCETHER=m
++CONFIG_USB_NET_CDC_EEM=m
++CONFIG_USB_NET_CDC_MBIM=m
++CONFIG_USB_NET_CDC_NCM=m
++CONFIG_USB_NET_CDC_SUBSET=m
++CONFIG_USB_NET_CH9200=m
++CONFIG_USB_NET_CX82310_ETH=m
++CONFIG_USB_NET_DM9601=m
++CONFIG_USB_NET_DRIVERS=m
++CONFIG_USB_NET_GL620A=m
++CONFIG_USB_NET_HUAWEI_CDC_NCM=m
++CONFIG_USB_NET_INT51X1=m
++CONFIG_USB_NET_KALMIA=m
++CONFIG_USB_NET_MCS7830=m
++CONFIG_USB_NET_NET1080=m
++CONFIG_USB_NET_PLUSB=m
++CONFIG_USB_NET_QMI_WWAN=m
++CONFIG_USB_NET_RNDIS_HOST=m
++CONFIG_USB_NET_RNDIS_WLAN=m
++CONFIG_USB_NET_SMSC75XX=m
++CONFIG_USB_NET_SMSC95XX=m
++CONFIG_USB_NET_SR9700=m
++CONFIG_USB_NET_SR9800=m
++CONFIG_USB_NET_ZAURUS=m
++CONFIG_USB_OHCI_BIG_ENDIAN_DESC=y
++CONFIG_USB_OHCI_BIG_ENDIAN_MMIO=y
++CONFIG_USB_OHCI_EXYNOS=y
++CONFIG_USB_OHCI_HCD=y
++CONFIG_USB_OHCI_HCD_OMAP3=m
++CONFIG_USB_OHCI_HCD_PCI=y
++# CONFIG_USB_OHCI_HCD_PPC_OF_LE is not set
++CONFIG_USB_OHCI_LITTLE_ENDIAN=y
++# CONFIG_USB_OTG is not set
++# CONFIG_USB_OTG_BLACKLIST_HUB is not set
++# CONFIG_USB_OTG_WHITELIST is not set
++CONFIG_USB_OXU210HP_HCD=m
++CONFIG_USB_PEGASUS=m
++CONFIG_USB_PHY=y
++CONFIG_USB_PRINTER=m
++CONFIG_USB_PWC=m
++# CONFIG_USB_PWC_DEBUG is not set
++CONFIG_USB_PWC_INPUT_EVDEV=y
++CONFIG_USB_PXA27X=m
++CONFIG_USB_QCOM_8X16_PHY=m
++CONFIG_USB_R8A66597=m
++CONFIG_USB_R8A66597_HCD=m
++CONFIG_USB_RAREMONO=m
++CONFIG_USB_RCAR_PHY=m
++CONFIG_USB_RENESAS_USBHS=m
++CONFIG_USB_RENESAS_USBHS_HCD=m
++CONFIG_USB_RENESAS_USBHS_UDC=m
++CONFIG_USB_RIO500=m
++CONFIG_USB_RTL8150=m
++CONFIG_USB_RTL8152=m
++CONFIG_USB_S2255=m
++CONFIG_USB_SERIAL=m
++CONFIG_USB_SERIAL_AIRCABLE=m
++CONFIG_USB_SERIAL_ARK3116=m
++CONFIG_USB_SERIAL_BELKIN=m
++CONFIG_USB_SERIAL_CH341=m
++CONFIG_USB_SERIAL_CP210X=m
++CONFIG_USB_SERIAL_CYBERJACK=m
++CONFIG_USB_SERIAL_CYPRESS_M8=m
++CONFIG_USB_SERIAL_DEBUG=m
++CONFIG_USB_SERIAL_DIGI_ACCELEPORT=m
++CONFIG_USB_SERIAL_EDGEPORT=m
++CONFIG_USB_SERIAL_EDGEPORT_TI=m
++CONFIG_USB_SERIAL_EMPEG=m
++CONFIG_USB_SERIAL_F81232=m
++CONFIG_USB_SERIAL_FTDI_SIO=m
++CONFIG_USB_SERIAL_GARMIN=m
++CONFIG_USB_SERIAL_GENERIC=y
++CONFIG_USB_SERIAL_IPAQ=m
++CONFIG_USB_SERIAL_IPW=m
++CONFIG_USB_SERIAL_IR=m
++CONFIG_USB_SERIAL_IUU=m
++CONFIG_USB_SERIAL_KEYSPAN=m
++CONFIG_USB_SERIAL_KEYSPAN_MPR=y
++CONFIG_USB_SERIAL_KEYSPAN_PDA=m
++CONFIG_USB_SERIAL_KEYSPAN_USA18X=y
++CONFIG_USB_SERIAL_KEYSPAN_USA19=y
++CONFIG_USB_SERIAL_KEYSPAN_USA19QI=y
++CONFIG_USB_SERIAL_KEYSPAN_USA19QW=y
++CONFIG_USB_SERIAL_KEYSPAN_USA19W=y
++CONFIG_USB_SERIAL_KEYSPAN_USA28=y
++CONFIG_USB_SERIAL_KEYSPAN_USA28X=y
++CONFIG_USB_SERIAL_KEYSPAN_USA28XA=y
++CONFIG_USB_SERIAL_KEYSPAN_USA28XB=y
++CONFIG_USB_SERIAL_KEYSPAN_USA49W=y
++CONFIG_USB_SERIAL_KEYSPAN_USA49WLC=y
++CONFIG_USB_SERIAL_KLSI=m
++CONFIG_USB_SERIAL_KOBIL_SCT=m
++CONFIG_USB_SERIAL_MCT_U232=m
++CONFIG_USB_SERIAL_METRO=m
++CONFIG_USB_SERIAL_MOS7715_PARPORT=y
++CONFIG_USB_SERIAL_MOS7720=m
++CONFIG_USB_SERIAL_MOS7840=m
++CONFIG_USB_SERIAL_MXUPORT=m
++CONFIG_USB_SERIAL_NAVMAN=m
++CONFIG_USB_SERIAL_OMNINET=m
++CONFIG_USB_SERIAL_OPTICON=m
++CONFIG_USB_SERIAL_OPTION=m
++CONFIG_USB_SERIAL_OTI6858=m
++CONFIG_USB_SERIAL_PL2303=m
++CONFIG_USB_SERIAL_QCAUX=m
++CONFIG_USB_SERIAL_QT2=m
++CONFIG_USB_SERIAL_QUALCOMM=m
++CONFIG_USB_SERIAL_SAFE=m
++# CONFIG_USB_SERIAL_SAFE_PADDED is not set
++CONFIG_USB_SERIAL_SIERRAWIRELESS=m
++CONFIG_USB_SERIAL_SIMPLE=m
++CONFIG_USB_SERIAL_SPCP8X5=m
++CONFIG_USB_SERIAL_SSU100=m
++CONFIG_USB_SERIAL_SYMBOL=m
++CONFIG_USB_SERIAL_TI=m
++CONFIG_USB_SERIAL_VISOR=m
++CONFIG_USB_SERIAL_WHITEHEAT=m
++CONFIG_USB_SERIAL_WISHBONE=m
++CONFIG_USB_SERIAL_WWAN=m
++CONFIG_USB_SERIAL_XIRCOM=m
++CONFIG_USB_SERIAL_XSENS_MT=m
++CONFIG_USB_SEVSEG=m
++CONFIG_USB_SI470X=m
++CONFIG_USB_SI4713=m
++CONFIG_USB_SIERRA_NET=m
++CONFIG_USB_SISUSBVGA=m
++# CONFIG_USB_SISUSBVGA_CON is not set
++CONFIG_USB_SL811_CS=m
++CONFIG_USB_SL811_HCD=m
++CONFIG_USB_SL811_HCD_ISO=y
++CONFIG_USB_SPEEDTOUCH=m
++CONFIG_USB_STKWEBCAM=m
++CONFIG_USB_STORAGE=m
++CONFIG_USB_STORAGE_ALAUDA=m
++CONFIG_USB_STORAGE_CYPRESS_ATACB=m
++CONFIG_USB_STORAGE_DATAFAB=m
++# CONFIG_USB_STORAGE_DEBUG is not set
++CONFIG_USB_STORAGE_ENE_UB6250=m
++CONFIG_USB_STORAGE_FREECOM=m
++CONFIG_USB_STORAGE_ISD200=m
++CONFIG_USB_STORAGE_JUMPSHOT=m
++CONFIG_USB_STORAGE_KARMA=m
++CONFIG_USB_STORAGE_ONETOUCH=m
++CONFIG_USB_STORAGE_REALTEK=m
++CONFIG_USB_STORAGE_SDDR09=m
++CONFIG_USB_STORAGE_SDDR55=m
++CONFIG_USB_STORAGE_USBAT=m
++CONFIG_USB_STV06XX=m
++CONFIG_USB_SWITCH_FSA9480=m
++CONFIG_USB_TEST=m
++CONFIG_USB_TMC=m
++CONFIG_USB_TRANCEVIBRATOR=m
++CONFIG_USB_U132_HCD=m
++CONFIG_USB_UAS=m
++CONFIG_USB_UEAGLEATM=m
++CONFIG_USB_UHCI_HCD=y
++CONFIG_USB_ULPI=y
++CONFIG_USB_ULPI_BUS=m
++CONFIG_USB_ULPI_VIEWPORT=y
++CONFIG_USB_USBNET=m
++CONFIG_USB_USS720=m
++CONFIG_USB_U_ETHER=m
++CONFIG_USB_U_SERIAL=m
++CONFIG_USB_VIDEO_CLASS=m
++CONFIG_USB_VIDEO_CLASS_INPUT_EVDEV=y
++CONFIG_USB_VL600=m
++CONFIG_USB_WDM=m
++CONFIG_USB_WHCI_HCD=m
++CONFIG_USB_WUSB=m
++CONFIG_USB_WUSB_CBAF=m
++# CONFIG_USB_WUSB_CBAF_DEBUG is not set
++CONFIG_USB_XHCI_HCD=y
++CONFIG_USB_XHCI_MVEBU=m
++CONFIG_USB_XHCI_PCI=y
++CONFIG_USB_XHCI_PLATFORM=m
++CONFIG_USB_XHCI_RCAR=m
++CONFIG_USB_XUSBATM=m
++CONFIG_USB_YUREX=m
++CONFIG_USB_ZD1201=m
++CONFIG_USB_ZERO=m
++CONFIG_USB_ZR364XX=m
++CONFIG_USELIB=y
++CONFIG_USERFAULTFD=y
++CONFIG_USERIO=m
++CONFIG_USER_NS=y
++CONFIG_USER_RETURN_NOTIFIER=y
++CONFIG_USER_STACKTRACE_SUPPORT=y
++CONFIG_USE_OF=y
++CONFIG_USE_PERCPU_NUMA_NODE_ID=y
++CONFIG_UTS_NS=y
++CONFIG_UWB_HWA=m
++CONFIG_UWB_I1480U=m
++CONFIG_UWB_WHCI=m
++CONFIG_V4L2_FLASH_LED_CLASS=m
++CONFIG_V4L2_MEM2MEM_DEV=m
++CONFIG_V4L_MEM2MEM_DRIVERS=y
++CONFIG_V4L_PLATFORM_DRIVERS=y
++CONFIG_V4L_RADIO_ISA_DRIVERS=y
++CONFIG_V4L_TEST_DRIVERS=y
++CONFIG_VCNL4000=m
++CONFIG_VDSO=y
++CONFIG_VDSO32=y
++CONFIG_VECTORS_BASE=0xffff0000
++CONFIG_VEN_RSI_91X=m
++# CONFIG_VEN_RSI_BT_ALONE is not set
++CONFIG_VEN_RSI_COEX=y
++CONFIG_VEN_RSI_DEBUGFS=y
++# CONFIG_VEN_RSI_P2P is not set
++CONFIG_VEN_RSI_SDIO=m
++CONFIG_VEN_RSI_USB=m
++CONFIG_VEN_RSI_WOW=y
++CONFIG_VERSION_SIGNATURE=""
++CONFIG_VETH=m
++CONFIG_VEXPRESS_CONFIG=y
++CONFIG_VEXPRESS_SYSCFG=y
++CONFIG_VF610_ADC=m
++CONFIG_VFAT_FS=y
++CONFIG_VFIO_AMBA=m
++CONFIG_VFIO_PCI_INTX=y
++CONFIG_VFIO_PCI_MMAP=y
++CONFIG_VFIO_PCI_VGA=y
++CONFIG_VFIO_PLATFORM=m
++CONFIG_VFIO_PLATFORM_AMDXGBE_RESET=m
++CONFIG_VFIO_PLATFORM_CALXEDAXGMAC_RESET=m
++CONFIG_VFP=y
++CONFIG_VFPv3=y
++CONFIG_VF_USE_ARM_GLOBAL_TIMER=y
++# CONFIG_VF_USE_PIT_TIMER is not set
++# CONFIG_VGACON_SOFT_SCROLLBACK is not set
++CONFIG_VGA_ARB=y
++CONFIG_VGA_ARB_MAX_GPUS=16
++CONFIG_VGA_CONSOLE=y
++CONFIG_VGA_SWITCHEROO=y
++CONFIG_VHOST=m
++# CONFIG_VHOST_CROSS_ENDIAN_LEGACY is not set
++CONFIG_VHOST_NET=m
++CONFIG_VHOST_RING=m
++CONFIG_VHOST_SCSI=m
++CONFIG_VIA_FIR=m
++CONFIG_VIA_RHINE=m
++CONFIG_VIA_RHINE_MMIO=y
++CONFIG_VIA_VELOCITY=m
++CONFIG_VIA_WDT=m
++CONFIG_VIDEOBUF2_CORE=m
++CONFIG_VIDEOBUF2_DMA_CONTIG=m
++CONFIG_VIDEOBUF2_DMA_SG=m
++CONFIG_VIDEOBUF2_DVB=m
++CONFIG_VIDEOBUF2_MEMOPS=m
++CONFIG_VIDEOBUF2_VMALLOC=m
++CONFIG_VIDEOBUF_DMA_CONTIG=m
++CONFIG_VIDEOBUF_DMA_SG=m
++CONFIG_VIDEOBUF_DVB=m
++CONFIG_VIDEOBUF_GEN=m
++CONFIG_VIDEOBUF_VMALLOC=m
++CONFIG_VIDEOMODE_HELPERS=y
++CONFIG_VIDEO_ADV7170=m
++CONFIG_VIDEO_ADV7175=m
++CONFIG_VIDEO_ADV7180=m
++CONFIG_VIDEO_ADV7511=m
++CONFIG_VIDEO_ADV7604=m
++CONFIG_VIDEO_ADV7842=m
++# CONFIG_VIDEO_ADV_DEBUG is not set
++CONFIG_VIDEO_AU0828=m
++CONFIG_VIDEO_AU0828_RC=y
++CONFIG_VIDEO_AU0828_V4L2=y
++CONFIG_VIDEO_BT819=m
++CONFIG_VIDEO_BT848=m
++CONFIG_VIDEO_BT856=m
++CONFIG_VIDEO_BT866=m
++CONFIG_VIDEO_CAFE_CCIC=m
++CONFIG_VIDEO_COBALT=m
++CONFIG_VIDEO_CODA=m
++CONFIG_VIDEO_CPIA2=m
++CONFIG_VIDEO_CS5345=m
++CONFIG_VIDEO_CS53L32A=m
++CONFIG_VIDEO_CX18=m
++CONFIG_VIDEO_CX18_ALSA=m
++CONFIG_VIDEO_CX231XX=m
++CONFIG_VIDEO_CX231XX_ALSA=m
++CONFIG_VIDEO_CX231XX_DVB=m
++CONFIG_VIDEO_CX231XX_RC=y
++CONFIG_VIDEO_CX2341X=m
++CONFIG_VIDEO_CX23885=m
++CONFIG_VIDEO_CX25821=m
++CONFIG_VIDEO_CX25821_ALSA=m
++CONFIG_VIDEO_CX25840=m
++CONFIG_VIDEO_CX88=m
++CONFIG_VIDEO_CX88_ALSA=m
++CONFIG_VIDEO_CX88_BLACKBIRD=m
++CONFIG_VIDEO_CX88_DVB=m
++CONFIG_VIDEO_CX88_ENABLE_VP3054=y
++CONFIG_VIDEO_CX88_MPEG=m
++CONFIG_VIDEO_CX88_VP3054=m
++CONFIG_VIDEO_DEV=m
++CONFIG_VIDEO_DT3155=m
++CONFIG_VIDEO_EM28XX=m
++CONFIG_VIDEO_EM28XX_ALSA=m
++CONFIG_VIDEO_EM28XX_DVB=m
++CONFIG_VIDEO_EM28XX_RC=m
++CONFIG_VIDEO_EM28XX_V4L2=m
++CONFIG_VIDEO_FB_IVTV=m
++# CONFIG_VIDEO_FIXED_MINOR_RANGES is not set
++CONFIG_VIDEO_GO7007=m
++CONFIG_VIDEO_GO7007_LOADER=m
++CONFIG_VIDEO_GO7007_USB=m
++CONFIG_VIDEO_GO7007_USB_S2250_BOARD=m
++CONFIG_VIDEO_HDPVR=m
++CONFIG_VIDEO_HEXIUM_GEMINI=m
++CONFIG_VIDEO_HEXIUM_ORION=m
++CONFIG_VIDEO_IR_I2C=m
++CONFIG_VIDEO_IVTV=m
++CONFIG_VIDEO_IVTV_ALSA=m
++CONFIG_VIDEO_KS0127=m
++CONFIG_VIDEO_M52790=m
++CONFIG_VIDEO_MEM2MEM_DEINTERLACE=m
++CONFIG_VIDEO_MEYE=m
++CONFIG_VIDEO_MSP3400=m
++CONFIG_VIDEO_MT9V011=m
++CONFIG_VIDEO_MX3=m
++CONFIG_VIDEO_MXB=m
++CONFIG_VIDEO_OMAP2_VOUT=m
++CONFIG_VIDEO_OMAP2_VOUT_VRFB=y
++CONFIG_VIDEO_OMAP3=m
++# CONFIG_VIDEO_OMAP3_DEBUG is not set
++CONFIG_VIDEO_OV7640=m
++CONFIG_VIDEO_OV7670=m
++CONFIG_VIDEO_PVRUSB2=m
++# CONFIG_VIDEO_PVRUSB2_DEBUGIFC is not set
++CONFIG_VIDEO_PVRUSB2_DVB=y
++CONFIG_VIDEO_PVRUSB2_SYSFS=y
++CONFIG_VIDEO_RCAR_VIN=m
++CONFIG_VIDEO_RENESAS_JPU=m
++CONFIG_VIDEO_RENESAS_VSP1=m
++CONFIG_VIDEO_SAA6588=m
++CONFIG_VIDEO_SAA6752HS=m
++CONFIG_VIDEO_SAA7110=m
++CONFIG_VIDEO_SAA711X=m
++CONFIG_VIDEO_SAA7127=m
++CONFIG_VIDEO_SAA7134=m
++CONFIG_VIDEO_SAA7134_ALSA=m
++CONFIG_VIDEO_SAA7134_DVB=m
++CONFIG_VIDEO_SAA7134_GO7007=m
++CONFIG_VIDEO_SAA7134_RC=y
++CONFIG_VIDEO_SAA7146=m
++CONFIG_VIDEO_SAA7146_VV=m
++CONFIG_VIDEO_SAA7164=m
++CONFIG_VIDEO_SAA717X=m
++CONFIG_VIDEO_SAA7185=m
++# CONFIG_VIDEO_SAMSUNG_EXYNOS4_IS is not set
++CONFIG_VIDEO_SAMSUNG_EXYNOS_GSC=m
++CONFIG_VIDEO_SAMSUNG_S5P_G2D=m
++CONFIG_VIDEO_SAMSUNG_S5P_HDMI=m
++CONFIG_VIDEO_SAMSUNG_S5P_HDMIPHY=m
++# CONFIG_VIDEO_SAMSUNG_S5P_HDMI_DEBUG is not set
++CONFIG_VIDEO_SAMSUNG_S5P_JPEG=m
++CONFIG_VIDEO_SAMSUNG_S5P_MFC=m
++CONFIG_VIDEO_SAMSUNG_S5P_MIXER=m
++# CONFIG_VIDEO_SAMSUNG_S5P_MIXER_DEBUG is not set
++CONFIG_VIDEO_SAMSUNG_S5P_SDO=m
++CONFIG_VIDEO_SAMSUNG_S5P_SII9234=m
++CONFIG_VIDEO_SAMSUNG_S5P_TV=y
++CONFIG_VIDEO_SH_MOBILE_CEU=m
++CONFIG_VIDEO_SH_MOBILE_CSI2=m
++CONFIG_VIDEO_SH_VEU=m
++CONFIG_VIDEO_SH_VOU=m
++CONFIG_VIDEO_SOLO6X10=m
++CONFIG_VIDEO_SONY_BTF_MPX=m
++CONFIG_VIDEO_STK1160=m
++CONFIG_VIDEO_STK1160_AC97=y
++CONFIG_VIDEO_STK1160_COMMON=m
++CONFIG_VIDEO_TDA7432=m
++CONFIG_VIDEO_TDA9840=m
++CONFIG_VIDEO_TEA6415C=m
++CONFIG_VIDEO_TEA6420=m
++CONFIG_VIDEO_TIMBERDALE=m
++CONFIG_VIDEO_TI_VPE=m
++# CONFIG_VIDEO_TI_VPE_DEBUG is not set
++CONFIG_VIDEO_TM6000=m
++CONFIG_VIDEO_TM6000_ALSA=m
++CONFIG_VIDEO_TM6000_DVB=m
++CONFIG_VIDEO_TUNER=m
++CONFIG_VIDEO_TVAUDIO=m
++CONFIG_VIDEO_TVEEPROM=m
++CONFIG_VIDEO_TVP5150=m
++CONFIG_VIDEO_TW2804=m
++CONFIG_VIDEO_TW68=m
++CONFIG_VIDEO_TW9903=m
++CONFIG_VIDEO_TW9906=m
++CONFIG_VIDEO_UDA1342=m
++CONFIG_VIDEO_UPD64031A=m
++CONFIG_VIDEO_UPD64083=m
++CONFIG_VIDEO_USBTV=m
++CONFIG_VIDEO_USBVISION=m
++CONFIG_VIDEO_V4L2=m
++CONFIG_VIDEO_V4L2_SUBDEV_API=y
++CONFIG_VIDEO_VIA_CAMERA=m
++CONFIG_VIDEO_VIM2M=m
++CONFIG_VIDEO_VIVID=m
++CONFIG_VIDEO_VIVID_MAX_DEVS=64
++CONFIG_VIDEO_VP27SMPX=m
++CONFIG_VIDEO_VPX3220=m
++CONFIG_VIDEO_WM8739=m
++CONFIG_VIDEO_WM8775=m
++CONFIG_VIDEO_XILINX=m
++CONFIG_VIDEO_XILINX_TPG=m
++CONFIG_VIDEO_XILINX_VTC=m
++CONFIG_VIDEO_ZORAN=m
++CONFIG_VIDEO_ZORAN_AVS6EYES=m
++CONFIG_VIDEO_ZORAN_BUZ=m
++CONFIG_VIDEO_ZORAN_DC10=m
++CONFIG_VIDEO_ZORAN_DC30=m
++CONFIG_VIDEO_ZORAN_LML33=m
++CONFIG_VIDEO_ZORAN_LML33R10=m
++CONFIG_VIDEO_ZORAN_ZR36060=m
++CONFIG_VIPERBOARD_ADC=m
++CONFIG_VIRTIO=y
++CONFIG_VIRTIO_BALLOON=y
++CONFIG_VIRTIO_BLK=y
++CONFIG_VIRTIO_CONSOLE=y
++CONFIG_VIRTIO_INPUT=m
++CONFIG_VIRTIO_MMIO_CMDLINE_DEVICES=y
++CONFIG_VIRTIO_NET=y
++CONFIG_VIRTIO_PCI=y
++CONFIG_VIRTIO_PCI_LEGACY=y
++CONFIG_VIRTUALIZATION=y
++CONFIG_VIRT_CPU_ACCOUNTING=y
++# CONFIG_VIRT_CPU_ACCOUNTING_GEN is not set
++CONFIG_VIRT_DRIVERS=y
++CONFIG_VIRT_TO_BUS=y
++CONFIG_VITESSE_PHY=m
++CONFIG_VLAN_8021Q=m
++CONFIG_VLAN_8021Q_GVRP=y
++CONFIG_VLAN_8021Q_MVRP=y
++CONFIG_VLSI_FIR=m
++CONFIG_VMCP=y
++CONFIG_VME_CA91CX42=m
++CONFIG_VME_PIO2=m
++CONFIG_VME_TSI148=m
++CONFIG_VME_USER=m
++CONFIG_VMIVME_7805=m
++CONFIG_VMLOGRDR=m
++# CONFIG_VMSPLIT_1G is not set
++# CONFIG_VMSPLIT_2G is not set
++CONFIG_VMSPLIT_3G=y
++# CONFIG_VMSPLIT_3G_OPT is not set
++CONFIG_VMWARE_BALLOON=m
++CONFIG_VMWARE_PVSCSI=m
++CONFIG_VMWARE_VMCI=m
++CONFIG_VMWARE_VMCI_VSOCKETS=m
++CONFIG_VM_EVENT_COUNTERS=y
++CONFIG_VORTEX=m
++CONFIG_VSOCKETS=m
++CONFIG_VSX=y
++CONFIG_VT=y
++CONFIG_VT6655=m
++CONFIG_VT6656=m
++CONFIG_VT_CONSOLE=y
++CONFIG_VT_CONSOLE_SLEEP=y
++CONFIG_VT_HW_CONSOLE_BINDING=y
++CONFIG_VXGE=m
++# CONFIG_VXGE_DEBUG_TRACE_ALL is not set
++CONFIG_VXLAN=m
++CONFIG_VZ89X=m
++CONFIG_W1_CON=y
++CONFIG_W1_MASTER_DS1WM=m
++CONFIG_W1_MASTER_DS2482=m
++CONFIG_W1_MASTER_DS2490=m
++CONFIG_W1_MASTER_GPIO=m
++CONFIG_W1_MASTER_MATROX=m
++CONFIG_W1_MASTER_MXC=m
++CONFIG_W1_SLAVE_BQ27000=m
++CONFIG_W1_SLAVE_DS2406=m
++CONFIG_W1_SLAVE_DS2408=m
++CONFIG_W1_SLAVE_DS2408_READBACK=y
++CONFIG_W1_SLAVE_DS2413=m
++CONFIG_W1_SLAVE_DS2423=m
++CONFIG_W1_SLAVE_DS2431=m
++CONFIG_W1_SLAVE_DS2433=m
++# CONFIG_W1_SLAVE_DS2433_CRC is not set
++CONFIG_W1_SLAVE_DS2760=m
++CONFIG_W1_SLAVE_DS2780=m
++CONFIG_W1_SLAVE_DS2781=m
++CONFIG_W1_SLAVE_DS28E04=m
++CONFIG_W1_SLAVE_SMEM=m
++CONFIG_W1_SLAVE_THERM=m
++CONFIG_W83627HF_WDT=m
++CONFIG_W83877F_WDT=m
++CONFIG_W83977F_WDT=m
++CONFIG_WAFER_WDT=m
++CONFIG_WANT_DEV_COREDUMP=y
++CONFIG_WANXL=m
++# CONFIG_WARN_DYNAMIC_STACK is not set
++CONFIG_WATCHDOG=y
++CONFIG_WATCHDOG_CORE=y
++# CONFIG_WATCHDOG_NOWAYOUT is not set
++CONFIG_WATCHDOG_RTAS=m
++CONFIG_WCN36XX=m
++# CONFIG_WCN36XX_DEBUGFS is not set
++CONFIG_WD80x3=m
++CONFIG_WDT=m
++CONFIG_WEXT_CORE=y
++CONFIG_WEXT_PRIV=y
++CONFIG_WEXT_PROC=y
++CONFIG_WEXT_SPY=y
++CONFIG_WIL6210=m
++CONFIG_WIL6210_ISR_COR=y
++CONFIG_WIL6210_TRACING=y
++# CONFIG_WILC1000_DRIVER is not set
++CONFIG_WILINK_PLATFORM_DATA=y
++CONFIG_WIMAX_DEBUG_LEVEL=8
++CONFIG_WIMAX_GDM72XX=m
++CONFIG_WIMAX_GDM72XX_K_MODE=y
++CONFIG_WIMAX_GDM72XX_QOS=y
++# CONFIG_WIMAX_GDM72XX_SDIO is not set
++CONFIG_WIMAX_GDM72XX_USB=y
++CONFIG_WIMAX_GDM72XX_USB_PM=y
++CONFIG_WIMAX_GDM72XX_WIMAX2=y
++CONFIG_WIMAX_I2400M=m
++CONFIG_WIMAX_I2400M_DEBUG_LEVEL=8
++CONFIG_WIMAX_I2400M_USB=m
++CONFIG_WINBOND_840=m
++CONFIG_WINBOND_FIR=m
++CONFIG_WINDFARM=m
++CONFIG_WINDFARM_PM112=m
++CONFIG_WINDFARM_PM121=m
++CONFIG_WINDFARM_PM72=m
++CONFIG_WINDFARM_PM81=m
++CONFIG_WINDFARM_PM91=m
++CONFIG_WINDFARM_RM31=m
++CONFIG_WIRELESS=y
++CONFIG_WIRELESS_EXT=y
++CONFIG_WIZNET_BUS_ANY=y
++# CONFIG_WIZNET_BUS_DIRECT is not set
++# CONFIG_WIZNET_BUS_INDIRECT is not set
++CONFIG_WIZNET_W5100=m
++CONFIG_WIZNET_W5300=m
++CONFIG_WKUP_M3_RPROC=m
++CONFIG_WL1251=m
++CONFIG_WL1251_SDIO=m
++CONFIG_WL1251_SPI=m
++CONFIG_WL12XX=m
++CONFIG_WL18XX=m
++CONFIG_WLAN=y
++CONFIG_WLAN_VENDOR_RSI=y
++CONFIG_WLCORE=m
++CONFIG_WLCORE_SDIO=m
++CONFIG_WLCORE_SPI=m
++CONFIG_WL_MEDIATEK=y
++CONFIG_WL_TI=y
++CONFIG_WM831X_BACKUP=m
++CONFIG_WM831X_POWER=m
++CONFIG_WM831X_WATCHDOG=m
++CONFIG_WM8350_POWER=m
++CONFIG_WM8350_WATCHDOG=m
++CONFIG_WQ_POWER_EFFICIENT_DEFAULT=y
++CONFIG_X25_ASY=m
++CONFIG_X509_CERTIFICATE_PARSER=y
++CONFIG_X86=y
++CONFIG_X86_16BIT=y
++CONFIG_X86_32=y
++CONFIG_X86_32_IRIS=m
++# CONFIG_X86_32_NON_STANDARD is not set
++CONFIG_X86_32_SMP=y
++CONFIG_X86_64=y
++CONFIG_X86_64_ACPI_NUMA=y
++CONFIG_X86_64_SMP=y
++CONFIG_X86_ACPI_CPUFREQ=y
++CONFIG_X86_ACPI_CPUFREQ_CPB=y
++CONFIG_X86_AMD_FREQ_SENSITIVITY=m
++CONFIG_X86_AMD_PLATFORM_DEVICE=y
++# CONFIG_X86_ANCIENT_MCE is not set
++CONFIG_X86_APM_BOOT=y
++# CONFIG_X86_BIGSMP is not set
++CONFIG_X86_BOOTPARAM_MEMORY_CORRUPTION_CHECK=y
++CONFIG_X86_CHECK_BIOS_CORRUPTION=y
++CONFIG_X86_CMOV=y
++CONFIG_X86_CMPXCHG64=y
++CONFIG_X86_CPUFREQ_NFORCE2=y
++CONFIG_X86_CPUID=m
++CONFIG_X86_DEBUGCTLMSR=y
++CONFIG_X86_DEBUG_FPU=y
++# CONFIG_X86_DEBUG_STATIC_CPU_HAS is not set
++# CONFIG_X86_DECODER_SELFTEST is not set
++CONFIG_X86_DEV_DMA_OPS=y
++CONFIG_X86_DIRECT_GBPAGES=y
++CONFIG_X86_ESPFIX32=y
++CONFIG_X86_ESPFIX64=y
++CONFIG_X86_EXTENDED_PLATFORM=y
++# CONFIG_X86_E_POWERSAVER is not set
++CONFIG_X86_FEATURE_NAMES=y
++CONFIG_X86_GENERIC=y
++# CONFIG_X86_GOLDFISH is not set
++CONFIG_X86_GX_SUSPMOD=m
++CONFIG_X86_INTEL_LPSS=y
++CONFIG_X86_INTEL_MID=y
++CONFIG_X86_INTEL_MPX=y
++CONFIG_X86_INTEL_PSTATE=y
++# CONFIG_X86_INTEL_QUARK is not set
++CONFIG_X86_INTEL_USERCOPY=y
++CONFIG_X86_INTERNODE_CACHE_SHIFT=6
++CONFIG_X86_IO_APIC=y
++CONFIG_X86_L1_CACHE_SHIFT=6
++CONFIG_X86_LEGACY_VM86=y
++CONFIG_X86_LOCAL_APIC=y
++CONFIG_X86_LONGHAUL=m
++CONFIG_X86_LONGRUN=m
++CONFIG_X86_MCE=y
++CONFIG_X86_MCE_AMD=y
++CONFIG_X86_MCE_INJECT=m
++CONFIG_X86_MCE_INTEL=y
++CONFIG_X86_MCE_THRESHOLD=y
++CONFIG_X86_MPPARSE=y
++CONFIG_X86_MSR=m
++CONFIG_X86_NEED_RELOCS=y
++CONFIG_X86_NUMACHIP=y
++CONFIG_X86_P4_CLOCKMOD=m
++CONFIG_X86_PAE=y
++CONFIG_X86_PAT=y
++CONFIG_X86_PCC_CPUFREQ=y
++CONFIG_X86_PKG_TEMP_THERMAL=m
++CONFIG_X86_PLATFORM_DEVICES=y
++CONFIG_X86_PMEM_LEGACY=y
++CONFIG_X86_PMEM_LEGACY_DEVICE=y
++CONFIG_X86_PM_TIMER=y
++CONFIG_X86_POWERNOW_K6=m
++CONFIG_X86_POWERNOW_K7=m
++CONFIG_X86_POWERNOW_K7_ACPI=y
++CONFIG_X86_POWERNOW_K8=y
++CONFIG_X86_PPRO_FENCE=y
++# CONFIG_X86_PTDUMP is not set
++# CONFIG_X86_PTDUMP_CORE is not set
++# CONFIG_X86_RDC321X is not set
++CONFIG_X86_REBOOTFIXUPS=y
++CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS=y
++CONFIG_X86_RESERVE_LOW=64
++CONFIG_X86_SFI_CPUFREQ=m
++CONFIG_X86_SMAP=y
++CONFIG_X86_SPEEDSTEP_CENTRINO=y
++CONFIG_X86_SPEEDSTEP_CENTRINO_TABLE=y
++CONFIG_X86_SPEEDSTEP_ICH=y
++CONFIG_X86_SPEEDSTEP_RELAXED_CAP_CHECK=y
++CONFIG_X86_SPEEDSTEP_SMI=y
++CONFIG_X86_SUPPORTS_MEMORY_FAILURE=y
++# CONFIG_X86_SYSFB is not set
++CONFIG_X86_THERMAL_VECTOR=y
++CONFIG_X86_TSC=y
++CONFIG_X86_USE_PPRO_CHECKSUM=y
++# CONFIG_X86_UV is not set
++# CONFIG_X86_VERBOSE_BOOTUP is not set
++# CONFIG_X86_VSMP is not set
++CONFIG_X86_VSYSCALL_EMULATION=y
++CONFIG_X86_X2APIC=y
++CONFIG_X86_X32=y
++CONFIG_XENFS=m
++CONFIG_XEN_512GB=y
++CONFIG_XEN_ACPI=y
++CONFIG_XEN_ACPI_PROCESSOR=y
++CONFIG_XEN_AUTO_XLATE=y
++CONFIG_XEN_BACKEND=y
++CONFIG_XEN_BALLOON=y
++CONFIG_XEN_BALLOON_MEMORY_HOTPLUG=y
++CONFIG_XEN_BLKDEV_BACKEND=m
++CONFIG_XEN_BLKDEV_FRONTEND=y
++CONFIG_XEN_COMPAT_XENFS=y
++# CONFIG_XEN_DEBUG_FS is not set
++CONFIG_XEN_DEV_EVTCHN=m
++CONFIG_XEN_DOM0=y
++CONFIG_XEN_EFI=y
++CONFIG_XEN_FBDEV_FRONTEND=m
++CONFIG_XEN_GNTDEV=m
++CONFIG_XEN_GRANT_DEV_ALLOC=m
++CONFIG_XEN_HAVE_PVMMU=y
++CONFIG_XEN_HAVE_VPMU=y
++CONFIG_XEN_MCE_LOG=y
++CONFIG_XEN_NETDEV_BACKEND=m
++CONFIG_XEN_NETDEV_FRONTEND=y
++CONFIG_XEN_PCIDEV_BACKEND=m
++CONFIG_XEN_PCIDEV_FRONTEND=m
++CONFIG_XEN_PRIVCMD=m
++CONFIG_XEN_PVH=y
++CONFIG_XEN_PVHVM=y
++CONFIG_XEN_SAVE_RESTORE=y
++CONFIG_XEN_SCRUB_PAGES=y
++CONFIG_XEN_SCSI_BACKEND=m
++CONFIG_XEN_SCSI_FRONTEND=m
++CONFIG_XEN_SELFBALLOONING=y
++CONFIG_XEN_SYMS=y
++CONFIG_XEN_SYS_HYPERVISOR=y
++CONFIG_XEN_TMEM=m
++CONFIG_XEN_WDT=m
++CONFIG_XEN_XENBUS_FRONTEND=y
++# CONFIG_XES_MPC85xx is not set
++CONFIG_XFRM=y
++CONFIG_XFRM_ALGO=m
++CONFIG_XFRM_IPCOMP=m
++# CONFIG_XFRM_MIGRATE is not set
++CONFIG_XFRM_STATISTICS=y
++# CONFIG_XFRM_SUB_POLICY is not set
++CONFIG_XFRM_USER=m
++# CONFIG_XFS_DEBUG is not set
++CONFIG_XFS_FS=m
++CONFIG_XFS_POSIX_ACL=y
++CONFIG_XFS_QUOTA=y
++CONFIG_XFS_RT=y
++# CONFIG_XFS_WARN is not set
++CONFIG_XGENE_DMA=m
++CONFIG_XGENE_SLIMPRO_MBOX=m
++CONFIG_XILINX_EMACLITE=m
++CONFIG_XILINX_LL_TEMAC=m
++CONFIG_XILLYBUS_OF=m
++CONFIG_XILLYBUS_PCIE=m
++CONFIG_XMON=y
++# CONFIG_XMON_DEFAULT is not set
++CONFIG_XMON_DISASSEMBLY=y
++CONFIG_XOR_BLOCKS=m
++CONFIG_XPS=y
++CONFIG_XPS_USB_HCD_XILINX=y
++CONFIG_XZ_DEC=y
++CONFIG_YAM=m
++CONFIG_YELLOWFIN=m
++CONFIG_YENTA=m
++CONFIG_YENTA_ENE_TUNE=y
++CONFIG_YENTA_O2=y
++CONFIG_YENTA_RICOH=y
++CONFIG_YENTA_TI=y
++CONFIG_YENTA_TOSHIBA=y
++CONFIG_ZBOOT_ROM_BSS=0x0
++CONFIG_ZBOOT_ROM_TEXT=0x0
++CONFIG_ZBUD=y
++CONFIG_ZCRYPT=m
++CONFIG_ZD1211RW=m
++# CONFIG_ZD1211RW_DEBUG is not set
++CONFIG_ZEROPLUS_FF=y
++CONFIG_ZFCP=m
++CONFIG_ZISOFS=y
++CONFIG_ZLIB_INFLATE=y
++CONFIG_ZONE_DEVICE=y
++CONFIG_ZONE_DMA=y
++CONFIG_ZONE_DMA32=y
++CONFIG_ZPOOL=y
++CONFIG_ZRAM=m
++CONFIG_ZRAM_LZ4_COMPRESS=y
++CONFIG_ZSMALLOC=y
++# CONFIG_ZSMALLOC_STAT is not set
++CONFIG_ZSWAP=y
+diff --git a/debian.master/config/i386/config.common.i386 b/debian.master/config/i386/config.common.i386
+new file mode 100644
+index 0000000..40538ef
+--- /dev/null
++++ b/debian.master/config/i386/config.common.i386
+@@ -0,0 +1,473 @@
++#
++# Config options for config.common.i386 automatically generated by splitconfig.pl
++#
++# CONFIG_64BIT is not set
++CONFIG_6LOWPAN=m
++CONFIG_ABX500_CORE=y
++CONFIG_AC97_BUS=m
++# CONFIG_ACPI_REDUCED_HARDWARE_ONLY is not set
++CONFIG_ADFS_FS=m
++CONFIG_AFFS_FS=m
++CONFIG_AIX_PARTITION=y
++CONFIG_ALIM7101_WDT=m
++CONFIG_ALTERA_TSE=m
++CONFIG_AMIGA_PARTITION=y
++CONFIG_APPLICOM=m
++CONFIG_ARCH_DEFCONFIG="arch/x86/configs/i386_defconfig"
++CONFIG_ARCH_DMA_ADDR_T_64BIT=y
++CONFIG_ARCH_HWEIGHT_CFLAGS="-fcall-saved-ecx -fcall-saved-edx"
++# CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
++CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
++CONFIG_ARCH_RANDOM=y
++CONFIG_ARCH_SELECT_MEMORY_MODEL=y
++CONFIG_ARCNET=m
++CONFIG_ATALK=m
++CONFIG_ATARI_PARTITION=y
++CONFIG_ATA_GENERIC=y
++# CONFIG_ATA_NONSTANDARD is not set
++CONFIG_ATA_OVER_ETH=m
++CONFIG_ATA_PIIX=y
++CONFIG_ATM=m
++# CONFIG_AUDIT_ARCH_COMPAT_GENERIC is not set
++CONFIG_AUTOFS4_FS=m
++CONFIG_AUXDISPLAY=y
++CONFIG_BACKLIGHT_LCD_SUPPORT=y
++CONFIG_BATMAN_ADV=m
++CONFIG_BCH=m
++CONFIG_BCMA=m
++CONFIG_BCM_KONA_USB2_PHY=m
++CONFIG_BE2ISCSI=m
++CONFIG_BEFS_FS=m
++CONFIG_BFS_FS=m
++CONFIG_BLK_CPQ_CISS_DA=m
++CONFIG_BLK_DEV_3W_XXXX_RAID=m
++CONFIG_BLK_DEV_CRYPTOLOOP=m
++CONFIG_BLK_DEV_DAC960=m
++CONFIG_BLK_DEV_NVME=m
++CONFIG_BLK_DEV_PCIESSD_MTIP32XX=m
++CONFIG_BLK_DEV_RSXX=m
++# CONFIG_BLK_DEV_SR_VENDOR is not set
++CONFIG_BLK_DEV_SX8=m
++CONFIG_BLK_DEV_UMEM=m
++CONFIG_BOUNCE=y
++CONFIG_BSD_DISKLABEL=y
++CONFIG_C2PORT=m
++CONFIG_CADENCE_WATCHDOG=m
++CONFIG_CAIF=m
++CONFIG_CAN=m
++CONFIG_CB710_CORE=m
++CONFIG_CC_STACKPROTECTOR=y
++CONFIG_CDROM_PKTCDVD=m
++CONFIG_CMA=y
++CONFIG_CMDLINE_PARTITION=y
++CONFIG_CONFIGFS_FS=m
++CONFIG_CRAMFS=m
++CONFIG_CRASH_DUMP=y
++# CONFIG_CXL_BASE is not set
++# CONFIG_CXL_EEH is not set
++# CONFIG_CXL_KERNEL_API is not set
++CONFIG_DECNET=m
++CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
++CONFIG_DMADEVICES=y
++CONFIG_DMA_SHARED_BUFFER=y
++CONFIG_DMA_VIRTUAL_CHANNELS=m
++# CONFIG_DM_DEBUG is not set
++CONFIG_DNET=m
++CONFIG_DRM=m
++CONFIG_DUMMY_IRQ=m
++CONFIG_DW_WATCHDOG=m
++CONFIG_ECHO=m
++CONFIG_EEPROM_93CX6=m
++CONFIG_EFS_FS=m
++# CONFIG_EM_TIMER_STI is not set
++CONFIG_ENCLOSURE_SERVICES=m
++CONFIG_ETHOC=m
++CONFIG_EXOFS_FS=m
++CONFIG_EXTCON=y
++CONFIG_F2FS_FS=m
++CONFIG_FB=y
++CONFIG_FB_ATY128=m
++CONFIG_FB_BOOT_VESA_SUPPORT=y
++# CONFIG_FB_CFB_REV_PIXELS_IN_BYTE is not set
++CONFIG_FB_IBM_GXT4500=m
++# CONFIG_FB_MACMODES is not set
++CONFIG_FB_SYS_COPYAREA=m
++CONFIG_FB_SYS_FILLRECT=m
++CONFIG_FB_SYS_FOPS=m
++CONFIG_FB_SYS_IMAGEBLIT=m
++CONFIG_FB_UDL=m
++CONFIG_FB_VOODOO1=m
++CONFIG_FDDI=y
++CONFIG_FEALNX=m
++CONFIG_FIREWIRE=m
++CONFIG_FIREWIRE_NOSY=m
++CONFIG_FIRMWARE_IN_KERNEL=y
++CONFIG_FIXED_PHY=y
++CONFIG_FMC=m
++# CONFIG_FONTS is not set
++CONFIG_FRAME_WARN=1024
++CONFIG_FUSION=y
++CONFIG_GAMEPORT=m
++CONFIG_GENERIC_PHY=y
++CONFIG_GPIO_GENERIC=m
++CONFIG_GPIO_GENERIC_PLATFORM=m
++CONFIG_GPIO_TWL4030=m
++CONFIG_GPIO_TWL6040=m
++# CONFIG_HAVE_64BIT_ALIGNED_ACCESS is not set
++CONFIG_HAVE_AOUT=y
++# CONFIG_HAVE_ARCH_BITREVERSE is not set
++# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
++CONFIG_HAVE_GENERIC_DMA_COHERENT=y
++CONFIG_HAVE_SETUP_PER_CPU_AREA=y
++CONFIG_HFSPLUS_FS=m
++CONFIG_HFS_FS=m
++CONFIG_HIBERNATION=y
++CONFIG_HIO=m
++CONFIG_HOTPLUG_PCI_PCIE=y
++CONFIG_HOTPLUG_PCI_SHPC=m
++CONFIG_HPET=y
++CONFIG_HPFS_FS=m
++CONFIG_HP_ILO=m
++CONFIG_HSI=m
++CONFIG_HSR=m
++CONFIG_HTC_PASIC3=m
++CONFIG_HUGETLB_PAGE=y
++CONFIG_HWMON=y
++CONFIG_HW_RANDOM_TIMERIOMEM=m
++# CONFIG_HZ_100 is not set
++CONFIG_I2C=y
++# CONFIG_I2C_SLAVE is not set
++CONFIG_I6300ESB_WDT=m
++CONFIG_IEEE802154=m
++CONFIG_IIO=m
++CONFIG_ILLEGAL_POINTER_VALUE=0
++CONFIG_IMA=y
++CONFIG_INFINIBAND_NES=m
++CONFIG_INFINIBAND_OCRDMA=m
++CONFIG_INPUT=y
++CONFIG_IPACK_BUS=m
++CONFIG_IPMI_HANDLER=m
++CONFIG_IPMI_SI_PROBE_DEFAULTS=y
++CONFIG_IPX=m
++# CONFIG_IP_DCCP_CCID3 is not set
++CONFIG_IRQ_BYPASS_MANAGER=m
++CONFIG_ISA=y
++CONFIG_JFS_FS=m
++CONFIG_JME=m
++CONFIG_JUMP_LABEL=y
++CONFIG_KARMA_PARTITION=y
++CONFIG_KERNEL_GZIP=y
++# CONFIG_KERNEL_XZ is not set
++CONFIG_KVM=m
++CONFIG_LAPB=m
++CONFIG_LDM_PARTITION=y
++CONFIG_LIBNVDIMM=y
++CONFIG_LLC2=m
++CONFIG_LOG_BUF_SHIFT=17
++CONFIG_LPC_ICH=m
++CONFIG_LPC_SCH=m
++CONFIG_MAC_PARTITION=y
++CONFIG_MAGIC_SYSRQ_DEFAULT_ENABLE=0x1
++CONFIG_MAILBOX=y
++# CONFIG_MATH_EMULATION is not set
++CONFIG_MAX63XX_WATCHDOG=m
++CONFIG_MCB=m
++CONFIG_MD_MULTIPATH=m
++CONFIG_MEDIA_SUPPORT=m
++CONFIG_MEGARAID_LEGACY=m
++CONFIG_MEGARAID_NEWGEN=y
++CONFIG_MEGARAID_SAS=m
++CONFIG_MEMORY=y
++CONFIG_MEMSTICK=m
++CONFIG_MFD_CORE=y
++CONFIG_MFD_JANZ_CMODIO=m
++CONFIG_MFD_KEMPLD=m
++CONFIG_MFD_MT6397=m
++CONFIG_MFD_RDC321X=m
++CONFIG_MFD_RTSX_PCI=m
++CONFIG_MFD_SM501=m
++CONFIG_MFD_SYSCON=y
++CONFIG_MFD_TI_AM335X_TSCADC=m
++# CONFIG_MFD_TMIO is not set
++CONFIG_MFD_VX855=m
++CONFIG_MII=m
++CONFIG_MINIX_FS=m
++CONFIG_MINIX_SUBPARTITION=y
++CONFIG_MMC=y
++CONFIG_MMC_BLOCK=m
++CONFIG_MMC_SDHCI=m
++CONFIG_MMC_SDHCI_PLTFM=m
++CONFIG_MTD=m
++CONFIG_MTD_BLKDEVS=m
++CONFIG_MTD_BLOCK=m
++CONFIG_MTD_CMDLINE_PARTS=m
++CONFIG_MTD_NAND=m
++CONFIG_MTD_NAND_BCH=m
++CONFIG_MTD_NAND_ECC=m
++CONFIG_MTD_NAND_IDS=m
++# CONFIG_MTD_NAND_OMAP_BCH_BUILD is not set
++CONFIG_NCP_FS=m
++CONFIG_NEED_DMA_MAP_STATE=y
++CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK=y
++CONFIG_NET_CADENCE=y
++CONFIG_NET_PACKET_ENGINE=y
++CONFIG_NET_VENDOR_3COM=y
++CONFIG_NET_VENDOR_ADAPTEC=y
++CONFIG_NET_VENDOR_AGERE=y
++CONFIG_NET_VENDOR_ALTEON=y
++CONFIG_NET_VENDOR_AMD=y
++CONFIG_NET_VENDOR_ARC=y
++CONFIG_NET_VENDOR_ATHEROS=y
++CONFIG_NET_VENDOR_BROADCOM=y
++CONFIG_NET_VENDOR_BROCADE=y
++CONFIG_NET_VENDOR_CAVIUM=y
++CONFIG_NET_VENDOR_CHELSIO=y
++CONFIG_NET_VENDOR_CISCO=y
++CONFIG_NET_VENDOR_DEC=y
++CONFIG_NET_VENDOR_DLINK=y
++CONFIG_NET_VENDOR_EMULEX=y
++CONFIG_NET_VENDOR_EXAR=y
++CONFIG_NET_VENDOR_EZCHIP=y
++CONFIG_NET_VENDOR_HP=y
++CONFIG_NET_VENDOR_INTEL=y
++CONFIG_NET_VENDOR_MARVELL=y
++CONFIG_NET_VENDOR_MICREL=y
++CONFIG_NET_VENDOR_MYRI=y
++CONFIG_NET_VENDOR_NATSEMI=y
++CONFIG_NET_VENDOR_NVIDIA=y
++CONFIG_NET_VENDOR_OKI=y
++CONFIG_NET_VENDOR_QLOGIC=y
++CONFIG_NET_VENDOR_QUALCOMM=y
++CONFIG_NET_VENDOR_RDC=y
++CONFIG_NET_VENDOR_REALTEK=y
++CONFIG_NET_VENDOR_RENESAS=y
++CONFIG_NET_VENDOR_ROCKER=y
++CONFIG_NET_VENDOR_SAMSUNG=y
++CONFIG_NET_VENDOR_SEEQ=y
++CONFIG_NET_VENDOR_SILAN=y
++CONFIG_NET_VENDOR_SIS=y
++CONFIG_NET_VENDOR_SMSC=y
++CONFIG_NET_VENDOR_STMICRO=y
++CONFIG_NET_VENDOR_SUN=y
++CONFIG_NET_VENDOR_SYNOPSYS=y
++CONFIG_NET_VENDOR_TEHUTI=y
++CONFIG_NET_VENDOR_TI=y
++CONFIG_NET_VENDOR_VIA=y
++CONFIG_NET_VENDOR_WIZNET=y
++CONFIG_NEW_LEDS=y
++CONFIG_NFC=m
++CONFIG_NOZOMI=m
++CONFIG_NR_CPUS=8
++CONFIG_NTB=m
++# CONFIG_NTFS_RW is not set
++CONFIG_NVMEM=m
++CONFIG_NVRAM=m
++CONFIG_N_GSM=m
++# CONFIG_OF is not set
++CONFIG_OMFS_FS=m
++# CONFIG_OPENNSL is not set
++CONFIG_OSF_PARTITION=y
++CONFIG_OUTPUT_FORMAT="elf32-i386"
++CONFIG_PAGE_EXTENSION=y
++CONFIG_PAGE_OFFSET=0xC0000000
++CONFIG_PANIC_TIMEOUT=0
++CONFIG_PARPORT=m
++CONFIG_PATA_SIS=y
++CONFIG_PCCARD=m
++CONFIG_PCIPCWATCHDOG=m
++CONFIG_PCI_PASID=y
++CONFIG_PCI_PRI=y
++CONFIG_PCI_QUIRKS=y
++CONFIG_PCMCIA=m
++CONFIG_PGTABLE_LEVELS=3
++CONFIG_PGTABLE_MAPPING=y
++CONFIG_PHANTOM=m
++CONFIG_PHONET=m
++CONFIG_PHYLIB=y
++CONFIG_PHYSICAL_ALIGN=0x1000000
++CONFIG_PHYSICAL_START=0x1000000
++CONFIG_PHYS_ADDR_T_64BIT=y
++# CONFIG_PHY_EXYNOS5250_USB2 is not set
++CONFIG_PHY_PXA_28NM_HSIC=m
++CONFIG_PHY_PXA_28NM_USB2=m
++CONFIG_PM_DEBUG=y
++CONFIG_PM_DEVFREQ=y
++CONFIG_PM_WAKELOCKS=y
++CONFIG_POWERCAP=y
++CONFIG_POWER_AVS=y
++CONFIG_POWER_SUPPLY=y
++CONFIG_PPP=y
++CONFIG_PPS=m
++CONFIG_PPS_CLIENT_GPIO=m
++CONFIG_PPS_CLIENT_LDISC=m
++# CONFIG_PREEMPT_NONE is not set
++CONFIG_PROBE_EVENTS=y
++CONFIG_PSTORE=y
++# CONFIG_PSTORE_CONSOLE is not set
++CONFIG_PSTORE_RAM=m
++CONFIG_PTP_1588_CLOCK=m
++CONFIG_PWM=y
++CONFIG_QNX4FS_FS=m
++CONFIG_QNX6FS_FS=m
++CONFIG_R3964=m
++CONFIG_RANDOMIZE_BASE_MAX_OFFSET=0x20000000
++CONFIG_RAW_DRIVER=m
++CONFIG_RCU_CPU_STALL_TIMEOUT=60
++CONFIG_REED_SOLOMON=m
++CONFIG_REGULATOR=y
++CONFIG_REGULATOR_FIXED_VOLTAGE=m
++CONFIG_REGULATOR_TWL4030=m
++CONFIG_REISERFS_FS=m
++CONFIG_RESET_CONTROLLER=y
++CONFIG_RFKILL=y
++CONFIG_ROMFS_FS=m
++CONFIG_RTC_DRV_CMOS=y
++CONFIG_RTC_DRV_DS3232=m
++CONFIG_RTC_DRV_PCF8523=m
++CONFIG_RTC_DRV_TWL4030=m
++CONFIG_SATA_AHCI_PLATFORM=m
++CONFIG_SATA_SVW=m
++CONFIG_SCHED_SMT=y
++CONFIG_SCSI_3W_9XXX=m
++CONFIG_SCSI_3W_SAS=m
++CONFIG_SCSI_AACRAID=m
++CONFIG_SCSI_ACARD=m
++CONFIG_SCSI_ADVANSYS=m
++CONFIG_SCSI_AIC79XX=m
++CONFIG_SCSI_AIC7XXX=m
++CONFIG_SCSI_AIC94XX=m
++CONFIG_SCSI_AM53C974=m
++CONFIG_SCSI_ARCMSR=m
++CONFIG_SCSI_BFA_FC=m
++CONFIG_SCSI_BNX2X_FCOE=m
++CONFIG_SCSI_BNX2_ISCSI=m
++CONFIG_SCSI_CHELSIO_FCOE=m
++CONFIG_SCSI_CXGB3_ISCSI=m
++CONFIG_SCSI_CXGB4_ISCSI=m
++CONFIG_SCSI_DC395x=m
++CONFIG_SCSI_DMX3191D=m
++CONFIG_SCSI_DPT_I2O=m
++CONFIG_SCSI_ESAS2R=m
++CONFIG_SCSI_FUTURE_DOMAIN=m
++CONFIG_SCSI_HPSA=m
++CONFIG_SCSI_HPTIOP=m
++CONFIG_SCSI_INIA100=m
++CONFIG_SCSI_INITIO=m
++CONFIG_SCSI_IPS=m
++CONFIG_SCSI_LPFC=m
++CONFIG_SCSI_MVSAS=m
++CONFIG_SCSI_MVUMI=m
++CONFIG_SCSI_PM8001=m
++CONFIG_SCSI_PMCRAID=m
++CONFIG_SCSI_QLA_FC=m
++CONFIG_SCSI_QLA_ISCSI=m
++CONFIG_SCSI_QLOGIC_1280=m
++CONFIG_SCSI_SNIC=m
++CONFIG_SCSI_SRP_ATTRS=m
++CONFIG_SCSI_STEX=m
++CONFIG_SCSI_SYM53C8XX_2=m
++CONFIG_SCSI_UFSHCD=m
++CONFIG_SCSI_WD719X=m
++CONFIG_SECURITY_SELINUX_BOOTPARAM=y
++CONFIG_SECURITY_SELINUX_DISABLE=y
++CONFIG_SENSORS_SCH56XX_COMMON=m
++CONFIG_SERIAL_8250=y
++CONFIG_SERIAL_8250_DW=m
++# CONFIG_SERIAL_8250_FSL is not set
++CONFIG_SERIAL_ALTERA_JTAGUART=m
++CONFIG_SERIAL_ALTERA_UART=m
++CONFIG_SERIAL_ARC=m
++CONFIG_SERIAL_CORE=y
++CONFIG_SERIAL_FSL_LPUART=m
++CONFIG_SERIAL_JSM=m
++CONFIG_SERIAL_NONSTANDARD=y
++CONFIG_SERIAL_RP2=m
++CONFIG_SERIAL_SCCNXP=y
++CONFIG_SERIO=y
++CONFIG_SFC=m
++CONFIG_SGI_IOC4=m
++CONFIG_SGI_PARTITION=y
++# CONFIG_SH_TIMER_CMT is not set
++# CONFIG_SH_TIMER_MTU2 is not set
++# CONFIG_SH_TIMER_TMU is not set
++CONFIG_SLIP=m
++CONFIG_SND=m
++CONFIG_SND_DMAENGINE_PCM=m
++CONFIG_SND_EMU10K1_SEQ=m
++CONFIG_SND_OPL4_LIB_SEQ=m
++CONFIG_SND_PCM=m
++CONFIG_SND_SBAWE_SEQ=m
++CONFIG_SND_SOC=m
++CONFIG_SND_SOC_FSL_SSI=m
++CONFIG_SND_SOC_I2C_AND_SPI=m
++CONFIG_SND_SOC_IMX_AUDMUX=m
++# CONFIG_SND_SOC_RT5677_SPI is not set
++CONFIG_SND_SOC_SGTL5000=m
++CONFIG_SND_TIMER=m
++CONFIG_SOC_TI=y
++CONFIG_SOLARIS_X86_PARTITION=y
++CONFIG_SOUND=m
++CONFIG_SPI=y
++CONFIG_SPI_PXA2XX_PCI=m
++CONFIG_SPMI=m
++CONFIG_SRAM=y
++CONFIG_SSB=m
++CONFIG_STAGING=y
++# CONFIG_STANDALONE is not set
++CONFIG_STE_MODEM_RPROC=m
++CONFIG_SUN_PARTITION=y
++CONFIG_SYSV68_PARTITION=y
++CONFIG_SYSV_FS=m
++CONFIG_SYS_HYPERVISOR=y
++CONFIG_THERMAL=y
++CONFIG_THUNDERBOLT=m
++CONFIG_TIFM_CORE=m
++CONFIG_TIGON3=m
++CONFIG_TI_CPSW_ALE=m
++CONFIG_TRACE_SINK=m
++CONFIG_TTY_PRINTK=y
++CONFIG_UFS_FS=m
++CONFIG_UIO=m
++CONFIG_ULTRIX_PARTITION=y
++CONFIG_UNIXWARE_DISKLABEL=y
++CONFIG_UPROBES=y
++CONFIG_USB_EHCI_HCD_PLATFORM=y
++CONFIG_USB_GADGET=m
++# CONFIG_USB_G_MULTI is not set
++CONFIG_USB_HCD_BCMA=m
++CONFIG_USB_HCD_SSB=m
++CONFIG_USB_MUSB_HDRC=m
++CONFIG_USB_OHCI_HCD_PLATFORM=y
++CONFIG_USB_SUPPORT=y
++CONFIG_UWB=m
++CONFIG_VFIO=m
++CONFIG_VFIO_IOMMU_TYPE1=m
++CONFIG_VFIO_PCI=m
++CONFIG_VFIO_VIRQFD=m
++CONFIG_VGASTATE=m
++CONFIG_VIRTIO_MMIO=y
++CONFIG_VM86=y
++CONFIG_VME_BUS=y
++CONFIG_VMXNET3=m
++CONFIG_VXFS_FS=m
++CONFIG_W1=m
++CONFIG_WAN=y
++CONFIG_WDTPCI=m
++CONFIG_WIMAX=m
++CONFIG_X25=m
++CONFIG_X86_MINIMUM_CPU_FAMILY=5
++CONFIG_X86_SPEEDSTEP_LIB=y
++CONFIG_XEN=y
++CONFIG_XEN_BALLOON_MEMORY_HOTPLUG_LIMIT=4
++CONFIG_XILINX_WATCHDOG=m
++CONFIG_XILLYBUS=m
++CONFIG_XZ_DEC_ARM=y
++CONFIG_XZ_DEC_ARMTHUMB=y
++CONFIG_XZ_DEC_BCJ=y
++CONFIG_XZ_DEC_IA64=y
++CONFIG_XZ_DEC_POWERPC=y
++CONFIG_XZ_DEC_SPARC=y
++CONFIG_XZ_DEC_TEST=m
++CONFIG_XZ_DEC_X86=y
++CONFIG_ZLIB_DEFLATE=y
++CONFIG_ZONE_DMA_FLAG=1
+diff --git a/debian.master/config/i386/config.flavour.generic b/debian.master/config/i386/config.flavour.generic
+new file mode 100644
+index 0000000..5c2e4e1
+--- /dev/null
++++ b/debian.master/config/i386/config.flavour.generic
+@@ -0,0 +1,9 @@
++#
++# Config options for config.flavour.generic automatically generated by splitconfig.pl
++#
++CONFIG_HZ=250
++# CONFIG_HZ_1000 is not set
++CONFIG_HZ_250=y
++# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
++# CONFIG_PREEMPT is not set
++CONFIG_PREEMPT_VOLUNTARY=y
+diff --git a/debian.master/config/i386/config.flavour.lowlatency b/debian.master/config/i386/config.flavour.lowlatency
+new file mode 100644
+index 0000000..6b121e3
+--- /dev/null
++++ b/debian.master/config/i386/config.flavour.lowlatency
+@@ -0,0 +1,9 @@
++#
++# Config options for config.flavour.lowlatency automatically generated by splitconfig.pl
++#
++CONFIG_HZ=1000
++CONFIG_HZ_1000=y
++# CONFIG_HZ_250 is not set
++CONFIG_IRQ_FORCED_THREADING_DEFAULT=y
++CONFIG_PREEMPT=y
++# CONFIG_PREEMPT_VOLUNTARY is not set
+diff --git a/debian.master/config/powerpc/config.common.powerpc b/debian.master/config/powerpc/config.common.powerpc
+new file mode 100644
+index 0000000..41c182d
+--- /dev/null
++++ b/debian.master/config/powerpc/config.common.powerpc
+@@ -0,0 +1,469 @@
++#
++# Config options for config.common.powerpc automatically generated by splitconfig.pl
++#
++CONFIG_64BIT=y
++CONFIG_6LOWPAN=m
++CONFIG_ABX500_CORE=y
++CONFIG_AC97_BUS=m
++CONFIG_ADFS_FS=m
++CONFIG_AFFS_FS=m
++CONFIG_AIX_PARTITION=y
++CONFIG_ALIM7101_WDT=m
++CONFIG_ALTERA_TSE=m
++CONFIG_AMIGA_PARTITION=y
++CONFIG_APM_EMULATION=m
++CONFIG_APPLICOM=m
++CONFIG_ARCH_HAS_ILOG2_U32=y
++CONFIG_ARCH_HAS_ILOG2_U64=y
++# CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
++CONFIG_ARCH_SELECT_MEMORY_MODEL=y
++CONFIG_ARCH_SPARSEMEM_DEFAULT=y
++CONFIG_ARCNET=m
++CONFIG_ATALK=m
++CONFIG_ATARI_PARTITION=y
++CONFIG_ATA_GENERIC=m
++CONFIG_ATA_OVER_ETH=m
++CONFIG_ATA_PIIX=m
++CONFIG_ATM=m
++# CONFIG_AUDIT_ARCH_COMPAT_GENERIC is not set
++CONFIG_AUTOFS4_FS=m
++CONFIG_AUXDISPLAY=y
++CONFIG_BACKLIGHT_LCD_SUPPORT=y
++CONFIG_BATMAN_ADV=m
++CONFIG_BCH=m
++CONFIG_BCMA=m
++CONFIG_BCM_KONA_USB2_PHY=m
++CONFIG_BE2ISCSI=m
++CONFIG_BEFS_FS=m
++CONFIG_BFS_FS=m
++CONFIG_BLK_CPQ_CISS_DA=m
++CONFIG_BLK_DEV_3W_XXXX_RAID=m
++CONFIG_BLK_DEV_CRYPTOLOOP=m
++CONFIG_BLK_DEV_DAC960=m
++CONFIG_BLK_DEV_NVME=m
++CONFIG_BLK_DEV_PCIESSD_MTIP32XX=m
++CONFIG_BLK_DEV_RSXX=m
++CONFIG_BLK_DEV_SKD=m
++# CONFIG_BLK_DEV_SR_VENDOR is not set
++CONFIG_BLK_DEV_SX8=m
++CONFIG_BLK_DEV_UMEM=m
++CONFIG_BOUNCE=y
++CONFIG_BSD_DISKLABEL=y
++CONFIG_C2PORT=m
++CONFIG_CADENCE_WATCHDOG=m
++CONFIG_CAIF=m
++CONFIG_CAN=m
++CONFIG_CB710_CORE=m
++# CONFIG_CC_STACKPROTECTOR is not set
++CONFIG_CDROM_PKTCDVD=m
++CONFIG_CMA=y
++CONFIG_CMDLINE_PARTITION=y
++CONFIG_CONFIGFS_FS=m
++CONFIG_CPU_BIG_ENDIAN=y
++# CONFIG_CPU_LITTLE_ENDIAN is not set
++CONFIG_CRAMFS=m
++# CONFIG_CRYPTO_DEV_FSL_CAAM_IMX is not set
++# CONFIG_CRYPTO_DEV_FSL_CAAM_LE is not set
++CONFIG_DECNET=m
++CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
++CONFIG_DMADEVICES=y
++CONFIG_DMA_SHARED_BUFFER=y
++CONFIG_DMA_VIRTUAL_CHANNELS=m
++# CONFIG_DM_DEBUG is not set
++CONFIG_DNET=m
++CONFIG_DRM=m
++CONFIG_DUMMY_IRQ=m
++CONFIG_DW_WATCHDOG=m
++CONFIG_ECHO=m
++CONFIG_EEPROM_93CX6=m
++CONFIG_EFS_FS=m
++# CONFIG_EM_TIMER_STI is not set
++CONFIG_ENCLOSURE_SERVICES=m
++CONFIG_ETHOC=m
++CONFIG_EXOFS_FS=m
++CONFIG_EXTCON=y
++CONFIG_F2FS_FS=m
++CONFIG_FB=y
++CONFIG_FB_ATY128=y
++# CONFIG_FB_BOOT_VESA_SUPPORT is not set
++# CONFIG_FB_CFB_REV_PIXELS_IN_BYTE is not set
++CONFIG_FB_IBM_GXT4500=m
++CONFIG_FB_MACMODES=y
++CONFIG_FB_VOODOO1=y
++CONFIG_FDDI=y
++CONFIG_FEALNX=m
++CONFIG_FIREWIRE=m
++CONFIG_FIREWIRE_NOSY=m
++CONFIG_FIRMWARE_IN_KERNEL=y
++CONFIG_FIXED_PHY=y
++CONFIG_FMC=m
++# CONFIG_FONTS is not set
++CONFIG_FRAME_WARN=1024
++CONFIG_FUSION=y
++CONFIG_GAMEPORT=m
++# CONFIG_GENERIC_CSUM is not set
++CONFIG_GENERIC_PHY=y
++CONFIG_GPIO_GENERIC=m
++CONFIG_GPIO_GENERIC_PLATFORM=m
++CONFIG_GPIO_TWL4030=m
++CONFIG_GPIO_TWL6040=m
++# CONFIG_HAVE_64BIT_ALIGNED_ACCESS is not set
++# CONFIG_HAVE_AOUT is not set
++# CONFIG_HAVE_ARCH_BITREVERSE is not set
++# CONFIG_HAVE_GENERIC_DMA_COHERENT is not set
++CONFIG_HFSPLUS_FS=m
++CONFIG_HFS_FS=m
++# CONFIG_HIO is not set
++CONFIG_HOTPLUG_PCI_PCIE=y
++CONFIG_HOTPLUG_PCI_SHPC=m
++CONFIG_HPFS_FS=m
++CONFIG_HP_ILO=m
++CONFIG_HSI=m
++CONFIG_HSR=m
++CONFIG_HTC_PASIC3=m
++CONFIG_HWMON=y
++CONFIG_HW_RANDOM_TIMERIOMEM=m
++CONFIG_HZ=250
++# CONFIG_HZ_100 is not set
++# CONFIG_HZ_1000 is not set
++CONFIG_HZ_250=y
++CONFIG_I2C=y
++# CONFIG_I2C_SLAVE is not set
++CONFIG_I6300ESB_WDT=m
++CONFIG_IEEE802154=m
++CONFIG_IIO=m
++CONFIG_INFINIBAND_NES=m
++CONFIG_INFINIBAND_OCRDMA=m
++CONFIG_INFINIBAND_QIB=m
++CONFIG_INPUT=y
++CONFIG_IPACK_BUS=m
++CONFIG_IPMI_HANDLER=m
++CONFIG_IPMI_SI_PROBE_DEFAULTS=y
++CONFIG_IPX=m
++# CONFIG_IP_DCCP_CCID3 is not set
++# CONFIG_IRQ_ALL_CPUS is not set
++CONFIG_IRQ_BYPASS_MANAGER=m
++# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
++# CONFIG_ISA is not set
++CONFIG_JFS_FS=m
++CONFIG_JME=m
++CONFIG_JUMP_LABEL=y
++CONFIG_KARMA_PARTITION=y
++CONFIG_KVM=y
++CONFIG_LAPB=m
++CONFIG_LDM_PARTITION=y
++CONFIG_LIBNVDIMM=y
++CONFIG_LLC2=m
++CONFIG_LOG_BUF_SHIFT=17
++# CONFIG_LPARCFG is not set
++CONFIG_LPC_ICH=m
++CONFIG_LPC_SCH=m
++CONFIG_MAC_PARTITION=y
++CONFIG_MAGIC_SYSRQ_DEFAULT_ENABLE=0x1
++CONFIG_MAILBOX=y
++CONFIG_MATH_EMULATION=y
++CONFIG_MAX63XX_WATCHDOG=m
++CONFIG_MCB=m
++CONFIG_MD_MULTIPATH=m
++CONFIG_MEDIA_SUPPORT=m
++CONFIG_MEGARAID_LEGACY=m
++CONFIG_MEGARAID_NEWGEN=y
++CONFIG_MEGARAID_SAS=m
++CONFIG_MEMORY=y
++CONFIG_MEMSTICK=m
++CONFIG_MFD_CORE=y
++CONFIG_MFD_JANZ_CMODIO=m
++CONFIG_MFD_KEMPLD=m
++CONFIG_MFD_MT6397=m
++CONFIG_MFD_RDC321X=m
++CONFIG_MFD_RTSX_PCI=m
++CONFIG_MFD_SM501=m
++CONFIG_MFD_SYSCON=y
++CONFIG_MFD_TI_AM335X_TSCADC=m
++# CONFIG_MFD_TMIO is not set
++CONFIG_MFD_VX855=m
++CONFIG_MII=m
++CONFIG_MINIX_FS=m
++CONFIG_MINIX_SUBPARTITION=y
++CONFIG_MMC=y
++CONFIG_MMC_BLOCK=m
++CONFIG_MMC_SDHCI=m
++CONFIG_MMC_SDHCI_PLTFM=m
++CONFIG_MPIC_MSGR=y
++CONFIG_MTD=m
++CONFIG_MTD_BLKDEVS=m
++CONFIG_MTD_BLOCK=m
++CONFIG_MTD_CMDLINE_PARTS=m
++CONFIG_MTD_NAND=m
++CONFIG_MTD_NAND_BCH=m
++CONFIG_MTD_NAND_ECC=m
++CONFIG_MTD_NAND_IDS=m
++# CONFIG_MTD_NAND_OMAP_BCH_BUILD is not set
++CONFIG_MTD_OF_PARTS=m
++CONFIG_NCP_FS=m
++CONFIG_NET_CADENCE=y
++CONFIG_NET_PACKET_ENGINE=y
++CONFIG_NET_VENDOR_3COM=y
++CONFIG_NET_VENDOR_ADAPTEC=y
++CONFIG_NET_VENDOR_AGERE=y
++CONFIG_NET_VENDOR_ALTEON=y
++CONFIG_NET_VENDOR_AMD=y
++CONFIG_NET_VENDOR_ARC=y
++CONFIG_NET_VENDOR_ATHEROS=y
++CONFIG_NET_VENDOR_BROADCOM=y
++CONFIG_NET_VENDOR_BROCADE=y
++CONFIG_NET_VENDOR_CAVIUM=y
++CONFIG_NET_VENDOR_CHELSIO=y
++CONFIG_NET_VENDOR_CISCO=y
++CONFIG_NET_VENDOR_DEC=y
++CONFIG_NET_VENDOR_DLINK=y
++CONFIG_NET_VENDOR_EMULEX=y
++CONFIG_NET_VENDOR_EXAR=y
++CONFIG_NET_VENDOR_EZCHIP=y
++CONFIG_NET_VENDOR_HP=y
++CONFIG_NET_VENDOR_INTEL=y
++CONFIG_NET_VENDOR_MARVELL=y
++CONFIG_NET_VENDOR_MICREL=y
++CONFIG_NET_VENDOR_MYRI=y
++CONFIG_NET_VENDOR_NATSEMI=y
++CONFIG_NET_VENDOR_NVIDIA=y
++CONFIG_NET_VENDOR_OKI=y
++CONFIG_NET_VENDOR_QLOGIC=y
++CONFIG_NET_VENDOR_QUALCOMM=y
++CONFIG_NET_VENDOR_RDC=y
++CONFIG_NET_VENDOR_REALTEK=y
++CONFIG_NET_VENDOR_RENESAS=y
++CONFIG_NET_VENDOR_ROCKER=y
++CONFIG_NET_VENDOR_SAMSUNG=y
++CONFIG_NET_VENDOR_SEEQ=y
++CONFIG_NET_VENDOR_SILAN=y
++CONFIG_NET_VENDOR_SIS=y
++CONFIG_NET_VENDOR_SMSC=y
++CONFIG_NET_VENDOR_STMICRO=y
++CONFIG_NET_VENDOR_SUN=y
++CONFIG_NET_VENDOR_SYNOPSYS=y
++CONFIG_NET_VENDOR_TEHUTI=y
++CONFIG_NET_VENDOR_TI=y
++CONFIG_NET_VENDOR_VIA=y
++CONFIG_NET_VENDOR_WIZNET=y
++CONFIG_NEW_LEDS=y
++CONFIG_NFC=m
++CONFIG_NODES_SHIFT=8
++CONFIG_NOZOMI=m
++CONFIG_NTB=m
++# CONFIG_NTFS_RW is not set
++CONFIG_NUMA_BALANCING_DEFAULT_ENABLED=y
++CONFIG_NVMEM=m
++CONFIG_NVRAM=y
++CONFIG_N_GSM=m
++CONFIG_OF=y
++CONFIG_OMFS_FS=m
++# CONFIG_OPENNSL is not set
++CONFIG_OSF_PARTITION=y
++CONFIG_PANIC_TIMEOUT=0
++CONFIG_PARPORT=m
++CONFIG_PATA_SIS=m
++CONFIG_PCCARD=m
++CONFIG_PCIPCWATCHDOG=m
++CONFIG_PCI_PASID=y
++CONFIG_PCI_PRI=y
++CONFIG_PCI_QUIRKS=y
++CONFIG_PCMCIA=m
++CONFIG_PGTABLE_MAPPING=y
++CONFIG_PHANTOM=m
++CONFIG_PHONET=m
++CONFIG_PHYLIB=y
++CONFIG_PHYSICAL_ALIGN=0x04000000
++CONFIG_PHYSICAL_START=0x00000000
++# CONFIG_PHY_EXYNOS5250_USB2 is not set
++CONFIG_PHY_PXA_28NM_HSIC=m
++CONFIG_PHY_PXA_28NM_USB2=m
++CONFIG_PM_DEBUG=y
++CONFIG_PM_DEVFREQ=y
++CONFIG_PM_WAKELOCKS=y
++# CONFIG_POWER7_CPU is not set
++CONFIG_POWERCAP=y
++CONFIG_POWER_AVS=y
++CONFIG_POWER_SUPPLY=y
++CONFIG_PPC_4K_PAGES=y
++# CONFIG_PPC_64K_PAGES is not set
++# CONFIG_PPC_DENORMALISATION is not set
++CONFIG_PPC_DISABLE_WERROR=y
++CONFIG_PPC_ICSWX=y
++# CONFIG_PPC_SMLPAR is not set
++# CONFIG_PPC_SPLPAR is not set
++CONFIG_PPP=y
++CONFIG_PPS=m
++CONFIG_PPS_CLIENT_GPIO=m
++CONFIG_PPS_CLIENT_LDISC=m
++# CONFIG_PREEMPT is not set
++# CONFIG_PREEMPT_NONE is not set
++CONFIG_PREEMPT_VOLUNTARY=y
++CONFIG_PROBE_EVENTS=y
++CONFIG_PSTORE=y
++# CONFIG_PSTORE_CONSOLE is not set
++CONFIG_PSTORE_RAM=m
++CONFIG_PTP_1588_CLOCK=m
++CONFIG_PWM=y
++CONFIG_QNX4FS_FS=m
++CONFIG_QNX6FS_FS=m
++CONFIG_R3964=m
++CONFIG_RAW_DRIVER=m
++CONFIG_RCU_CPU_STALL_TIMEOUT=21
++CONFIG_REED_SOLOMON=m
++CONFIG_REGULATOR=y
++CONFIG_REGULATOR_FIXED_VOLTAGE=m
++CONFIG_REGULATOR_TWL4030=m
++CONFIG_REISERFS_FS=m
++CONFIG_RESET_CONTROLLER=y
++CONFIG_RFKILL=y
++CONFIG_ROMFS_FS=m
++CONFIG_RTC_DRV_CMOS=m
++CONFIG_RTC_DRV_PCF8523=m
++CONFIG_RTC_DRV_TWL4030=m
++CONFIG_SATA_AHCI_PLATFORM=m
++CONFIG_SATA_SVW=y
++CONFIG_SCSI_3W_9XXX=m
++CONFIG_SCSI_3W_SAS=m
++CONFIG_SCSI_AACRAID=m
++CONFIG_SCSI_ACARD=m
++CONFIG_SCSI_ADVANSYS=m
++CONFIG_SCSI_AIC79XX=m
++CONFIG_SCSI_AIC7XXX=m
++CONFIG_SCSI_AIC94XX=m
++CONFIG_SCSI_AM53C974=m
++CONFIG_SCSI_ARCMSR=m
++CONFIG_SCSI_BFA_FC=m
++CONFIG_SCSI_BNX2X_FCOE=m
++CONFIG_SCSI_BNX2_ISCSI=m
++CONFIG_SCSI_CHELSIO_FCOE=m
++CONFIG_SCSI_CXGB3_ISCSI=m
++CONFIG_SCSI_CXGB4_ISCSI=m
++CONFIG_SCSI_DC395x=m
++CONFIG_SCSI_DMX3191D=m
++CONFIG_SCSI_DPT_I2O=m
++CONFIG_SCSI_ESAS2R=m
++CONFIG_SCSI_FUTURE_DOMAIN=m
++CONFIG_SCSI_HPSA=m
++CONFIG_SCSI_HPTIOP=m
++CONFIG_SCSI_INIA100=m
++CONFIG_SCSI_INITIO=m
++CONFIG_SCSI_IPS=m
++CONFIG_SCSI_LPFC=m
++CONFIG_SCSI_MVSAS=m
++CONFIG_SCSI_MVUMI=m
++CONFIG_SCSI_PM8001=m
++CONFIG_SCSI_PMCRAID=m
++CONFIG_SCSI_QLA_FC=m
++CONFIG_SCSI_QLA_ISCSI=m
++CONFIG_SCSI_QLOGIC_1280=m
++CONFIG_SCSI_SNIC=m
++CONFIG_SCSI_STEX=m
++CONFIG_SCSI_SYM53C8XX_2=m
++CONFIG_SCSI_UFSHCD=m
++CONFIG_SCSI_WD719X=m
++CONFIG_SECURITY_SELINUX_BOOTPARAM=y
++CONFIG_SECURITY_SELINUX_DISABLE=y
++# CONFIG_SENSORS_SCH56XX_COMMON is not set
++CONFIG_SERIAL_8250=y
++CONFIG_SERIAL_8250_DW=m
++CONFIG_SERIAL_8250_FSL=y
++CONFIG_SERIAL_ALTERA_JTAGUART=m
++CONFIG_SERIAL_ALTERA_UART=m
++CONFIG_SERIAL_ARC=m
++CONFIG_SERIAL_CORE=y
++CONFIG_SERIAL_FSL_LPUART=m
++CONFIG_SERIAL_JSM=m
++CONFIG_SERIAL_NONSTANDARD=y
++CONFIG_SERIAL_RP2=m
++CONFIG_SERIAL_SCCNXP=y
++CONFIG_SERIO=y
++CONFIG_SFC=m
++CONFIG_SGI_IOC4=m
++CONFIG_SGI_PARTITION=y
++# CONFIG_SH_TIMER_CMT is not set
++# CONFIG_SH_TIMER_MTU2 is not set
++# CONFIG_SH_TIMER_TMU is not set
++CONFIG_SIMPLE_GPIO=y
++CONFIG_SLIP=m
++CONFIG_SND=m
++CONFIG_SND_DMAENGINE_PCM=m
++CONFIG_SND_EMU10K1_SEQ=m
++# CONFIG_SND_OPL4_LIB_SEQ is not set
++CONFIG_SND_PCM=m
++# CONFIG_SND_SBAWE_SEQ is not set
++CONFIG_SND_SOC=m
++CONFIG_SND_SOC_FSL_SSI=m
++CONFIG_SND_SOC_I2C_AND_SPI=m
++CONFIG_SND_SOC_IMX_AUDMUX=m
++# CONFIG_SND_SOC_RT5677_SPI is not set
++CONFIG_SND_SOC_SGTL5000=m
++CONFIG_SND_TIMER=m
++CONFIG_SOC_TI=y
++CONFIG_SOLARIS_X86_PARTITION=y
++CONFIG_SOUND=m
++CONFIG_SPI=y
++CONFIG_SPMI=m
++CONFIG_SRAM=y
++CONFIG_SSB=m
++CONFIG_STAGING=y
++CONFIG_STANDALONE=y
++CONFIG_STE_MODEM_RPROC=m
++CONFIG_SUN_PARTITION=y
++CONFIG_SYSV68_PARTITION=y
++CONFIG_SYSV_FS=m
++# CONFIG_SYS_HYPERVISOR is not set
++CONFIG_THERMAL=y
++CONFIG_THUNDERBOLT=m
++CONFIG_TIFM_CORE=m
++CONFIG_TIGON3=m
++CONFIG_TI_CPSW_ALE=m
++CONFIG_TRACE_SINK=m
++CONFIG_TTY_PRINTK=y
++CONFIG_UDBG_RTAS_CONSOLE=y
++CONFIG_UFS_FS=m
++CONFIG_UIO=m
++CONFIG_ULTRIX_PARTITION=y
++CONFIG_UNIXWARE_DISKLABEL=y
++CONFIG_UPROBES=y
++CONFIG_USB_EHCI_HCD_PLATFORM=y
++CONFIG_USB_FSL_MPH_DR_OF=y
++CONFIG_USB_GADGET=m
++# CONFIG_USB_G_MULTI is not set
++CONFIG_USB_HCD_BCMA=m
++CONFIG_USB_HCD_SSB=m
++CONFIG_USB_MUSB_HDRC=m
++CONFIG_USB_OHCI_HCD_PLATFORM=y
++CONFIG_USB_OHCI_HCD_PPC_OF=y
++CONFIG_USB_OHCI_HCD_PPC_OF_BE=y
++CONFIG_USB_SUPPORT=y
++CONFIG_UWB=m
++CONFIG_VFIO=m
++CONFIG_VFIO_IOMMU_SPAPR_TCE=m
++# CONFIG_VFIO_IOMMU_TYPE1 is not set
++CONFIG_VFIO_PCI=m
++CONFIG_VFIO_SPAPR_EEH=m
++CONFIG_VFIO_VIRQFD=m
++CONFIG_VGASTATE=m
++CONFIG_VIRTIO_MMIO=y
++# CONFIG_VIRT_CPU_ACCOUNTING_NATIVE is not set
++CONFIG_VME_BUS=y
++CONFIG_VMXNET3=m
++CONFIG_VXFS_FS=m
++CONFIG_W1=m
++CONFIG_WAN=y
++CONFIG_WDTPCI=m
++CONFIG_WIMAX=m
++CONFIG_X25=m
++CONFIG_XILINX_WATCHDOG=m
++CONFIG_XILLYBUS=m
++CONFIG_XZ_DEC_ARM=y
++CONFIG_XZ_DEC_ARMTHUMB=y
++CONFIG_XZ_DEC_BCJ=y
++CONFIG_XZ_DEC_IA64=y
++CONFIG_XZ_DEC_POWERPC=y
++CONFIG_XZ_DEC_SPARC=y
++CONFIG_XZ_DEC_TEST=m
++CONFIG_XZ_DEC_X86=y
++CONFIG_ZLIB_DEFLATE=y
++CONFIG_ZONE_DMA_FLAG=1
+diff --git a/debian.master/config/powerpc/config.flavour.powerpc-e500mc b/debian.master/config/powerpc/config.flavour.powerpc-e500mc
+new file mode 100644
+index 0000000..3824193
+--- /dev/null
++++ b/debian.master/config/powerpc/config.flavour.powerpc-e500mc
+@@ -0,0 +1,59 @@
++#
++# Config options for config.flavour.powerpc-e500mc automatically generated by splitconfig.pl
++#
++CONFIG_ARCH_DMA_ADDR_T_64BIT=y
++CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
++# CONFIG_ARCH_RANDOM is not set
++# CONFIG_ATA_NONSTANDARD is not set
++# CONFIG_CRASH_DUMP is not set
++# CONFIG_CXL_BASE is not set
++# CONFIG_CXL_EEH is not set
++# CONFIG_CXL_KERNEL_API is not set
++CONFIG_DEFAULT_UIMAGE=y
++# CONFIG_EPAPR_BOOT is not set
++CONFIG_FB_SYS_COPYAREA=y
++CONFIG_FB_SYS_FILLRECT=y
++CONFIG_FB_SYS_FOPS=y
++CONFIG_FB_SYS_IMAGEBLIT=y
++CONFIG_FB_UDL=y
++CONFIG_FORCE_MAX_ZONEORDER=11
++CONFIG_GENERIC_TBSYNC=y
++CONFIG_HAS_RAPIDIO=y
++# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
++# CONFIG_HAVE_SETUP_PER_CPU_AREA is not set
++CONFIG_HIBERNATION=y
++CONFIG_HUGETLB_PAGE=y
++CONFIG_IMA=y
++CONFIG_KERNEL_START=0xc0000000
++# CONFIG_MMIO_NVRAM is not set
++# CONFIG_MPIC_U3_HT_IRQS is not set
++# CONFIG_NEED_DMA_MAP_STATE is not set
++# CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK is not set
++# CONFIG_NONSTATIC_KERNEL is not set
++CONFIG_NR_CPUS=8
++CONFIG_PAGE_EXTENSION=y
++CONFIG_PAGE_OFFSET=0xc0000000
++CONFIG_PGTABLE_LEVELS=2
++CONFIG_PHYS_ADDR_T_64BIT=y
++# CONFIG_PPC64 is not set
++CONFIG_PPC_85xx=y
++# CONFIG_PPC_970_NAP is not set
++# CONFIG_PPC_BOOK3S_32 is not set
++# CONFIG_PPC_CELL is not set
++# CONFIG_PPC_COPRO_BASE is not set
++CONFIG_PPC_DOORBELL=y
++CONFIG_PPC_EPAPR_HV_PIC=y
++# CONFIG_PPC_I8259 is not set
++# CONFIG_PPC_ICP_HV is not set
++# CONFIG_PPC_ICP_NATIVE is not set
++# CONFIG_PPC_ICS_RTAS is not set
++CONFIG_PPC_INDIRECT_PCI=y
++# CONFIG_PPC_MM_SLICES is not set
++# CONFIG_PPC_MPC106 is not set
++# CONFIG_PPC_P7_NAP is not set
++# CONFIG_PPC_RTAS is not set
++# CONFIG_PPC_XICS is not set
++CONFIG_RTC_DRV_DS3232=y
++CONFIG_SCSI_SRP_ATTRS=m
++CONFIG_SPI_PXA2XX_PCI=m
++CONFIG_WORD_SIZE=32
+diff --git a/debian.master/config/powerpc/config.flavour.powerpc-smp b/debian.master/config/powerpc/config.flavour.powerpc-smp
+new file mode 100644
+index 0000000..acc26a6
+--- /dev/null
++++ b/debian.master/config/powerpc/config.flavour.powerpc-smp
+@@ -0,0 +1,60 @@
++#
++# Config options for config.flavour.powerpc-smp automatically generated by splitconfig.pl
++#
++# CONFIG_ARCH_DMA_ADDR_T_64BIT is not set
++# CONFIG_ARCH_PHYS_ADDR_T_64BIT is not set
++# CONFIG_ARCH_RANDOM is not set
++# CONFIG_ATA_NONSTANDARD is not set
++# CONFIG_CRASH_DUMP is not set
++# CONFIG_CXL_BASE is not set
++# CONFIG_CXL_EEH is not set
++# CONFIG_CXL_KERNEL_API is not set
++# CONFIG_DEFAULT_UIMAGE is not set
++# CONFIG_EPAPR_BOOT is not set
++CONFIG_FB_SYS_COPYAREA=m
++CONFIG_FB_SYS_FILLRECT=m
++CONFIG_FB_SYS_FOPS=m
++CONFIG_FB_SYS_IMAGEBLIT=m
++CONFIG_FB_UDL=m
++CONFIG_FORCE_MAX_ZONEORDER=11
++CONFIG_GENERIC_TBSYNC=y
++# CONFIG_HAS_RAPIDIO is not set
++# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
++# CONFIG_HAVE_SETUP_PER_CPU_AREA is not set
++CONFIG_HIBERNATION=y
++# CONFIG_HUGETLB_PAGE is not set
++CONFIG_IMA=y
++CONFIG_KERNEL_START=0xc0000000
++# CONFIG_MMIO_NVRAM is not set
++# CONFIG_MPIC_U3_HT_IRQS is not set
++# CONFIG_NEED_DMA_MAP_STATE is not set
++# CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK is not set
++# CONFIG_NONSTATIC_KERNEL is not set
++CONFIG_NR_CPUS=4
++CONFIG_PAGE_EXTENSION=y
++CONFIG_PAGE_OFFSET=0xc0000000
++CONFIG_PGTABLE_LEVELS=2
++# CONFIG_PHYS_ADDR_T_64BIT is not set
++# CONFIG_PPC64 is not set
++# CONFIG_PPC_85xx is not set
++# CONFIG_PPC_970_NAP is not set
++CONFIG_PPC_BOOK3S_32=y
++# CONFIG_PPC_CELL is not set
++# CONFIG_PPC_COPRO_BASE is not set
++# CONFIG_PPC_DOORBELL is not set
++# CONFIG_PPC_EPAPR_HV_PIC is not set
++CONFIG_PPC_I8259=y
++# CONFIG_PPC_ICP_HV is not set
++# CONFIG_PPC_ICP_NATIVE is not set
++# CONFIG_PPC_ICS_RTAS is not set
++CONFIG_PPC_INDIRECT_PCI=y
++# CONFIG_PPC_MM_SLICES is not set
++CONFIG_PPC_MPC106=y
++CONFIG_PPC_OF_BOOT_TRAMPOLINE=y
++# CONFIG_PPC_P7_NAP is not set
++CONFIG_PPC_RTAS=y
++# CONFIG_PPC_XICS is not set
++CONFIG_RTC_DRV_DS3232=m
++CONFIG_SCSI_SRP_ATTRS=m
++# CONFIG_SPI_PXA2XX_PCI is not set
++CONFIG_WORD_SIZE=32
+diff --git a/debian.master/config/powerpc/config.flavour.powerpc64-emb b/debian.master/config/powerpc/config.flavour.powerpc64-emb
+new file mode 100644
+index 0000000..2087d8d
+--- /dev/null
++++ b/debian.master/config/powerpc/config.flavour.powerpc64-emb
+@@ -0,0 +1,63 @@
++#
++# Config options for config.flavour.powerpc64-emb automatically generated by splitconfig.pl
++#
++CONFIG_ARCH_DMA_ADDR_T_64BIT=y
++CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
++# CONFIG_ARCH_RANDOM is not set
++# CONFIG_ATA_NONSTANDARD is not set
++CONFIG_CRASH_DUMP=y
++# CONFIG_CXL_BASE is not set
++# CONFIG_CXL_EEH is not set
++# CONFIG_CXL_KERNEL_API is not set
++CONFIG_DEFAULT_UIMAGE=y
++# CONFIG_EPAPR_BOOT is not set
++CONFIG_FB_SYS_COPYAREA=y
++CONFIG_FB_SYS_FILLRECT=y
++CONFIG_FB_SYS_FOPS=y
++CONFIG_FB_SYS_IMAGEBLIT=y
++CONFIG_FB_UDL=y
++CONFIG_FORCE_MAX_ZONEORDER=13
++# CONFIG_GENERIC_TBSYNC is not set
++CONFIG_HAS_RAPIDIO=y
++# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
++CONFIG_HAVE_SETUP_PER_CPU_AREA=y
++# CONFIG_HIBERNATION is not set
++CONFIG_HUGETLB_PAGE=y
++# CONFIG_IMA is not set
++CONFIG_KERNEL_START=0xc000000000000000
++# CONFIG_MMIO_NVRAM is not set
++# CONFIG_MPIC_U3_HT_IRQS is not set
++CONFIG_NEED_DMA_MAP_STATE=y
++CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK=y
++CONFIG_NONSTATIC_KERNEL=y
++CONFIG_NR_CPUS=8
++# CONFIG_NUMA is not set
++# CONFIG_PAGE_EXTENSION is not set
++CONFIG_PAGE_OFFSET=0xc000000000000000
++CONFIG_PGTABLE_LEVELS=4
++CONFIG_PHYS_ADDR_T_64BIT=y
++CONFIG_PPC64=y
++# CONFIG_PPC_970_NAP is not set
++CONFIG_PPC_BOOK3E_64=y
++# CONFIG_PPC_BOOK3S_64 is not set
++# CONFIG_PPC_CELL is not set
++# CONFIG_PPC_COPRO_BASE is not set
++CONFIG_PPC_DOORBELL=y
++CONFIG_PPC_EPAPR_HV_PIC=y
++# CONFIG_PPC_I8259 is not set
++# CONFIG_PPC_ICP_HV is not set
++# CONFIG_PPC_ICP_NATIVE is not set
++# CONFIG_PPC_ICS_RTAS is not set
++CONFIG_PPC_INDIRECT_PCI=y
++# CONFIG_PPC_MM_SLICES is not set
++# CONFIG_PPC_MPC106 is not set
++# CONFIG_PPC_OF_BOOT_TRAMPOLINE is not set
++# CONFIG_PPC_P7_NAP is not set
++# CONFIG_PPC_RTAS is not set
++# CONFIG_PPC_XICS is not set
++CONFIG_RTC_DRV_DS3232=y
++# CONFIG_SCHED_SMT is not set
++CONFIG_SCSI_SRP_ATTRS=m
++CONFIG_SPI_PXA2XX_PCI=m
++# CONFIG_U3_DART is not set
++CONFIG_WORD_SIZE=64
+diff --git a/debian.master/config/powerpc/config.flavour.powerpc64-smp b/debian.master/config/powerpc/config.flavour.powerpc64-smp
+new file mode 100644
+index 0000000..ed5ac18
+--- /dev/null
++++ b/debian.master/config/powerpc/config.flavour.powerpc64-smp
+@@ -0,0 +1,63 @@
++#
++# Config options for config.flavour.powerpc64-smp automatically generated by splitconfig.pl
++#
++CONFIG_ARCH_DMA_ADDR_T_64BIT=y
++CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
++CONFIG_ARCH_RANDOM=y
++CONFIG_ATA_NONSTANDARD=y
++CONFIG_CRASH_DUMP=y
++CONFIG_CXL_BASE=y
++CONFIG_CXL_EEH=y
++CONFIG_CXL_KERNEL_API=y
++# CONFIG_DEFAULT_UIMAGE is not set
++CONFIG_EPAPR_BOOT=y
++CONFIG_FB_SYS_COPYAREA=y
++CONFIG_FB_SYS_FILLRECT=y
++CONFIG_FB_SYS_FOPS=y
++CONFIG_FB_SYS_IMAGEBLIT=y
++CONFIG_FB_UDL=m
++CONFIG_FORCE_MAX_ZONEORDER=13
++CONFIG_GENERIC_TBSYNC=y
++# CONFIG_HAS_RAPIDIO is not set
++CONFIG_HAVE_BOOTMEM_INFO_NODE=y
++CONFIG_HAVE_SETUP_PER_CPU_AREA=y
++CONFIG_HIBERNATION=y
++CONFIG_HUGETLB_PAGE=y
++CONFIG_IMA=y
++CONFIG_KERNEL_START=0xc000000000000000
++CONFIG_MMIO_NVRAM=y
++CONFIG_MPIC_U3_HT_IRQS=y
++CONFIG_NEED_DMA_MAP_STATE=y
++CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK=y
++CONFIG_NONSTATIC_KERNEL=y
++CONFIG_NR_CPUS=1024
++CONFIG_NUMA=y
++# CONFIG_PAGE_EXTENSION is not set
++CONFIG_PAGE_OFFSET=0xc000000000000000
++CONFIG_PGTABLE_LEVELS=4
++CONFIG_PHYS_ADDR_T_64BIT=y
++CONFIG_PPC64=y
++CONFIG_PPC_970_NAP=y
++# CONFIG_PPC_BOOK3E_64 is not set
++CONFIG_PPC_BOOK3S_64=y
++CONFIG_PPC_CELL=y
++CONFIG_PPC_COPRO_BASE=y
++CONFIG_PPC_DOORBELL=y
++# CONFIG_PPC_EPAPR_HV_PIC is not set
++CONFIG_PPC_I8259=y
++CONFIG_PPC_ICP_HV=y
++CONFIG_PPC_ICP_NATIVE=y
++CONFIG_PPC_ICS_RTAS=y
++# CONFIG_PPC_INDIRECT_PCI is not set
++CONFIG_PPC_MM_SLICES=y
++# CONFIG_PPC_MPC106 is not set
++CONFIG_PPC_OF_BOOT_TRAMPOLINE=y
++CONFIG_PPC_P7_NAP=y
++CONFIG_PPC_RTAS=y
++CONFIG_PPC_XICS=y
++CONFIG_RTC_DRV_DS3232=m
++CONFIG_SCHED_SMT=y
++CONFIG_SCSI_SRP_ATTRS=y
++# CONFIG_SPI_PXA2XX_PCI is not set
++CONFIG_U3_DART=y
++CONFIG_WORD_SIZE=64
+diff --git a/debian.master/config/ppc64el/config.common.ppc64el b/debian.master/config/ppc64el/config.common.ppc64el
+new file mode 100644
+index 0000000..d4a69ea
+--- /dev/null
++++ b/debian.master/config/ppc64el/config.common.ppc64el
+@@ -0,0 +1,520 @@
++#
++# Config options for config.common.ppc64el automatically generated by splitconfig.pl
++#
++CONFIG_64BIT=y
++CONFIG_6LOWPAN=m
++CONFIG_ABX500_CORE=y
++CONFIG_AC97_BUS=m
++CONFIG_ADFS_FS=m
++CONFIG_AFFS_FS=m
++CONFIG_AIX_PARTITION=y
++CONFIG_ALIM7101_WDT=m
++CONFIG_ALTERA_TSE=m
++CONFIG_AMIGA_PARTITION=y
++CONFIG_APPLICOM=m
++CONFIG_ARCH_DMA_ADDR_T_64BIT=y
++CONFIG_ARCH_HAS_ILOG2_U32=y
++CONFIG_ARCH_HAS_ILOG2_U64=y
++# CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
++CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
++CONFIG_ARCH_RANDOM=y
++CONFIG_ARCH_SELECT_MEMORY_MODEL=y
++CONFIG_ARCH_SPARSEMEM_DEFAULT=y
++CONFIG_ARCNET=m
++CONFIG_ATALK=m
++CONFIG_ATARI_PARTITION=y
++CONFIG_ATA_GENERIC=m
++# CONFIG_ATA_NONSTANDARD is not set
++CONFIG_ATA_OVER_ETH=m
++CONFIG_ATA_PIIX=m
++CONFIG_ATM=m
++# CONFIG_AUDIT_ARCH_COMPAT_GENERIC is not set
++CONFIG_AUTOFS4_FS=m
++CONFIG_AUXDISPLAY=y
++CONFIG_BACKLIGHT_LCD_SUPPORT=y
++CONFIG_BATMAN_ADV=m
++CONFIG_BCH=m
++CONFIG_BCMA=m
++CONFIG_BCM_KONA_USB2_PHY=m
++CONFIG_BE2ISCSI=m
++CONFIG_BEFS_FS=m
++CONFIG_BFS_FS=m
++CONFIG_BLK_CPQ_CISS_DA=m
++CONFIG_BLK_DEV_3W_XXXX_RAID=m
++CONFIG_BLK_DEV_CRYPTOLOOP=m
++CONFIG_BLK_DEV_DAC960=m
++CONFIG_BLK_DEV_NVME=m
++CONFIG_BLK_DEV_PCIESSD_MTIP32XX=m
++CONFIG_BLK_DEV_RSXX=m
++CONFIG_BLK_DEV_SKD=m
++# CONFIG_BLK_DEV_SR_VENDOR is not set
++CONFIG_BLK_DEV_SX8=m
++CONFIG_BLK_DEV_UMEM=m
++CONFIG_BOUNCE=y
++CONFIG_BSD_DISKLABEL=y
++CONFIG_C2PORT=m
++CONFIG_CADENCE_WATCHDOG=m
++CONFIG_CAIF=m
++CONFIG_CAN=m
++CONFIG_CB710_CORE=m
++# CONFIG_CC_STACKPROTECTOR is not set
++CONFIG_CDROM_PKTCDVD=m
++CONFIG_CMA=y
++CONFIG_CMDLINE_PARTITION=y
++CONFIG_CMM=m
++CONFIG_CONFIGFS_FS=m
++# CONFIG_CPU_BIG_ENDIAN is not set
++CONFIG_CPU_LITTLE_ENDIAN=y
++CONFIG_CRAMFS=m
++CONFIG_CRASH_DUMP=y
++CONFIG_CXL_BASE=y
++CONFIG_CXL_EEH=y
++CONFIG_CXL_KERNEL_API=y
++CONFIG_DECNET=m
++CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
++# CONFIG_DEFAULT_UIMAGE is not set
++CONFIG_DMADEVICES=y
++CONFIG_DMA_SHARED_BUFFER=y
++CONFIG_DMA_VIRTUAL_CHANNELS=m
++# CONFIG_DM_DEBUG is not set
++CONFIG_DNET=m
++CONFIG_DRM=m
++CONFIG_DUMMY_IRQ=m
++CONFIG_DW_WATCHDOG=m
++CONFIG_ECHO=m
++CONFIG_EEPROM_93CX6=m
++CONFIG_EFS_FS=m
++# CONFIG_EM_TIMER_STI is not set
++CONFIG_ENCLOSURE_SERVICES=m
++CONFIG_EPAPR_BOOT=y
++CONFIG_ETHOC=m
++CONFIG_EXOFS_FS=m
++CONFIG_EXTCON=y
++CONFIG_F2FS_FS=m
++CONFIG_FB=y
++CONFIG_FB_ATY128=m
++# CONFIG_FB_BOOT_VESA_SUPPORT is not set
++# CONFIG_FB_CFB_REV_PIXELS_IN_BYTE is not set
++CONFIG_FB_IBM_GXT4500=y
++CONFIG_FB_MACMODES=y
++CONFIG_FB_SYS_COPYAREA=m
++CONFIG_FB_SYS_FILLRECT=m
++CONFIG_FB_SYS_FOPS=m
++CONFIG_FB_SYS_IMAGEBLIT=m
++CONFIG_FB_UDL=m
++CONFIG_FB_VOODOO1=m
++CONFIG_FDDI=y
++CONFIG_FEALNX=m
++CONFIG_FIREWIRE=m
++CONFIG_FIREWIRE_NOSY=m
++CONFIG_FIRMWARE_IN_KERNEL=y
++CONFIG_FIXED_PHY=y
++CONFIG_FMC=m
++# CONFIG_FONTS is not set
++CONFIG_FORCE_MAX_ZONEORDER=9
++CONFIG_FRAME_WARN=2048
++CONFIG_FUSION=y
++CONFIG_GAMEPORT=m
++CONFIG_GENERIC_CSUM=y
++CONFIG_GENERIC_PHY=y
++# CONFIG_GENERIC_TBSYNC is not set
++CONFIG_GPIO_GENERIC=m
++CONFIG_GPIO_GENERIC_PLATFORM=m
++CONFIG_GPIO_TWL4030=m
++CONFIG_GPIO_TWL6040=m
++# CONFIG_HAS_RAPIDIO is not set
++CONFIG_HAVE_64BIT_ALIGNED_ACCESS=y
++# CONFIG_HAVE_AOUT is not set
++# CONFIG_HAVE_ARCH_BITREVERSE is not set
++CONFIG_HAVE_BOOTMEM_INFO_NODE=y
++# CONFIG_HAVE_GENERIC_DMA_COHERENT is not set
++CONFIG_HAVE_SETUP_PER_CPU_AREA=y
++CONFIG_HFSPLUS_FS=m
++CONFIG_HFS_FS=m
++# CONFIG_HIBERNATION is not set
++# CONFIG_HIO is not set
++# CONFIG_HOTPLUG_PCI_PCIE is not set
++# CONFIG_HOTPLUG_PCI_SHPC is not set
++CONFIG_HPFS_FS=m
++CONFIG_HP_ILO=m
++CONFIG_HSI=m
++CONFIG_HSR=m
++CONFIG_HTC_PASIC3=m
++CONFIG_HUGETLB_PAGE=y
++CONFIG_HWMON=y
++CONFIG_HW_RANDOM_TIMERIOMEM=m
++CONFIG_HZ=250
++# CONFIG_HZ_100 is not set
++# CONFIG_HZ_1000 is not set
++CONFIG_HZ_250=y
++CONFIG_I2C=y
++# CONFIG_I2C_SLAVE is not set
++CONFIG_I6300ESB_WDT=m
++CONFIG_IEEE802154=m
++CONFIG_IIO=m
++CONFIG_IMA=y
++CONFIG_INFINIBAND_NES=m
++CONFIG_INFINIBAND_OCRDMA=m
++CONFIG_INFINIBAND_QIB=m
++CONFIG_INPUT=y
++CONFIG_IPACK_BUS=m
++CONFIG_IPMI_HANDLER=m
++CONFIG_IPMI_SI_PROBE_DEFAULTS=y
++CONFIG_IPX=m
++# CONFIG_IP_DCCP_CCID3 is not set
++CONFIG_IRQ_ALL_CPUS=y
++CONFIG_IRQ_BYPASS_MANAGER=y
++# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
++CONFIG_JFS_FS=m
++CONFIG_JME=m
++CONFIG_JUMP_LABEL=y
++CONFIG_KARMA_PARTITION=y
++CONFIG_KERNEL_START=0xc000000000000000
++CONFIG_KVM=y
++CONFIG_LAPB=m
++CONFIG_LDM_PARTITION=y
++CONFIG_LIBNVDIMM=y
++CONFIG_LLC2=m
++CONFIG_LOG_BUF_SHIFT=17
++CONFIG_LPARCFG=y
++CONFIG_LPC_ICH=m
++CONFIG_LPC_SCH=m
++CONFIG_MAC_PARTITION=y
++CONFIG_MAGIC_SYSRQ_DEFAULT_ENABLE=0x1
++CONFIG_MAILBOX=y
++CONFIG_MAX63XX_WATCHDOG=m
++CONFIG_MCB=m
++CONFIG_MD_MULTIPATH=m
++CONFIG_MEDIA_SUPPORT=m
++CONFIG_MEGARAID_LEGACY=m
++CONFIG_MEGARAID_NEWGEN=y
++CONFIG_MEGARAID_SAS=m
++CONFIG_MEMORY=y
++CONFIG_MEMSTICK=m
++CONFIG_MFD_CORE=y
++CONFIG_MFD_JANZ_CMODIO=m
++CONFIG_MFD_KEMPLD=m
++CONFIG_MFD_MT6397=m
++CONFIG_MFD_RDC321X=m
++CONFIG_MFD_RTSX_PCI=m
++CONFIG_MFD_SM501=m
++CONFIG_MFD_SYSCON=y
++CONFIG_MFD_TI_AM335X_TSCADC=m
++# CONFIG_MFD_TMIO is not set
++CONFIG_MFD_VX855=m
++CONFIG_MII=m
++CONFIG_MINIX_FS=m
++CONFIG_MINIX_SUBPARTITION=y
++CONFIG_MMC=y
++CONFIG_MMC_BLOCK=m
++CONFIG_MMC_SDHCI=m
++CONFIG_MMC_SDHCI_PLTFM=m
++# CONFIG_MMIO_NVRAM is not set
++# CONFIG_MPIC_MSGR is not set
++# CONFIG_MPIC_U3_HT_IRQS is not set
++CONFIG_MTD=m
++CONFIG_MTD_BLKDEVS=m
++CONFIG_MTD_BLOCK=m
++CONFIG_MTD_CMDLINE_PARTS=m
++CONFIG_MTD_NAND=m
++CONFIG_MTD_NAND_BCH=m
++CONFIG_MTD_NAND_ECC=m
++CONFIG_MTD_NAND_IDS=m
++# CONFIG_MTD_NAND_OMAP_BCH_BUILD is not set
++CONFIG_MTD_OF_PARTS=m
++CONFIG_NCP_FS=m
++CONFIG_NEED_DMA_MAP_STATE=y
++CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK=y
++CONFIG_NET_CADENCE=y
++CONFIG_NET_PACKET_ENGINE=y
++CONFIG_NET_VENDOR_3COM=y
++CONFIG_NET_VENDOR_ADAPTEC=y
++CONFIG_NET_VENDOR_AGERE=y
++CONFIG_NET_VENDOR_ALTEON=y
++CONFIG_NET_VENDOR_AMD=y
++CONFIG_NET_VENDOR_ARC=y
++CONFIG_NET_VENDOR_ATHEROS=y
++CONFIG_NET_VENDOR_BROADCOM=y
++CONFIG_NET_VENDOR_BROCADE=y
++CONFIG_NET_VENDOR_CAVIUM=y
++CONFIG_NET_VENDOR_CHELSIO=y
++CONFIG_NET_VENDOR_CISCO=y
++CONFIG_NET_VENDOR_DEC=y
++CONFIG_NET_VENDOR_DLINK=y
++CONFIG_NET_VENDOR_EMULEX=y
++CONFIG_NET_VENDOR_EXAR=y
++CONFIG_NET_VENDOR_EZCHIP=y
++CONFIG_NET_VENDOR_HP=y
++CONFIG_NET_VENDOR_INTEL=y
++CONFIG_NET_VENDOR_MARVELL=y
++CONFIG_NET_VENDOR_MICREL=y
++CONFIG_NET_VENDOR_MYRI=y
++CONFIG_NET_VENDOR_NATSEMI=y
++CONFIG_NET_VENDOR_NVIDIA=y
++CONFIG_NET_VENDOR_OKI=y
++CONFIG_NET_VENDOR_QLOGIC=y
++CONFIG_NET_VENDOR_QUALCOMM=y
++CONFIG_NET_VENDOR_RDC=y
++CONFIG_NET_VENDOR_REALTEK=y
++CONFIG_NET_VENDOR_RENESAS=y
++CONFIG_NET_VENDOR_ROCKER=y
++CONFIG_NET_VENDOR_SAMSUNG=y
++CONFIG_NET_VENDOR_SEEQ=y
++CONFIG_NET_VENDOR_SILAN=y
++CONFIG_NET_VENDOR_SIS=y
++CONFIG_NET_VENDOR_SMSC=y
++CONFIG_NET_VENDOR_STMICRO=y
++CONFIG_NET_VENDOR_SUN=y
++CONFIG_NET_VENDOR_SYNOPSYS=y
++CONFIG_NET_VENDOR_TEHUTI=y
++CONFIG_NET_VENDOR_TI=y
++CONFIG_NET_VENDOR_VIA=y
++CONFIG_NET_VENDOR_WIZNET=y
++CONFIG_NEW_LEDS=y
++CONFIG_NFC=m
++CONFIG_NODES_SHIFT=8
++CONFIG_NONSTATIC_KERNEL=y
++CONFIG_NOZOMI=m
++CONFIG_NR_CPUS=2048
++CONFIG_NTB=m
++# CONFIG_NTFS_RW is not set
++CONFIG_NUMA=y
++CONFIG_NUMA_BALANCING_DEFAULT_ENABLED=y
++CONFIG_NVMEM=m
++CONFIG_N_GSM=m
++CONFIG_OF=y
++CONFIG_OMFS_FS=m
++# CONFIG_OPENNSL is not set
++CONFIG_OSF_PARTITION=y
++# CONFIG_PAGE_EXTENSION is not set
++CONFIG_PAGE_OFFSET=0xc000000000000000
++CONFIG_PANIC_TIMEOUT=10
++CONFIG_PARPORT=m
++CONFIG_PATA_SIS=m
++# CONFIG_PCCARD is not set
++CONFIG_PCIPCWATCHDOG=m
++CONFIG_PCI_PASID=y
++CONFIG_PCI_PRI=y
++CONFIG_PCI_QUIRKS=y
++CONFIG_PGTABLE_LEVELS=3
++CONFIG_PGTABLE_MAPPING=y
++CONFIG_PHANTOM=m
++CONFIG_PHONET=m
++CONFIG_PHYLIB=y
++CONFIG_PHYSICAL_START=0x00000000
++CONFIG_PHYS_ADDR_T_64BIT=y
++# CONFIG_PHY_EXYNOS5250_USB2 is not set
++CONFIG_PHY_PXA_28NM_HSIC=m
++CONFIG_PHY_PXA_28NM_USB2=m
++CONFIG_PM_DEBUG=y
++CONFIG_PM_DEVFREQ=y
++CONFIG_PM_WAKELOCKS=y
++CONFIG_POWER7_CPU=y
++CONFIG_POWERCAP=y
++CONFIG_POWER_AVS=y
++CONFIG_POWER_SUPPLY=y
++CONFIG_PPC64=y
++# CONFIG_PPC_4K_PAGES is not set
++CONFIG_PPC_64K_PAGES=y
++# CONFIG_PPC_970_NAP is not set
++# CONFIG_PPC_BOOK3E_64 is not set
++CONFIG_PPC_BOOK3S_64=y
++# CONFIG_PPC_CELL is not set
++CONFIG_PPC_COPRO_BASE=y
++CONFIG_PPC_DENORMALISATION=y
++# CONFIG_PPC_DISABLE_WERROR is not set
++CONFIG_PPC_DOORBELL=y
++# CONFIG_PPC_EPAPR_HV_PIC is not set
++CONFIG_PPC_I8259=y
++CONFIG_PPC_ICP_HV=y
++CONFIG_PPC_ICP_NATIVE=y
++# CONFIG_PPC_ICSWX is not set
++CONFIG_PPC_ICS_RTAS=y
++# CONFIG_PPC_INDIRECT_PCI is not set
++CONFIG_PPC_MM_SLICES=y
++# CONFIG_PPC_MPC106 is not set
++CONFIG_PPC_OF_BOOT_TRAMPOLINE=y
++CONFIG_PPC_P7_NAP=y
++CONFIG_PPC_RTAS=y
++CONFIG_PPC_SMLPAR=y
++CONFIG_PPC_SPLPAR=y
++CONFIG_PPC_XICS=y
++CONFIG_PPP=y
++CONFIG_PPS=y
++CONFIG_PPS_CLIENT_GPIO=m
++CONFIG_PPS_CLIENT_LDISC=m
++# CONFIG_PREEMPT is not set
++# CONFIG_PREEMPT_NONE is not set
++CONFIG_PREEMPT_VOLUNTARY=y
++CONFIG_PROBE_EVENTS=y
++CONFIG_PSTORE=y
++# CONFIG_PSTORE_CONSOLE is not set
++CONFIG_PSTORE_RAM=m
++CONFIG_PTP_1588_CLOCK=y
++CONFIG_PWM=y
++CONFIG_QNX4FS_FS=m
++CONFIG_QNX6FS_FS=m
++CONFIG_R3964=m
++CONFIG_RAW_DRIVER=m
++CONFIG_RCU_CPU_STALL_TIMEOUT=21
++CONFIG_REED_SOLOMON=m
++CONFIG_REGULATOR=y
++CONFIG_REGULATOR_FIXED_VOLTAGE=m
++CONFIG_REGULATOR_TWL4030=m
++CONFIG_REISERFS_FS=m
++CONFIG_RESET_CONTROLLER=y
++CONFIG_RFKILL=y
++CONFIG_ROMFS_FS=m
++CONFIG_RTC_DRV_CMOS=m
++CONFIG_RTC_DRV_DS3232=m
++CONFIG_RTC_DRV_PCF8523=m
++CONFIG_RTC_DRV_TWL4030=m
++CONFIG_SATA_AHCI_PLATFORM=m
++CONFIG_SATA_SVW=m
++CONFIG_SCHED_SMT=y
++CONFIG_SCSI_3W_9XXX=m
++CONFIG_SCSI_3W_SAS=m
++CONFIG_SCSI_AACRAID=m
++CONFIG_SCSI_ACARD=m
++CONFIG_SCSI_ADVANSYS=m
++CONFIG_SCSI_AIC79XX=m
++CONFIG_SCSI_AIC7XXX=m
++CONFIG_SCSI_AIC94XX=m
++CONFIG_SCSI_AM53C974=m
++CONFIG_SCSI_ARCMSR=m
++CONFIG_SCSI_BFA_FC=m
++CONFIG_SCSI_BNX2X_FCOE=m
++CONFIG_SCSI_BNX2_ISCSI=m
++CONFIG_SCSI_CHELSIO_FCOE=m
++CONFIG_SCSI_CXGB3_ISCSI=m
++CONFIG_SCSI_CXGB4_ISCSI=m
++CONFIG_SCSI_DC395x=m
++CONFIG_SCSI_DMX3191D=m
++CONFIG_SCSI_ESAS2R=m
++CONFIG_SCSI_FUTURE_DOMAIN=m
++CONFIG_SCSI_HPSA=m
++CONFIG_SCSI_HPTIOP=m
++CONFIG_SCSI_INIA100=m
++CONFIG_SCSI_INITIO=m
++CONFIG_SCSI_IPS=m
++CONFIG_SCSI_LPFC=m
++CONFIG_SCSI_MVSAS=m
++CONFIG_SCSI_MVUMI=m
++CONFIG_SCSI_PM8001=m
++CONFIG_SCSI_PMCRAID=m
++CONFIG_SCSI_QLA_FC=m
++CONFIG_SCSI_QLA_ISCSI=m
++CONFIG_SCSI_QLOGIC_1280=m
++CONFIG_SCSI_SNIC=m
++CONFIG_SCSI_SRP_ATTRS=y
++CONFIG_SCSI_STEX=m
++CONFIG_SCSI_SYM53C8XX_2=m
++CONFIG_SCSI_UFSHCD=m
++CONFIG_SCSI_WD719X=m
++CONFIG_SECURITY_SELINUX_BOOTPARAM=y
++CONFIG_SECURITY_SELINUX_DISABLE=y
++# CONFIG_SENSORS_SCH56XX_COMMON is not set
++CONFIG_SERIAL_8250=y
++CONFIG_SERIAL_8250_DW=m
++CONFIG_SERIAL_8250_FSL=y
++CONFIG_SERIAL_ALTERA_JTAGUART=m
++CONFIG_SERIAL_ALTERA_UART=m
++CONFIG_SERIAL_ARC=m
++CONFIG_SERIAL_CORE=y
++CONFIG_SERIAL_FSL_LPUART=m
++CONFIG_SERIAL_JSM=m
++CONFIG_SERIAL_NONSTANDARD=y
++CONFIG_SERIAL_RP2=m
++CONFIG_SERIAL_SCCNXP=y
++CONFIG_SERIO=y
++CONFIG_SFC=m
++CONFIG_SGI_IOC4=m
++CONFIG_SGI_PARTITION=y
++# CONFIG_SH_TIMER_CMT is not set
++# CONFIG_SH_TIMER_MTU2 is not set
++# CONFIG_SH_TIMER_TMU is not set
++# CONFIG_SIMPLE_GPIO is not set
++CONFIG_SLIP=m
++CONFIG_SND=m
++CONFIG_SND_DMAENGINE_PCM=m
++CONFIG_SND_EMU10K1_SEQ=m
++# CONFIG_SND_OPL4_LIB_SEQ is not set
++CONFIG_SND_PCM=m
++# CONFIG_SND_SBAWE_SEQ is not set
++CONFIG_SND_SOC=m
++CONFIG_SND_SOC_FSL_SSI=m
++CONFIG_SND_SOC_I2C_AND_SPI=m
++CONFIG_SND_SOC_IMX_AUDMUX=m
++# CONFIG_SND_SOC_RT5677_SPI is not set
++CONFIG_SND_SOC_SGTL5000=m
++CONFIG_SND_TIMER=m
++CONFIG_SOC_TI=y
++CONFIG_SOLARIS_X86_PARTITION=y
++CONFIG_SOUND=m
++CONFIG_SPI=y
++# CONFIG_SPI_PXA2XX_PCI is not set
++CONFIG_SPMI=m
++CONFIG_SRAM=y
++CONFIG_SSB=m
++CONFIG_STAGING=y
++CONFIG_STANDALONE=y
++CONFIG_STE_MODEM_RPROC=m
++CONFIG_SUN_PARTITION=y
++CONFIG_SYSV68_PARTITION=y
++CONFIG_SYSV_FS=m
++# CONFIG_SYS_HYPERVISOR is not set
++CONFIG_THERMAL=y
++CONFIG_THUNDERBOLT=m
++CONFIG_TIFM_CORE=m
++CONFIG_TIGON3=y
++CONFIG_TI_CPSW_ALE=m
++CONFIG_TRACE_SINK=m
++CONFIG_TTY_PRINTK=y
++# CONFIG_U3_DART is not set
++# CONFIG_UDBG_RTAS_CONSOLE is not set
++CONFIG_UFS_FS=m
++CONFIG_UIO=m
++CONFIG_ULTRIX_PARTITION=y
++CONFIG_UNIXWARE_DISKLABEL=y
++CONFIG_UPROBES=y
++CONFIG_USB_EHCI_HCD_PLATFORM=m
++CONFIG_USB_GADGET=m
++# CONFIG_USB_G_MULTI is not set
++CONFIG_USB_HCD_BCMA=m
++CONFIG_USB_HCD_SSB=m
++CONFIG_USB_MUSB_HDRC=m
++CONFIG_USB_OHCI_HCD_PLATFORM=m
++# CONFIG_USB_OHCI_HCD_PPC_OF is not set
++# CONFIG_USB_OHCI_HCD_PPC_OF_BE is not set
++CONFIG_USB_SUPPORT=y
++CONFIG_UWB=m
++CONFIG_VFIO=y
++CONFIG_VFIO_IOMMU_SPAPR_TCE=y
++# CONFIG_VFIO_IOMMU_TYPE1 is not set
++CONFIG_VFIO_PCI=y
++CONFIG_VFIO_SPAPR_EEH=y
++CONFIG_VFIO_VIRQFD=y
++CONFIG_VGASTATE=m
++CONFIG_VIRTIO_MMIO=y
++# CONFIG_VIRT_CPU_ACCOUNTING_NATIVE is not set
++CONFIG_VME_BUS=y
++CONFIG_VMXNET3=m
++CONFIG_VXFS_FS=m
++CONFIG_W1=m
++CONFIG_WAN=y
++CONFIG_WDTPCI=m
++CONFIG_WIMAX=m
++CONFIG_WORD_SIZE=64
++CONFIG_X25=m
++CONFIG_XILINX_WATCHDOG=m
++CONFIG_XILLYBUS=m
++CONFIG_XZ_DEC_ARM=y
++CONFIG_XZ_DEC_ARMTHUMB=y
++CONFIG_XZ_DEC_BCJ=y
++CONFIG_XZ_DEC_IA64=y
++CONFIG_XZ_DEC_POWERPC=y
++CONFIG_XZ_DEC_SPARC=y
++CONFIG_XZ_DEC_TEST=m
++CONFIG_XZ_DEC_X86=y
++CONFIG_ZLIB_DEFLATE=y
++CONFIG_ZONE_DMA_FLAG=1
+diff --git a/debian.master/config/ppc64el/config.flavour.generic b/debian.master/config/ppc64el/config.flavour.generic
+new file mode 100644
+index 0000000..bb7773a
+--- /dev/null
++++ b/debian.master/config/ppc64el/config.flavour.generic
+@@ -0,0 +1,3 @@
++#
++# Config options for config.flavour.generic automatically generated by splitconfig.pl
++#
+diff --git a/debian.master/config/s390x/config.common.s390x b/debian.master/config/s390x/config.common.s390x
+new file mode 100644
+index 0000000..b82bf27
+--- /dev/null
++++ b/debian.master/config/s390x/config.common.s390x
+@@ -0,0 +1,389 @@
++#
++# Config options for config.common.s390x automatically generated by splitconfig.pl
++#
++CONFIG_64BIT=y
++# CONFIG_6LOWPAN is not set
++# CONFIG_ABX500_CORE is not set
++# CONFIG_ADFS_FS is not set
++# CONFIG_AFFS_FS is not set
++# CONFIG_AIX_PARTITION is not set
++# CONFIG_ALIM7101_WDT is not set
++# CONFIG_ALTERA_TSE is not set
++# CONFIG_AMIGA_PARTITION is not set
++# CONFIG_APPLICOM is not set
++CONFIG_ARCH_DMA_ADDR_T_64BIT=y
++# CONFIG_ARCH_HAS_ILOG2_U32 is not set
++# CONFIG_ARCH_HAS_ILOG2_U64 is not set
++CONFIG_ARCH_SELECT_MEMORY_MODEL=y
++CONFIG_ARCH_SPARSEMEM_DEFAULT=y
++# CONFIG_ARCNET is not set
++# CONFIG_ATALK is not set
++# CONFIG_ATARI_PARTITION is not set
++# CONFIG_ATA_OVER_ETH is not set
++# CONFIG_ATM is not set
++# CONFIG_AUDIT_ARCH_COMPAT_GENERIC is not set
++CONFIG_AUTOFS4_FS=y
++# CONFIG_AUXDISPLAY is not set
++# CONFIG_BACKLIGHT_LCD_SUPPORT is not set
++# CONFIG_BATMAN_ADV is not set
++# CONFIG_BCMA is not set
++# CONFIG_BCM_KONA_USB2_PHY is not set
++# CONFIG_BE2ISCSI is not set
++# CONFIG_BEFS_FS is not set
++# CONFIG_BFS_FS is not set
++# CONFIG_BLK_CPQ_CISS_DA is not set
++# CONFIG_BLK_DEV_3W_XXXX_RAID is not set
++# CONFIG_BLK_DEV_CRYPTOLOOP is not set
++# CONFIG_BLK_DEV_DAC960 is not set
++# CONFIG_BLK_DEV_NVME is not set
++# CONFIG_BLK_DEV_PCIESSD_MTIP32XX is not set
++# CONFIG_BLK_DEV_RSXX is not set
++# CONFIG_BLK_DEV_SKD is not set
++CONFIG_BLK_DEV_SR_VENDOR=y
++# CONFIG_BLK_DEV_SX8 is not set
++# CONFIG_BLK_DEV_UMEM is not set
++# CONFIG_BOUNCE is not set
++# CONFIG_BSD_DISKLABEL is not set
++# CONFIG_C2PORT is not set
++# CONFIG_CADENCE_WATCHDOG is not set
++# CONFIG_CAIF is not set
++# CONFIG_CAN is not set
++# CONFIG_CB710_CORE is not set
++# CONFIG_CC_STACKPROTECTOR is not set
++# CONFIG_CDROM_PKTCDVD is not set
++# CONFIG_CMA is not set
++# CONFIG_CMDLINE_PARTITION is not set
++CONFIG_CMM=y
++CONFIG_CONFIGFS_FS=y
++# CONFIG_CRAMFS is not set
++CONFIG_CRASH_DUMP=y
++# CONFIG_CXL_BASE is not set
++# CONFIG_CXL_EEH is not set
++# CONFIG_CXL_KERNEL_API is not set
++# CONFIG_DECNET is not set
++CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
++# CONFIG_DMADEVICES is not set
++# CONFIG_DMA_SHARED_BUFFER is not set
++CONFIG_DM_DEBUG=y
++# CONFIG_DNET is not set
++# CONFIG_DRM is not set
++# CONFIG_DUMMY_IRQ is not set
++# CONFIG_DW_WATCHDOG is not set
++# CONFIG_ECHO is not set
++# CONFIG_EEPROM_93CX6 is not set
++# CONFIG_EFS_FS is not set
++# CONFIG_EM_TIMER_STI is not set
++# CONFIG_ENCLOSURE_SERVICES is not set
++# CONFIG_ETHOC is not set
++# CONFIG_EXOFS_FS is not set
++# CONFIG_EXTCON is not set
++# CONFIG_F2FS_FS is not set
++# CONFIG_FB is not set
++# CONFIG_FDDI is not set
++# CONFIG_FEALNX is not set
++# CONFIG_FIREWIRE is not set
++# CONFIG_FIREWIRE_NOSY is not set
++# CONFIG_FIRMWARE_IN_KERNEL is not set
++CONFIG_FIXED_PHY=m
++# CONFIG_FMC is not set
++CONFIG_FORCE_MAX_ZONEORDER=9
++CONFIG_FRAME_WARN=1024
++# CONFIG_FUSION is not set
++# CONFIG_GAMEPORT is not set
++# CONFIG_GENERIC_PHY is not set
++CONFIG_HAVE_64BIT_ALIGNED_ACCESS=y
++# CONFIG_HAVE_AOUT is not set
++# CONFIG_HAVE_ARCH_BITREVERSE is not set
++# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
++# CONFIG_HAVE_GENERIC_DMA_COHERENT is not set
++# CONFIG_HFSPLUS_FS is not set
++# CONFIG_HFS_FS is not set
++CONFIG_HIBERNATION=y
++CONFIG_HOTPLUG_PCI_PCIE=y
++# CONFIG_HOTPLUG_PCI_SHPC is not set
++# CONFIG_HPFS_FS is not set
++# CONFIG_HP_ILO is not set
++# CONFIG_HSI is not set
++# CONFIG_HSR is not set
++# CONFIG_HTC_PASIC3 is not set
++CONFIG_HUGETLB_PAGE=y
++# CONFIG_HWMON is not set
++# CONFIG_HW_RANDOM_TIMERIOMEM is not set
++CONFIG_HZ=100
++CONFIG_HZ_100=y
++# CONFIG_HZ_1000 is not set
++# CONFIG_HZ_250 is not set
++# CONFIG_I2C is not set
++# CONFIG_I6300ESB_WDT is not set
++# CONFIG_IEEE802154 is not set
++# CONFIG_IIO is not set
++CONFIG_IMA=y
++# CONFIG_INFINIBAND_NES is not set
++# CONFIG_INFINIBAND_OCRDMA is not set
++# CONFIG_INFINIBAND_QIB is not set
++# CONFIG_INPUT is not set
++# CONFIG_IPACK_BUS is not set
++# CONFIG_IPMI_HANDLER is not set
++# CONFIG_IPX is not set
++CONFIG_IP_DCCP_CCID3=y
++CONFIG_IRQ_BYPASS_MANAGER=m
++# CONFIG_JFS_FS is not set
++# CONFIG_JME is not set
++CONFIG_JUMP_LABEL=y
++# CONFIG_KARMA_PARTITION is not set
++# CONFIG_KERNEL_GZIP is not set
++CONFIG_KERNEL_XZ=y
++CONFIG_KVM=y
++# CONFIG_LAPB is not set
++# CONFIG_LDM_PARTITION is not set
++# CONFIG_LIBNVDIMM is not set
++# CONFIG_LLC2 is not set
++CONFIG_LOG_BUF_SHIFT=17
++# CONFIG_LPC_ICH is not set
++# CONFIG_LPC_SCH is not set
++# CONFIG_MAC_PARTITION is not set
++CONFIG_MAGIC_SYSRQ_DEFAULT_ENABLE=0x01b6
++# CONFIG_MAILBOX is not set
++# CONFIG_MAX63XX_WATCHDOG is not set
++# CONFIG_MCB is not set
++CONFIG_MD_MULTIPATH=y
++# CONFIG_MEDIA_SUPPORT is not set
++# CONFIG_MEGARAID_LEGACY is not set
++# CONFIG_MEGARAID_NEWGEN is not set
++# CONFIG_MEGARAID_SAS is not set
++# CONFIG_MEMORY is not set
++# CONFIG_MEMSTICK is not set
++# CONFIG_MFD_CORE is not set
++# CONFIG_MFD_JANZ_CMODIO is not set
++# CONFIG_MFD_KEMPLD is not set
++# CONFIG_MFD_MT6397 is not set
++# CONFIG_MFD_RDC321X is not set
++# CONFIG_MFD_RTSX_PCI is not set
++# CONFIG_MFD_SM501 is not set
++# CONFIG_MFD_SYSCON is not set
++# CONFIG_MFD_TI_AM335X_TSCADC is not set
++# CONFIG_MFD_TMIO is not set
++# CONFIG_MFD_VX855 is not set
++# CONFIG_MINIX_FS is not set
++# CONFIG_MINIX_SUBPARTITION is not set
++# CONFIG_MMC is not set
++# CONFIG_MTD is not set
++# CONFIG_NCP_FS is not set
++CONFIG_NEED_DMA_MAP_STATE=y
++# CONFIG_NET_CADENCE is not set
++# CONFIG_NET_PACKET_ENGINE is not set
++# CONFIG_NET_VENDOR_3COM is not set
++# CONFIG_NET_VENDOR_ADAPTEC is not set
++# CONFIG_NET_VENDOR_AGERE is not set
++# CONFIG_NET_VENDOR_ALTEON is not set
++# CONFIG_NET_VENDOR_AMD is not set
++# CONFIG_NET_VENDOR_ARC is not set
++# CONFIG_NET_VENDOR_ATHEROS is not set
++# CONFIG_NET_VENDOR_BROADCOM is not set
++# CONFIG_NET_VENDOR_BROCADE is not set
++# CONFIG_NET_VENDOR_CAVIUM is not set
++# CONFIG_NET_VENDOR_CHELSIO is not set
++# CONFIG_NET_VENDOR_CISCO is not set
++# CONFIG_NET_VENDOR_DEC is not set
++# CONFIG_NET_VENDOR_DLINK is not set
++# CONFIG_NET_VENDOR_EMULEX is not set
++# CONFIG_NET_VENDOR_EXAR is not set
++# CONFIG_NET_VENDOR_EZCHIP is not set
++# CONFIG_NET_VENDOR_HP is not set
++# CONFIG_NET_VENDOR_INTEL is not set
++# CONFIG_NET_VENDOR_MARVELL is not set
++# CONFIG_NET_VENDOR_MICREL is not set
++# CONFIG_NET_VENDOR_MYRI is not set
++# CONFIG_NET_VENDOR_NATSEMI is not set
++# CONFIG_NET_VENDOR_NVIDIA is not set
++# CONFIG_NET_VENDOR_OKI is not set
++# CONFIG_NET_VENDOR_QLOGIC is not set
++# CONFIG_NET_VENDOR_QUALCOMM is not set
++# CONFIG_NET_VENDOR_RDC is not set
++# CONFIG_NET_VENDOR_REALTEK is not set
++# CONFIG_NET_VENDOR_RENESAS is not set
++# CONFIG_NET_VENDOR_ROCKER is not set
++# CONFIG_NET_VENDOR_SAMSUNG is not set
++# CONFIG_NET_VENDOR_SEEQ is not set
++# CONFIG_NET_VENDOR_SILAN is not set
++# CONFIG_NET_VENDOR_SIS is not set
++# CONFIG_NET_VENDOR_SMSC is not set
++# CONFIG_NET_VENDOR_STMICRO is not set
++# CONFIG_NET_VENDOR_SUN is not set
++# CONFIG_NET_VENDOR_SYNOPSYS is not set
++# CONFIG_NET_VENDOR_TEHUTI is not set
++# CONFIG_NET_VENDOR_TI is not set
++# CONFIG_NET_VENDOR_VIA is not set
++# CONFIG_NET_VENDOR_WIZNET is not set
++# CONFIG_NEW_LEDS is not set
++# CONFIG_NFC is not set
++CONFIG_NODES_SHIFT=4
++# CONFIG_NOZOMI is not set
++CONFIG_NR_CPUS=256
++# CONFIG_NTB is not set
++CONFIG_NTFS_RW=y
++CONFIG_NUMA=y
++# CONFIG_NUMA_BALANCING_DEFAULT_ENABLED is not set
++CONFIG_NUMA_EMU=y
++# CONFIG_NVMEM is not set
++# CONFIG_N_GSM is not set
++# CONFIG_OF is not set
++# CONFIG_OMFS_FS is not set
++# CONFIG_OSF_PARTITION is not set
++# CONFIG_PAGE_EXTENSION is not set
++CONFIG_PANIC_TIMEOUT=0
++# CONFIG_PARPORT is not set
++# CONFIG_PCIPCWATCHDOG is not set
++# CONFIG_PCI_PASID is not set
++# CONFIG_PCI_PRI is not set
++# CONFIG_PCI_QUIRKS is not set
++# CONFIG_PCMCIA is not set
++CONFIG_PGTABLE_LEVELS=4
++# CONFIG_PGTABLE_MAPPING is not set
++# CONFIG_PHANTOM is not set
++# CONFIG_PHONET is not set
++CONFIG_PHYLIB=m
++CONFIG_PHYS_ADDR_T_64BIT=y
++# CONFIG_PHY_PXA_28NM_HSIC is not set
++# CONFIG_PHY_PXA_28NM_USB2 is not set
++# CONFIG_PM_DEBUG is not set
++# CONFIG_PM_DEVFREQ is not set
++# CONFIG_PM_WAKELOCKS is not set
++# CONFIG_POWERCAP is not set
++# CONFIG_POWER_AVS is not set
++# CONFIG_POWER_SUPPLY is not set
++# CONFIG_PPP is not set
++CONFIG_PPS=m
++# CONFIG_PPS_CLIENT_GPIO is not set
++# CONFIG_PPS_CLIENT_LDISC is not set
++# CONFIG_PREEMPT is not set
++CONFIG_PREEMPT_NONE=y
++# CONFIG_PREEMPT_VOLUNTARY is not set
++CONFIG_PROBE_EVENTS=y
++# CONFIG_PSTORE is not set
++CONFIG_PTP_1588_CLOCK=m
++# CONFIG_PWM is not set
++# CONFIG_QNX4FS_FS is not set
++# CONFIG_QNX6FS_FS is not set
++# CONFIG_R3964 is not set
++# CONFIG_RAW_DRIVER is not set
++CONFIG_RCU_CPU_STALL_TIMEOUT=21
++# CONFIG_REGULATOR is not set
++# CONFIG_REISERFS_FS is not set
++# CONFIG_RESET_CONTROLLER is not set
++# CONFIG_RFKILL is not set
++# CONFIG_ROMFS_FS is not set
++CONFIG_SCHED_SMT=y
++# CONFIG_SCSI_3W_9XXX is not set
++# CONFIG_SCSI_3W_SAS is not set
++# CONFIG_SCSI_AACRAID is not set
++# CONFIG_SCSI_ACARD is not set
++# CONFIG_SCSI_ADVANSYS is not set
++# CONFIG_SCSI_AIC79XX is not set
++# CONFIG_SCSI_AIC7XXX is not set
++# CONFIG_SCSI_AIC94XX is not set
++# CONFIG_SCSI_AM53C974 is not set
++# CONFIG_SCSI_ARCMSR is not set
++# CONFIG_SCSI_BFA_FC is not set
++# CONFIG_SCSI_BNX2X_FCOE is not set
++# CONFIG_SCSI_BNX2_ISCSI is not set
++# CONFIG_SCSI_CHELSIO_FCOE is not set
++# CONFIG_SCSI_CXGB3_ISCSI is not set
++# CONFIG_SCSI_CXGB4_ISCSI is not set
++# CONFIG_SCSI_DC395x is not set
++# CONFIG_SCSI_DMX3191D is not set
++# CONFIG_SCSI_DPT_I2O is not set
++# CONFIG_SCSI_ESAS2R is not set
++# CONFIG_SCSI_FUTURE_DOMAIN is not set
++# CONFIG_SCSI_HPSA is not set
++# CONFIG_SCSI_HPTIOP is not set
++# CONFIG_SCSI_INIA100 is not set
++# CONFIG_SCSI_INITIO is not set
++# CONFIG_SCSI_IPS is not set
++# CONFIG_SCSI_LPFC is not set
++# CONFIG_SCSI_MVSAS is not set
++# CONFIG_SCSI_MVUMI is not set
++# CONFIG_SCSI_PM8001 is not set
++# CONFIG_SCSI_PMCRAID is not set
++# CONFIG_SCSI_QLA_FC is not set
++# CONFIG_SCSI_QLA_ISCSI is not set
++# CONFIG_SCSI_QLOGIC_1280 is not set
++# CONFIG_SCSI_SNIC is not set
++CONFIG_SCSI_SRP_ATTRS=m
++# CONFIG_SCSI_STEX is not set
++# CONFIG_SCSI_SYM53C8XX_2 is not set
++# CONFIG_SCSI_UFSHCD is not set
++# CONFIG_SCSI_WD719X is not set
++# CONFIG_SECURITY_SELINUX_BOOTPARAM is not set
++# CONFIG_SECURITY_SELINUX_DISABLE is not set
++# CONFIG_SERIAL_8250 is not set
++# CONFIG_SERIAL_ALTERA_JTAGUART is not set
++# CONFIG_SERIAL_ALTERA_UART is not set
++# CONFIG_SERIAL_ARC is not set
++CONFIG_SERIAL_CORE=m
++# CONFIG_SERIAL_FSL_LPUART is not set
++# CONFIG_SERIAL_JSM is not set
++# CONFIG_SERIAL_NONSTANDARD is not set
++# CONFIG_SERIAL_RP2 is not set
++# CONFIG_SERIAL_SCCNXP is not set
++# CONFIG_SERIO is not set
++# CONFIG_SFC is not set
++# CONFIG_SGI_IOC4 is not set
++# CONFIG_SGI_PARTITION is not set
++# CONFIG_SH_TIMER_CMT is not set
++# CONFIG_SH_TIMER_MTU2 is not set
++# CONFIG_SH_TIMER_TMU is not set
++# CONFIG_SLIP is not set
++# CONFIG_SOC_TI is not set
++# CONFIG_SOLARIS_X86_PARTITION is not set
++# CONFIG_SOUND is not set
++# CONFIG_SPI is not set
++# CONFIG_SPMI is not set
++# CONFIG_SRAM is not set
++# CONFIG_SSB is not set
++# CONFIG_STAGING is not set
++CONFIG_STANDALONE=y
++# CONFIG_STE_MODEM_RPROC is not set
++# CONFIG_SUN_PARTITION is not set
++# CONFIG_SYSV68_PARTITION is not set
++# CONFIG_SYSV_FS is not set
++CONFIG_SYS_HYPERVISOR=y
++# CONFIG_THERMAL is not set
++# CONFIG_THUNDERBOLT is not set
++# CONFIG_TIFM_CORE is not set
++# CONFIG_TRACE_SINK is not set
++# CONFIG_TTY_PRINTK is not set
++# CONFIG_UFS_FS is not set
++# CONFIG_UIO is not set
++# CONFIG_ULTRIX_PARTITION is not set
++# CONFIG_UNIXWARE_DISKLABEL is not set
++CONFIG_UPROBES=y
++# CONFIG_USB_SUPPORT is not set
++# CONFIG_UWB is not set
++CONFIG_VFIO=m
++CONFIG_VFIO_IOMMU_TYPE1=m
++CONFIG_VFIO_PCI=m
++CONFIG_VFIO_VIRQFD=m
++# CONFIG_VGASTATE is not set
++# CONFIG_VIRTIO_MMIO is not set
++CONFIG_VIRT_CPU_ACCOUNTING_NATIVE=y
++# CONFIG_VME_BUS is not set
++# CONFIG_VMXNET3 is not set
++# CONFIG_VXFS_FS is not set
++# CONFIG_W1 is not set
++# CONFIG_WAN is not set
++# CONFIG_WDTPCI is not set
++# CONFIG_WIMAX is not set
++# CONFIG_X25 is not set
++# CONFIG_XILINX_WATCHDOG is not set
++# CONFIG_XILLYBUS is not set
++# CONFIG_XZ_DEC_ARM is not set
++# CONFIG_XZ_DEC_ARMTHUMB is not set
++# CONFIG_XZ_DEC_BCJ is not set
++# CONFIG_XZ_DEC_IA64 is not set
++# CONFIG_XZ_DEC_POWERPC is not set
++# CONFIG_XZ_DEC_SPARC is not set
++# CONFIG_XZ_DEC_TEST is not set
++# CONFIG_XZ_DEC_X86 is not set
++CONFIG_ZLIB_DEFLATE=m
++CONFIG_ZONE_DMA_FLAG=1
+diff --git a/debian.master/config/s390x/config.flavour.generic b/debian.master/config/s390x/config.flavour.generic
+new file mode 100644
+index 0000000..bb7773a
+--- /dev/null
++++ b/debian.master/config/s390x/config.flavour.generic
+@@ -0,0 +1,3 @@
++#
++# Config options for config.flavour.generic automatically generated by splitconfig.pl
++#
+diff --git a/debian.master/config/x32/config.common.x32 b/debian.master/config/x32/config.common.x32
+new file mode 100644
+index 0000000..ad33444
+--- /dev/null
++++ b/debian.master/config/x32/config.common.x32
+@@ -0,0 +1 @@
++# nothing here yet
+diff --git a/debian.master/config/x32/config.flavour.generic b/debian.master/config/x32/config.flavour.generic
+new file mode 100644
+index 0000000..ad33444
+--- /dev/null
++++ b/debian.master/config/x32/config.flavour.generic
+@@ -0,0 +1 @@
++# nothing here yet
+diff --git a/debian.master/control.d/flavour-control.stub b/debian.master/control.d/flavour-control.stub
+new file mode 100644
+index 0000000..5b7315a
+--- /dev/null
++++ b/debian.master/control.d/flavour-control.stub
+@@ -0,0 +1,134 @@
++# Items that get replaced:
++# FLAVOUR
++# DESC
++# ARCH
++# SUPPORTED
++# TARGET
++# BOOTLOADER
++# =PROVIDES=
++#
++# Items marked with =FOO= are optional
++#
++# This file describes the template for packages that are created for each flavour
++# in debian/control.d/vars.*
++#
++# This file gets edited in a couple of places. See the debian/control.stub rule in
++# debian/rules. PGGVER, ABINUM, and SRCPKGNAME are all converted in the
++# process of creating debian/control.
++#
++# The flavour specific strings (ARCH, DESC, etc) are converted using values from the various
++# flavour files in debian/control.d/vars.*
++#
++# XXX: Leave the blank line before the first package!!
++
++Package: linux-image-PKGVER-ABINUM-FLAVOUR
++Build-Profiles: <!stage1>
++Architecture: ARCH
++Section: kernel
++Priority: optional
++Provides: linux-image, fuse-module, =PROVIDES=${linux:rprovides}
++Depends: ${misc:Depends}, ${shlibs:Depends}, kmod
++Recommends: BOOTLOADER, initramfs-tools | linux-initramfs-tool
++Suggests: fdutils, SRCPKGNAME-doc-PKGVER | SRCPKGNAME-source-PKGVER, SRCPKGNAME-tools, linux-headers-PKGVER-ABINUM-FLAVOUR
++Description: Linux kernel image for version PKGVER on DESC
++ This package contains the Linux kernel image for version PKGVER on
++ DESC.
++ .
++ Also includes the corresponding System.map file, the modules built by the
++ packager, and scripts that try to ensure that the system is not left in an
++ unbootable state after an update.
++ .
++ Supports SUPPORTED processors.
++ .
++ TARGET
++ .
++ You likely do not want to install this package directly. Instead, install
++ the linux-FLAVOUR meta-package, which will ensure that upgrades work
++ correctly, and that supporting packages are also installed.
++
++Package: linux-image-extra-PKGVER-ABINUM-FLAVOUR
++Build-Profiles: <!stage1>
++Architecture: ARCH
++Section: kernel
++Priority: optional
++Depends: ${misc:Depends}, ${shlibs:Depends}, linux-image-PKGVER-ABINUM-FLAVOUR, crda | wireless-crda
++Description: Linux kernel extra modules for version PKGVER on DESC
++ This package contains the Linux kernel extra modules for version PKGVER on
++ DESC.
++ .
++ Also includes the corresponding System.map file, the modules built by the
++ packager, and scripts that try to ensure that the system is not left in an
++ unbootable state after an update.
++ .
++ Supports SUPPORTED processors.
++ .
++ TARGET
++ .
++ You likely do not want to install this package directly. Instead, install
++ the linux-FLAVOUR meta-package, which will ensure that upgrades work
++ correctly, and that supporting packages are also installed.
++
++Package: linux-headers-PKGVER-ABINUM-FLAVOUR
++Build-Profiles: <!stage1>
++Architecture: ARCH
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}, linux-headers-PKGVER-ABINUM, ${shlibs:Depends}
++Provides: linux-headers, linux-headers-3.0
++Description: Linux kernel headers for version PKGVER on DESC
++ This package provides kernel header files for version PKGVER on
++ DESC.
++ .
++ This is for sites that want the latest kernel headers.  Please read
++ /usr/share/doc/linux-headers-PKGVER-ABINUM/debian.README.gz for details.
++
++Package: linux-image-PKGVER-ABINUM-FLAVOUR-dbgsym
++Build-Profiles: <!stage1>
++Architecture: ARCH
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}
++Provides: linux-debug
++Description: Linux kernel debug image for version PKGVER on DESC
++ This package provides a kernel debug image for version PKGVER on
++ DESC.
++ .
++ This is for sites that wish to debug the kernel.
++ .
++ The kernel image contained in this package is NOT meant to boot from. It
++ is uncompressed, and unstripped. This package also includes the
++ unstripped modules.
++
++Package: linux-tools-PKGVER-ABINUM-FLAVOUR
++Build-Profiles: <!stage1>
++Architecture: ARCH
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}, SRCPKGNAME-tools-PKGVER-ABINUM
++Description: Linux kernel version specific tools for version PKGVER-ABINUM
++ This package provides the architecture dependant parts for kernel
++ version locked tools (such as perf and x86_energy_perf_policy) for
++ version PKGVER-ABINUM on
++ =HUMAN=.
++
++Package: linux-cloud-tools-PKGVER-ABINUM-FLAVOUR
++Build-Profiles: <!stage1>
++Architecture: ARCH
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}, SRCPKGNAME-cloud-tools-PKGVER-ABINUM
++Description: Linux kernel version specific cloud tools for version PKGVER-ABINUM
++ This package provides the architecture dependant parts for kernel
++ version locked tools for cloud for version PKGVER-ABINUM on
++ =HUMAN=.
++
++Package: linux-udebs-FLAVOUR
++Build-Profiles: <!stage1>
++XC-Package-Type: udeb
++Section: debian-installer
++Architecture: ARCH
++Depends: ${udeb:Depends}
++Description: Metapackage depending on kernel udebs
++ This package depends on the all udebs that the kernel build generated,
++ for easier version and migration tracking.
++
+diff --git a/debian.master/control.d/generic.inclusion-list b/debian.master/control.d/generic.inclusion-list
+new file mode 100644
+index 0000000..0c895ad
+--- /dev/null
++++ b/debian.master/control.d/generic.inclusion-list
+@@ -0,0 +1,237 @@
++arch/*/{crypto,kernel,oprofile}
++arch/*/kvm/kvm.ko
++arch/powerpc/kvm/kvm-hv.ko
++arch/powerpc/kvm/kvm-pr.ko
++arch/powerpc/platforms/powernv/opal-prd.ko
++arch/powerpc/kvm/vfio.ko
++arch/s390/*
++arch/x86/kvm/kvm-intel.ko
++arch/x86/kvm/kvm-amd.ko
++crypto/*
++drivers/acpi/*
++drivers/char/ipmi/ipmi_msghandler.ko
++drivers/ata/ahci_platform.ko
++drivers/ata/ahci.ko
++drivers/ata/acard-ahci.ko
++drivers/ata/libahci.ko
++drivers/ata/libahci_platform.ko
++drivers/block/brd.ko
++drivers/block/nbd.ko
++drivers/block/floppy.ko
++drivers/block/cryptoloop.ko
++drivers/block/rbd.ko
++drivers/char/hangcheck-timer.ko
++drivers/char/hw_random/virtio-rng.ko
++drivers/char/lp.ko
++drivers/char/nvram.ko
++drivers/char/hw_random/powernv-rng.ko
++drivers/char/ipmi/*
++drivers/char/ppdev.ko
++drivers/char/raw.ko
++drivers/crypto/nx/*
++drivers/crypto/vmx/vmx-crypto.ko
++drivers/firmware/iscsi_ibft.ko
++drivers/gpu/drm/ast/ast.ko
++drivers/gpu/drm/drm_kms_helper.ko
++drivers/gpu/drm/ttm/ttm.ko
++drivers/hid/hid.ko
++drivers/hid/hid-generic.ko
++drivers/hid/hid-hyperv.ko
++drivers/hid/usbhid/usbhid.ko
++drivers/hv/*
++drivers/hwmon/ibmpowernv.ko
++drivers/infiniband/core/ib_core.ko
++drivers/infiniband/core/ib_addr.ko
++drivers/infiniband/core/ib_cm.ko
++drivers/infiniband/core/ib_mad.ko
++drivers/infiniband/core/ib_sa.ko
++drivers/infiniband/core/iw_cm.ko
++drivers/infiniband/core/rdma_cm.ko
++drivers/infiniband/ulp/iser/ib_iser.ko
++drivers/infiniband/ulp/isert/ib_isert.ko
++drivers/input/evbug.ko
++drivers/input/gameport/gameport.ko
++drivers/input/input-leds.ko
++drivers/input/mouse/psmouse.ko
++drivers/input/serio/hyperv-keyboard.ko
++drivers/input/serio/serio_raw.ko
++drivers/input/serio/serport.ko
++drivers/input/joydev.ko
++drivers/input/touchscreen/usbtouchscreen.ko
++drivers/input/misc/xen-kbdfront.ko
++drivers/leds/leds-powernv.ko
++drivers/md/*
++drivers/message/fusion*
++drivers/misc/eeprom/at24.ko
++drivers/mtd/cmdlinepart.ko
++drivers/mtd/ofpart.ko
++drivers/mtd/devices/powernv_flash.ko
++drivers/nvme/host/nvme.ko
++drivers/nvmem/nvmem_core.ko
++drivers/s390/*
++drivers/scsi/scsi_transport_spi.ko
++drivers/misc/cxl/*
++drivers/misc/vmw_balloon.ko
++drivers/misc/vmw_vmci/vmw_vmci.ko
++drivers/net/caif/caif_virtio.ko
++drivers/net/mii.ko
++drivers/net/ethernet/8390/8390.ko
++drivers/net/ethernet/broadcom/bnx2x/*
++drivers/net/ethernet/emulex/benet/*
++drivers/net/ethernet/intel/i40e/*
++drivers/net/ethernet/intel/igb/*
++drivers/net/ethernet/intel/ixgbe/*
++drivers/net/ethernet/realtek/8139too.ko
++drivers/net/ethernet/realtek/8139cp.ko
++drivers/net/appletalk/ipddp.ko
++drivers/net/bonding/bonding.ko
++drivers/net/ppp/bsd_comp.ko
++drivers/net/dummy.ko
++drivers/net/ethernet/intel/e1000/e1000.ko
++drivers/net/ethernet/intel/e1000e/e1000e.ko
++drivers/net/eql.ko
++drivers/net/ethernet/ibm/*
++drivers/net/ifb.ko
++drivers/net/ethernet/intel/igbvf/igbvf.ko
++drivers/net/ethernet/intel/ixgbevf/ixgbevf.ko
++drivers/net/ethernet/amazon/ena/ena.ko
++drivers/net/geneve.ko
++drivers/net/macvlan.ko
++drivers/net/macvtap.ko
++drivers/net/ethernet/8390/ne2k-pci.ko
++drivers/net/netconsole.ko
++drivers/net/ethernet/amd/pcnet32.ko
++drivers/net/hyperv/hv_netvsc.ko
++drivers/net/ppp/*
++drivers/net/slip/*
++drivers/net/veth.ko
++drivers/net/vmxnet3/vmxnet3.ko
++drivers/net/vxlan.ko
++drivers/net/xen-netback/*
++drivers/net/ipvlan/*
++drivers/platform/x86/pvpanic.ko
++drivers/parport/parport.ko
++drivers/parport/parport_pc.ko
++drivers/pps/pps_core.ko
++drivers/ptp/ptp.ko
++drivers/net/ethernet/dec/tulip/*
++drivers/net/ethernet/mellanox/*
++drivers/scsi/aacraid/*
++drivers/scsi/BusLogic.ko
++drivers/scsi/cxlflash/*
++drivers/scsi/device_handler/scsi_dh_emc.ko
++drivers/scsi/device_handler/scsi_dh_alua.ko
++drivers/scsi/device_handler/scsi_dh_rdac.ko
++drivers/scsi/device_handler/scsi_dh_hp_sw.ko
++drivers/scsi/iscsi_boot_sysfs.ko
++drivers/scsi/iscsi_tcp.ko
++drivers/scsi/ipr.ko
++drivers/scsi/libiscsi.ko
++drivers/scsi/libiscsi_tcp.ko
++drivers/scsi/libsas/*
++drivers/scsi/lpfc/*
++drivers/scsi/megaraid/*
++drivers/scsi/mpt3sas/*
++drivers/scsi/osd/osd.ko
++drivers/scsi/osd/libosd.ko
++drivers/scsi/qla2xxx/*
++drivers/scsi/qla1280.ko
++drivers/scsi/raid_class.ko
++drivers/scsi/scsi_transport_fc.ko
++drivers/scsi/scsi_transport_iscsi.ko
++drivers/scsi/scsi_transport_sas.ko
++drivers/scsi/vmw_pvscsi.ko
++drivers/scsi/hv_storvsc.ko
++drivers/scsi/virtio_scsi.ko
++drivers/scsi/ibmvscsi/*
++drivers/target/target_core*.ko
++drivers/tty/serial/jsm/*
++drivers/uio/uio.ko
++drivers/uio/uio_pdrv_genirq.ko
++drivers/usb/host/*
++drivers/usb/storage/uas.ko
++drivers/usb/storage/usb-storage.ko
++drivers/vfio/*
++drivers/vhost/*
++drivers/video/fbdev/cirrusfb.ko
++drivers/video/fbdev/core/syscopyarea.ko
++drivers/video/fbdev/core/sysfillrect.ko
++drivers/video/fbdev/core/sysimgblt.ko
++drivers/video/fbdev/hyperv_fb.ko
++drivers/video/fbdev/vga16fb.ko
++drivers/video/vgastate.ko
++drivers/video/fbdev/xen-fbfront.ko
++drivers/video/fbdev/core/fb_sys_fops.ko
++drivers/watchdog/softdog.ko
++drivers/xen/*
++fs/9p/*
++fs/aufs/aufs.ko
++fs/binfmt_misc.ko
++fs/btrfs/*
++fs/cachefiles/cachefiles.ko
++fs/ceph/*
++fs/configfs/*
++fs/dlm/dlm.ko
++fs/exofs/libore.ko
++fs/fat/*
++fs/nls/nls_iso8859-1.ko
++fs/isofs/*
++fs/cifs/*
++fs/xfs/*
++fs/ufs/*
++fs/squashfs/*
++fs/nfs/*
++fs/nfsd/*
++fs/nfs_common/*
++fs/fscache/*
++fs/lockd/*
++fs/autofs4/autofs4.ko
++fs/overlayfs/*
++fs/udf/*
++lib/*
++net/6lowpan/*
++net/802/*
++net/8021q/*
++net/9p/*
++net/appletalk/*
++net/atm/*
++net/ax25/*
++net/bridge/*
++net/can/*
++net/core/*
++net/ceph/libceph.ko
++net/dccp/*
++net/decnet/*
++net/ieee802154/*
++net/ipv4/*
++net/ipv6/*
++net/ipx/*
++net/irda/*
++net/key/*
++net/lapb/*
++net/llc/*
++net/netfilter/*
++net/netlink/netlink_diag.ko
++net/netrom/*
++net/openvswitch/*
++net/packet/af_packet_diag.ko
++net/phonet/*
++net/rose/*
++net/rxrpc/*
++net/sched/*
++net/sctp/*
++net/tipc/*
++net/unix/unix_diag.ko
++net/vmw_vsock/*
++net/x25/*
++net/xfrm/*
++net/sunrpc/auth_gss/auth_rpcgss.ko
++net/sunrpc/auth_gss/rpcsec_gss_krb5.ko
++net/sunrpc/sunrpc.ko
++sound/soundcore.ko
++! find sound/core -name oss -prune -o -name *.ko -print
++sound/pci/snd-ens1370.ko
++sound/drivers/pcsp/snd-pcsp.ko
++ubuntu/vbox/vboxguest/vboxguest.ko
++ubuntu/vbox/vboxsf/vboxsf.ko
++zfs/*
+diff --git a/debian.master/control.d/vars.generic b/debian.master/control.d/vars.generic
+new file mode 100644
+index 0000000..2cda0bf
+--- /dev/null
++++ b/debian.master/control.d/vars.generic
+@@ -0,0 +1,6 @@
++arch="i386 amd64 armhf arm64 ppc64el s390x"
++supported="Generic"
++target="Geared toward desktop and server systems."
++desc="=HUMAN= SMP"
++bootloader="grub-pc [i386 amd64 x32] | grub-efi-amd64 [amd64 x32] | grub-efi-ia32 [i386 amd64 x32] | grub [i386 amd64 x32] | lilo [i386 amd64 x32] | flash-kernel [armhf arm64] | grub-ieee1275 [ppc64el]"
++provides="kvm-api-4, redhat-cluster-modules, ivtv-modules, virtualbox-guest-modules [i386 amd64 x32]"
+diff --git a/debian.master/control.d/vars.generic-lpae b/debian.master/control.d/vars.generic-lpae
+new file mode 100644
+index 0000000..616a7a5
+--- /dev/null
++++ b/debian.master/control.d/vars.generic-lpae
+@@ -0,0 +1,6 @@
++arch="armhf"
++supported="Generic LPAE"
++target="Geared toward desktop and server systems."
++desc="=HUMAN= SMP"
++bootloader="flash-kernel [armhf]"
++provides="kvm-api-4, redhat-cluster-modules, ivtv-modules"
+diff --git a/debian.master/control.d/vars.lowlatency b/debian.master/control.d/vars.lowlatency
+new file mode 100644
+index 0000000..9849cd3
+--- /dev/null
++++ b/debian.master/control.d/vars.lowlatency
+@@ -0,0 +1,6 @@
++arch="i386 amd64"
++supported="Lowlatency"
++target="Geared toward desktop and server systems."
++desc="=HUMAN= SMP"
++bootloader="grub-pc [i386 amd64 x32] | grub-efi-amd64 [amd64 x32] | grub-efi-ia32 [i386 amd64 x32] | grub [i386 amd64 x32] | lilo [i386 amd64 x32] | flash-kernel [armhf arm64]"
++provides="kvm-api-4, redhat-cluster-modules, ivtv-modules, virtualbox-guest-modules [i386 amd64 x32]"
+diff --git a/debian.master/control.d/vars.powerpc-e500mc b/debian.master/control.d/vars.powerpc-e500mc
+new file mode 100644
+index 0000000..b66f5de
+--- /dev/null
++++ b/debian.master/control.d/vars.powerpc-e500mc
+@@ -0,0 +1,6 @@
++supported="32-bit Freescale Power e500mc"
++target="Geared toward server systems."
++desc="32-bit Freescale Power e500mc"
++bootloader="grub-ieee1275"
++provides="redhat-cluster-modules, ivtv-modules"
++arch="powerpc"
+diff --git a/debian.master/control.d/vars.powerpc-smp b/debian.master/control.d/vars.powerpc-smp
+new file mode 100644
+index 0000000..67f19e1
+--- /dev/null
++++ b/debian.master/control.d/vars.powerpc-smp
+@@ -0,0 +1,6 @@
++supported="32-bit PowerPC SMP"
++target="Geared toward desktop or server systems."
++desc="32-bit PowerPC SMP"
++bootloader="yaboot"
++provides="redhat-cluster-modules, ivtv-modules"
++arch="powerpc"
+diff --git a/debian.master/control.d/vars.powerpc64-emb b/debian.master/control.d/vars.powerpc64-emb
+new file mode 100644
+index 0000000..c765cec
+--- /dev/null
++++ b/debian.master/control.d/vars.powerpc64-emb
+@@ -0,0 +1,6 @@
++supported="64-bit PowerPC SMP Book3E"
++target="Geared toward desktop or server systems."
++desc="64-bit PowerPC SMP Book3E"
++bootloader="grub-ieee1275"
++provides="redhat-cluster-modules, ivtv-modules"
++arch="powerpc"
+diff --git a/debian.master/control.d/vars.powerpc64-smp b/debian.master/control.d/vars.powerpc64-smp
+new file mode 100644
+index 0000000..8afa100
+--- /dev/null
++++ b/debian.master/control.d/vars.powerpc64-smp
+@@ -0,0 +1,6 @@
++supported="64-bit PowerPC SMP"
++target="Geared toward desktop or server systems."
++desc="64-bit PowerPC SMP"
++bootloader="yaboot"
++provides="redhat-cluster-modules, ivtv-modules"
++arch="powerpc"
+diff --git a/debian.master/control.stub.in b/debian.master/control.stub.in
+new file mode 100644
+index 0000000..3ccdba3
+--- /dev/null
++++ b/debian.master/control.stub.in
+@@ -0,0 +1,179 @@
++Source: linux
++Section: devel
++Priority: optional
++Maintainer: Ubuntu Kernel Team <kernel-team@lists.ubuntu.com>
++Standards-Version: 3.9.4.0
++Build-Depends:
++ debhelper (>= 5),
++ dh-systemd,
++ cpio,
++ kernel-wedge,
++ kmod <!stage1>,
++ makedumpfile [amd64 i386] <!stage1>,
++ libelf-dev <!stage1>,
++ libnewt-dev <!stage1>,
++ libiberty-dev <!stage1>,
++ rsync <!stage1>,
++ libdw-dev <!stage1>,
++ libpci-dev <!stage1>,
++ pkg-config <!stage1>,
++ flex <!stage1>,
++ bison <!stage1>,
++ libunwind8-dev [amd64 arm64 armhf i386 powerpc ppc64el] <!stage1>,
++ binutils-dev <!stage1>,
++ liblzma-dev <!stage1>,
++ openssl <!stage1>,
++ libssl-dev <!stage1>,
++ libaudit-dev <!stage1>,
++ bc <!stage1>,
++ python-dev <!stage1>,
++ gawk <!stage1>,
++ device-tree-compiler [powerpc] <!stage1>,
++ u-boot-tools [powerpc] <!stage1>,
++ libc6-dev-ppc64 [powerpc] <!stage1>,
++ libudev-dev <!stage1>,
++ autoconf <!stage1>,
++ automake <!stage1>,
++ libtool <!stage1>,
++ uuid-dev <!stage1>,
++Build-Depends-Indep:
++ xmlto <!stage1>,
++ docbook-utils <!stage1>,
++ ghostscript <!stage1>,
++ transfig <!stage1>,
++ bzip2 <!stage1>,
++ sharutils <!stage1>,
++ asciidoc <!stage1>,
++Vcs-Git: git://git.launchpad.net/~ubuntu-kernel/ubuntu/+source/linux/+git/xenial
++XS-Testsuite: autopkgtest
++#XS-Testsuite-Depends: gcc-4.7 binutils
++
++Package: SRCPKGNAME-source-PKGVER
++Build-Profiles: <!stage1>
++Architecture: all
++Section: devel
++Priority: optional
++Provides: SRCPKGNAME-source, SRCPKGNAME-source-3
++Depends: ${misc:Depends}, binutils, bzip2, coreutils
++Recommends: libc-dev, gcc, make
++Suggests: libncurses-dev | ncurses-dev, kernel-package, libqt3-dev
++Description: Linux kernel source for version PKGVER with Ubuntu patches
++ This package provides the source code for the Linux kernel version
++ PKGVER.
++ .
++ This package is mainly meant for other packages to use, in order to build
++ custom flavours.
++ .
++ If you wish to use this package to create a custom Linux kernel, then it
++ is suggested that you investigate the package kernel-package, which has
++ been designed to ease the task of creating kernel image packages.
++ .
++ If you are simply trying to build third-party modules for your kernel,
++ you do not want this package. Install the appropriate linux-headers
++ package instead.
++
++Package: SRCPKGNAME-doc
++Build-Profiles: <!stage1>
++Architecture: all
++Section: doc
++Priority: optional
++Depends: ${misc:Depends}
++Description: Linux kernel specific documentation for version PKGVER
++ This package provides the various documents in the PKGVER kernel
++ Documentation/ subdirectory.  These document kernel subsystems, APIs, device
++ drivers, and so on.  See
++ /usr/share/doc/SRCPKGNAME-doc/00-INDEX for a list of what is
++ contained in each file.
++
++Package: SRCPKGNAME-headers-PKGVER-ABINUM
++Build-Profiles: <!stage1>
++Architecture: all
++Multi-Arch: foreign
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}, coreutils
++Breaks: iscsitarget-dkms (<< 1.4.20.3+svn502-2ubuntu4.3)
++Description: Header files related to Linux kernel version PKGVER
++ This package provides kernel header files for version PKGVER, for sites
++ that want the latest kernel headers. Please read
++ /usr/share/doc/SRCPKGNAME-headers-PKGVER-ABINUM/debian.README.gz for details
++
++Package: SRCPKGNAME-libc-dev
++Architecture: i386 amd64 armhf arm64 x32 powerpc ppc64el s390x
++Depends: ${misc:Depends}
++Conflicts: SRCPKGNAME-kernel-headers
++Replaces: SRCPKGNAME-kernel-headers
++Provides: SRCPKGNAME-kernel-headers
++Multi-Arch: same
++Description: Linux Kernel Headers for development
++ This package provides headers from the Linux kernel.  These headers
++ are used by the installed headers for GNU glibc and other system
++ libraries. They are NOT meant to be used to build third-party modules for
++ your kernel. Use SRCPKGNAME-headers-* packages for that.
++
++Package: SRCPKGNAME-tools-common
++Build-Profiles: <!stage1>
++Architecture: all
++Multi-Arch: foreign
++Section: kernel
++Priority: optional
++Provides:
++ linux-aws-tools-common,
++ linux-gke-tools-common,
++Conflicts:
++ linux-aws-tools-common,
++ linux-gke-tools-common,
++Replaces:
++ linux-aws-tools-common,
++ linux-gke-tools-common,
++Depends: ${misc:Depends}, lsb-release
++Description: Linux kernel version specific tools for version PKGVER
++ This package provides the architecture independent parts for kernel
++ version locked tools (such as perf and x86_energy_perf_policy) for
++ version PGKVER.
++
++Package: SRCPKGNAME-tools-PKGVER-ABINUM
++Build-Profiles: <!stage1>
++Architecture: i386 amd64 armhf arm64 powerpc ppc64el s390x
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}, ${shlibs:Depends}, SRCPKGNAME-tools-common
++Description: Linux kernel version specific tools for version PKGVER-ABINUM
++ This package provides the architecture dependant parts for kernel
++ version locked tools (such as perf and x86_energy_perf_policy) for
++ version PKGVER-ABINUM on
++ =HUMAN=.
++ You probably want to install linux-tools-PKGVER-ABINUM-<flavour>.
++
++Package: SRCPKGNAME-cloud-tools-common
++Build-Profiles: <!stage1>
++Architecture: all
++Multi-Arch: foreign
++Section: kernel
++Priority: optional
++Provides:
++ linux-aws-cloud-tools-common,
++ linux-gke-cloud-tools-common,
++Conflicts:
++ linux-aws-cloud-tools-common,
++ linux-gke-cloud-tools-common,
++Replaces:
++ linux-aws-cloud-tools-common,
++ linux-gke-cloud-tools-common,
++Depends: ${misc:Depends}
++Description: Linux kernel version specific cloud tools for version PKGVER
++ This package provides the architecture independent parts for kernel
++ version locked tools for cloud tools for version PGKVER.
++
++Package: SRCPKGNAME-cloud-tools-PKGVER-ABINUM
++Build-Profiles: <!stage1>
++Architecture: i386 amd64 armhf
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}, ${shlibs:Depends}, SRCPKGNAME-cloud-tools-common
++Description: Linux kernel version specific cloud tools for version PKGVER-ABINUM
++ This package provides the architecture dependant parts for kernel
++ version locked tools for cloud tools for version PKGVER-ABINUM on
++ =HUMAN=.
++ You probably want to install linux-cloud-tools-PKGVER-ABINUM-<flavour>.
++
+diff --git a/debian.master/copyright b/debian.master/copyright
+new file mode 100644
+index 0000000..b24bd66
+--- /dev/null
++++ b/debian.master/copyright
+@@ -0,0 +1,60 @@
++This is the Ubuntu prepackaged version of the Linux kernel.
++Linux was written by Linus Torvalds <Linus.Torvalds@cs.Helsinki.FI>
++and others.
++
++This package was put together by the Ubuntu Kernel Team, from
++sources retrieved from upstream linux git.
++The sources may be found at most Linux ftp sites, including 
++ftp://ftp.kernel.org/pub/linux/kernel/
++
++This package is currently maintained by the
++Ubuntu Kernel Team <ubuntu-kernel@lists.ubuntu.com>
++
++Linux is copyrighted by Linus Torvalds and others.
++
++   This program is free software; you can redistribute it and/or modify
++   it under the terms of the GNU General Public License as published by
++   the Free Software Foundation; version 2 dated June, 1991.
++
++   This program is distributed in the hope that it will be useful,
++   but WITHOUT ANY WARRANTY; without even the implied warranty of
++   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
++   GNU General Public License for more details.
++
++   You should have received a copy of the GNU General Public License
++   along with this program; if not, write to the Free Software
++   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
++
++On Ubuntu Linux systems, the complete text of the GNU General
++Public License v2 can be found in `/usr/share/common-licenses/GPL-2'.
++
++Files: ubuntu/rsi/*
++Copyright (c) 2017 Redpine Signals Inc. All rights reserved.
++License: redpine-signals
++   Copyright (c) 2017 Redpine Signals Inc. All rights reserved.
++   
++   Redistribution and use in source and binary forms, with or without
++   modification, are permitted provided that the following conditions are met:
++   
++   1. Redistributions of source code must retain the above copyright
++      notice, this list of conditions and the following disclaimer.
++   
++   2. Redistributions in binary form must reproduce the above copyright
++      notice, this list of conditions and the following disclaimer in the
++      documentation and/or other materials provided with the distribution.
++   
++   3. Neither the name of the copyright holder nor the names of its
++      contributors may be used to endorse or promote products derived from
++      this software without specific prior written permission.
++   
++   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
++   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
++   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
++   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
++   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
++   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
++   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
++   INTERRUPTION). HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
++   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
++   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
++   POSSIBILITY OF SUCH DAMAGE.
+diff --git a/debian.master/d-i/exclude-firmware.armhf-generic b/debian.master/d-i/exclude-firmware.armhf-generic
+new file mode 100644
+index 0000000..ddb5eb8
+--- /dev/null
++++ b/debian.master/d-i/exclude-firmware.armhf-generic
+@@ -0,0 +1,2 @@
++nic-modules
++scsi-modules
+diff --git a/debian.master/d-i/exclude-firmware.armhf-generic-lpae b/debian.master/d-i/exclude-firmware.armhf-generic-lpae
+new file mode 100644
+index 0000000..ddb5eb8
+--- /dev/null
++++ b/debian.master/d-i/exclude-firmware.armhf-generic-lpae
+@@ -0,0 +1,2 @@
++nic-modules
++scsi-modules
+diff --git a/debian.master/d-i/exclude-modules.amd64-virtual b/debian.master/d-i/exclude-modules.amd64-virtual
+new file mode 100644
+index 0000000..59379cc
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.amd64-virtual
+@@ -0,0 +1,14 @@
++pata-modules
++firewire-core-modules
++plip-modules
++usb-modules
++pcmcia-storage-modules
++input-modules
++nic-pcmcia-modules
++pcmcia-modules
++nic-usb-modules
++nfs-modules
++speakup-modules
++ppp-modules
++sata-modules
++ipmi-modules
+diff --git a/debian.master/d-i/exclude-modules.arm64-generic b/debian.master/d-i/exclude-modules.arm64-generic
+new file mode 100644
+index 0000000..fe11eea
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.arm64-generic
+@@ -0,0 +1,9 @@
++serial-modules
++pata-modules
++firewire-core-modules
++floppy-modules
++pcmcia-storage-modules
++fb-modules
++nic-pcmcia-modules
++pcmcia-modules
++message-modules
+diff --git a/debian.master/d-i/exclude-modules.armhf-generic b/debian.master/d-i/exclude-modules.armhf-generic
+new file mode 100644
+index 0000000..39ab95b
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.armhf-generic
+@@ -0,0 +1,10 @@
++serial-modules
++firewire-core-modules
++floppy-modules
++pcmcia-storage-modules
++fb-modules
++nic-pcmcia-modules
++pcmcia-modules
++pata-modules
++message-modules
++virtio-modules
+diff --git a/debian.master/d-i/exclude-modules.armhf-generic-lpae b/debian.master/d-i/exclude-modules.armhf-generic-lpae
+new file mode 100644
+index 0000000..39ab95b
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.armhf-generic-lpae
+@@ -0,0 +1,10 @@
++serial-modules
++firewire-core-modules
++floppy-modules
++pcmcia-storage-modules
++fb-modules
++nic-pcmcia-modules
++pcmcia-modules
++pata-modules
++message-modules
++virtio-modules
+diff --git a/debian.master/d-i/exclude-modules.i386-virtual b/debian.master/d-i/exclude-modules.i386-virtual
+new file mode 100644
+index 0000000..59379cc
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.i386-virtual
+@@ -0,0 +1,14 @@
++pata-modules
++firewire-core-modules
++plip-modules
++usb-modules
++pcmcia-storage-modules
++input-modules
++nic-pcmcia-modules
++pcmcia-modules
++nic-usb-modules
++nfs-modules
++speakup-modules
++ppp-modules
++sata-modules
++ipmi-modules
+diff --git a/debian.master/d-i/exclude-modules.powerpc b/debian.master/d-i/exclude-modules.powerpc
+new file mode 100644
+index 0000000..ee75c96
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.powerpc
+@@ -0,0 +1,7 @@
++efi-modules
++fb-modules
++acpi-modules
++serial-modules
++nic-pcmcia-modules
++pcmcia-modules
++pcmcia-storage-modules
+diff --git a/debian.master/d-i/exclude-modules.ppc64el-generic b/debian.master/d-i/exclude-modules.ppc64el-generic
+new file mode 100644
+index 0000000..fba6f95
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.ppc64el-generic
+@@ -0,0 +1,11 @@
++serial-modules
++pata-modules
++fat-modules
++pcmcia-storage-modules
++nic-pcmcia-modules
++pcmcia-modules
++firewire-core-modules
++usb-modules
++mouse-modules
++irda-modules
++speakup-modules
+diff --git a/debian.master/d-i/exclude-modules.s390x b/debian.master/d-i/exclude-modules.s390x
+new file mode 100644
+index 0000000..a06a769
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.s390x
+@@ -0,0 +1,20 @@
++serial-modules
++ppp-modules
++pata-modules
++plip-modules
++floppy-modules
++pcmcia-storage-modules
++fb-modules
++mouse-modules
++irda-modules
++nic-pcmcia-modules
++pcmcia-modules
++sata-modules
++speakup-modules
++ipmi-modules
++usb-modules
++input-modules
++parport-modules
++nic-usb-modules
++firewire-core-modules
++message-modules
+diff --git a/debian.master/d-i/firmware/README.txt b/debian.master/d-i/firmware/README.txt
+new file mode 100644
+index 0000000..27a8600
+--- /dev/null
++++ b/debian.master/d-i/firmware/README.txt
+@@ -0,0 +1,4 @@
++#
++# Place the names of udeb modules into this directory that require
++# runtime firmware.
++#
+diff --git a/debian.master/d-i/firmware/nic-modules b/debian.master/d-i/firmware/nic-modules
+new file mode 100644
+index 0000000..f112ed2
+--- /dev/null
++++ b/debian.master/d-i/firmware/nic-modules
+@@ -0,0 +1,14 @@
++e100/d101m_ucode.bin ?
++e100/d101s_ucode.bin ?
++e100/d102e_ucode.bin ?
++bnx2/bnx2-mips-09-6.2.1b.fw ?
++bnx2/bnx2-rv2p-06-6.0.15.fw ?
++bnx2/bnx2-mips-06-6.2.3.fw ?
++bnx2/bnx2-rv2p-09-6.0.17.fw ?
++bnx2/bnx2-rv2p-09ax-6.0.17.fw ?
++bnx2x/bnx2x-e1h-7.12.30.0.fw ?
++bnx2x/bnx2x-e1-7.12.30.0.fw ?
++bnx2x/bnx2x-e2-7.12.30.0.fw ?
++tigon/tg3_tso5.bin ?
++tigon/tg3_tso.bin ?
++tigon/tg3.bin ?
+diff --git a/debian.master/d-i/firmware/scsi-modules b/debian.master/d-i/firmware/scsi-modules
+new file mode 100644
+index 0000000..56bf990
+--- /dev/null
++++ b/debian.master/d-i/firmware/scsi-modules
+@@ -0,0 +1,3 @@
++qlogic/1040.bin ?
++qlogic/12160.bin ?
++qlogic/1280.bin ?
+diff --git a/debian.master/d-i/kernel-versions.in b/debian.master/d-i/kernel-versions.in
+new file mode 100644
+index 0000000..d463c10
+--- /dev/null
++++ b/debian.master/d-i/kernel-versions.in
+@@ -0,0 +1,19 @@
++# arch	version		flavour		installedname			suffix	bdep
++amd64	PKGVER-ABINUM	generic		PKGVER-ABINUM-generic		-	-
++
++i386	PKGVER-ABINUM	generic		PKGVER-ABINUM-generic		-	-
++
++armhf	PKGVER-ABINUM	generic		PKGVER-ABINUM-generic		-	-
++armhf	PKGVER-ABINUM	generic-lpae	PKGVER-ABINUM-generic-lpae	-	-
++
++arm64	PKGVER-ABINUM	generic		PKGVER-ABINUM-generic		-	-
++
++ppc64el	PKGVER-ABINUM	generic		PKGVER-ABINUM-generic		-	-
++
++s390x	PKGVER-ABINUM	generic		PKGVER-ABINUM-generic		-	-
++
++# Ports
++# arch	version		flavour		installedname			suffix	bdep
++powerpc	PKGVER-ABINUM	powerpc-smp	PKGVER-ABINUM-powerpc-smp	-	-
++powerpc	PKGVER-ABINUM	powerpc64-smp	PKGVER-ABINUM-powerpc64-smp	-	-
++powerpc PKGVER-ABINUM	powerpc-e500mc	PKGVER-ABINUM-powerpc-e500mc	-	-
+diff --git a/debian.master/d-i/modules-powerpc/block-modules b/debian.master/d-i/modules-powerpc/block-modules
+new file mode 100644
+index 0000000..cd95917
+--- /dev/null
++++ b/debian.master/d-i/modules-powerpc/block-modules
+@@ -0,0 +1,31 @@
++aoe
++aten
++bpck
++bpck6 ?
++cciss
++comm
++cpqarray ?
++DAC960
++dstr
++epat
++epia
++fit2
++fit3
++friq
++frpw
++kbic
++ktti
++nbd
++on20
++on26
++paride
++pcd
++pd
++pf
++pg
++ps3disk ?
++ps3vram ?
++pt
++sx8
++umem
++virtio_blk ?
+diff --git a/debian.master/d-i/modules-powerpc/message-modules b/debian.master/d-i/modules-powerpc/message-modules
+new file mode 100644
+index 0000000..b9308e2
+--- /dev/null
++++ b/debian.master/d-i/modules-powerpc/message-modules
+@@ -0,0 +1,7 @@
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
+diff --git a/debian.master/d-i/modules-powerpc/nic-modules b/debian.master/d-i/modules-powerpc/nic-modules
+new file mode 100644
+index 0000000..05c63ea
+--- /dev/null
++++ b/debian.master/d-i/modules-powerpc/nic-modules
+@@ -0,0 +1,152 @@
++3c359 ?
++3c501 ?
++3c503 ?
++3c505 ?
++3c507 ?
++3c509 ?
++3c515 ?
++3c523 ?
++3c527 ?
++3c59x ?
++8139cp ?
++8139too ?
++82596 ?
++abyss ?
++ac3200 ?
++adm8211 ?
++airo ?
++airport ?
++amd8111e ?
++arc4 ?
++arcnet ?
++arc-rawmode ?
++arc-rimi ?
++arlan ?
++at1700 ?
++atl1 ?
++atl1e ?
++atl2 ?
++atmel ?
++atmel_pci ?
++b44 ?
++bcm43xx ?
++bcm43xx-mac80211 ?
++bmac ?
++bnx2 ?
++bnx2x ?
++bonding ?
++cassini ?
++com20020 ?
++com20020-pci ?
++com90io ?
++com90xx ?
++cs89x0 ?
++de2104x ?
++de4x5 ?
++de600 ?
++de620 ?
++defxx ?
++depca ?
++dl2k ?
++dmfe ?
++dummy ?
++e100 ?
++e1000 ?
++e1000e ?
++e2100 ?
++eepro ?
++eepro100 ?
++eexpress ?
++epic100 ?
++eql ?
++es3210 ?
++eth16i ?
++ewrk3 ?
++fealnx ?
++forcedeth ?
++igb ?
++hamachi ?
++hermes ?
++hp ?
++hp100 ?
++hp-plus ?
++ibmtr ?
++ibmveth ?
++ipddp ?
++ipw2100 ?
++ipw2200 ?
++ipw3945 ?
++ixgb ?
++lance ?
++lanstreamer ?
++lasi_82596 ?
++lne390 ?
++lp486e ?
++mace ?
++mv643xx_eth ?
++myri_sbus ?
++natsemi ?
++ne ?
++ne2 ?
++ne2k-pci ?
++ne3210 ?
++netconsole ?
++netxen_nic ?
++ni5010 ?
++ni52 ?
++ni65 ?
++niu ?
++ns83820 ?
++olympic ?
++orinoco ?
++orinoco_pci ?
++orinoco_plx ?
++orinoco_tmd ?
++pcnet32 ?
++ps3_gelic ?
++r8169 ?
++rate_control ?
++rfc1051 ?
++rfc1201 ?
++rrunner ?
++rt2400 ?
++rt2500 ?
++rt61pci ?
++s2io ?
++shaper ?
++sis190 ?
++sis900 ?
++spidernet ?
++skfp ?
++skge ?
++sk98lin ?
++sky2 ?
++smc9194 ?
++smc-ultra ?
++smc-ultra32 ?
++starfire ?
++strip ?
++sunbmac ?
++sundance ?
++sungem ?
++sungem_phy ?
++sunhme ?
++sunlance ?
++sunqe ?
++sunvnet ?
++tg3 ?
++tlan ?
++tms380tr ?
++tmspci ?
++tulip ?
++tun ?
++typhoon ?
++uli526x ?
++via-rhine ?
++via-velocity ?
++virtio_net ?
++wavelan ?
++wd ?
++winbond-840 ?
++yellowfin ?
++znet ?
+diff --git a/debian.master/d-i/modules-powerpc/scsi-modules b/debian.master/d-i/modules-powerpc/scsi-modules
+new file mode 100644
+index 0000000..2e77f63
+--- /dev/null
++++ b/debian.master/d-i/modules-powerpc/scsi-modules
+@@ -0,0 +1,118 @@
++# SCSI
++raid_class ?
++scsi_transport_spi ?
++scsi_transport_fc ?
++scsi_transport_iscsi ?
++scsi_transport_sas ?
++iscsi_tcp ?
++libiscsi ?
++amiga7xx ?
++a3000 ?
++a2091 ?
++gvp11 ?
++mvme147 ?
++sgiwd93 ?
++cyberstorm ?
++cyberstormII ?
++blz2060 ?
++blz1230 ?
++fastlane ?
++oktagon_esp_mod ?
++atari_scsi ?
++mac_scsi ?
++mac_esp ?
++sun3_scsi ?
++mvme16x ?
++bvme6000 ?
++sim710 ?
++advansys ?
++psi240i ?
++BusLogic ?
++dpt_i2o ?
++u14-34f ?
++ultrastor ?
++aha152x ?
++aha1542 ?
++aha1740 ?
++aic7xxx_old ?
++ips ?
++fd_mcs ?
++fdomain ?
++in2000 ?
++g_NCR5380 ?
++g_NCR5380_mmio ?
++NCR53c406a ?
++NCR_D700 ?
++NCR_Q720_mod ?
++sym53c416 ?
++qlogicfas408 ?
++qla1280 ?
++pas16 ?
++seagate ?
++seagate ?
++t128 ?
++dmx3191d ?
++dtc ?
++zalon7xx ?
++eata_pio ?
++wd7000 ?
++mca_53c9x ?
++ibmmca ?
++ibmvfc ?
++ibmvscsi ?
++eata ?
++dc395x ?
++tmscsim ?
++megaraid ?
++atp870u ?
++esp ?
++gdth ?
++initio ?
++a100u2w ?
++qlogicpti ?
++ide-scsi ?
++mesh ?
++mac53c94 ?
++pluto ?
++dec_esp ?
++3w-xxxx ?
++3w-9xxx ?
++ppa ?
++imm ?
++jazz_esp ?
++sun3x_esp ?
++fcal ?
++lasi700 ?
++nsp32 ?
++ipr ?
++hptiop ?
++stex ?
++osst ?
++sg ?
++ch ?
++scsi_debug ?
++aacraid ?
++aic7xxx ?
++aic79xx ?
++aic94xx ?
++arcmsr ?
++acornscsi_mod ?
++arxescsi ?
++cumana_1 ?
++cumana_2 ?
++ecoscsi ?
++oak ?
++powertec ?
++eesox ?
++ibmvscsic ?
++libsas ?
++lpfc ?
++megaraid_mm ?
++megaraid_mbox ?
++megaraid_sas ?
++qla2xxx ?
++sym53c8xx ?
++qla4xxx ?
++mvsas ?
++sr_mod ?
++sd_mod ?
+diff --git a/debian.master/d-i/modules-powerpc/storage-core-modules b/debian.master/d-i/modules-powerpc/storage-core-modules
+new file mode 100644
+index 0000000..de158a9
+--- /dev/null
++++ b/debian.master/d-i/modules-powerpc/storage-core-modules
+@@ -0,0 +1,13 @@
++# Core stacks
++usb-storage ?
++
++# Block level
++
++# Loop modules
++cryptoloop
++
++# Needs to be here for better cdrom initrd layout
++isofs
++
++ps3stor_lib ?
++ps3rom ?
+diff --git a/debian.master/d-i/modules-s390x/dasd-extra-modules b/debian.master/d-i/modules-s390x/dasd-extra-modules
+new file mode 100644
+index 0000000..fff5ab6
+--- /dev/null
++++ b/debian.master/d-i/modules-s390x/dasd-extra-modules
+@@ -0,0 +1 @@
++dasd_diag_mod ?
+diff --git a/debian.master/d-i/modules-s390x/dasd-modules b/debian.master/d-i/modules-s390x/dasd-modules
+new file mode 100644
+index 0000000..8e6185b
+--- /dev/null
++++ b/debian.master/d-i/modules-s390x/dasd-modules
+@@ -0,0 +1,3 @@
++dasd_mod ?
++dasd_fba_mod ?
++dasd_eckd_mod ?
+diff --git a/debian.master/d-i/modules/block-modules b/debian.master/d-i/modules/block-modules
+new file mode 100644
+index 0000000..04462c5
+--- /dev/null
++++ b/debian.master/d-i/modules/block-modules
+@@ -0,0 +1,42 @@
++aoe ?
++aten ?
++bpck ?
++bpck6 ?
++cciss ?
++comm ?
++cpqarray ?
++DAC960 ?
++dstr ?
++epat ?
++epia ?
++fit2 ?
++fit3 ?
++friq ?
++frpw ?
++hpsa ?
++hio ?
++kbic ?
++ktti ?
++nbd ?
++nvme ?
++on20 ?
++on26 ?
++paride ?
++pcd ?
++pd ?
++pf ?
++pg ?
++pt ?
++sdhci-tegra ?
++sx8 ?
++umem ?
++virtio_blk ?
++xen-blkfront ?
++mtip32xx ?
++mmc_block ?
++sdhci ?
++sdhci-pci ?
++sdhci-acpi ?
++tifm_sd ?
++dw_mmc ?
++dw_mmc_pltfm ?
+diff --git a/debian.master/d-i/modules/crypto-modules b/debian.master/d-i/modules/crypto-modules
+new file mode 100644
+index 0000000..333f5a50
+--- /dev/null
++++ b/debian.master/d-i/modules/crypto-modules
+@@ -0,0 +1,70 @@
++aesni-intel ?
++aes-x86_64 ?
++af_alg ?
++algif_hash ?
++algif_skcipher ?
++ansi_cprng ?
++anubis ?
++arc4 ?
++async_memcpy ?
++async_pq ?
++async_raid6_recov ?
++async_tx ?
++async_xor ?
++authenc ?
++authencesn ?
++blowfish_common ?
++blowfish_generic ?
++blowfish-x86_64 ?
++camellia ?
++cast5 ?
++cast6 ?
++ccm ?
++cryptd ?
++cryptoloop ?
++crypto_null ?
++crypto_user ?
++ctr ?
++cts ?
++deflate ?
++des_generic ?
++fcrypt ?
++gcm ?
++gf128mul ?
++ghash-clmulni-intel ?
++ghash-generic ?
++khazad ?
++lrw ?
++lzo ?
++md4 ?
++michael_mic ?
++padlock-aes ?
++padlock-sha ?
++pcbc ?
++pcrypt ?
++raid6test ?
++rmd128 ?
++rmd160 ?
++rmd256 ?
++rmd320 ?
++salsa20_generic ?
++salsa20-x86_64 ?
++seed ?
++seqiv ?
++serpent_generic ?
++serpent-sse2-x86_64 ?
++sha1-ssse3 ?
++sha512_generic ?
++tcrypt ?
++tea ?
++tgr192 ?
++twofish_common ?
++twofish_generic ?
++twofish-x86_64 ?
++twofish-x86_64-3way ?
++vmac ?
++wp512 ?
++xcbc ?
++xor ?
++xts ?
++zlib ?
+diff --git a/debian.master/d-i/modules/fat-modules b/debian.master/d-i/modules/fat-modules
+new file mode 100644
+index 0000000..0aa17c3
+--- /dev/null
++++ b/debian.master/d-i/modules/fat-modules
+@@ -0,0 +1,7 @@
++fat ?
++vfat ?
++
++# Supporting modules ?
++nls_cp437 ?
++nls_iso8859-1 ?
++nls_utf8 ?
+diff --git a/debian.master/d-i/modules/fb-modules b/debian.master/d-i/modules/fb-modules
+new file mode 100644
+index 0000000..eae829f
+--- /dev/null
++++ b/debian.master/d-i/modules/fb-modules
+@@ -0,0 +1,3 @@
++fbcon ?
++vesafb ?
++vga16fb ?
+diff --git a/debian.master/d-i/modules/firewire-core-modules b/debian.master/d-i/modules/firewire-core-modules
+new file mode 100644
+index 0000000..dbb9229
+--- /dev/null
++++ b/debian.master/d-i/modules/firewire-core-modules
+@@ -0,0 +1,4 @@
++firewire-core ?
++firewire-ohci ?
++firewire-sbp2 ?
++firewire-net ?
+diff --git a/debian.master/d-i/modules/floppy-modules b/debian.master/d-i/modules/floppy-modules
+new file mode 100644
+index 0000000..ca8d7ff
+--- /dev/null
++++ b/debian.master/d-i/modules/floppy-modules
+@@ -0,0 +1 @@
++floppy ?
+diff --git a/debian.master/d-i/modules/fs-core-modules b/debian.master/d-i/modules/fs-core-modules
+new file mode 100644
+index 0000000..7a7c2fc
+--- /dev/null
++++ b/debian.master/d-i/modules/fs-core-modules
+@@ -0,0 +1,5 @@
++ext2 ?
++jfs ?
++reiserfs ?
++xfs ?
++zfs ?
+diff --git a/debian.master/d-i/modules/fs-secondary-modules b/debian.master/d-i/modules/fs-secondary-modules
+new file mode 100644
+index 0000000..db46bb7
+--- /dev/null
++++ b/debian.master/d-i/modules/fs-secondary-modules
+@@ -0,0 +1,5 @@
++btrfs ?
++fuse ?
++ntfs ?
++hfs ?
++hfsplus ?
+diff --git a/debian.master/d-i/modules/input-modules b/debian.master/d-i/modules/input-modules
+new file mode 100644
+index 0000000..c6e1c7d
+--- /dev/null
++++ b/debian.master/d-i/modules/input-modules
+@@ -0,0 +1,71 @@
++hid ?
++hid-a4tech ?
++hid-apple ?
++hid-appleir ?
++hid-aureal ?
++hid-belkin ?
++hid-bright ?
++hid-cherry ?
++hid-chicony ?
++hid-corsair ?
++hid-cp2112 ?
++hid-cypress ?
++hid-dell ?
++hid-elecom ?
++hid-elo ?
++hid-ezkey ?
++hid-generic ?
++hid-gfrm ?
++hid-gt683r ?
++hid-gyration ?
++hid-holtek-kbd ?
++hid-holtek-mouse ?
++hid-hyperv ?
++hid-kensington ?
++hid-keytouch ?
++hid-kye ?
++hid-lcpower ?
++hid-lenovo ?
++hid-logitech ?
++hid-logitech-dj ?
++hid-logitech-hidpp ?
++hid-magicmouse ?
++hid-microsoft ?
++hid-monterey ?
++hid-multitouch ?
++hid-ntrig ?
++hid-ortek ?
++hid-penmount ?
++hid-petalynx ?
++hid-picolcd ?
++hid-pl ?
++hid-plantronics ?
++hid-primax ?
++hid-rmi ?
++hid-roccat ?
++hid-roccat-arvo ?
++hid-roccat-common ?
++hid-roccat-isku ?
++hid-roccat-kone ?
++hid-roccat-koneplus ?
++hid-roccat-konepure ?
++hid-roccat-kovaplus ?
++hid-roccat-lua ?
++hid-roccat-pyra ?
++hid-roccat-ryos ?
++hid-roccat-savu ?
++hid-samsung ?
++hid-sony ?
++hid-speedlink ?
++hid-sunplus ?
++hid-thingm ?
++hid-tivo ?
++hid-topseed ?
++hid-twinhan ?
++hid-uclogic ?
++hid-waltop ?
++hid-wiimote ?
++hid-xinmo ?
++hid-zydacron ?
++uhid ?
++usbhid ?
+diff --git a/debian.master/d-i/modules/ipmi-modules b/debian.master/d-i/modules/ipmi-modules
+new file mode 100644
+index 0000000..d539daa
+--- /dev/null
++++ b/debian.master/d-i/modules/ipmi-modules
+@@ -0,0 +1,5 @@
++ipmi_devintf ?
++ipmi_msghandler ?
++ipmi_poweroff ?
++ipmi_si ?
++ipmi_watchdog ?
+diff --git a/debian.master/d-i/modules/irda-modules b/debian.master/d-i/modules/irda-modules
+new file mode 100644
+index 0000000..552e7a7
+--- /dev/null
++++ b/debian.master/d-i/modules/irda-modules
+@@ -0,0 +1,30 @@
++act200l-sir ?
++actisys-sir ?
++ali-ircc ?
++donauboe ?
++esi-sir ?
++girbil-sir ?
++ircomm ?
++ircomm-tty ?
++irda ?
++irda-usb ?
++irlan ?
++irnet ?
++irport ?
++irtty-sir ?
++kingsun-sir ?
++ks959-sir ?
++ksdazzle-sir ?
++litelink-sir ?
++ma600-sir ?
++mcp2120-sir ?
++mcs7780 ?
++nsc-ircc ?
++old_belkin-sir ?
++sir-dev ?
++smsc-ircc2 ?
++stir4200 ?
++tekram-sir ?
++via-ircc ?
++vlsi_ir ?
++w83977af_ir ?
+diff --git a/debian.master/d-i/modules/kernel-image b/debian.master/d-i/modules/kernel-image
+new file mode 100644
+index 0000000..d059f70
+--- /dev/null
++++ b/debian.master/d-i/modules/kernel-image
+@@ -0,0 +1,30 @@
++ast ?
++gpio-pca953x ?
++gpio-regulator ?
++i2c-mux ?
++i2c-mux-pinctrl ?
++i2c-tegra ?
++max8907 ?
++max8907-regulator ?
++nvec ?
++nvec_kbd ?
++nvec_paz00 ?
++nvec_power ?
++nvec_ps2 ?
++palmas-regulator ?
++rtc-em3027 ?
++rtc-max8907 ?
++rtc-palmas ?
++rtc-tps6586x ?
++rtc-tps65910 ?
++tps51632-regulator ?
++tps62360-regulator ?
++tps65090-charger ?
++tps65090-regulator ?
++tps6586x-regulator ?
++tps65910-regulator ?
++host1x ?
++tegra-drm ?
++pwm_bl ?
++pwm-tegra ?
++panel-simple ?
+diff --git a/debian.master/d-i/modules/md-modules b/debian.master/d-i/modules/md-modules
+new file mode 100644
+index 0000000..64217bf
+--- /dev/null
++++ b/debian.master/d-i/modules/md-modules
+@@ -0,0 +1,16 @@
++dm-crypt ?
++dm-mirror ?
++dm-raid ?
++dm-snapshot ?
++dm-zero ?
++faulty ?
++linear ?
++multipath ?
++raid0 ?
++raid1 ?
++raid10 ?
++raid456 ?
++
++# Extras
++dm-raid45 ?
++dm-loop ?
+diff --git a/debian.master/d-i/modules/message-modules b/debian.master/d-i/modules/message-modules
+new file mode 100644
+index 0000000..fd0e9e2
+--- /dev/null
++++ b/debian.master/d-i/modules/message-modules
+@@ -0,0 +1,9 @@
++mptbase ?
++mptctl ?
++mptfc ?
++mptlan ?
++mptsas ?
++mpt2sas ?
++mpt3sas ?
++mptscsih ?
++mptspi ?
+diff --git a/debian.master/d-i/modules/mouse-modules b/debian.master/d-i/modules/mouse-modules
+new file mode 100644
+index 0000000..7b06256
+--- /dev/null
++++ b/debian.master/d-i/modules/mouse-modules
+@@ -0,0 +1,2 @@
++psmouse ?
++usbmouse ?
+diff --git a/debian.master/d-i/modules/multipath-modules b/debian.master/d-i/modules/multipath-modules
+new file mode 100644
+index 0000000..6e4fad7
+--- /dev/null
++++ b/debian.master/d-i/modules/multipath-modules
+@@ -0,0 +1,4 @@
++dm-multipath ?
++dm-round-robin ?
++dm-service-time ?
++dm-queue-length ?
+diff --git a/debian.master/d-i/modules/nfs-modules b/debian.master/d-i/modules/nfs-modules
+new file mode 100644
+index 0000000..a08f538
+--- /dev/null
++++ b/debian.master/d-i/modules/nfs-modules
+@@ -0,0 +1,6 @@
++nfs ?
++nfs_acl ?
++nfsv3 ?
++lockd ?
++sunrpc ?
++cifs ?
+diff --git a/debian.master/d-i/modules/nic-modules b/debian.master/d-i/modules/nic-modules
+new file mode 100644
+index 0000000..24efce0
+--- /dev/null
++++ b/debian.master/d-i/modules/nic-modules
+@@ -0,0 +1,196 @@
++3c359 ?
++3c501 ?
++3c503 ?
++3c505 ?
++3c507 ?
++3c509 ?
++3c515 ?
++3c523 ?
++3c527 ?
++3c59x ?
++8139cp ?
++8139too ?
++82596 ?
++abyss ?
++ac3200 ?
++adm8211 ?
++airo ?
++airport ?
++alx ?
++amd8111e ?
++amd-xgbe ?
++aquantia ?
++arcnet ?
++arc-rawmode ?
++arc-rimi ?
++arlan ?
++at1700 ?
++ath5k ?
++ath9k ?
++ath9k_htc ?
++atl1 ?
++atl1c ?
++atl1e ?
++atl2 ?
++atmel ?
++atmel_pci ?
++b44 ?
++bcm87xx ?
++be2net ?
++bmac ?
++bnx2 ?
++bnx2x ?
++bnxt_en ?
++bonding ?
++brcmfmac ?
++brcmsmac ?
++broadcom ?
++xgmac ?
++cassini ?
++ccwgroup ?
++com20020 ?
++com20020-pci ?
++com90io ?
++com90xx ?
++cs89x0 ?
++ctcm ?
++de2104x ?
++de4x5 ?
++de600 ?
++de620 ?
++defxx ?
++depca ?
++dl2k ?
++dmfe ?
++dummy ?
++e100 ?
++e1000 ?
++e1000e ?
++e2100 ?
++eepro ?
++eepro100 ?
++eexpress ?
++enic ?
++epic100 ?
++eql ?
++es3210 ?
++eth16i ?
++ewrk3 ?
++fealnx ?
++forcedeth ?
++fsm ?
++ibmveth ?
++igb ?
++ps3_gelic ?
++hamachi ?
++hermes ?
++hp ?
++hp100 ?
++hp-plus ?
++i40e ?
++i40evf ?
++ibmtr ?
++ipddp ?
++ipw2100 ?
++ipw2200 ?
++iwl3945 ?
++iwl4965 ?
++iwl-legacy ?
++iwldvm ?
++iwlwifi ?
++ixgb ?
++ixgbe ?
++lance ?
++lanstreamer ?
++lcs ?
++lasi_82596 ?
++lne390 ?
++lp486e ?
++mace ?
++marvell ?
++mdio-thunder ?
++mlx4_core ?
++mlx4_en ?
++mlx5_core ?
++mv643xx_eth ?
++myri_sbus ?
++natsemi ?
++ne ?
++ne2 ?
++ne2k-pci ?
++ne3210 ?
++netconsole ?
++netiucv ?
++netxen_nic ?
++ni5010 ?
++ni52 ?
++ni65 ?
++nicpf ?
++nicvf ?
++niu ?
++ns83820 ?
++olympic ?
++orinoco ?
++orinoco_pci ?
++orinoco_plx ?
++orinoco_tmd ?
++pcnet32 ?
++qeth ?
++qeth_l2 ?
++qeth_l3 ?
++qlcnic ?
++r815x ?
++r8169 ?
++rate_control ?
++realtek ?
++rfc1051 ?
++rfc1201 ?
++rrunner ?
++rt2400 ?
++rt2400pci ?
++rt2500 ?
++rt2500pci ?
++rt2800pci ?
++rt61pci ?
++s2io ?
++sfc ?
++shaper ?
++sis190 ?
++sis900 ?
++spidernet ?
++skfp ?
++skge ?
++sk98lin ?
++sky2 ?
++smc9194 ?
++smc-ultra ?
++smc-ultra32 ?
++starfire ?
++strip ?
++sunbmac ?
++sundance ?
++sungem ?
++sungem_phy ?
++sunhme ?
++sunlance ?
++sunqe ?
++sunvnet ?
++tg3 ?
++tlan ?
++tms380tr ?
++tmspci ?
++tulip ?
++tun ?
++typhoon ?
++uli526x ?
++via-rhine ?
++via-velocity ?
++virtio_net ?
++wavelan ?
++wd ?
++winbond-840 ?
++yellowfin ?
++znet ?
++vmxnet3 ?
++xen-netfront ?
++xgene-enet ?
+diff --git a/debian.master/d-i/modules/nic-pcmcia-modules b/debian.master/d-i/modules/nic-pcmcia-modules
+new file mode 100644
+index 0000000..1916875
+--- /dev/null
++++ b/debian.master/d-i/modules/nic-pcmcia-modules
+@@ -0,0 +1,19 @@
++3c574_cs ?
++3c589_cs ?
++airo_cs ?
++atmel_cs ?
++axnet_cs ?
++com20020_cs ?
++fmvj18x_cs ?
++ibmtr_cs ?
++netwave_cs ?
++nmclan_cs ?
++orinoco_cs ?
++pcnet_cs ?
++ray_cs ?
++smc91c92_cs ?
++wavelan_cs ?
++wl3501_cs ?
++xirc2ps_cs ?
++xircom_cb ?
++xircom_tulip_cb ?
+diff --git a/debian.master/d-i/modules/nic-shared-modules b/debian.master/d-i/modules/nic-shared-modules
+new file mode 100644
+index 0000000..0ee15aa
+--- /dev/null
++++ b/debian.master/d-i/modules/nic-shared-modules
+@@ -0,0 +1,26 @@
++# PHY
++8390 ?
++mii ?
++
++# CRC modules
++crc-ccitt ?
++crc-itu-t ?
++libcrc32c ?
++
++# mac80211 stuff
++mac80211 ?
++cfg80211 ?
++
++# rt2x00 lib (since rt2x00 is split across usb/pci/cb
++rt2x00lib ?
++rt2800lib ?
++
++# Atheros library (since drivers are split across nic-modules/nic-usb-modules)
++ath ?
++
++# Wireless 802.11 modules
++lib80211 ?
++cfg80211 ?
++lib80211_crypt_ccmp ?
++lib80211_crypt_tkip ?
++lib80211_crypt_wep ?
+diff --git a/debian.master/d-i/modules/nic-usb-modules b/debian.master/d-i/modules/nic-usb-modules
+new file mode 100644
+index 0000000..2dabc2d
+--- /dev/null
++++ b/debian.master/d-i/modules/nic-usb-modules
+@@ -0,0 +1,32 @@
++catc ?
++kaweth ?
++pegasus ?
++prism2_usb ?
++rtl8150 ?
++usbnet ?
++zd1211rw ?
++zd1201 ?
++rt2500usb ?
++rt73usb ?
++rt2570 ?
++rt2800usb ?
++rt2x00usb ?
++cdc_ether ?
++asix ?
++cdc_eem ?
++cdc_ether ?
++cdc-phonet ?
++cdc_subset ?
++dm9601 ?
++gl620a ?
++hso ?
++int51x1 ?
++mcs7830 ?
++net1080 ?
++plusb ?
++rndis_host ?
++smsc95xx ?
++zaurus ?
++carl9170 ?
++smsc75xx ?
++smsc95xx ?
+diff --git a/debian.master/d-i/modules/parport-modules b/debian.master/d-i/modules/parport-modules
+new file mode 100644
+index 0000000..75fe0b9
+--- /dev/null
++++ b/debian.master/d-i/modules/parport-modules
+@@ -0,0 +1,2 @@
++parport ?
++parport_pc ?
+diff --git a/debian.master/d-i/modules/pata-modules b/debian.master/d-i/modules/pata-modules
+new file mode 100644
+index 0000000..a58c30a
+--- /dev/null
++++ b/debian.master/d-i/modules/pata-modules
+@@ -0,0 +1,47 @@
++pata_ali.ko ?
++pata_amd.ko ?
++pata_artop.ko ?
++pata_atiixp.ko ?
++pata_atp867x.ko ?
++pata_cmd640.ko ?
++pata_cmd64x.ko ?
++pata_cs5520.ko ?
++pata_cs5530.ko ?
++pata_cs5535.ko ?
++pata_cs5536.ko ?
++pata_cypress.ko ?
++pata_efar.ko ?
++pata_hpt366.ko ?
++pata_hpt37x.ko ?
++pata_hpt3x2n.ko ?
++pata_hpt3x3.ko ?
++pata_isapnp.ko ?
++pata_it8213.ko ?
++pata_it821x.ko ?
++pata_jmicron.ko ?
++pata_legacy.ko ?
++pata_macio.ko ?
++pata_marvell.ko ?
++pata_mpiix.ko ?
++pata_netcell.ko ?
++pata_ninja32.ko ?
++pata_ns87410.ko ?
++pata_ns87415.ko ?
++pata_oldpiix.ko ?
++pata_optidma.ko ?
++pata_opti.ko ?
++pata_pcmcia.ko ?
++pata_pdc2027x.ko ?
++pata_pdc202xx_old.ko ?
++pata_qdi.ko ?
++pata_radisys.ko ?
++pata_rdc.ko ?
++pata_rz1000.ko ?
++pata_sc1200.ko ?
++pata_sch.ko ?
++pata_serverworks.ko ?
++pata_sil680.ko ?
++pata_sl82c105.ko ?
++pata_triflex.ko ?
++pata_via.ko ?
++pata_winbond.ko ?
+diff --git a/debian.master/d-i/modules/pcmcia-modules b/debian.master/d-i/modules/pcmcia-modules
+new file mode 100644
+index 0000000..06a5031
+--- /dev/null
++++ b/debian.master/d-i/modules/pcmcia-modules
+@@ -0,0 +1,8 @@
++i82092 ?
++i82365 ?
++pcmcia ?
++pcmcia_core ?
++pd6729 ?
++rsrc_nonstatic ?
++tcic ?
++yenta_socket ?
+diff --git a/debian.master/d-i/modules/pcmcia-storage-modules b/debian.master/d-i/modules/pcmcia-storage-modules
+new file mode 100644
+index 0000000..bb042a6
+--- /dev/null
++++ b/debian.master/d-i/modules/pcmcia-storage-modules
+@@ -0,0 +1,6 @@
++pata_pcmcia ?
++qlogic_cs ?
++fdomain_cs ?
++aha152x_cs ?
++nsp_cs ?
++sym53c500_cs ?
+diff --git a/debian.master/d-i/modules/plip-modules b/debian.master/d-i/modules/plip-modules
+new file mode 100644
+index 0000000..446e2bd
+--- /dev/null
++++ b/debian.master/d-i/modules/plip-modules
+@@ -0,0 +1 @@
++plip ?
+diff --git a/debian.master/d-i/modules/ppp-modules b/debian.master/d-i/modules/ppp-modules
+new file mode 100644
+index 0000000..d4f6a92
+--- /dev/null
++++ b/debian.master/d-i/modules/ppp-modules
+@@ -0,0 +1,6 @@
++ppp_async ?
++ppp_deflate ?
++ppp_mppe ?
++pppoe ?
++pppox ?
++ppp_synctty ?
+diff --git a/debian.master/d-i/modules/sata-modules b/debian.master/d-i/modules/sata-modules
+new file mode 100644
+index 0000000..6a4171d
+--- /dev/null
++++ b/debian.master/d-i/modules/sata-modules
+@@ -0,0 +1,18 @@
++sata_inic162x.ko ?
++sata_mv.ko ?
++sata_nv.ko ?
++sata_promise.ko ?
++sata_qstor.ko ?
++sata_sil24.ko ?
++sata_sil.ko ?
++sata_sis.ko ?
++sata_svw.ko ?
++sata_sx4.ko ?
++sata_uli.ko ?
++sata_via.ko ?
++sata_vsc.ko ?
++ahci_platform ?
++ahci ?
++acard-ahci ?
++libahci ?
++ahci_xgene ?
+diff --git a/debian.master/d-i/modules/scsi-modules b/debian.master/d-i/modules/scsi-modules
+new file mode 100644
+index 0000000..46e0ac9
+--- /dev/null
++++ b/debian.master/d-i/modules/scsi-modules
+@@ -0,0 +1,131 @@
++# SCSI
++raid_class ?
++scsi_transport_spi ?
++scsi_transport_fc ?
++scsi_transport_iscsi ?
++scsi_transport_sas ?
++iscsi_tcp ?
++libiscsi ?
++amiga7xx ?
++a3000 ?
++a2091 ?
++gvp11 ?
++mvme147 ?
++sgiwd93 ?
++cyberstorm ?
++cyberstormII ?
++blz2060 ?
++blz1230 ?
++fastlane ?
++oktagon_esp_mod ?
++atari_scsi ?
++mac_scsi ?
++mac_esp ?
++sun3_scsi ?
++mvme16x ?
++bvme6000 ?
++sim710 ?
++advansys ?
++pm80xx ?
++psi240i ?
++BusLogic ?
++dpt_i2o ?
++u14-34f ?
++ultrastor ?
++aha152x ?
++aha1542 ?
++aha1740 ?
++aic7xxx_old ?
++ips ?
++fd_mcs ?
++fdomain ?
++fnic ?
++in2000 ?
++g_NCR5380 ?
++g_NCR5380_mmio ?
++NCR53c406a ?
++NCR_D700 ?
++NCR_Q720_mod ?
++sym53c416 ?
++qlogicfas408 ?
++qla1280 ?
++pas16 ?
++seagate ?
++seagate ?
++t128 ?
++dmx3191d ?
++dtc ?
++zalon7xx ?
++eata_pio ?
++wd7000 ?
++mca_53c9x ?
++ibmmca ?
++eata ?
++dc395x ?
++tmscsim ?
++megaraid ?
++atp870u ?
++esp ?
++gdth ?
++initio ?
++a100u2w ?
++qlogicpti ?
++ide-scsi ?
++mesh ?
++mac53c94 ?
++pluto ?
++dec_esp ?
++3w-xxxx ?
++3w-9xxx ?
++ppa ?
++imm ?
++jazz_esp ?
++sun3x_esp ?
++fcal ?
++lasi700 ?
++nsp32 ?
++ipr ?
++hptiop ?
++stex ?
++osst ?
++sg ?
++ch ?
++scsi_debug ?
++aacraid ?
++aic7xxx ?
++aic79xx ?
++aic94xx ?
++arcmsr ?
++acornscsi_mod ?
++arxescsi ?
++cumana_1 ?
++cumana_2 ?
++ecoscsi ?
++oak ?
++powertec ?
++eesox ?
++ibmvscsi ?
++ibmvfc ?
++libsas ?
++lpfc ?
++megaraid_mm ?
++megaraid_mbox ?
++megaraid_sas ?
++qla2xxx ?
++sym53c8xx ?
++qla4xxx ?
++mvsas ?
++vmw_pvscsi ?
++ums-cypress ?
++be2iscsi ?
++3w-sas ?
++isci ?
++mlx4_ib ?
++mlx5_ib ?
++zfcp ?
++
++# device handlers
++scsi_dh_alua ?
++scsi_dh_emc ?
++scsi_dh_rdac ?
++scsi_dh_hp_sw ?
+diff --git a/debian.master/d-i/modules/serial-modules b/debian.master/d-i/modules/serial-modules
+new file mode 100644
+index 0000000..e170891
+--- /dev/null
++++ b/debian.master/d-i/modules/serial-modules
+@@ -0,0 +1,4 @@
++generic_serial ?
++serial_cs ?
++synclink_cs ?
++hyperv-keyboard ?
+diff --git a/debian.master/d-i/modules/speakup-modules b/debian.master/d-i/modules/speakup-modules
+new file mode 100644
+index 0000000..c3bef91
+--- /dev/null
++++ b/debian.master/d-i/modules/speakup-modules
+@@ -0,0 +1,16 @@
++speakup ?
++speakup_acntpc ?
++speakup_acntsa ?
++speakup_apollo ?
++speakup_audptr ?
++speakup_bns ?
++speakup_decext ?
++speakup_dectlk ?
++speakup_dtlk ?
++speakup_dummy ?
++speakup_keypc ?
++speakup_ltlk ?
++speakup_soft ?
++speakup_spkout ?
++speakup_txprt ?
++speakup_decpc ?
+diff --git a/debian.master/d-i/modules/storage-core-modules b/debian.master/d-i/modules/storage-core-modules
+new file mode 100644
+index 0000000..2abfc06
+--- /dev/null
++++ b/debian.master/d-i/modules/storage-core-modules
+@@ -0,0 +1,10 @@
++# Core stacks
++usb-storage ?
++
++# Block level
++
++# Loop modules
++cryptoloop ?
++
++# Needs to be here for better cdrom initrd layout
++isofs ?
+diff --git a/debian.master/d-i/modules/usb-modules b/debian.master/d-i/modules/usb-modules
+new file mode 100644
+index 0000000..283a028
+--- /dev/null
++++ b/debian.master/d-i/modules/usb-modules
+@@ -0,0 +1,14 @@
++ehci-hcd ?
++isp116x-hcd ?
++isp1760 ?
++ohci-hcd ?
++r8a66597-hcd ?
++sl811_cs ?
++sl811-hcd ?
++u132-hcd ?
++uhci-hcd ?
++xhci-hcd ?
++ehci-tegra ?
++ehci-msm ?
++uas ?
++xhci-plat-hcd ?
+diff --git a/debian.master/d-i/modules/virtio-modules b/debian.master/d-i/modules/virtio-modules
+new file mode 100644
+index 0000000..a7bcbb7
+--- /dev/null
++++ b/debian.master/d-i/modules/virtio-modules
+@@ -0,0 +1,11 @@
++virtio_balloon ?
++virtio_pci ?
++virtio_ring ?
++virtio-rng ?
++virtio_scsi ?
++hv_vmbus ?
++hv_utils ?
++hv_netvsc ?
++hv_mouse ?
++hv_storvsc ?
++hv_balloon ?
+diff --git a/debian.master/d-i/modules/vlan-modules b/debian.master/d-i/modules/vlan-modules
+new file mode 100644
+index 0000000..3d65a55
+--- /dev/null
++++ b/debian.master/d-i/modules/vlan-modules
+@@ -0,0 +1,3 @@
++slp ?
++garp ?
++8021q ?
+diff --git a/debian.master/d-i/package-list b/debian.master/d-i/package-list
+new file mode 100644
+index 0000000..41b775f
+--- /dev/null
++++ b/debian.master/d-i/package-list
+@@ -0,0 +1,207 @@
++Package: kernel-image
++Provides: ext3-modules, ext4-modules
++Provides_amd64: efi-modules, ext3-modules, ext4-modules
++Provides_i386: efi-modules, ext3-modules, ext4-modules
++Provides_ppc64el: ext3-modules, ext4-modules, fat-modules
++Provides_s390x: ext3-modules, ext4-modules, ppp-modules
++
++Package: dasd-modules
++Depends: kernel-image, storage-core-modules
++Priority: standard
++Description: DASD storage support
++
++Package: dasd-extra-modules
++Depends: dasd-modules
++Priority: extra
++Description: DASD storage support -- extras
++
++Package: fat-modules
++Depends: kernel-image
++Priority: standard
++Description: FAT filesystem support
++ This includes Windows FAT and VFAT support.
++
++Package: fb-modules
++Depends: kernel-image
++Priority: standard
++Description: Framebuffer modules
++
++Package: firewire-core-modules
++Depends: kernel-image, storage-core-modules
++Priority: standard
++Description: Firewire (IEEE-1394) Support
++
++Package: floppy-modules
++Depends: kernel-image
++Priority: standard
++Description: Floppy driver support
++
++Package: fs-core-modules
++Depends: kernel-image
++Priority: standard
++Provides: ext2-modules, jfs-modules, reiserfs-modules, xfs-modules
++Description: Base filesystem modules
++ This includes jfs, reiserfs and xfs.
++
++Package: fs-secondary-modules
++Depends: kernel-image, fat-modules
++Priority: standard
++Provides: btrfs-modules, ntfs-modules, hfs-modules
++Description: Extra filesystem modules
++ This includes support for Windows NTFS and MacOS HFS/HFSPlus
++
++Package: input-modules
++Depends: kernel-image, usb-modules
++Priority: standard
++Description: Support for various input methods
++
++Package: irda-modules
++Depends: kernel-image, nic-shared-modules
++Priority: standard
++Description: Support for Infrared protocols
++
++Package: md-modules
++Depends: kernel-image
++Priority: standard
++Provides: crypto-dm-modules
++Description: Multi-device support (raid, device-mapper, lvm)
++
++Package: nic-modules
++Depends: kernel-image, nic-shared-modules, virtio-modules
++Priority: standard
++Description: Network interface support
++
++Package: nic-pcmcia-modules
++Depends: kernel-image, nic-shared-modules, nic-modules
++Priority: standard
++Description: PCMCIA network interface support
++
++Package: nic-usb-modules
++Depends: kernel-image, nic-shared-modules, usb-modules
++Priority: standard
++Description: USB network interface support
++
++Package: nic-shared-modules
++Depends: kernel-image, crypto-modules
++Priority: standard
++Description: nic shared modules
++  This package contains modules which support nic modules
++
++Package: parport-modules
++Depends: kernel-image
++Priority: standard
++Description: Parallel port support
++
++Package: pata-modules
++Depends: kernel-image, storage-core-modules
++Priority: standard
++Description: PATA support modules
++
++Package: pcmcia-modules
++Depends: kernel-image
++Priority: standard
++Description: PCMCIA Modules
++
++Package: pcmcia-storage-modules
++Depends: kernel-image, scsi-modules
++Priority: standard
++Description: PCMCIA storage support
++
++Package: plip-modules
++Depends: kernel-image, nic-shared-modules, parport-modules
++Priority: standard
++Description: PLIP (parallel port) networking support
++
++Package: ppp-modules
++Depends: kernel-image, nic-shared-modules, serial-modules
++Priority: standard
++Description: PPP (serial port) networking support
++
++Package: sata-modules
++Depends: kernel-image, storage-core-modules
++Priority: standard
++Description: SATA storage support
++
++Package: scsi-modules
++Depends: kernel-image, storage-core-modules
++Priority: standard
++Description: SCSI storage support
++
++Package: serial-modules
++Depends: kernel-image
++Priority: standard
++Description: Serial port support
++
++Package: storage-core-modules
++Depends: kernel-image
++Priority: standard
++Provides: loop-modules
++Description: Core storage support
++ Includes core SCSI, LibATA, USB-Storage. Also includes related block
++ devices for CD, Disk and Tape medium (and IDE Floppy).
++
++Package: usb-modules
++Depends: kernel-image, storage-core-modules
++Priority: standard
++Description: Core USB support
++
++Package: nfs-modules
++Priority: standard
++Depends: kernel-image
++Description: NFS filesystem drivers
++ Includes the NFS client driver, and supporting modules.
++
++Package: block-modules
++Priority: standard
++Provides: nbd-modules
++Depends: kernel-image, storage-core-modules, parport-modules, virtio-modules
++Description: Block storage devices
++ This package contains the block storage devices, including DAC960 and
++ paraide.
++
++Package: message-modules
++Priority: standard
++Depends: kernel-image, storage-core-modules, scsi-modules
++Description: Fusion and i2o storage modules
++ This package containes the fusion and i2o storage modules.
++
++Package: crypto-modules
++Priority: extra
++Depends: kernel-image
++Description: crypto modules
++ This package contains crypto modules.
++
++Package: virtio-modules
++Priority: standard
++Depends: kernel-image
++Description: VirtIO Modules
++ Includes modules for VirtIO (virtual machine, generally kvm guests)
++
++Package: socket-modules
++Depends: kernel-image
++Priority: standard
++Description: Unix socket support
++
++Package: mouse-modules
++Depends: kernel-image, input-modules, usb-modules
++Priority: extra
++Description: Mouse support
++ This package contains mouse drivers for the Linux kernel.
++
++Package: vlan-modules
++Depends: kernel-image
++Priority: extra
++Description: vlan modules
++ This package contains vlan (8021.Q) modules.
++
++Package: ipmi-modules
++Depends: kernel-image
++Priority: standard
++Description: ipmi modules
++
++Package: multipath-modules
++Depends: kernel-image
++Priority: extra
++Description: DM-Multipath support
++  This package contains modules for device-mapper multipath support.
++
+diff --git a/debian.master/etc/getabis b/debian.master/etc/getabis
+new file mode 100644
+index 0000000..2bd1c18
+--- /dev/null
++++ b/debian.master/etc/getabis
+@@ -0,0 +1,20 @@
++repo_list=(
++	"http://archive.ubuntu.com/ubuntu/pool/main/l/linux"
++	"http://ports.ubuntu.com/ubuntu-ports/pool/main/l/linux"
++	"http://archive.ubuntu.com/ubuntu/pool/universe/l/linux"
++	"http://ports.ubuntu.com/ubuntu-ports/pool/universe/l/linux"
++	"http://ppa.launchpad.net/canonical-kernel-team/ppa/ubuntu/pool/main/l/linux"
++)
++
++package_prefixes linux-image linux-image-extra
++
++getall armhf generic
++getall armhf generic-lpae
++getall amd64 generic lowlatency
++getall i386 generic lowlatency
++getall arm64 generic
++getall ppc64el generic
++getall s390x generic
++
++# Ports arches and flavours.
++getall powerpc powerpc-smp powerpc64-smp powerpc-e500mc powerpc64-emb
+diff --git a/debian.master/etc/kernelconfig b/debian.master/etc/kernelconfig
+new file mode 100644
+index 0000000..b10b536
+--- /dev/null
++++ b/debian.master/etc/kernelconfig
+@@ -0,0 +1,7 @@
++if [ "$variant" = "ports" ]; then
++	archs=""
++	family='ports'
++else
++	archs="amd64 i386 armhf arm64 ppc64el powerpc s390x"
++	family='ubuntu'
++fi
+diff --git a/debian.master/info/OVERRIDES b/debian.master/info/OVERRIDES
+new file mode 100644
+index 0000000..e775ff2
+--- /dev/null
++++ b/debian.master/info/OVERRIDES
+@@ -0,0 +1,153 @@
++CONFIG_RCU_KTHREAD_PRIO=0
++CONFIG_X86_AMD_PLATFORM_DEVICE=y
++CONFIG_ZSMALLOC_STAT=N
++CONFIG_LIVEPATCH=y
++CONFIG_IEEE802154_SOCKET=m
++CONFIG_NET_ACT_BPF=m
++CONFIG_NET_ACT_CONNMARK=m
++# CONFIG_BT_SELFTEST is not set
++CONFIG_MTD_NAND_HISI504=m
++CONFIG_IXGBE_VXLAN=y
++CONFIG_TI_CPSW_ALE=m
++CONFIG_MOUSE_PS2_FOCALTECH=y
++CONFIG_INPUT_E3X0_BUTTON=m
++CONFIG_INPUT_REGULATOR_HAPTIC=m
++CONFIG_INPUT_TPS65218_PWRBUTTON=m
++CONFIG_INPUT_AXP20X_PEK=m
++# CONFIG_DEVMEM is not set
++CONFIG_TCG_TIS_I2C_ST33=m
++CONFIG_TCG_CRB=m
++CONFIG_SPI_DLN2=m
++CONFIG_CHARGER_MAX77693=m
++CONFIG_BATTERY_GAUGE_LTC2941=m
++CONFIG_MFD_DA9150=m
++CONFIG_MFD_RT5033=m
++CONFIG_REGULATOR_RT5033=m
++CONFIG_USB_GSPCA_TOUPTEK=m
++CONFIG_DUMMY_CONSOLE_COLUMNS=80
++CONFIG_DUMMY_CONSOLE_ROWS=25
++CONFIG_SND_USB_POD=m
++CONFIG_SND_USB_PODHD=m
++CONFIG_SND_USB_TONEPORT=m
++CONFIG_SND_USB_VARIAX=m
++CONFIG_SND_SOC_INTEL_CHT_BSW_RT5645_MACH=m
++CONFIG_SND_SOC_XTFPGA_I2S=m
++CONFIG_SND_SOC_STA32X=m
++CONFIG_HID_BETOP_FF=m
++CONFIG_USB_ISP1760=m
++CONFIG_USB_CONFIGFS_F_UVC=y
++CONFIG_LEDS_CLASS_FLASH=m
++CONFIG_RTC_DRV_ABB5ZES3=m
++CONFIG_RTC_DRV_DS1685_FAMILY=m
++# CONFIG_RTC_DS1685_PROC_REGS is not set
++# CONFIG_RTC_DS1685_SYSFS_REGS is not set
++CONFIG_VIRTIO_PCI_LEGACY=y
++CONFIG_FB_SM7XX=m
++CONFIG_FB_TFT=m
++CONFIG_FB_TFT_AGM1264K_FL=m
++CONFIG_FB_TFT_BD663474=m
++CONFIG_FB_TFT_HX8340BN=m
++CONFIG_FB_TFT_HX8347D=m
++CONFIG_FB_TFT_HX8353D=m
++CONFIG_FB_TFT_ILI9320=m
++CONFIG_FB_TFT_ILI9325=m
++CONFIG_FB_TFT_ILI9340=m
++CONFIG_FB_TFT_ILI9341=m
++CONFIG_FB_TFT_ILI9481=m
++CONFIG_FB_TFT_ILI9486=m
++CONFIG_FB_TFT_PCD8544=m
++CONFIG_FB_TFT_RA8875=m
++CONFIG_FB_TFT_S6D02A1=m
++CONFIG_FB_TFT_S6D1121=m
++CONFIG_FB_TFT_SSD1289=m
++CONFIG_FB_TFT_SSD1306=m
++CONFIG_FB_TFT_SSD1331=m
++CONFIG_FB_TFT_SSD1351=m
++CONFIG_FB_TFT_ST7735R=m
++CONFIG_FB_TFT_TINYLCD=m
++CONFIG_FB_TFT_TLS8204=m
++CONFIG_FB_TFT_UC1701=m
++CONFIG_FB_TFT_UPD161704=m
++CONFIG_FB_TFT_WATTEROTT=m
++CONFIG_FB_FLEX=m
++CONFIG_FB_TFT_FBTFT_DEVICE=m
++CONFIG_COMMON_CLK_CDCE706=m
++CONFIG_ALTERA_MBOX=m
++CONFIG_PM_DEVFREQ_EVENT=y
++CONFIG_MMA9551=m
++CONFIG_MMA9553=m
++CONFIG_CC10001_ADC=m
++CONFIG_QCOM_SPMI_VADC=m
++CONFIG_IIO_SSP_SENSORHUB=m
++CONFIG_KMX61=m
++CONFIG_CM3232=m
++CONFIG_JSA1212=m
++CONFIG_SX9500=m
++CONFIG_FS_DAX=y
++# CONFIG_PSTORE_PMSG is not set
++# CONFIG_F2FS_IO_TRACE is not set
++CONFIG_NFSD_PNFS=y
++CONFIG_GDB_SCRIPTS=y
++# CONFIG_KASAN is not set
++CONFIG_TEST_HEXDUMP=m
++CONFIG_SECURITY_SMACK_NETFILTER=y
++CONFIG_CRYPTO_USER_API_RNG=m
++CONFIG_BLK_DEV_RAM_DAX=y
++CONFIG_BATTERY_RT5033=m
++CONFIG_IIO_SSP_SENSORS_COMMONS=m
++# CONFIG_ZSMALLOC_STAT is not set
++# CONFIG_X86_INTEL_QUARK is not set
++# CONFIG_ZSMALLOC_STAT is not set
++CONFIG_X86_SFI_CPUFREQ=m
++# CONFIG_X86_INTEL_QUARK is not set
++# CONFIG_ZSMALLOC_STAT is not set
++CONFIG_X86_SFI_CPUFREQ=m
++# CONFIG_ARCH_DIGICOLOR is not set
++CONFIG_ARCH_HIP01=y
++CONFIG_MACH_MT6589=y
++CONFIG_MACH_MT6592=y
++CONFIG_MACH_MT8127=y
++CONFIG_MACH_MT8135=y
++# CONFIG_ARCH_R8A73A4 is not set
++# CONFIG_ZSMALLOC_STAT is not set
++CONFIG_ARM_EXYNOS_CPUFREQ=m
++# CONFIG_ARM_EXYNOS_CPU_FREQ_BOOST_SW is not set
++CONFIG_OF_OVERLAY=y
++CONFIG_HIP04_ETH=m
++CONFIG_SERIAL_CONEXANT_DIGICOLOR=m
++CONFIG_PINCTRL_MSM8916=m
++CONFIG_POWER_RESET_RMOBILE=m
++CONFIG_MEDIATEK_WATCHDOG=m
++CONFIG_MFD_QCOM_RPM=m
++CONFIG_REGULATOR_QCOM_RPM=m
++CONFIG_NOUVEAU_PLATFORM_DRIVER=y
++# CONFIG_DRM_EXYNOS7_DECON is not set
++CONFIG_DRM_ATMEL_HLCDC=m
++CONFIG_DISPLAY_ENCODER_OPA362=m
++CONFIG_SND_SOC_TEGRA_RT5677=m
++CONFIG_MMC_SDHCI_F_SDH30=m
++CONFIG_RTC_DRV_ARMADA38X=m
++CONFIG_RCAR_DMAC=m
++CONFIG_CLK_QORIQ=m
++CONFIG_IPQ_LCC_806X=m
++CONFIG_MSM_LCC_8960=m
++# CONFIG_IOMMU_IO_PGTABLE_LPAE is not set
++CONFIG_ARM_TEGRA_DEVFREQ=m
++# CONFIG_DEVFREQ_EVENT_EXYNOS_PPMU is not set
++# CONFIG_ARCH_DIGICOLOR is not set
++# CONFIG_ARCH_HIP01 is not set
++CONFIG_MACH_MT6589=y
++CONFIG_MACH_MT6592=y
++CONFIG_MACH_MT8127=y
++CONFIG_MACH_MT8135=y
++# CONFIG_ARCH_R8A73A4 is not set
++# CONFIG_CLK_QORIQ is not set
++# CONFIG_IOMMU_IO_PGTABLE_LPAE_SELFTEST is not set
++# CONFIG_ARCH_EXYNOS7 is not set
++# CONFIG_ARCH_FSL_LS2085A is not set
++# CONFIG_ARCH_TEGRA is not set
++CONFIG_CAN_XILINXCAN=m
++CONFIG_GPIO_XGENE_SB=m
++# CONFIG_DEBUG_ALIGN_RODATA is not set
++CONFIG_UIO_FSL_ELBC_GPCM=m
++# CONFIG_UIO_FSL_ELBC_GPCM_NETX5152 is not set
+diff --git a/debian.master/info/REBASE b/debian.master/info/REBASE
+new file mode 100644
+index 0000000..f87e398
+--- /dev/null
++++ b/debian.master/info/REBASE
+@@ -0,0 +1,47 @@
++Could not apply b551f2a4439d2179b3732c2a28277d9245dbb150... NEEDED UBUNTU: SAUCE: xgmac_mdio: Silence read errors
++	commit 1fcf77c87ad659a92e1dcfb883388cb43baeaab6
++
++Could not apply 7cc84cf61b760725973c93b9c7e39d6f521bfe62... NEEDED Revert "net/mlx4_en: Fix bad use of dev_id"
++	commit ca9f9f703950e5cb300526549b4f1b0a6605a5c5
++
++error: could not apply ff7e372... overlay: add backwards compatible overlayfs format support
++Could not apply 3fd5011f880877a583b1ccefd06ad481452cdef7... NEEDED overlay: add backwards compatible overlayfs format support (fixes)
++	XXX: needed
++
++Could not apply 98c64db6cffd59a894d4a4492aea761fa6e6c51a... NEEDED UBUNTU: SAUCE: (no-up) apparmor: Sync to apparmor3 - RC1 snapshot
++Could not apply 892b8b7cfb14b9bdfbc9ac2fee8e751a67707542... NEEDED UBUNTU: SAUCE: Revert: fix: only allow a single threaded process to ...
++Could not apply e1b6a4b88bdb9cf858e068d0e3a6b7449d648513... NEEDED UBUNTU: SAUCE: (no-up) fix: bad unix_addr_fs macro
++Could not apply 9defa41f9126d026cd6a1ead03e6443e98e97108... NEEDED UBUNTU: apparmor -- follow change to this_cpu_ptr
++Could not apply 36ca906c4d4cf34bb5a750d1dbd3e4abe36a4684... NEEDED UBUNTU: SAUCE: (no-up): apparmor: fix mediation of fs unix sockets
++	XXX: needed (apparmor)
++	PORTED AND REAPPLIED
++
++Could not apply 4594c0a5b120fc92fb141c1cf9eef3e8d665e4e6... NEEDED UBUNTU: SAUCE: storvsc: force SPC-3 compliance on win8 and win8 r2 hosts
++	commit b0a93d96b2814c725161f91a4e35d0c29ec0f95b
++
++Could not apply d8db9694361b258427eab1846b211be332c4a1f9... NEEDED UBUNTU: SAUCE: efi: Expose underlying UEFI firmware platform size to userland
++	commit 2859dff97e54db4795b8b7d9606cb8efcec722ff
++
++Could not apply fe8ce4f67a26106dab3193b3515fe865e136ab4a... NEEDED UBUNTU: SAUCE: arm64 -- psci tell the compiler which registers we are needing values in
++	commit f5e0a12ca2d939e47995f73428d9bf1ad372b289
++
++Could not apply e9f926b44c895d39152d3f816ce9ff37780f77cb... NEEDED xen: correct bug in p2m list initialization
++	commit b8f05c8803fce899d79ca66f8d7f348cf15fb40e
++
++Could not apply 7ec323466d993094545e140cc44559cb1cccbd14... NEEDED tpm/ibmvtpm: Additional LE support for tpm_ibmvtpm_send
++	commit 62dfd912ab3b5405b6fe72d0135c37e9648071f1
++
++Could not apply 6b610659f8b313644c0012a511c6381e9fe7d881... NEEDED net/mlx4_core: Maintain a persistent memory for mlx4 device
++	commit 872bf2fb69d90e3619befee842fc26db39d8e475
++
++Could not apply 7e9a6608ca11948dd0996b6db99e498ca043a0cd... NEEDED tools/power turbostat: support additional Broadwell model
++	commit 48a0631c891ab581cc010b44655ad49ff6eb3325
++
++Could not apply 9a9ab8a2348c722405964a0c785c4b2a613d8782... NEEDED KVM: Add generic support for dirty page logging
++	commit ba0513b5b8ffbcb0cc89e2f172c0bcb70497ba2e
++
++Could not apply 9a9ab8a2348c722405964a0c785c4b2a613d8782... NEEDED KVM: Add generic support for dirty page logging
++	commit 3b0f1d01e501792d8d89ab4371bc9e8cd2a10032
++
++Could not apply 0335b4283d02dcd6e7d6b54e175801099873852e... NEEDED KVM: VMX: Add PML support in VMX
++	commit 843e4330573cc5261ae260ce0b83dc570d8cdc05
+diff --git a/debian.master/info/RECONCILE b/debian.master/info/RECONCILE
+new file mode 100644
+index 0000000..0b90c95
+--- /dev/null
++++ b/debian.master/info/RECONCILE
+@@ -0,0 +1,506 @@
++=== total: 505 ignored: 55 (upstreamed: 49 reverted: 6) needed: 450 (debian: 298 ubuntu: 14 sauce: 138) ===
++3377e17d83c8ce29dc0128c9785043b630e283f3 IGNORE:IN:7486341a98f26857f383aec88ffa10950087c3a1 x86/platform, acpi: Bypass legacy PIC and PIT in ACPI hardware reduced mode
++e826d2f5ee447384828473c249ef38c08b72ffc1 IGNORE:IN:d474a4d365aaa5c7aabcf11a74ea43aa23f6f2e9 powercap / RAPL: handle domains with different energy units
++27ba48b7bec5dc0c9b665b334bbea30fdb44160a NEEDED:debian UBUNTU: [Config] add nvme to linux-virtual as this is now used in GCE to expose disks
++0788d51a2a8d794eb1c8394154028cb593be7ee7 NEEDED:debian UBUNTU: Ubuntu-3.19.0-10.10
++eb97881b6320d127b354b8cb03937504683a7f18 NEEDED HID: multitouch: Add support for button type usage
++554fc470460c6c4d94f202a8a73f24491bc9f0f7 NEEDED HID: multitouch: add support of clickpads
++e098a93f8c11db119261d5c4791d4f9c62c666e8 NEEDED:debian UBUNTU: fix up changelog for rebase
++c0b0bccbe70c7d602c114871d1e1ce42c478f6dc NEEDED:debian UBUNTU: rebase to v3.19.2
++9e086fc3fb3d7f09d4dacfccab0784812ef78764 NEEDED:debian UBUNTU: [Config] CONFIG_KVM_GENERIC_DIRTYLOG_READ_PROTECT=y
++0335b4283d02dcd6e7d6b54e175801099873852e NEEDED KVM: VMX: Add PML support in VMX
++9fa8950638aac15e1273204c9c76447524236345 IGNORE:IN:88178fd4f7187bbe290c5d373fd44aabec891934 KVM: x86: Add new dirty logging kvm_x86_ops for PML
++540b4deed1133b94ba9665ca1c5bdf692fc32c5b IGNORE:IN:1c91cad42366ce0799ca17e7ad6995418741d012 KVM: x86: Change parameter of kvm_mmu_slot_remove_write_access
++9cd0789cd13fe6ceb057b6ee0a9a8089e3d085d0 IGNORE:IN:9b51a63024bd759f97a12f50907b8af23b065b36 KVM: MMU: Explicitly set D-bit for writable spte.
++d06b40dc692080da03fd5fa3f19aa6c3d201cb38 IGNORE:IN:f4b4b1808690c37c7c703d43789c1988c5e7fdeb KVM: MMU: Add mmu help functions to support PML
++ec2347761088c13ec640886cb492e4d4f8aee759 NEEDED KVM: Rename kvm_arch_mmu_write_protect_pt_masked to be more generic for log dirty
++7b476333c9fd20d2be03eba64339df96a6d326d6 IGNORE:IN:e108ff2f8033a417ee3e517d9f8730f665646076 KVM: x86: switch to kvm_get_dirty_log_protect
++9a9ab8a2348c722405964a0c785c4b2a613d8782 NEEDED KVM: Add generic support for dirty page logging
++baddf7f579e3094b7b32c119fae9bb1b4ac557c5 IGNORE:IN:d91ffee9ec633c6523ef1ea39c36ace578760258 Optimize TLB flush in kvm_mmu_slot_remove_write_access.
++e824a2cfa15c76aefc09dcd0157ee31a565b2cb3 IGNORE:IN:7e71a59b250330fd52ee7293eb9d31952f16682e KVM: x86: flush TLB when D bit is manually changed.
++7e9a6608ca11948dd0996b6db99e498ca043a0cd NEEDED tools/power turbostat: support additional Broadwell model
++827aac896a47cdfbc19679d4e14dc269fd0ac846 IGNORE:IN:bea57077e44ec9c1e6d3a3c142c8a3c0289e290d intel_idle: support additional Broadwell model
++3057d6279a10157e6bd1ab7148ef4fc2ccb14d6d IGNORE:IN:3df76a9dcc74d5f012b94ea01ed6e7aaf8362c5a powerpc/pseries: Fix endian problems with LE migration
++dba28dfc35d65493b65d7d4bf382e09297ef9bb4 IGNORE:IN:4ad04e5987115ece5fa8a0cf1dc72fcd4707e33e powerpc/iommu: Remove IOMMU device references via bus notifier
++f9f283435213397957099d1a66a3a0d5bede3528 IGNORE:IN:5c65670c9bfa3be1234d29f36b742897c0360ef3 powerpc/perf/hv-24x7: Document sysfs event description entries
++179039e2ee295381d24a1832349100569ca96acb IGNORE:IN:97bf2640184f4fb2b2bf2c58ae3112768a6174fa powerpc/perf/hv-gpci: add the remaining gpci requests
++eb14eac49af21beac96d0933103b0e329ed4b2be IGNORE:IN:9e9f60108423f18a99c9cc93ef7f23490ecc709b powerpc/perf/{hv-gpci, hv-common}: generate requests with counters annotated
++23b8dd8e12de9f1268a1ecb18a1ec9d157444cfa IGNORE:IN:5c5cd7b502595f6b90509b8aa4bba6f81b69315c powerpc/perf/hv-24x7: parse catalog and populate sysfs with events
++0a72cae7a37a649fb997835c99a93711254210c9 IGNORE:IN:e08e52824e41fb42e46593450d378ad1b33caedb perf: define EVENT_DEFINE_RANGE_FORMAT_LITE helper
++06aa2a9afd745edcb3c3b80eec10c0cf6795cfc0 IGNORE:IN:f0405b816149665393cc62b9e5082fc2d79714df perf: add PMU_EVENT_ATTR_STRING() helper
++e38b3e25ccd090c3be55addc72746ffea85e26fd IGNORE:IN:fd979c0132074856975a6e79bc2226b99435ec5b perf: provide sysfs_show for struct perf_pmu_events_attr
++0512d012693ab7696fc390aa58e38623f774e8f0 IGNORE:IN:f9ab9c196d015f3bd8f6bd1c30785c5a49542323 perf tools: Document parameterized and symbolic events
++914c3ae025813d3868fddac5e7f63eef89a1f77c IGNORE:IN:98a43e0e9917059da32db89829b0eb95453a11ee perf Documentation: Add event parameters
++59c3fddc383e9d02e6ae04cbd9247d626f6acc90 IGNORE:IN:aaea36174991ff39c7a18044660db86527100c55 perf tools: Extend format_alias() to include event parameters
++7ee609fce3a1aa657c3613b985dc62f1a45acaf0 IGNORE:IN:688d4dfcdd624192cbf03c08402e444d1d11f294 perf tools: Support parsing parameterized events
++1d74db86f07ee680a466ae02b460e164aa58a38a NEEDED:debian UBUNTU: [Packaging] generate live watchdog blacklists
++6b5949d8cf32e576a5892472a7826545d94292a4 NEEDED:debian UBUNTU: Start new release
++a705b4e4855e7b484ed11831941fb7093a12d660 IGNORE:IN:285994a62c80f1d72c6924282bcb59608098d5ec arm64: Invalidate the TLB corresponding to intermediate page table levels
++fef4b02b6f20e9cbb50522916a4fd079ed821c07 IGNORE:IN:1b0eb5bc241354aa854671fdf02132d2d1452bdf thinkpad_acpi: support new BIOS version string pattern
++572a605fa5352dcb8a8cc982bbdb998f752aea07 NEEDED:debian UBUNTU: [Config] allow dracult to support initramfs as well
++727f017959487a34dd3c14659306b869545348a5 NEEDED:debian UBUNTU: [Packaging] control -- make element ordering deterministic
++6a501ec1a8e49e7b9869fed950bd1642dd1b68af NEEDED:debian UBUNTU: Ubuntu-3.19.0-9.9
++57165ece4262217e644bc0577bf9ccd5e452f2da NEEDED UBUNTU: SAUCE: IB/core: Prevent integer overflow in ib_umem_get address arithmetic
++4815357c48175b96d4bc67dfbd6c4fb30bb4d714 NEEDED:debian UBUNTU: Start new release
++03247c64299523710c3935227d1a7e28aeb34a97 NEEDED:debian UBUNTU: Ubuntu-3.19.0-8.8
++36ca906c4d4cf34bb5a750d1dbd3e4abe36a4684 NEEDED UBUNTU: SAUCE: (no-up): apparmor: fix mediation of fs unix sockets
++c34820ce1a87b536c2da84daf892e884de7f3067 IGNORE:IN:d0af71a3573f1217b140c60b66f1a9b335fb058b tg3: Hold tp->lock before calling tg3_halt() from tg3_init_one()
++420ed2b6622aa62d962e770422f887e38ede78ac IGNORE:IN:0cd9302734111abc0b5912b695336f2ee63cb22b net/mlx4_core: Reset flow activation upon SRIOV fatal command cases
++441e06e149e10acf3fa4497ae041f79f75a97c23 IGNORE:IN:55ad359225b2232b9b8f04a0dfa169bd3a7d86d2 net/mlx4_core: Enable device recovery flow with SRIOV
++6aa4bcac4501cbf723abbc1b49f22b113c7323f9 IGNORE:IN:2ba5fbd62b2534335f4e3b844ecc7860115525a3 net/mlx4_core: Handle AER flow properly
++a1b81382798563ef9092cad425cccc1e2fc2626e IGNORE:IN:c69453e294c9f16da977b68e658a8028b854c209 net/mlx4_core: Manage interface state for Reset flow cases
++da98e7467248aae377055c75b6380aa5f3f075ec IGNORE:IN:f5aef5aa35063f2b45c3605871cd525d0cb7fb7a net/mlx4_core: Activate reset flow upon fatal command cases
++9a583f4441d28f7b034a2eaaa3aeacdddc0ec65a IGNORE:IN:f6bc11e42646e661e699a5593cbd1e9dba7191d0 net/mlx4_core: Enhance the catas flow to support device reset
++5e52f6741b9fe61696f882effa83021eb013bb2e IGNORE:IN:ad9a0bf08ffbf32b8f292c3bb78ca0f24bb8f6b2 net/mlx4_core: Refactor the catas flow to work per device
++efee37c90fa0d7f1704ea59bcc47b8590b5cf7ca IGNORE:IN:dd0eefe3abbf47442db296bf68f27eb2860c1cdf net/mlx4_core: Set device configuration data to be persistent across reset
++6b610659f8b313644c0012a511c6381e9fe7d881 NEEDED net/mlx4_core: Maintain a persistent memory for mlx4 device
++7ec323466d993094545e140cc44559cb1cccbd14 NEEDED tpm/ibmvtpm: Additional LE support for tpm_ibmvtpm_send
++dd82e0b3366c0583f66daa1e6fd229e24468d615 IGNORE:IN:de61390cb3e03186f85997fe08a11dcb9f7a01a3 net/mlx5_core: Fix configuration of log_uar_page_sz
++aa391baed594091165eefe21e759f0604dd66c0a NEEDED:debian UBUNTU: rebase to stable v3.19.1
++7eaea45f7109a1e769d5379352e40b13e1b5d6d6 NEEDED:debian UBUNTU: Start new release
++a1ab7786a77235d3fe40ef93e239d26ad095f8c6 NEEDED:ubuntu-driver UBUNTU: ubuntu: vbox -- elide the new symlinks and reconstruct on clean:
++e9f926b44c895d39152d3f816ce9ff37780f77cb NEEDED xen: correct bug in p2m list initialization
++e253864af74e9fd0dbb79c6a1b9ab117d335a006 NEEDED:debian UBUNTU: Ubuntu-3.19.0-7.7
++da9ed9fbcffe22ad779cd0f9e63cae8125870f4c NEEDED:debian UBUNTU: Start new release
++a3efc506086bfc1770015e3a1545d708464dccbc IGNORE:IN:1b28f170d99170a1fdd22818a9610a73196b391d powerpc/eeh: Allow to set maximal frozen times
++d2616b0dfec986efcea32f5a7907bb67334fee40 IGNORE:IN:432227e9077eec13b3caf3aec6087f94a2f4327f powerpc/eeh: Introduce flag EEH_PE_REMOVED
++0d7adce37648ab16e146c07998c86f929933ced2 IGNORE:IN:3d5be0392f52489b7572903d83f1f267f26e6b69 cxl: Fail AFU initialisation if an invalid configuration record is found
++4406598cf9db984056879f543a1dbd0580589fc5 IGNORE:IN:b087e6190ddcd9ae4e8ff2c788d2b32f193e946b cxl: Export optional AFU configuration record in sysfs
++9810a8574ecb496bdb6805df46ef040889279489 IGNORE:IN:62fa19d4b4fd781ad37c9155c6332f28a9e97a2c cxl: Add ability to reset the card
++e0479a12aa4aceb678db96257318102e165127dc IGNORE:IN:1212aa1c8c9ca34642f7737e1edaa96c9ce3d7dd cxl: Enable CAPP recovery
++047163114be9cf5d4fd9ad368b6c0f8f18c177d8 IGNORE:IN:95bc11bcd1428afdb48400ec84dc6d5a83926138 cxl: Add image control to sysfs
++211238b75962ee2b4ddcb1648b94fd2d11464b64 IGNORE:IN:49fd644c3b0014fb80c2b1db7d8c86a75c4c6b1f cxl: Update CXL ABI documentation
++ef2cf73ffe825cb6e5350972edb6ef989f7c019b IGNORE:IN:9bcf28cdb28e6a793c4e59f0a42c66fe241993a8 cxl: Add tracepoints
++bb463fd6632c70d258c46e08a49dbd8ed90b6662 IGNORE:IN:d3383aaae9800b9e13e25b71f70dff3814d10373 cxl: remove redundant increment of hwirq
++50419f397e513bb53fd3a43953ddf97e344b1f9e IGNORE:IN:db7933f392ac4d9719d41d3f203a5f6a1c40f300 cxl: Disable SPAP register when freeing SPA
++1a4659245b032feb290aa890a831fe6db8cce677 IGNORE:IN:d6a6af2c181400aade59417e698c7cd9bec8804e cxl: Disable AFU debug flag
++9e024f9abf9a7bb11c8812ad8f4baac2542b41a4 IGNORE:IN:13da704682471669685ccc3fe111fd6c0127b2eb cxl: Early return from cxl_handle_fault for a shut down context
++b745d4388fd7f150d8c27239a107acc4769c3a55 IGNORE:IN:456295e284beb7b61a55ead9500d30f94ab06d52 cxl: Fix leaking interrupts if attach process fails
++aa79645da2c295c7a54a38d727ba5424c56e8c78 NEEDED:debian UBUNTU: Ubuntu-3.19.0-6.6
++2506464009b6efd8886841fd42aa35dd276e1ae2 NEEDED:ubuntu-driver UBUNTU: ubuntu: vbox -- update to 4.3.22-dfsg-1
++0af35a1df1616ee3af688b8f6811ea980b4ba105 NEEDED:debian UBUNTU: [Config] move vbox modules into linux-image
++591572a04b2929501bfd944f0e1b5dc918d905c2 NEEDED:debian UBUNTU: Disable module check for I2C_CHARDEV=y config change
++ded3e335312faf2066f1a293bc34612f20c7075a NEEDED:debian UBUNTU: [Config] I2C_CHARDEV=y
++6d41878ad435f83f107290bd47da1cae88a5960e NEEDED:debian UBUNTU: Start new release
++af9f67abe58ef01a0e38809dbf9dc9b579d6f729 NEEDED:debian UBUNTU: systemd -- fix hyper-v units to be non-forking
++e06b795ba62bfe38b378a77df6aa1f4e4b4be003 NEEDED:debian UBUNTU: SAUCE: DEP8 test to run our regression tests
++a651bfbc176a850449052a44a8f99cb298cb49f0 NEEDED:debian UBUNTU: Ubuntu-3.19.0-5.5
++65c15025855e39b160ced2bfd9cee0233e9eb5bd NEEDED:debian UBUNTU: rebase to v3.19 final
++00b14848d0ba3d47a244bbe142f4aec6abc6ad8a NEEDED:debian UBUNTU: Start new release
++e3963bddd383dbb567b6e9a3b6d1229b335be7c9 NEEDED:ubuntu-driver UBUNTU: ubuntu: vbox -- update to 4.3.20-dfsg-1ubuntu1
++5dde1b4a9a0dcbff893ba69c97bc8e9af5aeced4 NEEDED:ubuntu-driver UBUNTU: ubuntu: (no-squash) vbox -- infrastructure and updater
++4ac4ed6aaaabccd3113d12d2aae4227eeed2a94d NEEDED UBUNTU: SAUCE: ext4: disable ext4_punch_hole for indirect filesystems
++20f73500aa3c6973b662d434ea994a067d2732ce NEEDED:debian UBUNTU: [Config] Add ibmvfc to d-i
++27016d13d7def2d932edabe10cda08551eb76af4 NEEDED:debian UBUNTU: [Config] CONFIG_FA_DUMP=y
++043037877a7de2b8e6b2dff0420efe45ecff2ff5 NEEDED:debian UBUNTU: Ubuntu-3.19.0-4.4
++5dacd4f7dba5435e1b960bdc491293c82ee3ec2f NEEDED:debian UBUNTU: updateconfigs following rebase to v3.19-rc7
++9eade02480702c9670f2bac1bd55d38545a312cf NEEDED:debian UBUNTU: rebase to v3.19-rc7
++28f33eab58fbe7473e6ef7273c82f6b46108bd19 NEEDED:debian UBUNTU: Start new release
++113ccff71d64d15da62001f597421ead251c70a8 NEEDED:debian UBUNTU: hyper-v -- fix comment handing in /etc/network/interfaces
++2df9364c2056a3043e10cd5a62ce9706b2f7d1d1 NEEDED UBUNTU: SAUCE: rtsx_usb_ms: Use msleep_interruptible() in polling loop
++88065e99f0f6bcf3dc4631a2ceec2f2708af8cef NEEDED:debian UBUNTU: [Config] apply Kernel hacking >> Tracers config defaults
++0d569c89d78dfe8145fbeebe5249f794a9d0f552 NEEDED:debian UBUNTU: Ubuntu-3.19.0-3.3
++c0a8e98a3847348d78a54c944d202137d068b94d NEEDED:debian UBUNTU: annotations -- pull in updated annotations
++25a4fc67cec440d3bb4bc7705449df08e6c51858 NEEDED:debian UBUNTU: [Config] updateconfigs following rebase to v3.19-rc6
++7c37badc321d561bbd2f178669119c919ff20522 NEEDED:debian UBUNTU: rebase to v3.19-rc6
++4b617281c437581c70f6cf2334398bb1ab1c0340 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Mailbox Hardware Support config defaults
++32d6900d5dc2578bdb1627edfeed21e631a31e60 NEEDED:debian UBUNTU: [Config] apply General setup >> CPU/Task time and stats accounting >> Cputime accounting config defaults
++cd6b5ebc39722a4e376e47f1d48a0e46286ff308 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> SCSI device support >> SCSI device support >> SCSI low-level drivers config defaults
++c8a2a8aae37f1474453bea69acbf95c396227e31 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Real Time Clock config defaults
++a74fa91f9105e69fd2b101d914ab503ef67dd227 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Network device support >> Wireless LAN >> Intel Wireless WiFi Next Gen AGN - Wireless-N/Advanced-N/Ultimate-N (iwlwifi) config defaults
++fe8ce4f67a26106dab3193b3515fe865e136ab4a NEEDED UBUNTU: SAUCE: arm64 -- psci tell the compiler which registers we are needing values in
++2f02ebe61ad44b1175700cc78a3ccd94bb07ff06 NEEDED:debian UBUNTU: [Packaging] force "dpkg-source -I -i" behavior
++5a6bf13232cd325e73e6ebae516cac9b0da4421c NEEDED:debian UBUNTU: [Config] apply General setup >> Timers subsystem >> Timer tick handling config defaults
++d3d0add00f0801e6823242d1c7bd41c990eb05bb NEEDED:debian UBUNTU: [Config] apply Kernel hacking >> Kernel debugging config defaults
++3b255c82446a97f59e59adb3bd320df4550c1381 NEEDED:debian UBUNTU: [Config] apply Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IPv6: Netfilter Configuration >> IPv6 NAT config defaults
++3549c0af6717159aa8a3b77864dde9b341476b1b NEEDED:debian UBUNTU: [Config] apply Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> IP: Netfilter Configuration >> IPv4 NAT config defaults
++76fb94fa938323cea755f08923c1699f857849a4 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Pulse-Width Modulation (PWM) Support config defaults
++91aa3e3c5f375fcda9802e0bf30743388db97809 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Mice config defaults
++7e28f1d5b0f539c2f315248d638d322cc1bed204 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Keyboards config defaults
++83d976c317bc7939457ba2b194ca9b20942b08e8 NEEDED:debian UBUNTU: [Config] apply Networking support >> Wireless >> Generic IEEE 802.11 Networking Stack (mac80211) config defaults
++a6ff3e7b7835019303b4df16c7d34e83f7bc432f NEEDED:debian UBUNTU: [Config] apply Networking support >> Networking options >> TCP/IP networking config defaults
++fff6ce5d257e3a55676ab2f32f7174648b48bd4d NEEDED:debian UBUNTU: [Config] apply Networking support >> Networking options >> QoS and/or fair queueing >> Actions config defaults
++3db2706fa00266f41b26ac6156b92cc92013c4b6 NEEDED:debian UBUNTU: [Config] apply Networking support >> Networking options >> Network packet filtering framework (Netfilter) >> Core Netfilter Configuration >> Netfilter nf_tables support config defaults
++d379025cb43c73ba0ba6b1e9ae7030ef3706acbb NEEDED:debian UBUNTU: [Config] apply Networking support >> NFC subsystem support >> Near Field Communication (NFC) devices config defaults
++d682b0866fdab7676efc02d7aca31ffba5af5ba9 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> USB support >> USB Gadget Support >> USB Peripheral Controller config defaults
++cc6d21036b39e6747f35992743390b46f490ef71 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> USB support >> USB Gadget Support >> USB Gadget Drivers >> USB functions configurable through configfs config defaults
++f38ce7164ddb54b46a19ed6e3640d5e21f968aff NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Staging drivers >> Media staging drivers config defaults
++f2e32d3fe36a5af721325ad09244872f55783932 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Staging drivers >> Lustre file system client support config defaults
++3fa3a6e3f9bc72ccf4050d5278d82c4f18fa614c NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> HD-Audio config defaults
++7483bb4ddb3800421bf67db6f57e9a2ad68aede9 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> FireWire sound devices config defaults
++bb035568140e5726260cbffc40900186503e066e NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Sound card support >> Advanced Linux Sound Architecture >> ALSA for SoC audio support config defaults
++5857964914cdeedb945ef65490afa1353f0e7d06 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> SPI support config defaults
++67356ed062d29becaaf27108aa8737fee13cab69 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Pin controllers config defaults
++fdab45aa9ebd2c87af7ad88b62c557a9ddaf06eb NEEDED:debian UBUNTU: [Config] apply Device Drivers >> PHY Subsystem config defaults
++be26a7664fe53b25132a1570e7cb572cdfaf8f03 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Network device support >> Wireless LAN >> Intel PRO/Wireless 2200BG and 2915ABG Network Connection config defaults
++664ad4582ac5f69f585defe21f75a44efdc5def9 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Network device support >> Wireless LAN >> Hermes chipset 802.11b support (Orinoco/Prism2/Symbol) config defaults
++7abff1caa5b128105a095b294a4084d58eb4208a NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Network device support >> Network core driver support config defaults
++b85516a587125164e4fb6f40a937687859484278 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Network device support >> Distributed Switch Architecture drivers config defaults
++6eeec6ead3c181f9d305a5139a2af09ab02d25e2 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Multimedia support >> Remote Controller devices config defaults
++9bf5422ec87618ea0a9c158e2ee3ea763769635e NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Multimedia support >> Media PCI Adapters config defaults
++0062486c5f49ca81ce44c08483793cd28bd55d4e NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Multimedia support >> Cameras/video grabbers support >> Media test drivers config defaults
++a3cab812b888b76a1c6188d51837461f82579107 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Multifunction device drivers config defaults
++efce9b94895b00d4246281051a6f57abd556b593 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> MMC/SD/SDIO card support config defaults
++ba5f91a1915102862b13b8c73223662536b6ff51 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> LED Support >> LED Class Support config defaults
++5a655a22455c44e92b820d86de5f1eff080d44a1 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Touchscreens config defaults
++2dc2403265124b82af4a57da628cb21bafbab54a NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Input device support >> Generic input layer (needed for keyboard, mouse, ...) >> Mice config defaults
++9fe17395d411adbcfb323c915f84ea85f4c48ce8 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Industrial I/O support >> Pressure sensors config defaults
++5e7b068f32db503c6eb371a23ae2c2a16749578f NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Industrial I/O support >> Humidity sensors config defaults
++20e5409f0457d28d2abca5ef7c1630dc22d84813 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Industrial I/O support >> Analog to digital converters config defaults
++7ae44769248078c8d1ba362fcf3de16b8ab681ab NEEDED:debian UBUNTU: [Config] apply Device Drivers >> I2C support >> I2C support >> I2C Hardware Bus support config defaults
++581c6acbf122138da27108c2a13098d6815349df NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Hardware Monitoring support config defaults
++2e33cbcfe6451f61ae18aeec37fe1753d0a52cc2 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> HID support >> HID bus support >> Special HID drivers config defaults
++02139708b965f07a499593f9036750c30fbe6454 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Graphics support >> Frame buffer Devices >> Support for frame buffer devices config defaults
++a86fe195e825e37e694a5960f7af6ddfbf9f3673 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Graphics support >> Direct Rendering Manager >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI support) config defaults
++0d10ef98e5bb7c1fb144139e54e13d0051d6f5e4 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> GPIO Support config defaults
++0c423ad9c578e7596de1409cbfd2db4d5b988cd2 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Character devices >> Serial drivers config defaults
++58007d9583eaf94442bcaf472d4e69c8dc24cf61 NEEDED:debian UBUNTU: [Config] apply Device Drivers >> Character devices >> IPMI top-level message handler config defaults
++429394f5a6c855973e6027edbf8811d94f2e54d7 NEEDED:debian UBUNTU: [Config] Disable CONFIG_USB_OTG
++7676b5cebdfe24bebfe402c85ce7d232f76fe756 NEEDED:debian UBUNTU: [Config] CONFIG_DEBUG_INFO_SPLIT=n
++66857d56aa24e2eff079df005f0d189060d68645 NEEDED:debian UBUNTU: [Config] annotations: clean up CONFIG_FW_LOADER_USER_HELPER_FALLBACK and associates
++17fde7fa97d8da20c499e37ff9615895623adb8e NEEDED:debian UBUNTU: annotations: add new v3.19-rc5 options (and some returning options)
++3fd5011f880877a583b1ccefd06ad481452cdef7 NEEDED overlay: add backwards compatible overlayfs format support (fixes)
++7c3d7c6d8df09db4b2f6be809434232021d9305f NEEDED:debian UBUNTU: [Packaging] hyper-v -- daemons now require -n for non-forking startup
++e3defbff069c0d1afa9c30ecdb2cfbd3776c16eb NEEDED:debian UBUNTU: [Config] enforce CONFIG_FHANDLE=y
++b4d80bddacd59441e76e4f4b750154f1a95736a6 NEEDED:debian UBUNTU: annotations -- reorder pass
++ed8c877b843aeaa7fe38947d0bdbf15ef9405f27 NEEDED:debian UBUNTU: [Config] updateconfigs following rebase to v3.19-rc5
++9dd6f68702869ea7ee4219aeeba148bd11e9e211 NEEDED:debian UBUNTU: [Config] add modules removed due to tighter dependencies
++c3d1971989ed55f56aaa0bd882611d8c228cbc05 NEEDED:debian UBUNTU: rebase to v3.19-rc5
++07d995fd618003c3e4663f2e58b73318fa442c32 NEEDED:debian UBUNTU: Start new release
++610b443e33e236074875db94a42ed8d8190951f6 NEEDED:debian UBUNTU: [Packaging] enforce -- drop empty enforce file
++1dd97225d642eaa32460873d90a53c58aa11e243 NEEDED:debian UBUNTU: [Packaging] config-check -- drop support for enforce file
++129becf2ef8faffe61100ef5f6435d3bd396265c NEEDED:debian UBUNTU: [Config] annotations -- switch to ENFORCED annotations
++561c8f3a1941d2895a150b5780def64b5b8fa5b4 NEEDED:debian UBUNTU: [Packaging] config-check -- add support for enforced annotations
++33ea0bf33a842aa5d8f826f3be477a7b1fd7b8fa NEEDED:debian UBUNTU: annotations -- full v3.17/v3.18/v3.19 review pass
++eee1ca9895f0a19241010cea3ef7b5c87bbc3cc9 NEEDED:debian UBUNTU: annotations -- reorder to vivid menu layout
++57ccd817353c91a6b5ed620db15e86315251e1a9 NEEDED:debian UBUNTU: annotations -- utopic base
++5a62a2f9705b70bdf6a1a0870d15903016411c5c NEEDED UBUNTU: [Debian] arm64 -- build ubuntu drivers
++a58e808c17a895c7c3698bee63172114790a6d88 NEEDED:debian UBUNTU: Ubuntu-3.19.0-2.2
++d8db9694361b258427eab1846b211be332c4a1f9 NEEDED UBUNTU: SAUCE: efi: Expose underlying UEFI firmware platform size to userland
++c0b5915ac61b6c49e27fecf6ba8f62cc2d17297b NEEDED:debian UBUNTU: add missing buglink in unreleased versions
++80ac0a8626c33921522e59e258a0bcee0fac6620 NEEDED:debian UBUNTU: [Config] switch on "all" dtbs
++f5c5c728204613d98677cecfa499451a43c316d9 NEEDED:debian UBUNTU: [Packaging] install all dtb files
++4594c0a5b120fc92fb141c1cf9eef3e8d665e4e6 NEEDED UBUNTU: SAUCE: storvsc: force SPC-3 compliance on win8 and win8 r2 hosts
++2db975f991de109cb558a88b821aee4ab32294b9 NEEDED:debian UBUNTU: [Config] updateconfigs following rebase to v3.19-rc4
++efda5ea3e72181c54313960c4eb623cb9bf70184 NEEDED:debian UBUNTU: rebase to v3.19-rc4
++3ceca000c3f419e4ea82d5cc89b17788311e066a NEEDED:debian UBUNTU: [Config] Enable CONFIG_N_GSM as module.
++6d976353cda7b65cd3bccc025fd676a2b60be71e NEEDED UBUNTU: SAUCE: drivers/rtc/interface.c: ignore exprired times when enqueing new timers
++c2b14cbdd9db02c941b1a201ea7de7cbefd042a5 NEEDED:debian UBUNTU: Start new release
++7e4ee90affaec9dfd96c8c527e410e37e60e7cdd NEEDED:debian UBUNTU: Ubuntu-3.19.0-1.1
++07d5adb10aa7995e36b1c3fb063b1db97e0744bb NEEDED:debian UBUNTU: [Config] follow move of arm64 dts' into vendor directories
++c73a0ec29f0772426f60c0e5e4c660a5f49c2963 NEEDED:debian UBUNTU: [Packaging] handle dts directories
++c8f77b2dd48cc6a6bcce49411b546aefa08c799c NEEDED:debian UBUNTU: [Packaging] uploadnum should be the remainder of the version
++50a8041a37110aa8867a493b624aa6bf409acb93 NEEDED:debian UBUNTU: [Configs] updateconfigs following rebase to v3.19-rc3
++afa910e643c7b399c3cdd8312d84b65d1c64d197 NEEDED:debian UBUNTU: rebase to v3.19-rc3
++732f3e48b565abe6e7fd7f489edb3bc88e68581c NEEDED:debian UBUNTU: v3.19 series start
++ea0064b7d9878d01ec4653e528c9b998b4ae10b5 NEEDED:debian UBUNTU: [Configs] updateconfigs following aufs update
++13055ff9195392d6f1d8cc9065079147efd15b2e NEEDED:ubuntu-driver UBUNTU: ubuntu: AUFS -- update to 92ad9cc8bd289bf8e59b6bd8d83137d8e1a58c1c
++3df26820282895c299dffb25972f584721ea75c1 NEEDED:ubuntu-driver UBUNTU: ubuntu: AUFS -- substrate: aufs3-standalone.patch
++b9579ed6992d02cd55e4d94a13be89c32ce84ff5 NEEDED:ubuntu-driver UBUNTU: ubuntu: AUFS -- substrate: aufs3-mmap.patch
++b39b7e7301c7723004985b773bcfb74fbfb4eabb NEEDED:ubuntu-driver UBUNTU: ubuntu: AUFS -- substrate: aufs3-base.patch
++e08ec9211daa19f663ab406848b5df2271eac1d4 IGNORE:revert Revert "UBUNTU: SAUCE: AUFS -- aufs3-base.patch"
++4a9009a9ae4027ec12dd6313fd18a8bb56bf4918 IGNORE:revert Revert "UBUNTU: SAUCE: AUFS -- aufs3-mmap.patch"
++6ae8ad7291b70e01d11bf753e5e79d5b5aeee7fb IGNORE:revert Revert "UBUNTU: SAUCE: AUFS -- aufs3-standalone.patch"
++241d2270754f4ab7d90d52324a7c8a85be88aca7 NEEDED:debian UBUNTU: disable module checks for rebase
++9defa41f9126d026cd6a1ead03e6443e98e97108 NEEDED UBUNTU: apparmor -- follow change to this_cpu_ptr
++caae90a5781f1d312b91fe44839c56009f2e0eb3 NEEDED:ubuntu-driver UBUNTU: ubuntu: aufs3 -- follow rename for d_alias
++401119f392cb5bd61918659f9a20ab2ae54934e7 NEEDED:ubuntu-driver UBUNTU: ubuntu: aufs3 -- follow switch to get_unused_fd_flags()
++78df37e096365062f950d01f27dacf143ba57276 NEEDED:ubuntu-driver UBUNTU: ubuntu: aufs3 -- follow switch to d_splice_alias
++ca8d1a7503192dd5b9c1197eae4ea6be8f36ae81 NEEDED:ubuntu-driver UBUNTU: ubuntu: aufs3 -- follow rename of d_child
++388a35e8069f8657310c7f00d9062989da94b49d NEEDED:debian UBUNTU: [Config] defaultconfigs following rebase to v3.19-rc2
++e08b74c9afcc53d50a3c8ebe43e3b8cb60f2aa61 NEEDED:debian UBUNTU: rebase to v3.19-rc2
++a8d99914420de484583f3ef7327d603cce40fd3a NEEDED:debian UBUNTU: rebase to v3.19-rc1
++0373477d240b8de65a1b6f8596f1b55e61eb7871 NEEDED:ubuntu-driver UBUNTU: ubuntu: AUFS3 -- follow switch to vfs_fallocate
++817e01310fbcc1932419860833d9bba41e8d21a9 NEEDED:debian UBUNTU: Start new release
++685154a8fd43a024cc3f671d85c36158717c0f0c NEEDED arm64: optimized copy_to_user and copy_from_user assembly code
++980f00986e35f630c7bb18065836e3b2f518f7a2 NEEDED:debian UBUNTU: Ubuntu-3.18.0-7.8
++eef49554443cc3c5bf71b7f5aa500dce3ab3e0d0 NEEDED:debian UBUNTU: [config] set apparmor config options
++8a91a5705046dca1c9972ce2a76714edc837e367 NEEDED UBUNTU: SAUCE: (no-up) apparmor: add parameter to control whether policy hashing is used
++e1b6a4b88bdb9cf858e068d0e3a6b7449d648513 NEEDED UBUNTU: SAUCE: (no-up) fix: bad unix_addr_fs macro
++892b8b7cfb14b9bdfbc9ac2fee8e751a67707542 NEEDED UBUNTU: SAUCE: Revert: fix: only allow a single threaded process to ...
++98c64db6cffd59a894d4a4492aea761fa6e6c51a NEEDED UBUNTU: SAUCE: (no-up) apparmor: Sync to apparmor3 - RC1 snapshot
++178a99413c26c359c7ea63c23b70c14238c72c9e NEEDED:debian UBUNTU: [Config] CONFIG_FW_LOADER_USER_HELPER_FALLBACK=n
++0e7cd75372d106d02b3f03f9a2e6496782e39102 NEEDED:debian UBUNTU: Start new release
++354c399098d730724d47572411db3966640b886d NEEDED:debian UBUNTU: Ubuntu-3.18.0-6.7
++70f41850210ae054ddddd3cdb3c8c6b80d26fef9 NEEDED:debian UBUNTU: [Config] CONFIG_PCIEASPM_DEBUG=y
++69d6e475d4b184e691fde6bb6173b0b2a78f95ee NEEDED:debian UBUNTU: [Config] armhf: VIRTIO_[BALLOON|MMIO]=y
++e7248dea9798e37ed9136c0234e60c5d3724a09a NEEDED:debian UBUNTU: rebase to v3.18
++c08cb8bf95c2175a3c0d3916a3a95bb865516303 NEEDED:debian UBUNTU: Start new release
++5de9e13b14877580032ab92fb008417493ad5ab6 NEEDED:debian UBUNTU: Ubuntu-3.18.0-5.6
++f0c21c519145ef0374be78d7f3562691dae45800 NEEDED:debian UBUNTU: rebase to v3.18-rc7
++e74900777be8a73fd3d07669414bd103c385d2ce NEEDED:debian UBUNTU: [Config] CONFIG_SCSI_MQ_DEFAULT=n
++58dfe08f9155f1821f7a0659bcb9c869d4e5ac73 NEEDED:debian UBUNTU: Start new release
++10dd9a851640f6ab60c78594bbff79d76dbb2488 NEEDED:debian UBUNTU: [Config] CONFIG_SCOM_DEBUGFS=y for powerpc/powerpc64-smp ppc64el/generic
++9b1c8ecc6c86e71fab6d15bd84bd1628aae6cd2e NEEDED:debian UBUNTU: Ubuntu-3.18.0-4.5
++ea3282297f6f3af23009d7a400b35b73c3c10ac8 NEEDED:debian UBUNTU: [Config] enable overlayfs v1 support
++ff7e37255afb5b57b5e378e7aef2b4935cc3eb0f NEEDED overlay: add backwards compatible overlayfs format support
++47897ce32d62ea9af685c2a4b06734e76fbfcb1d NEEDED:debian UBUNTU: [Config] update configs following rebase to v3.18-rc6
++b9de0aaa58a863d277ac6141018e82d619d0a89c NEEDED:debian UBUNTU: rebase to v3.18-rc6
++f8bae137b946111d88cfd59cdb3501abc6072f7d NEEDED:debian UBUNTU: rebase to v3.18-rc5
++4550c44494ed6064b56dc746c1ca59cc42571292 NEEDED:debian UBUNTU: Start new release
++cb37df61a5a331fe0bf87d467f6938149b7be5f5 NEEDED:debian UBUNTU: Ubuntu-3.18.0-3.4
++394645d92e939afd7bad1e13d07367d8c077fe12 NEEDED UBUNTU: SAUCE: AUFS (no-squash): basic framework and update machinary -- part 2
++3a53bed921a6d5c0fb30fc8e02a06105fad9dcf7 NEEDED:debian UBUNTU: Ubuntu-3.18.0-3.3
++156d0481e2abded21be8e0a516f952d13cfd0ff5 NEEDED:debian UBUNTU: [Config] updateconfigs following aufs3 update
++4f0421c01639daf81bf6ccb3d5f4b8ff75e4552f NEEDED:ubuntu-driver UBUNTU: ubuntu: AUFS -- update to 9d5c349d5c452170b8e813d86956f896a0aef170
++6051ec34d1dbdcb54e4d8c5a9f2161793f85c99d IGNORE:reverted UBUNTU: SAUCE: AUFS -- aufs3-standalone.patch
++d85f1f5fbc58b6f338ed6172f1b281cf7d6cd638 IGNORE:reverted UBUNTU: SAUCE: AUFS -- aufs3-mmap.patch
++29946e18ae75d3ded766003caec2a3677a07a83f IGNORE:reverted UBUNTU: SAUCE: AUFS -- aufs3-base.patch
++57f696f01845322cb8c68804524bdd41a2ad1146 NEEDED:debian UBUNTU: rebase to v3.18-rc4
++11048583c75d357f740d6d2ba6b2285f2657d93f NEEDED:debian UBUNTU: [Config] Disable CONFIG_RCU_USER_QS on arm64
++a20ed54dbbda43450ec3bf5d3db536e2a9ef9000 NEEDED:debian UBUNTU: [Config] disable CONFIG_ARM64_RANDOMIZE_TEXT_OFFSET
++d2dfee2ba64140dc875aa2de2db76326021cd349 NEEDED:debian UBUNTU: [Debian] basic hook support
++696ca2c9a87c9da383d1d0475cc4699e81cf67ba NEEDED:debian UBUNTU: [Config] amd64 is now the indep architecture
++f500e7dcda3dfecfa2175847ba31bf8dd5470ce0 NEEDED:debian UBUNTU: [Config] Disable CONFIG_IPMI_SI_PROBE_DEFAULTS on armhf and arm64
++baf3a88eca0a927579ba1f6cf805c2b49f7b8165 NEEDED:debian UBUNTU: Start new release
++c72e2fb77e36121ff538fe2b6a21354128cd8194 NEEDED:debian UBUNTU: Ubuntu-3.18.0-2.2
++714d582bfcfdb5091e472a15d2b1c4ab74383756 NEEDED:debian UBUNTU: rebase to v3.18-rc3
++68ed89d5098ecb26c3cf2ce31a197b60147accd9 NEEDED:debian UBUNTU: Start new release
++9ba3dda425ca839667062942e93529e75382531a NEEDED:debian UBUNTU: Ubuntu-3.18.0-1.1
++76d6207803e1b92f419126d507d5e790738bb580 NEEDED:debian UBUNTU: [Debian] install usbipd
++2a878f46cd018c9cb2e3f6a9bf436238522e4799 NEEDED:debian UBUNTU: [Config] armhf: disable JUMP_LABEL
++994e6de3dd2affbd3ec963597d7d8af8990627e7 NEEDED:debian UBUNTU: [Config] CONFIG_DRM_BOCHS=n
++0f87fe85382c852b2d5faf7d8b94fa994ae00461 NEEDED:debian UBUNTU: [Config] enable cloud tools on i386
++3aab9a4865e735ffc6aa1979e4d32929da66e317 NEEDED:debian UBUNTU: [Config] CONFIG_PATA_MACIO=y
++f54e18bd24b7362841b1902c1a0804bc1dd12e2d NEEDED:debian UBUNTU: [Config] linux-image-extra postrm is not needed on purge
++be3df8ea980f12fac4ed6e27c5948dc13c25c9d2 NEEDED:debian UBUNTU: [Config] linux-image-extra is additive to linux-image
++809a654eb28d8127dc89dd89d679d44aad7e4cd6 NEEDED:debian UBUNTU: [Config] Added drivers/uio to generic inclusion list
++bc189702109182682081057777e98beaff1200cc NEEDED:debian UBUNTU: [Config] dropped scsi_tgt from generic inclusion list
++2ac80c0acfef71084a8072d792534e3b2617bee9 NEEDED:debian UBUNTU: CONFIG_MODULE_COMPRESS=n
++f7103d518249e744a5c0aa004aca24a1f7d57706 NEEDED:debian UBUNTU: [Debian] Fix linux-doc dangling symlinks
++ba30c7ba905e7f8cc776669e07c2e0a770b1aabf NEEDED:debian UBUNTU: rebase to v3.18-rc2
++0f81052c41fb44d865aa1fdcaf349bd35b097a6f NEEDED:debian UBUNTU: [Config] CONFIG_SOUND_OSS_CORE_PRECLAIM=n
++99f88d003b04a94cdffb06292a131e4c9eaacb10 NEEDED:debian UBUNTU: Enable vivid
++816874fb757dc85e42d20af922290d6d55cf9fac NEEDED:split-debian UBUNTU: rebase to v3.18-rc1
++5774f4dab5e36642e243e03837f63e68c93dfacf NEEDED:debian UBUNTU: rebase to v3.17
++dbabd921800e97ff2a708b068f772ca1182157bc NEEDED:debian UBUNTU: [Config] CONFIG_HOTPLUG_PCI_PCIE=n for ppc64el
++59c659ef34502c3c6b5a0e8490bac9c7ffa9e042 NEEDED:debian UBUNTU: rebase to v3.17-rc7
++431e93cbc6a563ae15b4877810beb1b9f4edd976 NEEDED:debian UBUNTU: [Debian] Don't fail if a symlink already exists
++0794c4f5d47196aaa1c774fcaa2ef81bd7214141 NEEDED:debian UBUNTU: [Config] CONFIG_HOTPLUG_PCI_SHPC=n for ppc64el
++4790317b5007565da1299b35578135011bd9c6e9 NEEDED:debian UBUNTU: [Config] CONFIG_SND_HDA_INTEL=n for ppc64el
++e7971f95deafcac1b3f524645a68fe915344845d NEEDED:debian UBUNTU: [Config] Correct annotation regarding CONFIG_DMA_CMA
++f2d29260d449d918c5885aa6abc182dade506257 NEEDED:debian UBUNTU: [Config] CONFIG_CRASH_DUMP=n for powerpc-smp
++56a2eb988714b6a0bb0f6c0da9a313a8f439291e NEEDED:debian UBUNTU: [Config] Enable usbip tools
++dc7084c88863a69e70e90265485b6b51c01ccbad NEEDED:debian UBUNTU: [Debian] usbip tools packaging
++40504c7e778f0ad9f19180a39ddd9018910c705a NEEDED UBUNTU: SAUCE: usbip: Update include path
++122f035765feacfa15b09515c78af28f7092877c NEEDED:debian UBUNTU: rebase to v3.17-rc6
++d7be42a7599c483c2294e1122d9c4d5f0d347321 NEEDED:debian UBUNTU: [Config] CONFIG_USB_OHCI_HCD_PCI=y
++dd1e6e6bf5f6ffcd1436ad3fbe32c93da7a5ff30 NEEDED:debian UBUNTU: [Config] follow rename of DEB_BUILD_PROFILES
++dee5d182c3b180973d3a6fab11ac30af4513559b NEEDED:debian UBUNTU: [Config] tools -- only build common tools when enabled
++782d85880d33461406f5a288942e6dcc11770e47 NEEDED:debian UBUNTU: [Debian] set do_*_tools after stage1 or bootstrap is determined
++5b118bbb3a38dc3e5be0d5c921603f672fe1ab4c NEEDED:debian UBUNTU: [Config] Add mpt3sas to d-i
++6afad884eeffc67a53e5d11ffe61c9e40b64d26a NEEDED:debian UBUNTU: [Config] CONFIG_DMA_CMA=n
++aa4e526d8be91b593cd6d0a0e4ab949d26541fa0 NEEDED:debian UBUNTU: [Config] CONFIG_KVM_BOOK3S_64_HV=m
++519ac1677b339775493fc2a4cff55d9e54c28ce7 NEEDED:debian UBUNTU: [Config] CONFIG_KVM_BOOK3S_64=m for ppc64el
++dc9bcbd1592cfede67a2c5ccb5c59f26f0589260 NEEDED:debian UBUNTU: [Config] CONFIG_XMON=y
++e9173466e3323cb9c78cdc807c72e6838f5d7119 NEEDED:debian UBUNTU: [Config] armhf: USB_[E|O]HCI_EXYNOS=y
++4377933f12fbcb31006f23d0117d8a0d164adb80 NEEDED:debian UBUNTU: rebase to v3.17-rc5
++2d172824498ca976ec7e37ec373a248d49a0d5cc NEEDED:debian UBUNTU: rebase to v3.17-rc4
++6980242f0ab61eca03c77142ad4000fadfa022f7 NEEDED:debian UBUNTU: rebase to v3.17-rc3
++72e421db34ebf1bbe15649de2ab2132970f21872 NEEDED:debian UBUNTU: [Config] arm/tegra/d-i: framebuffer and usb support for Tegra SoCs
++3cf410f0b6b36de437c55e319bde033fe75cdb28 NEEDED:debian UBUNTU: [Config] Add arm64 to enforcer CONFIG_CC_STACKPROTECTOR
++e332b2967797d421575080f7b872c7b675e47629 NEEDED:debian UBUNTU: [Config] armhf: REGULATOR_TWL4030=y
++c37acf9c89fae66506d9875bdf758a5fee0233ed NEEDED:debian UBUNTU: [Config] Added net/6lowpan/* to generic inclusion list
++4dd073455ec2c021accdd97ee82b8091b17ea7b7 NEEDED:debian UBUNTU: [Config] CONFIG_NFC_ST21NFCB=n
++abc7908d4c71425c16718d40bbbea1515bc39204 NEEDED:debian UBUNTU: updateconfigs
++e09aab2c0d195125f71b50cdff0a858983953609 NEEDED:debian UBUNTU: rebase to v3.17-rc2
++9d32d8b674a700e342c5559d8e09e9590785d40a NEEDED:debian UBUNTU: Start new release
++18ffc6ce8fa107ac99b52f69a8107511c9d560c5 NEEDED:debian UBUNTU: Ubuntu-3.16.0-11.16
++06f6d00b1c7ae75b5988b2ef922cdd8308edacd1 NEEDED:debian UBUNTU: [Config] CONFIG_ZPOOL=y
++7cc84cf61b760725973c93b9c7e39d6f521bfe62 NEEDED Revert "net/mlx4_en: Fix bad use of dev_id"
++6ffe8179fc951ea6d1886f28b0742eb2744f033c NEEDED:debian UBUNTU: Bump ABI
++cc21629a6a5f6a3efdaf91b320508479af69e1fa NEEDED:debian UBUNTU: Start new release
++d1a2628d426406b61d1d46747da2815e7995d3c9 NEEDED:debian UBUNTU: Ubuntu-3.16.0-10.15
++90b44b74910b3c5e86cb05cfde5f67fee0ef2b75 NEEDED UBUNTU: SAUCE: bcache: prevent crash on changing writeback_running
++e3102a21978dd9c109856a48cd84837e708b7b29 NEEDED:debian UBUNTU: [Config] CONFIG_SENSORS_IBMPOWERNV=m
++2819061858516119133b736fdfa0c11d23cceccc NEEDED:debian UBUNTU: [Config] CONFIG_SECURITY_NETWORK_XFRM=y
++a30185ef8f2fa9dd925cf8b99399a72bc308a397 NEEDED:debian UBUNTU: [Config] CONFIG_XFRM_STATISTICS=y
++9d4a441eb46227e80b77e99ef15a4248ba2ddfcd NEEDED UBUNTU: SAUCE: (no-up) arm64: dts: Add PMU node for APM X-Gene Storm SOC
++e7e22f86dfc3e11d8f6eab08074ebb610a20c5ab NEEDED UBUNTU: SAUCE: (no-up) dt-bindings: Add Potenza PMU binding
++5ed1bfbfcc717aead960bf74940328285d3bf957 NEEDED:debian UBUNTU: [debian] Fix regression with ABI subversions and backport
++62f12ae8d9c08cc6496b60b330350a4dfcbca77f NEEDED:debian UBUNTU: Start new release
++ab212af17f1b9eaa43bffde42440598079044839 NEEDED:debian UBUNTU: Ubuntu-3.16.0-9.14
++c8a4d4970d0835d19ff2acd700d0ae94b877b3e7 NEEDED UBUNTU: SAUCE: Overlayfs: allow unprivileged mounts
++38d659d55bb8fab6f71934dd969a1ba8badeed79 NEEDED:debian UBUNTU: rebase to v3.16.1
++aefca49c0717ac60ba231a3b2e0cb62f0937113c NEEDED:debian UBUNTU: Start new release
++a9dc14c5056a82cfd44e3b098b252e52fe0b6925 NEEDED:debian UBUNTU: Ubuntu-3.16.0-8.13
++ab4880f5e96efda31c6b52136704c9eb0ccab87b NEEDED:debian UBUNTU: [debian] Allow for package revisions condusive for branching
++981bed5cd793ef69ac7377e9cbb6375ce70351f6 NEEDED:debian UBUNTU: Start new release
++74a7d62985f35ddef973776c3e31ff256f4a5859 NEEDED:debian UBUNTU: Ubuntu-3.16.0-7.12
++aeaada62d9efea9463bbcfc2a6549d18f023cdd5 NEEDED:debian UBUNTU: [Config] Add hv_balloon to d-i virtio-modules
++035036c87c216bfbb44109c963375f5f20dc05a1 NEEDED:debian UBUNTU: [Config] d-i -- add virtio_scsi to virtio-modules
++62317e97c6bbb5d8043e1fc3e26df6b905325c4c NEEDED:debian UBUNTU: rebase to v3.16 final
++250eb531089a04b95b698be6524ce4edbe15ddc5 NEEDED:debian UBUNTU: [Packaging] Fix 'printchanges' to work with versions containing '+'
++53647a9928a35d01e9f1b59c5d7b96ad3353048a NEEDED:debian UBUNTU: [Config] CONFIG_CONTEXT_TRACKING_FORCE=n
++e1b2b4a99edece7053725bc318f7f58e53767692 NEEDED:debian UBUNTU: [Config] CONFIG_MICROCODE=y
++a1f57fea081dbab4be712029e9b64c60d61935a0 NEEDED:debian UBUNTU: Start new release
++b342b70677fb9741dd3dc137f45e5ce3181223e9 NEEDED:debian UBUNTU: Ubuntu-3.16.0-6.11
++f0c937317763b38820a72a6b02b1fdb0ad9d285d NEEDED:debian UBUNTU: rebase to v3.16-rc7
++d4d6d5fc58a66d37821bbbf8561ac2a814c977d9 NEEDED:debian UBUNTU: [Config] CONFIG_SCSI_IPR_TRACE=y, CONFIG_SCSI_IPR_DUMP=y
++c9990e0b0998d728503f56ab9c7821d56a721a58 NEEDED:debian UBUNTU: [Config] armhf: RTC_DRV_PCF8523=y
++82fd2a6b5fff23ba504adfe2d18dc1d44f109445 NEEDED:debian UBUNTU: [Config] armhf: build cubox & imx6 DTBs
++7fdb1513964145758aefdf7a43b06a1d0b6b5811 NEEDED:debian UBUNTU: [Config] armhf: KEYBOARD_IMX=m
++7534c02766b9c2305e03cd5b5a117c3997863ff4 NEEDED:debian UBUNTU: [Config] armhf: MXS_DMA=y && MTD_NAND_GPMI_NAND=m
++43470d1ec8f5355be9c153b05088af5505ebd499 NEEDED:debian UBUNTU: [Config] CONFIG_KEYS_DEBUG_PROC_KEYS=y
++6f1d20b13ce5c137c86d1144eb82ab38f99e76cf NEEDED:debian UBUNTU: Start new release
++9d6defca20c389c1ff93e5802c71973b092e7a14 NEEDED:split-debian UBUNTU: Ubuntu-3.16.0-5.10
++1d693f78502686a992d2038c9896c3e6c2652ce2 NEEDED UBUNTU: SAUCE: aufs3 -- update update scripting
++53acc12981cc9883d9038fcac7ac86b9ad274f24 NEEDED UBUNTU: SAUCE: AUFS (no-squash): basic framework and update machinary
++87428d40577506cfdf31336368aa613ae0c54639 NEEDED UBUNTU: SAUCE: 85xx: Only use generic tbsync routines on PPC32
++ad006bb4d530a83f425ee836b7d8de7d5c93e3cf NEEDED UBUNTU: SAUCE: (no-up) Select reboot driver for X-Gene platform.
++5d2fc3d65465aac854036c9ca737eab59b608042 NEEDED UBUNTU: SAUCE: nouveau: missing outputs should be warnings
++b2648e043821b5866f8c863c4b928732228d3402 NEEDED UBUNTU: SAUCE: kvm: BIOS disabled kvm support should be a warning
++8c10fb1a7bf59170ed6fd059cb35e5017abcd05f NEEDED UBUNTU: SAUCE: kthread: Do not leave kthread_create() immediately upon SIGKILL.
++6d0ed555d8ae64794d2902f9c1b7e0da5c39d939 NEEDED UBUNTU: SAUCE: intel_pstate: inform user that thermald is worth considering
++594f6dbf60084fd5fc21bdcc0a99b154be76e76d NEEDED UBUNTU: SAUCE: (no-up) mei_me: Add module parameter to disable MSI
++e62b73418e9503b09d61a6dc8721f457bec967d0 NEEDED UBUNTU: SAUCE: Revert "drm/crtc-helpers: fix dpms on logic"
++6e2be9569f946dc74fec9f5f24a9d80689275343 NEEDED UBUNTU: SAUCE: book3e cleanups for CONFIG_RELOCATABLE
++69923caf98a546b30325ec486536633fddb7ff90 NEEDED UBUNTU: SAUCE: book3e/kexec/kdump: recover "r4 = 0" to create the initial TLB
++2df7602013328910b0c6fce7f411a5d1b25be301 NEEDED UBUNTU: SAUCE: book3e/kexec/kdump: redefine VIRT_PHYS_OFFSET
++3d13bd1d0394d80f6dccae2daafdd1ce887e8672 NEEDED UBUNTU: SAUCE: book3e/kexec/kdump: implement ppc64 kexec specfic
++219cc9dd30079c35ad74590b3808ff7e12f3dd39 NEEDED UBUNTU: SAUCE: book3e/kexec/kdump: introduce a kexec kernel flag
++9e138c3c7acc6975d0ac364254ae021592e2d096 NEEDED UBUNTU: SAUCE: book3e/kexec/kdump: create a 1:1 TLB mapping
++2d3b205cde4d3b8069b8d9bb97203de57726ea92 NEEDED UBUNTU: SAUCE: book3e/kexec/kdump: enable kexec for kernel
++32b8a9f39e22e0b54dbe78a1c179de7ca0dfd9cb NEEDED UBUNTU: SAUCE: powerpc/book3e: support CONFIG_RELOCATABLE
++aa396fc0fa2317a5b447e88bc46b352f0411307e NEEDED UBUNTU: SAUCE: vt -- maintain bootloader screen mode and content until vt switch
++0e50fbdb8e04609ddd667428f54d81fd17ffc232 NEEDED UBUNTU: SAUCE: export some symbols for powerpc
++272b7c0f6c6c380981101491d9ef26bd45ade5fe NEEDED UBUNTU: SAUCE: allow IRQs to be irq-threaded by default via config
++d5c3c89b86cfe6ce6dc5c67c462e563326940d44 NEEDED UBUNTU: SAUCE: Provide booke stub for kvmppc_is_bigendian()
++b551f2a4439d2179b3732c2a28277d9245dbb150 NEEDED UBUNTU: SAUCE: xgmac_mdio: Silence read errors
++285f1bd95dd079825af0d06e33af71a7583aeee9 NEEDED UBUNTU: SAUCE: Fixup freescale usb phy driver to work on ppc64
++c2361b23e7b757ffa4241a6ab427694f3be844cd NEEDED UBUNTU: SAUCE: Revert "phy: vitesse make vsc824x_add_skew static"
++f40baa6f375e1730970cebce0a14a7456d539ab2 NEEDED UBUNTU: SAUCE: PPC: PCI: Fix pcibios_io_space_offset() so it works for 32-bit ptr/64-bit rsrcs
++dc7dff6e417c8642ead4659e42e9b1b601db199c NEEDED UBUNTU: SAUCE: phylib: Minimum hack to get the generic 10G PHY driver to work with 10G "fixed-link"s
++0bd9175323dad194fcff7b450aa14d39ce710b3d NEEDED UBUNTU: SAUCE: OMAP: AM33xx: hwmod: Correct AES module SYSC type
++3a1228b27e425e24b6257c8af1e3ccebc1f9f809 NEEDED UBUNTU: SAUCE: ARM: OMAP4: hwmod: Add hwmod data for AES IP
++eff618d811a4b62462674a8bb05556a548f2c112 NEEDED UBUNTU: SAUCE: ARM: OMAP: hwmod: Add SYSC offsets for AES IP
++8418ceb9869d41a7ba4e6217c631bdb28e07c33b NEEDED UBUNTU: SAUCE: suspicious unlocked ->status reading and writing in ipc/sem.c
++fd4bcb1162b482eafc3fc3fe480698cc8d1cdfdb NEEDED UBUNTU: SAUCE: tg3: Add support for new 57786 device id.
++00b5fd7aaa231697512b50a7c80ed2a3c8c7e3b0 NEEDED UBUNTU: SAUCE: Work around broken ACPI backlight on Dell Inspiron 5537
++bf3a2dfe2f7f34c174a0a938c350912e319fe032 NEEDED UBUNTU: SAUCE: disable stack-protector for ARM compressed bootloader
++29fb264813de8f4bbd8c8577901630e6a547d503 NEEDED UBUNTU: SAUCE: uvcvideo: quirk PROBE_DEF for Alienware X51 OmniVision webcam
++cdf48be1c63b4a07cecf2a62617f7fb7b847fabb NEEDED UBUNTU: SAUCE: isapnp_init: make isa PNP scans occur async
++eedee9b0f515aa2793fccbbfd7d58db95b2490d1 NEEDED UBUNTU: SAUCE: dm-crypt: never use write same
++6eccf1ef86175928b723ca681c2ab851d112e7ac NEEDED UBUNTU: SAUCE: (no-up) ACPI: Disable Windows 8 compatibility for some Lenovo ThinkPads
++07419bbe0eb79097693cae2b7ed1b3f467fca642 NEEDED UBUNTU: SAUCE: (no-up) intel_ips: blacklist ASUSTek G60JX laptops
++5b2c0e070ec1b4d29178b320220c5388ec9f9c82 NEEDED UBUNTU: SAUCE: (no-up) Update bnx2x firmware to 7.8.17.0
++fdbf1af4b48970478c1ee25e1c620ecb8cd4035e NEEDED UBUNTU: SAUCE: (no-up) trace: add trace events for open(), exec() and uselib() (for v3.7+)
++1d4ec94ffcaca71994e520abe769ee6dcf4579ee NEEDED UBUNTU: SAUCE: (no-up) x86: reboot: Make Dell Optiplex 390 use reboot=pci
++f760d3c92097784cfda92f3f4c094ccf9fc2497c NEEDED UBUNTU: SAUCE: (no-up) PCI: fix system hang issue of Marvell SATA host controller
++f43492d5b2cf399039ca6914348d25aaee474e4f NEEDED UBUNTU: SAUCE: (no-up) Convert bnx2x firmware files to ihex format
++8b732f482e348d75ee9b433c574bcf88d0a8991b NEEDED UBUNTU: SAUCE: (no-up) Input: Cypress PS/2 Trackpad simulated multitouch
++7466874e8128bab355ddf3512171ae836348b7f7 NEEDED UBUNTU: SAUCE: (no-up) hv: Supply vendor ID and package ABI
++6a5fff41e536a612ddc1352d93a5b6db8ba68f39 NEEDED UBUNTU: SAUCE: (no-up) Revert "VFS: don't do protected {sym,hard}links by default"
++ae359c3e312669ebde46bc3817d6cea99a7f9bef NEEDED UBUNTU: SAUCE: (no-up) Remove vicam files duplicated in linux-firmware
++794523f01c1303be9d736acca7f016af31b7b416 NEEDED UBUNTU: SAUCE: (no-up) Remove dsp56k files used only by m68k
++db779e5d146cf4d34aee88cf9d2f71d00a9c926c NEEDED UBUNTU: SAUCE: (no-up) Update bnx2x firmware to 7.8.2.0
++588fe8f57dc07478c434afb332793b91ea896bc9 NEEDED UBUNTU: SAUCE: (no-up) Remove radeon files duplicated in linux-firmware
++c4e09c38991997926099d1fdac4bef85cbdc4d72 NEEDED UBUNTU: SAUCE: (no-up) Remove sun files duplicated in linux-firmware
++14b6b1d6c7c6b42d778c4aacc0a9d68a451e5ba8 NEEDED UBUNTU: SAUCE: (no-up) Remove keyspan files duplicated in linux-firmware
++8989c6225b5d8ef4bd42337382c3fe58c4448887 NEEDED UBUNTU: SAUCE: (no-up) Remove acenic files duplicated in linux-firmware
++e9347676137c6b05dd8d1db1de39230e677ada95 NEEDED UBUNTU: SAUCE: (no-up) Remove r128 files duplicated in linux-firmware
++8a8c10cf8ebc650ed0ae9bb94de9787321fcef5b NEEDED UBUNTU: SAUCE: (no-up) Remove cxgb3 files duplicated in linux-firmware
++da35e9ad8c83e4ecc8a73b68b8cc556e8723cdb3 NEEDED UBUNTU: SAUCE: (no-up) Remove matrox files duplicated in linux-firmware
++31f0ae2767b81565b1333630f9572a09df295a04 NEEDED UBUNTU: SAUCE: (no-up) Remove tehuti files duplicated in linux-firmware
++ea4588800ea937d2044723f497632e608e5a713e NEEDED UBUNTU: SAUCE: (no-up) Remove yam files duplicated in linux-firmware
++5fa5e5d023fa3ad67d4947710062440e0b92b6f3 NEEDED UBUNTU: SAUCE: (no-up) fix highbank include path
++bcd707780091a34cd1815b8ab6cf795e13433e65 NEEDED UBUNTU: SAUCE: (no-up) vxge: Declare MODULE_FIRMWARE usage
++dbc6280f6dc2988546dd6d35055741be0a5fcbe7 NEEDED UBUNTU: SAUCE: (no-up) rds_ib_send() -- prevent local pings triggering BUG_ON()
++a381ec9f409f2e71151194c647685826aadc97f3 NEEDED UBUNTU: SAUCE: (no-up) firmware: Upgrade bnx2 to current versions
++b08d030d87047591794e27a4d8cfc05c779f9fda NEEDED UBUNTU: SAUCE: (no-up) firmware: Remove obsolete Myricom firmware
++c62121eeb1e43d1c1bee1161f0fce00506810966 NEEDED UBUNTU: SAUCE: (no-up) firmware: Remove cpia2 files duplicated in linux-firmware
++6ca0baacfe0faa7d6265a283a378c7530f2b3286 NEEDED UBUNTU: SAUCE: (no-up) firmware: Remove av7110 files duplicated in linux-firmware
++492d662a9f259fb958ad3025ff4989ebb1ae1801 NEEDED UBUNTU: SAUCE: (no-up) firmware: Remove ambassador files duplicated in linux-firmware
++9d9677898ade658ad4c68a47c2dda3aea3a9caa6 NEEDED UBUNTU: SAUCE: (no-up) firmware: Remove advansys files duplicated in linux-firmware
++0906f131cf4b10f377dc66818a01eaab485a61f4 NEEDED UBUNTU: SAUCE: (no-up) firmware: Remove adaptec files duplicated in linux-firmware
++fc950a48545f49a2ab8e8a465c682a4a3d504f57 NEEDED UBUNTU: SAUCE: (no-up) firmware: Remove ti_usb_3410_5052 duplicated in linux-firmware
++6d277f4ffe2a7e2754feac527955f4e948d276cf NEEDED UBUNTU: SAUCE: (no-up) firmware: Remove edgeport files duplicated in linux-firmware
++6cd197c9e6ecc8a3d864d9547837ce9e2ad6a6c1 NEEDED UBUNTU: SAUCE: (no-up) firmware: Remove kaweth files duplicated in linux-firmware
++6d4aea69136e4baaa70726361e5912a24b92ed1e NEEDED UBUNTU: SAUCE: (no-up) firmware: Remove ess files duplicated in linux-firmware
++264af3894a66b66b07162df0fb367836e76c9705 NEEDED UBUNTU: SAUCE: (no-up) Remove redundant keyspan_pda firmware
++dc000f4ec05b4b34c2c1dd9a67d0a87fe1faee22 NEEDED UBUNTU: SAUCE: (no-up) Remove redundant yamaha/ds1 firmware
++6f4b585535c0c28732c46bc12ba8dda042596f15 NEEDED UBUNTU: SAUCE: (no-up) Remove redundant ositech/Xilinx7OD firmware
++a879d556097343beda5c932144f61b5320916ae2 NEEDED UBUNTU: SAUCE: (no-up) Remove redundant ttusb-budget firmware
++ec8ca911878b3aae198cfcffaae02368f555f488 NEEDED UBUNTU: SAUCE: (no-up) Remove redundant cis firmware
++482038c4e6362498269ddf66b5fe21021f7e7fcd NEEDED UBUNTU: SAUCE: (no-up) firmware: Update bnx2x to current firmware version 7.2.51
++1c5fd21e2fe45eea97a41163273add224545ddae NEEDED UBUNTU: SAUCE: (no-up) kconfig: in debug mode some 0 length message prints occur
++0685b9c73aa31e52831400e053d37f2e438cfb1b NEEDED UBUNTU: SAUCE: (no-up) Allow filtering of cpufreq drivers
++bd58f8e98fd0c05bfe34b7d8b538f35a0864c8d4 NEEDED UBUNTU: SAUCE: (no-up) tools/hv: add basic manual pages
++08347031e66a781b7876584175c0bea0d0726788 NEEDED UBUNTU: SAUCE: (no-up) elide some ioctl warnings which are known benign
++9e07077485c5e5805517bc2f6272a251eb61211d NEEDED UBUNTU: SAUCE: (no-up) Input: synapticss - Set buttonpad property for all clickpads
++43644523536605f8c650aa46e420d59192fa230b NEEDED UBUNTU: SAUCE: (no-up) Input: synaptics - add second variant of two-button clickpad
++1224fcf60e5dbe150b446c0f36f55601e50b867b NEEDED UBUNTU: SAUCE: (no-up) x86: reboot: Make Dell Latitude E6220 use reboot=pci
++e08e98d5f3eaece0a55eca47eb31d2544561f1e0 NEEDED UBUNTU: SAUCE: (no-up) x86: reboot: Make Dell Optiplex 990 use reboot=pci
++710ae591a352831d514adfecde8cbb921ab72132 NEEDED UBUNTU: SAUCE: (no-up) x86: reboot: Make Dell Optiplex 790 use reboot=pci
++075dc4fd57b7523b7d1e64df09e8fbab2298a45c NEEDED UBUNTU: SAUCE: (no-up) x86: reboot: Make Dell Latitude E6520 use reboot=pci
++11f96bb408f15ceeef5f1c089f99d974f5cd93c5 NEEDED UBUNTU: SAUCE: (no-up) add support for installed header files to ubuntu directory
++83442377bb16b0007a304e1b5f81f35139abb29c NEEDED UBUNTU: SAUCE: (no-up) Added quirk to recognize GE0301 3G modem as an interface.
++84b3a7169b338740a70d22eb408e89619acfd9db NEEDED UBUNTU: SAUCE: (no-up) fix build error with CONFIG_BLK_DEV_INITRD=n
++6a2a16f3c9e9496523125c58f788055dede4495f NEEDED UBUNTU: SAUCE: (no-up) dma-mapping: Remove WARN_ON in dma_free_coherent
++35814b8981777d9781bcf9d1a3d068b502ce90f2 NEEDED UBUNTU: SAUCE: (no-up) cdrom -- default to not locking the tray when in use
++de67e5bc6fbe1fed74ec545291efc763ec91c2b3 NEEDED UBUNTU: SAUCE: (no-up) nbd: Change default partitions per device to 15
++a5263a89adad25c3cbec28d9ed6e35c83e8de677 NEEDED UBUNTU: SAUCE: (no-up) hostap: Change initial operation mode to managed (infra)
++aa48271e2f11700129d616010dca588d7a973a03 NEEDED UBUNTU: SAUCE: (no-up) version: Implement version_signature proc file.
++3dcb633bcdca132c4f3df40338a3b387f63f9271 NEEDED UBUNTU: SAUCE: (no-up) dm-raid45: Fix incompatible ptr assignments
++7d687b18ba73d86852971a9060380a3e5657d086 NEEDED UBUNTU: SAUCE: (no-up) ubuntu: dm-raid45
++4437f9d1f3c4c6f7820bd7162ad54002e740eda8 NEEDED:debian UBUNTU: [Debian] Cloud tools
++58244d3007f8256b8fd23b941a87c97b60e54f91 NEEDED:debian UBUNTU: [Debian] add debian/gbp.conf
++04e8205c37a0d4756b675ea2229bac647ca200af NEEDED:debian UBUNTU: [Debian] remove the kernel-image firmware list on clean
++a52ad698ad07262a8735801415c139789ae88cdb NEEDED:debian UBUNTU: [debian] Dynamically generate the kernel-image udebs firmware list
++fbaf6c736d49fd8cd3d6121ea26009fbf7acd301 NEEDED:debian UBUNTU: [debian] Fix indep_hdrs_pkg_name
++0588234eed4f92f77c24090f368bd9fc419e50e0 NEEDED:debian UBUNTU: [Debian] Improve tools version message
++442d458f2ab0669d904de435bc943ffdb20b42e1 NEEDED:debian UBUNTU: [Debian] Re-sign modules after debug objcopy
++a6e1d4fd0d9dc987991216b799e6dee2b7956ad7 NEEDED:debian UBUNTU: [Debian] sort out linux-tools naming
++5fee25691328f9d46874a824d8e75c3a25be05d2 NEEDED:debian UBUNTU: [Debian] linux-tools: switch to common generic version helper
++2d0634eb9debcc3197792e52f717e7f88352b835 NEEDED:debian UBUNTU: [Debian] postinst -- fix unchanged link detection
++66e7bf3df38ce1302a32baf8142dce56c0c81586 NEEDED:debian UBUNTU: [Debian] postinst -- improve relative symlink detection with missing files
++c5e7fa9208fbe047c329c124f4d4e1320321d34f NEEDED:debian UBUNTU: [Debian] getabis: Commit new ABI directory, remove the old
++f01e594cf5b3a0f05f19ac55e78589d93b06b8fa NEEDED:debian UBUNTU: [Debian] Add hv_vss_daemon to tools package
++687fa338e27867b855c77dd79860035dde626761 NEEDED:debian UBUNTU: [debian] tools: ship 'cpupower' in linux-tools
++23e6572a962df847252e07898a40174669e8f2a5 NEEDED:debian UBUNTU: [Debian] tools: enable x86 and hyper-v
++8bd69d23b91eee555b60a59e42a04201a7d0f1e7 NEEDED:debian UBUNTU: [Debian] autopkgtest: switch Depends: to build-essential
++2a6e95d999ee4efac165d88c8106a888fc9b5a8a NEEDED:debian UBUNTU: [Debian] supply perf with appropriate prefix to ensure use of local config
++81c56fe3b06596c30b9eae372008fe37ae20f3b7 NEEDED:debian UBUNTU: [Debian] Explicitly reference gawk in build rules awk in all and arch
++82429d09555509df1d684469d97dedc756ff11b8 NEEDED:debian UBUNTU: [Debian] fix SRCPKGNAME-udebs-FLAVOUR handling for complex flavours
++754e4d69262a59fff8c893b32f199d1fbec6905b NEEDED:debian UBUNTU: [Debian] Supply PKG_ABI in kmake
++d25ef28f3ab3ead424ce856ecc849d4bd8eff932 NEEDED:debian UBUNTU: [Debian] reduce udeb rules spew
++61ce255d6b166b9c48c8a4ff2176ea15089e381d NEEDED:debian UBUNTU: [Debian] Prepare to build using arch specific compiler
++9a9792eeae3e7ec48aed14e38a8cbb3e716d5e34 NEEDED:debian UBUNTU: [Debian] do_tools=false when cross compiling
++0ea3ee0721c59ddf26e95da242e5e9ead1e21278 NEEDED:debian UBUNTU: [Debian] generate a SRCPKGNAME-udebs-FLAVOUR-di depending on all built udebs
++553cbe477ce2085e1a249d629f268d62af484682 NEEDED:debian UBUNTU: [debian] Use dh_strip
++a418dffd68c2c8b88dc3e2fbaf09ead34cfc2fed NEEDED:debian UBUNTU: (debian) get-firmware: Be more selective about copies
++4c40a10a81f5cd9310b7b5766ff731db91224f3f NEEDED:debian UBUNTU: (debian) fix internal linkage for separated header packages
++b69a501e52aff469bc0e0b3ea7fcde5bfef63af1 NEEDED:debian UBUNTU: (debian) Abort build on unresolved symbols
++15bc58fd511b00f7703d2b5d8909af935b31c1d5 NEEDED UBUNTU: [debian] ensure debian/ is not excluded from git by default
++83f903be8906fc46d258124e64803590fa5a60ac NEEDED:debian UBUNTU: [debian] Specify python2.7 for perf tools build
++817c1f4144c1318dc2e5d62e8817979a7f721ff9 NEEDED:debian UBUNTU: [debian] do not use ../.$(series)-env file
++c00e4866e6e549618a43ae3928073f552cca12a5 NEEDED:debian UBUNTU: [debian] perf: NO_LIBPERL=1
++44e01631bcd442f4f61c264af78e193518daa683 NEEDED:debian UBUNTU: [debian] perf: NO_LIBPYTHON=1
++4ec3e6d91413db7e4ba6df1f8b069aee2e7ed216 NEEDED:debian UBUNTU: [debian] Build extras package only for specific arches
++6ea3c5606dfdac9dc0348d0eeafb17207cf1efbb NEEDED:debian UBUNTU: [debian] Remove dangling symlink from headers package
++9b0d5791d9345eb165fb26e8f80837209ed677f4 NEEDED:debian UBUNTU: [debian] DTB: add support for multiple DTBs
++fc9f46c418f454b138af5d810003db5e3d7eb582 NEEDED:debian UBUNTU: [debian] Add macro to selectively disable building perf
++c054564f4aeffa8baf045df5de9707140d3fd381 NEEDED:debian UBUNTU: [debian] insertchanges -- fix to work across major version changes
++2161b4265ed31268232cb4743f6201b1be7ce1a8 NEEDED:split-debian UBUNTU: [debian] Moved scripts/fw-to-ihex.sh to debian/scripts/misc
++187fb48b5107cf8714beb306cb24610e97101cee NEEDED:debian UBUNTU: [debian] find-obsolete-firmware: Use correct path
++6b259db6215d8e1d4a31c1ba46ed39d2dafe82f1 NEEDED:debian UBUNTU: [debian] get-firmware: Filter new files through fwinfo
++ba7c4f74efc87ea48be44992774a563151926bf7 NEEDED:debian UBUNTU: [debian] hmake -j1
++ff734a2a5e6dccf8e218115f0897c0296195408f NEEDED:debian UBUNTU: [debian] add an autopkgtest rebuild test
++8b92747ff62b53c7481de518a1d9e0dcc3efadc5 NEEDED:debian UBUNTU: [debian] move build tests out of the way
++65dc3834bd439e381e4a1319f47ba198ff59bfad NEEDED:debian UBUNTU: [debian] add rebuild-test support for autopkgtest
++85df5d081a0a1cf926bc1596fce86058a980957d NEEDED:debian UBUNTU: [debian] script to detect obsolete firmware
++0486170e5ff342ec83e3ad383d490ad9c4009012 NEEDED:debian UBUNTU: [debian] Use SRCPKGNAME as prefix for indep linux headers package
++4fecdbff008d99d5084ad220223d95f2a8b33430 NEEDED:debian UBUNTU: [debian] Document binary-indep dependency chain
++e31db9848498b37cec7974a7f55f3a0125ac98f7 NEEDED:debian UBUNTU: [debian] Use dh_prep instead of 'dh_clean -k'
++f97b9b22ffed7de7d3b2f0b79ffcbd74ae75af29 NEEDED:debian UBUNTU: [debian] enforcer -- fix debugging output
++97625cbcd6c760b92fcbd46b33127817abd3f5ec NEEDED:debian UBUNTU: [debian] Add custom_override rule to allow for alternate kernel file/install
++8dadbaaed08c1aba3f59d1f8cac96284420b422f NEEDED:debian UBUNTU: [debian] Update armhf comments.
++efd7c209638bec8871bdc80b05ac2678d98342f9 NEEDED:debian UBUNTU: [debian] drop manual headers copy
++a25e7161804d73bdc21933f8ce22dffc30737c4d NEEDED:debian UBUNTU: [debian] bootstrap: switch to the new DEB_BUILD_PROFILE
++5dedd7999df59975ea0faa207f5f8ed9c8d59e96 NEEDED:debian UBUNTU: [debian] do not fail secure copy on older kernels
++a6a3b1451ca57ca799e98ba62fb0d95cfec38c5d NEEDED:debian UBUNTU: [debian] allow us to select which builds have uefi signed versions
++a34c8331e9565c7af1a04c64bb6d1c57fc2c605e NEEDED:debian UBUNTU: [debian] we already have a valid src_pkg_name
++e606ba427f5f2abe7a4ec1ab18a4d5838345821c NEEDED:debian UBUNTU: [debian] add custom upload for the kernel binary package
++0ffed1cb10d43ba7d525fcc0af93e4eb9d88e8eb NEEDED:debian UBUNTU: [debian] note directory name changes
++a6d721352cbc862a3e31652e904311739b016727 NEEDED:split-debian UBUNTU: [debian] Initial debian and ubuntu directories
++b44d72ce530f51e7a882d23c66029a63b737231b NEEDED UBUNTU: [Debian] Prep for Ubuntu build infrastructure
+diff --git a/debian.master/modprobe.d/common.conf b/debian.master/modprobe.d/common.conf
+new file mode 100644
+index 0000000..e0fbbd6
+--- /dev/null
++++ b/debian.master/modprobe.d/common.conf
+@@ -0,0 +1,3 @@
++# LP:1434842 -- disable OSS drivers by default to allow pulseaudio to emulate
++blacklist snd-mixer-oss
++blacklist snd-pcm-oss
+diff --git a/debian.master/reconstruct b/debian.master/reconstruct
+new file mode 100755
+index 0000000..039e4d0
+--- /dev/null
++++ b/debian.master/reconstruct
+@@ -0,0 +1,2 @@
++#!/bin/sh
++exit 0
+diff --git a/debian.master/rules.d/amd64.mk b/debian.master/rules.d/amd64.mk
+new file mode 100644
+index 0000000..3de7b6d
+--- /dev/null
++++ b/debian.master/rules.d/amd64.mk
+@@ -0,0 +1,20 @@
++human_arch	= 64 bit x86
++build_arch	= x86_64
++header_arch	= $(build_arch)
++defconfig	= defconfig
++flavours	= generic lowlatency
++build_image	= bzImage
++kernel_file	= arch/$(build_arch)/boot/bzImage
++install_file	= vmlinuz
++loader		= grub
++vdso		= vdso_install
++no_dumpfile	= true
++uefi_signed     = true
++do_tools_usbip  = true
++do_tools_cpupower = true
++do_tools_perf   = true
++do_tools_x86	= true
++do_tools_hyperv	= true
++do_extras_package = true
++do_tools_common = true
++do_zfs		= true
+diff --git a/debian.master/rules.d/arm64.mk b/debian.master/rules.d/arm64.mk
+new file mode 100644
+index 0000000..670fa58
+--- /dev/null
++++ b/debian.master/rules.d/arm64.mk
+@@ -0,0 +1,19 @@
++human_arch	= ARMv8
++build_arch	= arm64
++header_arch	= arm64
++defconfig	= defconfig
++flavours	= generic
++build_image	= Image
++kernel_file	= arch/$(build_arch)/boot/Image
++install_file	= vmlinuz
++no_dumpfile = true
++
++loader		= grub
++vdso		= vdso_install
++
++do_tools_usbip  = true
++do_tools_cpupower = true
++do_tools_perf   = true
++
++do_dtbs		= true
++do_zfs		= true
+diff --git a/debian.master/rules.d/armhf.mk b/debian.master/rules.d/armhf.mk
+new file mode 100644
+index 0000000..6cabbf2
+--- /dev/null
++++ b/debian.master/rules.d/armhf.mk
+@@ -0,0 +1,17 @@
++human_arch	= ARM (hard float)
++build_arch	= arm
++header_arch	= arm
++defconfig	= defconfig
++flavours	= generic generic-lpae
++build_image	= zImage
++kernel_file	= arch/$(build_arch)/boot/zImage
++install_file	= vmlinuz
++no_dumpfile	= true
++
++loader		= grub
++
++do_tools_usbip  = true
++do_tools_cpupower = true
++do_tools_perf	= true
++
++do_dtbs		= true
+diff --git a/debian.master/rules.d/i386.mk b/debian.master/rules.d/i386.mk
+new file mode 100644
+index 0000000..95f22ba
+--- /dev/null
++++ b/debian.master/rules.d/i386.mk
+@@ -0,0 +1,17 @@
++human_arch	= 32 bit x86
++build_arch	= i386
++header_arch	= x86_64
++defconfig	= defconfig
++flavours        = generic lowlatency
++build_image	= bzImage
++kernel_file	= arch/$(build_arch)/boot/bzImage
++install_file	= vmlinuz
++loader		= grub
++vdso		= vdso_install
++no_dumpfile	= true
++do_tools_usbip  = true
++do_tools_cpupower = true
++do_tools_perf   = true
++do_tools_x86	= true
++do_tools_hyperv = true
++do_extras_package = true
+diff --git a/debian.master/rules.d/powerpc.mk b/debian.master/rules.d/powerpc.mk
+new file mode 100644
+index 0000000..6af9be6
+--- /dev/null
++++ b/debian.master/rules.d/powerpc.mk
+@@ -0,0 +1,39 @@
++human_arch	= PowerPC (32 bit userspace)
++build_arch	= powerpc
++header_arch	= $(build_arch)
++defconfig	= pmac32_defconfig
++flavours	= powerpc-smp powerpc64-smp powerpc-e500mc powerpc64-emb
++build_image	= zImage
++kernel_file	= $(shell if [ ! -f $(builddir)/build-$*/vmlinux.strip ] && \
++		    [ -f $(builddir)/build-$*/vmlinux.strip.gz ]; then \
++			gunzip -c $(builddir)/build-$*/vmlinux.strip.gz \
++			> $(builddir)/build-$*/vmlinux.strip; \
++		    fi && echo vmlinux.strip)
++install_file	= vmlinux
++
++# These flavours differ
++build_image_powerpc-e500mc	= uImage
++kernel_file_powerpc-e500mc	= arch/powerpc/boot/uImage
++
++build_image_powerpc64-emb	= uImage
++kernel_file_powerpc64-emb	= arch/powerpc/boot/uImage
++
++loader		= yaboot
++vdso		= vdso_install
++
++custom_flavours	=
++
++no_dumpfile		= true
++do_tools_usbip          = true
++do_tools_cpupower	= true
++do_tools_perf		= true
++
++# Default to true and disable to ensure that the crossbuild
++# override still has priority.
++do_zfs			= true
++do_zfs_powerpc-smp	= false
++# do_zfs_powerpc64-smp	= true
++do_zfs_powerpc-e500mc	= false
++do_zfs_powerpc64-emb	= false
++
++family			= ubuntu
+diff --git a/debian.master/rules.d/ppc64el.mk b/debian.master/rules.d/ppc64el.mk
+new file mode 100644
+index 0000000..3f8c4a4
+--- /dev/null
++++ b/debian.master/rules.d/ppc64el.mk
+@@ -0,0 +1,19 @@
++human_arch	= PowerPC 64el
++build_arch	= powerpc
++header_arch	= $(build_arch)
++defconfig	= pseries_le_defconfig
++flavours	= generic
++build_image	= vmlinux.strip
++kernel_file     = arch/powerpc/boot/vmlinux.strip
++install_file	= vmlinux
++no_dumpfile	= true
++vdso		= vdso_install
++loader		= grub
++do_extras_package = true
++
++do_tools_usbip    = true
++do_tools_cpupower = true
++do_tools_perf	  = true
++
++#do_flavour_image_package = false
++do_zfs		= true
+diff --git a/debian.master/rules.d/s390x.mk b/debian.master/rules.d/s390x.mk
+new file mode 100644
+index 0000000..5b468ac
+--- /dev/null
++++ b/debian.master/rules.d/s390x.mk
+@@ -0,0 +1,19 @@
++human_arch      = System 390x
++build_arch      = s390
++header_arch     = $(build_arch)
++defconfig       = defconfig
++flavours        = generic
++build_image	= bzImage
++kernel_file	= arch/$(build_arch)/boot/bzImage
++install_file	= vmlinuz
++
++vdso		= vdso_install
++no_dumpfile	= true
++
++do_extras_package = true
++
++do_tools_usbip    = true
++do_tools_cpupower = true
++do_tools_perf     = true
++
++do_zfs		= true
+diff --git a/debian.master/rules.d/x32.mk b/debian.master/rules.d/x32.mk
+new file mode 100644
+index 0000000..94d4c83
+--- /dev/null
++++ b/debian.master/rules.d/x32.mk
+@@ -0,0 +1,14 @@
++human_arch	= 64 bit x86 (32 bit userspace)
++build_arch	= x86_64
++header_arch	= $(build_arch)
++defconfig	= defconfig
++flavours	= 
++build_image	= bzImage
++kernel_file	= arch/$(build_arch)/boot/bzImage
++install_file	= vmlinuz
++loader		= grub
++vdso		= vdso_install
++no_dumpfile	= true
++uefi_signed     = true
++
++do_flavour_image_package = false
+diff --git a/debian/cloud-tools/hv_get_dhcp_info b/debian/cloud-tools/hv_get_dhcp_info
+new file mode 100755
+index 0000000..09fabd2
+--- /dev/null
++++ b/debian/cloud-tools/hv_get_dhcp_info
+@@ -0,0 +1,55 @@
++#!/bin/bash
++
++# This example script retrieves the DHCP state of a given interface.
++# In the interest of keeping the KVP daemon code free of distro specific
++# information; the kvp daemon code invokes this external script to gather
++# DHCP setting for the specific interface.
++#
++# Input: Name of the interface
++#
++# Output: The script prints the string "Enabled" to stdout to indicate
++#	that DHCP is enabled on the interface. If DHCP is not enabled,
++#	the script prints the string "Disabled" to stdout.
++#
++# Each Distro is expected to implement this script in a distro specific
++# fashion. 
++
++#set -x
++
++IF_FILE="/etc/network/interfaces"
++NMCMD="nmcli"
++
++function checknetworkmanager {
++	#Assumes if $NMCMD exists, inteface exists and interface is not
++	#  in $IF_FILE then dhcp is being used by NM
++        if  hash $NMCMD >/dev/null 2>&1  ; then
++                if  $NMCMD  dev status |grep -q $1  ; then
++                        echo "Enabled"
++                else
++                        echo "Disabled"
++                fi
++        else
++                #Give up
++                echo "Disabled"
++        fi
++}
++
++if [ -z $1 ]  ; then echo "Disabled"; exit; fi
++
++if [ -e $IF_FILE ]; then
++	if grep -v -e "^#" $IF_FILE|grep -q $1 ; then
++		#interface exists so
++		if grep -q -e $1\.\*dhcp $IF_FILE; then 
++			echo "Enabled"; exit;
++		else
++			echo "Disabled"; exit;
++		fi
++	else
++		checknetworkmanager $1
++		exit
++	fi
++else
++	checknetworkmanager $1
++	exit
++fi
++
+diff --git a/debian/cloud-tools/hv_get_dns_info b/debian/cloud-tools/hv_get_dns_info
+new file mode 100755
+index 0000000..058c17b
+--- /dev/null
++++ b/debian/cloud-tools/hv_get_dns_info
+@@ -0,0 +1,13 @@
++#!/bin/bash
++
++# This example script parses /etc/resolv.conf to retrive DNS information.
++# In the interest of keeping the KVP daemon code free of distro specific
++# information; the kvp daemon code invokes this external script to gather
++# DNS information.
++# This script is expected to print the nameserver values to stdout.
++# Each Distro is expected to implement this script in a distro specific
++# fashion. For instance on Distros that ship with Network Manager enabled,
++# this script can be based on the Network Manager APIs for retrieving DNS
++# entries.
++
++cat /etc/resolv.conf 2>/dev/null | awk '/^nameserver/ { print $2 }'
+diff --git a/debian/cloud-tools/hv_set_ifconfig b/debian/cloud-tools/hv_set_ifconfig
+new file mode 100755
+index 0000000..d8b0487
+--- /dev/null
++++ b/debian/cloud-tools/hv_set_ifconfig
+@@ -0,0 +1,288 @@
++#!/usr/bin/python3
++#
++# hv_set_ifconfig <config> -- take the hv_kvp_daemon generated configuration
++#                             file and apply it to the Ubuntu configuration.
++#
++
++# CONFIG example:
++# HWADDR=11:22:33:44:55:66
++# DEVICE=foo1
++# DHCP=yes
++
++# CONFIG example:
++# HWADDR=11:22:33:44:55:66
++# DEVICE=foo1
++# IPADDR=192.168.99.10
++# GATEWAY=192.168.99.1
++# DNS1=192.168.88.250
++# IPADDR2=192.168.99.11
++# IPV6ADDR=2001:DB8:99::10
++# IPV6NETMASK=64
++# IPV6_DEFAULTGW=2001:DB8:99::10
++
++# set interfaces in hv_kvp_daemon style
++import fileinput
++import sys
++import errno
++import os
++import shutil
++import tempfile
++import subprocess
++
++if_filename="/etc/network/interfaces"
++
++# Drop our output (XXX?)
++sys.stdout = open(os.devnull, 'w')
++sys.stderr = open(os.devnull, 'w')
++
++# Confirm we can open the network configuration.
++try:
++    if_file=open(if_filename,"r+")
++except IOError as e:
++    exit(e.errno)
++else:
++    if_file.close()
++
++# Usage: hv_set_ifconfig <config>
++if len(sys.argv) != 2 :
++    exit(errno.EINVAL)
++
++#
++# Here is the format of the ip configuration file:
++#
++# HWADDR=macaddr
++# DEVICE=interface name
++# BOOTPROTO=<protocol> (where <protocol> is "dhcp" if DHCP is configured
++#                       or "none" if no boot-time protocol should be used)
++#
++# IPADDR0=ipaddr1
++# IPADDR1=ipaddr2
++# IPADDRx=ipaddry (where y = x + 1)
++#
++# NETMASK0=netmask1
++# NETMASKx=netmasky (where y = x + 1)
++#
++# GATEWAY=ipaddr1
++# GATEWAYx=ipaddry (where y = x + 1)
++#
++# DNSx=ipaddrx (where first DNS address is tagged as DNS1 etc)
++#
++# IPV6 addresses will be tagged as IPV6ADDR, IPV6 gateway will be
++# tagged as IPV6_DEFAULTGW and IPV6 NETMASK will be tagged as
++# IPV6NETMASK.
++#
++
++kvp=dict(line.strip().split("=") for line in fileinput.input())
++
++# Setting the hwaddress to something azure is not expecting is fatal
++# to networking.
++if not "HWADDR" in kvp :
++    exit(errno.EPROTO)
++
++# Confirm we have a device specified.
++if not "DEVICE" in kvp :
++    exit(1)
++
++autolist = []
++output=[]
++basename=kvp["DEVICE"]
++
++# DNS entries will go with the first interface and there can be a max
++# of three.  These will be emitted with the first interface.
++dns = []
++for count in (1, 2, 3):
++    key = "DNS" + str(count)
++    if key in kvp:
++        dns += [kvp[key]]
++dns_emitted = False
++
++# IPV4 may either be dhcp or static.
++if ("DHCP" in kvp and kvp["DHCP"] == "yes") or \
++   ("BOOTPROTO" in kvp and kvp["BOOTPROTO"] == "dhcp"):
++    autolist.append(basename)
++    output += ["iface " + basename  + " inet dhcp"]
++    output += [""]
++else:
++    # Matchup the interface specific lines
++
++    # No real max for the number of interface + aliases ...
++    # only required is the address (but mate everything up that comes in.
++
++    # IPv4 -- ensure we sort by numeric suffixes.
++    v4names = [ int(name[6:]) for name in kvp.keys() if name.startswith("IPADDR") ]
++    v4names.sort()
++
++    for if_count in v4names:
++        ifname = basename
++        which = str(if_count)
++
++        if if_count:
++            ifname += ":" + str(if_count)
++            which_gw = which
++        else:
++            which_gw = ""
++
++        if not ifname in autolist:
++            autolist += [ifname]
++
++        output += [ "iface " + ifname + " inet static" ]
++        output += [ "\t" + "address " + kvp["IPADDR" + which] ]
++        if "NETMASK" + which in kvp:
++            output += [ "\tnetmask " + kvp["NETMASK" + which] ]
++        if "GATEWAY" + which_gw in kvp:
++            output += ["\tgateway " + kvp["GATEWAY" + which_gw]]
++
++        if not dns_emitted:
++            dns_emitted = True
++            output += ["\tdns-nameservers " + ' '.join(dns)]
++        output += [""]
++
++# IPv6 requires a netmask
++# If an ipv6 exists, you'll want to turn off /proc/sys/net/ipv6/conf/all/autoconf with
++# echo 0 > /proc/sys/net/ipv6/conf/all/autoconf
++v6names = [ int(name[8:]) for name in kvp.keys() if name.startswith("IPV6ADDR") ]
++v6names.sort()
++
++for if6_count in v6names:
++    ifname = basename
++    which = str(if6_count)
++
++    if if6_count:
++        ifname += ":" + str(if6_count)
++        which_gw = which
++    else:
++        which_gw = ""
++
++    if not ifname in autolist:
++        autolist += [ifname]
++
++    if "IPV6NETMASK" + which in kvp:
++        output += [ "iface " + ifname + " inet6 static"]
++        output += [ "\taddress " + kvp["IPV6ADDR" + which]]
++        output += [ "\tnetmask " + kvp["IPV6NETMASK" + which]]
++        if "IPV6_DEFAULTGW" + which_gw in kvp:
++            output += [ "\tgateway " + kvp["IPV6_DEFAULTGW" + which_gw] ]
++        if not dns_emitted:
++            dns_emitted = True
++            output += ["\tdns-nameservers " + ' '.join(dns)]
++        output += [""]
++
++# Mark this new interface for automatic up.
++if len(autolist):
++    output = ["auto "+" ".join(autolist)] + output
++
++print("===================================")
++print(output)
++print("===================================")
++
++
++# Time to clean out the existing interface file
++
++# Markers.
++start_mark = "# The following stanza(s) added by hv_set_ifconfig"
++end_mark = "#End of hv_set_ifconfig stanzas"
++
++f=open(if_filename,"r")
++flines=f.readlines()
++f.close()
++newfile=[]
++pitchstanza=0
++inastanza=0
++stanza=[]
++prev_line=None
++for line in flines:
++    if line.startswith("auto"):
++        if inastanza:
++            if not pitchstanza:
++                newfile.extend(stanza)
++            stanza=[]
++        inastanza=0
++        newline=""
++        autoline=line.strip().split(" ")
++        for word in autoline:
++            if (not word == basename) and (not word.startswith(basename+":")):
++                newline+=word + " "
++        newline = newline.strip()
++        if not newline == "auto":
++            newfile += [newline.strip()]
++    elif line.startswith(("iface","mapping","source")):
++        '''Read a stanza'''
++        '''A Stanza can also start with allow- ie allow-hotplug'''
++        if inastanza:
++            if not pitchstanza:
++                newfile.extend(stanza)
++            stanza=[]
++        inastanza=1
++        pitchstanza=0
++        autoline=line.strip().split(" ")
++        for word in autoline:
++            if (word == basename) or (word.startswith(basename+":")):
++                pitchstanza=1
++        if not pitchstanza:
++            stanza+=[line.strip()]
++    elif line.strip() in (start_mark, end_mark):
++        if inastanza:
++            if not pitchstanza:
++                newfile.extend(stanza)
++            stanza=[]
++        inastanza = 0
++        pitchstanza = 0
++        # Deduplicate markers.
++        if line != prev_line:
++            newfile += [line.strip()]
++    else:
++        if inastanza:
++            if not pitchstanza:
++                stanza+=[line.strip()]
++        else:
++            if not pitchstanza:
++                newfile += [line.strip()]
++    prev_line=line
++
++# Include pending stanza if any.
++if inastanza and not pitchstanza:
++    newfile.extend(stanza)
++
++
++def emit(line):
++    print(line)
++    output = line + "\n"
++    os.write(fd, output.encode('utf-8'))
++
++# Insert the new output at the end and inside the existing markers if found.
++emitted = False
++fd, path = tempfile.mkstemp()
++for line in newfile:
++    if line == end_mark:
++        emit("\n".join(output))
++        emitted = True
++    emit(line)
++if not emitted:
++    emit(start_mark)
++    emit("\n".join(output))
++    emit(end_mark)
++os.close(fd)
++
++shutil.copy(path,if_filename)
++os.chmod(if_filename,0o644)
++
++#print("TMPFILE is at: " + path)
++#print("Copied file is at: " + if_filename)
++
++try:
++    retcode = subprocess.call("ifdown "+basename , shell=True)
++    if retcode < 0:
++        print("Child was terminated by signal", -retcode, file=sys.stderr)
++    else:
++        print("Child returned", retcode, file=sys.stderr)
++except OSError as e:
++    print("Execution failed:", e, file=sys.stderr)
++
++try:
++    retcode = subprocess.call("ifup "+basename , shell=True)
++    if retcode < 0:
++        print("Child was terminated by signal", -retcode, file=sys.stderr)
++    else:
++        print("Child returned", retcode, file=sys.stderr)
++except OSError as e:
++    print("Execution failed:", e, file=sys.stderr)
+diff --git a/debian/commit-templates/bumpabi b/debian/commit-templates/bumpabi
+new file mode 100644
+index 0000000..6c373c9
+--- /dev/null
++++ b/debian/commit-templates/bumpabi
+@@ -0,0 +1,3 @@
++UBUNTU: Bump ABI
++
++Ignore: yes
+diff --git a/debian/commit-templates/config-updates b/debian/commit-templates/config-updates
+new file mode 100644
+index 0000000..4b62c29
+--- /dev/null
++++ b/debian/commit-templates/config-updates
+@@ -0,0 +1,15 @@
++#
++# This template is used for commit messages that don't need to
++# show up in debian/changelog. Administrative stuff like config
++# updates, ABI bumps, etc. Setting 'Ignore: yes' prevents
++# 'debian/rules insertchanges' from inserting this commit meesage
++# as a changelog entry.
++#
++# Please give a one-line description of the config change followed
++# by a detailed explanation if necessary
++
++UBUNTU: [Config] XXXX
++
++# BugLink: http://bugs.launchpad.net/bugs/<enter bug# here>
++# Ignore: yes
++# Other text below here.
+diff --git a/debian/commit-templates/external-driver b/debian/commit-templates/external-driver
+new file mode 100644
+index 0000000..decdc89
+--- /dev/null
++++ b/debian/commit-templates/external-driver
+@@ -0,0 +1,20 @@
++# Ubuntu external driver commit.
++#
++# NOTE: This gets reformatted for README.Ubuntu-External-Drivers and
++# debian/changelog.
++#
++# This is only needed when a driver is added, updated or removed. It is
++# not needed when patches or fixes are applied to the driver. If the
++# driver is being removed, add the line:
++#
++# Removing: yes
++#
++# to the commit, and you can remove all other tags (except UBUNTU:).
++#
++UBUNTU: 
++
++ExternalDriver: 
++Description:
++Url:
++Mask:
++Version:
+diff --git a/debian/commit-templates/missing-modules b/debian/commit-templates/missing-modules
+new file mode 100644
+index 0000000..f4872e7
+--- /dev/null
++++ b/debian/commit-templates/missing-modules
+@@ -0,0 +1,3 @@
++UBUNTU: build/modules: Add modules that have intentionally gone missing
++
++Ignore: yes
+diff --git a/debian/commit-templates/newrelease b/debian/commit-templates/newrelease
+new file mode 100644
+index 0000000..5f8931c
+--- /dev/null
++++ b/debian/commit-templates/newrelease
+@@ -0,0 +1,3 @@
++UBUNTU: Start new release
++
++Ignore: yes
+diff --git a/debian/commit-templates/sauce-patch b/debian/commit-templates/sauce-patch
+new file mode 100644
+index 0000000..08720a8
+--- /dev/null
++++ b/debian/commit-templates/sauce-patch
+@@ -0,0 +1,40 @@
++# Ubuntu commit template.
++#
++# NOTE: This gets reformatted for debian/changelog
++#
++#
++# SAUCE refers to the fact that this patch might not go upstream, but we need to
++# carry it to successive releases. In most cases you DONOT want to use this
++# template. 
++#
++# An example of a SAUCE patch is the ACPI DSDT-in-initramfs patch which has been
++# refused upstream, but still provides useful functionality to users with broken
++# BIOSes.
++#
++#-------------------------------------------------------------------------
++#
++# The initial UBUNTU is a flag that this is an Ubuntu commit. It will be
++# referenced to the Author in the debian/changelog entry.
++#
++# The text following is the short message that will be placed in the
++# changelog. Extra text on the following lines will be ignored, but left
++# in the git commit. Lines with # will be ignored in the commit.
++#
++# OriginalAuthor allows for alternate attribution.
++#
++# OriginalLocation allows for a URL or description of where the patch came
++# from.
++#
++# BugLink is a URL to a Malone bug.
++#
++# Ignore: yes will keep this commit from showing up in the changelog.
++#
++UBUNTU: SAUCE: 
++
++<Why is this patch not going upstream?>
++
++# OriginalAuthor: 
++# OriginalLocation: 
++# BugLink: http://bugs.launchpad.net/bugs/<enter bug# here>
++# Ignore: yes
++# Other text below here.
+diff --git a/debian/commit-templates/upstream-patch b/debian/commit-templates/upstream-patch
+new file mode 100644
+index 0000000..671ab6a
+--- /dev/null
++++ b/debian/commit-templates/upstream-patch
+@@ -0,0 +1,27 @@
++# Ubuntu commit template.
++#
++# NOTE: This gets reformatted for debian/changelog
++#
++# The initial UBUNTU is a flag that this is an Ubuntu commit. It will be
++# referenced to the Author in the debian/changelog entry.
++#
++# The text following is the short message that will be placed in the
++# changelog. Extra text on the following lines will be ignored, but left
++# in the git commit. Lines with # will be ignored in the commit.
++#
++# OriginalAuthor allows for alternate attribution.
++#
++# OriginalLocation allows for a URL or description of where the patch came
++# from.
++#
++# BugLink is a URL to a Malone bug.
++#
++# Ignore: yes will keep this commit from showing up in the changelog.
++#
++UBUNTU: [Upstream]
++
++# OriginalAuthor: 
++# OriginalLocation: 
++# BugLink: http://bugs.launchpad.net/bugs/<enter bug# here>
++# Ignore: yes
++# Other text below here.
+diff --git a/debian/compat b/debian/compat
+new file mode 100644
+index 0000000..7ed6ff8
+--- /dev/null
++++ b/debian/compat
+@@ -0,0 +1 @@
++5
+diff --git a/debian/control-scripts/extra-post b/debian/control-scripts/extra-post
+new file mode 100644
+index 0000000..0d3f3ad
+--- /dev/null
++++ b/debian/control-scripts/extra-post
+@@ -0,0 +1,14 @@
++#!/bin/sh
++set -e
++
++case "$0::$1" in
++*.postinst::configure|*.postrm::remove)
++	depmod -a -F /boot/System.map-=V =V || true
++	for dir in "/etc/kernel/postinst.d" "/etc/kernel/postinst.d/=V"
++	do
++		if [ -d "$dir" ]; then
++			run-parts --verbose --exit-on-error --arg="=V" --arg="/boot/=K-=V" "$dir"
++		fi
++	done
++	;;
++esac
+diff --git a/debian/control-scripts/headers-postinst b/debian/control-scripts/headers-postinst
+new file mode 100644
+index 0000000..2fb2be8
+--- /dev/null
++++ b/debian/control-scripts/headers-postinst
+@@ -0,0 +1,126 @@
++#!/usr/bin/perl
++#                              -*- Mode: Cperl -*- 
++# debian.postinst ---
++# Author           : Manoj Srivastava ( srivasta@pilgrim.umass.edu )
++# Created On       : Sat Apr 27 05:42:43 1996
++# Created On Node  : melkor.pilgrim.umass.edu
++# Last Modified By : Manoj Srivastava
++# Last Modified On : Sat Aug  5 13:20:22 2006
++# Last Machine Used: glaurung.internal.golden-gryphon.com
++# Update Count     : 45
++# Status           : Unknown, Use with caution!
++# HISTORY          :
++# Description      :
++#
++#
++#
++#  arch-tag: 1c716174-2f0a-476d-a626-a1322e62503a
++#
++
++
++$|=1;
++
++# Predefined values:
++my $version           = "=V";
++my $kimage            = "=K";
++my $package_name    = "linux-image-$version";
++
++
++# Ignore all invocations uxcept when called on to configure.
++exit 0 unless ($ARGV[0] && $ARGV[0] =~ /configure/);
++
++#known variables
++my $image_dest      = "/";
++my $realimageloc    = "/boot/";
++my $silent_modules  = '';
++my $modules_base    = '/lib/modules';
++my $CONF_LOC        = '/etc/kernel-img.conf';
++# remove multiple leading slashes; make sure there is at least one.
++$realimageloc  =~ s|^/*|/|o;
++$realimageloc  =~ s|/+|/|o;
++
++chdir '/usr/src' or die "Could not chdir to /usr/src:$!";
++
++if (-r "$CONF_LOC" && -f "$CONF_LOC"  ) {
++  if (open(CONF, "$CONF_LOC")) {
++    while (<CONF>) {
++      chomp;
++      s/\#.*$//g;
++      next if /^\s*$/;
++
++      $header_postinst_hook   = "$1"  if /^\s*header_postinst_hook\s*=\s*(\S+)/ig;
++    }
++    close CONF;
++  }
++}
++
++sub exec_script {
++  my $type   = shift;
++  my $script = shift;
++  print STDERR "Running $type hook script $script.\n";
++  system ("$script $version $realimageloc$kimage-$version") &&
++    print STDERR "User $type hook script [$script] ";
++  if ($?) {
++    if ($? == -1) {
++      print STDERR "failed to execute: $!\n";
++    }
++    elsif ($? & 127) {
++      printf STDERR "died with signal %d, %s coredump\n",
++        ($? & 127),  ($? & 128) ? 'with' : 'without';
++    }
++    else {
++      printf STDERR "exited with value %d\n", $? >> 8;
++    }
++    exit $? >> 8;
++  }
++}
++sub run_hook {
++  my $type   = shift;
++  my $script = shift;
++  if ($script =~ m,^/,) {
++    # Full path provided for the hook script
++    if (-x "$script") {
++      &exec_script($type,$script);
++    }
++    else {
++      die "The provided $type hook script [$script] could not be run.\n";
++    }
++  }
++  else {
++    # Look for it in a safe path
++    for my $path ('/bin', '/sbin', '/usr/bin', '/usr/sbin') {
++      if (-x "$path/$script") {
++        &exec_script($type, "$path/$script");
++        return 0;
++      }
++    }
++    # No luck
++    print STDERR "Could not find $type hook script [$script].\n";
++    die "Looked in: '/bin', '/sbin', '/usr/bin', '/usr/sbin'\n";
++  }
++}
++
++## Run user hook script here, if any
++if (-x "$header_postinst_hook") {
++  &run_hook("postinst", $header_postinst_hook);
++}
++
++if (-d "/etc/kernel/header_postinst.d") {
++  print STDERR "Examining /etc/kernel/header_postinst.d.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/header_postinst.d") &&
++            die "Failed to process /etc/kernel/header_postinst.d";
++}
++
++if (-d "/etc/kernel/header_postinst.d/$version") {
++  print STDERR "Examining /etc/kernel/header_postinst.d/$version.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/header_postinst.d/$version") &&
++            die "Failed to process /etc/kernel/header_postinst.d/$version";
++}
++
++exit 0;
++
++__END__
+diff --git a/debian/control-scripts/postinst b/debian/control-scripts/postinst
+new file mode 100644
+index 0000000..43de83f
+--- /dev/null
++++ b/debian/control-scripts/postinst
+@@ -0,0 +1,1137 @@
++#! /usr/bin/perl
++# OriginalAuthor : Manoj Srivastava ( srivasta@pilgrim.umass.edu )
++#
++# Customized for Ubuntu by: Ben Collins <bcollins@ubuntu.com>
++
++#use strict; #for debugging
++use Cwd 'abs_path';
++
++$|=1;
++
++# Predefined values:
++my $version           = "=V";
++my $link_in_boot      = "";  # Should be empty, mostly
++my $no_symlink        = "";   # Should be empty, mostly
++my $reverse_symlink   = "";   # Should be empty, mostly
++my $do_symlink        = "Yes";  # target machine defined
++my $do_boot_enable    = "Yes";  # target machine defined
++my $do_bootfloppy     = "Yes";  # target machine defined
++my $do_bootloader     = "Yes";  # target machine defined
++my $move_image        = '';     # target machine defined
++my $kimage            = "=K";   # Should be empty, mostly
++my $loader            = "=L"; # lilo, silo, quik, palo, vmelilo, nettrom, arcboot or delo
++my $image_dir         = "/boot";        # where the image is located
++my $clobber_modules   = '';          # target machine defined
++my $relative_links    = "";          # target machine defined
++my $initrd            = "YES";        # initrd kernel
++my $do_initrd         = '';     # Normally we do not
++my $use_hard_links    = ''; # hardlinks do not work across fs boundaries
++my $postinst_hook     = '';          #Normally we do not
++my $postrm_hook       = '';          #Normally we do not
++my $preinst_hook      = '';          #Normally we do not
++my $prerm_hook        = '';          #Normally we do not
++my $minimal_swap      = '';          # Do not swap symlinks
++my $ignore_depmod_err = '';          # normally we do not
++my $kernel_arch       = "=B";
++my $ramdisk           = "/usr/sbin/update-initramfs";  # List of tools to create initial ram fs.
++my $notifier          = "/usr/share/update-notifier/notify-reboot-required";
++my $package_name      = "linux-image-$version";
++my $explicit_do_loader = 'Yes';
++
++my $Loader          = "NoLOADER"; #
++$Loader             = "LILO"     if $loader =~ /^lilo/io;
++$Loader             = "SILO"     if $loader =~ /^silo/io;
++$Loader             = "QUIK"     if $loader =~ /^quik/io;
++$Loader             = "yaboot"   if $loader =~ /^yaboot/io;
++$Loader             = "PALO"     if $loader =~ /^palo/io;
++$Loader             = "NETTROM"  if $loader =~ /^nettrom/io;
++$Loader             = "VMELILO"  if $loader =~ /^vmelilo/io;
++$Loader             = "ZIPL"     if $loader =~ /^zipl/io;
++$Loader             = "ELILO"    if $loader =~ /^elilo/io;
++$Loader             = "ARCBOOT"  if $loader =~ /^arcboot/io;
++$Loader             = "DELO"     if $loader =~ /^delo/io;
++
++# This should not point to /tmp, because of security risks.
++my $temp_file_name = "/var/log/$loader" . "_log.$$";
++
++#known variables
++my $image_dest      = "/";
++my $realimageloc    = "/$image_dir/";
++my $have_conffile   = "";
++my $silent_modules  = '';
++my $silent_loader   = '';
++my $warn_reboot     = 'Yes';     # Warn that we are installing a version of
++                                 # the kernel we are running
++
++my $modules_base    = '/lib/modules';
++my $CONF_LOC        = '/etc/kernel-img.conf';
++
++# Ignore all invocations except when called on to configure.
++exit 0 unless $ARGV[0] =~ /configure/;
++
++my $DEBUG = 0;
++
++# Do some preliminary sanity checks here to ensure we actually have an
++# valid image dir
++chdir('/')           or die "could not chdir to /:$!\n";
++die "Internal Error: ($image_dir) is not a directory!\n"
++  unless -d $image_dir;
++
++# remove multiple leading slashes; make sure there is at least one.
++$realimageloc  =~ s|^/*|/|o;
++$realimageloc  =~ s|/+|/|o;
++die "Internal Error: ($realimageloc) is not a directory!\n"
++  unless -d $realimageloc;
++
++if (-r "$CONF_LOC" && -f "$CONF_LOC"  ) {
++  if (open(CONF, "$CONF_LOC")) {
++    while (<CONF>) {
++      chomp;
++      s/\#.*$//g;
++      next if /^\s*$/;
++
++      $do_symlink      = "" if /^\s*do_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $no_symlink      = "" if /^\s*no_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $reverse_symlink = "" if /^\s*reverse_symlink\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*image_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*link_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $move_image      = "" if /^\s*move_image\s*=\s*(no|false|0)\s*$/ig;
++      $clobber_modules = '' if /^\s*clobber_modules\s*=\s*(no|false|0)\s*$/ig;
++      $do_boot_enable  = '' if /^\s*do_boot_enable\s*=\s*(no|false|0)\s*$/ig;
++      $do_bootfloppy   = '' if /^\s*do_bootfloppy\s*=\s*(no|false|0)\s*$/ig;
++      $relative_links  = '' if /^\s*relative_links \s*=\s*(no|false|0)\s*$/ig;
++      $do_bootloader   = '' if /^\s*do_bootloader\s*=\s*(no|false|0)\s*$/ig;
++      $explicit_do_loader = '' if /^\s*do_bootloader\s*=\s*(no|false|0)\s*$/ig;
++      $do_initrd       = '' if /^\s*do_initrd\s*=\s*(no|false|0)\s*$/ig;
++      $use_hard_links  = '' if /^\s*use_hard_links\s*=\s*(no|false|0)\s*$/ig;
++      $silent_modules  = '' if /^\s*silent_modules\s*=\s*(no|false|0)\s*$/ig;
++      $silent_loader   = '' if /^\s*silent_loader\s*=\s*(no|false|0)\s*$/ig;
++      $warn_reboot     = '' if /^\s*warn_reboot\s*=\s*(no|false|0)\s*$/ig;
++      $minimal_swap    = '' if /^\s*minimal_swap\s*=\s*(no|false|0)\s*$/ig;
++      $ignore_depmod_err = '' if /^\s*ignore_depmod_err\s*=\s*(no|false|0)\s*$/ig;
++
++      $do_symlink      = "Yes" if /^\s*do_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $no_symlink      = "Yes" if /^\s*no_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $reverse_symlink = "Yes" if /^\s*reverse_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*image_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*link_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $move_image      = "Yes" if /^\s*move_image\s*=\s*(yes|true|1)\s*$/ig;
++      $clobber_modules = "Yes" if /^\s*clobber_modules\s*=\s*(yes|true|1)\s*$/ig;
++      $do_boot_enable  = "Yes" if /^\s*do_boot_enable\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootfloppy   = "Yes" if /^\s*do_bootfloppy\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootloader   = "Yes" if /^\s*do_bootloader\s*=\s*(yes|true|1)\s*$/ig;
++      $explicit_do_loader = "YES" if /^\s*do_bootloader\s*=\s*(yes|true|1)\s*$/ig;
++      $relative_links  = "Yes" if /^\s*relative_links\s*=\s*(yes|true|1)\s*$/ig;
++      $do_initrd       = "Yes" if /^\s*do_initrd\s*=\s*(yes|true|1)\s*$/ig;
++      $use_hard_links  = "Yes" if /^\s*use_hard_links\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_modules  = 'Yes' if /^\s*silent_modules\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_loader   = 'Yes' if /^\s*silent_loader\s*=\s*(yes|true|1)\s*$/ig;
++      $warn_reboot     = 'Yes' if /^\s*warn_reboot\s*=\s*(yes|true|1)\s*$/ig;
++      $minimal_swap    = 'Yes' if /^\s*minimal_swap\s*=\s*(yes|true|1)\s*$/ig;
++      $ignore_depmod_err = 'Yes' if /^\s*ignore_depmod_err\s*=\s*(yes|true|1)\s*$/ig;
++
++      $image_dest      = "$1"  if /^\s*image_dest\s*=\s*(\S+)/ig;
++      $postinst_hook   = "$1"  if /^\s*postinst_hook\s*=\s*(\S+)/ig;
++      $postrm_hook     = "$1"  if /^\s*postrm_hook\s*=\s*(\S+)/ig;
++      $preinst_hook    = "$1"  if /^\s*preinst_hook\s*=\s*(\S+)/ig;
++      $prerm_hook      = "$1"  if /^\s*prerm_hook\s*=\s*(\S+)/ig;
++      $ramdisk         = "$1"  if /^\s*ramdisk\s*=\s*(.+)$/ig;
++    }
++    close CONF;
++    $have_conffile = "Yes";
++  }
++}
++
++$initrd = '' if (! -x "$ramdisk");
++
++# For some versions of kernel-package, we had this warning in the
++# postinst, but the rules did not really interpolate the value in.
++# Here is a sanity check.
++my $pattern = "=" . "I";
++$initrd=~ s/^$pattern$//;
++
++if ($link_in_boot) {
++  $image_dest = "/$image_dir/"; # same as realimageloc
++}
++
++# Tack on at least one trainling /
++$image_dest = "$image_dest/";
++$image_dest =~ s|^/*|/|o;
++$image_dest =~ s|/+$|/|o;
++
++if (! -d "$image_dest") {
++  die "Expected Image Destination dir ($image_dest) to be a valid directory!\n";
++}
++
++# sanity
++if (!($do_bootfloppy || $do_bootloader)) {
++  $do_boot_enable = '';
++}
++if ($do_symlink && $no_symlink) {
++  warn "Both do_symlinks and no_symlinks options enabled; disabling no_symlinks\n";
++  $no_symlink = 0;
++}
++
++# most of our work is done in $image_dest (nominally /)
++chdir("$image_dest") or die "could not chdir to $image_dest:$!\n";
++
++# Paranoid check to make sure that the correct value is put in there
++if    (! $kimage)                 { $kimage = "vmlinuz"; } # Hmm. empty
++elsif ($kimage =~ m/^b?uImage$/o) { $kimage = "vmlinuz"; } # these produce vmlinuz
++elsif ($kimage =~ m/^b?zImage$/o) { $kimage = "vmlinuz"; } # these produce vmlinuz
++elsif ($kimage =~ m/^[iI]mage$/o) { my $nop = $kimage;   }
++elsif ($kimage =~ m/^vmlinux$/o)  { my $nop = $kimage;   }
++else                              { $kimage = "vmlinuz"; } # Default
++
++$ENV{KERNEL_ARCH}=$kernel_arch if $kernel_arch;
++
++
++die "Internal Error: Could not find image (" . $realimageloc
++  . "$kimage-$version)\n" unless -e $realimageloc
++  . "$kimage-$version";
++
++# search for the boot loader in the path
++my $loader_exec;
++($loader_exec = $loader)  =~ s|.*/||;
++my ($loaderloc) = grep -x, map "$_/$loader_exec",
++  map { length($_) ? $_ : "." }  split /:/, $ENV{PATH};
++
++
++######################################################################
++######################################################################
++###########        Test whether a relative symlinkwould be OK #######
++######################################################################
++######################################################################
++sub test_relative {
++  my %params = @_;
++  my $cwd;
++
++  die "Internal Error: Missing Required paramater 'Old Dir' "
++    unless $params{'Old Dir'};
++  die "Internal Error: Missing Required paramater New Dir' "
++    unless $params{'New Dir'};
++
++
++  die "Internal Error: No such dir $params{'Old Dir'} "
++    unless -d $params{'Old Dir'};
++  die "Internal Error: No such dir $params{'New Dir'} "
++    unless -d $params{'New Dir'};
++
++  # If the caller specified a test file, and it does not exist try and find
++  # another file to use in its stead.  As we are installing kernels we can
++  # use any versioned file from this kernel which should be in the same place.
++  if (defined $params{'Test File'} and
++      ! -f $params{'Old Dir'} . '/' . $params{'Test File'}) {
++
++      my @possible = glob($params{'Old Dir'} . "/*$version*");
++      if ($#possible >= 0) {
++        $params{'Test File'} = `basename "$possible[0]"`;
++        chomp($params{'Test File'});
++        warn "Test relative: selected $params{'Test File'}"
++          if $DEBUG;
++      }
++  }
++
++  warn "Test relative: testing $params{'Old Dir'} -> $params{'New Dir'}"
++    if $DEBUG;
++  chomp($cwd = `pwd`);
++  chdir ($params{'New Dir'}) or die "Could not chdir to $params{'New Dir'}:$!";
++  my $ok = 0;
++  $params{'Old Dir'}  =~ s|^/*||o;
++  if (-d $params{'Old Dir'} ) {
++    if (defined $params{'Test File'}) {
++      if (-e $params{'Old Dir'} . $params{'Test File'}) {
++        $ok  = 1;
++      }
++    } else {
++      $ok = 1;                  # well, backward compatibility
++    }
++  }
++  chdir ($cwd) or die "Could not chdir to $params{'New Dir'}:$!";
++  return $ok;
++}
++
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++# sub CanonicalizePath {
++#   my $path = join '/', @_;
++#   my @work = split '/', $path;
++#   my @out;
++#   my $is_absolute;
++
++#   if (@work && $work[0] eq "") {
++#     $is_absolute = 1; shift @work;
++#   }
++
++#   while (@work) {
++#     my $seg = shift @work;
++#     if ($seg eq "." || $seg eq "") {
++#     } 
++#     elsif ($seg eq "..") {
++#       if (@out && $out[-1] ne "..") {
++#         pop @out;
++#       } 
++#       else {
++#         # Leading "..", or "../..", etc.
++#         push @out, $seg;
++#       }
++#     } 
++#     else {
++#       push @out, $seg;
++#     }
++#   }
++
++#   unshift @out, "" if $is_absolute;
++#   return join('/', @out);
++# }
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++
++sub spath {
++  my %params = @_;
++
++  die "Missing Required paramater 'Old'" unless $params{'Old'};
++  die "Missing Required paramater 'New'" unless  $params{'New'};
++
++  my @olddir  = split '/', `readlink -q -m $params{'Old'}`;
++  my @newdir  = split '/', `readlink -q -m $params{'New'}`;
++  my @outdir  = @olddir;
++
++  my $out = '';
++  my $i;
++  for ($i = 0; $i <= $#olddir && $i <= $#newdir; $i++) {
++    $out++ if ($olddir[$i] ne $newdir[$i]);
++    shift @outdir unless $out;
++    unshift @outdir, ".." if $out;
++  }
++  if ($#newdir > $#olddir) {
++    for ($i=0; $i < $#newdir; $i++) {
++      unshift @outdir, "..";
++    }
++  }
++  return join ('/', @outdir);
++}
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++
++
++# This routine actually moves the kernel image
++# From: $realimageloc/$kimage-$version (/boot/vmlinuz-2.6.12)
++# To:   $image_dest/$kimage-$version   (/vmlinuz-2.6.12)
++# Note that the image is moved to a versioned destination, but ordinary
++# symlinks we create otherwise are not normally versioned
++sub really_move_image {
++  my $src_dir  = $_[0];
++  my $target   = $_[1];
++  my $dest_dir = $_[2];
++
++  warn "Really move image: src_dir=$src_dir, target=$target,\n destdir=$dest_dir"
++    if $DEBUG;
++  if (-e "$target") {
++    # we should be in dir $dest_dir == $image_dest /, normally
++    rename("$target", "$target.$$") ||
++      die "failed to move " . $dest_dir . "$target:$!";
++    warn "mv $target $target.$$" if $DEBUG;
++  }
++  warn "mv -f $src_dir$target $target" if $DEBUG;
++  my $ret = system("mv -f " . $src_dir . "$target " .
++                   " $target");
++  if ($ret) {
++    die("Failed to move " . $src_dir . "$target to "
++        . $dest_dir . "$target");
++  }
++  # Ok, now we may clobber the previous .old files
++  if (-e "$target.$$") {
++    rename("$target.$$", "$target.old") ||
++      die "failed to move " . $dest_dir . "$target:$!";
++    warn "mv $target.$$ $target " if $DEBUG;
++  }
++}
++
++# Normally called after really_move_image; and only called if we asked for 
++# reversed link this routine reverses the symbolic link that is notmally 
++# created. Since the real kernel image has been moved over to 
++# $image_dest/$kimage-$version. So, this routine links
++# From:   $image_dest/$kimage-$version   (/vmlinuz-2.6.12)
++# To:     $realimageloc/$kimage-$version (/boot/vmlinuz-2.6.12)
++sub really_reverse_link {
++  my $src_dir    = $_[0];
++  my $link_name  = $_[1];
++  my $dest_dir   = $_[2];
++  warn "Really reverse link: src_dir=$src_dir, link name=$link_name\n" .
++    "\tdestdir=$dest_dir" if $DEBUG;
++
++  my $Old = $dest_dir;
++  if (test_relative ('Old Dir' => $Old, 'New Dir' => $src_dir,
++                     'Test File' => "$link_name")) {
++    $Old   =~ s|^/*||o;
++  }
++  # Special case is they are in the same dir
++  my $rel_path = spath('Old' => "$Old", 'New' => "$src_dir" );
++  $Old ="" if $rel_path =~ m/^\s*$/o;
++
++  if ($use_hard_links =~ m/YES/i) {
++    link($Old . "$link_name", $src_dir . "$link_name") ||
++      die("Failed to link " . $dest_dir . "$link_name to " . $src_dir . 
++          "$link_name:$!");
++    warn "ln " . $Old . "$link_name " . $src_dir . "$link_name"  if $DEBUG;
++  }
++  else {
++    symlink($Old . "$link_name", $src_dir . "$link_name") ||
++      die("Failed to symbolic-link " . $dest_dir . "$link_name to " . $src_dir
++          . "$link_name:$!");
++    warn "ln -s " . $Old . "$link_name " . $src_dir . "$link_name" if $DEBUG;
++  }
++}
++
++# This routine is invoked if there is a symbolic link in place
++# in $image_dest/$kimage -- so a symlink exists in the destination.
++# What we are trying to determine is if we need to move the symbolic link over
++# to the the .old location
++sub move_p {
++  my $kimage     = $_[0];       # Name of the symbolic link
++  my $image_dest = $_[1];       # The directory the links goes into
++  my $image_name = $_[2]; 
++  my $src_dir    = $_[3]; 
++  my $force_move = 0;
++  warn "Move?: kimage=$kimage, image_dest=$image_dest, \n" .
++    "\timage_name=$image_name, src_dir=$src_dir" if $DEBUG;
++
++  if ($no_symlink || $reverse_symlink) {
++    # we do not want links, yet we have a symbolic link here!
++    warn "found a symbolic link in " . $image_dest . "$kimage \n" .
++      "even though no_symlink is defined\n" if $no_symlink;
++    warn "found a symbolic link in " . $image_dest . "$kimage \n" .
++      "even though reverse_symlink is defined\n" if $reverse_symlink;
++    # make sure we change this state of affairs
++    $force_move = 1;
++    return $force_move;
++  }
++
++  warn "DEBUG: OK. We found symlink, and we should have a symlink here.\n"
++    if $DEBUG;
++  my $vmlinuz_target = readlink "$kimage";
++  my $real_target = '';
++  my $target = `readlink -q -m "${realimageloc}${kimage}-${version}"`;
++  $real_target = abs_path($vmlinuz_target) if defined($vmlinuz_target);
++
++  if (!defined($vmlinuz_target) || ! -f "$real_target") {
++    # what, a dangling symlink?
++    warn "The link "  . $image_dest . "$kimage is a dangling link" .
++      "to $real_target\n";
++    $force_move = 1;
++    return $force_move;
++  }
++
++
++  warn "DEBUG: The link $kimage points to ($vmlinuz_target)\n" if $DEBUG;
++  warn "DEBUG: ($vmlinuz_target) is really ($real_target)\n" if $DEBUG;
++  my $cwd;
++  chomp ($cwd=`pwd`);
++  if ($vmlinuz_target !~ m|^/|o) {
++    $vmlinuz_target = $cwd . "/" . $vmlinuz_target;
++    $vmlinuz_target =~ s|/+|/|o;
++  }
++  $vmlinuz_target = `readlink -q -m $vmlinuz_target`;
++
++  if ("$vmlinuz_target" ne "$target") {
++    warn "DEBUG: We need to handle this.\n" if $DEBUG;
++    if ($minimal_swap) {
++      warn "DEBUG: Minimal swap.\n" if $DEBUG;
++      if (-l "$kimage.old") {
++        warn "DEBUG: There is an old link at $kimage.old\n" if $DEBUG;
++        my $old_target = readlink "$kimage.old";
++        my $real_old_target = '';
++        $real_old_target=abs_path($old_target) if defined ($old_target);
++
++        if ($real_old_target  && -f "$real_old_target") {
++          if ($old_target !~ m|^/|o) {
++            $old_target = $cwd . "/" . $old_target;
++            $old_target =~ s|/+|/|o;
++          }
++          $old_target = `readlink -q -m $old_target`;
++          if ("$old_target"  ne "$target") {
++            $force_move = 1;
++            warn "DEBUG: Old link ($old_target) does not point to us ($target)\n"
++              if $DEBUG;
++          } 
++          else {            # The .old points to the current
++            warn "$kimage.old --> $target -- doing nothing";
++            $force_move = 0;
++          }
++        } 
++        else { 
++          warn "DEBUG: Well, the old link does not exist -- so we move\n"
++            if $DEBUG;
++          $force_move = 1;
++        }
++      } 
++      else {
++        warn "DEBUG: No .old link -- OK to move\n"
++          if $DEBUG;
++        $force_move = 1;
++      }
++    } 
++    else {
++      warn "DEBUG: ok, minimal swap is no-- so we move.\n"
++        if $DEBUG;
++      $force_move = 1;
++    }
++  }
++  else {                  # already have proper link
++    warn "$kimage($vmlinuz_target) points to $target ($real_target) -- doing nothing";
++    $force_move = 0;
++  }
++  return $force_move;
++}
++
++
++# This routine moves the symbolic link around (/vmlinuz -> /vmlinuz.old)
++# It pays attention to whether we should the fact whether we should be using
++# hard links or not.
++sub really_move_link {
++  my $kimage     = $_[0];       # Name of the symbolic link
++  my $image_dest = $_[1];       # The directory the links goes into
++  my $image_name = $_[2]; 
++  my $src_dir    = $_[3]; 
++  warn "really_move_link: kimage=$kimage, image_dest=$image_dest\n" .
++    "\t image_name=$image_name, src_dir=$src_dir" if $DEBUG;
++
++  # don't clobber $kimage.old quite yet
++  rename("$kimage", "$kimage.$$") ||
++    die "failed to move " . $image_dest . "$kimage:$!";
++  warn "mv $kimage $kimage.$$" if $DEBUG;
++  my $Old = $src_dir;
++  my $cwd;
++
++  chomp($cwd=`pwd`);
++  if (test_relative ('Old Dir' => $Old, 'New Dir' => $cwd,
++                     'Test File' => "$image_name")) {
++    $Old   =~ s|^/*||o;
++  }
++  # Special case is they are in the same dir
++  my $rel_path = spath('Old' => "$Old", 'New' => "$cwd" );
++  $Old ="" if $rel_path =~ m/^\s*$/o;
++
++  if ($use_hard_links =~ m/YES/i) {
++    warn "ln ${Old}${image_name} $kimage" if $DEBUG;
++    if (! link("${Old}${image_name}", "$kimage")) {
++      rename("$kimage.$$", "$kimage");
++      die("Failed to link ${Old}${image_name} to " .
++          "${image_dest}${kimage}:$!");
++    }
++  } 
++  else {
++    warn "ln -s ${Old}${image_name} $kimage" if $DEBUG;
++    if (! symlink("${Old}${image_name}", "$kimage")) {
++      rename("$kimage.$$", "$kimage");
++      die("Failed to symbolic-link ${Old}${image_name} to " .
++          "${image_dest}${kimage}:$!");
++    }
++  }
++
++  # Ok, now we may clobber the previous .old file
++  if (-l "$kimage.old" || ! -e "$kimage.old" ) {
++    rename("$kimage.$$", "$kimage.old");
++    warn "mv $kimage.$$ $kimage.old" if $DEBUG;
++  }
++  else {
++    warn "$kimage.old is not a symlink, not clobbering\n";
++    warn "rm $kimage.$$";
++    unlink "$kimage.$$" if $DEBUG;
++  }
++}
++
++# This routine handles a request to do symlinks, but there is no
++# symlink file already there.  Either we are supposed to use copy, or we are
++# installing on a pristine system, or the user does not want symbolic links at
++# all.  We use a configuration file to tell the last two cases apart, creating
++# a config file if needed.
++sub handle_missing_link {
++  my $kimage     = $_[0];       # Name of the symbolic link
++  my $image_dest = $_[1];       # The directory the links goes into
++  my $image_name = $_[2]; 
++  my $src_dir    = $_[3]; 
++  warn "handle_missing_link: kimage=$kimage, image_dest=$image_dest\n" .
++    "\t image_name=$image_name, src_dir=$src_dir" if $DEBUG;
++
++  if ($no_symlink) {
++    warn "cp -a --backup=t $realimageloc$image_name $kimage" if $DEBUG;
++    my $ret = system("cp -a --backup=t " . $realimageloc .
++                     "$image_name "   . " $kimage");
++    if ($ret) {
++      die("Failed to copy " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++  } 
++  elsif ($reverse_symlink) {
++    warn "mv -f $realimageloc$image_name $kimage" if $DEBUG;
++    my $ret = system("mv -f " . $realimageloc . "$image_name "
++                     . "$kimage");
++    if ($ret) {
++      die("Failed to move " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++  } 
++  else {
++    if (! $have_conffile) {
++      my $ret;
++      my $answer='';
++      $do_symlink = "Yes";
++
++      if (open(CONF, ">$CONF_LOC")) {
++        print CONF "# Kernel Image management overrides\n";
++        print CONF "# See kernel-img.conf(5) for details\n";
++        if ($loader =~ /palo/i) {
++          print CONF "link_in_boot = Yes\n";
++          print CONF "do_symlinks = Yes\n";
++          print CONF "relative_links = Yes\n";
++          print CONF "do_bootloader = No\n";
++        } else {
++          print CONF "do_symlinks = $do_symlink\n";
++        }
++        close CONF;
++      }
++      $have_conffile = "Yes";
++    }
++  }
++
++  if (! $no_symlink && $do_symlink =~ /Yes/i) {
++    my $Old = $realimageloc;
++    my $New = $image_dest;
++    my $Name = "$image_name";
++    my $Link_Dest = "$kimage";
++
++    if ($reverse_symlink) {
++      $Old = $image_dest;
++      $New = $realimageloc;
++      $Name = "$kimage";
++      $Link_Dest = $realimageloc . "$image_name";
++    }
++    if (test_relative ('Old Dir' => $Old,
++                       'New Dir' => $New,
++                       'Test File' => $Name)) {
++      $Old   =~ s|^/*||o;
++    }
++    # Special case is they are in the same dir
++    my $rel_path = spath('Old' => "$Old", 'New' => "$New" );
++    $Old ="" if $rel_path =~ m/^\s*$/o;
++
++    symlink($Old . "$Name", "$Link_Dest") ||
++      die("Failed to symbolic-link ${Old}$Name to $Link_Dest:$!");
++    warn "ln -s ${Old}$Name $Link_Dest" if $DEBUG;
++
++  }
++}
++
++# This routine handles the rest of the cases, where the user has requested 
++# non-traditional handling, like using cp, or reverse symlinks, or hard links.
++sub handle_non_symlinks {
++  my $kimage     = $_[0];       # Name of the symbolic link
++  my $image_dest = $_[1];       # The directory the links goes into
++  my $image_name = $_[2]; 
++  my $src_dir    = $_[3]; 
++  warn "handle_non_link: kimage=$kimage, image_dest=$image_dest\n" .
++    "\t image_name=$image_name, src_dir=$src_dir" if $DEBUG;
++
++  # Save the current image. We do this in all four cases
++  rename("$kimage", "$kimage.$$") || 
++    die "failed to move " . $image_dest . "$kimage:$!";
++  warn "mv $kimage $kimage.$$" if $DEBUG;
++
++  ##,#### 
++  # case One
++  #`####
++  if ($no_symlink) {
++    # Maybe /$image_dest is on a dos system?
++    warn "cp -a --backup=t $realimageloc$image_name $kimage" if $DEBUG;
++    my $ret = system("cp -a --backup=t " . $realimageloc
++                     . "$image_name " . "$kimage");
++    if ($ret) {
++      if (-e "$kimage.$$") {
++        rename("$kimage.$$", "$kimage");
++        warn "mv $kimage.$$ $kimage" if $DEBUG;
++      }
++      die("Failed to copy " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++  }
++  ##,#### 
++  # case Two
++  #`####
++  elsif ($reverse_symlink) {  # Maybe /$image_dest is on a dos system?
++    warn "mv -f  $realimageloc$image_name $kimage" if $DEBUG;
++    my $ret = system("mv -f " . $realimageloc . "$image_name "
++                     . $image_dest . "$kimage");
++    if ($ret) {
++      if (-e "$kimage.$$") {
++        rename("$kimage.$$", "$kimage");
++        warn "mv $kimage.$$ $kimage" if $DEBUG;
++      }
++      die("Failed to move " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++    my $Old = $image_dest;
++    if (test_relative ('Old Dir' => $Old, 'New Dir' => $realimageloc,
++                       'Test File' => "$kimage")) {
++      $Old   =~ s|^/*||o;
++    }
++    # Special case is they are in the same dir
++    my $rel_path = spath('Old' => "$Old", 'New' => "$realimageloc" );
++    $Old ="" if $rel_path =~ m/^\s*$/o;
++
++    if ($use_hard_links =~ m/YES/i) {
++      warn "ln " . $Old . "$kimage " . $realimageloc . "$image_name" if $DEBUG;
++      if (! link($Old . "$kimage", $realimageloc . "$image_name")) {
++        warn "Could not link " . $image_dest .
++          "$kimage to $image_name :$!";
++      }
++    }
++    else {
++      warn "ln -s " . $Old . "$kimage " . $realimageloc . "$image_name" if $DEBUG;
++      if (! symlink($Old . "$kimage", $realimageloc . "$image_name")) {
++        warn "Could not symlink " . $image_dest .
++          "$kimage to $image_name :$!";
++      }
++    }
++  }
++  ##,####
++  # case Three
++  #`####
++  elsif ($use_hard_links =~ m/YES/i ) {
++    # Ok then. this ought to be a hard link, and hence fair game
++    # don't clobber $kimage.old quite yet
++    my $Old = $realimageloc;
++    my $cwd;
++    chomp($cwd=`pwd`);
++    if (test_relative ('Old Dir' => $Old, 'New Dir' => $cwd,
++                       'Test File' => "$image_name")) {
++      $Old   =~ s|^/*||o;
++    }
++    # Special case is they are in the same dir
++    my $rel_path = spath('Old' => "$Old", 'New' => "$cwd" );
++    $Old ="" if $rel_path =~ m/^\s*$/o;
++
++    warn "ln " . $Old . "$image_name " . "$kimage" if $DEBUG;
++    if (! link($Old . "$image_name", "$kimage")) {
++      warn "mv $kimage.$$ $kimage" if $DEBUG;
++      rename("$kimage.$$", "$kimage");
++      die("Failed to link " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++  }
++  ##,####
++  # case Five!?!
++  #`####
++  elsif ($do_symlink) {
++    # Ok then. this ought to be a symlink, and hence fair game
++    # don't clobber $kimage.old quite yet
++    my $Old = $realimageloc;
++    my $cwd;
++    chomp($cwd=`pwd`);
++    if (test_relative ('Old Dir' => $Old, 'New Dir' => $cwd,
++                       'Test File' => "$image_name")) {
++      $Old   =~ s|^/*||o;
++    }
++    # Special case is they are in the same dir
++    my $rel_path = spath('Old' => "$Old", 'New' => "$cwd" );
++    $Old ="" if $rel_path =~ m/^\s*$/o;
++
++    warn "symlink " . $Old . "$image_name " . "$kimage" if $DEBUG;
++    if (! symlink($Old . "$image_name", "$kimage")) {
++      warn "mv $kimage.$$ $kimage" if $DEBUG;
++      rename("$kimage.$$", "$kimage");
++      die("Failed to link " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++  }
++  ##,####
++  # case Four
++  #`####
++  else {
++    # We just use cp
++    warn "cp -a --backup=t $realimageloc$image_name $kimage" if $DEBUG;
++    my $ret = system("cp -a --backup=t " . $realimageloc
++                     . "$image_name " . "$kimage");
++    if ($ret) {
++      if (-e "$kimage.$$") {
++        warn "mv $kimage.$$ $kimage" if $DEBUG;
++        rename("$kimage.$$", "$kimage");
++      }
++      die("Failed to copy " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++  }
++  # Ok, now we may clobber the previous .old file
++  warn "mv $kimage.$$ $kimage.old if -e $kimage.$$" if $DEBUG;
++  rename("$kimage.$$", "$kimage.old") if -e "$kimage.$$";
++}
++
++# This routine is responsible for setting up the symbolic links
++# So, the actual kernel image lives in
++# $realimageloc/$image_name (/boot/vmlinuz-2.6.12).
++# This routine creates symbolic links in $image_dest/$kimage (/vmlinuz)
++sub image_magic {
++  my $kimage     = $_[0];       # Name of the symbolic link
++  my $image_dest = $_[1];       # The directory the links goes into
++  my $image_name = "$kimage-$version";
++  my $src_dir    = $realimageloc;
++  warn "image_magic: kimage=$kimage, image_dest=$image_dest\n" .
++    "\t image_name=$image_name, src_dir=$src_dir" if $DEBUG;
++
++  # Well, in any case, if the destination (the symlink we are trying
++  # to create) is a directory, we should do nothing, except throw a
++  # diagnostic.
++  if (-d "$kimage" ) {
++    die ("Hmm. $kimage is a directory, which I did not expect.  I am\n" .
++         "trying to create a symbolic link with that name linked to \n" .
++         "$image_dest . Since a directory exists here, my assumptions \n" .
++         "are way off, and I am aborting.\n" );
++    exit (3);
++  }
++
++  if ($move_image) {   # Maybe $image_dest is in on dos, or something?
++    #                   source dir,    link name,        dest dir
++    really_move_image(  $realimageloc, $image_name, $image_dest);
++    really_reverse_link($realimageloc, $image_name, $image_dest)
++      if $reverse_symlink;
++    return;
++  }
++
++  if (-l "$kimage") {           # There is a symbolic link
++    warn "DEBUG: There is a symlink for $kimage\n" if $DEBUG;
++    my $force_move = move_p($kimage, $image_dest, $image_name, $src_dir);
++
++    if ($force_move) {
++      really_move_link($kimage, $image_dest, $image_name, $src_dir);
++    }
++  }
++  elsif (! -e "$kimage") {
++    # Hmm. Pristine system? How can that be? Installing from scratch?
++    # Or maybe the user does not want a symbolic link here.
++    # Possibly they do not want a link here. (we should be in /
++    # here[$image_dest, really]
++    handle_missing_link($kimage, $image_dest, $image_name, $src_dir);
++  }
++  elsif (-e "$kimage" ) {
++    # OK, $kimage exists -- but is not a link
++    handle_non_symlinks($kimage, $image_dest, $image_name, $src_dir);
++  }
++}
++
++######################################################################
++######################################################################
++######################################################################
++######################################################################
++
++# We may not have any modules installed
++if ( -d "$modules_base/$version" ) {
++  print STDERR "Running depmod.\n";
++  my $ret = system("depmod -a $version");
++  if ($ret) {
++    print STDERR "Failed to run depmod\n";
++    exit(1);
++  }
++}
++
++
++
++sub find_initrd_tool {
++  my $hostversion = shift;
++  my $version = shift;
++  print STDERR "Finding valid ramdisk creators.\n";
++  my @ramdisks =
++    grep {
++      my $args = 
++        "$_ " .
++          "--supported-host-version=$hostversion " .
++            "--supported-target-version=$version " .
++              "1>/dev/null 2>&1"
++                ;
++      system($args) == 0;
++    }
++      split (/[:,\s]+/, $ramdisk);
++}
++
++# The initrd symlink should probably be in the same dir that the
++# symlinks are in
++if ($initrd) {
++  my $success = 0;
++
++  # Update-initramfs is called slightly different than mkinitrd and
++  # mkinitramfs. XXX It should really be made compatible with this stuff
++  # some how.
++  my $upgrading = 1;
++  if (! defined $ARGV[1] || ! $ARGV[1] || $ARGV[1] =~ m/<unknown>/og) {
++    $upgrading = 0;
++  }
++  my $ret = system("$ramdisk " . ($upgrading ? "-u" : "-c") . " -k " . $version . " >&2");
++  $success = 1 unless $ret;
++  die "Failed to create initrd image.\n" unless $success;
++  if (! defined $ARGV[1] || ! $ARGV[1] || $ARGV[1] =~ m/<unknown>/og) {
++    image_magic("initrd.img", $image_dest);
++  }
++  else {
++    lstat("initrd.img");
++    if (! -e _) {
++      handle_missing_link("initrd.img", $image_dest, "initrd.img-$version",
++                          $realimageloc);
++    }
++    else {
++      print STDERR
++        "Not updating initrd symbolic links since we are being updated/reinstalled \n";
++      print STDERR
++        "($ARGV[1] was configured last, according to dpkg)\n";
++    }
++  }
++
++  if ($initrd && -l "initrd" ) {
++    unlink "initrd";
++  }
++
++  if ($initrd && -l "$image_dir/initrd" && ! $link_in_boot) {
++    unlink "$image_dir/initrd";
++  }
++}
++else {                        # Not making an initrd emage
++  if (-l "initrd.img") {
++    # Ooh, last image was an initrd image? in any case, we should move it. 
++    my $target = readlink "initrd.img";
++    my $real_target = '';
++    $real_target = abs_path($target) if defined ($target);
++
++    if (!defined($target) || ! -f "$real_target") {
++      # Eh. dangling link. can safely be removed.
++      unlink("initrd.img");
++    } else {
++      if (-l "initrd.img.old" || ! -e "initrd.img.old" ) {
++        rename("initrd.img", "initrd.img.old");
++      } else {
++        warn "initrd.img.old is not a symlink, not clobbering\n";
++        unlink("initrd.img");
++      }
++    }
++  }
++}
++
++# Warn of a reboot
++if (-x $notifier) {
++  system($notifier);
++}
++
++# Let programs know not to hibernate if the kernel that would be used for
++# resume-from-hibernate is likely to differ from the currently running kernel.
++system("mountpoint -q /var/run");
++if ($? eq 0) {
++	system("touch /var/run/do-not-hibernate");
++}
++
++# Only change the symlinks if we are not being upgraded
++if (! defined $ARGV[1] || ! $ARGV[1] || $ARGV[1] =~ m/<unknown>/og) {
++  image_magic($kimage, $image_dest);
++}
++else {
++  lstat("$kimage");
++  if (! -e _) {
++    handle_missing_link($kimage, $image_dest, "$kimage-$version", 
++                        $realimageloc);
++  }
++  else {
++    print STDERR
++      "Not updating image symbolic links since we are being updated/reinstalled \n";
++    print STDERR
++      "($ARGV[1] was configured last, according to dpkg)\n";
++  }
++}
++
++# We used to have System.* files in /
++if (-e "/System.map" || -e "/System.old") {
++  unlink '/System.map' if -e '/System.map';
++  unlink '/System.old' if -e '/System.old';
++}
++
++# creating some info about kernel and initrd
++if ($DEBUG) {
++  my $ksize=sprintf("%.0f",(stat($realimageloc .
++                                 "$kimage-$version"))[7]/1024)."kB";
++  my $initrdsize='';
++  if ($initrd) {
++    $initrdsize=sprintf("%.0f",(stat($realimageloc .
++                                     "initrd.img-$version"))[7]/1024)."kB";
++  }
++
++  print STDERR <<"EOMSG";
++A new kernel image has been installed at $realimageloc$kimage-$version
++ (Size: $ksize)
++
++Symbolic links, unless otherwise specified, can be found in $image_dest
++
++EOMSG
++  ;
++
++  if ($initrd) {
++    print STDERR <<"EOMSGA";
++
++ Initial rootdisk image: ${realimageloc}initrd.img-$version (Size: $initrdsize)
++EOMSGA
++    ;
++  }
++}
++
++# set the env var stem
++$ENV{'STEM'} = "linux";
++sub exec_script {
++  my $type   = shift;
++  my $script = shift;
++  print STDERR "Running $type hook script $script.\n";
++  system ("$script $version $realimageloc$kimage-$version") &&
++    print STDERR "User $type hook script [$script] ";
++  if ($?) {
++    if ($? == -1) {
++      print STDERR "failed to execute: $!\n";
++    }
++    elsif ($? & 127) {
++      printf STDERR "died with signal %d, %s coredump\n",
++        ($? & 127),  ($? & 128) ? 'with' : 'without';
++    }
++    else {
++      printf STDERR "exited with value %d\n", $? >> 8;
++    }
++    exit $? >> 8;
++  }
++}
++sub run_hook {
++  my $type   = shift;
++  my $script = shift;
++  if ($script =~ m,^/,) {
++    # Full path provided for the hook script
++    if (-x "$script") {
++      &exec_script($type,$script);
++    }
++    else {
++      die "The provided $type hook script [$script] could not be run.\n";
++    }
++  }
++  else {
++    # Look for it in a safe path
++    for my $path ('/bin', '/sbin', '/usr/bin', '/usr/sbin') {
++      if (-x "$path/$script") {
++        &exec_script($type, "$path/$script");
++        return 0;
++      }
++    }
++    # No luck
++    print STDERR "Could not find $type hook script [$script].\n";
++    die "Looked in: '/bin', '/sbin', '/usr/bin', '/usr/sbin'\n";
++  }
++}
++
++my $options;
++for (@ARGV) {
++	s,','\\'',g;
++	$options .= " '$_'";
++}
++$ENV{'DEB_MAINT_PARAMS'}="$options";
++
++## Run user hook script here, if any
++if ($postinst_hook) {
++  &run_hook("postinst", $postinst_hook);
++}
++
++if (-d "/etc/kernel/postinst.d") {
++  print STDERR "Examining /etc/kernel/postinst.d.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/postinst.d") &&
++            die "Failed to process /etc/kernel/postinst.d";
++}
++
++if (-d "/etc/kernel/postinst.d/$version") {
++  print STDERR "Examining /etc/kernel/postinst.d/$version.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/postinst.d/$version") &&
++            die "Failed to process /etc/kernel/postinst.d/$version";
++}
++
++LOADER: {
++  last unless $do_boot_enable; # Exit if explicitly asked to
++
++  last if $loader =~ /silo/i; # SILO does not have to be executed.
++  last if $loader =~ /yaboot/i; # yaboot does not have to be executed.
++  last if $loader =~ /milo/i; # MILO does not have to be executed.
++  last if $loader =~ /nettrom/i; # NETTROM does not have to be executed.
++  last if $loader =~ /arcboot/i; # ARCBOOT does not have to be executed.
++  last if $loader =~ /delo/i; # DELO does not have to be executed.
++  last if $loader =~ /quik/i; # maintainer asked quik invocation to be ignored
++
++  last unless $loaderloc;
++  last unless -x $loaderloc;
++  last unless $do_bootloader;
++
++  if (-T "/etc/$loader.conf") {
++    # Trust and use the existing lilo.conf.
++    print STDERR "You already have a $Loader configuration in /etc/$loader.conf\n";
++    my $ret = &run_lilo();
++    exit $ret if $ret;
++  }
++}
++
++
++sub run_lilo (){
++  my $ret;
++  # Try and figure out if the user really wants lilo to be run --
++  # since the default is to run the boot laoder, which is ! grub -- but
++  # the user may be using grub now, and not changed the default.
++
++  # So, if the user has explicitly asked for the loader to be run, or
++  # if there is no postinst hook, or if there is no grub installed --
++  # we are OK. Or else, we ask.
++  if ($explicit_do_loader || (! ($postinst_hook && -x '/usr/sbin/grub')))  {
++    print STDERR "Running boot loader as requested\n";
++  } else {
++    print STDERR "Ok, not running $loader\n";
++  }
++  if ($loader =~ /^lilo/io or $loader =~ /vmelilo/io) {
++    print STDERR "Testing $loader.conf ... \n";
++    unlink $temp_file_name;     # security
++    $ret = system("$loaderloc -t >$temp_file_name 2>&1");
++    if ($ret) {
++      print STDERR "Boot loader test failed\n";
++      return $ret;
++    }
++    unlink "$temp_file_name";
++    print STDERR "Testing successful.\n";
++    print STDERR "Installing the ";
++    print STDERR "partition " if $loader =~ /^lilo/io;
++    print STDERR "boot sector... \n";
++  }
++
++  print STDERR "Running $loaderloc  ... \n";
++  if ($loader =~ /^elilo/io) {
++    $ret = system("$loaderloc 2>&1 | tee $temp_file_name");
++  } else {
++    $ret = system("$loaderloc >$temp_file_name 2>&1");
++  }
++  if ($ret) {
++    print STDERR "Boot loader failed to run\n";
++    return $ret;
++  }
++  unlink $temp_file_name;
++  print STDERR "Installation successful.\n";
++  return 0;
++}
++
++exit 0;
++
++__END__
++
+diff --git a/debian/control-scripts/postrm b/debian/control-scripts/postrm
+new file mode 100644
+index 0000000..9879178
+--- /dev/null
++++ b/debian/control-scripts/postrm
+@@ -0,0 +1,363 @@
++#! /usr/bin/perl
++#                              -*- Mode: Cperl -*- 
++# image.postrm --- 
++# Author           : Manoj Srivastava ( srivasta@glaurung.green-gryphon.com ) 
++# Created On       : Sat May 15 11:05:13 1999
++# Created On Node  : glaurung.green-gryphon.com
++# Last Modified By : Manoj Srivastava
++# Last Modified On : Wed Sep 13 11:26:19 2006
++# Last Machine Used: glaurung.internal.golden-gryphon.com
++# Update Count     : 57
++# Status           : Unknown, Use with caution!
++# HISTORY          : 
++# Description      : 
++# 
++#     $Id: image.postrm,v 1.31 2003/10/07 16:24:20 srivasta Exp $
++#
++
++
++# 
++#use strict; #for debugging
++use Cwd 'abs_path';
++
++$|=1;
++
++# Predefined values:
++my $version           = "=V";
++my $link_in_boot      = "";	# Should be empty, mostly
++my $no_symlink        = "";	# Should be empty, mostly
++my $reverse_symlink   = "";	# Should be empty, mostly
++my $do_symlink        = "Yes";	# target machine defined
++my $do_boot_enable    = "Yes";	# target machine defined
++my $do_bootfloppy     = "Yes";	# target machine defined
++my $do_bootloader     = "Yes";	# target machine defined
++my $move_image        = '';       # target machine defined
++my $kimage            = "=K";	# Should be empty, mostly
++my $loader            = "=L";     # lilo, silo, quik, palo, vmelilo, or nettrom
++my $image_dir         = "/boot";     # where the image is located
++my $clobber_modules   = '';       # target machine defined
++my $initrd            = "YES";     # initrd kernel
++my $do_initrd         = '';       # Normally, we don't
++my $warn_initrd       = 'YES';    # Normally we do
++my $use_hard_links    = '';       # hardlinks do not work across fs boundaries
++my $postinst_hook     = '';       #Normally we do not
++my $postrm_hook       = '';       #Normally we do not
++my $preinst_hook      = '';       #Normally we do not
++my $prerm_hook        = '';       #Normally we do not
++my $minimal_swap      = '';       # Do not swap symlinks
++my $ignore_depmod_err = '';	# normally we do not
++my $relink_build_link = 'YES';	# There is no harm in checking the link
++my $force_build_link  = '';	# we shall not create a dangling link
++my $kernel_arch       = "=B";
++my $ramdisk           = "/usr/sbin/update-initramfs";
++my $package_name    = "linux-image-$version";
++
++my $Loader          = "NoLOADER"; # 
++$Loader             = "LILO"     if $loader =~ /^lilo/io;
++$Loader             = "SILO"     if $loader =~ /^silo/io;
++$Loader             = "QUIK"     if $loader =~ /^quik/io;
++$Loader             = "yaboot"   if $loader =~ /^yaboot/io;
++$Loader             = "PALO"     if $loader =~ /^palo/io;
++$Loader             = "NETTROM"  if $loader =~ /^nettrom/io;
++$Loader             = "VMELILO"  if $loader =~ /^vmelilo/io;
++$Loader             = "ZIPL"     if $loader =~ /^zipl/io;
++$Loader             = "ELILO"    if $loader =~ /^elilo/io;
++
++
++# This should not point to /tmp, because of security risks.
++my $temp_file_name = "/var/log/$loader" . "_log.$$";
++
++#known variables
++my @boilerplate     = ();
++my @silotemplate    = ();
++my @quiktemplate    = ();
++my @palotemplate    = ();
++my @vmelilotemplate = ();
++my $bootdevice      = '';
++my $rootdevice      = '';
++my $rootdisk        = '';
++my $rootpartition   = '';
++my $image_dest      = "/";
++my $realimageloc    = "/$image_dir/";
++my $have_conffile   = "";
++my $CONF_LOC        = '/etc/kernel-img.conf';
++my $relative_links = '';
++my $silent_modules  = '';
++my $silent_loader   = '';
++my $warn_reboot     = 'Yes';     # Warn that we are installing a version of
++                                 # the kernel we are running
++
++chdir('/')           or die "could not chdir to /:$!\n";
++# remove multiple leading slashes; make sure there is at least one.
++$realimageloc  =~ s|^/*|/|o;
++$realimageloc  =~ s|/+|/|o;
++
++
++if (-r "$CONF_LOC" && -f "$CONF_LOC"  ) {
++  if (open(CONF, "$CONF_LOC")) {
++    while (<CONF>) {
++      chomp;
++      s/\#.*$//g;
++      next if /^\s*$/;
++
++      $do_symlink      = "" if /^\s*do_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $no_symlink      = "" if /^\s*no_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $reverse_symlink = "" if /^\s*reverse_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*image_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*link_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $move_image      = "" if /^\s*move_image\s*=\s*(no|false|0)\s*$/ig;
++      $clobber_modules = '' if /^\s*clobber_modules\s*=\s*(no|false|0)\s*$/ig;
++      $do_boot_enable  = '' if /^\s*do_boot_enable\s*=\s*(no|false|0)\s*$/ig;
++      $do_bootfloppy   = '' if /^\s*do_bootfloppy\s*=\s*(no|false|0)\s*$/ig;
++      $relative_links  = '' if /^\s*relative_links \s*=\s*(no|false|0)\s*$/ig;
++      $do_bootloader   = '' if /^\s*do_bootloader\s*=\s*(no|false|0)\s*$/ig;
++      $do_initrd       = '' if /^\s*do_initrd\s*=\s*(no|false|0)\s*$/ig;
++      $warn_initrd     = '' if /^\s*warn_initrd\s*=\s*(no|false|0)\s*$/ig;
++      $use_hard_links  = '' if /^\s*use_hard_links\s*=\s*(no|false|0)\s*$/ig;
++      $silent_modules  = '' if /^\s*silent_modules\s*=\s*(no|false|0)\s*$/ig;
++      $silent_loader   = '' if /^\s*silent_loader\s*=\s*(no|false|0)\s*$/ig;
++      $warn_reboot     = '' if /^\s*warn_reboot\s*=\s*(no|false|0)\s*$/ig;
++      $minimal_swap    = '' if /^\s*minimal_swap\s*=\s*(no|false|0)\s*$/ig;
++      $ignore_depmod_err = '' if /^\s*ignore_depmod_err\s*=\s*(no|false|0)\s*$/ig;
++      $relink_build_link = '' if /^\s*relink_build_link\s*=\s*(no|false|0)\s*$/ig;
++      $force_build_link = '' if /^\s*force_build_link\s*=\s*(no|false|0)\s*$/ig;
++
++      $do_symlink      = "Yes" if /^\s*do_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $no_symlink      = "Yes" if /^\s*no_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $reverse_symlink = "Yes" if /^\s*reverse_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*image_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*link_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $move_image      = "Yes" if /^\s*move_image\s*=\s*(yes|true|1)\s*$/ig;
++      $clobber_modules = "Yes" if /^\s*clobber_modules\s*=\s*(yes|true|1)\s*$/ig;
++      $do_boot_enable  = "Yes" if /^\s*do_boot_enable\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootfloppy   = "Yes" if /^\s*do_bootfloppy\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootloader   = "Yes" if /^\s*do_bootloader\s*=\s*(yes|true|1)\s*$/ig;
++      $relative_links  = "Yes" if /^\s*relative_links\s*=\s*(yes|true|1)\s*$/ig;
++      $do_initrd       = "Yes" if /^\s*do_initrd\s*=\s*(yes|true|1)\s*$/ig;
++      $warn_initrd     = "Yes" if /^\s*warn_initrd\s*=\s*(yes|true|1)\s*$/ig;
++      $use_hard_links  = "Yes" if /^\s*use_hard_links\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_modules  = 'Yes' if /^\s*silent_modules\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_loader   = 'Yes' if /^\s*silent_loader\s*=\s*(yes|true|1)\s*$/ig;
++      $warn_reboot     = 'Yes' if /^\s*warn_reboot\s*=\s*(yes|true|1)\s*$/ig;
++      $minimal_swap    = 'Yes' if /^\s*minimal_swap\s*=\s*(yes|true|1)\s*$/ig;
++      $ignore_depmod_err = 'Yes' if /^\s*ignore_depmod_err\s*=\s*(yes|true|1)\s*$/ig;
++      $relink_build_link = 'Yes' if /^\s*relink_build_link\s*=\s*(yes|true|1)\s*$/ig;
++      $force_build_link = 'Yes' if /^\s*force_build_link\s*=\s*(yes|true|1)\s*$/ig;
++
++      $image_dest      = "$1"  if /^\s*image_dest\s*=\s*(\S+)/ig;
++      $postinst_hook   = "$1"  if /^\s*postinst_hook\s*=\s*(\S+)/ig;
++      $postrm_hook     = "$1"  if /^\s*postrm_hook\s*=\s*(\S+)/ig;
++      $preinst_hook    = "$1"  if /^\s*preinst_hook\s*=\s*(\S+)/ig;
++      $prerm_hook      = "$1"  if /^\s*prerm_hook\s*=\s*(\S+)/ig;
++      $ramdisk         = "$1"  if /^\s*ramdisk\s*=\s*(.+)$/ig;
++    }
++    close CONF;
++    $have_conffile = "Yes";
++  }
++}
++
++$initrd = '' if (! -x "$ramdisk");
++
++if ($link_in_boot) {
++  $image_dest = "/$image_dir/";
++  $image_dest =~ s|^/*|/|o;
++}
++
++$image_dest = "$image_dest/";
++$image_dest =~ s|/+$|/|o;
++
++# The destdir may be gone by now.
++if (-d "$image_dest") {
++  chdir("$image_dest") or die "could not chdir to $image_dest:$!\n";
++}
++
++# Paranoid check to make sure that the correct value is put in there
++if (! $kimage)                    {$kimage = "vmlinuz"} # Hmm. empty
++elsif ($kimage =~ m/^b?uImage$/o) {$kimage = "vmlinuz"} # these produce vmlinuz
++elsif ($kimage =~ m/^b?zImage$/o) {$kimage = "vmlinuz"} # these produce vmlinuz
++elsif ($kimage =~ m/^[iI]mage$/o) { my $nop = $kimage;}
++elsif ($kimage =~ m/^vmlinux$/o)  { my $nop = $kimage;}
++else                              {$kimage = "vmlinuz"} # default
++
++$ENV{KERNEL_ARCH}=$kernel_arch if $kernel_arch;
++
++
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++sub remove_sym_link {
++  my $bad_image = $_[0];
++
++  warn "Removing symbolic link $bad_image \n";
++  if ($loader =~ /lilo/i) 
++    {
++      warn "Unless you used the optional flag in lilo, \n";
++    }
++  warn " you may need to re-run your boot loader" . ($loader ? "[$loader]":"")
++    . "\n";
++  # Remove the dangling link
++  unlink "$bad_image";
++}
++
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++sub CanonicalizePath {
++  my $path = join '/', @_;
++  my @work = split '/', $path;
++  my @out;
++  my $is_absolute;
++
++  if (@work && $work[0] eq "") { $is_absolute = 1; shift @work; }
++
++  while (@work) {
++    my $seg = shift @work;
++    if ($seg eq "." || $seg eq "") {
++    } elsif ($seg eq "..") {
++      if (@out && $out[-1] ne "..") {
++        pop @out;
++      } else {
++        # Leading "..", or "../..", etc.
++        push @out, $seg;
++      }
++    } else {
++      push @out, $seg;
++    }
++  }
++
++  unshift @out, "" if $is_absolute;
++  return join('/', @out);
++}
++
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++# This removes dangling symlinks. What do we do about hard links? Surely a 
++# something with the nane $image_dest . "$kimage" ought not to be left behind? 
++sub image_magic {
++  my $kimage = $_[0];
++  my $image_dest = $_[1];
++
++  if (-l "$kimage") {
++    # There is a symbolic link
++    my $force_move = 0;
++    my $vmlinuz_target = readlink "$kimage";
++    my $real_target = '';
++    $real_target = abs_path($vmlinuz_target) if defined ($vmlinuz_target);
++    if (!defined($vmlinuz_target) || ! -f "$real_target") {
++      # what, a dangling symlink?
++      warn "The link "  . $image_dest . "$kimage is a damaged link\n";
++      # Remove the dangling link
++      &remove_sym_link("$kimage");
++    }
++    else {
++      my $canonical_target = CanonicalizePath("$vmlinuz_target");
++      if (! -e $canonical_target) {
++	warn "The link "  . $image_dest . "$kimage is a dangling link\n";
++	&remove_sym_link("$kimage");
++      }
++    }
++  }
++}
++
++# set the env var stem
++$ENV{'STEM'} = "linux";
++
++sub exec_script {
++  my $type   = shift;
++  my $script = shift;
++  print STDERR "Running $type hook script $script.\n";
++  system ("$script $version $realimageloc$kimage-$version") &&
++    print STDERR "User $type hook script [$script] ";
++  if ($?) {
++    if ($? == -1) {
++      print STDERR "failed to execute: $!\n";
++    }
++    elsif ($? & 127) {
++      printf STDERR "died with signal %d, %s coredump\n",
++        ($? & 127),  ($? & 128) ? 'with' : 'without';
++    }
++    else {
++      printf STDERR "exited with value %d\n", $? >> 8;
++    }
++  }
++}
++sub run_hook {
++  my $type   = shift;
++  my $script = shift;
++  if ($script =~ m,^/,) {
++    # Full path provided for the hook script
++    if (-x "$script") {
++      &exec_script($type,$script);
++    }
++    else {
++      warn "The provided $type hook script [$script] could not be run.\n";
++    }
++  }
++  else {
++    # Look for it in a safe path
++    for my $path ('/bin', '/sbin', '/usr/bin', '/usr/sbin') {
++      if (-x "$path/$script") {
++        &exec_script($type, "$path/$script");
++        return 0;
++      }
++    }
++    # No luck
++    print STDERR "Could not find $type hook script [$script].\n";
++    warn "Looked in: '/bin', '/sbin', '/usr/bin', '/usr/sbin'\n";
++  }
++}
++
++my $options;
++for (@ARGV) {
++	s,','\\'',g;
++	$options .= " '$_'";
++}
++$ENV{'DEB_MAINT_PARAMS'}="$options";
++
++## Run user hook script here, if any
++if ($postrm_hook) {
++  &run_hook("postrm", $postrm_hook);
++}
++if (-d "/etc/kernel/postrm.d") {
++  warn "Examining /etc/kernel/postrm.d .\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/postrm.d") &&
++            die "Failed to process /etc/kernel/postrm.d";
++}
++if (-d "/etc/kernel/postrm.d/$version") {
++  warn "Examining /etc/kernel/postrm.d/$version .\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/postrm.d/$version") &&
++            die "Failed to process /etc/kernel/postrm.d/$version";
++}
++
++# check and remove damaged and dangling symlinks
++if ($ARGV[0] !~ /upgrade/) {
++  system("$ramdisk -d -k " . $version . " > /dev/null 2>&1");
++  if (-f $realimageloc . "initrd.img-$version.bak") {
++    unlink $realimageloc . "initrd.img-$version.bak";
++  }
++  image_magic($kimage,          $image_dest);
++  image_magic($kimage . ".old", $image_dest);
++  image_magic("initrd.img",     $image_dest) if $initrd;
++  image_magic("initrd.img.old", $image_dest) if $initrd;
++}
++
++exit 0;
++
++__END__
++
++
++
++
++
++
+diff --git a/debian/control-scripts/preinst b/debian/control-scripts/preinst
+new file mode 100644
+index 0000000..4c70e36
+--- /dev/null
++++ b/debian/control-scripts/preinst
+@@ -0,0 +1,317 @@
++#! /usr/bin/perl
++#                              -*- Mode: Cperl -*-
++# image.preinst ---
++# Author           : Manoj Srivastava ( srivasta@tiamat.datasync.com )
++# Created On       : Sun Jun 14 03:38:02 1998
++# Created On Node  : tiamat.datasync.com
++# Last Modified By : Manoj Srivastava
++# Last Modified On : Sun Sep 24 14:04:42 2006
++# Last Machine Used: glaurung.internal.golden-gryphon.com
++# Update Count     : 99
++# Status           : Unknown, Use with caution!
++# HISTORY          :
++# Description      :
++#
++#
++
++#
++#use strict; #for debugging
++
++use Debconf::Client::ConfModule qw(:all);
++version('2.0');
++my $capb=capb("backup");
++
++$|=1;
++
++# Predefined values:
++my $version         = "=V";
++my $link_in_boot    = "";     # Should be empty, mostly
++my $no_symlink      = "";     # Should be empty, mostly
++my $reverse_symlink = "";     # Should be empty, mostly
++my $do_symlink      = "Yes";	# target machine defined
++my $do_boot_enable  = "Yes";	# target machine defined
++my $do_bootfloppy   = "Yes";	# target machine defined
++my $do_bootloader   = "Yes";	# target machine defined
++my $move_image      = '';       # target machine defined
++my $kimage          = "=K";     # Should be empty, mostly
++my $loader          = "=L";     # lilo, silo, quik, palo, vmelilo, nettrom
++                                # or elilo
++my $image_dir       = "/boot";     # where the image is located
++my $initrd          = "YES";     # initrd kernel
++my $use_hard_links  = '';       # hardlinks do not wirk across fs boundaries
++my $postinst_hook   = '';       #Normally we do not
++my $postrm_hook     = '';       #Normally we do not
++my $preinst_hook    = '';       #Normally we do not
++my $prerm_hook      = '';       #Normally we do not
++my $minimal_swap    = '';       # Do not swap symlinks
++my $ignore_depmod_err = '';    # normally we do not
++my $relink_src_link   = 'YES';	# There is no harm in checking the link
++my $relink_build_link = 'YES'; # There is no harm in checking the link
++my $force_build_link  = '';	 # There is no harm in checking the link
++my $kernel_arch       = "=B";
++my $ramdisk           = "/usr/sbin/update-initramfs";  # List of tools to create initial ram fs.
++my $package_name    = "linux-image-$version";
++
++my $Loader          = "NoLOADER"; #
++$Loader             = "LILO"     if $loader =~ /^lilo/io;
++$Loader             = "SILO"     if $loader =~ /^silo/io;
++$Loader             = "QUIK"     if $loader =~ /^quik/io;
++$Loader             = "yaboot"   if $loader =~ /^yaboot/io;
++$Loader             = "PALO"     if $loader =~ /^palo/io;
++$Loader             = "NETTROM"  if $loader =~ /^nettrom/io;
++$Loader             = "VMELILO"  if $loader =~ /^vmelilo/io;
++$Loader             = "ZIPL"     if $loader =~ /^zipl/io;
++$Loader             = "ELILO"    if $loader =~ /^elilo/io;
++
++
++#known variables
++my @boilerplate     = ();
++my @silotemplate    = ();
++my @quiktemplate    = ();
++my @palotemplate    = ();
++my @vmelilotemplate = ();
++my $bootdevice      = '';
++my $rootdevice      = '';
++my $rootdisk        = '';
++my $rootpartition   = '';
++my $image_dest      = "/";
++my $realimageloc    = "/$image_dir/";
++my $have_conffile   = "";
++my $CONF_LOC        = '/etc/kernel-img.conf';
++my $relative_links  = '';
++my $silent_loader   = '';
++my $warn_reboot     = '';        # Warn that we are installing a version of
++                                 # the kernel we are running
++
++my $modules_base    = '/lib/modules';
++
++die "Pre inst Internal error. Aborting." unless $version;
++
++exit 0 if $ARGV[0] =~ /abort-upgrade/;
++exit 1 unless $ARGV[0] =~ /(install|upgrade)/;
++
++$arch = `uname -i`;
++if ($arch =~ m/86/) {
++	system ("grep -q ' pae ' /proc/cpuinfo");
++	if ($?) {
++			print STDERR "This kernel does not support a non-PAE CPU.\n";
++			exit 1;
++	}
++}
++
++# remove multiple leading slashes; make sure there is at least one.
++$realimageloc  =~ s|^/*|/|o;
++$realimageloc  =~ s|/+|/|o;
++
++if (-r "$CONF_LOC" && -f "$CONF_LOC"  ) {
++  if (open(CONF, "$CONF_LOC")) {
++    while (<CONF>) {
++      chomp;
++      s/\#.*$//g;
++      next if /^\s*$/;
++
++      $do_symlink      = "" if /^\s*do_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $no_symlink      = "" if /^\s*no_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $reverse_symlink = "" if /^\s*reverse_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*image_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*link_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $move_image      = "" if /^\s*move_image\s*=\s*(no|false|0)\s*$/ig;
++      $do_boot_enable  = '' if /^\s*do_boot_enable\s*=\s*(no|false|0)\s*$/ig;
++      $do_bootfloppy   = '' if /^\s*do_bootfloppy\s*=\s*(no|false|0)\s*$/ig;
++      $do_bootloader   = '' if /^\s*do_bootloader\s*=\s*(no|false|0)\s*$/ig;
++      $relative_links  = '' if /^\s*relative_links \s*=\s*(no|false|0)\s*$/ig;
++      $use_hard_links  = '' if /^\s*use_hard_links\s*=\s*(no|false|0)\s*$/ig;
++      $silent_loader   = '' if /^\s*silent_loader\s*=\s*(no|false|0)\s*$/ig;
++      $warn_reboot     = '' if /^\s*warn_reboot\s*=\s*(no|false|0)\s*$/ig;
++      $minimal_swap    = '' if /^\s*minimal_swap\s*=\s*(no|false|0)\s*$/ig;
++      $ignore_depmod_err = '' if /^\s*ignore_depmod_err\s*=\s*(no|false|0)\s*$/ig;
++      $relink_src_link   = '' if /^\s*relink_src_link\s*=\s*(no|false|0)\s*$/ig;
++      $relink_build_link = '' if /^\s*relink_build_link\s*=\s*(no|false|0)\s*$/ig;
++      $force_build_link = '' if /^\s*force_build_link\s*=\s*(no|false|0)\s*$/ig;
++
++      $do_symlink      = "Yes" if /^\s*do_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $no_symlink      = "Yes" if /^\s*no_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $reverse_symlink = "Yes" if /^\s*reverse_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*image_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*link_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $move_image      = "Yes" if /^\s*move_image\s*=\s*(yes|true|1)\s*$/ig;
++      $do_boot_enable  = "Yes" if /^\s*do_boot_enable\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootfloppy   = "Yes" if /^\s*do_bootfloppy\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootloader   = "Yes" if /^\s*do_bootloader\s*=\s*(yes|true|1)\s*$/ig;
++      $relative_links  = "Yes" if /^\s*relative_links\s*=\s*(yes|true|1)\s*$/ig;
++      $use_hard_links  = "Yes" if /^\s*use_hard_links\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_loader   = 'Yes' if /^\s*silent_loader\s*=\s*(yes|true|1)\s*$/ig;
++      $warn_reboot     = 'Yes' if /^\s*warn_reboot\s*=\s*(yes|true|1)\s*$/ig;
++      $minimal_swap    = 'Yes' if /^\s*minimal_swap\s*=\s*(yes|true|1)\s*$/ig;
++      $ignore_depmod_err = 'Yes' if /^\s*ignore_depmod_err\s*=\s*(yes|true|1)\s*$/ig;
++      $relink_src_link   = 'Yes' if /^\s*relink_src_link\s*=\s*(yes|true|1)\s*$/ig;
++      $relink_build_link = 'Yes' if /^\s*relink_build_link\s*=\s*(yes|true|1)\s*$/ig;
++      $force_build_link = 'Yes' if /^\s*force_build_link\s*=\s*(yes|true|1)\s*$/ig;
++
++      $image_dest      = "$1"  if /^\s*image_dest\s*=\s*(\S+)/ig;
++      $postinst_hook   = "$1"  if /^\s*postinst_hook\s*=\s*(\S+)/ig;
++      $postrm_hook     = "$1"  if /^\s*postrm_hook\s*=\s*(\S+)/ig;
++      $preinst_hook    = "$1"  if /^\s*preinst_hook\s*=\s*(\S+)/ig;
++      $prerm_hook      = "$1"  if /^\s*prerm_hook\s*=\s*(\S+)/ig;
++      $ramdisk         = "$1"  if /^\s*ramdisk\s*=\s*(.+)$/ig;
++    }
++    close CONF;
++    $have_conffile = "Yes";
++    $have_conffile = "Yes";	# stop perl complaining
++  }
++}
++
++$initrd = '' if (! -x "$ramdisk");
++
++$ENV{KERNEL_ARCH}=$kernel_arch if $kernel_arch;
++
++# About to upgrade this package from version $2 TO THIS VERSION.
++# "prerm upgrade" has already been called for the old version of
++# this package.
++
++sub find_initrd_tool {
++  my $hostversion = shift;
++  my $version = shift;
++  my @ramdisks =
++    grep {
++      my $args = 
++        "$_ " .
++          "--supported-host-version=$hostversion " .
++            "--supported-target-version=$version " .
++              "1>/dev/null 2>&1"
++                ;
++      system($args) == 0;
++    }
++      split (/[:,\s]+/, $ramdisk);
++}
++
++sub check {
++  my $version = shift;
++  my $lib_modules="$modules_base/$version";
++  my $message = '';
++
++  if (-d "$lib_modules") {
++    opendir(DIR, $lib_modules) || die "can’t opendir $lib_modules: $!";
++    my @children = readdir(DIR);
++    if ($#children > 1) {
++      my @dirs  = grep { -d "$lib_modules/$_" } @children;
++      if ($#dirs > 1) { # we have subdirs
++        my $dir_message='';
++        for my $dir (@dirs) {
++          if ($dir =~/kernel$/) {
++            $dir_message="An older install was detected.\n";
++          }
++          else {
++            $dir_message="Module sub-directories were detected.\n"
++              unless $dir_message;
++          }
++        }
++        $message += $dir_message if $dir_message;
++      }
++
++      my @links = grep { -l "$lib_modules/$_" } @children;
++      if ($#links > -1) {
++        my $links_message = '';
++        for my $link (@links) {
++          next if ($link =~ /^build$/);
++          next if ($link =~ /^source$/);
++          $links_message = "Symbolic links were detected in $modules_base/$version.\n";
++        }
++        $message += $links_message if $links_message;
++      }
++      my @files = grep { -f "$lib_modules/$_" } @children;
++      $message += "Additional files also exist in $modules_base/$version.\n"
++        if ($#files > -1);
++    }
++  }
++  else { $message .= "$lib_modules does not exist. ";}
++  return $message;
++}
++
++if (-d "$modules_base/$version") {
++  my $errors=check($version);
++  warn "Info:\n$errors\n" if $errors;
++}
++
++# set the env var stem
++$ENV{'STEM'} = "linux";
++
++sub exec_script {
++  my $type   = shift;
++  my $script = shift;
++  print STDERR "Running $type hook script $script.\n";
++  system ("$script $version $realimageloc$kimage-$version") &&
++    print STDERR "User $type hook script [$script] ";
++  if ($?) {
++    if ($? == -1) {
++      print STDERR "failed to execute: $!\n";
++    }
++    elsif ($? & 127) {
++      printf STDERR "died with signal %d, %s coredump\n",
++        ($? & 127),  ($? & 128) ? 'with' : 'without';
++    }
++    else {
++      printf STDERR "exited with value %d\n", $? >> 8;
++    }
++    exit $? >> 8;
++  }
++}
++sub run_hook {
++  my $type   = shift;
++  my $script = shift;
++  if ($script =~ m,^/,) {
++    # Full path provided for the hook script
++    if (-x "$script") {
++      &exec_script($type,$script);
++    }
++    else {
++      die "The provided $type hook script [$script] could not be run.\n";
++    }
++  }
++  else {
++    # Look for it in a safe path
++    for my $path ('/bin', '/sbin', '/usr/bin', '/usr/sbin') {
++      if (-x "$path/$script") {
++        &exec_script($type, "$path/$script");
++        return 0;
++      }
++    }
++    # No luck
++    print STDERR "Could not find $type hook script [$script].\n";
++    die "Looked in: '/bin', '/sbin', '/usr/bin', '/usr/sbin'\n";
++  }
++}
++
++
++my $options;
++for (@ARGV) {
++	s,','\\'',g;
++	$options .= " '$_'";
++}
++$ENV{'DEB_MAINT_PARAMS'}="$options";
++
++## Run user hook script here, if any
++if (-x "$preinst_hook") {
++  &run_hook("preinst", $preinst_hook);
++}
++if (-d "/etc/kernel/preinst.d") {
++  print STDERR "Examining /etc/kernel/preinst.d/\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version" .
++          " --arg=$realimageloc$kimage-$version" .
++          " /etc/kernel/preinst.d") &&
++            die "Failed to process /etc/kernel/preinst.d";
++}
++if (-d "/etc/kernel/preinst.d/$version") {
++  print STDERR "Examining /etc/kernel/preinst.d/$version.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version" .
++          " --arg=$realimageloc$kimage-$version" .
++          " /etc/kernel/preinst.d/$version") &&
++            die "Failed to process /etc/kernel/preinst.d/$version";
++}
++print STDERR "Done.\n";
++
++exit 0;
++
++__END__
++
++
+diff --git a/debian/control-scripts/prerm b/debian/control-scripts/prerm
+new file mode 100644
+index 0000000..755247f
+--- /dev/null
++++ b/debian/control-scripts/prerm
+@@ -0,0 +1,313 @@
++#! /usr/bin/perl
++#                              -*- Mode: Perl -*- 
++# image.prerm --- 
++# Author           : root ( root@melkor.pilgrim.umass.edu ) 
++# Created On       : Fri May 17 03:28:59 1996
++# Created On Node  : melkor.pilgrim.umass.edu
++# Last Modified By : Manoj Srivastava
++# Last Modified On : Sat Aug  5 13:14:17 2006
++# Last Machine Used: glaurung.internal.golden-gryphon.com
++# Update Count     : 85
++# Status           : Unknown, Use with caution!
++# HISTORY          : 
++# Description      : 
++# 
++#
++#    $Id: image.prerm,v 1.22 2003/10/07 16:24:20 srivasta Exp $
++#
++# 
++#use strict;
++
++$|=1;
++# Predefined values:
++my $version         = "=V";
++my $link_in_boot    = "";	# Should be empty, mostly
++my $no_symlink      = "";	# Should be empty, mostly
++my $reverse_symlink = "";	# Should be empty, mostly
++my $do_symlinks     = "Yes";	# target machine defined
++my $do_boot_enable  = "Yes";	# target machine defined
++my $do_bootfloppy   = "Yes";	# target machine defined
++my $do_bootloader   = "Yes";	# target machine defined
++my $move_image      = '';       # target machine defined
++my $kimage          = "=K";	# Should be empty, mostly
++my $loader          = "=L";     # lilo, silo, quik, palo, vmelilo, or nettrom
++my $image_dir       = "/boot";     # where the image is located
++my $clobber_modules = '';       # target machine defined
++my $initrd          = "YES";     # initrd kernel
++my $use_hard_links  = '';       # hardlinks do not wirk across fs boundaries
++my $postinst_hook   = '';       #Normally we do not
++my $postrm_hook     = '';       #Normally we do not
++my $preinst_hook    = '';       #Normally we do not
++my $prerm_hook      = '';       #Normally we do not
++my $minimal_swap    = '';       # Do not swap symlinks
++my $ignore_depmod_err = '';	# normally we do not
++my $relink_build_link = 'YES';	# There is no harm in checking the link
++my $force_build_link = '';	# There is no harm in checking the link
++my $kernel_arch       = "=B";
++my $ramdisk           = "/usr/sbin/update-initramfs";
++my $package_name    = "linux-image-$version";
++
++my $Loader          = "NoLOADER"; # 
++$Loader             = "LILO"     if $loader =~ /^lilo/io;
++$Loader             = "SILO"     if $loader =~ /^silo/io;
++$Loader             = "QUIK"     if $loader =~ /^quik/io;
++$Loader             = "yaboot"   if $loader =~ /^yaboot/io;
++$Loader             = "PALO"     if $loader =~ /^palo/io;
++$Loader             = "NETTROM"  if $loader =~ /^nettrom/io;
++$Loader             = "VMELILO"  if $loader =~ /^vmelilo/io;
++$Loader             = "ZIPL"     if $loader =~ /^zipl/io;
++$Loader             = "ELILO"    if $loader =~ /^elilo/io;
++
++
++# This should not point to /tmp, because of security risks.
++my $temp_file_name = "/var/log/$loader" . "_log.$$";
++
++#known variables
++my $image_dest      = "/";
++my $realimageloc    = "/$image_dir/";
++my $have_conffile   = "";
++my $CONF_LOC        = '/etc/kernel-img.conf';
++my $relative_links = '';
++my $silent_loader   = '';
++my $warn_reboot     = 'Yes';     # Warn that we are installing a version of
++                                 # the kernel we are running
++
++# remove multiple leading slashes; make sure there is at least one.
++$realimageloc  =~ s|^/*|/|o;
++$realimageloc  =~ s|/+|/|o;
++
++my $DEBUG = 0;
++
++# Variables used
++my $image='';
++my $ret=0;
++my $seen='';
++my $answer='';
++my $running = '';
++my $WouldInvalidate = 0;
++
++if ($ARGV[0] && ($ARGV[0] =~ /remove/ || $ARGV[0] =~ /upgrade/)) {
++  if (-l "/usr/doc/linux-image-$version") {
++    unlink "/usr/doc/linux-image-$version";
++  }
++}
++
++# Ignore all invocations uxcept when called on to remove
++exit 0 unless ($ARGV[0] && $ARGV[0] =~ /remove/) ;
++
++# Paranoid check to make sure that the correct value is put in there
++if (! $kimage)                    { $kimage = "vmlinuz";} # Hmm. empty
++elsif ($kimage =~ m/^b?uImage$/o) { $kimage = "vmlinuz";} # these produce vmlinuz
++elsif ($kimage =~ m/^b?zImage$/o) { $kimage = "vmlinuz";} # these produce vmlinuz
++elsif ($kimage =~ m/^[iI]mage$/o) { my $nop = $kimage;  }
++elsif ($kimage =~ m/^vmlinux$/o)  { my $nop = $kimage;  }
++else                              { $kimage = "vmlinuz";} # Default
++
++if (-r "$CONF_LOC" && -f "$CONF_LOC"  ) {
++  if (open(CONF, "$CONF_LOC")) {
++    while (<CONF>) {
++      chomp;
++      s/\#.*$//g;
++      next if /^\s*$/;
++
++      $do_symlink      = "" if /^\s*do_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $no_symlink      = "" if /^\s*no_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $reverse_symlink = "" if /^\s*reverse_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*image_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*link_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $move_image      = "" if /^\s*move_image\s*=\s*(no|false|0)\s*$/ig;
++      $clobber_modules = '' if /^\s*clobber_modules\s*=\s*(no|false|0)\s*$/ig;
++      $do_boot_enable  = '' if /^\s*do_boot_enable\s*=\s*(no|false|0)\s*$/ig;
++      $do_bootfloppy   = '' if /^\s*do_bootfloppy\s*=\s*(no|false|0)\s*$/ig;
++      $relative_links  = '' if /^\s*relative_links \s*=\s*(no|false|0)\s*$/ig;
++      $do_bootloader   = '' if /^\s*do_bootloader\s*=\s*(no|false|0)\s*$/ig;
++      $do_initrd       = '' if /^\s*do_initrd\s*=\s*(no|false|0)\s*$/ig;
++      $use_hard_links  = '' if /^\s*use_hard_links\s*=\s*(no|false|0)\s*$/ig;
++      $silent_loader   = '' if /^\s*silent_loader\s*=\s*(no|false|0)\s*$/ig;
++      $warn_reboot     = '' if /^\s*warn_reboot\s*=\s*(no|false|0)\s*$/ig;
++      $minimal_swap    = '' if /^\s*minimal_swap\s*=\s*(no|false|0)\s*$/ig;
++      $ignore_depmod_err = '' if /^\s*ignore_depmod_err\s*=\s*(no|false|0)\s*$/ig;
++      $relink_build_link = '' if /^\s*relink_build_link\s*=\s*(no|false|0)\s*$/ig;
++      $force_build_link = '' if /^\s*force_build_link\s*=\s*(no|false|0)\s*$/ig;
++
++
++      $do_symlink      = "Yes" if /^\s*do_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $no_symlink      = "Yes" if /^\s*no_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $reverse_symlink = "Yes" if /^\s*reverse_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*image_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*link_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $move_image      = "Yes" if /^\s*move_image\s*=\s*(yes|true|1)\s*$/ig;
++      $clobber_modules = "Yes" if /^\s*clobber_modules\s*=\s*(yes|true|1)\s*$/ig;
++      $do_boot_enable  = "Yes" if /^\s*do_boot_enable\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootfloppy   = "Yes" if /^\s*do_bootfloppy\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootloader   = "Yes" if /^\s*do_bootloader\s*=\s*(yes|true|1)\s*$/ig;
++      $relative_links  = "Yes" if /^\s*relative_links\s*=\s*(yes|true|1)\s*$/ig;
++      $do_initrd       = "Yes" if /^\s*do_initrd\s*=\s*(yes|true|1)\s*$/ig;
++      $use_hard_links  = "Yes" if /^\s*use_hard_links\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_loader   = 'Yes' if /^\s*silent_loader\s*=\s*(yes|true|1)\s*$/ig;
++      $warn_reboot     = 'Yes' if /^\s*warn_reboot\s*=\s*(yes|true|1)\s*$/ig;
++      $minimal_swap    = 'Yes' if /^\s*minimal_swap\s*=\s*(yes|true|1)\s*$/ig;
++      $ignore_depmod_err = 'Yes' if /^\s*ignore_depmod_err\s*=\s*(yes|true|1)\s*$/ig;
++      $relink_build_link = 'Yes' if /^\s*relink_build_link\s*=\s*(yes|true|1)\s*$/ig;
++      $force_build_link = 'Yes' if /^\s*force_build_link\s*=\s*(yes|true|1)\s*$/ig;
++
++      $image_dest      = "$1"  if /^\s*image_dest\s*=\s*(\S+)/ig;
++      $postinst_hook   = "$1"  if /^\s*postinst_hook\s*=\s*(\S+)/ig;
++      $postrm_hook     = "$1"  if /^\s*postrm_hook\s*=\s*(\S+)/ig;
++      $preinst_hook    = "$1"  if /^\s*preinst_hook\s*=\s*(\S+)/ig;
++      $prerm_hook      = "$1"  if /^\s*prerm_hook\s*=\s*(\S+)/ig;
++      $ramdisk         = "$1"  if /^\s*ramdisk\s*=\s*(.+)$/ig;
++    }
++    close CONF;
++    $have_conffile = "Yes";
++  }
++}
++
++$initrd = '' if (! -x "$ramdisk");
++
++$ENV{KERNEL_ARCH}=$kernel_arch if $kernel_arch;
++
++#check to see if we are trying to remove a running kernel
++# if so we abort right now.
++chop($running=`uname -r`);
++if ($running eq $version) {
++  print STDERR "WARN: Proceeding with removing running kernel image.\n";
++}
++
++#Now, they have an alternate kernel which they are currently running
++
++# This is just us being nice to lilo users.
++
++chdir("/") or die "could not chdir to /:$!\n";
++
++if (-f "/etc/$loader.conf") { #I know, could be a link, but ..
++  open (LILO, "/etc/$loader.conf") || &success(); # this is not critical
++  while (<LILO>) {
++    chop;
++    s/\#.*//;			  # nix the comments
++    next unless /^\s*image\s*=\s(\S+)/o;
++    $image = $1;
++    if ($image && -e $image) {
++      while (defined($image) && -l $image) {
++	$image = readlink ($image);
++      }
++      if (defined($image) && -e $image) {
++	$WouldInvalidate |= $image =~ /$kimage-$version/;
++      }
++      else {
++	&success(); # invalid $loader.conf file
++      }
++    }
++    else {
++      &success(); # invalid $loader.conf file
++    }
++  }
++  close (LILO);
++  if ($WouldInvalidate) {
++    print STFERR "WARN: Proceeding with removing running kernel image.\n";
++    &success();
++  }
++}
++
++
++# set the env var stem
++$ENV{'STEM'} = "linux";
++
++sub exec_script {
++  my $type   = shift;
++  my $script = shift;
++  print STDERR "Running $type hook script $script.\n";
++  system ("$script $version $realimageloc$kimage-$version") &&
++    print STDERR "User $type hook script [$script] ";
++  if ($?) {
++    if ($? == -1) {
++      print STDERR "failed to execute: $!\n";
++    }
++    elsif ($? & 127) {
++      printf STDERR "died with signal %d, %s coredump\n",
++        ($? & 127),  ($? & 128) ? 'with' : 'without';
++    }
++    else {
++      printf STDERR "exited with value %d\n", $? >> 8;
++    }
++    exit $? >> 8;
++  }
++}
++sub run_hook {
++  my $type   = shift;
++  my $script = shift;
++  if ($script =~ m,^/,) {
++    # Full path provided for the hook script
++    if (-x "$script") {
++      &exec_script($type,$script);
++    }
++    else {
++      die "The provided $type hook script [$script] could not be run.\n";
++    }
++  }
++  else {
++    # Look for it in a safe path
++    for my $path ('/bin', '/sbin', '/usr/bin', '/usr/sbin') {
++      if (-x "$path/$script") {
++        &exec_script($type, "$path/$script");
++        return 0;
++      }
++    }
++    # No luck
++    print STDERR "Could not find $type hook script [$script].\n";
++    die "Looked in: '/bin', '/sbin', '/usr/bin', '/usr/sbin'\n";
++  }
++}
++
++
++my $options;
++for (@ARGV) {
++	s,','\\'',g;
++	$options .= " '$_'";
++}
++$ENV{'DEB_MAINT_PARAMS'}="$options";
++
++## Run user hook script here, if any
++if (-x "$prerm_hook") {
++  &run_hook("prerm", $prerm_hook);
++}
++if (-d "/etc/kernel/prerm.d") {
++  print STDERR "Examining /etc/kernel/prerm.d.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " . 
++          "--arg=$realimageloc$kimage-$version /etc/kernel/prerm.d") &&
++            die "Failed to process /etc/kernel/prerm.d";
++}
++if (-d "/etc/kernel/prerm.d/$version") {
++  print STDERR "Examining /etc/kernel/prerm.d/$version.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version" .
++          " --arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/prerm.d/$version") &&
++            die "Failed to process /etc/kernel/prerm.d/$version";
++}
++
++sub success () {
++  # NOTE: need to keep this list in sync with rules.d/2-binary-arch.mk
++  my %files_to_keep = (
++	'modules.builtin'	=> 1,
++	'modules.order'		=> 1,
++  );
++  my $short;
++  for my $file (</lib/modules/$version/modules.*>) {
++    $short = $file; $short =~ s,.*/,,;
++    if (!defined $files_to_keep{$short}) {
++      unlink "$file";
++    }
++  }
++  exit 0;
++}
++
++
++
++&success();
++exit 0;
++__END__
++
++
++
++
++
+diff --git a/debian/debian.env b/debian/debian.env
+new file mode 100644
+index 0000000..be31a0c
+--- /dev/null
++++ b/debian/debian.env
+@@ -0,0 +1 @@
++DEBIAN=debian.master
+diff --git a/debian/docs/README.inclusion-list b/debian/docs/README.inclusion-list
+new file mode 100644
+index 0000000..b025393
+--- /dev/null
++++ b/debian/docs/README.inclusion-list
+@@ -0,0 +1,51 @@
++This README describes the reason for, and the use of, module
++inclusion lists.
++
++The original Hardy release had the notion of sub-flavours,
++e.g., a flavour that was constructed as a subset of an existing flavour.
++For example, the virtual flavour was extracted from the server flavour using
++a subset of the server flavour modules. However, there were some difficult
++mainteneance issues with regard to packaging, make rules, and scripts. This
++re-implementation of the sub-flavours philosophy is hopefully simpler,
++and retrofitable to all releases.
++
++A module inclusion list looks at the problem of of constructing a package
++from the perspective of what modules do we _want_ in the package, as opposed
++to what modules we _don't_ want. As the kernel matures, more and more devices are added
++which makes the problem of configuration maintenance a real pain in the ass.
++If we took the approach of disabling all of the config options that we don't want,
++then the differences between flavours will quickly become quite large, making
++it difficult to quickly compare the individual flavour configs.  Each time a
++new config option is added then we also have to make a decision about disabling in
++order to continue to keep the minimal number of modules.
++
++A module inclusion list is applied on a per-flavour basis. For example,
++debian.<BRANCH>/control.d/${flavour}.inclusion-list. For example, the
++config for virtual is very close to server and generic, but the inclusion list
++causes the virtual package to be constructed with _only_ the modules described 
++in the inclusion list.
++
++The inclusion list format is a simple bash regular expression list of files. For example,
++
++arch/*/{crypto,kernel,oprofile}
++drivers/acpi/*
++drivers/ata/ahci.ko
++
++These 3 regular expression forms are suitable for expansion by bash and as inputs to 'find'.
++See debian/scripts/module-inclusion for details.
++
++There are 2 log files created as a side effect of the application of the module
++inclusion list; $(flavour).inclusion-list.log and $(flavour).depmod.log.
++
++$(flavour).inclusion-list.log : This log is created while the inclusion list
++modules are being copied. If any are missing, then those warnings go in this log.
++While its not considered a fatal error, you should endevour to correct your inclusion
++list such that there are no missing modules.
++
++$(flavour).depmod.log : The log is created as a result of running depmod on the
++resulting set of modules. If there are missing symbols then you'll find that information
++here. Again, you should modify your inclusion list such that there are no missing
++symbols.
++
++Tim Gardner <tim.gardner@canonical.com>
++June 2, 2010
+diff --git a/debian/gbp.conf b/debian/gbp.conf
+new file mode 100644
+index 0000000..8ce5fda
+--- /dev/null
++++ b/debian/gbp.conf
+@@ -0,0 +1,2 @@
++[buildpackage]
++debian-tag = Ubuntu-%(version)s
+diff --git a/debian/linux-cloud-tools-common.hv-fcopy-daemon.service b/debian/linux-cloud-tools-common.hv-fcopy-daemon.service
+new file mode 100644
+index 0000000..43a3ecf
+--- /dev/null
++++ b/debian/linux-cloud-tools-common.hv-fcopy-daemon.service
+@@ -0,0 +1,12 @@
++# On Azure/Hyper-V systems start the hv_fcopy_daemon
++#
++# author "Andy Whitcroft <apw@canonical.com>"
++[Unit]
++Description=Hyper-V File Copy Protocol Daemon
++ConditionVirtualization=microsoft
++
++[Service]
++ExecStart=/usr/sbin/hv_fcopy_daemon -n
++
++[Install]
++WantedBy=multi-user.target
+diff --git a/debian/linux-cloud-tools-common.hv-fcopy-daemon.upstart b/debian/linux-cloud-tools-common.hv-fcopy-daemon.upstart
+new file mode 100644
+index 0000000..566bfbb
+--- /dev/null
++++ b/debian/linux-cloud-tools-common.hv-fcopy-daemon.upstart
+@@ -0,0 +1,22 @@
++# On Azure/Hyper-V systems start the hv_fcopy_daemon
++#
++description "Hyper-V File Copy Protocol Daemon"
++author "Andy Whitcroft <apw@canonical.com>"
++
++start on runlevel [2345]
++stop on runlevel [!2345]
++console log
++
++pre-start script
++        if [ -e "/etc/default/hv-kvp-daemon-init" ]; then
++                . /etc/default/hv-kvp-daemon-init
++        fi
++        [ "$RUN_FCOPY_DAEMON" -eq 0 ] && { stop; exit 0; }
++	if [ -d /sys/class/dmi/id/. ]; then
++		read company </sys/class/dmi/id/sys_vendor
++		read product </sys/class/dmi/id/product_name
++		[ "$company:$product" = 'Microsoft Corporation:Virtual Machine' ] || { stop; exit 0; }
++	fi
++end script
++
++exec /usr/sbin/hv_fcopy_daemon -n
+diff --git a/debian/linux-cloud-tools-common.hv-kvp-daemon.service b/debian/linux-cloud-tools-common.hv-kvp-daemon.service
+new file mode 100644
+index 0000000..c86a812
+--- /dev/null
++++ b/debian/linux-cloud-tools-common.hv-kvp-daemon.service
+@@ -0,0 +1,12 @@
++# On Azure/Hyper-V systems start the hv_kvp_daemon
++#
++# author "Andy Whitcroft <apw@canonical.com>"
++[Unit]
++Description=Hyper-V KVP Protocol Daemon
++ConditionVirtualization=microsoft
++
++[Service]
++ExecStart=/usr/sbin/hv_kvp_daemon -n
++
++[Install]
++WantedBy=multi-user.target
+diff --git a/debian/linux-cloud-tools-common.hv-kvp-daemon.upstart b/debian/linux-cloud-tools-common.hv-kvp-daemon.upstart
+new file mode 100644
+index 0000000..198184a
+--- /dev/null
++++ b/debian/linux-cloud-tools-common.hv-kvp-daemon.upstart
+@@ -0,0 +1,22 @@
++# On Azure/Hyper-V systems start the hv_kvp_daemon
++#
++description "Hyper-V KVP Protocol Daemon"
++author "Adam Conrad <adconrad@canonical.com>"
++
++start on runlevel [2345]
++stop on runlevel [!2345]
++console log
++
++pre-start script
++        if [ -e "/etc/default/hv-kvp-daemon-init" ]; then
++                . /etc/default/hv-kvp-daemon-init
++        fi
++        [ "$RUN_KVP_DAEMON" = 0 ] && { stop; exit 0; }
++	if [ -d /sys/class/dmi/id/. ]; then
++		read company </sys/class/dmi/id/sys_vendor
++		read product </sys/class/dmi/id/product_name
++		[ "$company:$product" = 'Microsoft Corporation:Virtual Machine' ] || { stop; exit 0; }
++	fi
++end script
++
++exec /usr/sbin/hv_kvp_daemon -n
+diff --git a/debian/linux-cloud-tools-common.hv-vss-daemon.service b/debian/linux-cloud-tools-common.hv-vss-daemon.service
+new file mode 100644
+index 0000000..20717a7
+--- /dev/null
++++ b/debian/linux-cloud-tools-common.hv-vss-daemon.service
+@@ -0,0 +1,12 @@
++# On Azure/Hyper-V systems start the hv_vss_daemon
++#
++# author "Andy Whitcroft <apw@canonical.com>"
++[Unit]
++Description=Hyper-V VSS Protocol Daemon
++ConditionVirtualization=microsoft
++
++[Service]
++ExecStart=/usr/sbin/hv_vss_daemon -n
++
++[Install]
++WantedBy=multi-user.target
+diff --git a/debian/linux-cloud-tools-common.hv-vss-daemon.upstart b/debian/linux-cloud-tools-common.hv-vss-daemon.upstart
+new file mode 100644
+index 0000000..3f3326a
+--- /dev/null
++++ b/debian/linux-cloud-tools-common.hv-vss-daemon.upstart
+@@ -0,0 +1,22 @@
++# On Azure/Hyper-V systems start the hv_vss_daemon
++#
++description "Hyper-V VSS Protocol Daemon"
++author "Ben Howard <ben.howard@canonical.com>"
++
++start on runlevel [2345]
++stop on runlevel [!2345]
++console log
++
++pre-start script
++        if [ -e "/etc/default/hv-kvp-daemon-init" ]; then
++                . /etc/default/hv-kvp-daemon-init
++        fi
++        [ "$RUN_VSS_DAEMON" -eq 0 ] && { stop; exit 0; }
++	if [ -d /sys/class/dmi/id/. ]; then
++		read company </sys/class/dmi/id/sys_vendor
++		read product </sys/class/dmi/id/product_name
++		[ "$company:$product" = 'Microsoft Corporation:Virtual Machine' ] || { stop; exit 0; }
++	fi
++end script
++
++exec /usr/sbin/hv_vss_daemon -n
+diff --git a/debian/rules b/debian/rules
+new file mode 100755
+index 0000000..1623a64
+--- /dev/null
++++ b/debian/rules
+@@ -0,0 +1,291 @@
++#!/usr/bin/make -f
++#
++# $(DEBIAN)/rules for Ubuntu linux
++#
++# Use this however you want, just give credit where credit is due.
++#
++# Copyright (c) 2007 Ben Collins <bcollins@ubuntu.com>
++#
++
++DEBIAN=$(shell awk -F= '($$1 == "DEBIAN") { print $$2 }' <debian/debian.env)
++
++# dpkg-buildpackage passes options that are incomptatible
++# with the kernel build.
++unexport CFLAGS
++unexport LDFLAGS
++
++export LC_ALL=C
++export SHELL=/bin/bash -e
++
++# Where do we find the common configuration.
++export DROOT=debian
++
++# Common variables for all architectures
++include $(DROOT)/rules.d/0-common-vars.mk
++
++# Pull in some arch specific stuff
++-include $(DEBIAN)/rules.d/$(arch).mk
++
++# Pull in some branch specific stuff. Used by LTS backport
++# branches to override master branch settings such as do_tools_common.
++-include $(DEBIAN)/rules.d/hooks.mk
++
++# Maintainer targets
++include $(DROOT)/rules.d/1-maintainer.mk
++
++do_linux_tools=$(sort $(filter-out false,$(do_tools_usbip) $(do_tools_cpupower) $(do_tools_perf) $(do_tools_x86)))
++do_cloud_tools=$(sort $(filter-out false,$(do_tools_hyperv)))
++
++# Don't build tools or udebs in a cross compile environment.
++ifneq ($(DEB_HOST_ARCH),$(DEB_BUILD_ARCH))
++	do_tools=false
++	disable_d_i=true
++	do_zfs=false
++	do_zfs_disable:=$(shell cat $(DROOT)/zfs-modules.ignore >>$(prev_abidir)/../modules.ignore)
++endif
++
++# Stages -- support both DEB_STAGE=stage1 and DEB_BUILD_PROFILE=bootstrap
++ifeq ($(DEB_STAGE),stage1)
++    DEB_BUILD_PROFILES=stage1
++endif
++ifneq ($(DEB_BUILD_PROFILE),)
++    DEB_BUILD_PROFILES=$(DEB_BUILD_PROFILE)
++endif
++ifneq ($(filter stage1,$(DEB_BUILD_PROFILES)),)
++    do_tools=false
++    do_doc_package=false
++    do_source_package=false
++    do_flavour_image_package=false
++    do_flavour_header_package=false
++endif
++
++# Being used to build a mainline build -- turn off things which do not work.
++ifeq ($(do_mainline_build),true)
++	do_extras_package=false
++	do_tools=false
++	no_dumpfile=1
++	do_zfs=false
++endif
++
++# Disable tools build and packaging if do_tools != true
++ifneq ($(do_tools),true)
++	do_linux_tools=
++	do_cloud_tools=
++	do_tools_common=
++endif
++
++# Either tools package needs the common source preparation
++do_any_tools=$(sort $(filter-out false,$(do_linux_tools) $(do_cloud_tools)))
++
++# autopkgtest -- rebuild support
++#  only build the first flavour on the assumption it is representative
++ifneq ($(filter autopkgtest,$(DEB_BUILD_PROFILES)),)
++flavours := $(firstword $(flavours))
++endif
++
++# Debian Build System targets
++binary: binary-indep binary-arch
++
++build: build-arch build-indep
++
++clean: debian/control
++	dh_testdir
++	dh_testroot
++	dh_clean
++
++	# d-i stuff
++	rm -rf $(DEBIAN)/d-i-$(arch)
++	# Generated on the fly.
++	rm -f $(DEBIAN)/d-i/firmware/kernel-image
++
++	# normal build junk
++	rm -rf $(DEBIAN)/abi/$(release)-$(revision)
++	rm -rf $(builddir)
++	rm -f $(stampdir)/stamp-*
++	rm -rf $(DEBIAN)/linux-*
++
++	# This gets rid of the d-i packages in control
++	cp -f $(DEBIAN)/control.stub $(DROOT)/control
++	cp $(DEBIAN)/changelog debian/changelog
++
++	# Install the copyright information.
++	cp $(DEBIAN)/copyright debian/copyright
++
++	# If we have a reconstruct script use it.
++	[ -f $(DEBIAN)/reconstruct ] && bash $(DEBIAN)/reconstruct
++
++	# Remove generated intermediate files
++	rm -f $(DROOT)/control.stub $(DEBIAN)/control.stub \
++		$(DEBIAN)/d-i/kernel-versions
++
++distclean: clean
++	rm -rf $(DROOT)/control debian/changelog \
++		debian/control debian/control.stub debian/copyright
++
++# Builds the image, arch headers and debug packages
++include $(DROOT)/rules.d/2-binary-arch.mk
++
++# Rules for building the udebs ($(DEBIAN)-installer)
++include $(DROOT)/rules.d/5-udebs.mk
++
++# Builds the source, doc and linux-headers indep packages
++include $(DROOT)/rules.d/3-binary-indep.mk
++
++# Various checks to be performed on builds
++include $(DROOT)/rules.d/4-checks.mk
++
++# Misc stuff
++.PHONY: $(DEBIAN)/control.stub
++$(DEBIAN)/control.stub: $(DEBIAN)/d-i/kernel-versions.in	\
++		$(DROOT)/scripts/control-create		\
++		$(DEBIAN)/control.stub.in			\
++		$(DEBIAN)/changelog			\
++		$(wildcard $(DEBIAN)/control.d/* $(DEBIAN)/sub-flavours/*.vars)
++	for i in $(DEBIAN)/d-i/kernel-versions.in $(DEBIAN)/control.stub.in; do	\
++	  new=`echo $$i | sed 's/\.in$$//'`;					\
++	  cat $$i | sed -e 's/PKGVER/$(release)/g'                              \
++	        -e 's/ABINUM/$(abinum)/g'                                       \
++		-e 's/SRCPKGNAME/$(src_pkg_name)/g'                             \
++		-e 's/=HUMAN=/$(human_arch)/g'                                    \
++	  > $$new;								\
++	done
++	flavours="$(sort $(wildcard $(DEBIAN)/control.d/vars.* $(DEBIAN)/sub-flavours/*.vars))";\
++	for i in $$flavours; do							\
++	  $(SHELL) $(DROOT)/scripts/control-create $$i |				\
++		sed -e 's/PKGVER/$(release)/g'                                  \
++		-e 's/ABINUM/$(abinum)/g'                                       \
++		-e 's/SRCPKGNAME/$(src_pkg_name)/g'                             \
++		-e 's/=HUMAN=/$(human_arch)/g'                                    \
++		>> $(DEBIAN)/control.stub;						\
++	done
++
++.PHONY: debian/control
++debian/control: $(DEBIAN)/control.stub
++	rm -rf $(builddir)/modules $(builddir)/firmware			\
++		$(builddir)/kernel-versions $(builddir)/package-list	\
++		$(builddir)/$(DEBIAN)
++	mkdir -p $(builddir)/modules/$(arch)/
++	cp $(DEBIAN)/d-i/modules/* $(builddir)/modules/$(arch)/
++	mkdir -p $(builddir)/firmware/$(arch)/
++	cp $(DEBIAN)/d-i/firmware/* $(builddir)/firmware/$(arch)/
++	cp $(DEBIAN)/d-i/package-list $(DEBIAN)/d-i/kernel-versions $(builddir)/
++	touch $(builddir)/modules/$(arch)/kernel-image
++	# kernel-wedge needs to poke around in $(DEBIAN)/
++	ln -nsf $(CURDIR)/debian $(builddir)/debian
++
++	# Some files may need to differ between architectures
++	if [ -d $(DEBIAN)/d-i/modules-$(arch) ]; then			\
++	    cp $(DEBIAN)/d-i/modules-$(arch)/* \
++		$(builddir)/modules/$(arch)/;				\
++	fi
++	if [ -d $(DEBIAN)/d-i/firmware-$(arch) ]; then			\
++	    cp $(DEBIAN)/d-i/firmware-$(arch)/* \
++		$(builddir)/firmware/$(arch)/;				\
++	fi
++
++	# Remove unwanted stuff for this architecture
++	if [ -r "$(DEBIAN)/d-i/exclude-modules.$(arch)" ]; then		\
++	    (cat $(DEBIAN)/d-i/exclude-modules.$(arch);			\
++	     ls $(builddir)/modules/$(arch)/) | sort | uniq -d |	\
++		(cd $(builddir)/modules/$(arch)/; xargs rm -f);		\
++	fi
++	if [ -r "$(DEBIAN)/d-i/exclude-firmware.$(arch)" ]; then		\
++	    (cat $(DEBIAN)/d-i/exclude-firmware.$(arch);			\
++	     ls $(builddir)/firmware/$(arch)/) | sort | uniq -d |	\
++		(cd $(builddir)/firmware/$(arch)/; xargs rm -f);	\
++	fi
++
++	# Per flavour module lists
++	flavour_modules=`ls $(DEBIAN)/d-i/modules.$(arch)-* 2>/dev/null`	\
++		|| true;						\
++	if [ "$$flavour_modules" != "" ]; then				\
++	    for flav in $$flavour_modules; do				\
++		name=`echo $$flav | sed 's/.*\/modules.$(arch)-//'`;	\
++		mkdir $(builddir)/modules/$(arch)-$$name;		\
++		(cd $(builddir)/modules/; tar cf - `cat ../$$flav`) |	\
++		    (cd $(builddir)/modules/$(arch)-$$name/; tar xf -);	\
++		touch $(builddir)/modules/$(arch)-$$name/kernel-image;	\
++	    done;							\
++	fi
++	flavour_firmware=`ls $(DEBIAN)/d-i/firmware.$(arch)-* 2>/dev/null`	\
++		|| true;						\
++	if [ "$$flavour_firmware" != "" ]; then				\
++	    for flav in $$flavour_firmware; do				\
++		name=`echo $$flav | sed 's/.*\/firmware.$(arch)-//'`;	\
++		mkdir $(builddir)/firmware/$(arch)-$$name;		\
++		(cd $(builddir)/firmware/; tar cf - `cat ../$$flav`) |	\
++		    (cd $(builddir)/firmware/$(arch)-$$name/; tar xf -);\
++		touch $(builddir)/firmware/$(arch)-$$name/kernel-image;	\
++	    done;							\
++	fi
++
++	# Some files may need to differ between flavours
++	flavour_module_dirs=`ls -d $(DEBIAN)/d-i/modules-$(arch)-* 2>/dev/null`\
++		|| true;						\
++	if [ "$$flavour_module_dirs" ]; then				\
++	    for flav in $$flavour_module_dirs; do			\
++		name=`echo $$flav | sed 's/.*\/modules-$(arch)-//'`;	\
++		[ -d $(builddir)/modules/$(arch)-$$name ] ||		\
++		    cp -a $(builddir)/modules/$(arch)			\
++			modules/$(arch)-$$name;				\
++		cp $$flav/* $(builddir)/modules/$(arch)-$$name/;	\
++	    done;							\
++	fi
++	flavour_firmware_dirs=`ls -d $(DEBIAN)/d-i/firmware-$(arch)-* 2>/dev/null`\
++		|| true;						\
++	if [ "$$flavour_firmware_dirs" ]; then				\
++	    for flav in $$flavour_firmware_dirs; do			\
++		name=`echo $$flav | sed 's/.*\/firmware-$(arch)-//'`;	\
++		[ -d $(builddir)/firmware/$(arch)-$$name ] ||		\
++		    cp -a $(builddir)/firmware/$(arch)			\
++			firmware/$(arch)-$$name;			\
++		cp $$flav/* $(builddir)/firmware/$(arch)-$$name/;	\
++	    done;							\
++	fi
++
++	# Remove unwanted stuff for each flavour
++	flavour_exclude=`ls $(DEBIAN)/d-i/exclude-modules.$(arch)-* 2>/dev/null`\
++		|| true;						\
++	if [ "$$flavour_exclude" ]; then				\
++	    for flav in $$flavour_exclude; do				\
++		name=`echo $$flav | sed 's/.*\/exclude-modules.$(arch)-//'`;\
++		[ -d $(builddir)/modules/$(arch)-$$name ] ||		\
++		    cp -a $(builddir)/modules/$(arch) 			\
++			$(builddir)/modules/$(arch)-$$name;		\
++		(cat $$flav;						\
++		 ls $(builddir)/modules/$(arch)-$$name) |		\
++		 sort |	uniq -d |					\
++		    (cd $(builddir)/modules/$(arch)-$$name/;		\
++		     xargs rm -f);					\
++	    done;							\
++	fi
++	flavour_exclude=`ls $(DEBIAN)/d-i/exclude-firmware.$(arch)-* 2>/dev/null`\
++		|| true;						\
++	if [ "$$flavour_exclude" ]; then				\
++	    for flav in $$flavour_exclude; do				\
++		name=`echo $$flav | sed 's/.*\/exclude-firmware.$(arch)-//'`;\
++		[ -d $(builddir)/firmware/$(arch)-$$name ] ||		\
++		    cp -a $(builddir)/firmware/$(arch) 			\
++			$(builddir)/firmware/$(arch)-$$name;		\
++		(cat $$flav;						\
++		 ls $(builddir)/firmware/$(arch)-$$name) |		\
++		 sort |	uniq -d |					\
++		    (cd $(builddir)/firmware/$(arch)-$$name/;		\
++		     xargs rm -f);					\
++	    done;							\
++	fi
++
++	if [ ! -d $(builddir)/modules/$(build_arch) ]; then		\
++		mkdir -p $(builddir)/modules/$(build_arch);		\
++		cp $(builddir)/modules/$(arch)/*			\
++			$(builddir)/modules/$(build_arch);		\
++	fi
++	if [ ! -d $(builddir)/firmware/$(build_arch) ]; then		\
++		mkdir -p $(builddir)/firmware/$(build_arch);		\
++		cp $(builddir)/firmware/$(arch)/*			\
++			$(builddir)/firmware/$(build_arch);		\
++	fi
++
++	echo "# placebo control.stub for kernel-wedge flow change" >debian/control.stub
++	cp $(DEBIAN)/control.stub debian/control
++	cd $(builddir) && LANG=C kernel-wedge gen-control >> $(CURDIR)/debian/control
+diff --git a/debian/rules.d/0-common-vars.mk b/debian/rules.d/0-common-vars.mk
+new file mode 100644
+index 0000000..0628e55
+--- /dev/null
++++ b/debian/rules.d/0-common-vars.mk
+@@ -0,0 +1,247 @@
++# Used when you need to 'escape' a comma.
++comma = ,
++
++#
++# The source package name will be the first token from $(DEBIAN)/changelog
++#
++src_pkg_name=$(shell sed -n '1s/^\(.*\) (.*).*$$/\1/p' $(DEBIAN)/changelog)
++
++# Get some version info
++release := $(shell sed -n '1s/^$(src_pkg_name).*(\(.*\)-.*).*$$/\1/p' $(DEBIAN)/changelog)
++revisions := $(shell sed -n 's/^$(src_pkg_name)\ .*($(release)-\(.*\)).*$$/\1/p' $(DEBIAN)/changelog | tac)
++revision ?= $(word $(words $(revisions)),$(revisions))
++prev_revisions := $(filter-out $(revision),0.0 $(revisions))
++prev_revision := $(word $(words $(prev_revisions)),$(prev_revisions))
++
++prev_fullver ?= $(shell dpkg-parsechangelog -l$(DEBIAN)/changelog -o1 -c1 | sed -ne 's/^Version: *//p')
++
++family=ubuntu
++
++# This is an internally used mechanism for the daily kernel builds. It
++# creates packages whose ABI is suffixed with a minimal representation of
++# the current git HEAD sha. If .git/HEAD is not present, then it uses the
++# uuidgen program,
++#
++# AUTOBUILD can also be used by anyone wanting to build a custom kernel
++# image, or rebuild the entire set of Ubuntu packages using custom patches
++# or configs.
++AUTOBUILD=
++
++ifneq ($(AUTOBUILD),)
++skipabi		= true
++skipmodule	= true
++skipdbg		= true
++gitver=$(shell if test -f .git/HEAD; then cat .git/HEAD; else uuidgen; fi)
++gitverpre=$(shell echo $(gitver) | cut -b -3)
++gitverpost=$(shell echo $(gitver) | cut -b 38-40)
++abi_suffix = -$(gitverpre)$(gitverpost)
++endif
++
++ifneq ($(NOKERNLOG),)
++ubuntu_log_opts += --no-kern-log
++endif
++ifneq ($(PRINTSHAS),)
++ubuntu_log_opts += --print-shas
++endif
++
++# Get the kernels own extra version to be added to the release signature.
++raw_kernelversion=$(shell make kernelversion)
++
++#
++# full_build -- are we doing a full buildd style build
++#
++ifeq ($(wildcard /CurrentlyBuilding),)
++full_build?=false
++else
++full_build?=true
++endif
++
++#
++# The debug packages are ginormous, so you probably want to skip
++# building them (as a developer).
++#
++ifeq ($(full_build),false)
++skipdbg=true
++endif
++
++abinum		:= $(shell echo $(revision) | sed -r -e 's/([^\+~]*)\.[^\.]+(~.*)?(\+.*)?$$/\1/')$(abi_suffix)
++prev_abinum	:= $(shell echo $(prev_revision) | sed -r -e 's/([^\+~]*)\.[^\.]+(~.*)?(\+.*)?$$/\1/')$(abi_suffix)
++abi_release	:= $(release)-$(abinum)
++
++uploadnum	:= $(shell echo $(revision) | sed -r -e 's/[^\+~]*\.([^\.~]+(~.*)?(\+.*)?$$)/\1/')
++ifneq ($(full_build),false)
++  uploadnum	:= $(uploadnum)-Ubuntu
++endif
++
++# XXX: linux-libc-dev got bumped to -803.N inadvertantly by a ti-omap4 upload
++#      shift our version higher for this package only.  Ensure this only
++#      occurs for the v2.6.35 kernel so that we do not propogate this into
++#      any other series.
++raw_uploadnum	:= $(shell echo $(revision) | sed -e 's/.*\.//')
++libc_dev_version :=
++ifeq ($(DEBIAN),debian.master)
++ifeq ($(release),2.6.35)
++libc_dev_version := -v$(release)-$(shell expr "$(abinum)" + 1000).$(raw_uploadnum)
++endif
++endif
++
++DEB_HOST_MULTIARCH = $(shell dpkg-architecture -qDEB_HOST_MULTIARCH)
++DEB_HOST_GNU_TYPE  = $(shell dpkg-architecture -qDEB_HOST_GNU_TYPE)
++DEB_BUILD_GNU_TYPE = $(shell dpkg-architecture -qDEB_BUILD_GNU_TYPE)
++DEB_HOST_ARCH = $(shell dpkg-architecture -qDEB_HOST_ARCH)
++DEB_BUILD_ARCH = $(shell dpkg-architecture -qDEB_BUILD_ARCH)
++
++#
++# Detect invocations of the form 'fakeroot debian/rules binary arch=armhf'
++# within an x86'en schroot. This only gets you part of the way since the
++# packaging phase fails, but you can at least compile the kernel quickly.
++#
++arch := $(DEB_HOST_ARCH)
++ifneq ($(arch),$(DEB_HOST_ARCH))
++	CROSS_COMPILE ?= $(shell dpkg-architecture -a$(arch) -qDEB_HOST_GNU_TYPE -f 2>/dev/null)-
++endif
++
++#
++# Detect invocations of the form 'dpkg-buildpackage -B -aarmhf' within
++# an x86'en schroot. This is the only way to build all of the packages
++# (except for tools).
++#
++ifneq ($(DEB_BUILD_GNU_TYPE),$(DEB_HOST_GNU_TYPE))
++	CROSS_COMPILE ?= $(DEB_HOST_GNU_TYPE)-
++endif
++
++abidir		:= $(CURDIR)/$(DEBIAN)/abi/$(release)-$(revision)/$(arch)
++prev_abidir	:= $(CURDIR)/$(DEBIAN)/abi/$(release)-$(prev_revision)/$(arch)
++commonconfdir	:= $(CURDIR)/$(DEBIAN)/config
++archconfdir	:= $(CURDIR)/$(DEBIAN)/config/$(arch)
++sharedconfdir	:= $(CURDIR)/debian.master/config
++builddir	:= $(CURDIR)/debian/build
++stampdir	:= $(CURDIR)/debian/stamps
++
++#
++# The binary package name always starts with linux-image-$KVER-$ABI.$UPLOAD_NUM. There
++# are places that you'll find linux-image hard coded, but I guess thats OK since the
++# assumption that the binary package always starts with linux-image will never change.
++#
++bin_pkg_name=linux-image-$(abi_release)
++extra_pkg_name=linux-image-extra-$(abi_release)
++hdrs_pkg_name=linux-headers-$(abi_release)
++indep_hdrs_pkg_name=$(src_pkg_name)-headers-$(abi_release)
++
++#
++# The generation of content in the doc package depends on both 'AUTOBUILD=' and
++# 'do_doc_package_content=true'. There are usually build errors during the development
++# cycle, so its OK to leave 'do_doc_package_content=false' until those build
++# failures get sorted out. Finally, the doc package doesn't really need to be built
++# for developer testing (its kind of slow), so only do it if on a buildd.
++do_doc_package=true
++do_doc_package_content=true
++ifeq ($(full_build),false)
++do_doc_package_content=false
++endif
++doc_pkg_name=$(src_pkg_name)-doc
++
++#
++# Similarly with the linux-source package, you need not build it as a developer. Its
++# somewhat I/O intensive and utterly useless.
++#
++do_source_package=true
++do_source_package_content=true
++ifeq ($(full_build),false)
++do_source_package_content=false
++endif
++
++# linux-libc-dev may not be needed, default to building it.
++do_libc_dev_package=true
++
++# common headers normally is built as an indep package, but may be arch
++do_common_headers_indep=true
++
++# add a 'full source' mode
++do_full_source=false
++
++# build common tools
++do_tools_common=true
++
++# build tools
++ifneq ($(wildcard $(CURDIR)/tools),)
++	ifeq ($(do_tools),)
++		ifneq ($(DEB_BUILD_GNU_TYPE),$(DEB_HOST_GNU_TYPE))
++			do_tools=false
++		endif
++	endif
++	do_tools?=true
++else
++	do_tools?=false
++endif
++tools_pkg_name=$(src_pkg_name)-tools-$(abi_release)
++tools_common_pkg_name=$(src_pkg_name)-tools-common
++tools_flavour_pkg_name=linux-tools-$(abi_release)
++cloud_pkg_name=$(src_pkg_name)-cloud-tools-$(abi_release)
++cloud_common_pkg_name=$(src_pkg_name)-cloud-tools-common
++cloud_flavour_pkg_name=linux-cloud-tools-$(abi_release)
++
++# The general flavour specific image package.
++do_flavour_image_package=true
++
++# The general flavour specific header package.
++do_flavour_header_package=true
++
++# DTBs
++do_dtbs=false
++
++# Support parallel=<n> in DEB_BUILD_OPTIONS (see #209008)
++#
++# These 2 environment variables set the -j value of the kernel build. For example,
++# CONCURRENCY_LEVEL=16 fakeroot $(DEBIAN)/rules binary-debs
++# or
++# DEB_BUILD_OPTIONS=parallel=16 fakeroot $(DEBIAN)/rules binary-debs
++#
++# The default is to use the number of CPUs.
++#
++COMMA=,
++DEB_BUILD_OPTIONS_PARA = $(subst parallel=,,$(filter parallel=%,$(subst $(COMMA), ,$(DEB_BUILD_OPTIONS))))
++ifneq (,$(DEB_BUILD_OPTIONS_PARA))
++  CONCURRENCY_LEVEL := $(DEB_BUILD_OPTIONS_PARA)
++endif
++
++ifeq ($(CONCURRENCY_LEVEL),)
++  # Check the environment
++  CONCURRENCY_LEVEL := $(shell echo $$CONCURRENCY_LEVEL)
++  # No? Then build with the number of CPUs on the host.
++  ifeq ($(CONCURRENCY_LEVEL),)
++      CONCURRENCY_LEVEL := $(shell expr `getconf _NPROCESSORS_ONLN` \* 1)
++  endif
++  # Oh hell, give 'em one
++  ifeq ($(CONCURRENCY_LEVEL),)
++    CONCURRENCY_LEVEL := 1
++  endif
++endif
++
++conc_level		= -j$(CONCURRENCY_LEVEL)
++
++# target_flavour is filled in for each step
++kmake = make ARCH=$(build_arch) \
++	CROSS_COMPILE=$(CROSS_COMPILE) \
++	KERNELVERSION=$(abi_release)-$(target_flavour) \
++	CONFIG_DEBUG_SECTION_MISMATCH=y \
++	KBUILD_BUILD_VERSION="$(uploadnum)" \
++	LOCALVERSION= localver-extra= \
++	CFLAGS_MODULE="-DPKG_ABI=$(abinum)"
++ifneq ($(LOCAL_ENV_CC),)
++kmake += CC=$(LOCAL_ENV_CC) DISTCC_HOSTS=$(LOCAL_ENV_DISTCC_HOSTS)
++endif
++
++# Locking is required in parallel builds to prevent loss of contents
++# of the debian/files.
++lockme_file = $(CURDIR)/debian/.LOCK
++lockme_cmd = flock -w 60
++lockme = $(lockme_cmd) $(lockme_file)
++
++# Don't fail if a link already exists.
++LN = ln -sf
++
++# Checks if a var is overriden by the custom rules. Called with var and
++# flavour as arguments.
++custom_override = \
++ $(shell if [ -n "$($(1)_$(2))" ]; then echo "$($(1)_$(2))"; else echo "$($(1))"; fi)
+diff --git a/debian/rules.d/1-maintainer.mk b/debian/rules.d/1-maintainer.mk
+new file mode 100644
+index 0000000..d469fc2
+--- /dev/null
++++ b/debian/rules.d/1-maintainer.mk
+@@ -0,0 +1,135 @@
++# The following targets are for the maintainer only! do not run if you don't
++# know what they do.
++
++.PHONY: printenv updateconfigs printchanges insertchanges startnewrelease diffupstream help updateportsconfigs editportsconfigs autoreconstruct
++
++help:
++	@echo "These are the targets in addition to the normal $(DEBIAN) ones:"
++	@echo
++	@echo "  printenv        : Print some variables used in the build"
++	@echo
++	@echo "  updateconfigs        : Update core arch configs"
++	@echo
++	@echo "  editconfigs          : Update core arch configs interractively"
++	@echo "  genconfigs           : Generate core arch configs in CONFIGS/*"
++	@echo
++	@echo "  updateportsconfigs   : Update ports arch configs"
++	@echo
++	@echo "  editportsconfigs     : Update ports arch configs interactivly"
++	@echo "  genportconfigs       : Generate ports arch configs in CONFIGS/*"
++	@echo
++	@echo "  printchanges    : Print the current changelog entries (from git)"
++	@echo
++	@echo "  insertchanges   : Insert current changelog entries (from git)"
++	@echo
++	@echo "  startnewrelease : Start a new changelog set"
++	@echo
++	@echo "  diffupstream    : Diff stock kernel code against upstream (git)"
++	@echo
++	@echo "  help            : If you are kernel hacking, you need the professional"
++	@echo "                    version of this"
++	@echo
++	@echo "Environment variables:"
++	@echo
++	@echo "  NOKERNLOG       : Do not add upstream kernel commits to changelog"
++	@echo "  CONCURRENCY_LEVEL=X"
++	@echo "                  : Use -jX for kernel compile"
++	@echo "  PRINTSHAS       : Include SHAs for commits in changelog"
++
++printdebian:
++	@echo "$(DEBIAN)"
++
++updateconfigs defaultconfigs editconfigs genconfigs dumpconfigs:
++	dh_testdir;
++	$(SHELL) $(DROOT)/scripts/misc/kernelconfig $@
++	rm -rf build
++
++updateportsconfigs defaultportsconfigs editportsconfigs genportsconfigs askconfigs:
++	dh_testdir;
++	$(SHELL) $(DROOT)/scripts/misc/kernelconfig $@ ports
++	rm -rf build
++
++printenv:
++	dh_testdir
++	@echo "src package name  = $(src_pkg_name)"
++	@echo "release           = $(release)"
++	@echo "revisions         = $(revisions)"
++	@echo "revision          = $(revision)"
++	@echo "uploadnum         = $(uploadnum)"
++	@echo "prev_revisions    = $(prev_revisions)"
++	@echo "prev_revision     = $(prev_revision)"
++	@echo "abinum            = $(abinum)"
++	@echo "gitver            = $(gitver)"
++	@echo "flavours          = $(flavours)"
++	@echo "skipabi           = $(skipabi)"
++	@echo "skipmodule        = $(skipmodule)"
++	@echo "skipdbg           = $(skipdbg)"
++	@echo "ubuntu_log_opts   = $(ubuntu_log_opts)"
++	@echo "CONCURRENCY_LEVEL = $(CONCURRENCY_LEVEL)"
++	@echo "bin package name  = $(bin_pkg_name)"
++	@echo "hdr package name  = $(hdrs_pkg_name)"
++	@echo "doc package name  = $(doc_pkg_name)"
++	@echo "do_doc_package            = $(do_doc_package)"
++	@echo "do_doc_package_content    = $(do_doc_package_content)"
++	@echo "do_source_package         = $(do_source_package)"
++	@echo "do_source_package_content = $(do_source_package_content)"
++	@echo "do_libc_dev_package       = $(do_libc_dev_package)"
++	@echo "do_flavour_image_package  = $(do_flavour_image_package)"
++	@echo "do_flavour_header_package = $(do_flavour_header_package)"
++	@echo "do_common_headers_indep   = $(do_common_headers_indep)"
++	@echo "do_full_source            = $(do_full_source)"
++	@echo "do_tools                  = $(do_tools)"
++	@echo "do_any_tools              = $(do_any_tools)"
++	@echo "do_linux_tools            = $(do_linux_tools)"
++	@echo " do_tools_cpupower         = $(do_tools_cpupower)"
++	@echo " do_tools_perf             = $(do_tools_perf)"
++	@echo " do_tools_x86              = $(do_tools_x86)"
++	@echo "do_cloud_tools            = $(do_cloud_tools)"
++	@echo " do_tools_hyperv           = $(do_tools_hyperv)"
++	@echo "full_build                = $(full_build)"
++	@echo "libc_dev_version          = $(libc_dev_version)"
++	@echo "DEB_HOST_GNU_TYPE         = $(DEB_HOST_GNU_TYPE)"
++	@echo "DEB_BUILD_GNU_TYPE        = $(DEB_BUILD_GNU_TYPE)"
++	@echo "DEB_HOST_ARCH             = $(DEB_HOST_ARCH)"
++	@echo "DEB_BUILD_ARCH            = $(DEB_BUILD_ARCH)"
++	@echo "arch                      = $(arch)"
++	@echo "kmake                     = $(kmake)"
++
++printchanges:
++	@baseCommit=$$(git log --pretty=format:'%H %s' | \
++		gawk '/UBUNTU: '".*Ubuntu-.*`echo $(prev_fullver) | sed 's/+/\\\\+/'`"'(~.*)?$$/ { print $$1; exit }'); \
++	if [ -z "$$baseCommit" ]; then \
++		echo "WARNING: couldn't find a commit for the previous version. Using the lastest one." >&2; \
++		baseCommit=$$(git log --pretty=format:'%H %s' | \
++			gawk '/UBUNTU:\s*Ubuntu-.*$$/ { print $$1; exit }'); \
++	fi; \
++	git log "$$baseCommit"..HEAD | \
++	$(DROOT)/scripts/misc/git-ubuntu-log $(ubuntu_log_opts)
++
++insertchanges: autoreconstruct
++	@perl -w -f $(DROOT)/scripts/misc/insert-changes.pl $(DROOT) $(DEBIAN) 
++
++autoreconstruct:
++	$(DROOT)/scripts/misc/gen-auto-reconstruct $(release) $(DEBIAN)/reconstruct $(DROOT)/source/options
++
++diffupstream:
++	@git diff-tree -p refs/remotes/linux-2.6/master..HEAD $(shell ls | grep -vE '^(ubuntu|$(DEBIAN)|\.git.*)')
++
++startnewrelease:
++	dh_testdir
++	@nextminor=$(shell expr `echo $(revision) | gawk -F. '{print $$2}'` + 1); \
++	nextmajor=$(shell expr `echo $(revision) | awk -F. '{print $$1}'` + 1); \
++	now="$(shell date -R)"; \
++	echo "Creating new changelog set for $(release)-$$nextmajor.$$nextminor..."; \
++	echo -e "$(src_pkg_name) ($(release)-$$nextmajor.$$nextminor) UNRELEASED; urgency=low\n" > $(DEBIAN)/changelog.new; \
++	echo "  CHANGELOG: Do not edit directly. Autogenerated at release." >> \
++		$(DEBIAN)/changelog.new; \
++	echo "  CHANGELOG: Use the printchanges target to see the curent changes." \
++		>> $(DEBIAN)/changelog.new; \
++	echo "  CHANGELOG: Use the insertchanges target to create the final log." \
++		>> $(DEBIAN)/changelog.new; \
++	echo -e "\n -- $$DEBFULLNAME <$$DEBEMAIL>  $$now\n" >> \
++		$(DEBIAN)/changelog.new ; \
++	cat $(DEBIAN)/changelog >> $(DEBIAN)/changelog.new; \
++	mv $(DEBIAN)/changelog.new $(DEBIAN)/changelog
++
+diff --git a/debian/rules.d/2-binary-arch.mk b/debian/rules.d/2-binary-arch.mk
+new file mode 100644
+index 0000000..8ce1fa8
+--- /dev/null
++++ b/debian/rules.d/2-binary-arch.mk
+@@ -0,0 +1,734 @@
++# We don't want make removing intermediary stamps
++.SECONDARY :
++
++# Prepare the out-of-tree build directory
++ifeq ($(do_full_source),true)
++build_cd = cd $(builddir)/build-$*; #
++build_O  =
++else
++build_cd =
++build_O  = O=$(builddir)/build-$*
++endif
++
++# Typically supplied from the arch makefile, e.g., debian.master/control.d/armhf.mk
++ifneq ($(gcc),)
++kmake += CC=$(CROSS_COMPILE)$(gcc)
++endif
++
++shlibdeps_opts = $(if $(CROSS_COMPILE),-- -l$(CROSS_COMPILE:%-=/usr/%)/lib)
++
++$(stampdir)/stamp-prepare-%: config-prepare-check-%
++	@echo Debug: $@
++	@touch $@
++$(stampdir)/stamp-prepare-tree-%: target_flavour = $*
++$(stampdir)/stamp-prepare-tree-%: $(commonconfdir)/config.common.$(family) $(archconfdir)/config.common.$(arch) $(archconfdir)/config.flavour.%
++	@echo Debug: $@
++	install -d $(builddir)/build-$*
++	touch $(builddir)/build-$*/ubuntu-build
++	[ "$(do_full_source)" != 'true' ] && true || \
++		rsync -a --exclude debian --exclude debian.master --exclude $(DEBIAN) * $(builddir)/build-$*
++	cat $^ | sed -e 's/.*CONFIG_VERSION_SIGNATURE.*/CONFIG_VERSION_SIGNATURE="Ubuntu $(release)-$(revision)-$* $(raw_kernelversion)"/' > $(builddir)/build-$*/.config
++	find $(builddir)/build-$* -name "*.ko" | xargs rm -f
++	$(build_cd) $(kmake) $(build_O) -j1 silentoldconfig prepare scripts
++	touch $@
++
++# Used by developers as a shortcut to prepare a tree for compilation.
++prepare-%: $(stampdir)/stamp-prepare-%
++	@echo Debug: $@
++# Used by developers to allow efficient pre-building without fakeroot.
++build-%: $(stampdir)/stamp-build-%
++	@echo Debug: $@
++
++define build_zfs =
++	#
++	# SPL/ZFS wants a fully built kernel before you can configure and build.
++	# It seems to be impossible to tease out the application configuration
++	# from the modules, but at least one can build just the modules.
++	#
++	install -d $(builddir)/build-$*/spl
++	rsync -a --exclude=dkms.conf --delete spl/ $(builddir)/build-$*/spl/
++	cd $(builddir)/build-$*/spl; sh autogen.sh; sh configure $(splopts)
++	$(kmake) -C $(builddir)/build-$*/spl/module $(conc_level)
++
++	install -d $(builddir)/build-$*/zfs
++	rsync -a --exclude=dkms.conf --delete zfs/ $(builddir)/build-$*/zfs/
++	cd $(builddir)/build-$*/zfs; sh autogen.sh; sh configure $(zfsopts)
++	$(kmake) -C $(builddir)/build-$*/zfs/module $(conc_level)
++endef
++
++# Do the actual build, including image and modules
++$(stampdir)/stamp-build-%: target_flavour = $*
++$(stampdir)/stamp-build-%: splopts  = --with-linux=$(CURDIR)
++$(stampdir)/stamp-build-%: splopts += --with-linux-obj=$(builddir)/build-$*
++$(stampdir)/stamp-build-%: zfsopts  = $(splopts)
++$(stampdir)/stamp-build-%: zfsopts += --with-spl=$(builddir)/build-$*/spl
++$(stampdir)/stamp-build-%: zfsopts += --with-spl-obj=$(builddir)/build-$*/spl
++$(stampdir)/stamp-build-%: zfsopts += --prefix=/usr --with-config=kernel
++$(stampdir)/stamp-build-%: bldimg = $(call custom_override,build_image,$*)
++$(stampdir)/stamp-build-%: enable_zfs = $(call custom_override,do_zfs,$*)
++$(stampdir)/stamp-build-%: $(stampdir)/stamp-prepare-%
++	@echo Debug: $@ build_image $(build_image) bldimg $(bldimg)
++	$(build_cd) $(kmake) $(build_O) $(conc_level) $(bldimg) modules $(if $(filter true,$(do_dtbs)),dtbs)
++
++	$(if $(filter true,$(enable_zfs)),$(call build_zfs))
++
++	@touch $@
++
++define install_zfs =
++	cd $(builddir)/build-$*/spl/module; \
++		$(kmake) -C $(builddir)/build-$* SUBDIRS=`pwd` modules_install $(splopts)
++	cd $(builddir)/build-$*/zfs/module; \
++		$(kmake) -C $(builddir)/build-$* SUBDIRS=`pwd` modules_install $(zfsopts)
++endef
++
++# Install the finished build
++install-%: pkgdir = $(CURDIR)/debian/$(bin_pkg_name)-$*
++install-%: pkgdir_ex = $(CURDIR)/debian/$(extra_pkg_name)-$*
++install-%: bindoc = $(pkgdir)/usr/share/doc/$(bin_pkg_name)-$*
++install-%: dbgpkgdir = $(CURDIR)/debian/$(bin_pkg_name)-$*-dbgsym
++install-%: signed = $(CURDIR)/debian/$(bin_pkg_name)-signed
++install-%: toolspkgdir = $(CURDIR)/debian/$(tools_flavour_pkg_name)-$*
++install-%: cloudpkgdir = $(CURDIR)/debian/$(cloud_flavour_pkg_name)-$*
++install-%: basepkg = $(hdrs_pkg_name)
++install-%: indeppkg = $(indep_hdrs_pkg_name)
++install-%: kernfile = $(call custom_override,kernel_file,$*)
++install-%: instfile = $(call custom_override,install_file,$*)
++install-%: hdrdir = $(CURDIR)/debian/$(basepkg)-$*/usr/src/$(basepkg)-$*
++install-%: target_flavour = $*
++install-%: MODHASHALGO=sha512
++install-%: MODSECKEY=$(builddir)/build-$*/certs/signing_key.pem
++install-%: MODPUBKEY=$(builddir)/build-$*/certs/signing_key.x509
++install-%: build_dir=$(builddir)/build-$*
++install-%: enable_zfs = $(call custom_override,do_zfs,$*)
++install-%: splopts  = INSTALL_MOD_STRIP=1
++install-%: splopts += INSTALL_MOD_PATH=$(pkgdir)/
++install-%: splopts += INSTALL_MOD_DIR=kernel/zfs
++install-%: splopts += $(conc_level)
++install-%: zfsopts  = $(splopts)
++install-%: checks-%
++	@echo Debug: $@ kernel_file $(kernel_file) kernfile $(kernfile) install_file $(install_file) instfile $(instfile)
++	dh_testdir
++	dh_testroot
++	dh_clean -k -p$(bin_pkg_name)-$*
++	dh_clean -k -p$(hdrs_pkg_name)-$*
++ifneq ($(skipdbg),true)
++	dh_clean -k -p$(dbg_pkg_name)-$*
++endif
++
++	# The main image
++	# compress_file logic required because not all architectures
++	# generate a zImage automatically out of the box
++ifeq ($(compress_file),)
++	install -m600 -D $(builddir)/build-$*/$(kernfile) \
++		$(pkgdir)/boot/$(instfile)-$(abi_release)-$*
++else
++	install -d $(pkgdir)/boot
++	gzip -c9v $(builddir)/build-$*/$(kernfile) > \
++		$(pkgdir)/boot/$(instfile)-$(abi_release)-$*
++	chmod 600 $(pkgdir)/boot/$(instfile)-$(abi_release)-$*
++endif
++
++ifeq ($(uefi_signed),true)
++	install -d $(signed)/$(release)-$(revision)
++	# Check to see if this supports handoff, if not do not sign it.
++	# Check the identification area magic and version >= 0x020b
++	handoff=`dd if="$(pkgdir)/boot/$(instfile)-$(abi_release)-$*" bs=1 skip=514 count=6 2>/dev/null | od -s | gawk '($$1 == 0 && $$2 == 25672 && $$3 == 21362 && $$4 >= 523) { print "GOOD" }'`; \
++	if [ "$$handoff" = "GOOD" ]; then \
++		cp -p $(pkgdir)/boot/$(instfile)-$(abi_release)-$* \
++			$(signed)/$(release)-$(revision)/$(instfile)-$(abi_release)-$*.efi; \
++	fi
++endif
++
++	install -m644 $(builddir)/build-$*/.config \
++		$(pkgdir)/boot/config-$(abi_release)-$*
++	install -m644 $(abidir)/$* \
++		$(pkgdir)/boot/abi-$(abi_release)-$*
++	install -m600 $(builddir)/build-$*/System.map \
++		$(pkgdir)/boot/System.map-$(abi_release)-$*
++	if [ "$(filter true,$(do_dtbs))" ]; then \
++		$(build_cd) $(kmake) $(build_O) $(conc_level) dtbs_install \
++			INSTALL_DTBS_PATH=$(pkgdir)/lib/firmware/$(abi_release)-$*/device-tree; \
++		( cd $(pkgdir)/lib/firmware/$(abi_release)-$*/ && find device-tree -print ) | \
++		while read dtb_file; do \
++			echo "$$dtb_file ?" >> $(DEBIAN)/d-i/firmware/kernel-image; \
++		done; \
++	fi
++ifeq ($(no_dumpfile),)
++	makedumpfile -g $(pkgdir)/boot/vmcoreinfo-$(abi_release)-$* \
++		-x $(builddir)/build-$*/vmlinux
++	chmod 0600 $(pkgdir)/boot/vmcoreinfo-$(abi_release)-$*
++endif
++
++	$(build_cd) $(kmake) $(build_O) $(conc_level) modules_install $(vdso) \
++		INSTALL_MOD_STRIP=1 INSTALL_MOD_PATH=$(pkgdir)/ \
++		INSTALL_FW_PATH=$(pkgdir)/lib/firmware/$(abi_release)-$*
++
++	$(if $(filter true,$(enable_zfs)),$(call install_zfs))
++
++	#
++	# Build module blacklists:
++	#  - blacklist all watchdog drivers (LP:1432837)
++	#
++	install -d $(pkgdir)/lib/modprobe.d
++	echo "# Kernel supplied blacklist for $(src_pkg_name) $(abi_release)-$* $(arch)" \
++		>$(pkgdir)/lib/modprobe.d/blacklist_$(src_pkg_name)_$(abi_release)-$*.conf
++	for conf in $(arch)-$* $(arch) common.conf; do \
++		if [ -f $(DEBIAN)/modprobe.d/$$conf ]; then \
++			echo "# modprobe.d/$$conf"; \
++			cat $(DEBIAN)/modprobe.d/$$conf; \
++		fi; \
++	done >>$(pkgdir)/lib/modprobe.d/blacklist_$(src_pkg_name)_$(abi_release)-$*.conf
++	echo "# Autogenerated watchdog blacklist" \
++		>>$(pkgdir)/lib/modprobe.d/blacklist_$(src_pkg_name)_$(abi_release)-$*.conf
++	ls -1 $(pkgdir)/lib/modules/$(abi_release)-$*/kernel/drivers/watchdog/ | \
++		sed -e 's/^/blacklist /' -e 's/.ko$$//' | \
++		sort -u \
++		>>$(pkgdir)/lib/modprobe.d/blacklist_$(src_pkg_name)_$(abi_release)-$*.conf
++
++ifeq ($(do_extras_package),true)
++	#
++	# Remove all modules not in the inclusion list.
++	#
++	if [ -f $(DEBIAN)/control.d/$(target_flavour).inclusion-list ] ; then \
++		/sbin/depmod -v -b $(pkgdir) $(abi_release)-$* | \
++			sed -e "s@$(pkgdir)/lib/modules/$(abi_release)-$*/kernel/@@g" | \
++			awk '{ print $$1 " " $$NF}' >$(build_dir)/module-inclusion.depmap; \
++		mkdir -p $(pkgdir_ex)/lib/modules/$(abi_release)-$*; \
++		mv $(pkgdir)/lib/modules/$(abi_release)-$*/kernel \
++			$(pkgdir_ex)/lib/modules/$(abi_release)-$*/kernel; \
++		$(SHELL) $(DROOT)/scripts/module-inclusion --master \
++			$(pkgdir_ex)/lib/modules/$(abi_release)-$*/kernel \
++			$(pkgdir)/lib/modules/$(abi_release)-$*/kernel \
++			$(DEBIAN)/control.d/$(target_flavour).inclusion-list \
++			$(build_dir)/module-inclusion.depmap 2>&1 | \
++				tee $(target_flavour).inclusion-list.log; \
++		/sbin/depmod -b $(pkgdir) -ea -F $(pkgdir)/boot/System.map-$(abi_release)-$* \
++			$(abi_release)-$* 2>&1 |tee $(target_flavour).depmod.log; \
++		if [ `grep -c 'unknown symbol' $(target_flavour).depmod.log` -gt 0 ]; then \
++			echo "EE: Unresolved module dependencies in base package!"; \
++			exit 1; \
++		fi \
++	fi
++endif
++
++ifeq ($(no_dumpfile),)
++	makedumpfile -g $(pkgdir)/boot/vmcoreinfo-$(abi_release)-$* \
++		-x $(builddir)/build-$*/vmlinux
++	chmod 0600 $(pkgdir)/boot/vmcoreinfo-$(abi_release)-$*
++endif
++	rm -f $(pkgdir)/lib/modules/$(abi_release)-$*/build
++	rm -f $(pkgdir)/lib/modules/$(abi_release)-$*/source
++
++	# Some initramfs-tools specific modules
++	install -d $(pkgdir)/lib/modules/$(abi_release)-$*/initrd
++	if [ -f $(pkgdir)/lib/modules/$(abi_release)-$*/kernel/drivers/video/vesafb.ko ]; then\
++	  $(LN) $(pkgdir)/lib/modules/$(abi_release)-$*/kernel/drivers/video/vesafb.ko \
++		$(pkgdir)/lib/modules/$(abi_release)-$*/initrd/; \
++	fi
++
++	# Now the image scripts
++	install -d $(pkgdir)/DEBIAN
++	for script in postinst postrm preinst prerm; do				\
++	  sed -e 's/=V/$(abi_release)-$*/g' -e 's/=K/$(instfile)/g'		\
++	      -e 's/=L/$(loader)/g'         -e 's@=B@$(build_arch)@g'		\
++	       $(DROOT)/control-scripts/$$script > $(pkgdir)/DEBIAN/$$script;	\
++	  chmod 755 $(pkgdir)/DEBIAN/$$script;					\
++	done
++ifeq ($(do_extras_package),true)
++	# Install the postinit/postrm scripts in the extras package.
++	if [ -f $(DEBIAN)/control.d/$(target_flavour).inclusion-list ] ; then	\
++		install -d $(pkgdir_ex)/DEBIAN;					\
++		for script in postinst postrm ; do				\
++			sed -e 's/=V/$(abi_release)-$*/g' -e 's/=K/$(instfile)/g'		\
++			    -e 's/=L/$(loader)/g'         -e 's@=B@$(build_arch)@g'		\
++			    debian/control-scripts/extra-post > $(pkgdir_ex)/DEBIAN/$$script; \
++			chmod 755 $(pkgdir_ex)/DEBIAN/$$script;			\
++		done;								\
++	fi
++endif
++
++	# Install the full changelog.
++ifeq ($(do_doc_package),true)
++	install -d $(bindoc)
++	cat $(DEBIAN)/changelog $(DEBIAN)/changelog.historical | \
++		gzip -9 >$(bindoc)/changelog.Debian.old.gz
++	chmod 644 $(bindoc)/changelog.Debian.old.gz
++endif
++
++ifneq ($(skipsub),true)
++	for sub in $($(*)_sub); do					\
++		if ! (TO=$$sub FROM=$* ABI_RELEASE=$(abi_release) $(SHELL)		\
++			$(DROOT)/scripts/sub-flavour); then exit 1; fi;		\
++		/sbin/depmod -b debian/$(bin_pkg_name)-$$sub		\
++			-ea -F debian/$(bin_pkg_name)-$$sub/boot/System.map-$(abi_release)-$* \
++			$(abi_release)-$*;					\
++		install -d debian/$(bin_pkg_name)-$$sub/DEBIAN;	\
++		for script in postinst postrm preinst prerm; do			\
++			sed -e 's/=V/$(abi_release)-$*/g'			\
++			    -e 's/=K/$(instfile)/g'				\
++			    -e 's/=L/$(loader)/g'				\
++			    -e 's@=B@$(build_arch)@g'				\
++				$(DROOT)/control-scripts/$$script >		\
++				debian/$(bin_pkg_name)-$$sub/DEBIAN/$$script;\
++			chmod 755  debian/$(bin_pkg_name)-$$sub/DEBIAN/$$script;\
++		done;								\
++	done
++endif
++
++ifneq ($(skipdbg),true)
++	# Debug image is simple
++	install -m644 -D $(builddir)/build-$*/vmlinux \
++		$(dbgpkgdir)/usr/lib/debug/boot/vmlinux-$(abi_release)-$*
++	$(build_cd) $(kmake) $(build_O) modules_install $(vdso) \
++		INSTALL_MOD_PATH=$(dbgpkgdir)/usr/lib/debug
++	# Add .gnu_debuglink sections to each stripped .ko
++	# pointing to unstripped verson
++	find $(pkgdir) -name '*.ko' | sed 's|$(pkgdir)||'| while read module ; do \
++		if [[ -f "$(dbgpkgdir)/usr/lib/debug/$$module" ]] ; then \
++			$(CROSS_COMPILE)objcopy \
++				--add-gnu-debuglink=$(dbgpkgdir)/usr/lib/debug/$$module \
++				$(pkgdir)/$$module; \
++			$(builddir)/build-$*/scripts/sign-file $(MODHASHALGO) \
++				$(MODSECKEY) \
++				$(MODPUBKEY) \
++				$(pkgdir)/$$module; \
++		fi; \
++	done
++	rm -f $(dbgpkgdir)/usr/lib/debug/lib/modules/$(abi_release)-$*/build
++	rm -f $(dbgpkgdir)/usr/lib/debug/lib/modules/$(abi_release)-$*/source
++	rm -f $(dbgpkgdir)/usr/lib/debug/lib/modules/$(abi_release)-$*/modules.*
++	rm -fr $(dbgpkgdir)/usr/lib/debug/lib/firmware
++endif
++
++	# The flavour specific headers image
++	# TODO: Would be nice if we didn't have to dupe the original builddir
++	install -d -m755 $(hdrdir)
++	cat $(builddir)/build-$*/.config | \
++		sed -e 's/.*CONFIG_DEBUG_INFO=.*/# CONFIG_DEBUG_INFO is not set/g' > \
++		$(hdrdir)/.config
++	chmod 644 $(hdrdir)/.config
++	$(kmake) O=$(hdrdir) -j1 silentoldconfig prepare scripts
++	# We'll symlink this stuff
++	rm -f $(hdrdir)/Makefile
++	rm -rf $(hdrdir)/include2 $(hdrdir)/source
++	# Copy over the compilation version.
++	cp "$(builddir)/build-$*/include/generated/compile.h" \
++		"$(hdrdir)/include/generated/compile.h"
++	# Add UTS_UBUNTU_RELEASE_ABI since UTS_RELEASE is difficult to parse.
++	echo "#define UTS_UBUNTU_RELEASE_ABI $(abinum)" >> $(hdrdir)/include/generated/utsrelease.h
++	# powerpc kernel arch seems to need some .o files for external module linking. Add them in.
++ifeq ($(build_arch),powerpc)
++	mkdir -p $(hdrdir)/arch/powerpc/lib
++	cp $(builddir)/build-$*/arch/powerpc/lib/*.o $(hdrdir)/arch/powerpc/lib
++endif
++	# Script to symlink everything up
++	$(SHELL) $(DROOT)/scripts/link-headers "$(hdrdir)" "$(indeppkg)" "$*"
++	# The build symlink
++	install -d debian/$(basepkg)-$*/lib/modules/$(abi_release)-$*
++	$(LN) /usr/src/$(basepkg)-$* \
++		debian/$(basepkg)-$*/lib/modules/$(abi_release)-$*/build
++	# And finally the symvers
++	install -m644 $(builddir)/build-$*/Module.symvers \
++		$(hdrdir)/Module.symvers
++
++	# Now the header scripts
++	install -d $(CURDIR)/debian/$(basepkg)-$*/DEBIAN
++	for script in postinst; do						\
++	  sed -e 's/=V/$(abi_release)-$*/g' -e 's/=K/$(instfile)/g'	\
++		$(DROOT)/control-scripts/headers-$$script > 			\
++			$(CURDIR)/debian/$(basepkg)-$*/DEBIAN/$$script;		\
++	  chmod 755 $(CURDIR)/debian/$(basepkg)-$*/DEBIAN/$$script;		\
++	done
++
++	# At the end of the package prep, call the tests
++	DPKG_ARCH="$(arch)" KERN_ARCH="$(build_arch)" FLAVOUR="$*"	\
++	 VERSION="$(abi_release)" REVISION="$(revision)"		\
++	 PREV_REVISION="$(prev_revision)" ABI_NUM="$(abinum)"		\
++	 PREV_ABI_NUM="$(prev_abinum)" BUILD_DIR="$(builddir)/build-$*"	\
++	 INSTALL_DIR="$(pkgdir)" SOURCE_DIR="$(CURDIR)"			\
++	 run-parts -v $(DROOT)/tests-build
++
++	#
++	# Remove files which are generated at installation by postinst,
++	# except for modules.order and modules.builtin
++	# 
++	# NOTE: need to keep this list in sync with postrm
++	#
++	mkdir $(pkgdir)/lib/modules/$(abi_release)-$*/_
++	mv $(pkgdir)/lib/modules/$(abi_release)-$*/modules.order \
++		$(pkgdir)/lib/modules/$(abi_release)-$*/_
++	if [ -f $(pkgdir)/lib/modules/$(abi_release)-$*/modules.builtin ] ; then \
++	    mv $(pkgdir)/lib/modules/$(abi_release)-$*/modules.builtin \
++		$(pkgdir)/lib/modules/$(abi_release)-$*/_; \
++	fi
++	rm -f $(pkgdir)/lib/modules/$(abi_release)-$*/modules.*
++	mv $(pkgdir)/lib/modules/$(abi_release)-$*/_/* \
++		$(pkgdir)/lib/modules/$(abi_release)-$*
++	rmdir $(pkgdir)/lib/modules/$(abi_release)-$*/_
++
++ifeq ($(do_linux_tools),true)
++	# Create the linux-tools tool links
++	install -d $(toolspkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++ifeq ($(do_tools_usbip),true)
++	$(LN) ../../$(src_pkg_name)-tools-$(abi_release)/usbip $(toolspkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++	$(LN) ../../$(src_pkg_name)-tools-$(abi_release)/usbipd $(toolspkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++endif
++ifeq ($(do_tools_cpupower),true)
++	$(LN) ../../$(src_pkg_name)-tools-$(abi_release)/cpupower $(toolspkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++endif
++ifeq ($(do_tools_perf),true)
++	$(LN) ../../$(src_pkg_name)-tools-$(abi_release)/perf $(toolspkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++endif
++ifeq ($(do_tools_x86),true)
++	$(LN) ../../$(src_pkg_name)-tools-$(abi_release)/x86_energy_perf_policy $(toolspkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++	$(LN) ../../$(src_pkg_name)-tools-$(abi_release)/turbostat $(toolspkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++endif
++endif
++ifeq ($(do_cloud_tools),true)
++ifeq ($(do_tools_hyperv),true)
++	# Create the linux-hyperv tool links
++	install -d $(cloudpkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++	$(LN) ../../$(src_pkg_name)-tools-$(abi_release)/hv_kvp_daemon $(cloudpkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++	$(LN) ../../$(src_pkg_name)-tools-$(abi_release)/hv_vss_daemon $(cloudpkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++	$(LN) ../../$(src_pkg_name)-tools-$(abi_release)/hv_fcopy_daemon $(cloudpkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++	$(LN) ../../$(src_pkg_name)-tools-$(abi_release)/lsvmbus $(cloudpkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++endif
++endif
++
++headers_tmp := $(CURDIR)/debian/tmp-headers
++headers_dir := $(CURDIR)/debian/linux-libc-dev
++
++hmake := $(MAKE) -C $(CURDIR) O=$(headers_tmp) \
++	KERNELVERSION=$(abi_release) INSTALL_HDR_PATH=$(headers_tmp)/install \
++	SHELL="$(SHELL)" ARCH=$(header_arch)
++
++install-arch-headers:
++	@echo Debug: $@
++	dh_testdir
++	dh_testroot
++	dh_clean -k -plinux-libc-dev
++
++	rm -rf $(headers_tmp)
++	install -d $(headers_tmp) $(headers_dir)/usr/include/
++
++	$(hmake) $(defconfig)
++	mv $(headers_tmp)/.config $(headers_tmp)/.config.old
++	sed -e 's/^# \(CONFIG_MODVERSIONS\) is not set$$/\1=y/' \
++	  -e 's/.*CONFIG_LOCALVERSION_AUTO.*/# CONFIG_LOCALVERSION_AUTO is not set/' \
++	  $(headers_tmp)/.config.old > $(headers_tmp)/.config
++	$(hmake) silentoldconfig
++	$(hmake) headers_install
++
++	( cd $(headers_tmp)/install/include/ && \
++		find . -name '.' -o -name '.*' -prune -o -print | \
++                cpio -pvd --preserve-modification-time \
++			$(headers_dir)/usr/include/ )
++	mkdir $(headers_dir)/usr/include/$(DEB_HOST_MULTIARCH)
++	mv $(headers_dir)/usr/include/asm $(headers_dir)/usr/include/$(DEB_HOST_MULTIARCH)/
++
++	rm -rf $(headers_tmp)
++
++binary-arch-headers: install-arch-headers
++	@echo Debug: $@
++	dh_testdir
++	dh_testroot
++ifeq ($(do_libc_dev_package),true)
++ifneq ($(DEBIAN),debian.master)
++	echo "non-master branch building linux-libc-dev, aborting"
++	exit 1
++endif
++	dh_installchangelogs -plinux-libc-dev
++	dh_installdocs -plinux-libc-dev
++	dh_compress -plinux-libc-dev
++	dh_fixperms -plinux-libc-dev
++	dh_installdeb -plinux-libc-dev
++	$(lockme) dh_gencontrol -plinux-libc-dev -- $(libc_dev_version)
++	dh_md5sums -plinux-libc-dev
++	dh_builddeb -plinux-libc-dev
++endif
++
++binary-%: pkgimg = $(bin_pkg_name)-$*
++binary-%: pkgimg_ex = $(extra_pkg_name)-$*
++binary-%: pkghdr = $(hdrs_pkg_name)-$*
++binary-%: dbgpkg = $(bin_pkg_name)-$*-dbgsym
++binary-%: dbgpkgdir = $(CURDIR)/debian/$(bin_pkg_name)-$*-dbgsym
++binary-%: pkgtools = $(tools_flavour_pkg_name)-$*
++binary-%: pkgcloud = $(cloud_flavour_pkg_name)-$*
++binary-%: rprovides = $(if $(filter true,$(call custom_override,do_zfs,$*)),$(comma) spl-dkms$(comma) zfs-dkms)
++binary-%: target_flavour = $*
++binary-%: install-%
++	@echo Debug: $@
++	dh_testdir
++	dh_testroot
++
++	dh_installchangelogs -p$(pkgimg)
++	dh_installdocs -p$(pkgimg)
++	dh_compress -p$(pkgimg)
++	dh_fixperms -p$(pkgimg) -X/boot/
++	dh_installdeb -p$(pkgimg)
++	dh_shlibdeps -p$(pkgimg) $(shlibdeps_opts)
++	$(lockme) dh_gencontrol -p$(pkgimg) -- -Vlinux:rprovides='$(rprovides)'
++	dh_md5sums -p$(pkgimg)
++	dh_builddeb -p$(pkgimg) -- -Zbzip2 -z9
++
++ifeq ($(do_extras_package),true)
++	if [ -f $(DEBIAN)/control.d/$(target_flavour).inclusion-list ] ; then \
++		dh_installchangelogs -p$(pkgimg_ex); \
++		dh_installdocs -p$(pkgimg_ex); \
++		dh_compress -p$(pkgimg_ex); \
++		dh_fixperms -p$(pkgimg_ex) -X/boot/; \
++		dh_installdeb -p$(pkgimg_ex); \
++		dh_shlibdeps -p$(pkgimg_ex) $(shlibdeps_opts); \
++		$(lockme) dh_gencontrol -p$(pkgimg_ex); \
++		dh_md5sums -p$(pkgimg_ex); \
++		dh_builddeb -p$(pkgimg_ex) -- -Zbzip2 -z9; \
++	fi
++endif
++
++	dh_installchangelogs -p$(pkghdr)
++	dh_installdocs -p$(pkghdr)
++	dh_compress -p$(pkghdr)
++	dh_fixperms -p$(pkghdr)
++	dh_shlibdeps -p$(pkghdr) $(shlibdeps_opts)
++	dh_installdeb -p$(pkghdr)
++	$(lockme) dh_gencontrol -p$(pkghdr)
++	dh_md5sums -p$(pkghdr)
++	dh_builddeb -p$(pkghdr)
++
++ifneq ($(skipsub),true)
++	@set -e; for sub in $($(*)_sub); do		\
++		pkg=$(bin_pkg_name)-$$sub;	\
++		dh_installchangelogs -p$$pkg;		\
++		dh_installdocs -p$$pkg;			\
++		dh_compress -p$$pkg;			\
++		dh_fixperms -p$$pkg -X/boot/;		\
++		dh_shlibdeps -p$$pkg $(shlibdeps_opts);	\
++		dh_installdeb -p$$pkg;			\
++		$(lockme) dh_gencontrol -p$$pkg;			\
++		dh_md5sums -p$$pkg;			\
++		dh_builddeb -p$$pkg;			\
++	done
++endif
++
++ifneq ($(skipdbg),true)
++	dh_installchangelogs -p$(dbgpkg)
++	dh_installdocs -p$(dbgpkg)
++	dh_compress -p$(dbgpkg)
++	dh_fixperms -p$(dbgpkg)
++	dh_installdeb -p$(dbgpkg)
++	$(lockme) dh_gencontrol -p$(dbgpkg)
++	dh_md5sums -p$(dbgpkg)
++	dh_builddeb -p$(dbgpkg)
++
++	# Hokay...here's where we do a little twiddling...
++	# Renaming the debug package prevents it from getting into
++	# the primary archive, and therefore prevents this very large
++	# package from being mirrored. It is instead, through some
++	# archive admin hackery, copied to http://ddebs.ubuntu.com.
++	#
++	mv ../$(dbgpkg)_$(release)-$(revision)_$(arch).deb \
++		../$(dbgpkg)_$(release)-$(revision)_$(arch).ddeb
++	set -e; \
++	( \
++		$(lockme_cmd) 9 || exit 1; \
++		if grep -qs '^Build-Debug-Symbols: yes$$' /CurrentlyBuilding; then \
++			sed -i '/^$(dbgpkg)_/s/\.deb /.ddeb /' debian/files; \
++		else \
++			grep -v '^$(dbgpkg)_.*$$' debian/files > debian/files.new; \
++			mv debian/files.new debian/files; \
++		fi; \
++	) 9>$(lockme_file)
++	# Now, the package wont get into the archive, but it will get put
++	# into the debug system.
++endif
++
++ifeq ($(do_linux_tools),true)
++	dh_installchangelogs -p$(pkgtools)
++	dh_installdocs -p$(pkgtools)
++	dh_compress -p$(pkgtools)
++	dh_fixperms -p$(pkgtools)
++	dh_shlibdeps -p$(pkgtools) $(shlibdeps_opts)
++	dh_installdeb -p$(pkgtools)
++	$(lockme) dh_gencontrol -p$(pkgtools)
++	dh_md5sums -p$(pkgtools)
++	dh_builddeb -p$(pkgtools)
++endif
++ifeq ($(do_cloud_tools),true)
++	dh_installchangelogs -p$(pkgcloud)
++	dh_installdocs -p$(pkgcloud)
++	dh_compress -p$(pkgcloud)
++	dh_fixperms -p$(pkgcloud)
++	dh_shlibdeps -p$(pkgcloud) $(shlibdeps_opts)
++	dh_installdeb -p$(pkgcloud)
++	$(lockme) dh_gencontrol -p$(pkgcloud)
++	dh_md5sums -p$(pkgcloud)
++	dh_builddeb -p$(pkgcloud)
++endif
++
++ifneq ($(full_build),false)
++	# Clean out this flavours build directory.
++	rm -rf $(builddir)/build-$*
++	# Clean out the debugging package source directory.
++	rm -rf $(dbgpkgdir)
++endif
++
++#
++# per-architecture packages
++#
++builddirpa = $(builddir)/tools-perarch
++
++$(stampdir)/stamp-prepare-perarch:
++	@echo Debug: $@
++ifeq ($(do_any_tools),true)
++	rm -rf $(builddirpa)
++	install -d $(builddirpa)
++	rsync -a --exclude debian --exclude debian.master --exclude $(DEBIAN) --exclude .git -a ./ $(builddirpa)/
++endif
++	touch $@
++
++$(stampdir)/stamp-build-perarch: $(stampdir)/stamp-prepare-perarch install-arch-headers
++	@echo Debug: $@
++ifeq ($(do_linux_tools),true)
++ifeq ($(do_tools_usbip),true)
++	chmod 755 $(builddirpa)/tools/usb/usbip/autogen.sh
++	cd $(builddirpa)/tools/usb/usbip && ./autogen.sh
++	chmod 755 $(builddirpa)/tools/usb/usbip/configure
++	cd $(builddirpa)/tools/usb/usbip && ./configure --prefix=$(builddirpa)/tools/usb/usbip/bin
++	cd $(builddirpa)/tools/usb/usbip && make install CFLAGS="-g -O2 -static" CROSS_COMPILE=$(CROSS_COMPILE)
++endif
++ifeq ($(do_tools_cpupower),true)
++	# Allow for multiple installed versions of cpupower and libcpupower.so:
++	# Override LIB_MIN in order to to generate a versioned .so named
++	# libcpupower.so.$(abi_release) and link cpupower with that.
++	make -C $(builddirpa)/tools/power/cpupower \
++		CROSS_COMPILE=$(CROSS_COMPILE) \
++		CROSS=$(CROSS_COMPILE) \
++		LIB_MIN=$(abi_release) CPUFREQ_BENCH=false
++endif
++ifeq ($(do_tools_perf),true)
++	cd $(builddirpa) && $(kmake) $(defconfig)
++	mv $(builddirpa)/.config $(builddirpa)/.config.old
++	sed -e 's/^# \(CONFIG_MODVERSIONS\) is not set$$/\1=y/' \
++	  -e 's/.*CONFIG_LOCALVERSION_AUTO.*/# CONFIG_LOCALVERSION_AUTO is not set/' \
++	  $(builddirpa)/.config.old > $(builddirpa)/.config
++	cd $(builddirpa) && $(kmake) silentoldconfig
++	cd $(builddirpa) && $(kmake) prepare
++	cd $(builddirpa)/tools/perf && \
++		$(kmake) prefix=/usr HAVE_CPLUS_DEMANGLE=1 CROSS_COMPILE=$(CROSS_COMPILE) NO_LIBPYTHON=1 NO_LIBPERL=1 PYTHON=python2.7
++endif
++ifeq ($(do_tools_x86),true)
++	cd $(builddirpa)/tools/power/x86/x86_energy_perf_policy && make CROSS_COMPILE=$(CROSS_COMPILE)
++	cd $(builddirpa)/tools/power/x86/turbostat && make CROSS_COMPILE=$(CROSS_COMPILE)
++endif
++endif
++ifeq ($(do_cloud_tools),true)
++ifeq ($(do_tools_hyperv),true)
++	cd $(builddirpa)/tools/hv && make CFLAGS="-I$(headers_dir)/usr/include -I$(headers_dir)/usr/include/$(DEB_HOST_MULTIARCH)" CROSS_COMPILE=$(CROSS_COMPILE) hv_kvp_daemon hv_vss_daemon hv_fcopy_daemon
++endif
++endif
++	@touch $@
++
++install-perarch: toolspkgdir = $(CURDIR)/debian/$(tools_pkg_name)
++install-perarch: cloudpkgdir = $(CURDIR)/debian/$(cloud_pkg_name)
++install-perarch: $(stampdir)/stamp-build-perarch
++	@echo Debug: $@
++	# Add the tools.
++ifeq ($(do_linux_tools),true)
++	install -d $(toolspkgdir)/usr/lib
++	install -d $(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++ifeq ($(do_tools_usbip),true)
++	install -m755 $(builddirpa)/tools/usb/usbip/bin/sbin/usbip \
++		$(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++	install -m755 $(builddirpa)/tools/usb/usbip/bin/sbin/usbipd \
++		$(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++endif
++ifeq ($(do_tools_cpupower),true)
++	install -m755 $(builddirpa)/tools/power/cpupower/cpupower \
++		$(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++	# Install only the full versioned libcpupower.so.$(abi_release), not
++	# the usual symlinks to it.
++	install -m644 $(builddirpa)/tools/power/cpupower/libcpupower.so.$(abi_release) \
++		$(toolspkgdir)/usr/lib/
++endif
++ifeq ($(do_tools_perf),true)
++	install -m755 $(builddirpa)/tools/perf/perf $(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++endif
++ifeq ($(do_tools_x86),true)
++	install -m755 $(builddirpa)/tools/power/x86/x86_energy_perf_policy/x86_energy_perf_policy \
++		$(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++	install -m755 $(builddirpa)/tools/power/x86/turbostat/turbostat \
++		$(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++endif
++endif
++ifeq ($(do_cloud_tools),true)
++ifeq ($(do_tools_hyperv),true)
++	install -d $(cloudpkgdir)/usr/lib
++	install -d $(cloudpkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++	install -m755 $(builddirpa)/tools/hv/hv_kvp_daemon \
++		$(cloudpkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++	install -m755 $(builddirpa)/tools/hv/hv_vss_daemon \
++		$(cloudpkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++	install -m755 $(builddirpa)/tools/hv/hv_fcopy_daemon \
++		$(cloudpkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++	install -m755 $(builddirpa)/tools/hv/lsvmbus \
++		$(cloudpkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++endif
++endif
++
++binary-perarch: toolspkg = $(tools_pkg_name)
++binary-perarch: cloudpkg = $(cloud_pkg_name)
++binary-perarch: install-perarch
++	@echo Debug: $@
++ifeq ($(do_linux_tools),true)
++	dh_strip -p$(toolspkg)
++	dh_installchangelogs -p$(toolspkg)
++	dh_installdocs -p$(toolspkg)
++	dh_compress -p$(toolspkg)
++	dh_fixperms -p$(toolspkg)
++	dh_shlibdeps -p$(toolspkg) $(shlibdeps_opts)
++	dh_installdeb -p$(toolspkg)
++	$(lockme) dh_gencontrol -p$(toolspkg)
++	dh_md5sums -p$(toolspkg)
++	dh_builddeb -p$(toolspkg)
++endif
++ifeq ($(do_cloud_tools),true)
++	dh_strip -p$(cloudpkg)
++	dh_installchangelogs -p$(cloudpkg)
++	dh_installdocs -p$(cloudpkg)
++	dh_compress -p$(cloudpkg)
++	dh_fixperms -p$(cloudpkg)
++	dh_shlibdeps -p$(cloudpkg) $(shlibdeps_opts)
++	dh_installdeb -p$(cloudpkg)
++	$(lockme) dh_gencontrol -p$(cloudpkg)
++	dh_md5sums -p$(cloudpkg)
++	dh_builddeb -p$(cloudpkg)
++endif
++
++binary-debs: signed = $(CURDIR)/debian/$(bin_pkg_name)-signed
++binary-debs: signedv = $(CURDIR)/debian/$(bin_pkg_name)-signed/$(release)-$(revision)
++binary-debs: signed_tar = $(src_pkg_name)_$(release)-$(revision)_$(arch).tar.gz
++binary-debs: binary-perarch $(addprefix binary-,$(flavours))
++	@echo Debug: $@
++ifeq ($(uefi_signed),true)
++	echo $(release)-$(revision) > $(signedv)/version
++	cd $(signedv) && ls *.efi >flavours
++	cd $(signed) && tar czvf ../../../$(signed_tar) .
++	dpkg-distaddfile $(signed_tar) raw-uefi -
++endif
++
++build-arch-deps-$(do_flavour_image_package) += $(addprefix $(stampdir)/stamp-build-,$(flavours))
++build-arch: $(build-arch-deps-true)
++	@echo Debug: $@
++
++ifeq ($(AUTOBUILD),)
++binary-arch-deps-$(do_flavour_image_package) += binary-udebs
++else
++binary-arch-deps-$(do_flavour_image_package) = binary-debs
++endif
++binary-arch-deps-$(do_libc_dev_package) += binary-arch-headers
++ifneq ($(do_common_headers_indep),true)
++binary-arch-deps-$(do_flavour_header_package) += binary-headers
++endif
++binary-arch: $(binary-arch-deps-true)
++	@echo Debug: $@
++
+diff --git a/debian/rules.d/3-binary-indep.mk b/debian/rules.d/3-binary-indep.mk
+new file mode 100644
+index 0000000..e488420
+--- /dev/null
++++ b/debian/rules.d/3-binary-indep.mk
+@@ -0,0 +1,185 @@
++build-indep:
++	@echo Debug: $@
++
++# The binary-indep dependency chain is:
++#
++# install-headers <- install-doc <- install-source <- install-tools <- install-indep <- binary-indep
++# install-headers <- binary-headers
++#
++indep_hdrpkg = $(indep_hdrs_pkg_name)
++indep_hdrdir = $(CURDIR)/debian/$(indep_hdrpkg)/usr/src/$(indep_hdrpkg)
++install-headers:
++	@echo Debug: $@
++	dh_testdir
++	dh_testroot
++	dh_prep
++
++ifeq ($(do_flavour_header_package),true)
++	install -d $(indep_hdrdir)
++	find . -path './debian' -prune -o -path './$(DEBIAN)' -prune \
++	  -o -path './include/*' -prune \
++	  -o -path './scripts/*' -prune -o -type f \
++	  \( -name 'Makefile*' -o -name 'Kconfig*' -o -name 'Kbuild*' -o \
++	     -name '*.sh' -o -name '*.pl' -o -name '*.lds' \) \
++	  -print | cpio -pd --preserve-modification-time $(indep_hdrdir)
++	cp -a scripts include $(indep_hdrdir)
++	(find arch -name include -type d -print | \
++		xargs -n1 -i: find : -type f) | \
++		cpio -pd --preserve-modification-time $(indep_hdrdir)
++endif
++
++docpkg = $(doc_pkg_name)
++docdir = $(CURDIR)/debian/$(docpkg)/usr/share/doc/$(docpkg)
++install-doc: install-headers
++	@echo Debug: $@
++ifeq ($(do_doc_package),true)
++	dh_testdir
++	dh_testroot
++
++	install -d $(docdir)
++ifeq ($(do_doc_package_content),true)
++	# First the html docs. We skip these for autobuilds
++	if [ -z "$(AUTOBUILD)" ]; then \
++		install -d $(docdir)/$(doc_pkg_name)-tmp; \
++		$(kmake) O=$(docdir)/$(doc_pkg_name)-tmp htmldocs; \
++		install -d $(docdir)/html; \
++		rsync -aL $(docdir)/$(doc_pkg_name)-tmp/Documentation/DocBook/ \
++			$(docdir)/html/; \
++		rm -rf $(docdir)/$(doc_pkg_name)-tmp; \
++	fi
++endif
++	# Copy the rest
++	cp -a Documentation/* $(docdir)
++	rm -rf $(docdir)/DocBook
++	find $(docdir) -name .gitignore | xargs rm -f
++endif
++
++srcpkg = $(src_pkg_name)-source-$(release)
++srcdir = $(CURDIR)/debian/$(srcpkg)/usr/src/$(srcpkg)
++balldir = $(CURDIR)/debian/$(srcpkg)/usr/src/$(srcpkg)/$(srcpkg)
++install-source: install-doc
++	@echo Debug: $@
++ifeq ($(do_source_package),true)
++
++	install -d $(srcdir)
++ifeq ($(do_source_package_content),true)
++	find . -path './debian' -prune -o -path './$(DEBIAN)' -prune -o \
++		-path './.*' -prune -o -print | \
++		cpio -pd --preserve-modification-time $(balldir)
++	(cd $(srcdir); tar cf - $(srcpkg)) | bzip2 -9c > \
++		$(srcdir)/$(srcpkg).tar.bz2
++	rm -rf $(balldir)
++	find './debian' './$(DEBIAN)' \
++		-path './debian/linux-*' -prune -o \
++		-path './debian/$(src_pkg_name)-*' -prune -o \
++		-path './debian/build' -prune -o \
++		-path './debian/files' -prune -o \
++		-path './debian/stamps' -prune -o \
++		-path './debian/tmp' -prune -o \
++		-print | \
++		cpio -pd --preserve-modification-time $(srcdir)
++	$(LN) $(srcpkg)/$(srcpkg).tar.bz2 $(srcdir)/..
++endif
++endif
++
++install-tools: toolspkg = $(tools_common_pkg_name)
++install-tools: toolsbin = $(CURDIR)/debian/$(toolspkg)/usr/bin
++install-tools: toolssbin = $(CURDIR)/debian/$(toolspkg)/usr/sbin
++install-tools: toolsman = $(CURDIR)/debian/$(toolspkg)/usr/share/man
++install-tools: cloudpkg = $(cloud_common_pkg_name)
++install-tools: cloudbin = $(CURDIR)/debian/$(cloudpkg)/usr/bin
++install-tools: cloudsbin = $(CURDIR)/debian/$(cloudpkg)/usr/sbin
++install-tools: cloudman = $(CURDIR)/debian/$(cloudpkg)/usr/share/man
++install-tools: install-source $(stampdir)/stamp-build-perarch
++	@echo Debug: $@
++
++ifeq ($(do_tools_common),true)
++ifneq ($(DEBIAN),debian.master)
++	echo "non-master branch building linux-tools-common, aborting"
++	exit 1
++endif
++	rm -rf $(builddir)/tools
++	install -d $(builddir)/tools
++	for i in *; do $(LN) $(CURDIR)/$$i $(builddir)/tools/; done
++	rm $(builddir)/tools/tools
++	rsync -a tools/ $(builddir)/tools/tools/
++
++	install -d $(toolsbin)
++	install -d $(toolsman)/man1
++
++	install -m755 debian/tools/generic $(toolsbin)/usbip
++	install -m755 debian/tools/generic $(toolsbin)/usbipd
++	install -m644 $(CURDIR)/tools/usb/usbip/doc/*.8 $(toolsman)/man1/
++
++	install -m755 debian/tools/generic $(toolsbin)/cpupower
++	install -m644 $(CURDIR)/tools/power/cpupower/man/*.1 $(toolsman)/man1/
++
++	install -m755 debian/tools/generic $(toolsbin)/perf
++
++	install -m755 debian/tools/generic $(toolsbin)/x86_energy_perf_policy
++	install -m755 debian/tools/generic $(toolsbin)/turbostat
++
++	cd $(builddir)/tools/tools/perf && make man
++	install -m644 $(builddir)/tools/tools/perf/Documentation/*.1 \
++		$(toolsman)/man1
++
++	install -d $(toolsman)/man8
++	install -m644 $(CURDIR)/tools/power/x86/x86_energy_perf_policy/*.8 $(toolsman)/man8
++	install -m644 $(CURDIR)/tools/power/x86/turbostat/*.8 $(toolsman)/man8
++
++	install -d $(cloudsbin)
++	install -m755 debian/tools/generic $(cloudsbin)/hv_kvp_daemon
++	install -m755 debian/tools/generic $(cloudsbin)/hv_vss_daemon
++	install -m755 debian/tools/generic $(cloudsbin)/hv_fcopy_daemon
++	install -m755 debian/tools/generic $(cloudsbin)/lsvmbus
++	install -m755 debian/cloud-tools/hv_get_dhcp_info $(cloudsbin)
++	install -m755 debian/cloud-tools/hv_get_dns_info $(cloudsbin)
++	install -m755 debian/cloud-tools/hv_set_ifconfig $(cloudsbin)
++
++	install -d $(cloudman)/man8
++	install -m644 $(CURDIR)/tools/hv/*.8 $(cloudman)/man8
++
++endif
++
++install-indep: install-tools
++	@echo Debug: $@
++
++# This is just to make it easy to call manually. Normally done in
++# binary-indep target during builds.
++binary-headers: install-headers
++	@echo Debug: $@
++	dh_installchangelogs -p$(indep_hdrpkg)
++	dh_installdocs -p$(indep_hdrpkg)
++	dh_compress -p$(indep_hdrpkg)
++	dh_fixperms -p$(indep_hdrpkg)
++	dh_installdeb -p$(indep_hdrpkg)
++	$(lockme) dh_gencontrol -p$(indep_hdrpkg)
++	dh_md5sums -p$(indep_hdrpkg)
++	dh_builddeb -p$(indep_hdrpkg)
++
++binary-indep: cloudpkg = $(cloud_common_pkg_name)
++binary-indep: install-indep
++	@echo Debug: $@
++
++	dh_installchangelogs -i
++	dh_installdocs -i
++	dh_compress -i
++	dh_fixperms -i
++ifeq ($(do_tools_common),true)
++ifneq ($(DEBIAN),debian.master)
++	echo "non-master branch building linux-cloud-tools-common, aborting"
++	exit 1
++endif
++	dh_installinit -p$(cloudpkg) -n --name hv-kvp-daemon
++	dh_installinit -p$(cloudpkg) -n --name hv-vss-daemon
++	dh_installinit -p$(cloudpkg) -n --name hv-fcopy-daemon
++	dh_systemd_enable -p$(cloudpkg)
++	dh_installinit -p$(cloudpkg) -o --name hv-kvp-daemon
++	dh_installinit -p$(cloudpkg) -o --name hv-vss-daemon
++	dh_installinit -p$(cloudpkg) -o --name hv-fcopy-daemon
++	dh_systemd_start -p$(cloudpkg)
++endif
++	dh_installdeb -i
++	$(lockme) dh_gencontrol -i
++	dh_md5sums -i
++	dh_builddeb -i
+diff --git a/debian/rules.d/4-checks.mk b/debian/rules.d/4-checks.mk
+new file mode 100644
+index 0000000..a431d0b
+--- /dev/null
++++ b/debian/rules.d/4-checks.mk
+@@ -0,0 +1,27 @@
++# Check ABI for package against last release (if not same abinum)
++abi-check-%: $(stampdir)/stamp-build-%
++	@echo Debug: $@
++	install -d $(abidir)
++	sed -e 's/^\(.\+\)[[:space:]]\+\(.\+\)[[:space:]]\(.\+\)$$/\3 \2 \1/'	\
++		$(builddir)/build-$*/Module.symvers | sort > $(abidir)/$*
++	@perl -f $(DROOT)/scripts/abi-check "$*" "$(prev_abinum)" "$(abinum)" \
++		"$(prev_abidir)" "$(abidir)" "$(skipabi)"
++
++# Check the module list against the last release (always)
++module-check-%: $(stampdir)/stamp-build-%
++	@echo Debug: $@
++	install -d $(abidir)
++	find $(builddir)/build-$*/ -name \*.ko | \
++		sed -e 's/.*\/\([^\/]*\)\.ko/\1/' | sort > $(abidir)/$*.modules
++	@perl -f $(DROOT)/scripts/module-check "$*" \
++		"$(prev_abidir)" "$(abidir)" $(skipmodule)
++
++checks-%: module-check-% abi-check-%
++	@echo Debug: $@
++
++# Check the config against the known options list.
++config-prepare-check-%: $(stampdir)/stamp-prepare-tree-%
++	@echo Debug: $@
++	@perl -f $(DROOT)/scripts/config-check \
++		$(builddir)/build-$*/.config "$(arch)" "$*" "$(commonconfdir)" "$(skipconfig)"
++
+diff --git a/debian/rules.d/5-udebs.mk b/debian/rules.d/5-udebs.mk
+new file mode 100644
+index 0000000..bb4f452
+--- /dev/null
++++ b/debian/rules.d/5-udebs.mk
+@@ -0,0 +1,74 @@
++# Do udebs if not disabled in the arch-specific makefile
++binary-udebs: binary-debs
++	@echo Debug: $@
++ifeq ($(disable_d_i),)
++	@$(MAKE) --no-print-directory -f $(DROOT)/rules DEBIAN=$(DEBIAN) \
++		do-binary-udebs
++endif
++
++do-binary-udebs: debian/control
++	@echo Debug: $@
++	dh_testdir
++	dh_testroot
++
++	# unpack the kernels into a temporary directory
++	mkdir -p debian/d-i-${arch}
++
++	imagelist=$$(cat $(builddir)/kernel-versions | grep ^${arch} | gawk '{print $$4}') && \
++	for i in $$imagelist; do \
++	  dpkg -x $$(ls ../linux-image-$$i\_$(release)-$(revision)_${arch}.deb) \
++		debian/d-i-${arch}; \
++	  if [ -f ../linux-image-extra-$$i\_$(release)-$(revision)_${arch}.deb ] ; then \
++	    dpkg -x ../linux-image-extra-$$i\_$(release)-$(revision)_${arch}.deb \
++		  debian/d-i-${arch}; \
++	  fi; \
++	  /sbin/depmod -b debian/d-i-${arch} $$i; \
++	done
++
++	# kernel-wedge will error if no modules unless this is touched
++	touch $(CURDIR)/debian/build/no-modules
++
++	touch ignore-dups
++	export SOURCEDIR=$(CURDIR)/debian/d-i-${arch} && \
++	  cd $(builddir) && \
++	  kernel-wedge install-files && \
++	  kernel-wedge check
++
++        # Build just the udebs
++	dilist=$$(dh_listpackages -s | grep "\-di$$") && \
++	[ -z "$dilist" ] || \
++	for i in $$dilist; do \
++	  dh_fixperms -p$$i; \
++	  $(lockme) dh_gencontrol -p$$i; \
++	  dh_builddeb -p$$i; \
++	done
++	
++	# Generate the meta-udeb dependancy lists.
++	@gawk '										\
++		/^Package:/ {								\
++			package=$$2; flavour=""; parch="" }				\
++		(/Package-Type: udeb/ && package !~ /^linux-udebs-/) {      \
++			match(package, "'$(release)'-'$(abinum)'-(.*)-di", bits);       \
++			flavour = bits[1];						\
++		}									\
++		(/^Architecture:/ && $$0 " " ~ / '$(arch)'/) {				\
++			parch=$$0;							\
++		}									\
++		(flavour != "" && parch != "") {					\
++			udebs[flavour] = udebs[flavour] package ", ";			\
++			flavour=""; parch="";						\
++		}                                                      			\
++		END {                                                  			\
++			for (flavour in udebs) {					\
++				package="linux-udebs-" flavour;		\
++				file="debian/" package ".substvars";			\
++				print("udeb:Depends=" udebs[flavour]) > file;		\
++				metas="'$(builddir)'/udeb-meta-packages";		\
++				print(package) >metas					\
++			}								\
++		}									\
++	' <$(CURDIR)/debian/control
++	@while read i; do \
++		$(lockme) dh_gencontrol -p$$i; \
++		dh_builddeb -p$$i; \
++	done <$(builddir)/udeb-meta-packages
+diff --git a/debian/scripts/abi-check b/debian/scripts/abi-check
+new file mode 100755
+index 0000000..039e4d0
+--- /dev/null
++++ b/debian/scripts/abi-check
+@@ -0,0 +1,2 @@
++#!/bin/sh
++exit 0
+diff --git a/debian/scripts/config-check b/debian/scripts/config-check
+new file mode 100755
+index 0000000..039e4d0
+--- /dev/null
++++ b/debian/scripts/config-check
+@@ -0,0 +1,2 @@
++#!/bin/sh
++exit 0
+diff --git a/debian/scripts/control-create b/debian/scripts/control-create
+new file mode 100755
+index 0000000..f8ee9a2
+--- /dev/null
++++ b/debian/scripts/control-create
+@@ -0,0 +1,25 @@
++#!/bin/bash
++
++. debian/debian.env
++
++vars=$1
++
++. $vars
++
++if [ "$is_sub" = "" ]; then
++	flavour=$(basename $vars | sed 's/.*\.//')
++	stub=${DEBIAN}/control.d/flavour-control.stub
++else
++	flavour=$(basename $vars .vars)
++	stub=${DEBIAN}/sub-flavours/control.stub
++fi
++
++cat $stub | grep -v '^#' | sed			\
++	-e "s#FLAVOUR#$flavour#g"		\
++	-e "s#DESC#$desc#g"			\
++	-e "s#ARCH#$arch#g"			\
++	-e "s#SUPPORTED#$supported#g"		\
++	-e "s#TARGET#$target#g"			\
++	-e "s#BOOTLOADER#$bootloader#g" 	\
++	-e "s#=PROVIDES=#$provides#g"		\
++	-e "s#=CONFLICTS=#$conflicts#g"
+diff --git a/debian/scripts/link-headers b/debian/scripts/link-headers
+new file mode 100755
+index 0000000..fb42dbd
+--- /dev/null
++++ b/debian/scripts/link-headers
+@@ -0,0 +1,42 @@
++#!/bin/bash -e
++
++. debian/debian.env
++
++hdrdir="$1"
++symdir="$2"
++flavour="$3"
++
++echo "Symlinking and copying headers for $flavour..."
++
++excludes="( -path ./debian -prune -o -path ./${DEBIAN} -prune -o -path ./.git ) -prune -o"
++
++(
++find . $excludes  -type f \
++	\( -name 'Makefile*' -o -name 'Kconfig*' -o -name 'Kbuild*' -o \
++	-name '*.sh' -o -name '*.pl' -o -name '*.lds' \) -print
++find ./include ./scripts -name .gitignore -prune -o -type f -print
++find ./include -mindepth 1 -maxdepth 1 $excludes -type d -print
++) | (
++while read file; do
++	dir=$file
++	lastdir=$file
++
++	if [ -e "$hdrdir/$file" -o -L "$hdrdir/$file" ]; then
++		continue
++	fi
++
++	while [ ! -e "$hdrdir/$dir" -a ! -L "$hdrdir/$dir" ]; do
++		lastdir=$dir
++		dir=`dirname $dir`
++	done
++	# If the last item to exist is a symlink we assume all is good
++	if [ ! -L "$hdrdir/$dir" ]; then
++		# Turns things like "./foo" into "../"
++		deref="`echo -n $lastdir | sed -e 's/^\.//' -e's,/[^/]*,../,g'`"
++		item="`echo -n $lastdir | sed -e 's/^\.\///'`"
++		ln -s $deref$symdir/$item $hdrdir/$item
++	fi
++done
++)
++
++exit
+diff --git a/debian/scripts/misc/find-obsolete-firmware b/debian/scripts/misc/find-obsolete-firmware
+new file mode 100755
+index 0000000..97a1f30
+--- /dev/null
++++ b/debian/scripts/misc/find-obsolete-firmware
+@@ -0,0 +1,91 @@
++#!/bin/bash
++#
++# Find all duplicate or obsolete firmware that is being carried
++# in the kernel firmware directory. Compare these files against
++# the linux-firmware package for the approriate release. For example,
++# assuming this is raring, then compare the kernel firmware files
++# against the raring branch of linux-firmware.
++#
++# Example: $0 ~/ubuntu/linux-firmware-raring
++
++USEAGE="$0 LINUX-FIRMWARE"
++
++. debian/debian.env
++
++NFWINFO="`find $DEBIAN -name fwinfo|wc -l`"
++if [ ! "$NFWINFO" = "1" ]
++then
++	echo Your repo is hosed. There can only be one fwinfo file.
++	find $DEBIAN -name fwinfo
++	exit 1
++fi
++
++FWINFO="`pwd`/`find $DEBIAN -name fwinfo`"
++
++if [ "$1" = "" ]
++then
++	echo $USEAGE
++	exit 1
++fi
++FW="$1"
++
++if [ ! -f $FW/WHENCE ]
++then
++	echo Bogus linux-firmware directory
++	exit 1
++fi
++if ! egrep -q "^firmware:" $FWINFO
++then
++	echo Bogus firmware info file
++	exit 1
++fi
++
++#
++# Prepare the tree and make firmware.
++#
++TEE="tee -a"
++LO=`pwd`/firmware.txt
++LF=`pwd`/lib/firmware
++rm -rf debian/build $LF $LO
++fakeroot debian/rules clean prepare-generic
++cp debian/build/build-generic/.config .
++mkdir -p $LF
++make firmware_install INSTALL_MOD_PATH=`pwd`
++
++(cd $LF
++find . -type f | while read f
++do
++	BN="`basename $f`"
++
++	if ! grep -q $BN $FWINFO
++	then
++		echo "Unused firmware: $f" | $TEE $LO
++	else
++		if [ -f $FW/$f ]
++		then
++			if ! cmp $FW/$f $f
++			then
++				echo "$f differs" | $TEE $LO
++			else
++				echo "$f is duplicated" | $TEE $LO
++			fi
++		else
++			echo "$f does not exist in $FW" | $TEE $LO
++		fi
++	fi
++done)
++
++#
++# Check for firmware files referenced by the kernel
++# that do not exist in either location.
++#
++cat $FWINFO | while read fwi f
++do
++	if [ -s lib/firmware/$f ] || [ -s $FW/$f ]
++	then
++		continue
++	else
++		echo "Missing firmware $f" | $TEE $LO
++	fi
++done
++
+diff --git a/debian/scripts/misc/fw-to-ihex.sh b/debian/scripts/misc/fw-to-ihex.sh
+new file mode 100755
+index 0000000..a63fe67
+--- /dev/null
++++ b/debian/scripts/misc/fw-to-ihex.sh
+@@ -0,0 +1,18 @@
++#!/bin/bash
++
++F=$1
++if [ "$F" = "" ]
++then
++	echo You must supply a firmware file.
++	exit 1
++fi
++
++echo "unsigned char d[] = {" > $F.c
++hexdump -v -e '"\t" 8/1 "0x%02x, " "\n"' $F >> $F.c
++echo "};" >> $F.c
++sed -i 's/0x .*$//' $F.c
++
++O="`dirname $F`/`basename $F`.o"
++gcc -o $O -c $F.c
++objcopy -Oihex $F.o $F.ihex
++
+diff --git a/debian/scripts/misc/gen-auto-reconstruct b/debian/scripts/misc/gen-auto-reconstruct
+new file mode 100755
+index 0000000..acc90fe
+--- /dev/null
++++ b/debian/scripts/misc/gen-auto-reconstruct
+@@ -0,0 +1,72 @@
++#!/bin/bash
++
++if [ "$#" -ne 3 ]; then
++	echo "Usage: $0 <orig tag>|<base release> <reconstruct> <options>" 1>&2
++	exit 1
++fi
++tag="$1"
++reconstruct="$2"
++options="$3"
++
++case "$tag" in
++v*)	;;
++*)	tag="v${tag%.*}" ;;
++esac
++
++# Validate the tag.
++count=$( git tag -l "$tag" | wc -l )
++if [ "$count" != 1 ]; then
++	echo "$0: $tag: tag invalid" 1>&2
++	exit 1
++fi
++
++#git ls-tree -r --full-tree HEAD | grep ^120 | \
++#while read mode type blobid name
++
++(
++	# Identify all new symlinks since the proffered tag.
++	echo "# Recreate any symlinks created since the orig."
++	git diff "$tag.." --raw --no-renames | awk '(/^:000000 120000/ && $5 == "A") { print $NF }' | \
++	while read name
++	do
++		link=$( readlink "$name" )
++
++		echo "[ ! -L '$name' ] && ln -sf '$link' '$name'"
++	done
++
++	# Identify all removed files since the proffered tag.
++	echo "# Remove any files deleted from the orig."
++	git diff "$tag.." --raw --no-renames | awk '(/^:/ && $5 == "D") { print $NF }' | \
++	while read name
++	do
++		echo "rm -f '$name'"
++	done
++
++	# All done, make sure this does not complete in error.
++	echo "exit 0"
++) >"$reconstruct"
++
++(
++	# Identify all new symlinks since the proffered tag.
++	echo "# Ignore any symlinks created since the orig which are rebuilt by reconstruct."
++	git diff "$tag.." --raw --no-renames | awk '(/^:000000 120000/ && $5 == "A") { print $NF }' | \
++	while read name
++	do
++		echo "extend-diff-ignore=^$name\$"
++	done
++) >"$options.update"
++
++
++head='^## autoreconstruct -- begin$'
++foot='^## autoreconstruct -- end$'
++sed -i -e "
++	/$head/,/$foot/{
++		/$head/{
++			p;
++			r $options.update
++		};
++		/$foot/p;
++		d
++	}
++" "$options"
++rm -f "$options.update"
+diff --git a/debian/scripts/misc/get-firmware b/debian/scripts/misc/get-firmware
+new file mode 100755
+index 0000000..b1ed8e6
+--- /dev/null
++++ b/debian/scripts/misc/get-firmware
+@@ -0,0 +1,62 @@
++#!/bin/bash
++#
++# Find all files in linux-firmware that are new or different since the previous release
++# and copy them into the kernel firmware directory. You should only do this on the
++# backport branch since it would be redundant on the released kernel. It assumed you've
++# unpacked linux-firmware from each release into separate directories.
++#
++# Example: $0 ~/ubuntu/linux-firmware-precise ~/ubuntu/linux-firmware-quantal
++
++if [ "$1" = "" ] || [ "$2" = "" ] || [ ! -f $1/WHENCE ] || [ ! -f $2/WHENCE ]
++then
++	echo You must supply 2 firmware directories.
++	exit 1
++fi
++
++if [ ! -f debian/debian.env ]
++then
++	echo You must run this script from the root of the repo
++	exit 1
++fi
++. debian/debian.env
++
++NFWINFO="`find $DEBIAN -name fwinfo|wc -l`"
++if [ ! "$NFWINFO" = "1" ]
++then
++	echo Your repo is hosed. There can only be one fwinfo file.
++	find $DEBIAN -name fwinfo
++	exit 1
++fi
++
++FWINFO="`pwd`/`find $DEBIAN -name fwinfo`"
++
++CDIR=`pwd`
++OFW=$1
++NFW=$2
++
++cd $NFW
++#
++# Find all files in $NFW that are new or different from $1
++#
++(find . -type f | egrep -v "debian|git|LICEN|WHEN|READ|Make|configure" | sed 's;\./;;' | \
++while read f
++do
++	if grep -q $f $FWINFO
++	then
++		if [ ! -f $OFW/$f ]
++		then
++			echo $f
++		elif ! cmp $f $OFW/$f > /dev/null
++		then
++			echo $f
++		fi
++	fi
++done) |\
++while read f
++do
++	mkdir -p $CDIR/firmware/`dirname $f`
++	if [ ! -f $CDIR/firmware/`dirname $f`/`basename $f`.ihex ]
++	then
++		cp -v $f $CDIR/firmware/`dirname $f`
++	fi
++done
+diff --git a/debian/scripts/misc/getabis b/debian/scripts/misc/getabis
+new file mode 100755
+index 0000000..c7a0c5f
+--- /dev/null
++++ b/debian/scripts/misc/getabis
+@@ -0,0 +1,137 @@
++#!/bin/bash
++
++export LC_ALL=C.UTF-8
++
++if [ "$#" != "2" ]; then
++	echo "Usage: $0 <release> <revision>" 1>&2
++	exit 1
++fi
++
++if [ "$DEBIAN" = "" ]; then
++	. debian/debian.env
++fi
++
++ver=$1
++revision=$2
++abi=$(echo $revision | sed -r -e 's/([^\+~]*)\.[^\.]+(~.*)?(\+.*)?$/\1/')
++
++verabi=$ver-$abi
++verfull=$ver-$revision
++
++WGET="wget --tries=1 --timeout=10 --quiet -c"
++
++abidir="`pwd`/$DEBIAN/abi/$verfull"
++tmpdir="`pwd`/abi-tmp-$verfull"
++origdir="`pwd`"
++fwinfo=$abidir/fwinfo
++
++test -d $tmpdir || mkdir $tmpdir
++
++package_prefixes() {
++	__package_prefixes="$@"
++}
++
++getall() {
++	arch=$1
++	shift
++
++	mkdir -p $abidir/$arch
++
++	for sub in $@; do
++		if [ -f $abidir/$arch/$sub ]; then
++			echo "Exists: $sub"
++			continue
++		fi
++		echo -n "Fetching $sub($arch)..."
++		prefixes=""
++		filenames=""
++		cd $tmpdir
++		for prefix in $__package_prefixes
++		do
++			filename=${prefix}-${verabi}-${sub}_${verfull}_${arch}.deb
++			for r in "${repo_list[@]}"
++			do
++				if ! [ -f $filename ]; then
++					$WGET $r/$filename
++				fi
++				if [ -f $filename ]; then
++					prefixes="$prefixes $prefix"
++					filenames="$filenames $filename"
++					break
++				fi
++			done
++		done
++		if [ "$filenames" != "" ]; then
++			echo -n "extracting$prefixes..."
++			for filename in $filenames
++			do
++				dpkg-deb --extract $filename tmp
++			done
++			find tmp -name "*.ko" | while read f; do
++				modinfo $f | grep ^firmware >> $fwinfo
++			done
++			if [ -f tmp/boot/abi-* ]; then
++				mv tmp/boot/abi-* $abidir/$arch/$sub
++			else
++				echo -n "NO ABI FILE..."
++			fi
++			(cd tmp; find lib/modules/$verabi-$sub/kernel -name '*.ko') | \
++				sed -e 's/.*\/\([^\/]*\)\.ko/\1/' | sort > \
++				$abidir/$arch/$sub.modules
++			(
++				cd tmp;
++				# Prevent exposing some errors when called by python scripts. SIGPIPE seems to get
++				# exposed when using the `find ...` form of the command.
++				ko=$(find lib/modules/$verabi-$sub/kernel \
++					-name '*.ko' | head -1)
++				readelf -p .comment "$ko" | gawk '
++					($1 == "[") {
++						printf("%s", $3);
++						for (n=4; n<=NF; n++) {
++							printf(" %s", $n);
++						}
++						print ""
++					}' | sort -u >$abidir/$arch/$sub.compiler
++				version=`cat $abidir/$arch/$sub.compiler`
++				echo -n "$version..."
++			)
++			rm -rf tmp $filenames
++			echo "done."
++		else
++			echo "FAILED."
++		fi
++		cd $origdir
++	done
++}
++
++# MAIN
++
++# Setup abi directory
++mkdir -p $abidir
++echo $abi > $abidir/abiname
++
++# NOTE: The flavours are hardcoded, because they may have changed from the
++# current build.
++
++__package_prefixes="linux-image"
++
++. $DEBIAN/etc/getabis
++
++# Extract compiler source package version from e.g.:
++#   GCC: (Ubuntu/Linaro 4.8.2-19ubuntu1) 4.8.2
++compilers=`sed 's/^.*(.* \(.*\)).*$/\1/' $abidir/*/*.compiler | sort -u | wc -l`
++if [ "$compilers" != 1 ]; then
++	echo "WARNING: inconsistent compiler versions detected:" 1>&2
++	sort -u $abidir/*/*.compiler | sed 's/^/WARNING:    /' 1>&2
++fi
++
++sort < $fwinfo | uniq > fwinfo.tmp
++mv fwinfo.tmp $fwinfo
++
++rmdir $tmpdir
++
++# If this is running in a git repo, add the new ABI directory, remove the old
++if [ -d ".git" ]; then
++    git add $abidir
++    find $DEBIAN/abi/* -maxdepth 0 -type d | grep -v $verfull | while read f; do git rm -r $f;done
++fi
+diff --git a/debian/scripts/misc/git-ubuntu-log b/debian/scripts/misc/git-ubuntu-log
+new file mode 100755
+index 0000000..e428e57
+--- /dev/null
++++ b/debian/scripts/misc/git-ubuntu-log
+@@ -0,0 +1,139 @@
++#!/usr/bin/python3
++
++import os
++import sys
++
++import codecs
++import urllib.request
++import json
++
++import textwrap
++
++sys.stdin = codecs.getreader("utf-8")(sys.stdin.detach())
++sys.stdout = codecs.getwriter("utf-8")(sys.stdout.detach())
++
++entries = []
++def add_entry(entry):
++    if entry and 'ignore' not in entry:
++        combo = []
++        for bug in entry.get('bugs', []):
++            combo.append(bug)
++        for cve in entry.get('cves', []):
++            combo.append(cve)
++        combo = sorted(combo)
++
++        if len(combo) == 0:
++            if entry.get('title', "").startswith('UBUNTU'):
++                combo = '__packaging__'
++            else:
++                combo = '__mainline__'
++        else:
++            if combo not in keys:
++                keys.append(combo)
++
++        entry['key'] = combo
++        entries.append(entry)
++
++
++# Suck up the git log output and extract the information we need.
++keys = []
++entry = None
++subject_wait = False
++for line in sys.stdin:
++    if line.startswith('commit '):
++        add_entry(entry)
++        entry = {}
++        subject_wait = True
++
++    elif line.startswith('Author: '):
++        bits = line.strip().split(maxsplit=1)
++        entry['author'] = bits[1]
++
++    elif subject_wait and line.startswith('    '):
++        subject_wait = False
++        entry['subject'] = line.strip()
++
++    elif line.startswith('    BugLink: ') and 'launchpad.net' in line:
++        bits = line.strip().split(maxsplit=1)
++        bits = bits[1].split('/')
++        entry.setdefault('bugs', []).append(bits[-1])
++
++    elif line.startswith('    CVE-'):
++        entry.setdefault('cves', []).append(line.strip())
++
++    elif line.startswith('    Ignore:'):
++        entry['ignore'] = True
++
++add_entry(entry)
++
++entries.reverse()
++
++# Go through the entries and clear out authors for upstream commits.
++for entry in entries:
++    if entry['subject'].startswith('UBUNTU:'):
++        entry['subject'] = entry['subject'][7:].strip()
++    else:
++        del entry['author']
++
++# Lump everything without a bug at the bottom.
++keys.append('__packaging__')
++keys.append('__mainline__')
++
++emit_nl = False
++for key in keys:
++    if key == '__packaging__':
++        title_set = [ 'Miscellaneous Ubuntu changes' ]
++    elif key == '__mainline__':
++        title_set = [ 'Miscellaneous upstream changes' ]
++    else:
++        title_set = []
++        for bug in key:
++            if bug.startswith('CVE-'):
++                title_set.append(bug)
++            else:
++                bug_info = None
++
++                try:
++                    #urllib.request.urlcleanup()
++                    request = urllib.request.Request('https://api.launchpad.net/devel/bugs/' + bug)
++                    request.add_header('Cache-Control', 'max-age=0')
++                    with urllib.request.urlopen(request) as response:
++                        data = response.read()
++                        bug_info = json.loads(data.decode('utf-8'))
++
++                    title = bug_info['title']
++                    if 'description' in bug_info:
++                        for line in bug_info['description'].split('\n'):
++                            if line.startswith('Kernel-Description:'):
++                                title = line.split(' ', 1)[1]
++
++                except urllib.error.HTTPError:
++                    title = 'INVALID or PRIVATE BUG'
++
++                title += ' (LP###' + bug + ')'
++                title_set.append(title)
++
++
++    emit_title = True
++    for entry in entries:
++        if entry['key'] != key:
++            continue
++
++        if emit_title:
++            if emit_nl:
++                print('')
++            emit_nl = True
++
++            title_lines = textwrap.wrap('#// '.join(title_set), 76)
++            print('  * ' + title_lines[0].replace('LP###', 'LP: #').replace('#//', ' //'))
++            for line in title_lines[1:]:
++                line = line.replace('LP###', 'LP: #').replace('#//', ' //')
++                print('    ' + line)
++
++            emit_title = False
++
++        title_lines = textwrap.wrap(entry['subject'], 76)
++        print('    - ' + title_lines[0])
++        for line in title_lines[1:]:
++            line = line.replace('LP###', 'LP: #')
++            print('      ' + line)
+diff --git a/debian/scripts/misc/insert-changes.pl b/debian/scripts/misc/insert-changes.pl
+new file mode 100755
+index 0000000..c820597
+--- /dev/null
++++ b/debian/scripts/misc/insert-changes.pl
+@@ -0,0 +1,36 @@
++#!/usr/bin/perl -w
++
++my $debian;
++$droot = $ARGV[0] if (defined $ARGV[0]);
++$droot = 'debian' if (!defined $droot);
++$debian = $ARGV[1] if (defined $ARGV[1]);
++$debian = 'debian.master' if (!defined $debian);
++
++system("make -s -f $droot/rules printchanges > $debian/changes");
++
++open(CHANGELOG, "< $debian/changelog") or die "Cannot open changelog";
++open(CHANGES, "< $debian/changes") or die "Cannot open new changes";
++open(NEW, "> $debian/changelog.new") or die "Cannot open new changelog";
++
++$printed = 0;
++
++while (<CHANGELOG>) {
++	if (/^  CHANGELOG: /) {
++		next if $printed;
++
++		while (<CHANGES>) {
++			print NEW;
++		}
++
++		$printed = 1;
++	} else {
++		print NEW;
++	}
++}
++
++close(NEW);
++close(CHANGES);
++close(CHANGELOG);
++
++rename("$debian/changelog.new", "$debian/changelog");
++unlink("$debian/changes");
+diff --git a/debian/scripts/misc/insert-mainline-changes b/debian/scripts/misc/insert-mainline-changes
+new file mode 100755
+index 0000000..5678b10
+--- /dev/null
++++ b/debian/scripts/misc/insert-mainline-changes
+@@ -0,0 +1,42 @@
++#!/usr/bin/perl
++
++if ($#ARGV != 2) {
++	warn "Usage: $0 <changelog> <to> <range>\n";
++	die  "       $0 debian.master/changelog v3.2.3 v3.2.2..v3.2.3\n";
++}
++my ($changelog, $to, $range) = @ARGV;
++
++my @changes = ();
++
++push(@changes, "\n");
++push(@changes, "  [ Upstream Kernel Changes ]\n\n");
++push(@changes, "  * rebase to $to\n");
++
++open(LOG, "git log '$range'|") || die "$0: git log failed: - $!\n";
++while (<LOG>) {
++	if (m@BugLink: .*launchpad.net/.*/([0-9]+)\s$@) {
++		push(@changes, "    - LP: #$1\n");
++	}
++}
++close(LOG);
++
++open(CHANGELOG, "< $changelog") or die "Cannot open changelog";
++open(NEW, "> $changelog.new") or die "Cannot open new changelog";
++
++$printed = 3;
++while (<CHANGELOG>) {
++	if (/^  CHANGELOG: /) {
++		$printed--;
++		print NEW;
++		if ($printed == 0) {
++			print NEW @changes;
++		}
++		next;
++	}
++	print NEW;
++}
++
++close(NEW);
++close(CHANGELOG);
++
++rename("$changelog.new", "$changelog");
+diff --git a/debian/scripts/misc/insert-ubuntu-changes b/debian/scripts/misc/insert-ubuntu-changes
+new file mode 100755
+index 0000000..145c81c
+--- /dev/null
++++ b/debian/scripts/misc/insert-ubuntu-changes
+@@ -0,0 +1,80 @@
++#!/usr/bin/perl
++
++if ($#ARGV != 2) {
++	die "Usage: $0 <changelog> <stop at> <start at>\n";
++}
++my ($changelog, $end, $start) = @ARGV;
++
++$end =~ s/^\D+//;
++$start =~ s/^\D+//;
++
++sub version_cmp($$) {
++	my @a = split(/[\.-]+/, $_[0]);
++	my @b = split(/[\.-]+/, $_[1]);
++	for (my $i = 1;; $i++) {
++		if (!defined $a[$i]) {
++			if (!defined $b[$i]) {
++				return 0;
++			}
++			return -1;
++		}
++		if (!defined $b[$i]) {
++			return 1;
++		}
++		if ($a[$i] < $b[$i]) {
++			return -1;
++		}
++		if ($a[$i] > $b[$i]) {
++			return 1;
++		}
++	}
++}
++
++my @changes = ();
++my $output = 0;
++open(CHG, "<debian.master/changelog") ||
++	open(CHG, "<debian/changelog") ||
++	die "$0: debian/changelog: open failed - $!\n";
++while (<CHG>) {
++	if (/^\S+\s+\((.*)\)/) {
++		if (version_cmp($1, $end) <= 0) {
++			last;
++		}
++		if ($1 eq $start) {
++			$output = 1;
++		}
++		if ($output) {
++			push(@changes, "\n  [ Ubuntu: $1 ]\n\n");
++			next;
++		}
++	}
++	next if ($output == 0);
++
++	next if (/^\s*$/);
++	next if (/^\s--/);
++	next if (/^\s\s[^\*\s]/);
++
++	push(@changes, $_);
++}
++close(CHG);
++
++open(CHANGELOG, "< $changelog") or die "Cannot open changelog";
++open(NEW, "> $changelog.new") or die "Cannot open new changelog";
++
++$printed = 3;
++while (<CHANGELOG>) {
++	if (/^  CHANGELOG: /) {
++		$printed--;
++		print NEW;
++		if ($printed == 0) {
++			print NEW @changes;
++		}
++		next;
++	}
++	print NEW;
++}
++
++close(NEW);
++close(CHANGELOG);
++
++rename("$changelog.new", "$changelog");
+diff --git a/debian/scripts/misc/kernelconfig b/debian/scripts/misc/kernelconfig
+new file mode 100755
+index 0000000..ffb6082
+--- /dev/null
++++ b/debian/scripts/misc/kernelconfig
+@@ -0,0 +1,172 @@
++#!/bin/bash
++
++. debian/debian.env
++
++# Script to merge all configs and run 'make silentoldconfig' on it to wade out bad juju.
++# Then split the configs into distro-commmon and flavour-specific parts
++
++# We have to be in the top level kernel source directory
++if [ ! -f MAINTAINERS ] || [ ! -f Makefile ]; then
++	echo "This does not appear to be the kernel source directory." 1>&2
++	exit 1
++fi
++
++mode=${1:?"Usage: $0 [oldconfig|editconfig]"}
++yes=0
++case "$mode" in
++    update*configs)  mode='silentoldconfig' ;;
++    default*configs) mode='oldconfig'; yes=1 ;;
++    edit*configs)    ;; # All is good
++    gen*configs)     mode='genconfigs' ;; # All is good
++    dump*configs)    mode='config'; yes=1 ;;
++    *) echo "$0 called with invalid mode" 1>&2
++       exit 1 ;;
++esac
++kerneldir="`pwd`"
++confdir="$kerneldir/${DEBIAN}/config"
++variant="$2"
++
++. $DEBIAN/etc/kernelconfig
++
++bindir="`pwd`/${DROOT}/scripts/misc"
++common_conf="$confdir/config.common.$family"
++tmpdir=`mktemp -d`
++mkdir "$tmpdir/CONFIGS"
++
++if [ "$mode" = "genconfigs" ]; then
++	keep=1
++	mode="oldconfig"
++	test -d CONFIGS || mkdir CONFIGS
++fi
++
++for arch in $archs; do
++	rm -rf build
++	mkdir build
++
++	# Map debian archs to kernel archs
++	case "$arch" in
++		ppc64|ppc64el)	kernarch="powerpc"	;;
++		amd64)		kernarch="x86_64"	;;
++		lpia)		kernarch="x86" 		;;
++		sparc)		kernarch="sparc64"	;;
++		armel|armhf)	kernarch="arm"		;;
++		s390x)		kernarch="s390"		;;
++		*)		kernarch="$arch"	;;
++	esac
++
++	archconfdir=$confdir/$arch
++	flavourconfigs=$(cd $archconfdir && ls config.flavour.*)
++
++	# Merge configs
++	# We merge config.common.ubuntu + config.common.<arch> +
++	# config.flavour.<flavour>
++
++	for config in $flavourconfigs; do
++		fullconf="$tmpdir/$arch-$config-full"
++		case $config in
++		*)
++			: >"$fullconf"
++			if [ -f $common_conf ]; then
++				cat $common_conf >> "$fullconf"
++			fi
++			if [ -f $archconfdir/config.common.$arch ]; then
++				cat $archconfdir/config.common.$arch >> "$fullconf"
++			fi
++			cat "$archconfdir/$config" >>"$fullconf"
++			if [ -f $confdir/OVERRIDES ]; then
++				cat $confdir/OVERRIDES >> "$fullconf"
++			fi
++			;;
++		esac
++	done
++
++	for config in $flavourconfigs; do
++		if [ -f $archconfdir/$config ]; then
++			fullconf="$tmpdir/$arch-$config-full"
++			cat "$fullconf" > build/.config
++			# Call oldconfig or menuconfig
++			case "$mode" in
++			    editconfigs)
++				# Interactively edit config parameters
++				while : ; do
++					echo -n "Do you want to edit config: $arch/$config? [Y/n] "
++					read choice
++					
++					case "$choice" in
++					y* | Y* | "" )
++						make O=`pwd`/build ARCH=$kernarch menuconfig
++						break ;;
++					n* | N* )
++						break ;;
++					*)
++						echo "Entry not valid"
++					esac
++				done
++				;;
++			    *)
++				echo "* Run $mode (yes=$yes) on $arch/$config ..."
++				if [ "$yes" -eq 1 ]; then
++					yes "" | make O=`pwd`/build ARCH=$kernarch "$mode"
++				else
++					make O=`pwd`/build ARCH=$kernarch "$mode"
++				fi ;;
++			esac
++			cat build/.config > $archconfdir/$config
++			cat build/.config > "$tmpdir/CONFIGS/$arch-$config"
++			if [ "$keep" = "1" ]; then
++				cat build/.config > CONFIGS/$arch-$config
++			fi
++		else
++			echo "!! Config not found $archconfdir/$config..."
++		fi
++	done
++
++	echo "Running splitconfig.pl for $arch"
++	echo
++
++	# Can we make this more robust by avoiding $tmpdir completely?
++	# This approach was used for now because I didn't want to change
++	# splitconfig.pl
++	(cd $archconfdir; $bindir/splitconfig.pl config.flavour.*; mv config.common \
++	 config.common.$arch; cp config.common.$arch $tmpdir)
++done
++
++rm -f $common_conf
++
++# Now run splitconfig.pl on all the config.common.<arch> copied to
++# $tmpdir
++(cd $tmpdir; $bindir/splitconfig.pl *)
++(
++	cd $confdir;
++	rm -f *-full
++	grep -v 'is UNMERGABLE' <$tmpdir/config.common >$common_conf
++	for arch in $archs; do
++		grep -v 'is UNMERGABLE' <$tmpdir/config.common.$arch \
++			>$arch/config.common.$arch
++	done
++)
++
++echo ""
++echo "Running config-check for all configurations ..."
++echo ""
++fail=0
++for arch in $archs; do
++	archconfdir=$confdir/$arch
++	flavourconfigs=$(cd $archconfdir && ls config.flavour.*)
++	for config in $flavourconfigs; do
++		flavour="${config##*.}"
++		if [ -f $archconfdir/$config ]; then
++			fullconf="$tmpdir/CONFIGS/$arch-$config"
++			"$bindir/../config-check" "$fullconf" "$arch" "$flavour" "$confdir" "0" || let "fail=$fail+1"
++		fi
++	done
++done
++
++if [ "$fail" != 0 ]; then
++	echo ""
++	echo "*** ERROR: $fail config-check failures detected"
++	echo ""
++fi
++
++rm -rf build
++
+diff --git a/debian/scripts/misc/retag b/debian/scripts/misc/retag
+new file mode 100755
+index 0000000..94cf169
+--- /dev/null
++++ b/debian/scripts/misc/retag
+@@ -0,0 +1,34 @@
++#!/usr/bin/perl -w
++
++open(TAGS, "git tag -l |") or die "Could not get list of tags";
++@tags = <TAGS>;
++close(TAGS);
++
++open(LOGS, "git log --pretty=short |") or die "ERROR: Calling git log";
++my $commit = "";
++
++while (<LOGS>) {
++	my $origtag;
++
++	if (m|^commit (.*)$|) {
++		$commit = $1;
++		next;
++	}
++
++	m|\s*UBUNTU: (Ubuntu-2\.6\..*)| or next;
++
++	$tag = $1;
++
++	($origtag) = grep(/^$tag.orig$/, @tags);
++
++	if (!defined($origtag)) {
++		print "I: Adding original tag for $tag\n";
++		system("git tag -m $tag $tag.orig $tag");
++	}
++
++	print "I: Tagging $tag => $commit\n";
++
++	system("git tag -f -m $tag $tag $commit");
++}
++
++close(LOGS);
+diff --git a/debian/scripts/misc/splitconfig.pl b/debian/scripts/misc/splitconfig.pl
+new file mode 100755
+index 0000000..3270ede
+--- /dev/null
++++ b/debian/scripts/misc/splitconfig.pl
+@@ -0,0 +1,107 @@
++#!/usr/bin/perl -w
++
++%allconfigs = ();
++%common = ();
++
++print "Reading config's ...\n";
++
++for $config (@ARGV) {
++	# Only config.*
++	next if $config !~ /^config\..*/;
++	# Nothing that is disabled, or remnant
++	next if $config =~ /.*\.(default|disabled|stub)$/;
++
++	%{$allconfigs{$config}} = ();
++
++	print "  processing $config ... ";
++
++	open(CONFIG, "< $config");
++
++	while (<CONFIG>) {
++		# Skip comments
++		/^#*\s*CONFIG_(\w+)[\s=](.*)$/ or next;
++
++		${$allconfigs{$config}}{$1} = $2;
++
++		$common{$1} = $2;
++	}
++
++	close(CONFIG);
++
++	print "done.\n";
++}
++
++print "\n";
++
++print "Merging lists ... \n";
++
++# %options - pointer to flavour config inside the allconfigs array
++for $config (keys(%allconfigs)) {
++	my %options = %{$allconfigs{$config}};
++
++	print "   processing $config ... ";
++
++	for $key (keys(%common)) {
++		next if not defined $common{$key};
++
++		# If we don't have the common option, then it isn't
++		# common. If we do have that option, it must have the same
++		# value.  EXCEPT where this file does not have a value at all
++		# which may safely be merged with any other value; the value
++		# will be elided during recombination of the parts.
++		if (!defined($options{$key})) {
++			# Its ok really ... let it merge
++		} elsif (not defined($options{$key})) {
++			undef $common{$key};
++		} elsif ($common{$key} ne $options{$key}) {
++			undef $common{$key};
++		}
++	}
++
++	print "done.\n";
++}
++
++print "\n";
++
++print "Creating common config ... ";
++
++open(COMMON, "> config.common");
++print COMMON "#\n# Common config options automatically generated by splitconfig.pl\n#\n";
++
++for $key (sort(keys(%common))) {
++	if (not defined $common{$key}) {
++		print COMMON "# CONFIG_$key is UNMERGABLE\n";
++	} elsif ($common{$key} eq "is not set") {
++		print COMMON "# CONFIG_$key is not set\n";
++	} else {
++		print COMMON "CONFIG_$key=$common{$key}\n";
++	}
++}
++close(COMMON);
++
++print "done.\n\n";
++
++print "Creating stub configs ...\n";
++
++for $config (keys(%allconfigs)) {
++	my %options = %{$allconfigs{$config}};
++
++	print "  processing $config ... ";
++
++	open(STUB, "> $config");
++	print STUB "#\n# Config options for $config automatically generated by splitconfig.pl\n#\n";
++
++	for $key (sort(keys(%options))) {
++		next if defined $common{$key};
++
++		if ($options{$key} =~ /^is /) {
++			print STUB "# CONFIG_$key $options{$key}\n";
++		} else {
++			print STUB "CONFIG_$key=$options{$key}\n";
++		}
++	}
++
++	close(STUB);
++
++	print "done.\n";
++}
+diff --git a/debian/scripts/misc/update-aufs.sh b/debian/scripts/misc/update-aufs.sh
+new file mode 100755
+index 0000000..288b920
+--- /dev/null
++++ b/debian/scripts/misc/update-aufs.sh
+@@ -0,0 +1,50 @@
++#!/bin/bash
++
++AUFS=aufs4-standalone
++
++#
++# Before you run this be sure you've removed or reverted the 'UBUNTU: SAUCE: AUFS" patch.
++#
++#
++# Make sure the current working directory is at the top of the
++# linux tree.
++#
++if ! grep PATCHLEVEL Makefile
++then
++	echo "You must run this script from the top of the linux tree"
++	exit 1
++fi
++
++clean=0
++if [ "$#" = 1 ]; then
++	AUFS="$1"
++else
++	clean=1
++	rm -rf ${AUFS}
++	git clone https://github.com/sfjro/aufs4-standalone.git ${AUFS}
++	(cd ${AUFS}; git checkout -b aufs4.x-rcN remotes/origin/aufs4.x-rcN)
++fi
++
++cp ${AUFS}/include/uapi/linux/aufs_type.h include/uapi/linux
++rsync -av ${AUFS}/fs/ fs/
++rsync -av ${AUFS}/Documentation/ Documentation/
++
++PATCHES="${PATCHES} aufs4-kbuild.patch"
++PATCHES="${PATCHES} aufs4-base.patch"
++PATCHES="${PATCHES} aufs4-mmap.patch"
++PATCHES="${PATCHES} aufs4-standalone.patch"
++PATCHES="${PATCHES} aufs4-loopback.patch"
++#PATCHES="${PATCHES} vfs-ino.patch"
++PATCHES="${PATCHES} tmpfs-idr.patch"
++
++for i in ${PATCHES}
++do
++	patch -p1 < ${AUFS}/$i
++done
++
++[ "$clean" = 1 ] && rm -rf ${AUFS}
++git add mm/prfile.c
++git add -u
++find . -name "*.orig" | xargs rm
++find . |grep aufs | xargs git add
++git commit -s -m"UBUNTU: SAUCE: AUFS"
+diff --git a/debian/scripts/misc/update-zfs.sh b/debian/scripts/misc/update-zfs.sh
+new file mode 100755
+index 0000000..860ad24
+--- /dev/null
++++ b/debian/scripts/misc/update-zfs.sh
+@@ -0,0 +1,33 @@
++#!/bin/bash
++#
++# Update spl/zfs from the Ubuntu archive. You will have to manually check
++# to see if the version has been updated.
++#
++SPL_MAJOR_VER=${_SPL_MAJOR_VER:-0.6.5.4}
++SPL_MINOR_VER=${_SPL_MINOR_VER:-0ubuntu1}
++SPL_DKMS=${_SPL_DKMS:-http://archive.ubuntu.com/ubuntu/pool/universe/s/spl-linux/spl-dkms_${SPL_MAJOR_VER}-${SPL_MINOR_VER}_amd64.deb}
++
++ZFS_MAJOR_VER=${_ZFS_MAJOR_VER:-0.6.5.4}
++ZFS_MINOR_VER=${_ZFS_MINOR_VER:-0ubuntu1}
++ZFS_DKMS=${_ZFS_DKMS:-http://archive.ubuntu.com/ubuntu/pool/universe/z/zfs-linux/zfs-dkms_${ZFS_MAJOR_VER}-${ZFS_MINOR_VER}_amd64.deb}
++
++function update_from_archive {
++
++	URL=$1
++	DEST_DIR=$2
++	VER=$3
++
++	rm -rf ${DEST_DIR}.tmp
++	wget -O ${DEST_DIR}.deb ${URL}
++	dpkg -x ${DEST_DIR}.deb ${DEST_DIR}.tmp
++	mkdir -p ${DEST_DIR}
++	rsync -a --delete ${DEST_DIR}.tmp/usr/src/${DEST_DIR}-${VER}*/ ${DEST_DIR}/
++	rm -rf ${DEST_DIR}.deb ${DEST_DIR}.tmp
++	find ${DEST_DIR} -type f | while read f;do git add -f $f;done
++}
++
++update_from_archive ${SPL_DKMS} spl ${SPL_MAJOR_VER}
++update_from_archive ${ZFS_DKMS} zfs ${ZFS_MAJOR_VER}
++
++git add -u
++git commit -s -m"UBUNTU: SAUCE: (noup) Update spl to ${SPL_MAJOR_VER}-${SPL_MINOR_VER}, zfs to ${ZFS_MAJOR_VER}-${ZFS_MINOR_VER}"
+diff --git a/debian/scripts/module-check b/debian/scripts/module-check
+new file mode 100755
+index 0000000..039e4d0
+--- /dev/null
++++ b/debian/scripts/module-check
+@@ -0,0 +1,2 @@
++#!/bin/sh
++exit 0
+diff --git a/debian/scripts/module-inclusion b/debian/scripts/module-inclusion
+new file mode 100755
+index 0000000..ccec0f2
+--- /dev/null
++++ b/debian/scripts/module-inclusion
+@@ -0,0 +1,104 @@
++#!/bin/bash
++
++#
++# Build a new directory of modules based on an inclusion list.
++# The includsion list format must be a bash regular expression.
++#
++# usage: $0 ROOT INCLUSION_LIST
++# example: $0 \
++#       debian/build/build-virtual-ALL debian/build/build-virtual \
++#	debian.master/control.d/virtual.inclusion-list \
++#	virtual.depmap
++master=0
++if [ "$1" = "--master" ]; then
++	master=1
++	shift
++fi
++
++ROOT=$1
++NROOT=$2
++ILIST=$3
++DEPMAP=$4
++
++tmp="/tmp/module-inclusion.$$"
++
++#
++# Prep a destination directory.
++#
++mkdir -p ${NROOT}
++
++{
++	# Copy over the framework into the master package.
++	if  [ "$master" -eq 1 ]; then
++		(cd ${ROOT}; find . ! -name "*.ko" -type f)
++	fi
++
++	# Copy over modules by name or pattern.
++	while read -r i
++	do
++		#
++		# 'find' blurts a warning if it cannot find any ko files.
++		#
++		case "$i" in
++		\!*)
++			(cd ${ROOT}; ${i#!} || true)
++			;;
++		*\**)
++			(cd ${ROOT}; eval find "${i}" -name "*.ko" || true)
++			;;
++		*)
++			echo "$i"
++			;;
++		esac
++	done <"${ILIST}"
++} >"$tmp"
++
++# Copy over the listed modules.
++while read i
++do
++	# If this is already moved over, all is good.
++	if [ -f "${NROOT}/$i" ]; then
++		:
++
++	# If present in the source, moved it over.
++	elif [ -f "${ROOT}/$i" ]; then
++		mkdir -p "${NROOT}/`dirname $i`"
++		mv "${ROOT}/$i" "${NROOT}/$i"
++
++	# Otherwise, it is missing.
++	else
++		echo "Warning: Could not find ${ROOT}/$i" 1>&2
++	fi
++done <"$tmp"
++
++# Copy over any dependancies, note if those are missing
++# we know they are in a pre-requisite package as they must
++# have existed at depmap generation time, and can only have
++# moved into a package.
++let n=0 || true
++while [ -s "$tmp" ]
++do
++	let n="$n+1" || true
++	[ "$n" = "20" ] && break || true
++
++	echo "NOTE: pass $n: dependency scan" 1>&2
++
++	while read i
++	do
++		grep "^$i " "$DEPMAP" | \
++		while read m d
++		do
++			if [ -f "${ROOT}/$d" ]; then
++				echo "NOTE: pass $n: ${i} pulls in ${d}" 1>&2
++				echo "$d"
++				mkdir -p "${NROOT}/`dirname $d`"
++				mv "${ROOT}/$d" "${NROOT}/$d"
++			fi
++		done
++	done <"$tmp" >"$tmp.new"
++	mv -f "$tmp.new" "$tmp"
++done
++
++rm -f "$tmp"
++
++exit 0
+diff --git a/debian/scripts/sub-flavour b/debian/scripts/sub-flavour
+new file mode 100644
+index 0000000..0100493
+--- /dev/null
++++ b/debian/scripts/sub-flavour
+@@ -0,0 +1,69 @@
++#!/bin/bash
++
++. debian/debian.env
++
++echo "SUB_PROCESS $FROM => $TO"
++
++export from_pkg="linux-image-$ABI_RELEASE-$FROM"
++export to_pkg="linux-image-$ABI_RELEASE-$TO"
++
++from_moddir="debian/$from_pkg/lib/modules/$ABI_RELEASE-$FROM"
++to_moddir="debian/$to_pkg/lib/modules/$ABI_RELEASE-$FROM"
++
++install -d "debian/$to_pkg/boot"
++install -m644 debian/$from_pkg/boot/config-$ABI_RELEASE-$FROM \
++	debian/$to_pkg/boot/
++install -m600 debian/$from_pkg/boot/{vmlinuz,System.map}-$ABI_RELEASE-$FROM \
++	debian/$to_pkg/boot/
++
++#
++# Print some warnings if there are files in the sub-flavours list
++# that do not actually exist.
++#
++cat ${DEBIAN}/sub-flavours/$TO.list | while read line
++do
++(
++	cd debian/$from_pkg/lib/modules/$ABI_RELEASE-$FROM/kernel;
++	#
++	# If its a wildcard, then check that there are files that match.
++	#
++	if echo "$line" | grep '\*' > /dev/null
++	then
++		if [ `eval find "$line" -name '*.ko' 2>/dev/null|wc -l` -lt 1 ]
++		then
++			echo SUB_INST Warning - No files in $line
++		fi
++	#
++	# Else it should be a single file reference.
++	#
++	elif [ ! -f "$line" ]
++	then
++		echo SUB_INST Warning - could not find "$line"
++	fi
++)
++done
++
++cat ${DEBIAN}/sub-flavours/$TO.list | while read line; do
++	(
++	cd debian/$from_pkg/lib/modules/$ABI_RELEASE-$FROM/kernel;
++	if echo "$line" | grep '\*' > /dev/null
++	then
++		eval find "$line" -name '*.ko' 2>/dev/null || true
++	elif [ -f "$line" ]
++	then
++		echo "$line"
++	fi
++	);
++done | while read mod; do
++	echo "SUB_INST checking: $mod"
++	fromdir="/lib/modules/$ABI_RELEASE-$FROM/"
++	egrep "^($fromdir)?kernel/$mod:" \
++		$from_moddir/modules.dep | sed -e "s|^$fromdir||" -e 's/://' -e 's/ /\n/g' | \
++	while read m; do
++		m="${fromdir}$m"
++		test -f debian/$to_pkg/$m && continue
++		echo "SUB_INST installing: $m"
++		install -D -m644 debian/$from_pkg/$m \
++			debian/$to_pkg/$m
++	done
++done
+diff --git a/debian/snapcraft.mk b/debian/snapcraft.mk
+new file mode 100644
+index 0000000..49f8727
+--- /dev/null
++++ b/debian/snapcraft.mk
+@@ -0,0 +1,11 @@
++ifeq ($(ARCH),)
++  arch := $(shell uname -m | sed -e s/i.86/i386/ -e s/x86_64/amd64/ \
++            -e s/arm.*/armhf/ -e s/s390/s390x/ -e s/ppc.*/powerpc/ \
++            -e s/aarch64.*/arm64/ )
++else ifeq ($(ARCH),arm)
++  arch := armhf
++else
++  arch := $(ARCH)
++endif
++config:
++	cat debian.$(branch)/config/config.common.ubuntu debian.$(branch)/config/$(arch)/config.common.$(arch) debian.$(branch)/config/$(arch)/config.flavour.$(flavour) >.config
+diff --git a/debian/source/format b/debian/source/format
+new file mode 100644
+index 0000000..d3827e7
+--- /dev/null
++++ b/debian/source/format
+@@ -0,0 +1 @@
++1.0
+diff --git a/debian/source/options b/debian/source/options
+new file mode 100644
+index 0000000..ccc7d39
+--- /dev/null
++++ b/debian/source/options
+@@ -0,0 +1,14 @@
++# Ignore vbox symlinks, we will regenerate these at clean (LP:1426113)
++## autoreconstruct -- begin
++# Ignore any symlinks created since the orig which are rebuilt by reconstruct.
++extend-diff-ignore=^ubuntu/vbox/vboxguest/include$
++extend-diff-ignore=^ubuntu/vbox/vboxguest/r0drv$
++extend-diff-ignore=^ubuntu/vbox/vboxsf/include$
++extend-diff-ignore=^ubuntu/vbox/vboxsf/r0drv$
++extend-diff-ignore=^ubuntu/vbox/vboxvideo/include$
++extend-diff-ignore=^ubuntu/vbox/vboxvideo/r0drv$
++## autoreconstruct -- end
++
++# force "dpkg-source -I -i" behavior
++diff-ignore
++tar-ignore
+diff --git a/debian/stamps/keep-dir b/debian/stamps/keep-dir
+new file mode 100644
+index 0000000..5c38d4a
+--- /dev/null
++++ b/debian/stamps/keep-dir
+@@ -0,0 +1 @@
++Place holder
+diff --git a/debian/tests-build/README b/debian/tests-build/README
+new file mode 100644
+index 0000000..c74d1c4
+--- /dev/null
++++ b/debian/tests-build/README
+@@ -0,0 +1,21 @@
++Scripts placed in this directory get called one at a time by run-parts(8).
++The scripts are expected to perform some sort of sanity checks on the
++finished build. Scripts will be called once for each flavour.
++
++Some environment variables are exported to make life a little easier:
++
++DPKG_ARCH     : The dpkg architecture (e.g. "amd64")
++KERN_ARCH     : The kernel architecture (e.g. "x86_64")
++FLAVOUR       : The specific flavour for this run (e.g. "generic")
++VERSION       : The full version of this build (e.g. 2.6.22-1)
++REVISION      : The exact revision of this build (e.g. 1.3)
++PREV_REVISION : The revision prior to this one
++ABI_NUM       : The specific ABI number for this build (e.g. 2)
++PREV_ABI_NUM  : The previous ABI number. Can be the same as ABI_NUM.
++BUILD_DIR     : The directory where this build took place
++INSTALL_DIR   : The directory where the package is prepared
++SOURCE_DIR    : Where the main kernel source is
++
++Scripts are expected to have a zero exit status when no problems occur,
++and non-zero when an error occurs that should stop the build. Scripts
++should print whatever info they deem needed to deduce the problem.
+diff --git a/debian/tests-build/check-aliases b/debian/tests-build/check-aliases
+new file mode 100755
+index 0000000..b85118f
+--- /dev/null
++++ b/debian/tests-build/check-aliases
+@@ -0,0 +1,24 @@
++#!/usr/bin/perl -w
++
++my %map;
++
++print "Checking for dupe aliases in $ENV{'FLAVOUR'}...\n";
++
++$aliases =
++  "$ENV{'INSTALL_DIR'}/lib/modules/$ENV{'VERSION'}-$ENV{'FLAVOUR'}/modules.alias";
++
++open(ALIASES, "< $aliases") or die "Could not open $aliases";
++
++while (<ALIASES>) {
++	chomp;
++	my ($junk, $alias, $module) = split;
++
++	if (defined($map{$alias})) {
++		printf("%s %20s / %-20s : %s \n", ("$map{$alias}" eq "$module")
++			? "INT" : "   ", $map{$alias}, $module, $alias);
++	} else {
++		$map{$alias} = $module;
++	}
++}
++
++exit(0);
+diff --git a/debian/tests/control b/debian/tests/control
+new file mode 100644
+index 0000000..c24efa1
+--- /dev/null
++++ b/debian/tests/control
+@@ -0,0 +1,7 @@
++Tests: rebuild
++Depends: @builddeps@, fakeroot
++Restrictions: allow-stderr
++
++Tests: ubuntu-regression-suite
++Depends: build-essential, gcc-multilib [amd64 arm64 armhf i386 powerpc], gdb, git, bzr
++Restrictions: allow-stderr, isolation-machine, breaks-testbed
+diff --git a/debian/tests/rebuild b/debian/tests/rebuild
+new file mode 100644
+index 0000000..8149156
+--- /dev/null
++++ b/debian/tests/rebuild
+@@ -0,0 +1,20 @@
++#!/bin/sh
++
++# If we are triggering for just linux or linux-meta we know we have
++# just built the kernel and there is no point in repeating that
++# build, it just wastes time.  (LP: #1498862)
++build_needed=0
++for trigger in ${ADT_TEST_TRIGGERS:-force}
++do
++	case "$trigger" in
++	linux/*|linux-lts-*/*|linux-meta*/*)		;;
++	*)						build_needed=1 ;;
++	esac
++done
++if [ "$build_needed" -eq 0 ]; then
++	echo "rebuild: short circuiting build for '${ADT_TEST_TRIGGERS}'"
++	exit 0
++fi
++
++set -e
++dpkg-buildpackage -rfakeroot -us -uc -b -Pautopkgtest
+diff --git a/debian/tests/ubuntu-regression-suite b/debian/tests/ubuntu-regression-suite
+new file mode 100755
+index 0000000..1de5ce6
+--- /dev/null
++++ b/debian/tests/ubuntu-regression-suite
+@@ -0,0 +1,19 @@
++#!/bin/sh
++set -e
++
++sver=`dpkg-parsechangelog -SVersion`
++read x rver x </proc/version_signature
++
++flavour=${rver#*-*-}
++rver=${rver%-$flavour}
++
++echo "Source Package Version: $sver"
++echo "Running Kernel Version: $rver"
++
++if [ "$sver" != "$rver" ]; then
++    echo "ERROR: running version does not match source package" 1>&2
++    exit 1
++fi
++
++git clone git://kernel.ubuntu.com/ubuntu/kernel-testing
++kernel-testing/run-dep8-tests
+diff --git a/debian/tools/generic b/debian/tools/generic
+new file mode 100644
+index 0000000..ebc87fd
+--- /dev/null
++++ b/debian/tools/generic
+@@ -0,0 +1,60 @@
++#!/bin/bash
++full_version=`uname -r`
++
++# First check for a fully qualified version.
++this="/usr/lib/linux-tools/$full_version/`basename $0`"
++if [ -f "$this" ]; then
++	exec "$this" "$@"
++fi
++
++# Removing flavour from version i.e. generic or server.
++flavour_abi=${full_version#*-}
++flavour=${flavour_abi#*-}
++version=${full_version%-$flavour}
++this="$0_$version"
++if [ -f "$this" ]; then
++	exec "$this" "$@"
++fi
++
++# Before saucy kernels we had no flavour linkage.
++if dpkg --compare-versions "$version" lt "3.11.0"; then
++	flavour=''
++else
++	flavour="-$flavour"
++fi
++# Hint at the cloud tools if they exist (trusty and later)
++if dpkg --compare-versions "$version" ge "3.13.0"; then
++	cld=""
++else
++	cld=":"
++fi
++# Work out if this is an LTS backport or not.
++codename=`lsb_release -cs`
++case "$codename" in
++precise)	base='3.2.0-9999' ;;
++trusty)		base='3.13.0-9999' ;;
++*)		base='' ;;
++esac
++std=""
++lts=":"
++if [ "$base" != "" ]; then
++	if dpkg --compare-versions "$version" gt "$base"; then
++		std=":"
++		lts=""
++	fi
++fi
++
++# Give them a hint as to what to install.
++		echo "WARNING: `basename $0` not found for kernel $version" >&2
++		echo "" >&2
++		echo "  You may need to install the following packages for this specific kernel:" >&2
++		echo "    linux-tools-$version$flavour" >&2
++$cld		echo "    linux-cloud-tools-$version$flavour" >&2
++		echo "" >&2
++		echo "  You may also want to install one of the following packages to keep up to date:" >&2
++$std		echo "    linux-tools$flavour" >&2
++$std $cld	echo "    linux-cloud-tools$flavour" >&2
++$lts		echo "    linux-tools$flavour-lts-<series>" >&2
++$lts $cld	echo "    linux-cloud-tools$flavour-lts-<series>" >&2
++
++exit 2
+diff --git a/debian/zfs-modules.ignore b/debian/zfs-modules.ignore
+new file mode 100644
+index 0000000..9529d23
+--- /dev/null
++++ b/debian/zfs-modules.ignore
+@@ -0,0 +1,8 @@
++spl
++splat
++zavl
++zcommon
++zfs
++znvpair
++zpios
++zunicode
+-- 
+2.7.4
+
diff --git a/buffalo/ubuntu/0005-debian-changelog.patch b/buffalo/ubuntu/0005-debian-changelog.patch
new file mode 100644
index 00000000..3d2fcde
--- /dev/null
+++ b/buffalo/ubuntu/0005-debian-changelog.patch
@@ -0,0 +1,25105 @@
+From 680c2ceca31b950281046641effca52439f63c50 Mon Sep 17 00:00:00 2001
+From: Kernel Builder <kernel@gloin.kernel>
+Date: Sat, 3 Feb 2018 12:31:06 -0500
+Subject: [PATCH 5/6] debian changelog
+
+---
+ debian.master/changelog | 25085 +---------------------------------------------
+ 1 file changed, 3 insertions(+), 25082 deletions(-)
+
+diff --git a/debian.master/changelog b/debian.master/changelog
+index fea7d8f..f5215bc 100644
+--- a/debian.master/changelog
++++ b/debian.master/changelog
+@@ -1,25085 +1,6 @@
+-linux (4.4.0-112.135) xenial; urgency=low
++linux (4.4.115-0404115.201802031230) xenial; urgency=low
+ 
+-  * linux: 4.4.0-112.135 -proposed tracker (LP: #1744244)
++  Mainline build at commit: v4.4.115
+ 
+-  * CVE-2017-5715 // CVE-2017-5753
+-    - x86/cpuid: Provide get_scattered_cpuid_leaf()
+-    - SAUCE: Fix spec_ctrl support in KVM
+-    - SAUCE: s390: improve cpu alternative handling for gmb and nobp
+-    - SAUCE: s390: print messages for gmb and nobp
+-    - [Config] KERNEL_NOBP=y
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Fri, 19 Jan 2018 11:03:51 +0100
+-
+-linux (4.4.0-111.134) xenial; urgency=low
+-
+-  * linux: 4.4.0-111.134 -proposed tracker (LP: #1743362)
+-
+-  * Do not duplicate changelog entries assigned to more than one bug or CVE
+-    (LP: #1743383)
+-    - [Packaging] git-ubuntu-log -- handle multiple bugs/cves better
+-
+-  * CVE-2017-5715 // CVE-2017-5753
+-    - SAUCE: x86/microcode: Extend post microcode reload to support IBPB feature
+-      -- repair missmerge
+-    - Revert "x86/svm: Add code to clear registers on VM exit"
+-    - kvm: vmx: Scrub hardware GPRs at VM-exit
+-
+-  * CVE-2017-5754
+-    - SAUCE: powerpc: use sync instead of hwsync mnemonic
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Mon, 15 Jan 2018 15:05:02 +0100
+-
+-linux (4.4.0-110.133) xenial; urgency=low
+-
+-  * linux: 4.4.0-110.133 -proposed tracker (LP: #1742995)
+-
+-  * CVE-2017-5753
+-    - x86/microcode/AMD: Add support for fam17h microcode loading
+-    - bpf: add bpf_patch_insn_single helper
+-    - bpf: prepare bpf_int_jit_compile/bpf_prog_select_runtime apis
+-    - bpf: add generic constant blinding for use in jits
+-    - locking/barriers: introduce new memory barrier gmb()
+-    - bpf: prevent speculative execution in eBPF interpreter
+-    - x86, bpf, jit: prevent speculative execution when JIT is enabled
+-    - uvcvideo: prevent speculative execution
+-    - carl9170: prevent speculative execution
+-    - qla2xxx: prevent speculative execution
+-    - Thermal/int340x: prevent speculative execution
+-    - userns: prevent speculative execution
+-    - ipv6: prevent speculative execution
+-    - fs: prevent speculative execution
+-    - net: mpls: prevent speculative execution
+-    - udf: prevent speculative execution
+-    - x86/feature: Enable the x86 feature to control Speculation
+-    - x86/feature: Report presence of IBPB and IBRS control
+-    - x86/enter: MACROS to set/clear IBRS and set IBPB
+-    - x86/enter: Use IBRS on syscall and interrupts
+-    - x86/idle: Disable IBRS entering idle and enable it on wakeup
+-    - x86/idle: Disable IBRS when offlining cpu and re-enable on wakeup
+-    - x86/mm: Set IBPB upon context switch
+-    - x86/mm: Only set IBPB when the new thread cannot ptrace current thread
+-    - x86/entry: Stuff RSB for entry to kernel for non-SMEP platform
+-    - x86/kvm: add MSR_IA32_SPEC_CTRL and MSR_IA32_PRED_CMD to kvm
+-    - x86/kvm: Set IBPB when switching VM
+-    - x86/kvm: Toggle IBRS on VM entry and exit
+-    - x86/kvm: Pad RSB on VM transition
+-    - x86/spec_ctrl: Add sysctl knobs to enable/disable SPEC_CTRL feature
+-    - x86/spec_ctrl: Add lock to serialize changes to ibrs and ibpb control
+-    - x86/syscall: Clear unused extra registers on syscall entrance
+-    - x86/syscall: Clear unused extra registers on 32-bit compatible syscall
+-      entrance
+-    - x86/entry: Use retpoline for syscall's indirect calls
+-    - x86/cpu/amd, kvm: Satisfy guest kernel reads of IC_CFG MSR
+-    - x86/cpu/AMD: Add speculative control support for AMD
+-    - x86/microcode: Extend post microcode reload to support IBPB feature
+-    - KVM: SVM: Do not intercept new speculative control MSRs
+-    - x86/svm: Set IBRS value on VM entry and exit
+-    - x86/svm: Set IBPB when running a different VCPU
+-    - KVM: x86: Add speculative control CPUID support for guests
+-    - x86/svm: Add code to clobber the RSB on VM exit
+-    - x86/svm: Add code to clear registers on VM exit
+-    - x86/cpu/AMD: Make the LFENCE instruction serialized
+-    - x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC feature
+-    - powerpc: add gmb barrier
+-    - s390/spinlock: add gmb memory barrier
+-    - SAUCE: x86/kvm: Fix stuff_RSB() for 32-bit
+-    - arm64: no gmb() implementation yet
+-    - arm: no gmb() implementation yet
+-
+-  * CVE-2017-5715
+-    - x86/microcode/AMD: Add support for fam17h microcode loading
+-    - bpf: add bpf_patch_insn_single helper
+-    - bpf: prepare bpf_int_jit_compile/bpf_prog_select_runtime apis
+-    - bpf: add generic constant blinding for use in jits
+-    - locking/barriers: introduce new memory barrier gmb()
+-    - bpf: prevent speculative execution in eBPF interpreter
+-    - x86, bpf, jit: prevent speculative execution when JIT is enabled
+-    - uvcvideo: prevent speculative execution
+-    - carl9170: prevent speculative execution
+-    - qla2xxx: prevent speculative execution
+-    - Thermal/int340x: prevent speculative execution
+-    - userns: prevent speculative execution
+-    - ipv6: prevent speculative execution
+-    - fs: prevent speculative execution
+-    - net: mpls: prevent speculative execution
+-    - udf: prevent speculative execution
+-    - x86/feature: Enable the x86 feature to control Speculation
+-    - x86/feature: Report presence of IBPB and IBRS control
+-    - x86/enter: MACROS to set/clear IBRS and set IBPB
+-    - x86/enter: Use IBRS on syscall and interrupts
+-    - x86/idle: Disable IBRS entering idle and enable it on wakeup
+-    - x86/idle: Disable IBRS when offlining cpu and re-enable on wakeup
+-    - x86/mm: Set IBPB upon context switch
+-    - x86/mm: Only set IBPB when the new thread cannot ptrace current thread
+-    - x86/entry: Stuff RSB for entry to kernel for non-SMEP platform
+-    - x86/kvm: add MSR_IA32_SPEC_CTRL and MSR_IA32_PRED_CMD to kvm
+-    - x86/kvm: Set IBPB when switching VM
+-    - x86/kvm: Toggle IBRS on VM entry and exit
+-    - x86/kvm: Pad RSB on VM transition
+-    - x86/spec_ctrl: Add sysctl knobs to enable/disable SPEC_CTRL feature
+-    - x86/spec_ctrl: Add lock to serialize changes to ibrs and ibpb control
+-    - x86/syscall: Clear unused extra registers on syscall entrance
+-    - x86/syscall: Clear unused extra registers on 32-bit compatible syscall
+-      entrance
+-    - x86/entry: Use retpoline for syscall's indirect calls
+-    - x86/cpu/amd, kvm: Satisfy guest kernel reads of IC_CFG MSR
+-    - x86/cpu/AMD: Add speculative control support for AMD
+-    - x86/microcode: Extend post microcode reload to support IBPB feature
+-    - KVM: SVM: Do not intercept new speculative control MSRs
+-    - x86/svm: Set IBRS value on VM entry and exit
+-    - x86/svm: Set IBPB when running a different VCPU
+-    - KVM: x86: Add speculative control CPUID support for guests
+-    - x86/svm: Add code to clobber the RSB on VM exit
+-    - x86/svm: Add code to clear registers on VM exit
+-    - x86/cpu/AMD: Make the LFENCE instruction serialized
+-    - x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC feature
+-    - powerpc: add gmb barrier
+-    - s390/spinlock: add gmb memory barrier
+-    - SAUCE: x86/kvm: Fix stuff_RSB() for 32-bit
+-    - arm64: no gmb() implementation yet
+-    - arm: no gmb() implementation yet
+-
+-  * powerpc: flush L1D on return to use (LP: #1742772)
+-    - SAUCE: powerpc: Secure memory rfi flush
+-    - SAUCE: rfi-flush: Make DEBUG_RFI a CONFIG option
+-    - SAUCE: rfi-flush: Add HRFI_TO_UNKNOWN and use it in denorm
+-    - SAUCE: Fixup rfid in kvmppc_skip_Hinterrupt should be hrfid
+-    - SAUCE: rfi-flush: kvmppc_skip_(H)interrupt returns to host
+-    - SAUCE: KVM: Revert the implementation of H_GET_CPU_CHARACTERISTICS
+-    - SAUCE: rfi-flush: Implement congruence-first fallback flush
+-    - SAUCE: rfi-flush: Make l1d_flush_type bit flags
+-    - SAUCE: rfi-flush: Push the instruction selection down to the patching
+-      routine
+-    - SAUCE: rfi-flush: Expand the RFI section to two nop slots
+-    - SAUCE: rfi-flush: Support more than one flush type at once
+-    - SAUCE: rfi-flush: Allow HV to advertise multiple flush types
+-    - SAUCE: rfi-flush: Add speculation barrier before ori 30,30,0 flush
+-    - SAUCE: powerpc/asm: Allow including ppc_asm.h in asm files
+-    - SAUCE: Remove setup.h include file otherwise compilation complains about
+-      missing header file.
+-    - SAUCE: Fix compilation errors for arch/powerpc/lib/feature-fixups.c
+-    - SAUCE: rfi-flush: Add barriers to the fallback L1D flushing
+-    - SAUCE: rfi-flush: Rework powernv logic to be more cautious
+-    - SAUCE: rfi-flush: Rework pseries logic to be more cautious
+-    - SAUCE: rfi-flush: Fix the fallback flush to actually activate
+-    - SAUCE: rfi-flush: Fix HRFI_TO_UNKNOWN
+-    - SAUCE: rfi-flush: Refactor the macros so the nops are defined once
+-    - SAUCE: rfi-flush: Add no_rfi_flush and nopti comandline options
+-    - SAUCE: rfi-flush: Use rfi-flush in printks
+-    - SAUCE: rfi-flush: Fallback flush add load dependency
+-    - SAUCE: rfi-flush: Fix the 32-bit KVM build
+-    - SAUCE: rfi-flush: Fix some RFI conversions in the KVM code
+-    - SAUCE: UBUNTU: [Config] Disable CONFIG_PPC_DEBUG_RFI
+-
+-  * s390: add ppa to kernel entry/exit (LP: #1742771)
+-    - s390: introduce CPU alternatives
+-    - s390: add ppa to kernel entry / exit
+-
+-  * CVE-2017-5754
+-    - x86/tlb: Drop the _GPL from the cpu_tlbstate export
+-    - Map the vsyscall page with _PAGE_USER
+-    - s390: introduce CPU alternatives
+-    - s390: add ppa to kernel entry / exit
+-    - SAUCE: powerpc: Secure memory rfi flush
+-    - SAUCE: rfi-flush: Make DEBUG_RFI a CONFIG option
+-    - SAUCE: rfi-flush: Add HRFI_TO_UNKNOWN and use it in denorm
+-    - SAUCE: Fixup rfid in kvmppc_skip_Hinterrupt should be hrfid
+-    - SAUCE: rfi-flush: kvmppc_skip_(H)interrupt returns to host
+-    - SAUCE: KVM: Revert the implementation of H_GET_CPU_CHARACTERISTICS
+-    - SAUCE: rfi-flush: Implement congruence-first fallback flush
+-    - SAUCE: rfi-flush: Make l1d_flush_type bit flags
+-    - SAUCE: rfi-flush: Push the instruction selection down to the patching
+-      routine
+-    - SAUCE: rfi-flush: Expand the RFI section to two nop slots
+-    - SAUCE: rfi-flush: Support more than one flush type at once
+-    - SAUCE: rfi-flush: Allow HV to advertise multiple flush types
+-    - SAUCE: rfi-flush: Add speculation barrier before ori 30,30,0 flush
+-    - SAUCE: powerpc/asm: Allow including ppc_asm.h in asm files
+-    - SAUCE: Remove setup.h include file otherwise compilation complains about
+-      missing header file.
+-    - SAUCE: Fix compilation errors for arch/powerpc/lib/feature-fixups.c
+-    - SAUCE: rfi-flush: Add barriers to the fallback L1D flushing
+-    - SAUCE: rfi-flush: Rework powernv logic to be more cautious
+-    - SAUCE: rfi-flush: Rework pseries logic to be more cautious
+-    - SAUCE: rfi-flush: Fix the fallback flush to actually activate
+-    - SAUCE: rfi-flush: Fix HRFI_TO_UNKNOWN
+-    - SAUCE: rfi-flush: Refactor the macros so the nops are defined once
+-    - SAUCE: rfi-flush: Add no_rfi_flush and nopti comandline options
+-    - SAUCE: rfi-flush: Use rfi-flush in printks
+-    - SAUCE: rfi-flush: Fallback flush add load dependency
+-    - SAUCE: rfi-flush: Fix the 32-bit KVM build
+-    - SAUCE: rfi-flush: Fix some RFI conversions in the KVM code
+-    - SAUCE: UBUNTU: [Config] Disable CONFIG_PPC_DEBUG_RFI
+-
+- -- Marcelo Henrique Cerri <marcelo.cerri@canonical.com>  Fri, 12 Jan 2018 14:47:54 -0200
+-
+-linux (4.4.0-109.132) xenial; urgency=low
+-
+-  * linux: 4.4.0-109.132 -proposed tracker (LP: #1742252)
+-
+-  * Kernel trace with xenial 4.4  (4.4.0-108.131, Candidate kernels for PTI fix)
+-    (LP: #1741934)
+-    - SAUCE: kaiser: fix perf crashes - fix to original commit
+-
+- -- Marcelo Henrique Cerri <marcelo.cerri@canonical.com>  Tue, 09 Jan 2018 15:56:26 -0200
+-
+-linux (4.4.0-108.131) xenial; urgency=low
+-
+-  * linux: 4.4.0-108.131 -proposed tracker (LP: #1741727)
+-
+-  * CVE-2017-5754
+-    - x86/mm: Disable PCID on 32-bit kernels
+-
+- -- Marcelo Henrique Cerri <marcelo.cerri@canonical.com>  Sun, 07 Jan 2018 11:46:05 -0200
+-
+-linux (4.4.0-107.130) xenial; urgency=low
+-
+-  * linux: 4.4.0-107.130 -proposed tracker (LP: #1741643)
+-
+-  * CVE-2017-5754
+-    - Revert "UBUNTU: SAUCE: arch/x86/entry/vdso: temporarily disable vdso"
+-    - KPTI: Report when enabled
+-    - x86, vdso, pvclock: Simplify and speed up the vdso pvclock reader
+-    - x86/vdso: Get pvclock data from the vvar VMA instead of the fixmap
+-    - x86/kasan: Clear kasan_zero_page after TLB flush
+-    - kaiser: Set _PAGE_NX only if supported
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Sat, 06 Jan 2018 17:13:03 +0100
+-
+-linux (4.4.0-106.129) xenial; urgency=low
+-
+-  * linux: 4.4.0-106.129 -proposed tracker (LP: #1741528)
+-
+-  * CVE-2017-5754
+-    - KAISER: Kernel Address Isolation
+-    - kaiser: merged update
+-    - kaiser: do not set _PAGE_NX on pgd_none
+-    - kaiser: stack map PAGE_SIZE at THREAD_SIZE-PAGE_SIZE
+-    - kaiser: fix build and FIXME in alloc_ldt_struct()
+-    - kaiser: KAISER depends on SMP
+-    - kaiser: fix regs to do_nmi() ifndef CONFIG_KAISER
+-    - kaiser: fix perf crashes
+-    - kaiser: ENOMEM if kaiser_pagetable_walk() NULL
+-    - kaiser: tidied up asm/kaiser.h somewhat
+-    - kaiser: tidied up kaiser_add/remove_mapping slightly
+-    - kaiser: kaiser_remove_mapping() move along the pgd
+-    - kaiser: cleanups while trying for gold link
+-    - kaiser: name that 0x1000 KAISER_SHADOW_PGD_OFFSET
+-    - kaiser: delete KAISER_REAL_SWITCH option
+-    - kaiser: vmstat show NR_KAISERTABLE as nr_overhead
+-    - x86/mm: Enable CR4.PCIDE on supported systems
+-    - x86/mm: Build arch/x86/mm/tlb.c even on !SMP
+-    - x86/mm, sched/core: Uninline switch_mm()
+-    - x86/mm: Add INVPCID helpers
+-    - x86/mm: If INVPCID is available, use it to flush global mappings
+-    - kaiser: enhanced by kernel and user PCIDs
+-    - kaiser: load_new_mm_cr3() let SWITCH_USER_CR3 flush user
+-    - kaiser: PCID 0 for kernel and 128 for user
+-    - kaiser: x86_cr3_pcid_noflush and x86_cr3_pcid_user
+-    - kaiser: paranoid_entry pass cr3 need to paranoid_exit
+-    - kaiser: _pgd_alloc() without __GFP_REPEAT to avoid stalls
+-    - kaiser: fix unlikely error in alloc_ldt_struct()
+-    - kaiser: add "nokaiser" boot option, using ALTERNATIVE
+-    - x86/kaiser: Rename and simplify X86_FEATURE_KAISER handling
+-    - x86/boot: Add early cmdline parsing for options with arguments
+-    - x86/kaiser: Check boottime cmdline params
+-    - kaiser: use ALTERNATIVE instead of x86_cr3_pcid_noflush
+-    - kaiser: drop is_atomic arg to kaiser_pagetable_walk()
+-    - kaiser: asm/tlbflush.h handle noPGE at lower level
+-    - kaiser: kaiser_flush_tlb_on_return_to_user() check PCID
+-    - x86/paravirt: Dont patch flush_tlb_single
+-    - x86/kaiser: Reenable PARAVIRT
+-    - kaiser: disabled on Xen PV
+-    - x86/kaiser: Move feature detection up
+-    - kvm: x86: fix RSM when PCID is non-zero
+-    - SAUCE: arch/x86/entry/vdso: temporarily disable vdso
+-    - [Config]: CONFIG_KAISER=y
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Fri, 05 Jan 2018 19:53:41 +0100
+-
+-linux (4.4.0-104.127) xenial; urgency=low
+-
+-  * linux: 4.4.0-104.127 -proposed tracker (LP: #1737511)
+-
+-  * upgrading linux-image package to 4.4.0-103.126 breaks Ceph network file
+-    system connection (LP: #1737033)
+-    - Revert "libceph: MOSDOpReply v7 encoding"
+-    - Revert "libceph: advertise support for TUNABLES5"
+-    - Revert "crush: decode and initialize chooseleaf_stable"
+-    - Revert "crush: add chooseleaf_stable tunable"
+-    - Revert "crush: ensure take bucket value is valid"
+-    - Revert "crush: ensure bucket id is valid before indexing buckets array"
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Mon, 11 Dec 2017 12:20:36 +0100
+-
+-linux (4.4.0-103.126) xenial; urgency=low
+-
+-  * linux: 4.4.0-103.126 -proposed tracker (LP: #1736181)
+-
+-  * CVE-2017-1000405
+-    - mm, thp: Do not make page table dirty unconditionally in touch_p[mu]d()
+-
+-  * CVE-2017-16939
+-    - netlink: add a start callback for starting a netlink dump
+-    - ipsec: Fix aborted xfrm policy dump crash
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Mon, 04 Dec 2017 16:50:53 +0100
+-
+-linux (4.4.0-102.125) xenial; urgency=low
+-
+-  * linux: 4.4.0-102.125 -proposed tracker (LP: #1733541)
+-
+-  * tar -x sometimes fails on overlayfs (LP: #1728489)
+-    - ovl: check if all layers are on the same fs
+-    - ovl: persistent inode number for directories
+-
+-  * NVMe timeout is too short (LP: #1729119)
+-    - nvme: update timeout module parameter type
+-
+-  * Set PANIC_TIMEOUT=10 on Power Systems (LP: #1730660)
+-    - [Config]: Set PANIC_TIMEOUT=10 on ppc64el
+-
+-  * Cannot pair BLE remote devices when using combo BT SoC (LP: #1731467)
+-    - Bluetooth: increase timeout for le auto connections
+-
+-  * CIFS errors on 4.4.0-98, but not on 4.4.0-97 with same config (LP: #1729337)
+-    - SMB3: Validate negotiate request must always be signed
+-
+-  * Plantronics P610 does not support sample rate reading (LP: #1719853)
+-    - ALSA: usb-audio: Add sample rate quirk for Plantronics P610
+-
+-  * Invalid btree pointer causes the kernel NULL pointer dereference
+-    (LP: #1729256)
+-    - xfs: reinit btree pointer on attr tree inactivation walk
+-
+-  * Samba mount/umount in docker container triggers kernel Oops (LP: #1729637)
+-    - ipv6: only call ip6_route_dev_notify() once for NETDEV_UNREGISTER
+-    - ipv6: fix NULL dereference in ip6_route_dev_notify()
+-
+-  * [kernel] tty/hvc: Use opal irqchip interface if available (LP: #1728098)
+-    - tty/hvc: Use opal irqchip interface if available
+-
+-  * Device hotplugging with MPT SAS cannot work for VMWare ESXi (LP: #1730852)
+-    - scsi: mptsas: Fixup device hotplug for VMWare ESXi
+-
+-  * NMI watchdog: BUG: soft lockup on Guest upon boot (KVM) (LP: #1727331)
+-    - KVM: PPC: Book3S: Treat VTB as a per-subcore register, not per-thread
+-
+-  * Attempt to map rbd image from ceph jewel/luminous hangs (LP: #1728739)
+-    - crush: ensure bucket id is valid before indexing buckets array
+-    - crush: ensure take bucket value is valid
+-    - crush: add chooseleaf_stable tunable
+-    - crush: decode and initialize chooseleaf_stable
+-    - libceph: advertise support for TUNABLES5
+-    - libceph: MOSDOpReply v7 encoding
+-
+-  * Xenial update to 4.4.98 stable release (LP: #1732698)
+-    - adv7604: Initialize drive strength to default when using DT
+-    - video: fbdev: pmag-ba-fb: Remove bad `__init' annotation
+-    - PCI: mvebu: Handle changes to the bridge windows while enabled
+-    - xen/netback: set default upper limit of tx/rx queues to 8
+-    - drm: drm_minor_register(): Clean up debugfs on failure
+-    - KVM: PPC: Book 3S: XICS: correct the real mode ICP rejecting counter
+-    - iommu/arm-smmu-v3: Clear prior settings when updating STEs
+-    - powerpc/corenet: explicitly disable the SDHC controller on kmcoge4
+-    - ARM: omap2plus_defconfig: Fix probe errors on UARTs 5 and 6
+-    - crypto: vmx - disable preemption to enable vsx in aes_ctr.c
+-    - iio: trigger: free trigger resource correctly
+-    - phy: increase size of MII_BUS_ID_SIZE and bus_id
+-    - serial: sh-sci: Fix register offsets for the IRDA serial port
+-    - usb: hcd: initialize hcd->flags to 0 when rm hcd
+-    - netfilter: nft_meta: deal with PACKET_LOOPBACK in netdev family
+-    - IPsec: do not ignore crypto err in ah4 input
+-    - Input: mpr121 - handle multiple bits change of status register
+-    - Input: mpr121 - set missing event capability
+-    - IB/ipoib: Change list_del to list_del_init in the tx object
+-    - s390/qeth: issue STARTLAN as first IPA command
+-    - (config) Add NET_DSA=n
+-    - net: dsa: select NET_SWITCHDEV
+-    - platform/x86: hp-wmi: Fix detection for dock and tablet mode
+-    - cdc_ncm: Set NTB format again after altsetting switch for Huawei devices
+-    - KEYS: trusted: sanitize all key material
+-    - KEYS: trusted: fix writing past end of buffer in trusted_read()
+-    - platform/x86: hp-wmi: Fix error value for hp_wmi_tablet_state
+-    - platform/x86: hp-wmi: Do not shadow error values
+-    - x86/uaccess, sched/preempt: Verify access_ok() context
+-    - workqueue: Fix NULL pointer dereference
+-    - crypto: x86/sha1-mb - fix panic due to unaligned access
+-    - KEYS: fix NULL pointer dereference during ASN.1 parsing [ver #2]
+-    - ARM: 8720/1: ensure dump_instr() checks addr_limit
+-    - ALSA: seq: Fix OSS sysex delivery in OSS emulation
+-    - ALSA: seq: Avoid invalid lockdep class warning
+-    - MIPS: microMIPS: Fix incorrect mask in insn_table_MM
+-    - MIPS: Fix CM region target definitions
+-    - MIPS: SMP: Use a completion event to signal CPU up
+-    - MIPS: Fix race on setting and getting cpu_online_mask
+-    - MIPS: SMP: Fix deadlock & online race
+-    - test: firmware_class: report errors properly on failure
+-    - selftests: firmware: add empty string and async tests
+-    - selftests: firmware: send expected errors to /dev/null
+-    - tools: firmware: check for distro fallback udev cancel rule
+-    - MIPS: AR7: Defer registration of GPIO
+-    - MIPS: AR7: Ensure that serial ports are properly set up
+-    - Input: elan_i2c - add ELAN060C to the ACPI table
+-    - drm/vmwgfx: Fix Ubuntu 17.10 Wayland black screen issue
+-    - rbd: use GFP_NOIO for parent stat and data requests
+-    - can: sun4i: handle overrun in RX FIFO
+-    - can: c_can: don't indicate triple sampling support for D_CAN
+-    - x86/oprofile/ppro: Do not use __this_cpu*() in preemptible context
+-    - PKCS#7: fix unitialized boolean 'want'
+-    - Linux 4.4.98
+-
+-  * ELANTECH Touchpad is not detected in 'Lenovo Ideapad 320 14AST' after fresh
+-    install (LP: #1727544)
+-    - Input: elan_i2c - add ELAN060C to the ACPI table
+-
+-  * Xenial update to 4.4.97 stable release (LP: #1731915)
+-    - ALSA: timer: Add missing mutex lock for compat ioctls
+-    - ALSA: seq: Fix nested rwsem annotation for lockdep splat
+-    - cifs: check MaxPathNameComponentLength != 0 before using it
+-    - KEYS: return full count in keyring_read() if buffer is too small
+-    - KEYS: fix out-of-bounds read during ASN.1 parsing
+-    - ASoC: adau17x1: Workaround for noise bug in ADC
+-    - arm64: ensure __dump_instr() checks addr_limit
+-    - ARM: dts: mvebu: pl310-cache disable double-linefill
+-    - ARM: 8715/1: add a private asm/unaligned.h
+-    - ocfs2: fstrim: Fix start offset of first cluster group during fstrim
+-    - perf tools: Fix build failure on perl script context
+-    - drm/msm: Fix potential buffer overflow issue
+-    - drm/msm: fix an integer overflow test
+-    - tracing/samples: Fix creation and deletion of simple_thread_fn creation
+-    - Fix tracing sample code warning.
+-    - PM / wakeirq: report a wakeup_event on dedicated wekup irq
+-    - mmc: s3cmci: include linux/interrupt.h for tasklet_struct
+-    - ARM: pxa: Don't rely on public mmc header to include leds.h
+-    - mfd: ab8500-sysctrl: Handle probe deferral
+-    - mfd: axp20x: Fix axp288 PEK_DBR and PEK_DBF irqs being swapped
+-    - staging: rtl8712u: Fix endian settings for structs describing network
+-      packets
+-    - ext4: fix stripe-unaligned allocations
+-    - ext4: do not use stripe_width if it is not set
+-    - i2c: riic: correctly finish transfers
+-    - drm/amdgpu: when dpm disabled, also need to stop/start vce.
+-    - perf tools: Only increase index if perf_evsel__new_idx() succeeds
+-    - cx231xx: Fix I2C on Internal Master 3 Bus
+-    - xen/manage: correct return value check on xenbus_scanf()
+-    - scsi: aacraid: Process Error for response I/O
+-    - platform/x86: intel_mid_thermal: Fix module autoload
+-    - staging: lustre: llite: don't invoke direct_IO for the EOF case
+-    - staging: lustre: hsm: stack overrun in hai_dump_data_field
+-    - staging: lustre: ptlrpc: skip lock if export failed
+-    - exynos4-is: fimc-is: Unmap region obtained by of_iomap()
+-    - mei: return error on notification request to a disconnected client
+-    - s390/dasd: check for device error pointer within state change interrupts
+-    - bt8xx: fix memory leak
+-    - xen: don't print error message in case of missing Xenstore entry
+-    - staging: r8712u: Fix Sparse warning in rtl871x_xmit.c
+-    - Linux 4.4.97
+-
+-  * Xenial update to 4.4.96 stable release (LP: #1731882)
+-    - workqueue: replace pool->manager_arb mutex with a flag
+-    - ALSA: hda/realtek - Add support for ALC236/ALC3204
+-    - ALSA: hda - fix headset mic problem for Dell machines with alc236
+-    - ceph: unlock dangling spinlock in try_flush_caps()
+-    - usb: xhci: Handle error condition in xhci_stop_device()
+-    - spi: uapi: spidev: add missing ioctl header
+-    - fuse: fix READDIRPLUS skipping an entry
+-    - xen/gntdev: avoid out of bounds access in case of partial gntdev_mmap()
+-    - Input: elan_i2c - add ELAN0611 to the ACPI table
+-    - Input: gtco - fix potential out-of-bound access
+-    - assoc_array: Fix a buggy node-splitting case
+-    - scsi: zfcp: fix erp_action use-before-initialize in REC action trace
+-    - scsi: sg: Re-fix off by one in sg_fill_request_table()
+-    - can: sun4i: fix loopback mode
+-    - can: kvaser_usb: Correct return value in printout
+-    - can: kvaser_usb: Ignore CMD_FLUSH_QUEUE_REPLY messages
+-    - regulator: fan53555: fix I2C device ids
+-    - x86/microcode/intel: Disable late loading on model 79
+-    - ecryptfs: fix dereference of NULL user_key_payload
+-    - Revert "drm: bridge: add DT bindings for TI ths8135"
+-    - Linux 4.4.96
+-
+-  * Touchpad not detected - Lenovo ideapad 320-15IKB (LP: #1723736)
+-    - Input: elan_i2c - add ELAN0611 to the ACPI table
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Tue, 21 Nov 2017 15:37:52 +0100
+-
+-linux (4.4.0-101.124) xenial; urgency=low
+-
+-  * linux: 4.4.0-101.124 -proposed tracker (LP: #1731264)
+-
+-  * s390/mm: fix write access check in gup_huge_pmd() (LP: #1730596)
+-    - s390/mm: fix write access check in gup_huge_pmd()
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Fri, 10 Nov 2017 08:24:10 -0200
+-
+-linux (4.4.0-100.123) xenial; urgency=low
+-
+-  * linux: 4.4.0-100.123 -proposed tracker (LP: #1729273)
+-
+-  * Xenial update to 4.4.95 stable release (LP: #1729107)
+-    - USB: devio: Revert "USB: devio: Don't corrupt user memory"
+-    - USB: core: fix out-of-bounds access bug in usb_get_bos_descriptor()
+-    - USB: serial: metro-usb: add MS7820 device id
+-    - usb: cdc_acm: Add quirk for Elatec TWN3
+-    - usb: quirks: add quirk for WORLDE MINI MIDI keyboard
+-    - usb: hub: Allow reset retry for USB2 devices on connect bounce
+-    - ALSA: usb-audio: Add native DSD support for Pro-Ject Pre Box S2 Digital
+-    - can: gs_usb: fix busy loop if no more TX context is available
+-    - usb: musb: sunxi: Explicitly release USB PHY on exit
+-    - usb: musb: Check for host-mode using is_host_active() on reset interrupt
+-    - can: esd_usb2: Fix can_dlc value for received RTR, frames
+-    - drm/nouveau/bsp/g92: disable by default
+-    - drm/nouveau/mmu: flush tlbs before deleting page tables
+-    - ALSA: seq: Enable 'use' locking in all configurations
+-    - ALSA: hda: Remove superfluous '-' added by printk conversion
+-    - i2c: ismt: Separate I2C block read from SMBus block read
+-    - brcmsmac: make some local variables 'static const' to reduce stack size
+-    - bus: mbus: fix window size calculation for 4GB windows
+-    - clockevents/drivers/cs5535: Improve resilience to spurious interrupts
+-    - rtlwifi: rtl8821ae: Fix connection lost problem
+-    - KEYS: encrypted: fix dereference of NULL user_key_payload
+-    - lib/digsig: fix dereference of NULL user_key_payload
+-    - KEYS: don't let add_key() update an uninstantiated key
+-    - pkcs7: Prevent NULL pointer dereference, since sinfo is not always set.
+-    - parisc: Avoid trashing sr2 and sr3 in LWS code
+-    - parisc: Fix double-word compare and exchange in LWS code on 32-bit kernels
+-    - sched/autogroup: Fix autogroup_move_group() to never skip sched_move_task()
+-    - f2fs crypto: replace some BUG_ON()'s with error checks
+-    - f2fs crypto: add missing locking for keyring_key access
+-    - fscrypt: fix dereference of NULL user_key_payload
+-    - KEYS: Fix race between updating and finding a negative key
+-    - fscrypto: require write access to mount to set encryption policy
+-    - FS-Cache: fix dereference of NULL user_key_payload
+-    - Linux 4.4.95
+-
+-  * Xenial update to 4.4.94 stable release (LP: #1729105)
+-    - percpu: make this_cpu_generic_read() atomic w.r.t. interrupts
+-    - drm/dp/mst: save vcpi with payloads
+-    - MIPS: Fix minimum alignment requirement of IRQ stack
+-    - sctp: potential read out of bounds in sctp_ulpevent_type_enabled()
+-    - bpf/verifier: reject BPF_ALU64|BPF_END
+-    - udpv6: Fix the checksum computation when HW checksum does not apply
+-    - ip6_gre: skb_push ipv6hdr before packing the header in ip6gre_header
+-    - net: emac: Fix napi poll list corruption
+-    - packet: hold bind lock when rebinding to fanout hook
+-    - bpf: one perf event close won't free bpf program attached by another perf
+-      event
+-    - isdn/i4l: fetch the ppp_write buffer in one shot
+-    - vti: fix use after free in vti_tunnel_xmit/vti6_tnl_xmit
+-    - l2tp: Avoid schedule while atomic in exit_net
+-    - l2tp: fix race condition in l2tp_tunnel_delete
+-    - tun: bail out from tun_get_user() if the skb is empty
+-    - packet: in packet_do_bind, test fanout with bind_lock held
+-    - packet: only test po->has_vnet_hdr once in packet_snd
+-    - net: Set sk_prot_creator when cloning sockets to the right proto
+-    - tipc: use only positive error codes in messages
+-    - Revert "bsg-lib: don't free job in bsg_prepare_job"
+-    - locking/lockdep: Add nest_lock integrity test
+-    - watchdog: kempld: fix gcc-4.3 build
+-    - irqchip/crossbar: Fix incorrect type of local variables
+-    - mac80211_hwsim: check HWSIM_ATTR_RADIO_NAME length
+-    - mac80211: fix power saving clients handling in iwlwifi
+-    - net/mlx4_en: fix overflow in mlx4_en_init_timestamp()
+-    - netfilter: nf_ct_expect: Change __nf_ct_expect_check() return value.
+-    - iio: adc: xilinx: Fix error handling
+-    - Btrfs: send, fix failure to rename top level inode due to name collision
+-    - f2fs: do not wait for writeback in write_begin
+-    - md/linear: shutup lockdep warnning
+-    - sparc64: Migrate hvcons irq to panicked cpu
+-    - net/mlx4_core: Fix VF overwrite of module param which disables DMFS on new
+-      probed PFs
+-    - crypto: xts - Add ECB dependency
+-    - ocfs2/dlmglue: prepare tracking logic to avoid recursive cluster lock
+-    - slub: do not merge cache if slub_debug contains a never-merge flag
+-    - scsi: scsi_dh_emc: return success in clariion_std_inquiry()
+-    - net: mvpp2: release reference to txq_cpu[] entry after unmapping
+-    - i2c: at91: ensure state is restored after suspending
+-    - ceph: clean up unsafe d_parent accesses in build_dentry_path
+-    - uapi: fix linux/rds.h userspace compilation errors
+-    - uapi: fix linux/mroute6.h userspace compilation errors
+-    - target/iscsi: Fix unsolicited data seq_end_offset calculation
+-    - nfsd/callback: Cleanup callback cred on shutdown
+-    - cpufreq: CPPC: add ACPI_PROCESSOR dependency
+-    - Revert "tty: goldfish: Fix a parameter of a call to free_irq"
+-    - Linux 4.4.94
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 01 Nov 2017 16:54:28 -0200
+-
+-linux (4.4.0-99.122) xenial; urgency=low
+-
+-  * linux: 4.4.0-99.122 -proposed tracker (LP: #1728945)
+-
+-  * Remove vmbus-rdma driver from Xenial kernel (LP: #1721538)
+-    - SAUCE: remove hv_network_direct driver
+-    - [Config]: Remove hv_network_direct driver
+-
+-  * usb 3-1: 2:1: cannot get freq at ep 0x1 (LP: #1708499)
+-    - ALSA: usb-audio: Add sample rate quirk for Plantronics C310/C520-M
+-
+-  * Plantronics Blackwire C520-M - Cannot get freq at ep 0x1, 0x81
+-    (LP: #1709282)
+-    - ALSA: usb-audio: Add sample rate quirk for Plantronics C310/C520-M
+-
+-  * wait-for-root fails to detect nbd root (LP: #696435)
+-    - nbd: Create size change events for userspace
+-
+-  * Fix OpenNSL GPL bugs found by CoverityScan static analysis (LP: #1718388)
+-    - SAUCE: opennsl: bcm-knet: check for null sinfo to avoid a null pointer
+-      dereference
+-    - SAUCE: opennsl: bcm-knet: remove redundant null checks on dev->name
+-    - SAUCE: opennsl: bde: check for out-of-bounds index io.dev
+-
+-  * HID: multitouch: Correct ALPS PTP Stick and Touchpad devices ID
+-    (LP: #1722719)
+-    - Revert "HID: multitouch: Support ALPS PTP stick with pid 0x120A"
+-
+-  * Xenial update to 4.4.93 stable release (LP: #1724836)
+-    - brcmfmac: add length check in brcmf_cfg80211_escan_handler()
+-    - ext4: in ext4_seek_{hole,data}, return -ENXIO for negative offsets
+-    - CIFS: Reconnect expired SMB sessions
+-    - nl80211: Define policy for packet pattern attributes
+-    - iwlwifi: mvm: use IWL_HCMD_NOCOPY for MCAST_FILTER_CMD
+-    - rcu: Allow for page faults in NMI handlers
+-    - USB: dummy-hcd: Fix deadlock caused by disconnect detection
+-    - MIPS: math-emu: Remove pr_err() calls from fpu_emu()
+-    - dmaengine: edma: Align the memcpy acnt array size with the transfer
+-    - HID: usbhid: fix out-of-bounds bug
+-    - crypto: shash - Fix zero-length shash ahash digest crash
+-    - KVM: nVMX: fix guest CR4 loading when emulating L2 to L1 exit
+-    - usb: renesas_usbhs: Fix DMAC sequence for receiving zero-length packet
+-    - iommu/amd: Finish TLB flush in amd_iommu_unmap()
+-    - ALSA: usb-audio: Kill stray URB at exiting
+-    - ALSA: seq: Fix use-after-free at creating a port
+-    - ALSA: seq: Fix copy_from_user() call inside lock
+-    - ALSA: caiaq: Fix stray URB at probe error path
+-    - ALSA: line6: Fix leftover URB at error-path during probe
+-    - usb: gadget: composite: Fix use-after-free in
+-      usb_composite_overwrite_options
+-    - direct-io: Prevent NULL pointer access in submit_page_section
+-    - fix unbalanced page refcounting in bio_map_user_iov
+-    - USB: serial: ftdi_sio: add id for Cypress WICED dev board
+-    - USB: serial: cp210x: add support for ELV TFD500
+-    - USB: serial: option: add support for TP-Link LTE module
+-    - Revert "UBUNTU: SAUCE: USB: serial: qcserial: add Dell DW5818, DW5819"
+-    - USB: serial: qcserial: add Dell DW5818, DW5819
+-    - USB: serial: console: fix use-after-free after failed setup
+-    - x86/alternatives: Fix alt_max_short macro to really be a max()
+-    - Linux 4.4.93
+-
+-  * NULL pointer dereference in tty_write() in kernel 4.4.0-93.116+
+-    (LP: #1721065)
+-    - tty: Prepare for destroying line discipline on hangup
+-
+-  * Xenial update to 4.4.92 stable release (LP: #1724783)
+-    - usb: gadget: inode.c: fix unbalanced spin_lock in ep0_write
+-    - USB: gadgetfs: Fix crash caused by inadequate synchronization
+-    - USB: gadgetfs: fix copy_to_user while holding spinlock
+-    - usb: gadget: udc: atmel: set vbus irqflags explicitly
+-    - usb-storage: unusual_devs entry to fix write-access regression for Seagate
+-      external drives
+-    - usb: renesas_usbhs: fix the BCLR setting condition for non-DCP pipe
+-    - usb: renesas_usbhs: fix usbhsf_fifo_clear() for RX direction
+-    - ALSA: usb-audio: Check out-of-bounds access by corrupted buffer descriptor
+-    - usb: pci-quirks.c: Corrected timeout values used in handshake
+-    - USB: dummy-hcd: fix connection failures (wrong speed)
+-    - USB: dummy-hcd: fix infinite-loop resubmission bug
+-    - USB: dummy-hcd: Fix erroneous synchronization change
+-    - USB: devio: Don't corrupt user memory
+-    - usb: gadget: mass_storage: set msg_registered after msg registered
+-    - USB: g_mass_storage: Fix deadlock when driver is unbound
+-    - lsm: fix smack_inode_removexattr and xattr_getsecurity memleak
+-    - ALSA: compress: Remove unused variable
+-    - ALSA: usx2y: Suppress kernel warning at page allocation failures
+-    - driver core: platform: Don't read past the end of "driver_override" buffer
+-    - Drivers: hv: fcopy: restore correct transfer length
+-    - stm class: Fix a use-after-free
+-    - ftrace: Fix kmemleak in unregister_ftrace_graph
+-    - HID: i2c-hid: allocate hid buffers for real worst case
+-    - iwlwifi: add workaround to disable wide channels in 5GHz
+-    - scsi: sd: Do not override max_sectors_kb sysfs setting
+-    - USB: uas: fix bug in handling of alternate settings
+-    - USB: core: harden cdc_parse_cdc_header
+-    - usb: Increase quirk delay for USB devices
+-    - USB: fix out-of-bounds in usb_set_configuration
+-    - xhci: fix finding correct bus_state structure for USB 3.1 hosts
+-    - iio: adc: twl4030: Fix an error handling path in 'twl4030_madc_probe()'
+-    - iio: adc: twl4030: Disable the vusb3v1 rugulator in the error handling path
+-      of 'twl4030_madc_probe()'
+-    - iio: ad_sigma_delta: Implement a dedicated reset function
+-    - staging: iio: ad7192: Fix - use the dedicated reset function avoiding dma
+-      from stack.
+-    - iio: core: Return error for failed read_reg
+-    - iio: ad7793: Fix the serial interface reset
+-    - iio: adc: mcp320x: Fix readout of negative voltages
+-    - iio: adc: mcp320x: Fix oops on module unload
+-    - uwb: properly check kthread_run return value
+-    - uwb: ensure that endpoint is interrupt
+-    - brcmfmac: setup passive scan if requested by user-space
+-    - drm/i915/bios: ignore HDMI on port A
+-    - sched/cpuset/pm: Fix cpuset vs. suspend-resume bugs
+-    - ext4: fix data corruption for mmap writes
+-    - ext4: Don't clear SGID when inheriting ACLs
+-    - ext4: don't allow encrypted operations without keys
+-    - Linux 4.4.92
+-
+-  * Xenial update to 4.4.91 stable release (LP: #1724772)
+-    - drm_fourcc: Fix DRM_FORMAT_MOD_LINEAR #define
+-    - drm: bridge: add DT bindings for TI ths8135
+-    - GFS2: Fix reference to ERR_PTR in gfs2_glock_iter_next
+-    - RDS: RDMA: Fix the composite message user notification
+-    - ARM: dts: r8a7790: Use R-Car Gen 2 fallback binding for msiof nodes
+-    - MIPS: Ensure bss section ends on a long-aligned address
+-    - MIPS: ralink: Fix incorrect assignment on ralink_soc
+-    - igb: re-assign hw address pointer on reset after PCI error
+-    - extcon: axp288: Use vbus-valid instead of -present to determine cable
+-      presence
+-    - sh_eth: use correct name for ECMR_MPDE bit
+-    - hwmon: (gl520sm) Fix overflows and crash seen when writing into limit
+-      attributes
+-    - iio: adc: axp288: Drop bogus AXP288_ADC_TS_PIN_CTRL register modifications
+-    - iio: adc: hx711: Add DT binding for avia,hx711
+-    - ARM: 8635/1: nommu: allow enabling REMAP_VECTORS_TO_RAM
+-    - tty: goldfish: Fix a parameter of a call to free_irq
+-    - IB/ipoib: Fix deadlock over vlan_mutex
+-    - IB/ipoib: rtnl_unlock can not come after free_netdev
+-    - IB/ipoib: Replace list_del of the neigh->list with list_del_init
+-    - drm/amdkfd: fix improper return value on error
+-    - USB: serial: mos7720: fix control-message error handling
+-    - USB: serial: mos7840: fix control-message error handling
+-    - partitions/efi: Fix integer overflow in GPT size calculation
+-    - ASoC: dapm: handle probe deferrals
+-    - audit: log 32-bit socketcalls
+-    - usb: chipidea: vbus event may exist before starting gadget
+-    - ASoC: dapm: fix some pointer error handling
+-    - MIPS: Lantiq: Fix another request_mem_region() return code check
+-    - net: core: Prevent from dereferencing null pointer when releasing SKB
+-    - net/packet: check length in getsockopt() called with PACKET_HDRLEN
+-    - team: fix memory leaks
+-    - usb: plusb: Add support for PL-27A1
+-    - mmc: sdio: fix alignment issue in struct sdio_func
+-    - bridge: netlink: register netdevice before executing changelink
+-    - netfilter: invoke synchronize_rcu after set the _hook_ to NULL
+-    - MIPS: IRQ Stack: Unwind IRQ stack onto task stack
+-    - exynos-gsc: Do not swap cb/cr for semi planar formats
+-    - netfilter: nfnl_cthelper: fix incorrect helper->expect_class_max
+-    - parisc: perf: Fix potential NULL pointer dereference
+-    - iommu/io-pgtable-arm: Check for leaf entry before dereferencing it
+-    - rds: ib: add error handle
+-    - md/raid10: submit bio directly to replacement disk
+-    - i2c: meson: fix wrong variable usage in meson_i2c_put_data
+-    - xfs: remove kmem_zalloc_greedy
+-    - libata: transport: Remove circular dependency at free time
+-    - drivers: firmware: psci: drop duplicate const from psci_of_match
+-    - IB/qib: fix false-postive maybe-uninitialized warning
+-    - ARM: remove duplicate 'const' annotations'
+-    - ALSA: au88x0: avoid theoretical uninitialized access
+-    - ttpci: address stringop overflow warning
+-    - Linux 4.4.91
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Tue, 31 Oct 2017 11:49:30 -0200
+-
+-linux (4.4.0-98.121) xenial; urgency=low
+-
+-  * linux: 4.4.0-98.121 -proposed tracker (LP: #1722299)
+-
+-  * Controller lockup detected on ProLiant DL380 Gen9 with P440 Controller
+-    (LP: #1720359)
+-    - scsi: hpsa: limit transfer length to 1MB
+-
+-  * [Dell Docking IE][0bda:8153] Realtek USB Ethernet leads to system hang
+-    (LP: #1720977)
+-    - r8152: fix the list rx_done may be used without initialization
+-
+-  * Add installer support for Broadcom BCM573xx network drivers. (LP: #1720466)
+-    - d-i: Add bnxt_en to nic-modules.
+-
+-  * snapcraft.yaml: add dpkg-dev to the build deps (LP: #1718886)
+-    - snapcraft.yaml: add dpkg-dev to the build deps
+-
+-  * Support setting I2C_TIMEOUT via ioctl for i2c-designware (LP: #1718578)
+-    - i2c: designware: Use transfer timeout from ioctl I2C_TIMEOUT
+-
+-  * 5U84 - ses driver isn't binding right - cannot blink lights on 1 of the 2
+-    5u84 (LP: #1693369)
+-    - scsi_transport_sas: add function to get SAS endpoint address
+-    - ses: fix discovery of SATA devices in SAS enclosures
+-    - scsi: sas: provide stub implementation for scsi_is_sas_rphy
+-    - scsi: ses: Fix SAS device detection in enclosure
+-
+-  * multipath -ll is not showing the disks which are actually multipath
+-    (LP: #1718397)
+-    - fs: aio: fix the increment of aio-nr and counting against aio-max-nr
+-
+-  * Support Dell Wireless DW5819/5818 WWAN devices (LP: #1721455)
+-    - SAUCE: USB: serial: qcserial: add Dell DW5818, DW5819
+-
+-  * CVE-2017-10911
+-    - xen-blkback: don't leak stack data via response ring
+-
+-  * implement 'complain mode' in seccomp for developer mode with snaps
+-    (LP: #1567597)
+-    - seccomp: Provide matching filter for introspection
+-    - seccomp: Sysctl to display available actions
+-    - seccomp: Operation for checking if an action is available
+-    - seccomp: Sysctl to configure actions that are allowed to be logged
+-    - seccomp: Selftest for detection of filter flag support
+-    - seccomp: Action to log before allowing
+-
+-  * implement errno action logging in seccomp for strict mode with snaps
+-    (LP: #1721676)
+-    - seccomp: Provide matching filter for introspection
+-    - seccomp: Sysctl to display available actions
+-    - seccomp: Operation for checking if an action is available
+-    - seccomp: Sysctl to configure actions that are allowed to be logged
+-    - seccomp: Selftest for detection of filter flag support
+-    - seccomp: Filter flag to log all actions except SECCOMP_RET_ALLOW
+-
+-  * [Xenial] update OpenNSL kernel modules to 6.5.10 (LP: #1721511)
+-    - SAUCE: update OpenNSL kernel modules to 6.5.10
+-
+-  * Xenial update to 4.4.90 stable release (LP: #1721550)
+-    - cifs: release auth_key.response for reconnect.
+-    - mac80211: flush hw_roc_start work before cancelling the ROC
+-    - KVM: PPC: Book3S: Fix race and leak in kvm_vm_ioctl_create_spapr_tce()
+-    - tracing: Fix trace_pipe behavior for instance traces
+-    - tracing: Erase irqsoff trace with empty write
+-    - md/raid5: fix a race condition in stripe batch
+-    - md/raid5: preserve STRIPE_ON_UNPLUG_LIST in break_stripe_batch_list
+-    - scsi: scsi_transport_iscsi: fix the issue that iscsi_if_rx doesn't parse
+-      nlmsg properly
+-    - crypto: talitos - Don't provide setkey for non hmac hashing algs.
+-    - crypto: talitos - fix sha224
+-    - KEYS: fix writing past end of user-supplied buffer in keyring_read()
+-    - KEYS: prevent creating a different user's keyrings
+-    - KEYS: prevent KEYCTL_READ on negative key
+-    - powerpc/pseries: Fix parent_dn reference leak in add_dt_node()
+-    - Fix SMB3.1.1 guest authentication to Samba
+-    - SMB: Validate negotiate (to protect against downgrade) even if signing off
+-    - SMB3: Don't ignore O_SYNC/O_DSYNC and O_DIRECT flags
+-    - vfs: Return -ENXIO for negative SEEK_HOLE / SEEK_DATA offsets
+-    - nl80211: check for the required netlink attributes presence
+-    - bsg-lib: don't free job in bsg_prepare_job
+-    - seccomp: fix the usage of get/put_seccomp_filter() in seccomp_get_filter()
+-    - arm64: Make sure SPsel is always set
+-    - arm64: fault: Route pte translation faults via do_translation_fault
+-    - KVM: VMX: Do not BUG() on out-of-bounds guest IRQ
+-    - kvm: nVMX: Don't allow L2 to access the hardware CR8
+-    - PCI: Fix race condition with driver_override
+-    - btrfs: fix NULL pointer dereference from free_reloc_roots()
+-    - btrfs: propagate error to btrfs_cmp_data_prepare caller
+-    - btrfs: prevent to set invalid default subvolid
+-    - x86/fpu: Don't let userspace set bogus xcomp_bv
+-    - gfs2: Fix debugfs glocks dump
+-    - timer/sysclt: Restrict timer migration sysctl values to 0 and 1
+-    - KVM: VMX: do not change SN bit in vmx_update_pi_irte()
+-    - KVM: VMX: remove WARN_ON_ONCE in kvm_vcpu_trigger_posted_interrupt
+-    - cxl: Fix driver use count
+-    - dmaengine: mmp-pdma: add number of requestors
+-    - ARM: pxa: add the number of DMA requestor lines
+-    - ARM: pxa: fix the number of DMA requestor lines
+-    - KVM: VMX: use cmpxchg64
+-    - video: fbdev: aty: do not leak uninitialized padding in clk to userspace
+-    - swiotlb-xen: implement xen_swiotlb_dma_mmap callback
+-    - fix xen_swiotlb_dma_mmap prototype
+-    - Linux 4.4.90
+-
+-  * Xenial update to 4.4.89 stable release (LP: #1721477)
+-    - ipv6: accept 64k - 1 packet length in ip6_find_1stfragopt()
+-    - ipv6: add rcu grace period before freeing fib6_node
+-    - ipv6: fix sparse warning on rt6i_node
+-    - qlge: avoid memcpy buffer overflow
+-    - Revert "net: phy: Correctly process PHY_HALTED in phy_stop_machine()"
+-    - Revert "net: use lib/percpu_counter API for fragmentation mem accounting"
+-    - Revert "net: fix percpu memory leaks"
+-    - gianfar: Fix Tx flow control deactivation
+-    - ipv6: fix memory leak with multiple tables during netns destruction
+-    - ipv6: fix typo in fib6_net_exit()
+-    - f2fs: check hot_data for roll-forward recovery
+-    - x86/fsgsbase/64: Report FSBASE and GSBASE correctly in core dumps
+-    - md/raid5: release/flush io in raid5_do_work()
+-    - nfsd: Fix general protection fault in release_lock_stateid()
+-    - mm: prevent double decrease of nr_reserved_highatomic
+-    - tty: improve tty_insert_flip_char() fast path
+-    - tty: improve tty_insert_flip_char() slow path
+-    - tty: fix __tty_insert_flip_char regression
+-    - Input: i8042 - add Gigabyte P57 to the keyboard reset table
+-    - MIPS: math-emu: <MAX|MAXA|MIN|MINA>.<D|S>: Fix quiet NaN propagation
+-    - MIPS: math-emu: <MAX|MAXA|MIN|MINA>.<D|S>: Fix cases of both inputs zero
+-    - MIPS: math-emu: <MAX|MIN>.<D|S>: Fix cases of both inputs negative
+-    - MIPS: math-emu: <MAXA|MINA>.<D|S>: Fix cases of input values with opposite
+-      signs
+-    - MIPS: math-emu: <MAXA|MINA>.<D|S>: Fix cases of both infinite inputs
+-    - MIPS: math-emu: MINA.<D|S>: Fix some cases of infinity and zero inputs
+-    - crypto: AF_ALG - remove SGL terminator indicator when chaining
+-    - ext4: fix incorrect quotaoff if the quota feature is enabled
+-    - ext4: fix quota inconsistency during orphan cleanup for read-only mounts
+-    - powerpc: Fix DAR reporting when alignment handler faults
+-    - block: Relax a check in blk_start_queue()
+-    - md/bitmap: disable bitmap_resize for file-backed bitmaps.
+-    - skd: Avoid that module unloading triggers a use-after-free
+-    - skd: Submit requests to firmware before triggering the doorbell
+-    - scsi: zfcp: fix queuecommand for scsi_eh commands when DIX enabled
+-    - scsi: zfcp: add handling for FCP_RESID_OVER to the fcp ingress path
+-    - scsi: zfcp: fix capping of unsuccessful GPN_FT SAN response trace records
+-    - scsi: zfcp: fix passing fsf_req to SCSI trace on TMF to correlate with HBA
+-    - scsi: zfcp: fix missing trace records for early returns in TMF eh handlers
+-    - scsi: zfcp: fix payload with full FCP_RSP IU in SCSI trace records
+-    - scsi: zfcp: trace HBA FSF response by default on dismiss or timedout late
+-      response
+-    - scsi: zfcp: trace high part of "new" 64 bit SCSI LUN
+-    - scsi: megaraid_sas: Check valid aen class range to avoid kernel panic
+-    - scsi: megaraid_sas: Return pended IOCTLs with cmd_status
+-      MFI_STAT_WRONG_STATE in case adapter is dead
+-    - scsi: storvsc: fix memory leak on ring buffer busy
+-    - scsi: sg: remove 'save_scat_len'
+-    - scsi: sg: use standard lists for sg_requests
+-    - scsi: sg: off by one in sg_ioctl()
+-    - scsi: sg: factor out sg_fill_request_table()
+-    - scsi: sg: fixup infoleak when using SG_GET_REQUEST_TABLE
+-    - scsi: qla2xxx: Fix an integer overflow in sysfs code
+-    - ftrace: Fix selftest goto location on error
+-    - tracing: Apply trace_clock changes to instance max buffer
+-    - ARC: Re-enable MMU upon Machine Check exception
+-    - PCI: shpchp: Enable bridge bus mastering if MSI is enabled
+-    - media: v4l2-compat-ioctl32: Fix timespec conversion
+-    - media: uvcvideo: Prevent heap overflow when accessing mapped controls
+-    - bcache: initialize dirty stripes in flash_dev_run()
+-    - bcache: Fix leak of bdev reference
+-    - bcache: do not subtract sectors_to_gc for bypassed IO
+-    - bcache: correct cache_dirty_target in __update_writeback_rate()
+-    - bcache: Correct return value for sysfs attach errors
+-    - bcache: fix for gc and write-back race
+-    - bcache: fix bch_hprint crash and improve output
+-    - ftrace: Fix memleak when unregistering dynamic ops when tracing disabled
+-    - Linux 4.4.89
+-
+-  * ETPS/2 Elantech Touchpad inconsistently detected (Gigabyte P57W laptop)
+-    (LP: #1594214)
+-    - Input: i8042 - add Gigabyte P57 to the keyboard reset table
+-
+-  * Xenial update to 4.4.88 stable release (LP: #1718195)
+-    - usb: quirks: add delay init quirk for Corsair Strafe RGB keyboard
+-    - USB: serial: option: add support for D-Link DWM-157 C1
+-    - usb: Add device quirk for Logitech HD Pro Webcam C920-C
+-    - usb:xhci:Fix regression when ATI chipsets detected
+-    - USB: core: Avoid race of async_completed() w/ usbdev_release()
+-    - staging/rts5208: fix incorrect shift to extract upper nybble
+-    - driver core: bus: Fix a potential double free
+-    - intel_th: pci: Add Cannon Lake PCH-H support
+-    - intel_th: pci: Add Cannon Lake PCH-LP support
+-    - ath10k: fix memory leak in rx ring buffer allocation
+-    - rtlwifi: rtl_pci_probe: Fix fail path of _rtl_pci_find_adapter
+-    - Bluetooth: Add support of 13d3:3494 RTL8723BE device
+-    - dlm: avoid double-free on error path in dlm_device_{register,unregister}
+-    - mwifiex: correct channel stat buffer overflows
+-    - drm/nouveau/pci/msi: disable MSI on big-endian platforms by default
+-    - workqueue: Fix flag collision
+-    - cs5536: add support for IDE controller variant
+-    - scsi: sg: protect against races between mmap() and SG_SET_RESERVED_SIZE
+-    - scsi: sg: recheck MMAP_IO request length with lock held
+-    - drm: adv7511: really enable interrupts for EDID detection
+-    - drm/bridge: adv7511: Fix mutex deadlock when interrupts are disabled
+-    - drm/bridge: adv7511: Use work_struct to defer hotplug handing to out of irq
+-      context
+-    - drm/bridge: adv7511: Switch to using drm_kms_helper_hotplug_event()
+-    - drm/bridge: adv7511: Re-write the i2c address before EDID probing
+-    - btrfs: resume qgroup rescan on rw remount
+-    - locktorture: Fix potential memory leak with rw lock test
+-    - ALSA: msnd: Optimize / harden DSP and MIDI loops
+-    - ARM: 8692/1: mm: abort uaccess retries upon fatal signal
+-    - NFS: Fix 2 use after free issues in the I/O code
+-    - xfs: XFS_IS_REALTIME_INODE() should be false if no rt device present
+-    - Linux 4.4.88
+-
+-  * Kernel has troule recognizing Corsair Strafe RGB keyboard (LP: #1678477)
+-    - usb: quirks: add delay init quirk for Corsair Strafe RGB keyboard
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Tue, 10 Oct 2017 08:52:24 -0300
+-
+-linux (4.4.0-97.120) xenial; urgency=low
+-
+-  * linux: 4.4.0-97.120 -proposed tracker (LP: #1718149)
+-
+-  * blk-mq: possible deadlock on CPU hot(un)plug (LP: #1670634)
+-    - [Config] s390x -- disable CONFIG_{DM, SCSI}_MQ_DEFAULT
+-
+-  * Xenial update to 4.4.87 stable release (LP: #1715678)
+-    - irqchip: mips-gic: SYNC after enabling GIC region
+-    - i2c: ismt: Don't duplicate the receive length for block reads
+-    - i2c: ismt: Return EMSGSIZE for block reads with bogus length
+-    - ceph: fix readpage from fscache
+-    - cpumask: fix spurious cpumask_of_node() on non-NUMA multi-node configs
+-    - cpuset: Fix incorrect memory_pressure control file mapping
+-    - alpha: uapi: Add support for __SANE_USERSPACE_TYPES__
+-    - CIFS: remove endian related sparse warning
+-    - wl1251: add a missing spin_lock_init()
+-    - xfrm: policy: check policy direction value
+-    - drm/ttm: Fix accounting error when fail to get pages for pool
+-    - kvm: arm/arm64: Fix race in resetting stage2 PGD
+-    - kvm: arm/arm64: Force reading uncached stage2 PGD
+-    - epoll: fix race between ep_poll_callback(POLLFREE) and ep_free()/ep_remove()
+-    - crypto: algif_skcipher - only call put_page on referenced and used pages
+-    - Linux 4.4.87
+-
+-  * Xenial update to 4.4.86 stable release (LP: #1715430)
+-    - scsi: isci: avoid array subscript warning
+-    - ALSA: au88x0: Fix zero clear of stream->resources
+-    - btrfs: remove duplicate const specifier
+-    - i2c: jz4780: drop superfluous init
+-    - gcov: add support for gcc version >= 6
+-    - gcov: support GCC 7.1
+-    - lightnvm: initialize ppa_addr in dev_to_generic_addr()
+-    - p54: memset(0) whole array
+-    - lpfc: Fix Device discovery failures during switch reboot test.
+-    - arm64: mm: abort uaccess retries upon fatal signal
+-    - x86/io: Add "memory" clobber to insb/insw/insl/outsb/outsw/outsl
+-    - arm64: fpsimd: Prevent registers leaking across exec
+-    - scsi: sg: protect accesses to 'reserved' page array
+-    - scsi: sg: reset 'res_in_use' after unlinking reserved array
+-    - drm/i915: fix compiler warning in drivers/gpu/drm/i915/intel_uncore.c
+-    - Linux 4.4.86
+-
+-  * Xenial update to 4.4.85 stable release (LP: #1714298)
+-    - af_key: do not use GFP_KERNEL in atomic contexts
+-    - dccp: purge write queue in dccp_destroy_sock()
+-    - dccp: defer ccid_hc_tx_delete() at dismantle time
+-    - ipv4: fix NULL dereference in free_fib_info_rcu()
+-    - net_sched/sfq: update hierarchical backlog when drop packet
+-    - ipv4: better IP_MAX_MTU enforcement
+-    - sctp: fully initialize the IPv6 address in sctp_v6_to_addr()
+-    - tipc: fix use-after-free
+-    - ipv6: reset fn->rr_ptr when replacing route
+-    - ipv6: repair fib6 tree in failure case
+-    - tcp: when rearming RTO, if RTO time is in past then fire RTO ASAP
+-    - irda: do not leak initialized list.dev to userspace
+-    - net: sched: fix NULL pointer dereference when action calls some targets
+-    - net_sched: fix order of queue length updates in qdisc_replace()
+-    - mei: me: add broxton pci device ids
+-    - mei: me: add lewisburg device ids
+-    - Input: trackpoint - add new trackpoint firmware ID
+-    - Input: elan_i2c - add ELAN0602 ACPI ID to support Lenovo Yoga310
+-    - ALSA: core: Fix unexpected error at replacing user TLV
+-    - ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
+-    - ARCv2: PAE40: Explicitly set MSB counterpart of SLC region ops addresses
+-    - i2c: designware: Fix system suspend
+-    - drm: Release driver tracking before making the object available again
+-    - drm/atomic: If the atomic check fails, return its value first
+-    - drm: rcar-du: lvds: Fix PLL frequency-related configuration
+-    - drm: rcar-du: lvds: Rename PLLEN bit to PLLON
+-    - drm: rcar-du: Fix crash in encoder failure error path
+-    - drm: rcar-du: Fix display timing controller parameter
+-    - drm: rcar-du: Fix H/V sync signal polarity configuration
+-    - tracing: Fix freeing of filter in create_filter() when set_str is false
+-    - cifs: Fix df output for users with quota limits
+-    - cifs: return ENAMETOOLONG for overlong names in cifs_open()/cifs_lookup()
+-    - nfsd: Limit end of page list when decoding NFSv4 WRITE
+-    - perf/core: Fix group {cpu,task} validation
+-    - Bluetooth: hidp: fix possible might sleep error in hidp_session_thread
+-    - Bluetooth: cmtp: fix possible might sleep error in cmtp_session
+-    - Bluetooth: bnep: fix possible might sleep error in bnep_session
+-    - binder: use group leader instead of open thread
+-    - binder: Use wake up hint for synchronous transactions.
+-    - ANDROID: binder: fix proc->tsk check.
+-    - iio: imu: adis16480: Fix acceleration scale factor for adis16480
+-    - iio: hid-sensor-trigger: Fix the race with user space powering up sensors
+-    - staging: rtl8188eu: add RNX-N150NUB support
+-    - ASoC: simple-card: don't fail if sysclk setting is not supported
+-    - ASoC: rsnd: disable SRC.out only when stop timing
+-    - ASoC: rsnd: avoid pointless loop in rsnd_mod_interrupt()
+-    - ASoC: rsnd: Add missing initialization of ADG req_rate
+-    - ASoC: rsnd: ssi: 24bit data needs right-aligned settings
+-    - ASoC: rsnd: don't call update callback if it was NULL
+-    - ntb_transport: fix qp count bug
+-    - ntb_transport: fix bug calculating num_qps_mw
+-    - ACPI: ioapic: Clear on-stack resource before using it
+-    - ACPI / APEI: Add missing synchronize_rcu() on NOTIFY_SCI removal
+-    - Linux 4.4.85
+-
+-  * Xenial update to 4.4.84 stable release (LP: #1713729)
+-    - audit: Fix use after free in audit_remove_watch_rule()
+-    - parisc: pci memory bar assignment fails with 64bit kernels on dino/cujo
+-    - crypto: x86/sha1 - Fix reads beyond the number of blocks passed
+-    - Input: elan_i2c - Add antoher Lenovo ACPI ID for upcoming Lenovo NB
+-    - ALSA: seq: 2nd attempt at fixing race creating a queue
+-    - Revert "UBUNTU: SAUCE: (no-up) ALSA: usb-audio: Add quirk for sennheiser
+-      officerunner"
+-    - ALSA: usb-audio: Apply sample rate quirk to Sennheiser headset
+-    - ALSA: usb-audio: Add mute TLV for playback volumes on C-Media devices
+-    - mm/mempolicy: fix use after free when calling get_mempolicy
+-    - xen: fix bio vec merging
+-    - x86/asm/64: Clear AC on NMI entries
+-    - irqchip/atmel-aic: Fix unbalanced of_node_put() in aic_common_irq_fixup()
+-    - irqchip/atmel-aic: Fix unbalanced refcount in aic_common_rtc_irq_fixup()
+-    - Sanitize 'move_pages()' permission checks
+-    - pids: make task_tgid_nr_ns() safe
+-    - perf/x86: Fix LBR related crashes on Intel Atom
+-    - usb: optimize acpi companion search for usb port devices
+-    - usb: qmi_wwan: add D-Link DWM-222 device ID
+-    - Linux 4.4.84
+-
+-  * Intel i40e PF reset due to incorrect MDD detection (LP: #1713553)
+-    - i40e: Limit TX descriptor count in cases where frag size is greater than 16K
+-
+-  * Neighbour confirmation broken, breaks ARP cache aging (LP: #1715812)
+-    - sock: add sk_dst_pending_confirm flag
+-    - net: add dst_pending_confirm flag to skbuff
+-    - sctp: add dst_pending_confirm flag
+-    - tcp: replace dst_confirm with sk_dst_confirm
+-    - net: add confirm_neigh method to dst_ops
+-    - net: use dst_confirm_neigh for UDP, RAW, ICMP, L2TP
+-    - net: pending_confirm is not used anymore
+-
+-  * CVE-2017-14106
+-    - tcp: initialize rcv_mss to TCP_MIN_MSS instead of 0
+-
+-  * [CIFS] Fix maximum SMB2 header size (LP: #1713884)
+-    - CIFS: Fix maximum SMB2 header size
+-
+-  * Middle button of trackpoint doesn't work (LP: #1715271)
+-    - Input: trackpoint - assume 3 buttons when buttons detection fails
+-
+-  * kernel BUG at /build/linux-lts-xenial-_hWfOZ/linux-lts-
+-    xenial-4.4.0/security/apparmor/include/context.h:69! (LP: #1626984)
+-    - SAUCE: fix oops when disabled and module parameters, are accessed
+-
+-  * Touchpad not detected (LP: #1708852)
+-    - Input: elan_i2c - add ELAN0608 to the ACPI table
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Tue, 19 Sep 2017 17:55:11 +0200
+-
+-linux (4.4.0-96.119) xenial; urgency=low
+-
+-  * linux: 4.4.0-96.119 -proposed tracker (LP: #1716613)
+-
+-  * kernel panic -not syncing: Fatal exception: panic_on_oops (LP: #1708399)
+-    - s390/mm: no local TLB flush for clearing-by-ASCE IDTE
+-    - SAUCE: s390/mm: fix local TLB flushing vs. detach of an mm address space
+-    - SAUCE: s390/mm: fix race on mm->context.flush_mm
+-
+-  * CVE-2017-1000251
+-    - Bluetooth: Properly check L2CAP config option output buffer length
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Tue, 12 Sep 2017 15:40:01 +0200
+-
+-linux (4.4.0-95.118) xenial; urgency=low
+-
+-  * linux: 4.4.0-95.118 -proposed tracker (LP: #1715651)
+-
+-  * Xenial update to 4.4.78 stable release broke Address Sanitizer
+-    (LP: #1715636)
+-    - mm: revert x86_64 and arm64 ELF_ET_DYN_BASE base changes
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Thu, 07 Sep 2017 17:26:15 +0200
+-
+-linux (4.4.0-94.117) xenial; urgency=low
+-
+-  * linux: 4.4.0-94.117 -proposed tracker (LP: #1713462)
+-
+-  * mwifiex causes kernel oops when AP mode is enabled (LP: #1712746)
+-    - SAUCE: net/wireless: do not dereference invalid pointer
+-    - SAUCE: mwifiex: do not dereference invalid pointer
+-
+-  * Backport more recent Broadcom bnxt_en driver (LP: #1711056)
+-    - SAUCE: bnxt_en_bpo: Import bnxt_en driver version 1.8.1
+-    - SAUCE: bnxt_en_bpo: Drop distro out-of-tree detection logic
+-    - SAUCE: bnxt_en_bpo: Remove unnecessary compile flags
+-    - SAUCE: bnxt_en_bpo: Move config settings to Kconfig
+-    - SAUCE: bnxt_en_bpo: Remove PCI_IDs handled by the regular driver
+-    - SAUCE: bnxt_en_bpo: Rename the backport driver to bnxt_en_bpo
+-    - bnxt_en_bpo: [Config] Enable CONFIG_BNXT_BPO=m
+-
+-  * HID: multitouch: Support ALPS PTP Stick and Touchpad devices (LP: #1712481)
+-    - HID: multitouch: Support PTP Stick and Touchpad device
+-    - SAUCE: HID: multitouch: Support ALPS PTP stick with pid 0x120A
+-
+-  * igb: Support using Broadcom 54616 as PHY (LP: #1712024)
+-    - SAUCE: igb: add support for using Broadcom 54616 as PHY
+-
+-  * IPR driver causes multipath to fail paths/stuck IO on Medium Errors
+-    (LP: #1682644)
+-    - scsi: ipr: do not set DID_PASSTHROUGH on CHECK CONDITION
+-
+-  * accessing /dev/hvc1 with stress-ng on Ubuntu xenial causes crash
+-    (LP: #1711401)
+-    - tty/hvc: Use IRQF_SHARED for OPAL hvc consoles
+-
+-  * memory-hotplug test needs to be fixed (LP: #1710868)
+-    - selftests: typo correction for memory-hotplug test
+-    - selftests: check hot-pluggagble memory for memory-hotplug test
+-    - selftests: check percentage range for memory-hotplug test
+-    - selftests: add missing test name in memory-hotplug test
+-    - selftests: fix memory-hotplug test
+-
+-  * HP lt4132 LTE/HSPA+ 4G Module (03f0:a31d) does not work (LP: #1707643)
+-    - net: cdc_mbim: apply "NDP to end" quirk to HP lt4132
+-
+-  * Migrating KSM page causes the VM lock up as the KSM page merging list is too
+-    large (LP: #1680513)
+-    - ksm: introduce ksm_max_page_sharing per page deduplication limit
+-    - ksm: fix use after free with merge_across_nodes = 0
+-    - ksm: cleanup stable_node chain collapse case
+-    - ksm: swap the two output parameters of chain/chain_prune
+-    - ksm: optimize refile of stable_node_dup at the head of the chain
+-
+-  * sort ABI files with C.UTF-8 locale (LP: #1712345)
+-    - [Packaging] sort ABI files with C.UTF-8 locale
+-
+-  * Include Broadcom GPL modules in Xenial Kernel (LP: #1665783)
+-    - [Config] OpenNSL Kconfig/Makefile
+-    - Import OpenNSL v3.1.0.17
+-    - [Config] CONFIG_OPENNSL=y for amd64
+-    - OpenNSL: Enable Kconfig and build
+-    - SAUCE: opennsl: add proper CFLAGS
+-
+-  * Xenial update to 4.4.83 stable release (LP: #1711557)
+-    - cpuset: fix a deadlock due to incomplete patching of cpusets_enabled()
+-    - mm: ratelimit PFNs busy info message
+-    - iscsi-target: fix memory leak in iscsit_setup_text_cmd()
+-    - iscsi-target: Fix iscsi_np reset hung task during parallel delete
+-    - fuse: initialize the flock flag in fuse_file on allocation
+-    - nfs/flexfiles: fix leak of nfs4_ff_ds_version arrays
+-    - USB: serial: option: add D-Link DWM-222 device ID
+-    - USB: serial: cp210x: add support for Qivicon USB ZigBee dongle
+-    - USB: serial: pl2303: add new ATEN device id
+-    - usb: musb: fix tx fifo flush handling again
+-    - USB: hcd: Mark secondary HCD as dead if the primary one died
+-    - staging:iio:resolver:ad2s1210 fix negative IIO_ANGL_VEL read
+-    - iio: accel: bmc150: Always restore device to normal mode after suspend-
+-      resume
+-    - iio: light: tsl2563: use correct event code
+-    - uas: Add US_FL_IGNORE_RESIDUE for Initio Corporation INIC-3069
+-    - USB: Check for dropped connection before switching to full speed
+-    - usb: core: unlink urbs from the tail of the endpoint's urb_list
+-    - usb: quirks: Add no-lpm quirk for Moshi USB to Ethernet Adapter
+-    - usb:xhci:Add quirk for Certain failing HP keyboard on reset after resume
+-    - iio: adc: vf610_adc: Fix VALT selection value for REFSEL bits
+-    - pnfs/blocklayout: require 64-bit sector_t
+-    - pinctrl: sunxi: add a missing function of A10/A20 pinctrl driver
+-    - pinctrl: samsung: Remove bogus irq_[un]mask from resource management
+-    - Linux 4.4.83
+-
+-  * Xenial update to 4.4.82 stable release (LP: #1711535)
+-    - tcp: avoid setting cwnd to invalid ssthresh after cwnd reduction states
+-    - net: fix keepalive code vs TCP_FASTOPEN_CONNECT
+-    - bpf, s390: fix jit branch offset related to ldimm64
+-    - net: sched: set xt_tgchk_param par.nft_compat as 0 in ipt_init_target
+-    - tcp: fastopen: tcp_connect() must refresh the route
+-    - net: avoid skb_warn_bad_offload false positives on UFO
+-    - sparc64: Prevent perf from running during super critical sections
+-    - KVM: arm/arm64: Handle hva aging while destroying the vm
+-    - mm/mempool: avoid KASAN marking mempool poison checks as use-after-free
+-    - Linux 4.4.82
+-
+-  * Xenial update to 4.4.81 stable release (LP: #1711526)
+-    - libata: array underflow in ata_find_dev()
+-    - workqueue: restore WQ_UNBOUND/max_active==1 to be ordered
+-    - ALSA: hda - Fix speaker output from VAIO VPCL14M1R
+-    - ASoC: do not close shared backend dailink
+-    - KVM: async_pf: make rcu irq exit if not triggered from idle task
+-    - mm/page_alloc: Remove kernel address exposure in free_reserved_area()
+-    - ext4: fix SEEK_HOLE/SEEK_DATA for blocksize < pagesize
+-    - ext4: fix overflow caused by missing cast in ext4_resize_fs()
+-    - ARM: dts: armada-38x: Fix irq type for pca955
+-    - media: platform: davinci: return -EINVAL for VPFE_CMD_S_CCDC_RAW_PARAMS
+-      ioctl
+-    - target: Avoid mappedlun symlink creation during lun shutdown
+-    - iscsi-target: Always wait for kthread_should_stop() before kthread exit
+-    - iscsi-target: Fix early sk_data_ready LOGIN_FLAGS_READY race
+-    - iscsi-target: Fix initial login PDU asynchronous socket close OOPs
+-    - iscsi-target: Fix delayed logout processing greater than
+-      SECONDS_FOR_LOGOUT_COMP
+-    - iser-target: Avoid isert_conn->cm_id dereference in isert_login_recv_done
+-    - mm, mprotect: flush TLB if potentially racing with a parallel reclaim
+-      leaving stale TLB entries
+-    - media: lirc: LIRC_GET_REC_RESOLUTION should return microseconds
+-    - f2fs: sanity check checkpoint segno and blkoff
+-    - drm: rcar-du: fix backport bug
+-    - saa7164: fix double fetch PCIe access condition
+-    - ipv4: ipv6: initialize treq->txhash in cookie_v[46]_check()
+-    - net: Zero terminate ifr_name in dev_ifname().
+-    - ipv6: avoid overflow of offset in ip6_find_1stfragopt
+-    - ipv4: initialize fib_trie prior to register_netdev_notifier call.
+-    - rtnetlink: allocate more memory for dev_set_mac_address()
+-    - mcs7780: Fix initialization when CONFIG_VMAP_STACK is enabled
+-    - openvswitch: fix potential out of bound access in parse_ct
+-    - packet: fix use-after-free in prb_retire_rx_blk_timer_expired()
+-    - ipv6: Don't increase IPSTATS_MIB_FRAGFAILS twice in ip6_fragment()
+-    - net: ethernet: nb8800: Handle all 4 RGMII modes identically
+-    - dccp: fix a memleak that dccp_ipv6 doesn't put reqsk properly
+-    - dccp: fix a memleak that dccp_ipv4 doesn't put reqsk properly
+-    - dccp: fix a memleak for dccp_feat_init err process
+-    - sctp: don't dereference ptr before leaving _sctp_walk_{params, errors}()
+-    - sctp: fix the check for _sctp_walk_params and _sctp_walk_errors
+-    - net/mlx5: Fix command bad flow on command entry allocation failure
+-    - net: phy: Correctly process PHY_HALTED in phy_stop_machine()
+-    - net: phy: Fix PHY unbind crash
+-    - xen-netback: correctly schedule rate-limited queues
+-    - sparc64: Measure receiver forward progress to avoid send mondo timeout
+-    - wext: handle NULL extra data in iwe_stream_add_point better
+-    - sh_eth: R8A7740 supports packet shecksumming
+-    - net: phy: dp83867: fix irq generation
+-    - tg3: Fix race condition in tg3_get_stats64().
+-    - x86/boot: Add missing declaration of string functions
+-    - phy state machine: failsafe leave invalid RUNNING state
+-    - scsi: qla2xxx: Get mutex lock before checking optrom_state
+-    - drm/virtio: fix framebuffer sparse warning
+-    - virtio_blk: fix panic in initialization error path
+-    - ARM: 8632/1: ftrace: fix syscall name matching
+-    - mm, slab: make sure that KMALLOC_MAX_SIZE will fit into MAX_ORDER
+-    - lib/Kconfig.debug: fix frv build failure
+-    - signal: protect SIGNAL_UNKILLABLE from unintentional clearing.
+-    - mm: don't dereference struct page fields of invalid pages
+-    - workqueue: implicit ordered attribute should be overridable
+-    - Linux 4.4.81
+-
+-  * Xenial update to 4.4.80 stable release (LP: #1710646)
+-    - af_key: Add lock to key dump
+-    - pstore: Make spinlock per zone instead of global
+-    - powerpc/pseries: Fix of_node_put() underflow during reconfig remove
+-    - crypto: authencesn - Fix digest_null crash
+-    - md/raid5: add thread_group worker async_tx_issue_pending_all
+-    - drm/vmwgfx: Fix gcc-7.1.1 warning
+-    - drm/nouveau/bar/gf100: fix access to upper half of BAR2
+-    - KVM: PPC: Book3S HV: Context-switch EBB registers properly
+-    - KVM: PPC: Book3S HV: Restore critical SPRs to host values on guest exit
+-    - KVM: PPC: Book3S HV: Reload HTM registers explicitly
+-    - KVM: PPC: Book3S HV: Save/restore host values of debug registers
+-    - Revert "powerpc/numa: Fix percpu allocations to be NUMA aware"
+-    - Staging: comedi: comedi_fops: Avoid orphaned proc entry
+-    - drm/rcar: Nuke preclose hook
+-    - drm: rcar-du: Perform initialization/cleanup at probe/remove time
+-    - drm: rcar-du: Simplify and fix probe error handling
+-    - perf intel-pt: Fix ip compression
+-    - perf intel-pt: Fix last_ip usage
+-    - perf intel-pt: Use FUP always when scanning for an IP
+-    - perf intel-pt: Ensure never to set 'last_ip' when packet 'count' is zero
+-    - xfs: don't BUG() on mixed direct and mapped I/O
+-    - nfc: fdp: fix NULL pointer dereference
+-    - net: phy: Do not perform software reset for Generic PHY
+-    - isdn: Fix a sleep-in-atomic bug
+-    - isdn/i4l: fix buffer overflow
+-    - ath10k: fix null deref on wmi-tlv when trying spectral scan
+-    - wil6210: fix deadlock when using fw_no_recovery option
+-    - mailbox: always wait in mbox_send_message for blocking Tx mode
+-    - mailbox: skip complete wait event if timer expired
+-    - mailbox: handle empty message in tx_tick
+-    - mpt3sas: Don't overreach ioc->reply_post[] during initialization
+-    - kaweth: fix firmware download
+-    - kaweth: fix oops upon failed memory allocation
+-    - sched/cgroup: Move sched_online_group() back into css_online() to fix crash
+-    - PM / Domains: defer dev_pm_domain_set() until genpd->attach_dev succeeds if
+-      present
+-    - RDMA/uverbs: Fix the check for port number
+-    - libnvdimm, btt: fix btt_rw_page not returning errors
+-    - ipmi/watchdog: fix watchdog timeout set on reboot
+-    - v4l: s5c73m3: fix negation operator
+-    - pstore: Allow prz to control need for locking
+-    - pstore: Correctly initialize spinlock and flags
+-    - pstore: Use dynamic spinlock initializer
+-    - net: skb_needs_check() accepts CHECKSUM_NONE for tx
+-    - sched/cputime: Fix prev steal time accouting during CPU hotplug
+-    - xen/blkback: don't free be structure too early
+-    - xen/blkback: don't use xen_blkif_get() in xen-blkback kthread
+-    - tpm: fix a kernel memory leak in tpm-sysfs.c
+-    - tpm: Replace device number bitmap with IDR
+-    - x86/mce/AMD: Make the init code more robust
+-    - r8169: add support for RTL8168 series add-on card.
+-    - ARM: dts: n900: Mark eMMC slot with no-sdio and no-sd flags
+-    - net/mlx4: Remove BUG_ON from ICM allocation routine
+-    - drm/msm: Ensure that the hardware write pointer is valid
+-    - drm/msm: Verify that MSM_SUBMIT_BO_FLAGS are set
+-    - vfio-pci: use 32-bit comparisons for register address for gcc-4.5
+-    - irqchip/keystone: Fix "scheduling while atomic" on rt
+-    - ASoC: tlv320aic3x: Mark the RESET register as volatile
+-    - spi: dw: Make debugfs name unique between instances
+-    - ASoC: nau8825: fix invalid configuration in Pre-Scalar of FLL
+-    - irqchip/mxs: Enable SKIP_SET_WAKE and MASK_ON_SUSPEND
+-    - openrisc: Add _text symbol to fix ksym build error
+-    - dmaengine: ioatdma: Add Skylake PCI Dev ID
+-    - dmaengine: ioatdma: workaround SKX ioatdma version
+-    - dmaengine: ti-dma-crossbar: Add some 'of_node_put()' in error path.
+-    - ARM64: zynqmp: Fix W=1 dtc 1.4 warnings
+-    - ARM64: zynqmp: Fix i2c node's compatible string
+-    - ARM: s3c2410_defconfig: Fix invalid values for NF_CT_PROTO_*
+-    - ACPI / scan: Prefer devices without _HID/_CID for _ADR matching
+-    - usb: gadget: Fix copy/pasted error message
+-    - Btrfs: adjust outstanding_extents counter properly when dio write is split
+-    - tools lib traceevent: Fix prev/next_prio for deadline tasks
+-    - xfrm: Don't use sk_family for socket policy lookups
+-    - perf tools: Install tools/lib/traceevent plugins with install-bin
+-    - perf symbols: Robustify reading of build-id from sysfs
+-    - video: fbdev: cobalt_lcdfb: Handle return NULL error from devm_ioremap
+-    - vfio-pci: Handle error from pci_iomap
+-    - arm64: mm: fix show_pte KERN_CONT fallout
+-    - nvmem: imx-ocotp: Fix wrong register size
+-    - sh_eth: enable RX descriptor word 0 shift on SH7734
+-    - ALSA: usb-audio: test EP_FLAG_RUNNING at urb completion
+-    - HID: ignore Petzl USB headlamp
+-    - scsi: fnic: Avoid sending reset to firmware when another reset is in
+-      progress
+-    - scsi: snic: Return error code on memory allocation failure
+-    - ASoC: dpcm: Avoid putting stream state to STOP when FE stream is paused
+-    - Linux 4.4.80
+-
+-  * Please only recommend or suggest initramfs-tools | linux-initramfs-tool for
+-    kernels able to boot without initramfs (LP: #1700972)
+-    - [Debian] Don't depend on initramfs-tools
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Mon, 28 Aug 2017 17:07:08 +0200
+-
+-linux (4.4.0-93.116) xenial; urgency=low
+-
+-  * linux: 4.4.0-93.116 -proposed tracker (LP: #1709296)
+-
+-  * Creating conntrack entry failure with kernel 4.4.0-89 (LP: #1709032)
+-    - Revert "Revert "netfilter: synproxy: fix conntrackd interaction""
+-    - netfilter: nf_ct_ext: fix possible panic after nf_ct_extend_unregister
+-
+-  * CVE-2017-1000112
+-    - Revert "udp: consistently apply ufo or fragmentation"
+-    - udp: consistently apply ufo or fragmentation
+-
+-  * CVE-2017-1000111
+-    - Revert "net-packet: fix race in packet_set_ring on PACKET_RESERVE"
+-    - packet: fix tp_reserve race in packet_set_ring
+-
+-  * kernel BUG at [tty_ldisc_reinit] mm/slub.c! (LP: #1709126)
+-    - tty: Simplify tty_set_ldisc() exit handling
+-    - tty: Reset c_line from driver's init_termios
+-    - tty: Handle NULL tty->ldisc
+-    - tty: Move tty_ldisc_kill()
+-    - tty: Use 'disc' for line discipline index name
+-    - tty: Refactor tty_ldisc_reinit() for reuse
+-    - tty: Destroy ldisc instance on hangup
+-
+-  * atheros bt failed after S3 (LP: #1706833)
+-    - SAUCE: Bluetooth: Make request workqueue freezable
+-
+-  * The Precision Touchpad(PTP) button sends incorrect event code (LP: #1708372)
+-    - HID: multitouch: handle external buttons for Precision Touchpads
+-
+-  * Set CONFIG_SATA_HIGHBANK=y on armhf (LP: #1703430)
+-    - [Config] CONFIG_SATA_HIGHBANK=y
+-
+-  * xfs slab objects (memory) leak when xfs shutdown is called (LP: #1706132)
+-    - xfs: fix xfs_log_ticket leak in xfs_end_io() after fs shutdown
+-
+-  * Adt tests of src:linux time out often on armhf lxc containers (LP: #1705495)
+-    - [Packaging] tests -- reduce rebuild test to one flavour
+-
+-  * CVE-2017-7495
+-    - ext4: fix data exposure after a crash
+-
+-  * ubuntu/rsi driver downlink wifi throughput drops to 5-6 Mbps when BT
+-    keyboard is connected (LP: #1706991)
+-    - SAUCE: Redpine: enable power save by default for coex mode
+-    - SAUCE: Redpine: uapsd configuration changes
+-
+-  * [Hyper-V] hv_netvsc: Exclude non-TCP port numbers from vRSS hashing
+-    (LP: #1690174)
+-    - hv_netvsc: Exclude non-TCP port numbers from vRSS hashing
+-
+-  * ath10k doesn't report full RSSI information (LP: #1706531)
+-    - ath10k: add per chain RSSI reporting
+-
+-  * ideapad_laptop don't support v310-14isk (LP: #1705378)
+-    - platform/x86: ideapad-laptop: Add several models to no_hw_rfkill
+-
+-  * [8087:0a2b] Failed to load bluetooth firmware(might affect some other Intel
+-    bt devices) (LP: #1705633)
+-    - Bluetooth: btintel: Create common Intel Version Read function
+-    - Bluetooth: Use switch statement for Intel hardware variants
+-    - Bluetooth: Replace constant hw_variant from Intel Bluetooth firmware
+-      filename
+-    - Bluetooth: hci_intel: Fix firmware file name to use hw_variant
+-    - Bluetooth: btintel: Add MODULE_FIRMWARE entries for iBT 3.5 controllers
+-
+-  * xhci_hcd: ERROR Transfer event TRB DMA ptr not part of current TD ep_index 2
+-    comp_code 13 (LP: #1667750)
+-    - xhci: Bad Ethernet performance plugged in ASM1042A host
+-
+-  * OpenPower: Some multipaths temporarily have only a single path
+-    (LP: #1696445)
+-    - scsi: ses: don't get power status of SES device slot on probe
+-
+-  * Hotkeys on new Thinkpad systems aren't working (LP: #1705169)
+-    - platform/x86: thinkpad_acpi: Adding new hotkey ID for Lenovo thinkpad
+-    - platform/x86: thinkpad_acpi: guard generic hotkey case
+-    - platform/x86: thinkpad_acpi: add mapping for new hotkeys
+-
+-  * CVE-2015-7837
+-    - SAUCE: (no-up) kexec/uefi: copy secure_boot flag in boot params across kexec
+-      reboot
+-
+-  * misleading kernel warning skb_warn_bad_offload during checksum calculation
+-    (LP: #1705447)
+-    - net: reduce skb_warn_bad_offload() noise
+-
+-  * bonding: stack dump when unregistering a netdev (LP: #1704102)
+-    - bonding: avoid NETDEV_CHANGEMTU event when unregistering slave
+-
+-  * Ubuntu 16.04 IOB Error when the Mustang board rebooted (LP: #1693673)
+-    - drivers: net: xgene: Fix redundant prefetch buffer cleanup
+-
+-  * Ubuntu16.04: NVMe 4K+T10 DIF/DIX format returns I/O error on dd with split
+-    op (LP: #1689946)
+-    - blk-mq: NVMe 512B/4K+T10 DIF/DIX format returns I/O error on dd with split
+-      op
+-
+-  * linux >= 4.2: bonding 802.3ad does not work with 5G, 25G and 50G link speeds
+-    (LP: #1697892)
+-    - bonding: add 802.3ad support for 100G speeds
+-    - bonding: fix 802.3ad aggregator reselection
+-    - bonding: add 802.3ad support for 25G speeds
+-    - bonding: fix 802.3ad support for 5G and 50G speeds
+-
+-  * Xenial update to 4.4.79 stable release (LP: #1707233)
+-    - disable new gcc-7.1.1 warnings for now
+-    - ir-core: fix gcc-7 warning on bool arithmetic
+-    - s5p-jpeg: don't return a random width/height
+-    - thermal: cpu_cooling: Avoid accessing potentially freed structures
+-    - ath9k: fix tx99 use after free
+-    - ath9k: fix tx99 bus error
+-    - NFC: fix broken device allocation
+-    - NFC: nfcmrvl_uart: add missing tty-device sanity check
+-    - NFC: nfcmrvl: do not use device-managed resources
+-    - NFC: nfcmrvl: use nfc-device for firmware download
+-    - NFC: nfcmrvl: fix firmware-management initialisation
+-    - nfc: Ensure presence of required attributes in the activate_target handler
+-    - nfc: Fix the sockaddr length sanitization in llcp_sock_connect
+-    - NFC: Add sockaddr length checks before accessing sa_family in bind handlers
+-    - perf intel-pt: Move decoder error setting into one condition
+-    - perf intel-pt: Improve sample timestamp
+-    - perf intel-pt: Fix missing stack clear
+-    - perf intel-pt: Ensure IP is zero when state is INTEL_PT_STATE_NO_IP
+-    - perf intel-pt: Clear FUP flag on error
+-    - Bluetooth: use constant time memory comparison for secret values
+-    - wlcore: fix 64K page support
+-    - ASoC: compress: Derive substream from stream based on direction
+-    - PM / Domains: Fix unsafe iteration over modified list of device links
+-    - PM / Domains: Fix unsafe iteration over modified list of domain providers
+-    - scsi: ses: do not add a device to an enclosure if enclosure_add_links()
+-      fails.
+-    - iscsi-target: Add login_keys_workaround attribute for non RFC initiators
+-    - powerpc/64: Fix atomic64_inc_not_zero() to return an int
+-    - powerpc: Fix emulation of mcrf in emulate_step()
+-    - powerpc: Fix emulation of mfocrf in emulate_step()
+-    - powerpc/asm: Mark cr0 as clobbered in mftb()
+-    - af_key: Fix sadb_x_ipsecrequest parsing
+-    - PCI/PM: Restore the status of PCI devices across hibernation
+-    - ipvs: SNAT packet replies only for NATed connections
+-    - xhci: fix 20000ms port resume timeout
+-    - xhci: Fix NULL pointer dereference when cleaning up streams for removed host
+-    - usb: storage: return on error to avoid a null pointer dereference
+-    - USB: cdc-acm: add device-id for quirky printer
+-    - usb: renesas_usbhs: fix usbhsc_resume() for !USBHSF_RUNTIME_PWCTRL
+-    - usb: renesas_usbhs: gadget: disable all eps when the driver stops
+-    - md: don't use flush_signals in userspace processes
+-    - x86/xen: allow userspace access during hypercalls
+-    - cx88: Fix regression in initial video standard setting
+-    - Raid5 should update rdev->sectors after reshape
+-    - s390/syscalls: Fix out of bounds arguments access
+-    - drm/amd/amdgpu: Return error if initiating read out of range on vram
+-    - drm/radeon/ci: disable mclk switching for high refresh rates (v2)
+-    - drm/radeon: Fix eDP for single-display iMac10,1 (v2)
+-    - ipmi: use rcu lock around call to intf->handlers->sender()
+-    - ipmi:ssif: Add missing unlock in error branch
+-    - f2fs: Don't clear SGID when inheriting ACLs
+-    - vfio: Fix group release deadlock
+-    - vfio: New external user group/file match
+-    - ftrace: Fix uninitialized variable in match_records()
+-    - MIPS: Fix mips_atomic_set() retry condition
+-    - MIPS: Fix mips_atomic_set() with EVA
+-    - MIPS: Negate error syscall return in trace
+-    - x86/acpi: Prevent out of bound access caused by broken ACPI tables
+-    - x86/ioapic: Pass the correct data to unmask_ioapic_irq()
+-    - MIPS: Fix MIPS I ISA /proc/cpuinfo reporting
+-    - MIPS: Save static registers before sysmips
+-    - MIPS: Actually decode JALX in `__compute_return_epc_for_insn'
+-    - MIPS: Fix unaligned PC interpretation in `compute_return_epc'
+-    - MIPS: math-emu: Prevent wrong ISA mode instruction emulation
+-    - MIPS: Send SIGILL for BPOSGE32 in `__compute_return_epc_for_insn'
+-    - MIPS: Rename `sigill_r6' to `sigill_r2r6' in `__compute_return_epc_for_insn'
+-    - MIPS: Send SIGILL for linked branches in `__compute_return_epc_for_insn'
+-    - MIPS: Fix a typo: s/preset/present/ in r2-to-r6 emulation error message
+-    - Input: i8042 - fix crash at boot time
+-    - NFS: only invalidate dentrys that are clearly invalid.
+-    - udf: Fix deadlock between writeback and udf_setsize()
+-    - target: Fix COMPARE_AND_WRITE caw_sem leak during se_cmd quiesce
+-    - perf annotate: Fix broken arrow at row 0 connecting jmp instruction to its
+-      target
+-    - Revert "perf/core: Drop kernel samples even though :u is specified"
+-    - staging: rtl8188eu: add TL-WN722N v2 support
+-    - ceph: fix race in concurrent readdir
+-    - RDMA/core: Initialize port_num in qp_attr
+-    - drm/mst: Fix error handling during MST sideband message reception
+-    - drm/mst: Avoid dereferencing a NULL mstb in drm_dp_mst_handle_up_req()
+-    - drm/mst: Avoid processing partially received up/down message transactions
+-    - of: device: Export of_device_{get_modalias, uvent_modalias} to modules
+-    - spmi: Include OF based modalias in device uevent
+-    - tracing: Fix kmemleak in instance_rmdir
+-    - alarmtimer: don't rate limit one-shot timers
+-    - Linux 4.4.79
+-
+-  * Xenial update to 4.4.78 stable release (LP: #1705707)
+-    - net_sched: fix error recovery at qdisc creation
+-    - net: sched: Fix one possible panic when no destroy callback
+-    - net/phy: micrel: configure intterupts after autoneg workaround
+-    - ipv6: avoid unregistering inet6_dev for loopback
+-    - net: dp83640: Avoid NULL pointer dereference.
+-    - tcp: reset sk_rx_dst in tcp_disconnect()
+-    - net: prevent sign extension in dev_get_stats()
+-    - bpf: prevent leaking pointer via xadd on unpriviledged
+-    - net: handle NAPI_GRO_FREE_STOLEN_HEAD case also in napi_frags_finish()
+-    - ipv6: dad: don't remove dynamic addresses if link is down
+-    - net: ipv6: Compare lwstate in detecting duplicate nexthops
+-    - vrf: fix bug_on triggered by rx when destroying a vrf
+-    - rds: tcp: use sock_create_lite() to create the accept socket
+-    - brcmfmac: fix possible buffer overflow in brcmf_cfg80211_mgmt_tx()
+-    - cfg80211: Define nla_policy for NL80211_ATTR_LOCAL_MESH_POWER_MODE
+-    - cfg80211: Validate frequencies nested in NL80211_ATTR_SCAN_FREQUENCIES
+-    - cfg80211: Check if PMKID attribute is of expected size
+-    - irqchip/gic-v3: Fix out-of-bound access in gic_set_affinity
+-    - parisc: Report SIGSEGV instead of SIGBUS when running out of stack
+-    - parisc: use compat_sys_keyctl()
+-    - parisc: DMA API: return error instead of BUG_ON for dma ops on non dma devs
+-    - parisc/mm: Ensure IRQs are off in switch_mm()
+-    - tools/lib/lockdep: Reduce MAX_LOCK_DEPTH to avoid overflowing lock_chain/:
+-      Depth
+-    - kernel/extable.c: mark core_kernel_text notrace
+-    - mm/list_lru.c: fix list_lru_count_node() to be race free
+-    - fs/dcache.c: fix spin lockup issue on nlru->lock
+-    - checkpatch: silence perl 5.26.0 unescaped left brace warnings
+-    - binfmt_elf: use ELF_ET_DYN_BASE only for PIE
+-    - arm: move ELF_ET_DYN_BASE to 4MB
+-    - arm64: move ELF_ET_DYN_BASE to 4GB / 4MB
+-    - powerpc: move ELF_ET_DYN_BASE to 4GB / 4MB
+-    - s390: reduce ELF_ET_DYN_BASE
+-    - exec: Limit arg stack to at most 75% of _STK_LIM
+-    - vt: fix unchecked __put_user() in tioclinux ioctls
+-    - mnt: In umount propagation reparent in a separate pass
+-    - mnt: In propgate_umount handle visiting mounts in any order
+-    - mnt: Make propagate_umount less slow for overlapping mount propagation trees
+-    - selftests/capabilities: Fix the test_execve test
+-    - tpm: Get rid of chip->pdev
+-    - tpm: Provide strong locking for device removal
+-    - Add "shutdown" to "struct class".
+-    - tpm: Issue a TPM2_Shutdown for TPM2 devices.
+-    - mm: fix overflow check in expand_upwards()
+-    - crypto: talitos - Extend max key length for SHA384/512-HMAC and AEAD
+-    - crypto: atmel - only treat EBUSY as transient if backlog
+-    - crypto: sha1-ssse3 - Disable avx2
+-    - crypto: caam - fix signals handling
+-    - sched/topology: Fix overlapping sched_group_mask
+-    - sched/topology: Optimize build_group_mask()
+-    - PM / wakeirq: Convert to SRCU
+-    - PM / QoS: return -EINVAL for bogus strings
+-    - tracing: Use SOFTIRQ_OFFSET for softirq dectection for more accurate results
+-    - KVM: x86: disable MPX if host did not enable MPX XSAVE features
+-    - kvm: vmx: Do not disable intercepts for BNDCFGS
+-    - kvm: x86: Guest BNDCFGS requires guest MPX support
+-    - kvm: vmx: Check value written to IA32_BNDCFGS
+-    - kvm: vmx: allow host to access guest MSR_IA32_BNDCFGS
+-    - Linux 4.4.78
+-
+-  * Xenial update to 4.4.77 stable release (LP: #1705238)
+-    - fs: add a VALID_OPEN_FLAGS
+-    - fs: completely ignore unknown open flags
+-    - driver core: platform: fix race condition with driver_override
+-    - bgmac: reset & enable Ethernet core before using it
+-    - mm: fix classzone_idx underflow in shrink_zones()
+-    - tracing/kprobes: Allow to create probe with a module name starting with a
+-      digit
+-    - usb: dwc3: replace %p with %pK
+-    - USB: serial: cp210x: add ID for CEL EM3588 USB ZigBee stick
+-    - Add USB quirk for HVR-950q to avoid intermittent device resets
+-    - usb: usbip: set buffer pointers to NULL after free
+-    - usb: Fix typo in the definition of Endpoint[out]Request
+-    - mac80211_hwsim: Replace bogus hrtimer clockid
+-    - sysctl: don't print negative flag for proc_douintvec
+-    - sysctl: report EINVAL if value is larger than UINT_MAX for proc_douintvec
+-    - pinctrl: sh-pfc: r8a7791: Fix SCIF2 pinmux data
+-    - pinctrl: meson: meson8b: fix the NAND DQS pins
+-    - pinctrl: sunxi: Fix SPDIF function name for A83T
+-    - pinctrl: mxs: atomically switch mux and drive strength config
+-    - pinctrl: sh-pfc: Update info pointer after SoC-specific init
+-    - USB: serial: option: add two Longcheer device ids
+-    - USB: serial: qcserial: new Sierra Wireless EM7305 device ID
+-    - gfs2: Fix glock rhashtable rcu bug
+-    - x86/tools: Fix gcc-7 warning in relocs.c
+-    - x86/uaccess: Optimize copy_user_enhanced_fast_string() for short strings
+-    - ath10k: override CE5 config for QCA9377
+-    - KEYS: Fix an error code in request_master_key()
+-    - RDMA/uverbs: Check port number supplied by user verbs cmds
+-    - mqueue: fix a use-after-free in sys_mq_notify()
+-    - tools include: Add a __fallthrough statement
+-    - tools string: Use __fallthrough in perf_atoll()
+-    - tools strfilter: Use __fallthrough
+-    - perf top: Use __fallthrough
+-    - perf intel-pt: Use __fallthrough
+-    - perf thread_map: Correctly size buffer used with dirent->dt_name
+-    - perf scripting perl: Fix compile error with some perl5 versions
+-    - perf tests: Avoid possible truncation with dirent->d_name + snprintf
+-    - perf bench numa: Avoid possible truncation when using snprintf()
+-    - perf tools: Use readdir() instead of deprecated readdir_r()
+-    - perf thread_map: Use readdir() instead of deprecated readdir_r()
+-    - perf script: Use readdir() instead of deprecated readdir_r()
+-    - perf tools: Remove duplicate const qualifier
+-    - perf annotate browser: Fix behaviour of Shift-Tab with nothing focussed
+-    - perf pmu: Fix misleadingly indented assignment (whitespace)
+-    - perf dwarf: Guard !x86_64 definitions under #ifdef else clause
+-    - perf trace: Do not process PERF_RECORD_LOST twice
+-    - perf tests: Remove wrong semicolon in while loop in CQM test
+-    - perf tools: Use readdir() instead of deprecated readdir_r() again
+-    - md: fix incorrect use of lexx_to_cpu in does_sb_need_changing
+-    - md: fix super_offset endianness in super_1_rdev_size_change
+-    - tcp: fix tcp_mark_head_lost to check skb len before fragmenting
+-    - staging: vt6556: vnt_start Fix missing call to vnt_key_init_table.
+-    - staging: comedi: fix clean-up of comedi_class in comedi_init()
+-    - ext4: check return value of kstrtoull correctly in reserved_clusters_store
+-    - x86/mm/pat: Don't report PAT on CPUs that don't support it
+-    - saa7134: fix warm Medion 7134 EEPROM read
+-    - Linux 4.4.77
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Fri, 11 Aug 2017 16:51:50 +0200
+-
+-linux (4.4.0-92.115) xenial; urgency=low
+-
+-  * linux: 4.4.0-92.115 -proposed tracker (LP: #1709812)
+-
+-  * Creating conntrack entry failure with kernel 4.4.0-89 (LP: #1709032)
+-    - Revert "netfilter: synproxy: fix conntrackd interaction"
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Thu, 10 Aug 2017 10:29:51 +0200
+-
+-linux (4.4.0-91.114) xenial; urgency=low
+-
+-  * CVE-2017-1000112
+-    - ipv4: Should use consistent conditional judgement for ip fragment in
+-      __ip_append_data and ip_finish_output
+-    - ipv6: Don't use ufo handling on later transformed packets
+-    - udp: avoid ufo handling on IP payload compression packets
+-    - ipv6: Should use consistent conditional judgement for ip6 fragment between
+-      __ip6_append_data and ip6_finish_output
+-    - net: account for current skb length when deciding about UFO
+-    - udp: consistently apply ufo or fragmentation
+-
+-  * CVE-2017-1000111
+-    - net-packet: fix race in packet_set_ring on PACKET_RESERVE
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Mon, 07 Aug 2017 13:14:36 +0200
+-
+-linux (4.4.0-89.112) xenial; urgency=low
+-
+-  * CVE-2017-7533
+-    - dentry name snapshots
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Mon, 31 Jul 2017 14:50:32 -0300
+-
+-linux (4.4.0-88.111) xenial; urgency=low
+-
+-  * linux: 4.4.0-88.111 -proposed tracker (LP: #1705270)
+-
+-  * [Xenial] nvme: Quirks for PM1725 controllers (LP: #1704435)
+-    - nvme: Quirks for PM1725 controllers
+-
+-  * Upgrade Redpine WLAN/BT driver to ver. 1.2 (production release)
+-    (LP: #1697829)
+-    - SAUCE: Redpine: Upgrade to ver. 1.2 production release
+-
+-  * ubuntu/rsi driver has several issues as picked up by static analysis
+-    (LP: #1694733)
+-    - SAUCE: Redpine: Upgrade to ver. 1.2 production release
+-
+-  * Redpine vendor driver - Switching to AP mode causes kernel panic
+-    (LP: #1700941)
+-    - SAUCE: Redpine: Upgrade to ver. 1.2 production release
+-
+-  * CVE-2017-10810
+-    - drm/virtio: don't leak bo on drm_gem_object_init failure
+-
+-  * Ath10k to read different board data file if specify in SMBIOS (LP: #1666742)
+-    - ath10k: search SMBIOS for OEM board file extension
+-
+-  * make snap-pkg support (LP: #1700747)
+-    - SAUCE: make snap-pkg support
+-
+-  * ISST-LTE: Briggs:Stratton:UbuntuKVM:  ics_opal_set_affinity on host kernel
+-    log using Intel X710 (i40e driver) (LP: #1703663)
+-    - i40e: use valid online CPU on q_vector initialization
+-
+-  * Update snapcraft.yaml (LP: #1700480)
+-    - snapcraft.yaml: various improvements
+-
+-  * Xenial update to 4.4.76 stable release (LP: #1702863)
+-    - ipv6: release dst on error in ip6_dst_lookup_tail
+-    - net: don't call strlen on non-terminated string in dev_set_alias()
+-    - decnet: dn_rtmsg: Improve input length sanitization in
+-      dnrmg_receive_user_skb
+-    - net: Zero ifla_vf_info in rtnl_fill_vfinfo()
+-    - af_unix: Add sockaddr length checks before accessing sa_family in bind and
+-      connect handlers
+-    - Fix an intermittent pr_emerg warning about lo becoming free.
+-    - net: caif: Fix a sleep-in-atomic bug in cfpkt_create_pfx
+-    - igmp: acquire pmc lock for ip_mc_clear_src()
+-    - igmp: add a missing spin_lock_init()
+-    - ipv6: fix calling in6_ifa_hold incorrectly for dad work
+-    - net/mlx5: Wait for FW readiness before initializing command interface
+-    - decnet: always not take dst->__refcnt when inserting dst into hash table
+-    - net: 8021q: Fix one possible panic caused by BUG_ON in free_netdev
+-    - sfc: provide dummy definitions of vswitch functions
+-    - ipv6: Do not leak throw route references
+-    - rtnetlink: add IFLA_GROUP to ifla_policy
+-    - netfilter: xt_TCPMSS: add more sanity tests on tcph->doff
+-    - netfilter: synproxy: fix conntrackd interaction
+-    - NFSv4: fix a reference leak caused WARNING messages
+-    - drm/ast: Handle configuration without P2A bridge
+-    - mm, swap_cgroup: reschedule when neeed in swap_cgroup_swapoff()
+-    - MIPS: Avoid accidental raw backtrace
+-    - MIPS: pm-cps: Drop manual cache-line alignment of ready_count
+-    - MIPS: Fix IRQ tracing & lockdep when rescheduling
+-    - ALSA: hda - Fix endless loop of codec configure
+-    - ALSA: hda - set input_path bitmap to zero after moving it to new place
+-    - drm/vmwgfx: Free hash table allocated by cmdbuf managed res mgr
+-    - usb: gadget: f_fs: Fix possibe deadlock
+-    - sysctl: enable strict writes
+-    - mm: numa: avoid waiting on freed migrated pages
+-    - KVM: x86: fix fixing of hypercalls
+-    - scsi: sd: Fix wrong DPOFUA disable in sd_read_cache_type
+-    - scsi: lpfc: Set elsiocb contexts to NULL after freeing it
+-    - qla2xxx: Fix erroneous invalid handle message
+-    - ARM: dts: BCM5301X: Correct GIC_PPI interrupt flags
+-    - net: mvneta: Fix for_each_present_cpu usage
+-    - MIPS: ath79: fix regression in PCI window initialization
+-    - net: korina: Fix NAPI versus resources freeing
+-    - MIPS: ralink: MT7688 pinmux fixes
+-    - MIPS: ralink: fix USB frequency scaling
+-    - MIPS: ralink: Fix invalid assignment of SoC type
+-    - MIPS: ralink: fix MT7628 pinmux typos
+-    - MIPS: ralink: fix MT7628 wled_an pinmux gpio
+-    - mtd: bcm47xxpart: limit scanned flash area on BCM47XX (MIPS) only
+-    - bgmac: fix a missing check for build_skb
+-    - mtd: bcm47xxpart: don't fail because of bit-flips
+-    - bgmac: Fix reversed test of build_skb() return value.
+-    - net: bgmac: Fix SOF bit checking
+-    - net: bgmac: Start transmit queue in bgmac_open
+-    - net: bgmac: Remove superflous netif_carrier_on()
+-    - powerpc/eeh: Enable IO path on permanent error
+-    - gianfar: Do not reuse pages from emergency reserve
+-    - Btrfs: fix truncate down when no_holes feature is enabled
+-    - virtio_console: fix a crash in config_work_handler
+-    - swiotlb-xen: update dev_addr after swapping pages
+-    - xen-netfront: Fix Rx stall during network stress and OOM
+-    - scsi: virtio_scsi: Reject commands when virtqueue is broken
+-    - platform/x86: ideapad-laptop: handle ACPI event 1
+-    - amd-xgbe: Check xgbe_init() return code
+-    - net: dsa: Check return value of phy_connect_direct()
+-    - drm/amdgpu: check ring being ready before using
+-    - vfio/spapr: fail tce_iommu_attach_group() when iommu_data is null
+-    - virtio_net: fix PAGE_SIZE > 64k
+-    - vxlan: do not age static remote mac entries
+-    - ibmveth: Add a proper check for the availability of the checksum features
+-    - kernel/panic.c: add missing \n
+-    - HID: i2c-hid: Add sleep between POWER ON and RESET
+-    - scsi: lpfc: avoid double free of resource identifiers
+-    - spi: davinci: use dma_mapping_error()
+-    - mac80211: initialize SMPS field in HT capabilities
+-    - x86/mpx: Use compatible types in comparison to fix sparse error
+-    - coredump: Ensure proper size of sparse core files
+-    - swiotlb: ensure that page-sized mappings are page-aligned
+-    - s390/ctl_reg: make __ctl_load a full memory barrier
+-    - be2net: fix status check in be_cmd_pmac_add()
+-    - perf probe: Fix to show correct locations for events on modules
+-    - net/mlx4_core: Eliminate warning messages for SRQ_LIMIT under SRIOV
+-    - sctp: check af before verify address in sctp_addr_id2transport
+-    - ravb: Fix use-after-free on `ifconfig eth0 down`
+-    - jump label: fix passing kbuild_cflags when checking for asm goto support
+-    - xfrm: fix stack access out of bounds with CONFIG_XFRM_SUB_POLICY
+-    - xfrm: NULL dereference on allocation failure
+-    - xfrm: Oops on error in pfkey_msg2xfrm_state()
+-    - watchdog: bcm281xx: Fix use of uninitialized spinlock.
+-    - sched/loadavg: Avoid loadavg spikes caused by delayed NO_HZ accounting
+-    - ARM64/ACPI: Fix BAD_MADT_GICC_ENTRY() macro implementation
+-    - ARM: 8685/1: ensure memblock-limit is pmd-aligned
+-    - x86/mpx: Correctly report do_mpx_bt_fault() failures to user-space
+-    - x86/mm: Fix flush_tlb_page() on Xen
+-    - ocfs2: o2hb: revert hb threshold to keep compatible
+-    - iommu/vt-d: Don't over-free page table directories
+-    - iommu: Handle default domain attach failure
+-    - iommu/amd: Fix incorrect error handling in amd_iommu_bind_pasid()
+-    - cpufreq: s3c2416: double free on driver init error path
+-    - KVM: x86: fix emulation of RSM and IRET instructions
+-    - KVM: x86/vPMU: fix undefined shift in intel_pmu_refresh()
+-    - KVM: x86: zero base3 of unusable segments
+-    - KVM: nVMX: Fix exception injection
+-    - Linux 4.4.76
+-
+-  * Xenial update to 4.4.75 stable release (LP: #1702118)
+-    - fs/exec.c: account for argv/envp pointers
+-    - autofs: sanity check status reported with AUTOFS_DEV_IOCTL_FAIL
+-    - lib/cmdline.c: fix get_options() overflow while parsing ranges
+-    - KVM: PPC: Book3S HV: Preserve userspace HTM state properly
+-    - CIFS: Improve readdir verbosity
+-    - HID: Add quirk for Dell PIXART OEM mouse
+-    - signal: Only reschedule timers on signals timers have sent
+-    - powerpc/kprobes: Pause function_graph tracing during jprobes handling
+-    - Input: i8042 - add Fujitsu Lifebook AH544 to notimeout list
+-    - time: Fix clock->read(clock) race around clocksource changes
+-    - target: Fix kref->refcount underflow in transport_cmd_finish_abort
+-    - iscsi-target: Reject immediate data underflow larger than SCSI transfer
+-      length
+-    - drm/radeon: add a PX quirk for another K53TK variant
+-    - drm/radeon: add a quirk for Toshiba Satellite L20-183
+-    - drm/amdgpu/atom: fix ps allocation size for EnableDispPowerGating
+-    - drm/amdgpu: adjust default display clock
+-    - USB: usbip: fix nonconforming hub descriptor
+-    - rxrpc: Fix several cases where a padded len isn't checked in ticket decode
+-    - of: Add check to of_scan_flat_dt() before accessing initial_boot_params
+-    - mtd: spi-nor: fix spansion quad enable
+-    - powerpc/slb: Force a full SLB flush when we insert for a bad EA
+-    - usb: gadget: f_fs: avoid out of bounds access on comp_desc
+-    - net: phy: Initialize mdio clock at probe function
+-    - net: phy: fix marvell phy status reading
+-    - Linux 4.4.75
+-
+-  * Xenial update to 4.4.74 stable release (LP: #1702104)
+-    - configfs: Fix race between create_link and configfs_rmdir
+-    - can: gs_usb: fix memory leak in gs_cmd_reset()
+-    - cpufreq: conservative: Allow down_threshold to take values from 1 to 10
+-    - vb2: Fix an off by one error in 'vb2_plane_vaddr'
+-    - mac80211: don't look at the PM bit of BAR frames
+-    - mac80211/wpa: use constant time memory comparison for MACs
+-    - mac80211: fix CSA in IBSS mode
+-    - mac80211: fix IBSS presp allocation size
+-    - serial: efm32: Fix parity management in 'efm32_uart_console_get_options()'
+-    - x86/mm/32: Set the '__vmalloc_start_set' flag in initmem_init()
+-    - mfd: omap-usb-tll: Fix inverted bit use for USB TLL mode
+-    - staging: rtl8188eu: prevent an underflow in rtw_check_beacon_data()
+-    - iio: proximity: as3935: recalibrate RCO after resume
+-    - USB: hub: fix SS max number of ports
+-    - usb: core: fix potential memory leak in error path during hcd creation
+-    - pvrusb2: reduce stack usage pvr2_eeprom_analyze()
+-    - USB: gadget: dummy_hcd: fix hub-descriptor removable fields
+-    - usb: r8a66597-hcd: select a different endpoint on timeout
+-    - usb: r8a66597-hcd: decrease timeout
+-    - drivers/misc/c2port/c2port-duramar2150.c: checking for NULL instead of
+-      IS_ERR()
+-    - usb: xhci: ASMedia ASM1042A chipset need shorts TX quirk
+-    - USB: gadgetfs, dummy-hcd, net2280: fix locking for callbacks
+-    - mm/memory-failure.c: use compound_head() flags for huge pages
+-    - swap: cond_resched in swap_cgroup_prepare()
+-    - genirq: Release resources in __setup_irq() error path
+-    - alarmtimer: Prevent overflow of relative timers
+-    - usb: dwc3: exynos fix axius clock error path to do cleanup
+-    - MIPS: Fix bnezc/jialc return address calculation
+-    - alarmtimer: Rate limit periodic intervals
+-    - Linux 4.4.74
+-
+-  * Side Button (Display Toggle) fails on Dell AIO systems (LP: #1702541)
+-    - dell-wmi: Add a WMI event code for display on/off
+-
+-  * Intel i40e PF reset under load (LP: #1700834)
+-    - i40e/i40evf: Limit TSO to 7 descriptors for payload instead of 8 per packet
+-
+-  * update ENA driver to 1.2.0k from net-next (LP: #1701575)
+-    - net: ena: remove superfluous check in ena_remove()
+-    - net: ena: fix rare uncompleted admin command false alarm
+-    - net: ena: add missing return when ena_com_get_io_handlers() fails
+-    - net: ena: fix race condition between submit and completion admin command
+-    - net: ena: add missing unmap bars on device removal
+-    - net: ena: fix theoretical Rx hang on low memory systems
+-    - net: ena: disable admin msix while working in polling mode
+-    - net: ena: bug fix in lost tx packets detection mechanism
+-    - net: ena: update ena driver to version 1.1.7
+-    - net: ena: change return value for unsupported features unsupported return
+-      value
+-    - net: ena: add hardware hints capability to the driver
+-    - net: ena: change sizeof() argument to be the type pointer
+-    - net: ena: add reset reason for each device FLR
+-    - net: ena: add support for out of order rx buffers refill
+-    - net: ena: use napi_schedule_irqoff when possible
+-    - net: ena: separate skb allocation to dedicated function
+-    - net: ena: use lower_32_bits()/upper_32_bits() to split dma address
+-    - net: ena: update driver's rx drop statistics
+-    - net: ena: update ena driver to version 1.2.0
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Thu, 20 Jul 2017 09:25:21 +0200
+-
+-linux (4.4.0-87.110) xenial; urgency=low
+-
+-  * linux: 4.4.0-87.110 -proposed tracker (LP: #1704982)
+-
+-  * CVE-2017-1000364
+-    - mm/mmap.c: do not blow on PROT_NONE MAP_FIXED holes in the stack
+-    - mm/mmap.c: expand_downwards: don't require the gap if !vm_prev
+-
+-  * CIFS causes oops (LP: #1704857)
+-    - CIFS: Fix null pointer deref during read resp processing
+-    - CIFS: Fix some return values in case of error in 'crypt_message'
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Tue, 18 Jul 2017 13:58:43 +0200
+-
+-linux (4.4.0-86.109) xenial; urgency=low
+-
+-  * linux: 4.4.0-86.109 -proposed tracker (LP: #1703995)
+-
+-  * sock_recvmsg has dropped size argument (LP: #1701697)
+-    - Packaging: Breaks unfixed iscsitarget versions
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 12 Jul 2017 18:23:18 -0300
+-
+-linux (4.4.0-85.108) xenial; urgency=low
+-
+-  * linux: 4.4.0-85.108 -proposed tracker (LP: #1702103)
+-
+-  * [Hyper-V] Implement Hyper-V PTP Source (LP: #1676635)
+-    - SAUCE: hv: make clocksource available for PTP device supporting
+-    - Drivers: hv: util: Use hv_get_current_tick() to get current tick
+-    - hv_util: switch to using timespec64
+-    - hv_utils: implement Hyper-V PTP source
+-    - Drivers: hv: util: Fix a typo
+-    - Drivers: hv: util: don't forget to init host_ts.lock
+-    - hv_utils: drop .getcrosststamp() support from PTP driver
+-    - hv_utils: fix TimeSync work on pre-TimeSync-v4 hosts
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Mon, 03 Jul 2017 10:50:09 -0300
+-
+-linux (4.4.0-84.107) xenial; urgency=low
+-
+-  * linux: 4.4.0-84.107 -proposed tracker (LP: #1701024)
+-
+-  * Can't disable USB port from BIOS (LP: #1695216)
+-    - SAUCE: xhci: AMD Promontory USB disable port support
+-
+-  * KILLER1435-S[0489:e0a2] BT cannot search BT 4.0 device (LP: #1699651)
+-    - Bluetooth: btusb: Add support for 0489:e0a2 QCA_ROME device
+-
+-  * CIFS: Enable encryption for SMB3 (LP: #1670508)
+-    - Revert "Handle mismatched open calls"
+-    - Revert "Call echo service immediately after socket reconnect"
+-    - cifs: Make echo interval tunable
+-    - Prepare for encryption support (first part). Add decryption and encryption
+-      key generation. Thanks to Metze for helping with this.
+-    - [net] drop 'size' argument of sock_recvmsg()
+-    - cifs: merge the hash calculation helpers
+-    - cifs: no need to wank with copying and advancing iovec on recvmsg side
+-      either
+-    - cifs: don't bother with kmap on read_pages side
+-    - cifs_readv_receive: use cifs_read_from_socket()
+-    - Fix memory leaks in cifs_do_mount()
+-    - SMB3: Add mount parameter to allow user to override max credits
+-    - SMB2: Separate Kerberos authentication from SMB2_sess_setup
+-    - SMB2: Separate RawNTLMSSP authentication from SMB2_sess_setup
+-    - SMB3: parsing for new snapshot timestamp mount parm
+-    - cifs: Simplify SMB2 and SMB311 dependencies
+-    - cifs: Only select the required crypto modules
+-    - cifs: Add soft dependencies
+-    - CIFS: Separate SMB2 header structure
+-    - CIFS: Make SendReceive2() takes resp iov
+-    - CIFS: Make send_cancel take rqst as argument
+-    - CIFS: Send RFC1001 length in a separate iov
+-    - CIFS: Separate SMB2 sync header processing
+-    - CIFS: Separate RFC1001 length processing for SMB2 read
+-    - CIFS: Add capability to transform requests before sending
+-    - CIFS: Enable encryption during session setup phase
+-    - CIFS: Encrypt SMB3 requests before sending
+-    - CIFS: Add transform header handling callbacks
+-    - CIFS: Add mid handle callback
+-    - CIFS: Add copy into pages callback for a read operation
+-    - CIFS: Decrypt and process small encrypted packets
+-    - CIFS: Add capability to decrypt big read responses
+-    - CIFS: Allow to switch on encryption with seal mount option
+-    - CIFS: Fix possible use after free in demultiplex thread
+-    - Call echo service immediately after socket reconnect
+-    - Handle mismatched open calls
+-
+-  * CVE-2017-9150
+-    - bpf: don't let ldimm64 leak map addresses on unprivileged
+-
+-  * CVE-2015-8944
+-    - Make file credentials available to the seqfile interfaces
+-    - /proc/iomem: only expose physical resource addresses to privileged users
+-
+-  * Xenial update to 4.4.73 stable release (LP: #1698817)
+-    - s390/vmem: fix identity mapping
+-    - partitions/msdos: FreeBSD UFS2 file systems are not recognized
+-    - ARM: dts: imx6dl: Fix the VDD_ARM_CAP voltage for 396MHz operation
+-    - staging: rtl8192e: rtl92e_fill_tx_desc fix write to mapped out memory.
+-    - net: xilinx_emaclite: fix freezes due to unordered I/O
+-    - net: xilinx_emaclite: fix receive buffer overflow
+-    - ipv6: Handle IPv4-mapped src to in6addr_any dst.
+-    - ipv6: Inhibit IPv4-mapped src address on the wire.
+-    - NET: Fix /proc/net/arp for AX.25
+-    - NET: mkiss: Fix panic
+-    - net: hns: Fix the device being used for dma mapping during TX
+-    - sierra_net: Skip validating irrelevant fields for IDLE LSIs
+-    - sierra_net: Add support for IPv6 and Dual-Stack Link Sense Indications
+-    - i2c: piix4: Fix request_region size
+-    - ipv6: Fix IPv6 packet loss in scenarios involving roaming + snooping
+-      switches
+-    - PM / runtime: Avoid false-positive warnings from might_sleep_if()
+-    - jump label: pass kbuild_cflags when checking for asm goto support
+-    - kasan: respect /proc/sys/kernel/traceoff_on_warning
+-    - log2: make order_base_2() behave correctly on const input value zero
+-    - ethtool: do not vzalloc(0) on registers dump
+-    - fscache: Fix dead object requeue
+-    - fscache: Clear outstanding writes when disabling a cookie
+-    - FS-Cache: Initialise stores_lock in netfs cookie
+-    - ipv6: fix flow labels when the traffic class is non-0
+-    - drm/nouveau: prevent userspace from deleting client object
+-    - drm/nouveau/fence/g84-: protect against concurrent access to semaphore
+-      buffers
+-    - gianfar: synchronize DMA API usage by free_skb_rx_queue w/ gfar_new_page
+-    - pinctrl: berlin-bg4ct: fix the value for "sd1a" of pin SCRD0_CRD_PRES
+-    - net: adaptec: starfire: add checks for dma mapping errors
+-    - parisc, parport_gsc: Fixes for printk continuation lines
+-    - drm/nouveau: Don't enabling polling twice on runtime resume
+-    - drm/ast: Fixed system hanged if disable P2A
+-    - ravb: unmap descriptors when freeing rings
+-    - nfs: Fix "Don't increment lock sequence ID after NFS4ERR_MOVED"
+-    - r8152: re-schedule napi for tx
+-    - r8152: fix rtl8152_post_reset function
+-    - r8152: avoid start_xmit to schedule napi when napi is disabled
+-    - sctp: sctp_addr_id2transport should verify the addr before looking up assoc
+-    - romfs: use different way to generate fsid for BLOCK or MTD
+-    - proc: add a schedule point in proc_pid_readdir()
+-    - tipc: ignore requests when the connection state is not CONNECTED
+-    - xtensa: don't use linux IRQ #0
+-    - s390/kvm: do not rely on the ILC on kvm host protection fauls
+-    - sparc64: make string buffers large enough
+-    - Linux 4.4.73
+-
+-  * Xenial update to 4.4.72 stable release (LP: #1698799)
+-    - bnx2x: Fix Multi-Cos
+-    - ipv6: xfrm: Handle errors reported by xfrm6_find_1stfragopt()
+-    - cxgb4: avoid enabling napi twice to the same queue
+-    - tcp: disallow cwnd undo when switching congestion control
+-    - vxlan: fix use-after-free on deletion
+-    - ipv6: Fix leak in ipv6_gso_segment().
+-    - net: ping: do not abuse udp_poll()
+-    - net: ethoc: enable NAPI before poll may be scheduled
+-    - net: bridge: start hello timer only if device is up
+-    - sparc64: mm: fix copy_tsb to correctly copy huge page TSBs
+-    - sparc: Machine description indices can vary
+-    - sparc64: reset mm cpumask after wrap
+-    - sparc64: combine activate_mm and switch_mm
+-    - sparc64: redefine first version
+-    - sparc64: add per-cpu mm of secondary contexts
+-    - sparc64: new context wrap
+-    - sparc64: delete old wrap code
+-    - arch/sparc: support NR_CPUS = 4096
+-    - serial: ifx6x60: fix use-after-free on module unload
+-    - ptrace: Properly initialize ptracer_cred on fork
+-    - KEYS: fix dereferencing NULL payload with nonzero length
+-    - KEYS: fix freeing uninitialized memory in key_update()
+-    - crypto: gcm - wait for crypto op not signal safe
+-    - drm/amdgpu/ci: disable mclk switching for high refresh rates (v2)
+-    - nfsd4: fix null dereference on replay
+-    - nfsd: Fix up the "supattr_exclcreat" attributes
+-    - kvm: async_pf: fix rcu_irq_enter() with irqs enabled
+-    - KVM: cpuid: Fix read/write out-of-bounds vulnerability in cpuid emulation
+-    - arm: KVM: Allow unaligned accesses at HYP
+-    - KVM: async_pf: avoid async pf injection when in guest mode
+-    - dmaengine: usb-dmac: Fix DMAOR AE bit definition
+-    - dmaengine: ep93xx: Always start from BASE0
+-    - xen/privcmd: Support correctly 64KB page granularity when mapping memory
+-    - xen-netfront: do not cast grant table reference to signed short
+-    - xen-netfront: cast grant table reference first to type int
+-    - ext4: fix SEEK_HOLE
+-    - ext4: keep existing extra fields when inode expands
+-    - ext4: fix fdatasync(2) after extent manipulation operations
+-    - usb: gadget: f_mass_storage: Serialize wake and sleep execution
+-    - usb: chipidea: udc: fix NULL pointer dereference if udc_start failed
+-    - usb: chipidea: debug: check before accessing ci_role
+-    - staging/lustre/lov: remove set_fs() call from lov_getstripe()
+-    - iio: light: ltr501 Fix interchanged als/ps register field
+-    - iio: proximity: as3935: fix AS3935_INT mask
+-    - drivers: char: random: add get_random_long()
+-    - random: properly align get_random_int_hash
+-    - stackprotector: Increase the per-task stack canary's random range from 32
+-      bits to 64 bits on 64-bit platforms
+-    - cpufreq: cpufreq_register_driver() should return -ENODEV if init fails
+-    - target: Re-add check to reject control WRITEs with overflow data
+-    - drm/msm: Expose our reservation object when exporting a dmabuf.
+-    - Input: elantech - add Fujitsu Lifebook E546/E557 to force crc_enabled
+-    - cpuset: consider dying css as offline
+-    - fs: add i_blocksize()
+-    - ufs: restore proper tail allocation
+-    - fix ufs_isblockset()
+-    - ufs: restore maintaining ->i_blocks
+-    - ufs: set correct ->s_maxsize
+-    - ufs_extend_tail(): fix the braino in calling conventions of
+-      ufs_new_fragments()
+-    - ufs_getfrag_block(): we only grab ->truncate_mutex on block creation path
+-    - cxl: Fix error path on bad ioctl
+-    - btrfs: use correct types for page indices in btrfs_page_exists_in_range
+-    - btrfs: fix memory leak in update_space_info failure path
+-    - KVM: arm/arm64: Handle possible NULL stage2 pud when ageing pages
+-    - scsi: qla2xxx: don't disable a not previously enabled PCI device
+-    - powerpc/eeh: Avoid use after free in eeh_handle_special_event()
+-    - powerpc/numa: Fix percpu allocations to be NUMA aware
+-    - powerpc/hotplug-mem: Fix missing endian conversion of aa_index
+-    - perf/core: Drop kernel samples even though :u is specified
+-    - drm/vmwgfx: Handle vmalloc() failure in vmw_local_fifo_reserve()
+-    - drm/vmwgfx: Make sure backup_handle is always valid
+-    - drm/nouveau/tmr: fully separate alarm execution/pending lists
+-    - ALSA: timer: Fix race between read and ioctl
+-    - ALSA: timer: Fix missing queue indices reset at SNDRV_TIMER_IOCTL_SELECT
+-    - ASoC: Fix use-after-free at card unregistration
+-    - drivers: char: mem: Fix wraparound check to allow mappings up to the end
+-    - tty: Drop krefs for interrupted tty lock
+-    - serial: sh-sci: Fix panic when serial console and DMA are enabled
+-    - mm: consider memblock reservations for deferred memory initialization sizing
+-    - NFS: Ensure we revalidate attributes before using execute_ok()
+-    - NFSv4: Don't perform cached access checks before we've OPENed the file
+-    - Make __xfs_xattr_put_listen preperly report errors.
+-    - arm64: hw_breakpoint: fix watchpoint matching for tagged pointers
+-    - arm64: entry: improve data abort handling of tagged pointers
+-    - RDMA/qib,hfi1: Fix MR reference count leak on write with immediate
+-    - usercopy: Adjust tests to deal with SMAP/PAN
+-    - arm64: armv8_deprecated: ensure extension of addr
+-    - arm64: ensure extension of smp_store_release value
+-    - Linux 4.4.72
+-
+-  * Xenial update to 4.4.71 stable release (LP: #1697001)
+-    - sparc: Fix -Wstringop-overflow warning
+-    - s390/qeth: handle sysfs error during initialization
+-    - s390/qeth: unbreak OSM and OSN support
+-    - s390/qeth: avoid null pointer dereference on OSN
+-    - tcp: avoid fragmenting peculiar skbs in SACK
+-    - sctp: fix src address selection if using secondary addresses for ipv6
+-    - tcp: eliminate negative reordering in tcp_clean_rtx_queue
+-    - net: Improve handling of failures on link and route dumps
+-    - bridge: netlink: check vlan_default_pvid range
+-    - qmi_wwan: add another Lenovo EM74xx device ID
+-    - bridge: start hello_timer when enabling KERNEL_STP in br_stp_start
+-    - be2net: Fix offload features for Q-in-Q packets
+-    - virtio-net: enable TSO/checksum offloads for Q-in-Q vlans
+-    - tcp: avoid fastopen API to be used on AF_UNSPEC
+-    - sctp: fix ICMP processing if skb is non-linear
+-    - ipv4: add reference counting to metrics
+-    - netem: fix skb_orphan_partial()
+-    - net: phy: marvell: Limit errata to 88m1101
+-    - vlan: Fix tcp checksum offloads in Q-in-Q vlans
+-    - i2c: i2c-tiny-usb: fix buffer not being DMA capable
+-    - mmc: sdhci-iproc: suppress spurious interrupt with Multiblock read
+-    - HID: wacom: Have wacom_tpc_irq guard against possible NULL dereference
+-    - scsi: mpt3sas: Force request partial completion alignment
+-    - drm/radeon/ci: disable mclk switching for high refresh rates (v2)
+-    - drm/radeon: Unbreak HPD handling for r600+
+-    - pcmcia: remove left-over %Z format
+-    - ALSA: hda - apply STAC_9200_DELL_M22 quirk for Dell Latitude D430
+-    - slub/memcg: cure the brainless abuse of sysfs attributes
+-    - drm/gma500/psb: Actually use VBT mode when it is found
+-    - mm/migrate: fix refcount handling when !hugepage_migration_supported()
+-    - mlock: fix mlock count can not decrease in race condition
+-    - xfs: Fix missed holes in SEEK_HOLE implementation
+-    - xfs: fix off-by-one on max nr_pages in xfs_find_get_desired_pgoff()
+-    - xfs: fix over-copying of getbmap parameters from userspace
+-    - xfs: handle array index overrun in xfs_dir2_leaf_readbuf()
+-    - xfs: prevent multi-fsb dir readahead from reading random blocks
+-    - xfs: fix up quotacheck buffer list error handling
+-    - xfs: support ability to wait on new inodes
+-    - xfs: update ag iterator to support wait on new inodes
+-    - xfs: wait on new inodes during quotaoff dquot release
+-    - xfs: fix indlen accounting error on partial delalloc conversion
+-    - xfs: bad assertion for delalloc an extent that start at i_size
+-    - xfs: fix unaligned access in xfs_btree_visit_blocks
+-    - xfs: in _attrlist_by_handle, copy the cursor back to userspace
+-    - xfs: only return -errno or success from attr ->put_listent
+-    - Linux 4.4.71
+-
+-  * CVE-2017-7346
+-    - drm/vmwgfx: limit the number of mip levels in vmw_gb_surface_define_ioctl()
+-
+-  * Power button does not work on Latitude 7480 (LP: #1697116)
+-    - intel-hid: Remove duplicated acpi_remove_notify_handler
+-    - platform/x86: intel-hid: Support 5 button array
+-
+-  * CVE-2017-9074
+-    - ipv6: Check ip6_find_1stfragopt() return value properly.
+-
+-  * CVE-2014-9900
+-    - net: Zeroing the structure ethtool_wolinfo in ethtool_get_wol()
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 28 Jun 2017 14:47:02 -0300
+-
+-linux (4.4.0-83.106) xenial; urgency=low
+-
+-  * linux: 4.4.0-83.106 -proposed tracker (LP: #1700541)
+-
+-  * CVE-2017-1000364
+-    - Revert "UBUNTU: SAUCE: mm: Only expand stack if guard area is hit"
+-    - Revert "mm: do not collapse stack gap into THP"
+-    - Revert "mm: enlarge stack guard gap"
+-    - mm: vma_adjust: remove superfluous confusing update in remove_next == 1 case
+-    - mm: larger stack guard gap, between vmas
+-    - mm: fix new crash in unmapped_area_topdown()
+-    - Allow stack to grow up to address space limit
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Mon, 26 Jun 2017 12:27:55 -0300
+-
+-linux (4.4.0-82.105) xenial; urgency=low
+-
+-  * linux: 4.4.0-82.105 -proposed tracker (LP: #1699064)
+-
+-  * CVE-2017-1000364
+-    - SAUCE: mm: Only expand stack if guard area is hit
+-
+-  * linux-aws/linux-gke incorrectly producing and using linux-*-tools-
+-    common/linux-*-cloud-tools-common (LP: #1688579)
+-    - [Config] make linux-tools-common and linux-cloud-tools-common protection
+-      consistent
+-
+-  * CVE-2017-9242
+-    - ipv6: fix out of bound writes in __ip6_append_data()
+-
+-  * CVE-2017-9075
+-    - sctp: do not inherit ipv6_{mc|ac|fl}_list from parent
+-
+-  * CVE-2017-9074
+-    - ipv6: Prevent overrun when parsing v6 header options
+-
+-  * CVE-2017-9076
+-    - ipv6/dccp: do not inherit ipv6_mc_list from parent
+-
+-  * CVE-2017-9077
+-    - ipv6/dccp: do not inherit ipv6_mc_list from parent
+-
+-  * CVE-2017-8890
+-    - dccp/tcp: do not inherit mc_list from parent
+-
+-  * Module signing exclusion for staging drivers does not work properly
+-    (LP: #1690908)
+-    - SAUCE: Fix module signing exclusion in package builds
+-
+-  * extend-diff-ignore should use exact matches (LP: #1693504)
+-    - [Packaging] exact extend-diff-ignore matches
+-
+-  * Dell XPS 9360 wifi 5G performance is poor (LP: #1692836)
+-    - SAUCE: ath10k: fix the wifi speed issue for kill 1535
+-
+-  *  Upgrade Redpine WLAN/BT driver to ver. 1.2.RC12 (LP: #1694607)
+-    - SAUCE: Redpine: Upgrade to ver. 1.2.RC12
+-
+-  * [DP MST] No audio output through HDMI/DP/mDP ports in Dell WD15 and TB15
+-    docking stations (LP: #1694665)
+-    - drm/i915: Store port enum in intel_encoder
+-    - drm/i915: Eliminate redundant local variable definition
+-    - drm/i915: Switch to using port stored in intel_encoder
+-    - drm/i915: Move audio_connector to intel_encoder
+-    - drm/i915/dp: DP audio API changes for MST
+-    - drm/i915: abstract ddi being audio enabled
+-    - drm/i915/audio: extend get_saved_enc() to support more scenarios
+-    - drm/i915: enable dp mst audio
+-
+-  * Xenial update to 4.4.70 stable release (LP: #1694621)
+-    - usb: misc: legousbtower: Fix buffers on stack
+-    - usb: misc: legousbtower: Fix memory leak
+-    - USB: ene_usb6250: fix DMA to the stack
+-    - watchdog: pcwd_usb: fix NULL-deref at probe
+-    - char: lp: fix possible integer overflow in lp_setup()
+-    - USB: core: replace %p with %pK
+-    - ARM: tegra: paz00: Mark panel regulator as enabled on boot
+-    - tpm_crb: check for bad response size
+-    - infiniband: call ipv6 route lookup via the stub interface
+-    - dm btree: fix for dm_btree_find_lowest_key()
+-    - dm raid: select the Kconfig option CONFIG_MD_RAID0
+-    - dm bufio: avoid a possible ABBA deadlock
+-    - dm bufio: check new buffer allocation watermark every 30 seconds
+-    - dm cache metadata: fail operations if fail_io mode has been established
+-    - dm bufio: make the parameter "retain_bytes" unsigned long
+-    - dm thin metadata: call precommit before saving the roots
+-    - dm space map disk: fix some book keeping in the disk space map
+-    - md: update slab_cache before releasing new stripes when stripes resizing
+-    - rtlwifi: rtl8821ae: setup 8812ae RFE according to device type
+-    - mwifiex: pcie: fix cmd_buf use-after-free in remove/reset
+-    - ima: accept previously set IMA_NEW_FILE
+-    - KVM: x86: Fix load damaged SSEx MXCSR register
+-    - KVM: X86: Fix read out-of-bounds vulnerability in kvm pio emulation
+-    - regulator: tps65023: Fix inverted core enable logic.
+-    - s390/kdump: Add final note
+-    - s390/cputime: fix incorrect system time
+-    - ath9k_htc: Add support of AirTies 1eda:2315 AR9271 device
+-    - ath9k_htc: fix NULL-deref at probe
+-    - drm/amdgpu: Avoid overflows/divide-by-zero in latency_watermark
+-      calculations.
+-    - drm/amdgpu: Make display watermark calculations more accurate
+-    - drm/nouveau/therm: remove ineffective workarounds for alarm bugs
+-    - drm/nouveau/tmr: ack interrupt before processing alarms
+-    - drm/nouveau/tmr: fix corruption of the pending list when rescheduling an
+-      alarm
+-    - drm/nouveau/tmr: avoid processing completed alarms when adding a new one
+-    - drm/nouveau/tmr: handle races with hw when updating the next alarm time
+-    - cdc-acm: fix possible invalid access when processing notification
+-    - proc: Fix unbalanced hard link numbers
+-    - of: fix sparse warning in of_pci_range_parser_one
+-    - iio: dac: ad7303: fix channel description
+-    - pid_ns: Sleep in TASK_INTERRUPTIBLE in zap_pid_ns_processes
+-    - pid_ns: Fix race between setns'ed fork() and zap_pid_ns_processes()
+-    - USB: serial: ftdi_sio: fix setting latency for unprivileged users
+-    - USB: serial: ftdi_sio: add Olimex ARM-USB-TINY(H) PIDs
+-    - ext4 crypto: don't let data integrity writebacks fail with ENOMEM
+-    - ext4 crypto: fix some error handling
+-    - net: qmi_wwan: Add SIMCom 7230E
+-    - fscrypt: fix context consistency check when key(s) unavailable
+-    - f2fs: check entire encrypted bigname when finding a dentry
+-    - fscrypt: avoid collisions when presenting long encrypted filenames
+-    - usb: host: xhci-plat: propagate return value of platform_get_irq()
+-    - xhci: apply PME_STUCK_QUIRK and MISSING_CAS quirk for Denverton
+-    - usb: host: xhci-mem: allocate zeroed Scratchpad Buffer
+-    - net: irda: irda-usb: fix firmware name on big-endian hosts
+-    - usbvision: fix NULL-deref at probe
+-    - mceusb: fix NULL-deref at probe
+-    - ttusb2: limit messages to buffer size
+-    - usb: musb: tusb6010_omap: Do not reset the other direction's packet size
+-    - USB: iowarrior: fix info ioctl on big-endian hosts
+-    - usb: serial: option: add Telit ME910 support
+-    - USB: serial: qcserial: add more Lenovo EM74xx device IDs
+-    - USB: serial: mct_u232: fix big-endian baud-rate handling
+-    - USB: serial: io_ti: fix div-by-zero in set_termios
+-    - USB: hub: fix SS hub-descriptor handling
+-    - USB: hub: fix non-SS hub-descriptor handling
+-    - ipx: call ipxitf_put() in ioctl error path
+-    - iio: proximity: as3935: fix as3935_write
+-    - ceph: fix recursion between ceph_set_acl() and __ceph_setattr()
+-    - gspca: konica: add missing endpoint sanity check
+-    - s5p-mfc: Fix unbalanced call to clock management
+-    - dib0700: fix NULL-deref at probe
+-    - zr364xx: enforce minimum size when reading header
+-    - dvb-frontends/cxd2841er: define symbol_rate_min/max in T/C fe-ops
+-    - cx231xx-audio: fix init error path
+-    - cx231xx-audio: fix NULL-deref at probe
+-    - cx231xx-cards: fix NULL-deref at probe
+-    - powerpc/book3s/mce: Move add_taint() later in virtual mode
+-    - powerpc/pseries: Fix of_node_put() underflow during DLPAR remove
+-    - powerpc/64e: Fix hang when debugging programs with relocated kernel
+-    - ARM: dts: at91: sama5d3_xplained: fix ADC vref
+-    - ARM: dts: at91: sama5d3_xplained: not all ADC channels are available
+-    - arm64: xchg: hazard against entire exchange variable
+-    - arm64: uaccess: ensure extension of access_ok() addr
+-    - arm64: documentation: document tagged pointer stack constraints
+-    - xc2028: Fix use-after-free bug properly
+-    - Revert "UBUNTU: SAUCE: mm: Respect FOLL_FORCE/FOLL_COW for thp"
+-    - mm/huge_memory.c: respect FOLL_FORCE/FOLL_COW for thp
+-    - staging: rtl8192e: fix 2 byte alignment of register BSSIDR.
+-    - staging: rtl8192e: rtl92e_get_eeprom_size Fix read size of EPROM_CMD.
+-    - iommu/vt-d: Flush the IOTLB to get rid of the initial kdump mappings
+-    - metag/uaccess: Fix access_ok()
+-    - metag/uaccess: Check access_ok in strncpy_from_user
+-    - uwb: fix device quirk on big-endian hosts
+-    - genirq: Fix chained interrupt data ordering
+-    - osf_wait4(): fix infoleak
+-    - tracing/kprobes: Enforce kprobes teardown after testing
+-    - PCI: Fix pci_mmap_fits() for HAVE_PCI_RESOURCE_TO_USER platforms
+-    - PCI: Freeze PME scan before suspending devices
+-    - drm/edid: Add 10 bpc quirk for LGD 764 panel in HP zBook 17 G2
+-    - nfsd: encoders mustn't use unitialized values in error cases
+-    - drivers: char: mem: Check for address space wraparound with mmap()
+-    - Linux 4.4.70
+-
+-  * Xenial update to 4.4.69 stable release (LP: #1692900)
+-    - xen: adjust early dom0 p2m handling to xen hypervisor behavior
+-    - target: Fix compare_and_write_callback handling for non GOOD status
+-    - target/fileio: Fix zero-length READ and WRITE handling
+-    - target: Convert ACL change queue_depth se_session reference usage
+-    - iscsi-target: Set session_fall_back_to_erl0 when forcing reinstatement
+-    - usb: host: xhci: print correct command ring address
+-    - USB: serial: ftdi_sio: add device ID for Microsemi/Arrow SF2PLUS Dev Kit
+-    - USB: Proper handling of Race Condition when two USB class drivers try to
+-      call init_usb_class simultaneously
+-    - staging: vt6656: use off stack for in buffer USB transfers.
+-    - staging: vt6656: use off stack for out buffer USB transfers.
+-    - staging: gdm724x: gdm_mux: fix use-after-free on module unload
+-    - staging: comedi: jr3_pci: fix possible null pointer dereference
+-    - staging: comedi: jr3_pci: cope with jiffies wraparound
+-    - usb: misc: add missing continue in switch
+-    - usb: Make sure usb/phy/of gets built-in
+-    - usb: hub: Fix error loop seen after hub communication errors
+-    - usb: hub: Do not attempt to autosuspend disconnected devices
+-    - x86/boot: Fix BSS corruption/overwrite bug in early x86 kernel startup
+-    - selftests/x86/ldt_gdt_32: Work around a glibc sigaction() bug
+-    - x86, pmem: Fix cache flushing for iovec write < 8 bytes
+-    - um: Fix PTRACE_POKEUSER on x86_64
+-    - KVM: x86: fix user triggerable warning in kvm_apic_accept_events()
+-    - KVM: arm/arm64: fix races in kvm_psci_vcpu_on
+-    - block: fix blk_integrity_register to use template's interval_exp if not 0
+-    - crypto: algif_aead - Require setkey before accept(2)
+-    - dm era: save spacemap metadata root after the pre-commit
+-    - vfio/type1: Remove locked page accounting workqueue
+-    - IB/core: Fix sysfs registration error flow
+-    - IB/IPoIB: ibX: failed to create mcg debug file
+-    - IB/mlx4: Fix ib device initialization error flow
+-    - IB/mlx4: Reduce SRIOV multicast cleanup warning message to debug level
+-    - ext4: evict inline data when writing to memory map
+-    - fs/xattr.c: zero out memory copied to userspace in getxattr
+-    - ceph: fix memory leak in __ceph_setxattr()
+-    - fs/block_dev: always invalidate cleancache in invalidate_bdev()
+-    - Set unicode flag on cifs echo request to avoid Mac error
+-    - SMB3: Work around mount failure when using SMB3 dialect to Macs
+-    - CIFS: fix mapping of SFM_SPACE and SFM_PERIOD
+-    - cifs: fix CIFS_IOC_GET_MNT_INFO oops
+-    - CIFS: add misssing SFM mapping for doublequote
+-    - padata: free correct variable
+-    - arm64: KVM: Fix decoding of Rt/Rt2 when trapping AArch32 CP accesses
+-    - serial: samsung: Use right device for DMA-mapping calls
+-    - serial: omap: fix runtime-pm handling on unbind
+-    - serial: omap: suspend device on probe errors
+-    - tty: pty: Fix ldisc flush after userspace become aware of the data already
+-    - Bluetooth: Fix user channel for 32bit userspace on 64bit kernel
+-    - Bluetooth: hci_bcm: add missing tty-device sanity check
+-    - Bluetooth: hci_intel: add missing tty-device sanity check
+-    - mac80211: pass RX aggregation window size to driver
+-    - mac80211: pass block ack session timeout to to driver
+-    - mac80211: RX BA support for sta max_rx_aggregation_subframes
+-    - wlcore: Pass win_size taken from ieee80211_sta to FW
+-    - wlcore: Add RX_BA_WIN_SIZE_CHANGE_EVENT event
+-    - ipmi: Fix kernel panic at ipmi_ssif_thread()
+-    - Linux 4.4.69
+-
+-  * Support IPMI system interface on Cavium ThunderX (LP: #1688132)
+-    - i2c: octeon: Cleanup kerneldoc comments
+-    - i2c: octeon: Cleanup i2c-octeon driver
+-    - i2c: octeon: Cleanup resource allocation code
+-    - i2c: octeon: Support I2C_M_RECV_LEN
+-    - i2c: octeon: Increase retry default and use fixed timeout value
+-    - i2c: octeon: Move set-clock and init-lowlevel upward
+-    - i2c: octeon: Rename [read|write]_sw to reg_[read|write]
+-    - i2c: octeon: Introduce helper functions for register access
+-    - i2c: octeon: Remove superfluous check in octeon_i2c_test_iflg
+-    - i2c: octeon: Improve error status checking
+-    - i2c: octeon: Use i2c recovery framework
+-    - i2c: octeon: Add flush writeq helper function
+-    - i2c: octeon: Enable High-Level Controller
+-    - i2c: octeon: Add support for cn78xx chips
+-    - i2c: octeon: Remove zero-length message support
+-    - i2c: octeon: Improve performance if interrupt is early
+-    - i2c: octeon: Add workaround for broken irqs on CN3860
+-    - i2c: octeon: Missing AAK flag in case of I2C_M_RECV_LEN
+-    - i2c: octeon: Avoid printk after too long SMBUS message
+-    - i2c: octeon: Rename driver to prepare for split
+-    - i2c: octeon: Split the driver into two parts
+-    - [Config] CONFIG_I2C_THUNDERX=m
+-    - i2c: thunderx: Add i2c driver for ThunderX SOC
+-    - i2c: thunderx: Add SMBUS alert support
+-    - i2c: octeon,thunderx: Move register offsets to struct
+-    - i2c: octeon: Sort include files alphabetically
+-    - i2c: octeon: Use booleon values for booleon variables
+-    - i2c: octeon: thunderx: Add MAINTAINERS entry
+-    - i2c: octeon: Fix set SCL recovery function
+-    - i2c: octeon: Avoid sending STOP during recovery
+-    - i2c: octeon: Fix high-level controller status check
+-    - i2c: octeon: thunderx: TWSI software reset in recovery
+-    - i2c: octeon: thunderx: Remove double-check after interrupt
+-    - i2c: octeon: thunderx: Limit register access retries
+-    - i2c: thunderx: Enable HWMON class probing
+-
+-  * Xenial update to 4.4.68 stable release (LP: #1691418)
+-    - 9p: fix a potential acl leak
+-    - ARM: 8452/3: PJ4: make coprocessor access sequences buildable in Thumb2 mode
+-    - cpupower: Fix turbo frequency reporting for pre-Sandy Bridge cores
+-    - powerpc/powernv: Fix opal_exit tracepoint opcode
+-    - power: supply: bq24190_charger: Fix irq trigger to IRQF_TRIGGER_FALLING
+-    - power: supply: bq24190_charger: Call set_mode_host() on pm_resume()
+-    - power: supply: bq24190_charger: Install irq_handler_thread() at end of
+-      probe()
+-    - power: supply: bq24190_charger: Call power_supply_changed() for relevant
+-      component
+-    - power: supply: bq24190_charger: Don't read fault register outside
+-      irq_handle_thread()
+-    - power: supply: bq24190_charger: Handle fault before status on interrupt
+-    - leds: ktd2692: avoid harmless maybe-uninitialized warning
+-    - ARM: OMAP5 / DRA7: Fix HYP mode boot for thumb2 build
+-    - mwifiex: debugfs: Fix (sometimes) off-by-1 SSID print
+-    - mwifiex: remove redundant dma padding in AMSDU
+-    - mwifiex: Avoid skipping WEP key deletion for AP
+-    - x86/ioapic: Restore IO-APIC irq_chip retrigger callback
+-    - x86/pci-calgary: Fix iommu_free() comparison of unsigned expression >= 0
+-    - clk: Make x86/ conditional on CONFIG_COMMON_CLK
+-    - kprobes/x86: Fix kernel panic when certain exception-handling addresses are
+-      probed
+-    - x86/platform/intel-mid: Correct MSI IRQ line for watchdog device
+-    - Revert "KVM: nested VMX: disable perf cpuid reporting"
+-    - KVM: nVMX: initialize PML fields in vmcs02
+-    - KVM: nVMX: do not leak PML full vmexit to L1
+-    - usb: host: ehci-exynos: Decrese node refcount on exynos_ehci_get_phy() error
+-      paths
+-    - usb: host: ohci-exynos: Decrese node refcount on exynos_ehci_get_phy() error
+-      paths
+-    - usb: chipidea: Only read/write OTGSC from one place
+-    - usb: chipidea: Handle extcon events properly
+-    - USB: serial: keyspan_pda: fix receive sanity checks
+-    - USB: serial: digi_acceleport: fix incomplete rx sanity check
+-    - USB: serial: ssu100: fix control-message error handling
+-    - USB: serial: io_edgeport: fix epic-descriptor handling
+-    - USB: serial: ti_usb_3410_5052: fix control-message error handling
+-    - USB: serial: ark3116: fix open error handling
+-    - USB: serial: ftdi_sio: fix latency-timer error handling
+-    - USB: serial: quatech2: fix control-message error handling
+-    - USB: serial: mct_u232: fix modem-status error handling
+-    - USB: serial: io_edgeport: fix descriptor error handling
+-    - phy: qcom-usb-hs: Add depends on EXTCON
+-    - serial: 8250_omap: Fix probe and remove for PM runtime
+-    - scsi: mac_scsi: Fix MAC_SCSI=m option when SCSI=m
+-    - MIPS: R2-on-R6 MULTU/MADDU/MSUBU emulation bugfix
+-    - brcmfmac: Ensure pointer correctly set if skb data location changes
+-    - brcmfmac: Make skb header writable before use
+-    - staging: wlan-ng: add missing byte order conversion
+-    - staging: emxx_udc: remove incorrect __init annotations
+-    - ALSA: hda - Fix deadlock of controller device lock at unbinding
+-    - tcp: do not underestimate skb->truesize in tcp_trim_head()
+-    - bpf, arm64: fix jit branch offset related to ldimm64
+-    - tcp: fix wraparound issue in tcp_lp
+-    - tcp: do not inherit fastopen_req from parent
+-    - ipv4, ipv6: ensure raw socket message is big enough to hold an IP header
+-    - rtnetlink: NUL-terminate IFLA_PHYS_PORT_NAME string
+-    - ipv6: initialize route null entry in addrconf_init()
+-    - ipv6: reorder ip6_route_dev_notifier after ipv6_dev_notf
+-    - bnxt_en: allocate enough space for ->ntp_fltr_bmap
+-    - f2fs: sanity check segment count
+-    - drm/ttm: fix use-after-free races in vm fault handling
+-    - block: get rid of blk_integrity_revalidate()
+-    - Linux 4.4.68
+-
+-  * Keyboard backlight control does not work on some dell laptops.
+-    (LP: #1693126)
+-    - platform/x86: dell-laptop: Add Latitude 7480 and others to the DMI whitelist
+-    - platform/x86: dell-laptop: Add keyboard backlight timeout AC settings
+-
+-  * Upgrade Redpine WLAN/BT driver to ver. 1.2.RC9 (LP: #1690498)
+-    - SAUCE: Redpine: Upgrade to ver. 1.2.RC9
+-
+-  * exec'ing a setuid binary from a threaded program sometimes fails to setuid
+-    (LP: #1672819)
+-    - SAUCE: exec: ensure file system accounting in check_unsafe_exec is correct
+-
+-  * attempts to rename vlans / vlans have addr_assign_type of 0 on kernel 4.4
+-    (LP: #1682871)
+-    - vlan: Propagate MAC address to VLANs
+-
+-  * Exar usb-serial doesn't restore baud rate after resume from S3/S4
+-    (LP: #1690362)
+-    - SAUCE: xr-usb-serial: re-initialise baudrate after resume from S3/S4
+-
+-  * st_pressure, st_accel IIO drivers fail to detect sensors after reloading
+-    kernel modules (LP: #1690310)
+-    - SAUCE: (no-up) iio: st_pressure: st_accel: Initialise sensor platform data
+-      properly
+-
+-  * nvidia-docker on ppc64le-ubuntu16.04  issue due to cross-thread naming if
+-    !PR_DUMPABLE (LP: #1690225)
+-    - procfs: fix pthread cross-thread naming if !PR_DUMPABLE
+-
+-  * linux xenial derivatives fail to build (LP: #1691814)
+-    - [Packaging] Set do_tools_common in common vars
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Tue, 20 Jun 2017 15:47:03 +0200
+-
+-linux (4.4.0-81.104) xenial; urgency=low
+-
+-  * CVE-2017-1000364
+-    - mm: enlarge stack guard gap
+-    - mm: do not collapse stack gap into THP
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Thu, 08 Jun 2017 15:19:41 +0200
+-
+-linux (4.4.0-79.100) xenial; urgency=low
+-
+-  * linux: 4.4.0-79.100 -proposed tracker (LP: #1691180)
+-
+-  * linux-aws/linux-gke incorrectly producing and using linux-*-tools-
+-    common/linux-*-cloud-tools-common (LP: #1688579)
+-    - [Config] make linux-tools-common and linux-cloud-tools-common provide linux-
+-      gke versions
+-    - [Config] make linux-tools-common and linux-cloud-tools-common provide linux-
+-      aws versions
+-    - [Packaging] prevent linux-*-tools-common from being produced from non linux
+-      packages
+-
+-  * CVE-2017-0605
+-    - tracing: Use strlcpy() instead of strcpy() in __trace_find_cmdline()
+-
+-  * i915-bpo crashes on external hdmi input (LP: #1580272)
+-    - SAUCE: i915_bpo: Silence the warning about watermark entries not changing
+-
+-  * Kernel panics on Xenial when using cgroups and strict CFS limits
+-    (LP: #1687512)
+-    - sched/fair: Initialize throttle_count for new task-groups lazily
+-    - sched/fair: Do not announce throttled next buddy in dequeue_task_fair()
+-
+-  * bonding - mlx5 - speed changed to 0 after changing ring size  (LP: #1687877)
+-    - bonding: allow notifications for bond_set_slave_link_state
+-
+-  * Xenial update to 4.4.67 stable release (LP: #1689296)
+-    - timerfd: Protect the might cancel mechanism proper
+-    - Handle mismatched open calls
+-    - ASoC: intel: Fix PM and non-atomic crash in bytcr drivers
+-    - ALSA: ppc/awacs: shut up maybe-uninitialized warning
+-    - drbd: avoid redefinition of BITS_PER_PAGE
+-    - mtd: avoid stack overflow in MTD CFI code
+-    - net: tg3: avoid uninitialized variable warning
+-    - netlink: Allow direct reclaim for fallback allocation
+-    - IB/qib: rename BITS_PER_PAGE to RVT_BITS_PER_PAGE
+-    - IB/ehca: fix maybe-uninitialized warnings
+-    - ext4: require encryption feature for EXT4_IOC_SET_ENCRYPTION_POLICY
+-    - ext4 crypto: revalidate dentry after adding or removing the key
+-    - ext4 crypto: use dget_parent() in ext4_d_revalidate()
+-    - ext4/fscrypto: avoid RCU lookup in d_revalidate
+-    - nfsd4: minor NFSv2/v3 write decoding cleanup
+-    - nfsd: stricter decoding of write-like NFSv2/v3 ops
+-    - dm ioctl: prevent stack leak in dm ioctl call
+-    - Linux 4.4.67
+-
+-  * Precision Rack failed to resume from S4 (LP: #1686061)
+-    - x86 / hibernate: Use hlt_play_dead() when resuming from hibernation
+-    - x86/boot: Split out kernel_ident_mapping_init()
+-    - x86/power/64: Always create temporary identity mapping correctly
+-
+-  * Xenial update to 4.4.66 stable release (LP: #1688505)
+-    - f2fs: do more integrity verification for superblock
+-    - xc2028: unlock on error in xc2028_set_config()
+-    - ARM: OMAP2+: timer: add probe for clocksources
+-    - clk: sunxi: Add apb0 gates for H3
+-    - crypto: testmgr - fix out of bound read in __test_aead()
+-    - drm/amdgpu: fix array out of bounds
+-    - ext4: check if in-inode xattr is corrupted in ext4_expand_extra_isize_ea()
+-    - md:raid1: fix a dead loop when read from a WriteMostly disk
+-    - MIPS: Fix crash registers on non-crashing CPUs
+-    - net: cavium: liquidio: Avoid dma_unmap_single on uninitialized ndata
+-    - net_sched: close another race condition in tcf_mirred_release()
+-    - RDS: Fix the atomicity for congestion map update
+-    - regulator: core: Clear the supply pointer if enabling fails
+-    - usb: gadget: f_midi: Fixed a bug when buflen was smaller than wMaxPacketSize
+-    - xen/x86: don't lose event interrupts
+-    - sparc64: kern_addr_valid regression
+-    - sparc64: Fix kernel panic due to erroneous #ifdef surrounding pmd_write()
+-    - net: neigh: guard against NULL solicit() method
+-    - net: phy: handle state correctly in phy_stop_machine
+-    - l2tp: purge socket queues in the .destruct() callback
+-    - l2tp: take reference on sessions being dumped
+-    - l2tp: fix PPP pseudo-wire auto-loading
+-    - net: ipv4: fix multipath RTM_GETROUTE behavior when iif is given
+-    - sctp: listen on the sock only when it's state is listening or closed
+-    - tcp: clear saved_syn in tcp_disconnect()
+-    - dp83640: don't recieve time stamps twice
+-    - net: ipv6: RTF_PCPU should not be settable from userspace
+-    - netpoll: Check for skb->queue_mapping
+-    - ip6mr: fix notification device destruction
+-    - macvlan: Fix device ref leak when purging bc_queue
+-    - ipv6: check skb->protocol before lookup for nexthop
+-    - ipv6: check raw payload size correctly in ioctl
+-    - ALSA: firewire-lib: fix inappropriate assignment between signed/unsigned
+-      type
+-    - ALSA: seq: Don't break snd_use_lock_sync() loop by timeout
+-    - MIPS: KGDB: Use kernel context for sleeping threads
+-    - MIPS: Avoid BUG warning in arch_check_elf
+-    - p9_client_readdir() fix
+-    - Input: i8042 - add Clevo P650RS to the i8042 reset list
+-    - nfsd: check for oversized NFSv2/v3 arguments
+-    - ARCv2: save r30 on kernel entry as gcc uses it for code-gen
+-    - ftrace/x86: Fix triple fault with graph tracing and suspend-to-ram
+-    - Linux 4.4.66
+-
+-  * Xenial update to 4.4.65 stable release (LP: #1688483)
+-    - tipc: make sure IPv6 header fits in skb headroom
+-    - tipc: make dist queue pernet
+-    - tipc: re-enable compensation for socket receive buffer double counting
+-    - tipc: correct error in node fsm
+-    - tty: nozomi: avoid a harmless gcc warning
+-    - hostap: avoid uninitialized variable use in hfa384x_get_rid
+-    - gfs2: avoid uninitialized variable warning
+-    - tipc: fix random link resets while adding a second bearer
+-    - tipc: fix socket timer deadlock
+-    - xc2028: avoid use after free
+-    - netfilter: nfnetlink: correctly validate length of batch messages
+-    - tipc: check minimum bearer MTU
+-    - vfio/pci: Fix integer overflows, bitmask check
+-    - staging/android/ion : fix a race condition in the ion driver
+-    - ping: implement proper locking
+-    - perf/core: Fix concurrent sys_perf_event_open() vs. 'move_group' race
+-    - Linux 4.4.65
+-
+-  * Xenial update to 4.4.64 stable release (LP: #1687638)
+-    - KEYS: Disallow keyrings beginning with '.' to be joined as session keyrings
+-    - KEYS: Change the name of the dead type to ".dead" to prevent user access
+-    - KEYS: fix keyctl_set_reqkey_keyring() to not leak thread keyrings
+-    - tracing: Allocate the snapshot buffer before enabling probe
+-    - ring-buffer: Have ring_buffer_iter_empty() return true when empty
+-    - cifs: Do not send echoes before Negotiate is complete
+-    - CIFS: remove bad_network_name flag
+-    - s390/mm: fix CMMA vs KSM vs others
+-    - VSOCK: Detach QP check should filter out non matching QPs.
+-    - Input: elantech - add Fujitsu Lifebook E547 to force crc_enabled
+-    - ACPI / power: Avoid maybe-uninitialized warning
+-    - mmc: sdhci-esdhc-imx: increase the pad I/O drive strength for DDR50 card
+-    - mac80211: reject ToDS broadcast data frames
+-    - ubi/upd: Always flush after prepared for an update
+-    - powerpc/kprobe: Fix oops when kprobed on 'stdu' instruction
+-    - x86/mce/AMD: Give a name to MCA bank 3 when accessed with legacy MSRs
+-    - kvm: arm/arm64: Fix locking for kvm_free_stage2_pgd
+-    - x86, pmem: fix broken __copy_user_nocache cache-bypass assumptions
+-    - block: fix del_gendisk() vs blkdev_ioctl crash
+-    - tipc: fix crash during node removal
+-    - Linux 4.4.64
+-
+-  * Xenial update to 4.4.63 stable release (LP: #1687629)
+-    - cgroup, kthread: close race window where new kthreads can be migrated to
+-      non-root cgroups
+-    - thp: fix MADV_DONTNEED vs clear soft dirty race
+-    - drm/nouveau/mpeg: mthd returns true on success now
+-    - drm/nouveau/mmu/nv4a: use nv04 mmu rather than the nv44 one
+-    - CIFS: store results of cifs_reopen_file to avoid infinite wait
+-    - Input: xpad - add support for Razer Wildcat gamepad
+-    - perf/x86: Avoid exposing wrong/stale data in intel_pmu_lbr_read_32()
+-    - x86/vdso: Ensure vdso32_enabled gets set to valid values only
+-    - x86/vdso: Plug race between mapping and ELF header setup
+-    - acpi, nfit, libnvdimm: fix interleave set cookie calculation (64-bit
+-      comparison)
+-    - iscsi-target: Fix TMR reference leak during session shutdown
+-    - iscsi-target: Drop work-around for legacy GlobalSAN initiator
+-    - scsi: sr: Sanity check returned mode data
+-    - scsi: sd: Consider max_xfer_blocks if opt_xfer_blocks is unusable
+-    - scsi: sd: Fix capacity calculation with 32-bit sector_t
+-    - xen, fbfront: fix connecting to backend
+-    - libnvdimm: fix reconfig_mutex, mmap_sem, and jbd2_handle lockdep splat
+-    - irqchip/irq-imx-gpcv2: Fix spinlock initialization
+-    - ftrace: Fix removing of second function probe
+-    - char: Drop bogus dependency of DEVPORT on !M68K
+-    - char: lack of bool string made CONFIG_DEVPORT always on
+-    - Revert "MIPS: Lantiq: Fix cascaded IRQ setup"
+-    - kvm: fix page struct leak in handle_vmon
+-    - zram: do not use copy_page with non-page aligned address
+-    - powerpc: Disable HFSCR[TM] if TM is not supported
+-    - crypto: ahash - Fix EINPROGRESS notification callback
+-    - ath9k: fix NULL pointer dereference
+-    - dvb-usb-v2: avoid use-after-free
+-    - ext4: fix inode checksum calculation problem if i_extra_size is small
+-    - platform/x86: acer-wmi: setup accelerometer when machine has appropriate
+-      notify event
+-    - rtc: tegra: Implement clock handling
+-    - mm: Tighten x86 /dev/mem with zeroing reads
+-    - dvb-usb: don't use stack for firmware load
+-    - dvb-usb-firmware: don't do DMA on stack
+-    - virtio-console: avoid DMA from stack
+-    - pegasus: Use heap buffers for all register access
+-    - rtl8150: Use heap buffers for all register access
+-    - catc: Combine failure cleanup code in catc_probe()
+-    - catc: Use heap buffer for memory size test
+-    - tty/serial: atmel: RS485 half duplex w/DMA: enable RX after TX is done
+-    - net: ipv6: check route protocol when deleting routes
+-    - MIPS: fix Select HAVE_IRQ_EXIT_ON_IRQ_STACK patch.
+-    - Linux 4.4.63
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Wed, 17 May 2017 16:44:58 +0200
+-
+-linux (4.4.0-78.99) xenial; urgency=low
+-
+-  * linux: 4.4.0-78.99 -proposed tracker (LP: #1686645)
+-
+-  * Please backport fix to reference leak in cgroup blkio throttle
+-    (LP: #1683976)
+-    - block: fix module reference leak on put_disk() call for cgroups throttle
+-
+-  * UbuntuKVM guest crashed while running I/O stress test with Ubuntu kernel
+-    4.4.0-47-generic (LP: #1659111)
+-    - block: Unhash block device inodes on gendisk destruction
+-    - block: Use pointer to backing_dev_info from request_queue
+-    - block: Dynamically allocate and refcount backing_dev_info
+-    - block: Make blk_get_backing_dev_info() safe without open bdev
+-    - block: Get rid of blk_get_backing_dev_info()
+-    - block: Move bdev_unhash_inode() after invalidate_partition()
+-    - block: Unhash also block device inode for the whole device
+-    - block: Revalidate i_bdev reference in bd_aquire()
+-    - block: Initialize bd_bdi on inode initialization
+-    - block: Move bdi_unregister() to del_gendisk()
+-    - block: Allow bdi re-registration
+-    - bdi: Fix use-after-free in wb_congested_put()
+-    - block: Make del_gendisk() safer for disks without queues
+-    - block: Fix bdi assignment to bdev inode when racing with disk delete
+-    - bdi: Mark congested->bdi as internal
+-    - bdi: Make wb->bdi a proper reference
+-    - bdi: Unify bdi->wb_list handling for root wb_writeback
+-    - bdi: Shutdown writeback on all cgwbs in cgwb_bdi_destroy()
+-    - bdi: Do not wait for cgwbs release in bdi_unregister()
+-    - bdi: Rename cgwb_bdi_destroy() to cgwb_bdi_unregister()
+-    - block: Fix oops in locked_inode_to_wb_and_lock_list()
+-    - kobject: Export kobject_get_unless_zero()
+-    - block: Fix oops scsi_disk_get()
+-
+-  * Touchpad not working correctly after kernel upgrade (LP: #1662589)
+-    - Input: ALPS - fix V8+ protocol handling (73 03 28)
+-
+-  * Xenial update to v4.4.62 stable release (LP: #1683728)
+-    - drm/i915: Avoid tweaking evaluation thresholds on Baytrail v3
+-    - drm/i915: Stop using RP_DOWN_EI on Baytrail
+-    - usb: dwc3: gadget: delay unmap of bounced requests
+-    - mtd: bcm47xxpart: fix parsing first block after aligned TRX
+-    - MIPS: Introduce irq_stack
+-    - MIPS: Stack unwinding while on IRQ stack
+-    - MIPS: Only change $28 to thread_info if coming from user mode
+-    - MIPS: Switch to the irq_stack in interrupts
+-    - MIPS: Select HAVE_IRQ_EXIT_ON_IRQ_STACK
+-    - MIPS: IRQ Stack: Fix erroneous jal to plat_irq_dispatch
+-    - crypto: caam - fix RNG deinstantiation error checking
+-    - Linux 4.4.62
+-
+-  * ifup service of network device stay active after driver stop (LP: #1672144)
+-    - net: use net->count to check whether a netns is alive or not
+-
+-  * [Hyper-V] mkfs regression in kernel 4.4+ (LP: #1682215)
+-    - block: relax check on sg gap
+-
+-  * [Feature] KBL: intel_powerclamp driver support (LP: #1591641)
+-    - thermal/powerclamp: remove cpu whitelist
+-    - thermal/powerclamp: correct cpu support check
+-    - thermal/powerclamp: add back module device table
+-
+-  * sysfs channel reads of lps22hb pressure sensor are stale (LP: #1682103)
+-    - iio: st_pressure: initialize lps22hb bootime
+-
+-  * Backlight control does not work and there are no entries in
+-    /sys/class/backlight (LP: #1667323)
+-    - Revert "ACPI / video: Add force_native quirk for HP Pavilion dv6"
+-
+-  * [Feature] KBL: intel_rapl driver support (LP: #1591640)
+-    - powercap/intel_rapl: Add support for Kabylake
+-
+-  * Xenial update to v4.4.61 stable release (LP: #1682140)
+-    - drm/vmwgfx: Type-check lookups of fence objects
+-    - drm/vmwgfx: NULL pointer dereference in vmw_surface_define_ioctl()
+-    - drm/vmwgfx: avoid calling vzalloc with a 0 size in vmw_get_cap_3d_ioctl()
+-    - drm/ttm, drm/vmwgfx: Relax permission checking when opening surfaces
+-    - drm/vmwgfx: Remove getparam error message
+-    - drm/vmwgfx: fix integer overflow in vmw_surface_define_ioctl()
+-    - sysfs: be careful of error returns from ops->show()
+-    - staging: android: ashmem: lseek failed due to no FMODE_LSEEK.
+-    - arm/arm64: KVM: Take mmap_sem in stage2_unmap_vm
+-    - arm/arm64: KVM: Take mmap_sem in kvm_arch_prepare_memory_region
+-    - iio: bmg160: reset chip when probing
+-    - Reset TreeId to zero on SMB2 TREE_CONNECT
+-    - ptrace: fix PTRACE_LISTEN race corrupting task->state
+-    - ring-buffer: Fix return value check in test_ringbuffer()
+-    - metag/usercopy: Drop unused macros
+-    - metag/usercopy: Fix alignment error checking
+-    - metag/usercopy: Add early abort to copy_to_user
+-    - metag/usercopy: Zero rest of buffer from copy_from_user
+-    - metag/usercopy: Set flags before ADDZ
+-    - metag/usercopy: Fix src fixup in from user rapf loops
+-    - metag/usercopy: Add missing fixups
+-    - powerpc/mm: Add missing global TLB invalidate if cxl is active
+-    - powerpc: Don't try to fix up misaligned load-with-reservation instructions
+-    - nios2: reserve boot memory for device tree
+-    - s390/decompressor: fix initrd corruption caused by bss clear
+-    - s390/uaccess: get_user() should zero on failure (again)
+-    - MIPS: Force o32 fp64 support on 32bit MIPS64r6 kernels
+-    - MIPS: ralink: Fix typos in rt3883 pinctrl
+-    - MIPS: End spinlocks with .insn
+-    - MIPS: Lantiq: fix missing xbar kernel panic
+-    - MIPS: Flush wrong invalid FTLB entry for huge page
+-    - mm/mempolicy.c: fix error handling in set_mempolicy and mbind.
+-    - Linux 4.4.61
+-
+-  * Xenial update to v4.4.60 stable release (LP: #1681862)
+-    - libceph: force GFP_NOIO for socket allocations
+-    - xen/setup: Don't relocate p2m over existing one
+-    - scsi: mpt3sas: fix hang on ata passthrough commands
+-    - scsi: sg: check length passed to SG_NEXT_CMD_LEN
+-    - scsi: libsas: fix ata xfer length
+-    - ALSA: seq: Fix race during FIFO resize
+-    - ALSA: hda - fix a problem for lineout on a Dell AIO machine
+-    - ASoC: atmel-classd: fix audio clock rate
+-    - ACPI: Fix incompatibility with mcount-based function graph tracing
+-    - ACPI: Do not create a platform_device for IOAPIC/IOxAPIC
+-    - tty/serial: atmel: fix race condition (TX+DMA)
+-    - tty/serial: atmel: fix TX path in atmel_console_write()
+-    - USB: fix linked-list corruption in rh_call_control()
+-    - KVM: x86: clear bus pointer when destroyed
+-    - drm/radeon: Override fpfn for all VRAM placements in radeon_evict_flags
+-    - mm, hugetlb: use pte_present() instead of pmd_present() in follow_huge_pmd()
+-    - MIPS: Lantiq: Fix cascaded IRQ setup
+-    - rtc: s35390a: fix reading out alarm
+-    - rtc: s35390a: make sure all members in the output are set
+-    - rtc: s35390a: implement reset routine as suggested by the reference
+-    - rtc: s35390a: improve irq handling
+-    - KVM: kvm_io_bus_unregister_dev() should never fail
+-    - power: reset: at91-poweroff: timely shutdown LPDDR memories
+-    - blk: improve order of bio handling in generic_make_request()
+-    - blk: Ensure users for current->bio_list can see the full list.
+-    - padata: avoid race in reordering
+-    - Linux 4.4.60
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Thu, 27 Apr 2017 10:24:08 -0300
+-
+-linux (4.4.0-77.98) xenial; urgency=low
+-
+-  * linux: 4.4.0-77.98 -proposed tracker (LP: #1686040)
+-
+-  * [Hyper-V][SAUCE] pci-hyperv: Use only 16 bit integer for PCI domain
+-    (LP: #1684971)
+-    - SAUCE: pci-hyperv: Use only 16 bit integer for PCI domain
+-
+-  * Upgrade Redpine WLAN/BT driver to ver. 1.2.RC4 (LP: #1669672)
+-    - SAUCE: sdhci: use PCI ID to identify Dell IoT gateways
+-    - SAUCE: Redpine: Upgrade to ver. 1.2.RC4
+-    - [Config] Update CONFIG_VEN_RSI_* configs
+-    - SAUCE: Redpine: add copyright to kernel packages
+-
+-  * Fix RX fail issue on Exar USB serial driver after resume from S3/S4
+-    (LP: #1685133)
+-    - SAUCE: xr-usb-serial: Update driver for Exar USB serial ports
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Config] updating configs to match redpine driver changes
+-
+- -- Kleber Sacilotto de Souza <kleber.souza@canonical.com>  Tue, 25 Apr 2017 19:32:01 +0200
+-
+-linux (4.4.0-75.96) xenial; urgency=low
+-
+-  * linux: 4.4.0-75.96 -proposed tracker (LP: #1684441)
+-
+-  * [Hyper-V] hv: util: move waiting for release to hv_utils_transport itself
+-    (LP: #1682561)
+-    - Drivers: hv: util: move waiting for release to hv_utils_transport itself
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Wed, 19 Apr 2017 17:14:23 +0200
+-
+-linux (4.4.0-74.95) xenial; urgency=low
+-
+-  * linux: 4.4.0-74.95 -proposed tracker (LP: #1682041)
+-
+-  * [Hyper-V] hv: vmbus: Raise retry/wait limits in vmbus_post_msg()
+-    (LP: #1681893)
+-    - Drivers: hv: vmbus: Raise retry/wait limits in vmbus_post_msg()
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Wed, 12 Apr 2017 10:30:01 +0200
+-
+-linux (4.4.0-73.94) xenial; urgency=low
+-
+-  * linux: 4.4.0-73.94 -proposed tracker (LP: #1680416)
+-
+-  * CVE-2017-6353
+-    - sctp: deny peeloff operation on asocs with threads sleeping on it
+-
+-  * vfat: missing iso8859-1 charset (LP: #1677230)
+-    - [Config] NLS_ISO8859_1=y
+-
+-  * Regression: KVM modules should be on main kernel package (LP: #1678099)
+-    - [Config] powerpc: Add kvm-hv and kvm-pr to the generic inclusion list
+-
+-  * linux-lts-xenial 4.4.0-63.84~14.04.2 ADT test failure with linux-lts-xenial
+-    4.4.0-63.84~14.04.2 (LP: #1664912)
+-    - SAUCE: apparmor: fix link auditing failure due to, uninitialized var
+-
+-  * regession tests failing after stackprofile test is run (LP: #1661030)
+-    - SAUCE: fix regression with domain change in complain mode
+-
+-  * Permission denied and inconsistent behavior in complain mode with 'ip netns
+-    list' command (LP: #1648903)
+-    - SAUCE: fix regression with domain change in complain mode
+-
+-  * unexpected errno=13 and disconnected path when trying to open /proc/1/ns/mnt
+-    from a unshared mount namespace (LP: #1656121)
+-    - SAUCE: apparmor: null profiles should inherit parent control flags
+-
+-  * apparmor refcount leak of profile namespace when removing profiles
+-    (LP: #1660849)
+-    - SAUCE: apparmor: fix ns ref count link when removing profiles from policy
+-
+-  * tor in lxd: apparmor="DENIED" operation="change_onexec"
+-    namespace="root//CONTAINERNAME_<var-lib-lxd>" profile="unconfined"
+-    name="system_tor" (LP: #1648143)
+-    - SAUCE: apparmor: Fix no_new_privs blocking change_onexec when using stacked
+-      namespaces
+-
+-  * apparmor oops in bind_mnt when dev_path lookup fails (LP: #1660840)
+-    - SAUCE: apparmor: fix oops in bind_mnt when dev_path lookup fails
+-
+-  * apparmor  auditing denied access of special apparmor .null fi\ le
+-    (LP: #1660836)
+-    - SAUCE: apparmor: Don't audit denied access of special apparmor .null file
+-
+-  * apparmor label leak when new label is unused (LP: #1660834)
+-    - SAUCE: apparmor: fix label leak when new label is unused
+-
+-  * apparmor reference count bug in label_merge_insert() (LP: #1660833)
+-    - SAUCE: apparmor: fix reference count bug in label_merge_insert()
+-
+-  * apparmor's raw_data file in securityfs is sometimes truncated (LP: #1638996)
+-    - SAUCE: apparmor: fix replacement race in reading rawdata
+-
+-  * unix domain socket cross permission check failing with nested namespaces
+-    (LP: #1660832)
+-    - SAUCE: apparmor: fix cross ns perm of unix domain sockets
+-
+-  * Xenial update to v4.4.59 stable release (LP: #1678960)
+-    - xfrm: policy: init locks early
+-    - virtio_balloon: init 1st buffer in stats vq
+-    - pinctrl: qcom: Don't clear status bit on irq_unmask
+-    - c6x/ptrace: Remove useless PTRACE_SETREGSET implementation
+-    - h8300/ptrace: Fix incorrect register transfer count
+-    - mips/ptrace: Preserve previous registers for short regset write
+-    - sparc/ptrace: Preserve previous registers for short regset write
+-    - metag/ptrace: Preserve previous registers for short regset write
+-    - metag/ptrace: Provide default TXSTATUS for short NT_PRSTATUS
+-    - metag/ptrace: Reject partial NT_METAG_RPIPE writes
+-    - fscrypt: remove broken support for detecting keyring key revocation
+-    - sched/rt: Add a missing rescheduling point
+-    - Linux 4.4.59
+-
+-  * Update ENA driver to 1.1.2 from net-next (LP: #1664312)
+-    - net: ena: Remove unnecessary pci_set_drvdata()
+-    - net: ena: Fix error return code in ena_device_init()
+-    - net: ena: change the return type of ena_set_push_mode() to be void.
+-    - net: ena: use setup_timer() and mod_timer()
+-    - net/ena: remove ntuple filter support from device feature list
+-    - net/ena: fix queues number calculation
+-    - net/ena: fix ethtool RSS flow configuration
+-    - net/ena: fix RSS default hash configuration
+-    - net/ena: fix NULL dereference when removing the driver after device reset
+-      failed
+-    - net/ena: refactor ena_get_stats64 to be atomic context safe
+-    - net/ena: fix potential access to freed memory during device reset
+-    - net/ena: use READ_ONCE to access completion descriptors
+-    - net/ena: reduce the severity of ena printouts
+-    - net/ena: change driver's default timeouts
+-    - net/ena: change condition for host attribute configuration
+-    - net/ena: update driver version to 1.1.2
+-
+-  * Xenial update to v4.4.58 stable release (LP: #1677600)
+-    - net/openvswitch: Set the ipv6 source tunnel key address attribute correctly
+-    - net: bcmgenet: Do not suspend PHY if Wake-on-LAN is enabled
+-    - net: properly release sk_frag.page
+-    - amd-xgbe: Fix jumbo MTU processing on newer hardware
+-    - net: unix: properly re-increment inflight counter of GC discarded candidates
+-    - net/mlx5: Increase number of max QPs in default profile
+-    - net/mlx5e: Count LRO packets correctly
+-    - net: bcmgenet: remove bcmgenet_internal_phy_setup()
+-    - ipv4: provide stronger user input validation in nl_fib_input()
+-    - socket, bpf: fix sk_filter use after free in sk_clone_lock
+-    - tcp: initialize icsk_ack.lrcvtime at session start time
+-    - Input: elan_i2c - add ASUS EeeBook X205TA special touchpad fw
+-    - Input: i8042 - add noloop quirk for Dell Embedded Box PC 3000
+-    - Input: iforce - validate number of endpoints before using them
+-    - Input: ims-pcu - validate number of endpoints before using them
+-    - Input: hanwang - validate number of endpoints before using them
+-    - Input: yealink - validate number of endpoints before using them
+-    - Input: cm109 - validate number of endpoints before using them
+-    - Input: kbtab - validate number of endpoints before using them
+-    - Input: sur40 - validate number of endpoints before using them
+-    - ALSA: seq: Fix racy cell insertions during snd_seq_pool_done()
+-    - ALSA: ctxfi: Fix the incorrect check of dma_set_mask() call
+-    - ALSA: hda - Adding a group of pin definition to fix headset problem
+-    - USB: serial: option: add Quectel UC15, UC20, EC21, and EC25 modems
+-    - USB: serial: qcserial: add Dell DW5811e
+-    - ACM gadget: fix endianness in notifications
+-    - usb: gadget: f_uvc: Fix SuperSpeed companion descriptor's wBytesPerInterval
+-    - usb-core: Add LINEAR_FRAME_INTR_BINTERVAL USB quirk
+-    - USB: uss720: fix NULL-deref at probe
+-    - USB: lvtest: fix NULL-deref at probe
+-    - USB: idmouse: fix NULL-deref at probe
+-    - USB: wusbcore: fix NULL-deref at probe
+-    - usb: musb: cppi41: don't check early-TX-interrupt for Isoch transfer
+-    - usb: hub: Fix crash after failure to read BOS descriptor
+-    - uwb: i1480-dfu: fix NULL-deref at probe
+-    - uwb: hwa-rc: fix NULL-deref at probe
+-    - mmc: ushc: fix NULL-deref at probe
+-    - iio: adc: ti_am335x_adc: fix fifo overrun recovery
+-    - iio: hid-sensor-trigger: Change get poll value function order to avoid
+-      sensor properties losing after resume from S3
+-    - parport: fix attempt to write duplicate procfiles
+-    - ext4: mark inode dirty after converting inline directory
+-    - mmc: sdhci: Do not disable interrupts while waiting for clock
+-    - xen/acpi: upload PM state from init-domain to Xen
+-    - iommu/vt-d: Fix NULL pointer dereference in device_to_iommu
+-    - ARM: at91: pm: cpu_idle: switch DDR to power-down mode
+-    - ARM: dts: at91: sama5d2: add dma properties to UART nodes
+-    - cpufreq: Restore policy min/max limits on CPU online
+-    - raid10: increment write counter after bio is split
+-    - libceph: don't set weight to IN when OSD is destroyed
+-    - xfs: don't allow di_size with high bit set
+-    - xfs: fix up xfs_swap_extent_forks inline extent handling
+-    - nl80211: fix dumpit error path RTNL deadlocks
+-    - USB: usbtmc: add missing endpoint sanity check
+-    - xfs: clear _XBF_PAGES from buffers when readahead page
+-    - igb: add i211 to i210 PHY workaround
+-    - vfio/spapr: Postpone allocation of userspace version of TCE table
+-    - block: allow WRITE_SAME commands with the SG_IO ioctl
+-    - fbcon: Fix vc attr at deinit
+-    - crypto: algif_hash - avoid zero-sized array
+-    - Linux 4.4.58
+-
+-  * PS/2 mouse does not work on Dell embedded computer (LP: #1591053)
+-    - Input: i8042 - add noloop quirk for Dell Embedded Box PC 3000
+-
+-  * Xenial update to v4.4.57 stable release (LP: #1676424)
+-    - give up on gcc ilog2() constant optimizations
+-    - perf/core: Fix event inheritance on fork()
+-    - cpufreq: Fix and clean up show_cpuinfo_cur_freq()
+-    - powerpc/boot: Fix zImage TOC alignment
+-    - md/raid1/10: fix potential deadlock
+-    - target/pscsi: Fix TYPE_TAPE + TYPE_MEDIMUM_CHANGER export
+-    - scsi: lpfc: Add shutdown method for kexec
+-    - scsi: libiscsi: add lock around task lists to fix list corruption regression
+-    - target: Fix VERIFY_16 handling in sbc_parse_cdb
+-    - isdn/gigaset: fix NULL-deref at probe
+-    - gfs2: Avoid alignment hole in struct lm_lockname
+-    - percpu: acquire pcpu_lock when updating pcpu_nr_empty_pop_pages
+-    - ext4: fix fencepost in s_first_meta_bg validation
+-    - Linux 4.4.57
+-
+-  * Xenial update to v4.4.56 stable release (LP: #1675789)
+-    - netlink: remove mmapped netlink support
+-    - [Config] CONFIG_NETLINK_MMAP disappeared
+-    - vxlan: correctly validate VXLAN ID against VXLAN_N_VID
+-    - vti6: return GRE_KEY for vti6
+-    - ipv4: mask tos for input route
+-    - l2tp: avoid use-after-free caused by l2tp_ip_backlog_recv
+-    - net: don't call strlen() on the user buffer in packet_bind_spkt()
+-    - net: net_enable_timestamp() can be called from irq contexts
+-    - dccp: Unlock sock before calling sk_free()
+-    - tcp: fix various issues for sockets morphing to listen state
+-    - net: fix socket refcounting in skb_complete_wifi_ack()
+-    - net: fix socket refcounting in skb_complete_tx_timestamp()
+-    - dccp: fix use-after-free in dccp_feat_activate_values
+-    - vrf: Fix use-after-free in vrf_xmit
+-    - uapi: fix linux/packet_diag.h userspace compilation error
+-    - act_connmark: avoid crashing on malformed nlattrs with null parms
+-    - mpls: Send route delete notifications when router module is unloaded
+-    - ipv6: make ECMP route replacement less greedy
+-    - ipv6: avoid write to a possibly cloned skb
+-    - dccp/tcp: fix routing redirect race
+-    - dccp: fix memory leak during tear-down of unsuccessful connection request
+-    - net sched actions: decrement module reference count after table flush.
+-    - fscrypt: fix renaming and linking special files
+-    - fscrypto: lock inode while setting encryption policy
+-    - x86/kasan: Fix boot with KASAN=y and PROFILE_ANNOTATED_BRANCHES=y
+-    - x86/perf: Fix CR4.PCE propagation to use active_mm instead of mm
+-    - futex: Fix potential use-after-free in FUTEX_REQUEUE_PI
+-    - futex: Add missing error handling to FUTEX_REQUEUE_PI
+-    - Linux 4.4.56
+-
+-  * Kernel linux-image-4.4.0-67-generic prevent the boot on Microsoft Hyper-v
+-    2012r2 Gen2 VM (LP: #1674635)
+-    - scsi: storvsc: Workaround for virtual DVD SCSI version
+-
+-  * [Hyper-V][Mellanox] net/mlx4_core: Avoid delays during VF driver device
+-    shutdown (LP: #1672785)
+-    - net/mlx4_core: Avoid delays during VF driver device shutdown
+-
+-  * Channel data values for IIO based st_sensors (st_accel, st_pressure) are
+-    incorrect (LP: #1676356)
+-    - iio: core: added support for IIO_VAL_INT
+-    - iio: st_sensors: simplify buffer address handling
+-    - iio: st_sensors: read each channel individually
+-    - iio:st_sensors: emulate SMBus block read if needed
+-    - iio:st_sensors: align on storagebits boundaries
+-    - iio:st_pressure: temperature triggered buffering
+-    - iio:st_pressure: clean useless static channel initializers
+-    - iio: st_pressure: Fix data sign
+-
+-  * Enable lspcon on i915 (LP: #1676747)
+-    - drm: Helper for lspcon in drm_dp_dual_mode
+-    - drm/i915: Add lspcon support for I915 driver
+-    - drm/i915: Parse VBT data for lspcon
+-    - drm/i915: Enable lspcon initialization
+-    - drm/i915: Add lspcon resume function
+-
+-  * stress_smoke_test passing and exiting rc=9 (linux 4.9.0-12.13 ADT test
+-    failure with linux 4.9.0-12.13) (LP: #1658633)
+-    - ext4: lock the xattr block before checksuming it
+-
+-  * Fix line-out port noise on Baytrail-I with RT5660 based sound card
+-    (LP: #1675327)
+-    - SAUCE: (no-up): ASoC: Intel: bytcr-rt5660: Fix noise in line-out
+-
+-  * Kernel 4.4.0-67 Defaults to ACPI-cpufreq rather than P-State - Dell
+-    Precision 5520  (LP: #1674390)
+-    - cpufreq: intel_pstate: Enable HWP by default
+-
+-  * ip_rcv_finish() NULL pointer kernel panic (LP: #1672470)
+-    - bridge: drop netfilter fake rtable unconditionally
+-
+-  * dm-queue-length module is not included in installer/initramfs (LP: #1673350)
+-    - d-i: Also add dm-queue-length to multipath modules
+-
+-  * Broadcom bluetooth modules sometimes fail to initialize (LP: #1483101)
+-    - Bluetooth: btbcm: Add a delay for module reset
+-
+-  * Need support of Broadcom bluetooth device [413c:8143] (LP: #1166113)
+-    - Bluetooth: btusb: Add support for 413c:8143
+-
+-  * i40e Intel X710 error during device probe prevents link set up and ip
+-    association (LP: #1672550)
+-    - i40e: check for and deal with non-contiguous TCs
+-
+-  * CIFS: Call echo service immediately after socket reconnect (LP: #1669941)
+-    - Call echo service immediately after socket reconnect
+-
+-  * FC Adapter (LPe32000-based) prints "iotag out of range", goes offline, and
+-    delays boot a lot (Ubuntu17.04/Emulex/lpfc)) (LP: #1670490)
+-    - scsi: lpfc: Add missing memory barrier
+-
+-  * No C-State Deeper than C3 utilized by Kaby Lake 7820HQ in Precision 5520
+-    (LP: #1672439)
+-    - intel_idle: Add KBL support
+-
+-  * [Hyper-V] Missing PCI patches breaking SR-IOV hot remove (LP: #1670518)
+-    - PCI: hv: Fix hv_pci_remove() for hot-remove
+-    - PCI: hv: Delete the device earlier from hbus->children for hot-remove
+-    - PCI: hv: Make unnecessarily global IRQ masking functions static
+-    - PCI: hv: Allocate physically contiguous hypercall params buffer
+-
+-  * Xenial update to v4.4.55 stable release (LP: #1674292)
+-    - USB: serial: digi_acceleport: fix OOB data sanity check
+-    - USB: serial: digi_acceleport: fix OOB-event processing
+-    - crypto: improve gcc optimization flags for serpent and wp512
+-    - MIPS: Update defconfigs for NF_CT_PROTO_DCCP/UDPLITE change
+-    - MIPS: ip27: Disable qlge driver in defconfig
+-    - MIPS: Update ip27_defconfig for SCSI_DH change
+-    - MIPS: ip22: Fix ip28 build for modern gcc
+-    - MIPS: Update lemote2f_defconfig for CPU_FREQ_STAT change
+-    - mtd: pmcmsp: use kstrndup instead of kmalloc+strncpy
+-    - MIPS: ralink: Cosmetic change to prom_init().
+-    - MIPS: ralink: Remove unused rt*_wdt_reset functions
+-    - cpmac: remove hopeless #warning
+-    - mm: memcontrol: avoid unused function warning
+-    - MIPS: DEC: Avoid la pseudo-instruction in delay slots
+-    - MIPS: Netlogic: Fix CP0_EBASE redefinition warnings
+-    - tracing: Add #undef to fix compile error
+-    - powerpc: Emulation support for load/store instructions on LE
+-    - usb: gadget: dummy_hcd: clear usb_gadget region before registration
+-    - usb: dwc3: gadget: make Set Endpoint Configuration macros safe
+-    - usb: gadget: function: f_fs: pass companion descriptor along
+-    - usb: host: xhci-dbg: HCIVERSION should be a binary number
+-    - usb: host: xhci-plat: Fix timeout on removal of hot pluggable xhci
+-      controllers
+-    - USB: serial: safe_serial: fix information leak in completion handler
+-    - USB: serial: omninet: fix reference leaks at open
+-    - USB: iowarrior: fix NULL-deref at probe
+-    - USB: iowarrior: fix NULL-deref in write
+-    - USB: serial: io_ti: fix NULL-deref in interrupt callback
+-    - USB: serial: io_ti: fix information leak in completion handler
+-    - serial: samsung: Continue to work if DMA request fails
+-    - mvsas: fix misleading indentation
+-    - KVM: s390: Fix guest migration for huge guests resulting in panic
+-    - s390/kdump: Use "LINUX" ELF note name instead of "CORE"
+-    - nfit, libnvdimm: fix interleave set cookie calculation
+-    - dm: flush queued bios when process blocks to avoid deadlock
+-    - ext4: don't BUG when truncating encrypted inodes on the orphan list
+-    - Linux 4.4.55
+-
+-  * Xenial update to v4.4.54 stable release (LP: #1673541)
+-    - serial: 8250_pci: Add MKS Tenta SCOM-0800 and SCOM-0801 cards
+-    - KVM: s390: Disable dirty log retrieval for UCONTROL guests
+-    - KVM: VMX: use correct vmcs_read/write for guest segment selector/base
+-    - Bluetooth: Add another AR3012 04ca:3018 device
+-    - s390/qdio: clear DSCI prior to scanning multiple input queues
+-    - s390/dcssblk: fix device size calculation in dcssblk_direct_access()
+-    - s390: TASK_SIZE for kernel threads
+-    - s390: make setup_randomness work
+-    - s390: use correct input data address for setup_randomness
+-    - net: mvpp2: fix DMA address calculation in mvpp2_txq_inc_put()
+-    - mnt: Tuck mounts under others instead of creating shadow/side mounts.
+-    - IB/ipoib: Fix deadlock between rmmod and set_mode
+-    - IB/IPoIB: Add destination address when re-queue packet
+-    - IB/srp: Avoid that duplicate responses trigger a kernel bug
+-    - IB/srp: Fix race conditions related to task management
+-    - ktest: Fix child exit code processing
+-    - ceph: remove req from unsafe list when unregistering it
+-    - target: Fix NULL dereference during LUN lookup + active I/O shutdown
+-    - nlm: Ensure callback code also checks that the files match
+-    - pwm: pca9685: Fix period change with same duty cycle
+-    - xtensa: move parse_tag_fdt out of #ifdef CONFIG_BLK_DEV_INITRD
+-    - mac80211: flush delayed work when entering suspend
+-    - drm/amdgpu: add more cases to DCE11 possible crtc mask setup
+-    - drm/ast: Fix test for VGA enabled
+-    - drm/ast: Call open_key before enable_mmio in POST code
+-    - drm/ast: Fix AST2400 POST failure without BMC FW or VBIOS
+-    - drm/edid: Add EDID_QUIRK_FORCE_8BPC quirk for Rotel RSX-1058
+-    - drm/ttm: Make sure BOs being swapped out are cacheable
+-    - drm/atomic: fix an error code in mode_fixup()
+-    - fakelb: fix schedule while atomic
+-    - drm/i915/dsi: Do not clear DPOUNIT_CLOCK_GATE_DISABLE from
+-      vlv_init_display_clock_gating
+-    - libceph: use BUG() instead of BUG_ON(1)
+-    - fat: fix using uninitialized fields of fat_inode/fsinfo_inode
+-    - drivers: hv: Turn off write permission on the hypercall page
+-    - Linux 4.4.54
+-
+-  * Xenial update to v4.4.53 stable release (LP: #1673538)
+-    - samples: move mic/mpssd example code from Documentation
+-    - MIPS: Fix special case in 64 bit IP checksumming.
+-    - MIPS: BCM47XX: Fix button inversion for Asus WL-500W
+-    - MIPS: OCTEON: Fix copy_from_user fault handling for large buffers
+-    - MIPS: Lantiq: Keep ethernet enabled during boot
+-    - MIPS: Clear ISA bit correctly in get_frame_info()
+-    - MIPS: Prevent unaligned accesses during stack unwinding
+-    - MIPS: Fix get_frame_info() handling of microMIPS function size
+-    - MIPS: Fix is_jump_ins() handling of 16b microMIPS instructions
+-    - MIPS: Calculate microMIPS ra properly when unwinding the stack
+-    - MIPS: Handle microMIPS jumps in the same way as MIPS32/MIPS64 jumps
+-    - am437x-vpfe: always assign bpp variable
+-    - uvcvideo: Fix a wrong macro
+-    - media: fix dm1105.c build error
+-    - ARM: at91: define LPDDR types
+-    - ARM: dts: at91: Enable DMA on sama5d4_xplained console
+-    - ARM: dts: at91: Enable DMA on sama5d2_xplained console
+-    - ALSA: hda/realtek - Cannot adjust speaker's volume on a Dell AIO
+-    - ALSA: hda - fix Lewisburg audio issue
+-    - ALSA: timer: Reject user params with too small ticks
+-    - ALSA: ctxfi: Fallback DMA mask to 32bit
+-    - ALSA: seq: Fix link corruption by event error handling
+-    - ALSA: hda - Add subwoofer support for Dell Inspiron 17 7000 Gaming
+-    - ALSA: hda - Fix micmute hotkey problem for a lenovo AIO machine
+-    - staging: rtl: fix possible NULL pointer dereference
+-    - regulator: Fix regulator_summary for deviceless consumers
+-    - iommu/vt-d: Fix some macros that are incorrectly specified in intel-iommu
+-    - iommu/vt-d: Tylersburg isoch identity map check is done too late.
+-    - mm/page_alloc: fix nodes for reclaim in fast path
+-    - mm: vmpressure: fix sending wrong events on underflow
+-    - mm: do not access page->mapping directly on page_endio
+-    - ipc/shm: Fix shmat mmap nil-page protection
+-    - dm cache: fix corruption seen when using cache > 2TB
+-    - dm stats: fix a leaked s->histogram_boundaries array
+-    - Revert "scsi: storvsc: properly set residual data length on errors"
+-    - scsi: storvsc: properly set residual data length on errors
+-    - scsi: aacraid: Reorder Adapter status check
+-    - scsi: use 'scsi_device_from_queue()' for scsi_dh
+-    - sd: get disk reference in sd_check_events()
+-    - Fix: Disable sys_membarrier when nohz_full is enabled
+-    - jbd2: don't leak modified metadata buffers on an aborted journal
+-    - block/loop: fix race between I/O and set_status
+-    - loop: fix LO_FLAGS_PARTSCAN hang
+-    - ext4: Include forgotten start block on fallocate insert range
+-    - ext4: do not polute the extents cache while shifting extents
+-    - ext4: trim allocation requests to group size
+-    - ext4: fix data corruption in data=journal mode
+-    - ext4: fix inline data error paths
+-    - ext4: preserve the needs_recovery flag when the journal is aborted
+-    - ext4: return EROFS if device is r/o and journal replay is needed
+-    - samples/seccomp: fix 64-bit comparison macros
+-    - target: Obtain se_node_acl->acl_kref during get_initiator_node_acl
+-    - target: Fix multi-session dynamic se_node_acl double free OOPs
+-    - ath5k: drop bogus warning on drv_set_key with unsupported cipher
+-    - ath9k: fix race condition in enabling/disabling IRQs
+-    - ath9k: use correct OTP register offsets for the AR9340 and AR9550
+-    - crypto: testmgr - Pad aes_ccm_enc_tv_template vector
+-    - fuse: add missing FR_FORCE
+-    - arm/arm64: KVM: Enforce unconditional flush to PoC when mapping to stage-2
+-    - iio: pressure: mpl115: do not rely on structure field ordering
+-    - iio: pressure: mpl3115: do not rely on structure field ordering
+-    - can: usb_8dev: Fix memory leak of priv->cmd_msg_buffer
+-    - w1: don't leak refcount on slave attach failure in w1_attach_slave_device()
+-    - w1: ds2490: USB transfer buffers need to be DMAable
+-    - usb: musb: da8xx: Remove CPPI 3.0 quirk and methods
+-    - usb: host: xhci: plat: check hcc_params after add hcd
+-    - usb: gadget: udc: fsl: Add missing complete function.
+-    - hv: allocate synic pages for all present CPUs
+-    - hv: init percpu_list in hv_synic_alloc()
+-    - Drivers: hv: util: kvp: Fix a rescind processing issue
+-    - Drivers: hv: util: Fcopy: Fix a rescind processing issue
+-    - Drivers: hv: util: Backup: Fix a rescind processing issue
+-    - RDMA/core: Fix incorrect structure packing for booleans
+-    - rdma_cm: fail iwarp accepts w/o connection params
+-    - gfs2: Add missing rcu locking for glock lookup
+-    - rtlwifi: Fix alignment issues
+-    - rtlwifi: rtl8192c-common: Fix "BUG: KASAN:
+-    - nfsd: minor nfsd_setattr cleanup
+-    - nfsd: special case truncates some more
+-    - NFSv4: Fix memory and state leak in _nfs4_open_and_get_state
+-    - NFSv4: fix getacl head length estimation
+-    - NFSv4: fix getacl ERANGE for some ACL buffer sizes
+-    - rtc: sun6i: Add some locking
+-    - rtc: sun6i: Switch to the external oscillator
+-    - md linear: fix a race between linear_add() and linear_congested()
+-    - bcma: use (get|put)_device when probing/removing device driver
+-    - dmaengine: ipu: Make sure the interrupt routine checks all interrupts.
+-    - powerpc/xmon: Fix data-breakpoint
+-    - MIPS: IP22: Reformat inline assembler code to modern standards.
+-    - MIPS: IP22: Fix build error due to binutils 2.25 uselessnes.
+-    - scsi: lpfc: Correct WQ creation for pagesize
+-    - Linux 4.4.53
+-
+-  * move aufs.ko from -extra to linux-image package (LP: #1673498)
+-    - [config] aufs.ko moved to linux-image package
+-
+-  * [Xenial] net: better skb->sender_cpu and skb->napi_id cohabitation
+-    (LP: #1673303)
+-    - net: better skb->sender_cpu and skb->napi_id cohabitation
+-
+-  * lsattr 32bit does not work on 64bit kernel (Inappropriate ioctl error)
+-    (LP: #1619918)
+-    - btrfs: fix btrfs_compat_ioctl failures on non-compat ioctls
+-
+-  * linux-tools-common should Depends: lsb-release (LP: #1667571)
+-    - [Config] linux-tools-common depends on lsb-release
+-
+-  * Add Use-After-Free Patch for Ubuntu16.10 - EEH on BELL3 adapter fails to
+-    recover (serial/tty) (LP: #1669153)
+-    - 8250_pci: Fix potential use-after-free in error path
+-
+-  * [Hyper-V] pci-hyperv: Use device serial number as PCI domain (LP: #1667527)
+-    - net/mlx4_core: Use cq quota in SRIOV when creating completion EQs
+-    - PCI: hv: Use device serial number as PCI domain
+-
+-  * [Xenial - 16.04 ]Bonding driver - stack corruption when trying to copy 20
+-    bytes to a sockaddr (LP: #1668042)
+-    - net/bonding: Enforce active-backup policy for IPoIB bonds
+-
+-  * Request to backport cxlflash patches to Xenial SRU stream (LP: #1623750)
+-    - scsi: cxlflash: Scan host only after the port is ready for I/O
+-    - scsi: cxlflash: Remove the device cleanly in the system shutdown path
+-    - scsi: cxlflash: Fix to avoid EEH and host reset collisions
+-    - scsi: cxlflash: Improve EEH recovery time
+-
+-  * Xenial update to v4.4.52 stable release (LP: #1669016)
+-    - net/llc: avoid BUG_ON() in skb_orphan()
+-    - packet: fix races in fanout_add()
+-    - packet: Do not call fanout_release from atomic contexts
+-    - irda: Fix lockdep annotations in hashbin_delete().
+-    - ip: fix IP_CHECKSUM handling
+-    - net: socket: fix recvmmsg not returning error from sock_error
+-    - tty: serial: msm: Fix module autoload
+-    - USB: serial: mos7840: fix another NULL-deref at open
+-    - USB: serial: cp210x: add new IDs for GE Bx50v3 boards
+-    - USB: serial: ftdi_sio: fix modem-status error handling
+-    - USB: serial: ftdi_sio: fix extreme low-latency setting
+-    - USB: serial: ftdi_sio: fix line-status over-reporting
+-    - USB: serial: spcp8x5: fix modem-status handling
+-    - USB: serial: opticon: fix CTS retrieval at open
+-    - USB: serial: ark3116: fix register-accessor error handling
+-    - x86/platform/goldfish: Prevent unconditional loading
+-    - goldfish: Sanitize the broken interrupt handler
+-    - block: fix double-free in the failure path of cgwb_bdi_init()
+-    - rtlwifi: rtl_usb: Fix for URB leaking when doing ifconfig up/down
+-    - Revert "usb: chipidea: imx: enable CI_HDRC_SET_NON_ZERO_TTHA"
+-    - kvm: vmx: ensure VMCS is current while enabling PML
+-    - Linux 4.4.52
+-
+-  * Xenial update to v4.4.51 stable release (LP: #1669015)
+-    - vfs: fix uninitialized flags in splice_to_pipe()
+-    - siano: make it work again with CONFIG_VMAP_STACK
+-    - fuse: fix use after free issue in fuse_dev_do_read()
+-    - scsi: don't BUG_ON() empty DMA transfers
+-    - Fix missing sanity check in /dev/sg
+-    - Input: elan_i2c - add ELAN0605 to the ACPI table
+-    - drm/radeon: Use mode h/vdisplay fields to hide out of bounds HW cursor
+-    - drm/dp/mst: fix kernel oops when turning off secondary monitor
+-    - futex: Move futex_init() to core_initcall
+-    - ARM: 8658/1: uaccess: fix zeroing of 64-bit get_user()
+-    - printk: use rcuidle console tracepoint
+-    - NTB: ntb_transport: fix debugfs_remove_recursive
+-    - ntb_transport: Pick an unused queue
+-    - bcache: Make gc wakeup sane, remove set_task_state()
+-    - mmc: core: fix multi-bit bus width without high-speed mode
+-    - Linux 4.4.51
+-
+-  * Xenial update to v4.4.50 stable release (LP: #1666324)
+-    - can: Fix kernel panic at security_sock_rcv_skb
+-    - ipv6: fix ip6_tnl_parse_tlv_enc_lim()
+-    - ipv6: pointer math error in ip6_tnl_parse_tlv_enc_lim()
+-    - tcp: fix 0 divide in __tcp_select_window()
+-    - net: use a work queue to defer net_disable_timestamp() work
+-    - ipv4: keep skb->dst around in presence of IP options
+-    - netlabel: out of bound access in cipso_v4_validate()
+-    - ip6_gre: fix ip6gre_err() invalid reads
+-    - ipv6: tcp: add a missing tcp_v6_restore_cb()
+-    - tcp: avoid infinite loop in tcp_splice_read()
+-    - tun: read vnet_hdr_sz once
+-    - macvtap: read vnet_hdr_size once
+-    - mlx4: Invoke softirqs after napi_reschedule
+-    - sctp: avoid BUG_ON on sctp_wait_for_sndbuf
+-    - sit: fix a double free on error path
+-    - net: introduce device min_header_len
+-    - packet: round up linear to header len
+-    - ping: fix a null pointer dereference
+-    - l2tp: do not use udp_ioctl()
+-    - Linux 4.4.50
+-
+-  * FlashGT Integration and Setup: fsbmc30: After 17th reboot of soft bootme,
+-    HTX & Linux errors seen with 256 virtual LUNs (LP: #1667239)
+-    - cxl: Fix coredump generation when cxl_get_fd() is used
+-
+-  * [Hyper-V] Ubuntu 14.04.2 LTS Generation 2 SCSI Errors on VSS Based Backups
+-    (LP: #1470250)
+-    - Drivers: hv: vss: Operation timeouts should match host expectation
+-    - SAUCE: Tools: hv: vss: Thaw the filesystem and continue after freeze fails
+-
+-  * kernel 4.4.0-63 with USB WLAN RTL8192CU freezes desktop (LP: #1666421)
+-    - rtlwifi: rtl_usb: Fix missing entry in USB driver's private data
+-
+-  * Export symbol "dev_pm_qos_update_user_latency_tolerance" (LP: #1666401)
+-    - PM / QoS: Export dev_pm_qos_update_user_latency_tolerance
+-
+-  * Linux ZFS port doesn't respect RLIMIT_FSIZE (LP: #1656259)
+-    - SAUCE: (noup) Update zfs to 0.6.5.6-0ubuntu16
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Thu, 06 Apr 2017 09:34:27 +0100
+-
+-linux (4.4.0-72.93) xenial; urgency=low
+-
+-  * linux: 4.4.0-72.93 -proposed tracker (LP: #1678078)
+-
+-  * Fix CVE-2017-7308 (LP: #1678009)
+-    - net/packet: fix overflow in check for priv area size
+-    - net/packet: fix overflow in check for tp_frame_nr
+-    - net/packet: fix overflow in check for tp_reserve
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Fri, 31 Mar 2017 09:20:03 +0200
+-
+-linux (4.4.0-71.92) xenial; urgency=low
+-
+-  * CVE-2017-7184
+-    - xfrm_user: validate XFRM_MSG_NEWAE XFRMA_REPLAY_ESN_VAL replay_window
+-    - xfrm_user: validate XFRM_MSG_NEWAE incoming ESN size harder
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Fri, 24 Mar 2017 09:32:49 -0300
+-
+-linux (4.4.0-70.91) xenial; urgency=low
+-
+-  * linux: 4.4.0-70.91 -proposed tracker (LP: #1674938)
+-
+-  * snaps with classic + jailmode confinement started to fail on zesty
+-    (LP: #1666897)
+-    - Revert "UBUNTU: SAUCE: apparmor: fix link auditing failure due to,
+-      uninitialized var"
+-    - Revert "UBUNTU: SAUCE: fix regression with domain change in complain mode"
+-    - Revert "UBUNTU: SAUCE: apparmor: flock mediation is not being enforced on
+-      cache check"
+-    - Revert "UBUNTU: SAUCE: apparmor: null profiles should inherit parent control
+-      flags"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix ns ref count link when removing
+-      profiles from policy"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix no_new_privs blocking change_onexec
+-      when using stacked namespaces"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix oops in bind_mnt when dev_path lookup
+-      fails"
+-    - Revert "UBUNTU: SAUCE: apparmor: Don't audit denied access of special
+-      apparmor .null file"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix label leak when new label is unused"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix reference count bug in
+-      label_merge_insert()"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix replacement race in reading rawdata"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix cross ns perm of unix domain sockets"
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Wed, 22 Mar 2017 09:28:43 +0100
+-
+-linux (4.4.0-67.88) xenial; urgency=low
+-
+-  * linux: 4.4.0-67.88 -proposed tracker (LP: #1667052)
+-
+-  * Recent KVM RTC cherry-picks break (some) Windows Live-Migrations
+-    (LP: #1668594)
+-    - kvm: x86: correctly reset dest_map->vector when restoring LAPIC state
+-
+-  * Regression in 4.4.0-65-generic causes very frequent system crashes
+-    (LP: #1669611)
+-    - Revert "UBUNTU: SAUCE: apparmor: fix lock ordering for mkdir"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix leak on securityfs pin count"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix reference count leak when
+-      securityfs_setup_d_inode() fails"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix not handling error case when
+-      securityfs_pin_fs() fails"
+-
+-  * Upgrade Redpine RS9113 driver to support AP mode (LP: #1665211)
+-    - SAUCE: Redpine driver to support Host AP mode
+-
+-  * NFS client : permission denied when trying to access subshare, since kernel
+-    4.4.0-31 (LP: #1649292)
+-    - fs: Better permission checking for submounts
+-
+-  * [Hyper-V] SAUCE: pci-hyperv fixes for SR-IOV on Azure (LP: #1665097)
+-    - SAUCE: PCI: hv: Fix wslot_to_devfn() to fix warnings on device removal
+-    - SAUCE: pci-hyperv: properly handle pci bus remove
+-    - SAUCE: pci-hyperv: lock pci bus on device eject
+-
+-  * [Hyper-V/Azure] Please include Mellanox OFED drivers in Azure kernel and
+-    image (LP: #1650058)
+-    - net/mlx4_en: Fix bad WQE issue
+-    - net/mlx4_core: Fix racy CQ (Completion Queue) free
+-    - net/mlx4_core: Fix when to save some qp context flags for dynamic VST to VGT
+-      transitions
+-    - net/mlx4_core: Avoid command timeouts during VF driver device shutdown
+-
+-  * Xenial update to v4.4.49 stable release (LP: #1664960)
+-    - ARC: [arcompact] brown paper bag bug in unaligned access delay slot fixup
+-    - selinux: fix off-by-one in setprocattr
+-    - Revert "x86/ioapic: Restore IO-APIC irq_chip retrigger callback"
+-    - cpumask: use nr_cpumask_bits for parsing functions
+-    - hns: avoid stack overflow with CONFIG_KASAN
+-    - ARM: 8643/3: arm/ptrace: Preserve previous registers for short regset write
+-    - target: Don't BUG_ON during NodeACL dynamic -> explicit conversion
+-    - target: Use correct SCSI status during EXTENDED_COPY exception
+-    - target: Fix early transport_generic_handle_tmr abort scenario
+-    - target: Fix COMPARE_AND_WRITE ref leak for non GOOD status
+-    - ARM: 8642/1: LPAE: catch pending imprecise abort on unmask
+-    - mac80211: Fix adding of mesh vendor IEs
+-    - netvsc: Set maximum GSO size in the right place
+-    - scsi: zfcp: fix use-after-free by not tracing WKA port open/close on failed
+-      send
+-    - scsi: aacraid: Fix INTx/MSI-x issue with older controllers
+-    - scsi: mpt3sas: disable ASPM for MPI2 controllers
+-    - xen-netfront: Delete rx_refill_timer in xennet_disconnect_backend()
+-    - ALSA: seq: Fix race at creating a queue
+-    - ALSA: seq: Don't handle loop timeout at snd_seq_pool_done()
+-    - drm/i915: fix use-after-free in page_flip_completed()
+-    - Linux 4.4.49
+-
+-  * NFS client : kernel 4.4.0-57 crash with nfsv4 enries in /etc/fstab
+-    (LP: #1650336)
+-    - SUNRPC: fix refcounting problems with auth_gss messages.
+-
+-  * [0bda:0328] Card reader failed after S3 (LP: #1664809)
+-    - usb: hub: Wait for connection to be reestablished after port reset
+-
+-  * linux-lts-xenial 4.4.0-63.84~14.04.2 ADT test failure with linux-lts-xenial
+-    4.4.0-63.84~14.04.2 (LP: #1664912)
+-    - SAUCE: apparmor: fix link auditing failure due to, uninitialized var
+-
+-  * ibmvscsis: Add SGL LIMIT (LP: #1662551)
+-    - ibmvscsis: Add SGL limit
+-
+-  * [Hyper-V] Bug fixes for storvsc (tagged queuing, error conditions)
+-    (LP: #1663687)
+-    - scsi: storvsc: Enable tracking of queue depth
+-    - scsi: storvsc: Remove the restriction on max segment size
+-    - scsi: storvsc: Enable multi-queue support
+-    - scsi: storvsc: use tagged SRB requests if supported by the device
+-    - scsi: storvsc: properly handle SRB_ERROR when sense message is present
+-    - scsi: storvsc: properly set residual data length on errors
+-
+-  * ISST-LTE:pNV: ppc64_cpu command is hung w HDs, SSDs and NVMe (LP: #1662666)
+-    - blk-mq: Avoid memory reclaim when remapping queues
+-    - blk-mq: Fix failed allocation path when mapping queues
+-
+-  * Possible missing firmware /lib/firmware/i915/kbl_dmc_ver1.bin for module
+-    i915_bpo (LP: #1624164)
+-    - SAUCE: i915_bpo: Remove MODULE_FIRMWARE statement for i915/kbl_dmc_ver1.bin
+-
+-  *  Intel I210 ethernet does not work both after S3 (LP: #1662763)
+-    - igb: implement igb_ptp_suspend
+-    - igb: call igb_ptp_suspend during suspend/resume cycle
+-
+-  * [Hyper-V] Fix ring buffer handling to avoid host throttling (LP: #1661430)
+-    - Drivers: hv: vmbus: On write cleanup the logic to interrupt the host
+-    - Drivers: hv: vmbus: On the read path cleanup the logic to interrupt the host
+-    - Drivers: hv: vmbus: finally fix hv_need_to_signal_on_read()
+-
+-  * brd module compiled as built-in (LP: #1593293)
+-    - [Config] CONFIG_BLK_DEV_RAM=m
+-
+-  * regession tests failing after stackprofile test is run (LP: #1661030)
+-    - SAUCE: fix regression with domain change in complain mode
+-
+-  * Permission denied and inconsistent behavior in complain mode with 'ip netns
+-    list' command (LP: #1648903)
+-    - SAUCE: fix regression with domain change in complain mode
+-
+-  * flock not mediated by 'k' (LP: #1658219)
+-    - SAUCE: apparmor: flock mediation is not being enforced on cache check
+-
+-  * unexpected errno=13 and disconnected path when trying to open /proc/1/ns/mnt
+-    from a unshared mount namespace (LP: #1656121)
+-    - SAUCE: apparmor: null profiles should inherit parent control flags
+-
+-  * apparmor refcount leak of profile namespace when removing profiles
+-    (LP: #1660849)
+-    - SAUCE: apparmor: fix ns ref count link when removing profiles from policy
+-
+-  * tor in lxd: apparmor="DENIED" operation="change_onexec"
+-    namespace="root//CONTAINERNAME_<var-lib-lxd>" profile="unconfined"
+-    name="system_tor" (LP: #1648143)
+-    - SAUCE: apparmor: Fix no_new_privs blocking change_onexec when using stacked
+-      namespaces
+-
+-  * apparmor_parser hangs indefinitely when called by multiple threads
+-    (LP: #1645037)
+-    - SAUCE: apparmor: fix lock ordering for mkdir
+-
+-  * apparmor leaking securityfs pin count (LP: #1660846)
+-    - SAUCE: apparmor: fix leak on securityfs pin count
+-
+-  * apparmor reference count leak when securityfs_setup_d_inode\ () fails
+-    (LP: #1660845)
+-    - SAUCE: apparmor: fix reference count leak when securityfs_setup_d_inode()
+-      fails
+-
+-  * apparmor not checking error if security_pin_fs() fails (LP: #1660842)
+-    - SAUCE: apparmor: fix not handling error case when securityfs_pin_fs() fails
+-
+-  * apparmor oops in bind_mnt when dev_path lookup fails (LP: #1660840)
+-    - SAUCE: apparmor: fix oops in bind_mnt when dev_path lookup fails
+-
+-  * apparmor  auditing denied access of special apparmor .null fi\ le
+-    (LP: #1660836)
+-    - SAUCE: apparmor: Don't audit denied access of special apparmor .null file
+-
+-  * apparmor label leak when new label is unused (LP: #1660834)
+-    - SAUCE: apparmor: fix label leak when new label is unused
+-
+-  * apparmor reference count bug in label_merge_insert() (LP: #1660833)
+-    - SAUCE: apparmor: fix reference count bug in label_merge_insert()
+-
+-  * apparmor's raw_data file in securityfs is sometimes truncated (LP: #1638996)
+-    - SAUCE: apparmor: fix replacement race in reading rawdata
+-
+-  * unix domain socket cross permission check failing with nested namespaces
+-    (LP: #1660832)
+-    - SAUCE: apparmor: fix cross ns perm of unix domain sockets
+-
+-  * docker permission issues with overlay2 storage driver (LP: #1659417)
+-    - SAUCE: overlayfs: Replace ovl_prepare_creds() with ovl_override_creds()
+-    - Revert "UBUNTU: SAUCE: cred: Add clone_cred() interface"
+-    - ovl: check mounter creds on underlying lookup
+-
+-  * Enable CONFIG_NET_DROP_MONITOR=m in Ubuntu Kernel (LP: #1660634)
+-    - [Config] CONFIG_NET_DROP_MONITOR=m
+-
+-  * Xenial update to v4.4.48 stable release (LP: #1663657)
+-    - PCI/ASPM: Handle PCI-to-PCIe bridges as roots of PCIe hierarchies
+-    - ext4: validate s_first_meta_bg at mount time
+-    - drm/nouveau/disp/gt215: Fix HDA ELD handling (thus, HDMI audio) on gt215
+-    - drm/nouveau/nv1a,nv1f/disp: fix memory clock rate retrieval
+-    - crypto: api - Clear CRYPTO_ALG_DEAD bit before registering an alg
+-    - crypto: arm64/aes-blk - honour iv_out requirement in CBC and CTR modes
+-    - perf/core: Fix PERF_RECORD_MMAP2 prot/flags for anonymous memory
+-    - ata: sata_mv:- Handle return value of devm_ioremap.
+-    - libata: apply MAX_SEC_1024 to all CX1-JB*-HP devices
+-    - powerpc/eeh: Fix wrong flag passed to eeh_unfreeze_pe()
+-    - powerpc: Add missing error check to prom_find_boot_cpu()
+-    - NFSD: Fix a null reference case in find_or_create_lock_stateid()
+-    - svcrpc: fix oops in absence of krb5 module
+-    - zswap: disable changing params if init fails
+-    - cifs: initialize file_info_lock
+-    - mm/memory_hotplug.c: check start_pfn in test_pages_in_a_zone()
+-    - mm, fs: check for fatal signals in do_generic_file_read()
+-    - can: bcm: fix hrtimer/tasklet termination in bcm op removal
+-    - mmc: sdhci: Ignore unexpected CARD_INT interrupts
+-    - percpu-refcount: fix reference leak during percpu-atomic transition
+-    - HID: wacom: Fix poor prox handling in 'wacom_pl_irq'
+-    - KVM: x86: do not save guest-unsupported XSAVE state
+-    - USB: serial: qcserial: add Dell DW5570 QDL
+-    - USB: serial: pl2303: add ATEN device ID
+-    - USB: Add quirk for WORLDE easykey.25 MIDI keyboard
+-    - usb: gadget: f_fs: Assorted buffer overflow checks.
+-    - USB: serial: option: add device ID for HP lt2523 (Novatel E371)
+-    - x86/irq: Make irq activate operations symmetric
+-    - base/memory, hotplug: fix a kernel oops in show_valid_zones()
+-    - Linux 4.4.48
+-
+-  * Xenial update to v4.4.47 stable release (LP: #1662507)
+-    - r8152: fix the sw rx checksum is unavailable
+-    - mlxsw: spectrum: Fix memory leak at skb reallocation
+-    - mlxsw: switchx2: Fix memory leak at skb reallocation
+-    - mlxsw: pci: Fix EQE structure definition
+-    - net: lwtunnel: Handle lwtunnel_fill_encap failure
+-    - net: ipv4: fix table id in getroute response
+-    - net: systemport: Decouple flow control from __bcm_sysport_tx_reclaim
+-    - tcp: fix tcp_fastopen unaligned access complaints on sparc
+-    - openvswitch: maintain correct checksum state in conntrack actions
+-    - ravb: do not use zero-length alignment DMA descriptor
+-    - ax25: Fix segfault after sock connection timeout
+-    - net: fix harmonize_features() vs NETIF_F_HIGHDMA
+-    - net: phy: bcm63xx: Utilize correct config_intr function
+-    - ipv6: addrconf: Avoid addrconf_disable_change() using RCU read-side lock
+-    - tcp: initialize max window for a new fastopen socket
+-    - bridge: netlink: call br_changelink() during br_dev_newlink()
+-    - r8152: don't execute runtime suspend if the tx is not empty
+-    - af_unix: move unix_mknod() out of bindlock
+-    - qmi_wwan/cdc_ether: add device ID for HP lt2523 (Novatel E371) WWAN card
+-    - net: dsa: Bring back device detaching in dsa_slave_suspend()
+-    - Linux 4.4.47
+-
+-  * Xenial update to v4.4.46 stable release (LP: #1660994)
+-    - fbdev: color map copying bounds checking
+-    - tile/ptrace: Preserve previous registers for short regset write
+-    - drm: Fix broken VT switch with video=1366x768 option
+-    - mm/mempolicy.c: do not put mempolicy before using its nodemask
+-    - sysctl: fix proc_doulongvec_ms_jiffies_minmax()
+-    - ISDN: eicon: silence misleading array-bounds warning
+-    - RDMA/cma: Fix unknown symbol when CONFIG_IPV6 is not enabled
+-    - s390/ptrace: Preserve previous registers for short regset write
+-    - can: c_can_pci: fix null-pointer-deref in c_can_start() - set device pointer
+-    - can: ti_hecc: add missing prepare and unprepare of the clock
+-    - ARC: udelay: fix inline assembler by adding LP_COUNT to clobber list
+-    - ARC: [arcompact] handle unaligned access delay slot corner case
+-    - parisc: Don't use BITS_PER_LONG in userspace-exported swab.h header
+-    - nfs: Don't increment lock sequence ID after NFS4ERR_MOVED
+-    - NFSv4.0: always send mode in SETATTR after EXCLUSIVE4
+-    - SUNRPC: cleanup ida information when removing sunrpc module
+-    - drm/i915: Don't leak edid in intel_crt_detect_ddc()
+-    - IB/ipoib: move back IB LL address into the hard header
+-    - IB/umem: Release pid in error and ODP flow
+-    - s5k4ecgx: select CRC32 helper
+-    - pinctrl: broxton: Use correct PADCFGLOCK offset
+-    - platform/x86: intel_mid_powerbtn: Set IRQ_ONESHOT
+-    - mm, memcg: do not retry precharge charges
+-    - Linux 4.4.46
+-
+-  * Xenial update to v4.4.45 stable release (LP: #1660993)
+-    - ftrace/x86: Set ftrace_stub to weak to prevent gcc from using short jumps to
+-      it
+-    - IB/mlx5: Wait for all async command completions to complete
+-    - IB/mlx4: Set traffic class in AH
+-    - IB/mlx4: Fix out-of-range array index in destroy qp flow
+-    - IB/mlx4: Fix port query for 56Gb Ethernet links
+-    - IB/mlx4: When no DMFS for IPoIB, don't allow NET_IF QPs
+-    - IB/IPoIB: Remove can't use GFP_NOIO warning
+-    - perf scripting: Avoid leaking the scripting_context variable
+-    - ARM: dts: imx31: fix clock control module interrupts description
+-    - ARM: dts: imx31: move CCM device node to AIPS2 bus devices
+-    - ARM: dts: imx31: fix AVIC base address
+-    - tmpfs: clear S_ISGID when setting posix ACLs
+-    - x86/PCI: Ignore _CRS on Supermicro X8DTH-i/6/iF/6F
+-    - svcrpc: don't leak contexts on PROC_DESTROY
+-    - fuse: clear FR_PENDING flag when moving requests out of pending queue
+-    - PCI: Enumerate switches below PCI-to-PCIe bridges
+-    - HID: corsair: fix DMA buffers on stack
+-    - HID: corsair: fix control-transfer error handling
+-    - mmc: mxs-mmc: Fix additional cycles after transmission stop
+-    - ieee802154: atusb: do not use the stack for buffers to make them DMA able
+-    - mtd: nand: xway: disable module support
+-    - x86/ioapic: Restore IO-APIC irq_chip retrigger callback
+-    - qla2xxx: Fix crash due to null pointer access
+-    - ubifs: Fix journal replay wrt. xattr nodes
+-    - clocksource/exynos_mct: Clear interrupt when cpu is shut down
+-    - svcrdma: avoid duplicate dma unmapping during error recovery
+-    - ARM: 8634/1: hw_breakpoint: blacklist Scorpion CPUs
+-    - ceph: fix bad endianness handling in parse_reply_info_extra
+-    - ARM: dts: da850-evm: fix read access to SPI flash
+-    - arm64/ptrace: Preserve previous registers for short regset write
+-    - arm64/ptrace: Preserve previous registers for short regset write - 2
+-    - arm64/ptrace: Preserve previous registers for short regset write - 3
+-    - arm64/ptrace: Avoid uninitialised struct padding in fpr_set()
+-    - arm64/ptrace: Reject attempts to set incomplete hardware breakpoint fields
+-    - ARM: dts: imx6qdl-nitrogen6_max: fix sgtl5000 pinctrl init
+-    - ARM: ux500: fix prcmu_is_cpu_in_wfi() calculation
+-    - ARM: 8613/1: Fix the uaccess crash on PB11MPCore
+-    - blackfin: check devm_pinctrl_get() for errors
+-    - ite-cir: initialize use_demodulator before using it
+-    - dmaengine: pl330: Fix runtime PM support for terminated transfers
+-    - selftest/powerpc: Wrong PMC initialized in pmc56_overflow test
+-    - arm64: avoid returning from bad_mode
+-    - Linux 4.4.45
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 08 Mar 2017 11:47:26 -0300
+-
+-linux (4.4.0-66.87) xenial; urgency=low
+-
+-  * CVE-2017-2636
+-    - TTY: n_hdlc, fix lockdep false positive
+-    - tty: n_hdlc: get rid of racy n_hdlc.tbuf
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Fri, 03 Mar 2017 12:01:27 +0100
+-
+-linux (4.4.0-64.85) xenial; urgency=low
+-
+-  * CVE-2017-6074 (LP: #1665935)
+-    - dccp: fix freeing skb too early for IPV6_RECVPKTINFO
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Mon, 20 Feb 2017 11:06:47 +0100
+-
+-linux (4.4.0-63.84) xenial; urgency=low
+-
+-  [ Thadeu Lima de Souza Cascardo ]
+-
+-  * Release Tracking Bug
+-    - LP: #1660704
+-
+-  * Backport Dirty COW patch to prevent wineserver freeze (LP: #1658270)
+-    - SAUCE: mm: Respect FOLL_FORCE/FOLL_COW for thp
+-
+-  * Kdump through NMI SMP and single core not working on Ubuntu16.10
+-    (LP: #1630924)
+-    - x86/hyperv: Handle unknown NMIs on one CPU when unknown_nmi_panic
+-    - SAUCE: hv: don't reset hv_context.tsc_page on crash
+-
+-  * [regression 4.8.0-14 -> 4.8.0-17] keyboard and touchscreen lost on Acer
+-    Chromebook R11 (LP: #1630238)
+-    - [Config] CONFIG_PINCTRL_CHERRYVIEW=y
+-
+-  * Call trace when testing fstat stressor on ppc64el with virtual  keyboard and
+-    mouse present (LP: #1652132)
+-    - SAUCE: HID: usbhid: Quirk a AMI virtual mouse and keyboard with ALWAYS_POLL
+-
+-  * VLAN SR-IOV regression for IXGBE driver (LP: #1658491)
+-    - ixgbe: Force VLNCTRL.VFE to be set in all VMDq paths
+-
+-  * "Out of memory" errors after upgrade to 4.4.0-59 (LP: #1655842)
+-    - mm, page_alloc: convert alloc_flags to unsigned
+-    - mm, compaction: change COMPACT_ constants into enum
+-    - mm, compaction: distinguish COMPACT_DEFERRED from COMPACT_SKIPPED
+-    - mm, compaction: simplify __alloc_pages_direct_compact feedback interface
+-    - mm, compaction: distinguish between full and partial COMPACT_COMPLETE
+-    - mm, compaction: abstract compaction feedback to helpers
+-    - mm, oom: protect !costly allocations some more
+-    - mm: consider compaction feedback also for costly allocation
+-    - mm, oom, compaction: prevent from should_compact_retry looping for ever for
+-      costly orders
+-    - mm, oom: protect !costly allocations some more for !CONFIG_COMPACTION
+-    - mm, oom: prevent premature OOM killer invocation for high order request
+-
+-  * Backport 3 patches to fix bugs with AIX clients using IBMVSCSI Target Driver
+-    (LP: #1657194)
+-    - SAUCE: ibmvscsis: Fix max transfer length
+-    - SAUCE: ibmvscsis: fix sleeping in interrupt context
+-    - SAUCE: ibmvscsis: Fix srp_transfer_data fail return code
+-
+-  * NVMe: adapter is missing after abnormal shutdown followed by quick reboot,
+-    quirk needed (LP: #1656913)
+-    - nvme: apply DELAY_BEFORE_CHK_RDY quirk at probe time too
+-
+-  * Ubuntu 16.10 KVM SRIOV: if enable sriov while ping flood is running ping
+-    will stop working (LP: #1625318)
+-    - PCI: Do any VF BAR updates before enabling the BARs
+-    - PCI: Ignore BAR updates on virtual functions
+-    - PCI: Update BARs using property bits appropriate for type
+-    - PCI: Separate VF BAR updates from standard BAR updates
+-    - PCI: Don't update VF BARs while VF memory space is enabled
+-    - PCI: Remove pci_resource_bar() and pci_iov_resource_bar()
+-    - PCI: Decouple IORESOURCE_ROM_ENABLE and PCI_ROM_ADDRESS_ENABLE
+-    - PCI: Add comments about ROM BAR updating
+-
+-  * Linux rtc self test fails in a VM under xenial (LP: #1649718)
+-    - kvm: x86: Convert ioapic->rtc_status.dest_map to a struct
+-    - kvm: x86: Track irq vectors in ioapic->rtc_status.dest_map
+-    - kvm: x86: Check dest_map->vector to match eoi signals for rtc
+-
+-  * Xenial update to v4.4.44 stable release (LP: #1658091)
+-    - Input: xpad - use correct product id for x360w controllers
+-    - Input: i8042 - add Pegatron touchpad to noloop table
+-    - selftests: do not require bash to run netsocktests testcase
+-    - selftests: do not require bash for the generated test
+-    - mm: fix devm_memremap_pages crash, use mem_hotplug_{begin, done}
+-    - ocfs2: fix crash caused by stale lvb with fsdlm plugin
+-    - mm/hugetlb.c: fix reservation race when freeing surplus pages
+-    - KVM: x86: fix emulation of "MOV SS, null selector"
+-    - KVM: eventfd: fix NULL deref irqbypass consumer
+-    - jump_labels: API for flushing deferred jump label updates
+-    - KVM: x86: flush pending lapic jump label updates on module unload
+-    - KVM: x86: add Align16 instruction flag
+-    - KVM: x86: add asm_safe wrapper
+-    - KVM: x86: emulate FXSAVE and FXRSTOR
+-    - KVM: x86: Introduce segmented_write_std
+-    - nl80211: fix sched scan netlink socket owner destruction
+-    - USB: serial: kl5kusb105: fix line-state error handling
+-    - USB: serial: ch341: fix initial modem-control state
+-    - USB: serial: ch341: fix open error handling
+-    - USB: serial: ch341: fix control-message error handling
+-    - USB: serial: ch341: fix open and resume after B0
+-    - Input: elants_i2c - avoid divide by 0 errors on bad touchscreen data
+-    - i2c: print correct device invalid address
+-    - i2c: fix kernel memory disclosure in dev interface
+-    - xhci: fix deadlock at host remove by running watchdog correctly
+-    - vme: Fix wrong pointer utilization in ca91cx42_slave_get
+-    - mnt: Protect the mountpoint hashtable with mount_lock
+-    - tty/serial: atmel_serial: BUG: stop DMA from transmitting in stop_tx
+-    - sysrq: attach sysrq handler correctly for 32-bit kernel
+-    - sysctl: Drop reference added by grab_header in proc_sys_readdir
+-    - drm/radeon: drop verde dpm quirks
+-    - USB: serial: ch341: fix resume after reset
+-    - USB: serial: ch341: fix modem-control and B0 handling
+-    - x86/cpu: Fix bootup crashes by sanitizing the argument of the 'clearcpuid='
+-      command-line option
+-    - btrfs: fix locking when we put back a delayed ref that's too new
+-    - btrfs: fix error handling when run_delayed_extent_op fails
+-    - pinctrl: meson: fix gpio request disabling other modes
+-    - pNFS: Fix race in pnfs_wait_on_layoutreturn
+-    - NFS: Fix a performance regression in readdir
+-    - NFSv4.1: nfs4_fl_prepare_ds must be careful about reporting success.
+-    - cpufreq: powernv: Disable preemption while checking CPU throttling state
+-    - block: cfq_cpd_alloc() should use @gfp
+-    - ACPI / APEI: Fix NMI notification handling
+-    - blk-mq: Always schedule hctx->next_cpu
+-    - bus: vexpress-config: fix device reference leak
+-    - powerpc/ibmebus: Fix further device reference leaks
+-    - powerpc/ibmebus: Fix device reference leaks in sysfs interface
+-    - pinctrl: sh-pfc: Do not unconditionally support PIN_CONFIG_BIAS_DISABLE
+-    - Linux 4.4.44
+-
+-  * Add support for RT5660 codec based sound cards on Baytrail (LP: #1657674)
+-    - ASoC: rt5660: add rt5660 codec driver
+-    - ASoC: rt5660: enable MCLK detection
+-    - ASoC: Intel: Atom: flip logic for gain Switch
+-    - SAUCE: (no-up) ASoC: rt5660: Add ACPI support
+-    - SAUCE: (no-up) ASoC: Intel: Support machine driver for RT5660 on Baytrail
+-    - [Config] CONFIG_SND_SOC_INTEL_BYTCR_RT5660_MACH=m, CONFIG_SND_SOC_RT5660=m
+-
+-  * Support latest Redpine WLAN/BT RS9113 driver (LP: #1657682)
+-    - SAUCE: Support Redpine RS9113 WLAN/BT
+-    - SAUCE: Separate Redpine RS9113 WLAN/BT vendor and kernel drivers
+-    - SAUCE: Redpine RS9113 WLAN/BT driver ver. 0.9.7
+-    - SAUCE: RS9113: Use vendor driver to support WLAN/BT card on Caracalla HW
+-      only
+-    - SAUCE: RS9113: Comment out IDs from upstream driver
+-    - [Config] Enable CONFIG_VEN_RSI_* configs
+-
+-  * [Hyper-V] netvsc: add rcu_read locked to netvsc callback (LP: #1657540)
+-    - netvsc: add rcu_read locking to netvsc callback
+-
+-  * [Hyper-V] Rebase Hyper-V in 16.04 and 16.10 to the the upstream 4.9 kernel
+-    (LP: #1650059)
+-    - memory-hotplug: add automatic onlining policy for the newly added memory
+-    - hv_netvsc: Add query for initial physical link speed
+-    - hv_netvsc: Add handler for physical link speed change
+-    - hv_netvsc: Implement batching of receive completions
+-    - PCI: hv: Use list_move_tail() instead of list_del() + list_add_tail()
+-    - hv_netvsc: fix rtnl locking in callback
+-    - hv_netvsc: make RSS hash key static
+-    - hv_netvsc: use kcalloc
+-    - hv_netvsc: style cleanups
+-    - hv_netvsc: make inline functions static
+-    - hv_netvsc: use ARRAY_SIZE() for NDIS versions
+-    - hv_netvsc: make device_remove void
+-    - hv_netvsc: init completion during alloc
+-    - hv_netvsc: rearrange start_xmit
+-    - hv_netvsc: refactor completion function
+-    - hv_netvsc: make netvsc_destroy_buf void
+-    - hv_netvsc: make variable local
+-    - hv_netvsc: report vmbus name in ethtool
+-    - hv_netvsc: add ethtool statistics for tx packet issues
+-    - Drivers: hv: get rid of redundant messagecount in create_gpadl_header()
+-    - Drivers: hv: don't leak memory in vmbus_establish_gpadl()
+-    - Drivers: hv: get rid of timeout in vmbus_open()
+-    - Drivers: hv: utils: fix a race on userspace daemons registration
+-    - Drivers: hv: vmbus: fix the race when querying & updating the percpu list
+-    - Drivers: hv: vmbus: Enable explicit signaling policy for NIC channels
+-    - Drivers: hv: vmbus: Reduce the delay between retries in vmbus_post_msg()
+-    - Drivers: hv: vmbus: Implement a mechanism to tag the channel for low latency
+-    - Tools: hv: kvp: ensure kvp device fd is closed on exec
+-    - Drivers: hv: balloon: keep track of where ha_region starts
+-    - Drivers: hv: balloon: account for gaps in hot add regions
+-    - Drivers: hv: balloon: don't wait for ol_waitevent when memhp_auto_online is
+-      enabled
+-    - Drivers: hv: balloon: replace ha_region_mutex with spinlock
+-    - Drivers: hv: balloon: Use available memory value in pressure report
+-    - Drivers: hv: cleanup vmbus_open() for wrap around mappings
+-    - Drivers: hv: ring_buffer: wrap around mappings for ring buffers
+-    - Drivers: hv: ring_buffer: use wrap around mappings in hv_copy{from,
+-      to}_ringbuffer()
+-    - Drivers: hv: ring_buffer: count on wrap around mappings in
+-      get_next_pkt_raw()
+-    - Drivers: hv: Introduce a policy for controlling channel affinity
+-    - Drivers: hv: utils: Continue to poll VSS channel after handling requests.
+-    - Drivers: hv: utils: Check VSS daemon is listening before a hot backup
+-    - PCI: hv: Use zero-length array in struct pci_packet
+-    - PCI: hv: Use pci_function_description[0] in struct definitions
+-    - PCI: hv: Remove the unused 'wrk' in struct hv_pcibus_device
+-    - PCI: hv: Handle vmbus_sendpacket() failure in hv_compose_msi_msg()
+-    - PCI: hv: Handle hv_pci_generic_compl() error case
+-    - Revert "Drivers: hv: ring_buffer: count on wrap around mappings in
+-      get_next_pkt_raw()"
+-    - Driver: hv: vmbus: Make mmio resource local
+-    - Drivers: hv: vmbus: suppress some "hv_vmbus: Unknown GUID" warnings
+-    - Drivers: hv: utils: Rename version definitions to reflect protocol version.
+-    - Drivers: hv: utils: Use TimeSync samples to adjust the clock after boot.
+-    - Drivers: hv: utils: Support TimeSync version 4.0 protocol samples.
+-    - Drivers: hv: hv_util: Avoid dynamic allocation in time synch
+-    - Revert "hv_netvsc: make inline functions static"
+-    - hv_netvsc: use consume_skb
+-    - hv_netvsc: dev hold/put reference to VF
+-    - hv_netvsc: simplify callback event code
+-    - hv_netvsc: improve VF device matching
+-    - hv_netvsc: use RCU to protect vf_netdev
+-    - hv_netvsc: remove VF in flight counters
+-    - hv_netvsc: count multicast packets received
+-    - hv_netvsc: fix comments
+-    - Drivers: hv: make VMBus bus ids persistent
+-    - Drivers: hv: get rid of id in struct vmbus_channel
+-    - netvsc: fix checksum on UDP IPV6
+-    - netvsc: Remove mistaken udp.h inclusion.
+-    - net/hyperv: avoid uninitialized variable
+-    - Revert "hv_netvsc: report vmbus name in ethtool"
+-    - vmbus: make sysfs names consistent with PCI
+-    - netvsc: reduce maximum GSO size
+-    - Drivers: hv: vmbus: Base host signaling strictly on the ring state
+-    - tools: hv: Add a script to help bonding synthetic and VF NICs
+-
+-  * Ubuntu - ibmveth: abnormally large TCP MSS value caused a TCP session to
+-    hang with a zero window (LP: #1655420)
+-    - ibmveth: set correct gso_size and gso_type
+-    - ibmveth: calculate gso_segs for large packets
+-
+-  * netfilter regression introducing a performance slowdown in binary
+-    arp/ip/ip6tables (LP: #1640786)
+-    - netfilter: x_tables: pass xt_counters struct instead of packet counter
+-    - netfilter: x_tables: pass xt_counters struct to counter allocator
+-    - netfilter: x_tables: pack percpu counter allocations
+-
+-  * Move some kernel modules to the main kernel package (part 2) (LP: #1655002)
+-    - [Config] Add IBM power drivers to the inclusion list
+-
+-  * Xenial update to v4.4.43 stable release (LP: #1656876)
+-    - netvsc: reduce maximum GSO size
+-    - ser_gigaset: return -ENOMEM on error instead of success
+-    - net: vrf: Drop conntrack data after pass through VRF device on Tx
+-    - ipv6: handle -EFAULT from skb_copy_bits
+-    - net, sched: fix soft lockup in tc_classify
+-    - net: stmmac: Fix race between stmmac_drv_probe and stmmac_open
+-    - net/mlx5: Check FW limitations on log_max_qp before setting it
+-    - net/mlx5: Avoid shadowing numa_node
+-    - drop_monitor: add missing call to genlmsg_end
+-    - drop_monitor: consider inserted data in genlmsg_end
+-    - igmp: Make igmp group member RFC 3376 compliant
+-    - ipv4: Do not allow MAIN to be alias for new LOCAL w/ custom rules
+-    - r8152: split rtl8152_suspend function
+-    - r8152: fix rx issue for runtime suspend
+-    - gro: Enter slow-path if there is no tailroom
+-    - gro: use min_t() in skb_gro_reset_offset()
+-    - gro: Disable frag0 optimization on IPv6 ext headers
+-    - net: ipv4: Fix multipath selection with vrf
+-    - net: vrf: do not allow table id 0
+-    - HID: hid-cypress: validate length of report
+-    - ALSA: firewire-tascam: Fix to handle error from initialization of stream
+-      data
+-    - powerpc: Fix build warning on 32-bit PPC
+-    - ARM: zynq: Reserve correct amount of non-DMA RAM
+-    - ARM: OMAP4+: Fix bad fallthrough for cpuidle
+-    - spi: mvebu: fix baudrate calculation for armada variant
+-    - ALSA: usb-audio: Add a quirk for Plantronics BT600
+-    - mm/init: fix zone boundary creation
+-    - Linux 4.4.43
+-
+-  * Xenial update to v4.4.42 stable release (LP: #1655969)
+-    - ALSA: hda - Fix up GPIO for ASUS ROG Ranger
+-    - ALSA: hda - Apply asus-mode8 fixup to ASUS X71SL
+-    - ALSA: usb-audio: Fix irq/process data synchronization
+-    - ARM: davinci: da850: don't add emac clock to lookup table twice
+-    - mac80211: initialize fast-xmit 'info' later
+-    - KVM: x86: reset MMU on KVM_SET_VCPU_EVENTS
+-    - KVM: MIPS: Flush KVM entry code from icache globally
+-    - usb: musb: core: add clear_ep_rxintr() to musb_platform_ops
+-    - usb: musb: dsps: implement clear_ep_rxintr() callback
+-    - usb: storage: unusual_uas: Add JMicron JMS56x to unusual device
+-    - usb: gadgetfs: restrict upper bound on device configuration size
+-    - USB: gadgetfs: fix unbounded memory allocation bug
+-    - USB: gadgetfs: fix use-after-free bug
+-    - USB: gadgetfs: fix checks of wTotalLength in config descriptors
+-    - USB: fix problems with duplicate endpoint addresses
+-    - USB: dummy-hcd: fix bug in stop_activity (handle ep0)
+-    - usb: gadget: composite: Test get_alt() presence instead of set_alt()
+-    - usb: dwc3: core: avoid Overflow events
+-    - usb: xhci: fix possible wild pointer
+-    - xhci: workaround for hosts missing CAS bit
+-    - usb: xhci: apply XHCI_PME_STUCK_QUIRK to Intel Apollo Lake
+-    - xhci: free xhci virtual devices with leaf nodes first
+-    - usb: xhci: fix return value of xhci_setup_device()
+-    - usb: host: xhci: Fix possible wild pointer when handling abort command
+-    - xhci: Handle command completion and timeout race
+-    - usb: xhci: hold lock over xhci_abort_cmd_ring()
+-    - USB: serial: omninet: fix NULL-derefs at open and disconnect
+-    - USB: serial: quatech2: fix sleep-while-atomic in close
+-    - USB: serial: pl2303: fix NULL-deref at open
+-    - USB: serial: keyspan_pda: verify endpoints at probe
+-    - USB: serial: spcp8x5: fix NULL-deref at open
+-    - USB: serial: io_ti: fix NULL-deref at open
+-    - USB: serial: io_ti: fix another NULL-deref at open
+-    - USB: serial: io_ti: fix I/O after disconnect
+-    - USB: serial: iuu_phoenix: fix NULL-deref at open
+-    - USB: serial: garmin_gps: fix memory leak on failed URB submit
+-    - USB: serial: ti_usb_3410_5052: fix NULL-deref at open
+-    - USB: serial: io_edgeport: fix NULL-deref at open
+-    - USB: serial: oti6858: fix NULL-deref at open
+-    - USB: serial: cyberjack: fix NULL-deref at open
+-    - USB: serial: kobil_sct: fix NULL-deref in write
+-    - USB: serial: mos7840: fix NULL-deref at open
+-    - USB: serial: mos7720: fix NULL-deref at open
+-    - USB: serial: mos7720: fix use-after-free on probe errors
+-    - USB: serial: mos7720: fix parport use-after-free on probe errors
+-    - USB: serial: mos7720: fix parallel probe
+-    - usb: xhci-mem: use passed in GFP flags instead of GFP_KERNEL
+-    - xhci: Use delayed_work instead of timer for command timeout
+-    - xhci: Fix race related to abort operation
+-    - usb: dwc3: pci: add Intel Gemini Lake PCI ID
+-    - usb: musb: Fix trying to free already-free IRQ 4
+-    - usb: hub: Move hub_port_disable() to fix warning if PM is disabled
+-    - usb: musb: blackfin: add bfin_fifo_offset in bfin_ops
+-    - ALSA: usb-audio: Fix bogus error return in snd_usb_create_stream()
+-    - USB: serial: kl5kusb105: abort on open exception path
+-    - ARM: dts: r8a7794: Correct hsusb parent clock
+-    - USB: phy: am335x-control: fix device and of_node leaks
+-    - USB: serial: io_ti: bind to interface after fw download
+-    - mei: bus: fix mei_cldev_enable KDoc
+-    - staging: iio: ad7606: fix improper setting of oversampling pins
+-    - usb: dwc3: gadget: always unmap EP0 requests
+-    - usb: dwc3: ep0: add dwc3_ep0_prepare_one_trb()
+-    - usb: dwc3: ep0: explicitly call dwc3_ep0_prepare_one_trb()
+-    - stable-fixup: hotplug: fix unused function warning
+-    - ath10k: use the right length of "background"
+-    - cris: Only build flash rescue image if CONFIG_ETRAX_AXISFLASHMAP is selected
+-    - hwmon: (scpi) Fix module autoload
+-    - hwmon: (amc6821) sign extension temperature
+-    - hwmon: (ds620) Fix overflows seen when writing temperature limits
+-    - hwmon: (nct7802) Fix overflows seen when writing into limit attributes
+-    - hwmon: (g762) Fix overflows and crash seen when writing limit attributes
+-    - clk: clk-wm831x: fix a logic error
+-    - clk: imx31: fix rewritten input argument of mx31_clocks_init()
+-    - iommu/amd: Missing error code in amd_iommu_init_device()
+-    - iommu/amd: Fix the left value check of cmd buffer
+-    - iommu/vt-d: Fix pasid table size encoding
+-    - iommu/vt-d: Flush old iommu caches for kdump when the device gets context
+-      mapped
+-    - ASoC: samsung: i2s: Fixup last IRQ unsafe spin lock call
+-    - scsi: mvsas: fix command_active typo
+-    - target/iscsi: Fix double free in lio_target_tiqn_addtpg()
+-    - irqchip/bcm7038-l1: Implement irq_cpu_offline() callback
+-    - PM / wakeirq: Fix dedicated wakeirq for drivers not using autosuspend
+-    - mmc: mmc_test: Uninitialized return value
+-    - s390/crypto: unlock on error in prng_tdes_read()
+-    - crypto: arm64/sha2-ce - fix for big endian
+-    - crypto: arm64/ghash-ce - fix for big endian
+-    - crypto: arm/aes-ce - fix for big endian
+-    - crypto: arm64/aes-ccm-ce: fix for big endian
+-    - crypto: arm64/aes-neon - fix for big endian
+-    - crypto: arm64/sha1-ce - fix for big endian
+-    - crypto: arm64/aes-xts-ce: fix for big endian
+-    - crypto: arm64/aes-ce - fix for big endian
+-    - md: MD_RECOVERY_NEEDED is set for mddev->recovery
+-    - powerpc/pci/rpadlpar: Fix device reference leaks
+-    - staging: comedi: dt282x: tidy up register bit defines
+-    - cred/userns: define current_user_ns() as a function
+-    - net: ti: cpmac: Fix compiler warning due to type confusion
+-    - net: vxge: avoid unused function warnings
+-    - cx23885-dvb: move initialization of a8293_pdata
+-    - drm/radeon: Always store CRTC relative radeon_crtc->cursor_x/y values
+-    - tick/broadcast: Prevent NULL pointer dereference
+-    - Revert "usb: gadget: composite: always set ep->mult to a sensible value"
+-    - usb: gadget: composite: always set ep->mult to a sensible value
+-    - Linux 4.4.42
+-
+-  * Xenial update to v4.4.41 stable release (LP: #1655041)
+-    - ssb: Fix error routine when fallback SPROM fails
+-    - rtlwifi: Fix enter/exit power_save
+-    - cfg80211/mac80211: fix BSS leaks when abandoning assoc attempts
+-    - ath9k: Really fix LED polarity for some Mini PCI AR9220 MB92 cards.
+-    - mmc: sdhci: Fix recovery from tuning timeout
+-    - regulator: stw481x-vmmc: fix ages old enable error
+-    - timekeeping_Force_unsigned_clocksource_to_nanoseconds_conversion
+-    - clk: bcm2835: Avoid overwriting the div info when disabling a pll_div clk
+-    - thermal: hwmon: Properly report critical temperature in sysfs
+-    - staging: comedi: ni_mio_common: fix M Series ni_ai_insn_read() data mask
+-    - staging: comedi: ni_mio_common: fix E series ni_ai_insn_read() data
+-    - ACPI / video: Add force_native quirk for Dell XPS 17 L702X
+-    - ACPI / video: Add force_native quirk for HP Pavilion dv6
+-    - drm/nouveau/kms: lvds panel strap moved again on maxwell
+-    - drm/nouveau/bios: require checksum to match for fast acpi shadow method
+-    - drm/nouveau/ltc: protect clearing of comptags with mutex
+-    - drm/nouveau/fifo/gf100-: protect channel preempt with subdev mutex
+-    - drm/nouveau/i2c/gk110b,gm10x: use the correct implementation
+-    - drm/radeon: Also call cursor_move_locked when the cursor size changes
+-    - drm/radeon: Hide the HW cursor while it's out of bounds
+-    - drm/radeon: add additional pci revision to dpm workaround
+-    - drm/gma500: Add compat ioctl
+-    - drivers/gpu/drm/ast: Fix infinite loop if read fails
+-    - mei: request async autosuspend at the end of enumeration
+-    - block: protect iterate_bdevs() against concurrent close
+-    - vt: fix Scroll Lock LED trigger name
+-    - scsi: megaraid_sas: For SRIOV enabled firmware, ensure VF driver waits for
+-      30secs before reset
+-    - scsi: megaraid_sas: Do not set MPI2_TYPE_CUDA for JBOD FP path for FW which
+-      does not support JBOD sequence map
+-    - scsi: zfcp: fix use-after-"free" in FC ingress path after TMF
+-    - scsi: zfcp: do not trace pure benign residual HBA responses at default level
+-    - scsi: zfcp: fix rport unblock race with LUN recovery
+-    - scsi: avoid a permanent stop of the scsi device's request queue
+-    - ARC: mm: arc700: Don't assume 2 colours for aliasing VIPT dcache
+-    - firmware: fix usermode helper fallback loading
+-    - s390/vmlogrdr: fix IUCV buffer allocation
+-    - sc16is7xx: Drop bogus use of IRQF_ONESHOT
+-    - md/raid5: limit request size according to implementation limits
+-    - KVM: PPC: Book3S HV: Save/restore XER in checkpointed register state
+-    - KVM: PPC: Book3S HV: Don't lose hardware R/C bit updates in H_PROTECT
+-    - kvm: nVMX: Allow L1 to intercept software exceptions (#BP and #OF)
+-    - platform/x86: asus-nb-wmi.c: Add X45U quirk
+-    - fgraph: Handle a case where a tracer ignores set_graph_notrace
+-    - IB/mad: Fix an array index check
+-    - IPoIB: Avoid reading an uninitialized member variable
+-    - IB/multicast: Check ib_find_pkey() return value
+-    - IB/cma: Fix a race condition in iboe_addr_get_sgid()
+-    - media: solo6x10: fix lockup by avoiding delayed register write
+-    - Input: drv260x - fix input device's parent assignment
+-    - PCI: Check for PME in targeted sleep state
+-    - libceph: verify authorize reply on connect
+-    - nfs_write_end(): fix handling of short copies
+-    - powerpc/ps3: Fix system hang with GCC 5 builds
+-    - powerpc: Convert cmp to cmpd in idle enter sequence
+-    - kconfig/nconf: Fix hang when editing symbol with a long prompt
+-    - sg_write()/bsg_write() is not fit to be called under KERNEL_DS
+-    - net: mvpp2: fix dma unmapping of TX buffers for fragments
+-    - Linux 4.4.41
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 01 Feb 2017 14:00:35 -0200
+-
+-linux (4.4.0-62.83) xenial; urgency=low
+-
+-  [ Thadeu Lima de Souza Cascardo ]
+-
+-  * Release Tracking Bug
+-    - LP: #1657430
+-
+-  * Backport DP MST fixes to i915 (LP: #1657353)
+-    - SAUCE: i915_bpo: Fix DP link rate math
+-    - SAUCE: i915_bpo: Validate mode against max. link data rate for DP MST
+-
+-  * Ubuntu xenial - 4.4.0-59-generic i3 I/O performance issue (LP: #1657281)
+-    - blk-mq: really fix plug list flushing for nomerge queues
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Wed, 18 Jan 2017 09:34:07 -0200
+-
+-linux (4.4.0-61.82) xenial; urgency=low
+-
+-  [ Thadeu Lima de Souza Cascardo ]
+-
+-  * Release Tracking Bug
+-    - LP: #1656810
+-
+-  * Xen MSI setup code incorrectly re-uses cached pirq (LP: #1656381)
+-    - SAUCE: xen: do not re-use pirq number cached in pci device msi msg data
+-
+-  * nvme drive probe failure (LP: #1626894)
+-    - nvme: revert NVMe: only setup MSIX once
+-
+- -- Thadeu Lima de Souza Cascardo <cascardo@canonical.com>  Mon, 16 Jan 2017 10:30:12 -0200
+-
+-linux (4.4.0-60.81) xenial; urgency=low
+-
+-  [ John Donnelly ]
+-
+-  * Release Tracking Bug
+-    - LP: #1656084
+-
+-  * Couldn't emulate instruction 0x7813427c (LP: #1634129)
+-    - KVM: PPC: Book3S PR: Fix illegal opcode emulation
+-
+-  * perf: 24x7: Eliminate domain name suffix in event names (LP: #1560482)
+-    - powerpc/perf/hv-24x7: Fix usage with chip events.
+-    - powerpc/perf/hv-24x7: Display change in counter values
+-    - powerpc/perf/hv-24x7: Display domain indices in sysfs
+-    - powerpc/perf/24x7: Eliminate domain suffix in event names
+-
+-  * i386 ftrace tests hang on ADT testing (LP: #1655040)
+-    - ftrace/x86_32: Set ftrace_stub to weak to prevent gcc from using short jumps
+-      to it
+-
+-  * VMX module autoloading if available (LP: #1651322)
+-    - powerpc: Add module autoloading based on CPU features
+-    - crypto: vmx - Convert to CPU feature based module autoloading
+-
+-  * ACPI probe support for AD5592/3 configurable multi-channel converter
+-    (LP: #1654497)
+-    - SAUCE: iio: dac: ad5592r: Add ACPI support
+-    - SAUCE: iio: dac: ad5593r: Add ACPI support
+-
+-  * Xenial update to v4.4.40 stable release (LP: #1654602)
+-    - btrfs: limit async_work allocation and worker func duration
+-    - Btrfs: fix tree search logic when replaying directory entry deletes
+-    - btrfs: store and load values of stripes_min/stripes_max in balance status
+-      item
+-    - Btrfs: fix qgroup rescan worker initialization
+-    - USB: serial: option: add support for Telit LE922A PIDs 0x1040, 0x1041
+-    - USB: serial: option: add dlink dwm-158
+-    - USB: serial: kl5kusb105: fix open error path
+-    - USB: cdc-acm: add device id for GW Instek AFG-125
+-    - usb: hub: Fix auto-remount of safely removed or ejected USB-3 devices
+-    - usb: gadget: f_uac2: fix error handling at afunc_bind
+-    - usb: gadget: composite: correctly initialize ep->maxpacket
+-    - USB: UHCI: report non-PME wakeup signalling for Intel hardware
+-    - ALSA: usb-audio: Add QuickCam Communicate Deluxe/S7500 to
+-      volume_control_quirks
+-    - ALSA: hiface: Fix M2Tech hiFace driver sampling rate change
+-    - ALSA: hda/ca0132 - Add quirk for Alienware 15 R2 2016
+-    - ALSA: hda - ignore the assoc and seq when comparing pin configurations
+-    - ALSA: hda - fix headset-mic problem on a Dell laptop
+-    - ALSA: hda - Gate the mic jack on HP Z1 Gen3 AiO
+-    - ALSA: hda: when comparing pin configurations, ignore assoc in addition to
+-      seq
+-    - clk: ti: omap36xx: Work around sprz319 advisory 2.1
+-    - Btrfs: fix memory leak in reading btree blocks
+-    - Btrfs: bail out if block group has different mixed flag
+-    - Btrfs: return gracefully from balance if fs tree is corrupted
+-    - Btrfs: don't leak reloc root nodes on error
+-    - Btrfs: fix memory leak in do_walk_down
+-    - Btrfs: don't BUG() during drop snapshot
+-    - btrfs: make file clone aware of fatal signals
+-    - block_dev: don't test bdev->bd_contains when it is not stable
+-    - ptrace: Capture the ptracer's creds not PT_PTRACE_CAP
+-    - crypto: caam - fix AEAD givenc descriptors
+-    - ext4: fix mballoc breakage with 64k block size
+-    - ext4: fix stack memory corruption with 64k block size
+-    - ext4: use more strict checks for inodes_per_block on mount
+-    - ext4: fix in-superblock mount options processing
+-    - ext4: add sanity checking to count_overhead()
+-    - ext4: reject inodes with negative size
+-    - ext4: return -ENOMEM instead of success
+-    - ext4: do not perform data journaling when data is encrypted
+-    - f2fs: set ->owner for debugfs status file's file_operations
+-    - loop: return proper error from loop_queue_rq()
+-    - mm/vmscan.c: set correct defer count for shrinker
+-    - fs: exec: apply CLOEXEC before changing dumpable task flags
+-    - exec: Ensure mm->user_ns contains the execed files
+-    - usb: gadget: composite: always set ep->mult to a sensible value
+-    - blk-mq: Do not invoke .queue_rq() for a stopped queue
+-    - dm flakey: return -EINVAL on interval bounds error in flakey_ctr()
+-    - dm crypt: mark key as invalid until properly loaded
+-    - dm space map metadata: fix 'struct sm_metadata' leak on failed create
+-    - ASoC: intel: Fix crash at suspend/resume without card registration
+-    - CIFS: Fix a possible memory corruption during reconnect
+-    - CIFS: Fix missing nls unload in smb2_reconnect()
+-    - CIFS: Fix a possible memory corruption in push locks
+-    - kernel/watchdog: use nmi registers snapshot in hardlockup handler
+-    - kernel/debug/debug_core.c: more properly delay for secondary CPUs
+-    - tpm xen: Remove bogus tpm_chip_unregister
+-    - xen/gntdev: Use VM_MIXEDMAP instead of VM_IO to avoid NUMA balancing
+-    - arm/xen: Use alloc_percpu rather than __alloc_percpu
+-    - xfs: set AGI buffer type in xlog_recover_clear_agi_bucket
+-    - driver core: fix race between creating/querying glue dir and its cleanup
+-    - ppp: defer netns reference release for ppp channel
+-    - Linux 4.4.40
+-
+-  * igb i210 probe of pci device failed with error -2 (LP: #1639810)
+-    - SAUCE: igb: Workaround for igb i210 firmware issue.
+-    - SAUCE: igb: add i211 to i210 PHY workaround
+-
+-  * PowerNV: PCI Slot is invalid after fencedPHB Error injection (LP: #1652018)
+-    - powerpc/powernv: Call opal_pci_poll() if needed
+-
+-  * mfd: intel-lpss: Add default I2C device properties for Apollo Lake
+-    (LP: #1635177)
+-    - mfd: intel-lpss: Add default I2C device properties for Apollo Lake
+-
+-  * Xenial update to v4.4.39 stable release (LP: #1650609)
+-    - powerpc/eeh: Fix deadlock when PE frozen state can't be cleared
+-    - parisc: Purge TLB before setting PTE
+-    - parisc: Remove unnecessary TLB purges from flush_dcache_page_asm and
+-      flush_icache_page_asm
+-    - parisc: Fix TLB related boot crash on SMP machines
+-    - zram: restrict add/remove attributes to root only
+-    - locking/rtmutex: Prevent dequeue vs. unlock race
+-    - locking/rtmutex: Use READ_ONCE() in rt_mutex_owner()
+-    - perf/x86: Fix full width counter, counter overflow
+-    - crypto: mcryptd - Check mcryptd algorithm compatibility
+-    - can: raw: raw_setsockopt: limit number of can_filter that can be set
+-    - can: peak: fix bad memory access and free sequence
+-    - arm64: futex.h: Add missing PAN toggling
+-    - m68k: Fix ndelay() macro
+-    - batman-adv: Check for alloc errors when preparing TT local data
+-    - hotplug: Make register and unregister notifier API symmetric
+-    - crypto: rsa - Add Makefile dependencies to fix parallel builds
+-    - Linux 4.4.39
+-
+-  * Xenial update to v4.4.38 stable release (LP: #1650607)
+-    - virtio-net: add a missing synchronize_net()
+-    - net: check dead netns for peernet2id_alloc()
+-    - ip6_tunnel: disable caching when the traffic class is inherited
+-    - net: sky2: Fix shutdown crash
+-    - af_unix: conditionally use freezable blocking calls in read
+-    - rtnetlink: fix FDB size computation
+-    - l2tp: fix racy SOCK_ZAPPED flag check in l2tp_ip{,6}_bind()
+-    - net: dsa: bcm_sf2: Ensure we re-negotiate EEE during after link change
+-    - net, sched: respect rcu grace period on cls destruction
+-    - net/sched: pedit: make sure that offset is valid
+-    - netlink: Call cb->done from a worker thread
+-    - netlink: Do not schedule work from sk_destruct
+-    - net/dccp: fix use-after-free in dccp_invalid_packet
+-    - net: bcmgenet: Utilize correct struct device for all DMA operations
+-    - sh_eth: remove unchecked interrupts for RZ/A1
+-    - geneve: avoid use-after-free of skb->data
+-    - net: ping: check minimum size on ICMP header length
+-    - sparc32: Fix inverted invalid_frame_pointer checks on sigreturns
+-    - sparc64: Fix find_node warning if numa node cannot be found
+-    - sparc64: fix compile warning section mismatch in find_node()
+-    - constify iov_iter_count() and iter_is_iovec()
+-    - Don't feed anything but regular iovec's to blk_rq_map_user_iov
+-    - ipv6: Set skb->protocol properly for local output
+-    - ipv4: Set skb->protocol properly for local output
+-    - esp4: Fix integrity verification when ESN are used
+-    - esp6: Fix integrity verification when ESN are used
+-    - Linux 4.4.38
+-
+-  * Xenial update to v4.4.37 stable release (LP: #1650604)
+-    - ARC: Don't use "+l" inline asm constraint
+-    - zram: fix unbalanced idr management at hot removal
+-    - kasan: update kasan_global for gcc 7
+-    - x86/traps: Ignore high word of regs->cs in early_fixup_exception()
+-    - rcu: Fix soft lockup for rcu_nocb_kthread
+-    - PCI: Export pcie_find_root_port
+-    - PCI: Set Read Completion Boundary to 128 iff Root Port supports it (_HPX)
+-    - mwifiex: printk() overflow with 32-byte SSIDs
+-    - pwm: Fix device reference leak
+-    - arm64: cpufeature: Schedule enable() calls instead of calling them via IPI
+-    - arm64: mm: Set PSTATE.PAN from the cpu_enable_pan() call
+-    - arm64: suspend: Reconfigure PSTATE after resume from idle
+-    - Linux 4.4.37
+-
+-  * Xenial update to v4.4.36 stable release (LP: #1650601)
+-    - iommu/vt-d: Fix PASID table allocation
+-    - iommu/vt-d: Fix IOMMU lookup for SR-IOV Virtual Functions
+-    - KVM: x86: check for pic and ioapic presence before use
+-    - usb: chipidea: move the lock initialization to core file
+-    - USB: serial: cp210x: add ID for the Zone DPMX
+-    - USB: serial: ftdi_sio: add support for TI CC3200 LaunchPad
+-    - Fix USB CB/CBI storage devices with CONFIG_VMAP_STACK=y
+-    - scsi: mpt3sas: Fix secure erase premature termination
+-    - tile: avoid using clocksource_cyc2ns with absolute cycle count
+-    - cfg80211: limit scan results cache size
+-    - NFSv4.x: hide array-bounds warning
+-    - parisc: Fix races in parisc_setup_cache_timing()
+-    - parisc: Fix race in pci-dma.c
+-    - parisc: Also flush data TLB in flush_icache_page_asm
+-    - mpi: Fix NULL ptr dereference in mpi_powm() [ver #3]
+-    - drm/radeon: Ensure vblank interrupt is enabled on DPMS transition to on
+-    - mei: me: disable driver on SPT SPS firmware
+-    - mei: me: fix place for kaby point device ids.
+-    - mei: fix return value on disconnection
+-    - scsi: mpt3sas: Unblock device after controller reset
+-    - Linux 4.4.36
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Debian] consider renames in gen-auto-reconstruct
+-
+- -- John Donnelly <john.donnelly@canonical.com>  Fri, 13 Jan 2017 08:54:11 +0000
+-
+-linux (4.4.0-59.80) xenial; urgency=low
+-
+-  [ John Donnelly ]
+-
+-  * Release Tracking Bug
+-    - LP: #1654282
+-
+-  * [2.1.1] MAAS has nvme0n1 set as boot disk, curtin fails (LP: #1651602)
+-    - (fix) nvme: only require 1 interrupt vector, not 2+
+-
+- -- John Donnelly <john.donnelly@canonical.com>  Thu, 05 Jan 2017 12:49:16 +0000
+-
+-linux (4.4.0-58.79) xenial; urgency=low
+-
+-  [ Luis Henriques ]
+-
+-  * Release Tracking Bug
+-    - LP: #1651402
+-
+-  * Support ACPI probe for IIO sensor drivers from ST Micro (LP: #1650123)
+-    - SAUCE: iio: st_sensors: match sensors using ACPI handle
+-    - SAUCE: iio: st_accel: Support sensor i2c probe using acpi
+-    - SAUCE: iio: st_pressure: Support i2c probe using acpi
+-    - [Config] CONFIG_HTS221=m, CONFIG_HTS221_I2C=m, CONFIG_HTS221_SPI=m
+-
+-  * Fix channel data parsing in ST Micro sensor IIO drivers (LP: #1650189)
+-    - SAUCE: iio: common: st_sensors: fix channel data parsing
+-
+-  * ST Micro lng2dm 3-axis "femto" accelerometer support (LP: #1650112)
+-    - SAUCE: iio: st-accel: add support for lis2dh12
+-    - SAUCE: iio: st_sensors: support active-low interrupts
+-    - SAUCE: iio: accel: Add support for the h3lis331dl accelerometer
+-    - SAUCE: iio: st_sensors: verify interrupt event to status
+-    - SAUCE: iio: st_sensors: support open drain mode
+-    - SAUCE: iio:st_sensors: fix power regulator usage
+-    - SAUCE: iio: st_sensors: switch to a threaded interrupt
+-    - SAUCE: iio: accel: st_accel: Add lis3l02dq support
+-    - SAUCE: iio: st_sensors: fix scale configuration for h3lis331dl
+-    - SAUCE: iio: accel: st_accel: add support to lng2dm
+-    - SAUCE: iio: accel: st_accel: inline per-sensor data
+-    - SAUCE: Documentation: dt: iio: accel: add lng2dm sensor device binding
+-
+-  * ST Micro hts221 relative humidity sensor support (LP: #1650116)
+-    - SAUCE: iio: humidity: add support to hts221 rh/temp combo device
+-    - SAUCE: Documentation: dt: iio: humidity: add hts221 sensor device binding
+-    - SAUCE: iio: humidity: remove
+-    - SAUCE: iio: humidity: Support acpi probe for hts211
+-
+-  * crypto : tolerate new crypto hardware for z Systems (LP: #1644557)
+-    - s390/zcrypt: Introduce CEX6 toleration
+-
+-  * Acer, Inc ID 5986:055a is useless after 14.04.2 installed. (LP: #1433906)
+-    - uvcvideo: uvc_scan_fallback() for webcams with broken chain
+-
+-  * vmxnet3 driver could causes kernel panic with v4.4 if LRO enabled.
+-    (LP: #1650635)
+-    - vmxnet3: segCnt can be 1 for LRO packets
+-
+-  * system freeze when swapping to encrypted swap partition (LP: #1647400)
+-    - mm, oom: rework oom detection
+-    - mm: throttle on IO only when there are too many dirty and writeback pages
+-
+-  * Kernel Fixes to get TCMU File Backed Optical to work (LP: #1646204)
+-    - target/user: Use sense_reason_t in tcmu_queue_cmd_ring
+-    - target/user: Return an error if cmd data size is too large
+-    - target/user: Fix comments to not refer to data ring
+-    - SAUCE: (no-up) target/user: Fix use-after-free of tcmu_cmds if they are
+-      expired
+-
+-  * CVE-2016-9756
+-    - KVM: x86: drop error recovery in em_jmp_far and em_ret_far
+-
+-  * Dell Precision 5520 & 3520 freezes at login screent (LP: #1650054)
+-    - ACPI / blacklist: add _REV quirks for Dell Precision 5520 and 3520
+-
+-  * CVE-2016-9794
+-    - ALSA: pcm : Call kill_fasync() in stream lock
+-
+-  * Allow fuse user namespace mounts by default in xenial (LP: #1634964)
+-    - (namespace) mnt: Move the FS_USERNS_MOUNT check into sget_userns
+-    - (namespace) Revert "UBUNTU: SAUCE: fs: Refuse uid/gid changes which don't
+-      map into s_user_ns"
+-    - (namespace) fs: Refuse uid/gid changes which don't map into s_user_ns
+-    - (namespace) Revert "UBUNTU: SAUCE: fs: Update posix_acl support to handle
+-      user namespace mounts"
+-    - (namespace) vfs: Verify acls are valid within superblock's s_user_ns.
+-    - SAUCE: (namespace) posix_acl: Export posix_acl_fix_xattr_userns() to modules
+-    - SAUCE: (namespace) fuse: Translate ids in posix acl xattrs
+-    - (namespace) vfs: Don't modify inodes with a uid or gid unknown to the vfs
+-    - (namespace) vfs: Don't create inodes with a uid or gid unknown to the vfs
+-    - (namespace) Revert "UBUNTU: SAUCE: quota: Require that qids passed to
+-      dqget() be valid and map into s_user_ns"
+-    - (namespace) Revert "UBUNTU: SAUCE: quota: Convert ids relative to s_user_ns"
+-    - (namespace) quota: Ensure qids map to the filesystem
+-    - (namespace) quota: Handle quota data stored in s_user_ns in quota_setxquota
+-    - (namespace) dquot: For now explicitly don't support filesystems outside of
+-      init_user_ns
+-    - (namespace) Revert "UBUNTU: SAUCE: ima/evm: Allow root in s_user_ns to set
+-      xattrs"
+-    - SAUCE: (namespace) security/integrity: Harden against malformed xattrs
+-    - (namespace) Revert "UBUNTU: SAUCE: fs: Allow superblock owner to change
+-      ownership of inodes with unmappable ids"
+-    - SAUCE: (namespace) fs: Allow superblock owner to change ownership of inodes
+-    - (namespace) Revert "UBUNTU: SAUCE: fs: Don't remove suid for CAP_FSETID in
+-      s_user_ns"
+-    - SAUCE: (namespace) fs: Don't remove suid for CAP_FSETID for userns root
+-    - SAUCE: (namespace) fuse: Allow user namespace mounts by default
+-
+-  * Boot crash in xen_send_IPI_one (LP: #1649821)
+-    - xen/qspinlock: Don't kick CPU if IRQ is not initialized
+-
+-  * linux: Staging modules should be unsigned (LP: #1642368)
+-    - [Debian] Suppress module signing for staging drivers
+-    - SAUCE: Add rtl drivers to signature inclusion list
+-
+-  * Ethernet not work after upgrade from kernel 3.19 to 4.4 [10ec:8168]
+-    (LP: #1648279)
+-    - ACPI / blacklist: Make Dell Latitude 3350 ethernet work
+-
+-  * CVE-2016-9793
+-    - net: avoid signed overflows for SO_{SND|RCV}BUFFORCE
+-
+-  * [Hyper-V] Kernel panic not functional on 32bit Ubuntu 14.10, 15.04, and
+-    15.10 (LP: #1400319)
+-    - Drivers: hv: avoid vfree() on crash
+-
+-  * [Hyper-V] netvsc: fix incorrect receive checksum offloading (LP: #1636656)
+-    - netvsc: fix incorrect receive checksum offloading
+-
+- -- Luis Henriques <luis.henriques@canonical.com>  Tue, 20 Dec 2016 10:54:41 +0000
+-
+-linux (4.4.0-57.78) xenial; urgency=low
+-
+-  * Release Tracking Bug
+-    - LP: #1648867
+-
+-  * Miscellaneous Ubuntu changes
+-    - SAUCE: Do not build the xr-usb-serial driver for s390
+-
+- -- Brad Figg <brad.figg@canonical.com>  Fri, 09 Dec 2016 10:51:16 -0800
+-
+-linux (4.4.0-56.77) xenial; urgency=low
+-
+-  * Release Tracking Bug
+-    - LP: #1648867
+-
+-  * Release Tracking Bug
+-    - LP: #1648579
+-
+-  * CONFIG_NR_CPUS=256 is too low (LP: #1579205)
+-    - [Config] Increase the NR_CPUS to 512 for amd64 to support systems with a
+-      large number of cores.
+-
+-  * NVMe drives in Amazon AWS instance fail to initialize (LP: #1648449)
+-    - SAUCE: (no-up) NVMe: only setup MSIX once
+-
+- -- Brad Figg <brad.figg@canonical.com>  Thu, 08 Dec 2016 10:50:49 -0800
+-
+-linux (4.4.0-55.76) xenial; urgency=low
+-
+-  [ Luis Henriques ]
+-
+-  * Release Tracking Bug
+-    - LP: #1648503
+-
+-  * NVMe driver accidentally reverted to use GSI instead of MSIX (LP: #1647887)
+-    - (fix) NVMe: restore code to always use MSI/MSI-x interrupts
+-
+- -- Luis Henriques <luis.henriques@canonical.com>  Thu, 08 Dec 2016 14:34:40 +0000
+-
+-linux (4.4.0-54.75) xenial; urgency=low
+-
+-  [ Luis Henriques ]
+-
+-  * Release Tracking Bug
+-    - LP: #1648017
+-
+-  * Update hio driver to 2.1.0.28 (LP: #1646643)
+-    - SAUCE: hio: update to Huawei ES3000_V2 (2.1.0.28)
+-
+-  * linux: Enable live patching for all supported architectures (LP: #1633577)
+-    - [Config] CONFIG_LIVEPATCH=y for s390x
+-
+-  * Botched backport breaks level triggered EOIs in QEMU guests with --machine
+-    kernel_irqchip=split (LP: #1644394)
+-    - kvm/irqchip: kvm_arch_irq_routing_update renaming split
+-
+-  * Xenial update to v4.4.35 stable release (LP: #1645453)
+-    - x86/cpu/AMD: Fix cpu_llc_id for AMD Fam17h systems
+-    - KVM: x86: fix missed SRCU usage in kvm_lapic_set_vapic_addr
+-    - KVM: Disable irq while unregistering user notifier
+-    - fuse: fix fuse_write_end() if zero bytes were copied
+-    - mfd: intel-lpss: Do not put device in reset state on suspend
+-    - can: bcm: fix warning in bcm_connect/proc_register
+-    - i2c: mux: fix up dependencies
+-    - kbuild: add -fno-PIE
+-    - scripts/has-stack-protector: add -fno-PIE
+-    - x86/kexec: add -fno-PIE
+-    - kbuild: Steal gcc's pie from the very beginning
+-    - ext4: sanity check the block and cluster size at mount time
+-    - crypto: caam - do not register AES-XTS mode on LP units
+-    - drm/amdgpu: Attach exclusive fence to prime exported bo's. (v5)
+-    - clk: mmp: pxa910: fix return value check in pxa910_clk_init()
+-    - clk: mmp: pxa168: fix return value check in pxa168_clk_init()
+-    - clk: mmp: mmp2: fix return value check in mmp2_clk_init()
+-    - rtc: omap: Fix selecting external osc
+-    - iwlwifi: pcie: fix SPLC structure parsing
+-    - mfd: core: Fix device reference leak in mfd_clone_cell
+-    - uwb: fix device reference leaks
+-    - PM / sleep: fix device reference leak in test_suspend
+-    - PM / sleep: don't suspend parent when async child suspend_{noirq, late}
+-      fails
+-    - IB/mlx4: Check gid_index return value
+-    - IB/mlx4: Fix create CQ error flow
+-    - IB/mlx5: Use cache line size to select CQE stride
+-    - IB/mlx5: Fix fatal error dispatching
+-    - IB/core: Avoid unsigned int overflow in sg_alloc_table
+-    - IB/uverbs: Fix leak of XRC target QPs
+-    - IB/cm: Mark stale CM id's whenever the mad agent was unregistered
+-    - netfilter: nft_dynset: fix element timeout for HZ != 1000
+-    - Linux 4.4.35
+-
+-  * Upstream stable 4.4.34 and 4.8.10 regression (LP: #1645278)
+-    - flow_dissect: call init_default_flow_dissectors() earlier
+-
+-  * AD5593R configurable multi-channel converter support (LP: #1644726)
+-    - iio: dac: Add support for the AD5592R/AD5593R ADCs/DACs
+-    - iio: dac: ad5592r: Off by one bug in ad5592r_alloc_channels()
+-    - [Config] CONFIG_AD5592R/AD5593R=m
+-
+-  * ST Micro lps22hb pressure sensor support (LP: #1642258)
+-    - iio:st_pressure:initial lps22hb sensor support
+-    - iio:st_pressure: align storagebits on power of 2
+-    - iio:st_pressure: document sampling gains
+-    - iio:st_pressure:lps22hb: temperature support
+-
+-  * Fix Kernel Crashing under IBM Virtual Scsi Driver (LP: #1642299)
+-    - SAUCE: ibmvscsis: Rearrange functions for future patches
+-    - SAUCE: ibmvscsis: Synchronize cmds at tpg_enable_store time
+-    - SAUCE: ibmvscsis: Synchronize cmds at remove time
+-    - SAUCE: ibmvscsis: Clean up properly if target_submit_cmd/tmr fails
+-    - SAUCE: ibmvscsis: Return correct partition name/# to client
+-    - SAUCE: ibmvscsis: Issues from Dan Carpenter/Smatch
+-
+-  * System stalls when creating device node on booting (LP: #1643797)
+-    - sched/fair: Fix new task's load avg removed from source CPU in
+-      wake_up_new_task()
+-
+-  * nvme: improve performance for virtual Google NVMe devices (LP: #1637565)
+-    - blk-mq: add blk_mq_alloc_request_hctx
+-    - nvme.h: add NVMe over Fabrics definitions
+-    - [Config] CONFIG_NVME_VENDOR_EXT_GOOGLE=y
+-    - SAUCE: nvme: improve performance for virtual NVMe devices
+-
+-  * Move some kernel modules to the main kernel package (LP: #1642228)
+-    - [Config] Move some powerpc kernel modules to the main kernel package
+-
+-  * sched: Match-all classifier is missing in xenial (LP: #1642514)
+-    - [Config] CONFIG_NET_CLS_MATCHALL=m
+-    - net/sched: introduce Match-all classifier
+-
+-  * Xenial update to 4.4.34 stable release (LP: #1643637)
+-    - dctcp: avoid bogus doubling of cwnd after loss
+-    - net: clear sk_err_soft in sk_clone_lock()
+-    - net: mangle zero checksum in skb_checksum_help()
+-    - bgmac: stop clearing DMA receive control register right after it is set
+-    - ip6_tunnel: Clear IP6CB in ip6tunnel_xmit()
+-    - tcp: fix potential memory corruption
+-    - dccp: do not send reset to already closed sockets
+-    - dccp: fix out of bound access in dccp_v4_err()
+-    - ipv6: dccp: fix out of bound access in dccp_v6_err()
+-    - ipv6: dccp: add missing bind_conflict to dccp_ipv6_mapped
+-    - sctp: assign assoc_id earlier in __sctp_connect
+-    - fib_trie: Correct /proc/net/route off by one error
+-    - sock: fix sendmmsg for partial sendmsg
+-    - net: __skb_flow_dissect() must cap its return value
+-    - ipv4: use new_gw for redirect neigh lookup
+-    - tcp: take care of truncations done by sk_filter()
+-    - tty: Prevent ldisc drivers from re-using stale tty fields
+-    - sparc: Don't leak context bits into thread->fault_address
+-    - sparc: serial: sunhv: fix a double lock bug
+-    - sparc64 mm: Fix base TSB sizing when hugetlb pages are used
+-    - sparc: Handle negative offsets in arch_jump_label_transform
+-    - sparc64: Handle extremely large kernel TSB range flushes sanely.
+-    - sparc64: Fix illegal relative branches in hypervisor patched TLB code.
+-    - sparc64: Fix instruction count in comment for
+-      __hypervisor_flush_tlb_pending.
+-    - sparc64: Fix illegal relative branches in hypervisor patched TLB cross-call
+-      code.
+-    - sparc64: Handle extremely large kernel TLB range flushes more gracefully.
+-    - sparc64: Delete __ret_efault.
+-    - sparc64: Prepare to move to more saner user copy exception handling.
+-    - sparc64: Convert copy_in_user to accurate exception reporting.
+-    - sparc64: Convert GENcopy_{from,to}_user to accurate exception reporting.
+-    - sparc64: Convert U1copy_{from,to}_user to accurate exception reporting.
+-    - sparc64: Convert NG4copy_{from,to}_user to accurate exception reporting.
+-    - sparc64: Convert NGcopy_{from,to}_user to accurate exception reporting.
+-    - sparc64: Convert NG2copy_{from,to}_user to accurate exception reporting.
+-    - sparc64: Convert U3copy_{from,to}_user to accurate exception reporting.
+-    - sparc64: Delete now unused user copy assembler helpers.
+-    - sparc64: Delete now unused user copy fixup functions.
+-    - Linux 4.4.34
+-
+-  * Xenial update to v4.4.33 stable release (LP: #1642968)
+-    - ALSA: info: Return error for invalid read/write
+-    - ALSA: info: Limit the proc text input size
+-    - ASoC: cs4270: fix DAPM stream name mismatch
+-    - dib0700: fix nec repeat handling
+-    - swapfile: fix memory corruption via malformed swapfile
+-    - coredump: fix unfreezable coredumping task
+-    - s390/hypfs: Use get_free_page() instead of kmalloc to ensure page alignment
+-    - ARC: timer: rtc: implement read loop in "C" vs. inline asm
+-    - pinctrl: cherryview: Serialize register access in suspend/resume
+-    - pinctrl: cherryview: Prevent possible interrupt storm on resume
+-    - staging: iio: ad5933: avoid uninitialized variable in error case
+-    - drivers: staging: nvec: remove bogus reset command for PS/2 interface
+-    - Revert "staging: nvec: ps2: change serio type to passthrough"
+-    - staging: nvec: remove managed resource from PS2 driver
+-    - USB: cdc-acm: fix TIOCMIWAIT
+-    - usb: gadget: u_ether: remove interrupt throttling
+-    - drbd: Fix kernel_sendmsg() usage - potential NULL deref
+-    - toshiba-wmi: Fix loading the driver on non Toshiba laptops
+-    - clk: qoriq: Don't allow CPU clocks higher than starting value
+-    - iio: hid-sensors: Increase the precision of scale to fix wrong reading
+-      interpretation.
+-    - iio: orientation: hid-sensor-rotation: Add PM function (fix non working
+-      driver)
+-    - scsi: qla2xxx: Fix scsi scan hang triggered if adapter fails during init
+-    - scsi: mpt3sas: Fix for block device of raid exists even after deleting raid
+-      disk
+-    - KVM: MIPS: Precalculate MMIO load resume PC
+-    - drm/i915: Respect alternate_ddc_pin for all DDI ports
+-    - dmaengine: at_xdmac: fix spurious flag status for mem2mem transfers
+-    - tty/serial: at91: fix hardware handshake on Atmel platforms
+-    - iommu/amd: Free domain id when free a domain of struct dma_ops_domain
+-    - iommu/vt-d: Fix dead-locks in disable_dmar_iommu() path
+-    - mei: bus: fix received data size check in NFC fixup
+-    - lib/genalloc.c: start search from start of chunk
+-    - hwrng: core - Don't use a stack buffer in add_early_randomness()
+-    - i40e: fix call of ndo_dflt_bridge_getlink()
+-    - ACPI / APEI: Fix incorrect return value of ghes_proc()
+-    - ASoC: sun4i-codec: return error code instead of NULL when create_card fails
+-    - mmc: mxs: Initialize the spinlock prior to using it
+-    - btrfs: qgroup: Prevent qgroup->reserved from going subzero
+-    - netfilter: fix namespace handling in nf_log_proc_dostring
+-    - Linux 4.4.33
+-
+-  * Xenial update to 4.4.32 stable release (LP: #1642573)
+-    - tcp: fix overflow in __tcp_retransmit_skb()
+-    - net: avoid sk_forward_alloc overflows
+-    - tcp: fix wrong checksum calculation on MTU probing
+-    - tcp: fix a compile error in DBGUNDO()
+-    - ip6_gre: fix flowi6_proto value in ip6gre_xmit_other()
+-    - ipmr, ip6mr: fix scheduling while atomic and a deadlock with ipmr_get_route
+-    - tg3: Avoid NULL pointer dereference in tg3_io_error_detected()
+-    - net: fec: set mac address unconditionally
+-    - net: pktgen: fix pkt_size
+-    - net/sched: act_vlan: Push skb->data to mac_header prior calling skb_vlan_*()
+-      functions
+-    - net: Add netdev all_adj_list refcnt propagation to fix panic
+-    - packet: call fanout_release, while UNREGISTERING a netdev
+-    - netlink: do not enter direct reclaim from netlink_dump()
+-    - ipv6: tcp: restore IP6CB for pktoptions skbs
+-    - ip6_tunnel: fix ip6_tnl_lookup
+-    - net: pktgen: remove rcu locking in pktgen_change_name()
+-    - bridge: multicast: restore perm router ports on multicast enable
+-    - rtnetlink: Add rtnexthop offload flag to compare mask
+-    - net: add recursion limit to GRO
+-    - ipv4: disable BH in set_ping_group_range()
+-    - ipv4: use the right lock for ping_group_range
+-    - net: sctp, forbid negative length
+-    - udp: fix IP_CHECKSUM handling
+-    - net sched filters: fix notification of filter delete with proper handle
+-    - sctp: validate chunk len before actually using it
+-    - packet: on direct_xmit, limit tso and csum to supported devices
+-    - of: silence warnings due to max() usage
+-    - Revert KVM: MIPS: Drop other CPU ASIDs on guest MMU changes
+-    - KVM: MIPS: Drop other CPU ASIDs on guest MMU changes
+-    - drm/amdgpu/dp: add back special handling for NUTMEG
+-    - drm/amdgpu: fix DP mode validation
+-    - drm/radeon: fix DP mode validation
+-    - scsi: megaraid_sas: fix macro MEGASAS_IS_LOGICAL to avoid regression
+-    - Linux 4.4.32
+-
+-  * Xenial update to 4.4.31 stable release (LP: #1642572)
+-    - i2c: xgene: Avoid dma_buffer overrun
+-    - i2c: core: fix NULL pointer dereference under race condition
+-    - drm/dp/mst: Clear port->pdt when tearing down the i2c adapter
+-    - h8300: fix syscall restarting
+-    - libxfs: clean up _calc_dquots_per_chunk
+-    - mm/list_lru.c: avoid error-path NULL pointer deref
+-    - mm: memcontrol: do not recurse in direct reclaim
+-    - ALSA: usb-audio: Add quirk for Syntek STK1160
+-    - ALSA: hda - Merge RIRB_PRE_DELAY into CTX_WORKAROUND caps
+-    - ALSA: hda - Raise AZX_DCAPS_RIRB_DELAY handling into top drivers
+-    - ALSA: hda - allow 40 bit DMA mask for NVidia devices
+-    - ALSA: hda - Adding a new group of pin cfg into ALC295 pin quirk table
+-    - ALSA: hda - Fix headset mic detection problem for two Dell laptops
+-    - ANDROID: binder: Add strong ref checks
+-    - ANDROID: binder: Clear binder and cookie when setting handle in flat binder
+-      struct
+-    - btrfs: fix races on root_log_ctx lists
+-    - ubifs: Abort readdir upon error
+-    - ubifs: Fix regression in ubifs_readdir()
+-    - mei: txe: don't clean an unprocessed interrupt cause.
+-    - usb: gadget: function: u_ether: don't starve tx request queue
+-    - USB: serial: fix potential NULL-dereference at probe
+-    - USB: serial: ftdi_sio: add support for Infineon TriBoard TC2X7
+-    - xhci: use default USB_RESUME_TIMEOUT when resuming ports.
+-    - usb: increase ohci watchdog delay to 275 msec
+-    - Fix potential infoleak in older kernels
+-    - vt: clear selection before resizing
+-    - xhci: add restart quirk for Intel Wildcatpoint PCH
+-    - tty: limit terminal size to 4M chars
+-    - USB: serial: cp210x: fix tiocmget error handling
+-    - dm: free io_barrier after blk_cleanup_queue call
+-    - KVM: x86: fix wbinvd_dirty_mask use-after-free
+-    - KVM: MIPS: Make ERET handle ERL before EXL
+-    - ovl: fsync after copy-up
+-    - parisc: Ensure consistent state when switching to kernel stack at syscall
+-      entry
+-    - virtio_ring: Make interrupt suppression spec compliant
+-    - virtio: console: Unlock vqs while freeing buffers
+-    - dm mirror: fix read error on recovery after default leg failure
+-    - Input: i8042 - add XMG C504 to keyboard reset table
+-    - firewire: net: guard against rx buffer overflows
+-    - firewire: net: fix fragmented datagram_size off-by-one
+-    - mac80211: discard multicast and 4-addr A-MSDUs
+-    - scsi: megaraid_sas: Fix data integrity failure for JBOD (passthrough)
+-      devices
+-    - scsi: scsi_debug: Fix memory leak if LBP enabled and module is unloaded
+-    - scsi: arcmsr: Send SYNCHRONIZE_CACHE command to firmware
+-    - mmc: dw_mmc-pltfm: fix the potential NULL pointer dereference
+-    - Revert "drm/radeon: fix DP link training issue with second 4K monitor"
+-    - drm/radeon/si_dpm: Limit clocks on HD86xx part
+-    - drm/radeon/si_dpm: workaround for SI kickers
+-    - drm/radeon: drop register readback in cayman_cp_int_cntl_setup
+-    - drm/dp/mst: Check peer device type before attempting EDID read
+-    - perf build: Fix traceevent plugins build race
+-    - x86/xen: fix upper bound of pmd loop in xen_cleanhighmap()
+-    - powerpc/ptrace: Fix out of bounds array access warning
+-    - ARM: 8584/1: floppy: avoid gcc-6 warning
+-    - mm/cma: silence warnings due to max() usage
+-    - drm/exynos: fix error handling in exynos_drm_subdrv_open
+-    - cgroup: avoid false positive gcc-6 warning
+-    - smc91x: avoid self-comparison warning
+-    - Disable "frame-address" warning
+-    - UBI: fastmap: scrub PEB when bitflips are detected in a free PEB EC header
+-    - pwm: Unexport children before chip removal
+-    - usb: dwc3: Fix size used in dma_free_coherent()
+-    - tty: vt, fix bogus division in csi_J
+-    - kvm: x86: Check memopp before dereference (CVE-2016-8630)
+-    - ubi: fastmap: Fix add_vol() return value test in ubi_attach_fastmap()
+-    - HID: usbhid: add ATEN CS962 to list of quirky devices
+-    - Linux 4.4.31
+-
+-  * CVE-2016-6213
+-    - mnt: Add a per mount namespace limit on the number of mounts
+-
+-  * ThinkPad T460 hotkeys stop working in Ubuntu 16.04 (LP: #1642114)
+-    - thinkpad_acpi: Add support for HKEY version 0x200
+-
+-  * CVE-2016-4568
+-    - videobuf2-v4l2: Verify planes array in buffer dequeueing
+-
+-  * [SRU] Add 0cf3:e009 to btusb (LP: #1641562)
+-    - Bluetooth: btusb: Add support for 0cf3:e009
+-
+-  * Fix resource leak in btusb (LP: #1641569)
+-    - SAUCE: Bluetooth: decrease refcount after use
+-
+-  * WiFi LED doesn't work on some Edge Gateway units (LP: #1640418)
+-    - SAUCE: mwifiex: Use PCI ID instead of DMI ID to identify Edge Gateways
+-
+-  * [Hyper-V] do not lose pending heartbeat vmbus packets (LP: #1632786)
+-    - hv: do not lose pending heartbeat vmbus packets
+-
+-  * ipv6: connected routes are missing after a down/up cycle on the loopback
+-    (LP: #1634545)
+-    - ipv6: correctly add local routes when lo goes up
+-
+-  * audit: prevent a new auditd to stop an old auditd still alive (LP: #1633404)
+-    - audit: stop an old auditd being starved out by a new auditd
+-
+-  * hv_set_ifconfig script parsing fails for certain configuration
+-    (LP: #1640109)
+-    - hv_set_ifconfig -- handle DHCP interfaces correctly
+-    - hv_set_ifconfig -- ensure we include the last stanza
+-
+-  * CVE-2016-7039 and CVE-2016-8666 (LP: #1631287)
+-    - Revert "UBUNTU: SAUCE: net: add recursion limit to GRO"
+-
+- -- Luis Henriques <luis.henriques@canonical.com>  Wed, 07 Dec 2016 10:13:50 +0000
+-
+-linux (4.4.0-53.74) xenial; urgency=low
+-
+-  * CVE-2016-8655 (LP: #1646318)
+-    - packet: fix race condition in packet_set_ring
+-
+- -- Brad Figg <brad.figg@canonical.com>  Thu, 01 Dec 2016 10:54:01 -0800
+-
+-linux (4.4.0-51.72) xenial; urgency=low
+-
+-  [ Luis Henriques ]
+-
+-  * Release Tracking Bug
+-    - LP: #1644611
+-
+-  * 4.4.0-1037-snapdragon #41: kernel panic on boot (LP: #1644596)
+-    - Revert "dma-mapping: introduce the DMA_ATTR_NO_WARN attribute"
+-    - Revert "powerpc: implement the DMA_ATTR_NO_WARN attribute"
+-    - Revert "nvme: use the DMA_ATTR_NO_WARN attribute"
+-
+- -- Luis Henriques <luis.henriques@canonical.com>  Thu, 24 Nov 2016 17:56:21 +0000
+-
+-linux (4.4.0-50.71) xenial; urgency=low
+-
+-  [ Luis Henriques ]
+-
+-  * Release Tracking Bug
+-    - LP: #1644169
+-
+-  * xenial 4.4.0-49.70 kernel breaks LXD userspace (LP: #1644165)
+-    - Revert "UBUNTU: SAUCE: (namespace) fuse: Allow user namespace mounts by
+-      default"
+-    - Revert "UBUNTU: SAUCE: (namespace) fs: Don't remove suid for CAP_FSETID for
+-      userns root"
+-    - Revert "(namespace) Revert "UBUNTU: SAUCE: fs: Don't remove suid for
+-      CAP_FSETID in s_user_ns""
+-    - Revert "UBUNTU: SAUCE: (namespace) fs: Allow superblock owner to change
+-      ownership of inodes"
+-    - Revert "(namespace) Revert "UBUNTU: SAUCE: fs: Allow superblock owner to
+-      change ownership of inodes with unmappable ids""
+-    - Revert "UBUNTU: SAUCE: (namespace) security/integrity: Harden against
+-      malformed xattrs"
+-    - Revert "(namespace) Revert "UBUNTU: SAUCE: ima/evm: Allow root in s_user_ns
+-      to set xattrs""
+-    - Revert "(namespace) dquot: For now explicitly don't support filesystems
+-      outside of init_user_ns"
+-    - Revert "(namespace) quota: Handle quota data stored in s_user_ns in
+-      quota_setxquota"
+-    - Revert "(namespace) quota: Ensure qids map to the filesystem"
+-    - Revert "(namespace) Revert "UBUNTU: SAUCE: quota: Convert ids relative to
+-      s_user_ns""
+-    - Revert "(namespace) Revert "UBUNTU: SAUCE: quota: Require that qids passed
+-      to dqget() be valid and map into s_user_ns""
+-    - Revert "(namespace) vfs: Don't create inodes with a uid or gid unknown to
+-      the vfs"
+-    - Revert "(namespace) vfs: Don't modify inodes with a uid or gid unknown to
+-      the vfs"
+-    - Revert "UBUNTU: SAUCE: (namespace) fuse: Translate ids in posix acl xattrs"
+-    - Revert "UBUNTU: SAUCE: (namespace) posix_acl: Export
+-      posix_acl_fix_xattr_userns() to modules"
+-    - Revert "(namespace) vfs: Verify acls are valid within superblock's
+-      s_user_ns."
+-    - Revert "(namespace) Revert "UBUNTU: SAUCE: fs: Update posix_acl support to
+-      handle user namespace mounts""
+-    - Revert "(namespace) fs: Refuse uid/gid changes which don't map into
+-      s_user_ns"
+-    - Revert "(namespace) Revert "UBUNTU: SAUCE: fs: Refuse uid/gid changes which
+-      don't map into s_user_ns""
+-    - Revert "(namespace) mnt: Move the FS_USERNS_MOUNT check into sget_userns"
+-
+- -- Luis Henriques <luis.henriques@canonical.com>  Wed, 23 Nov 2016 10:16:31 +0000
+-
+-linux (4.4.0-49.70) xenial; urgency=low
+-
+-  [ Luis Henriques ]
+-
+-  * Release Tracking Bug
+-    - LP: #1640921
+-
+-  * Infiniband driver (kernel module) needed for Azure (LP: #1641139)
+-    - SAUCE: RDMA Infiniband for Windows Azure
+-    - [Config] CONFIG_HYPERV_INFINIBAND_ND=m
+-    - SAUCE: Makefile RDMA infiniband driver for Windows Azure
+-    - [Config] Add hv_network_direct.ko to generic inclusion list
+-    - SAUCE: RDMA Infiniband for Windows Azure is dependent on amd64
+-
+- -- Luis Henriques <luis.henriques@canonical.com>  Fri, 11 Nov 2016 15:36:20 +0000
+-
+-linux (4.4.0-48.69) xenial; urgency=low
+-
+-  [ Luis Henriques ]
+-
+-  * Release Tracking Bug
+-    - LP: #1640758
+-
+-  * lxc-attach to malicious container allows access to host (LP: #1639345)
+-    - Revert "UBUNTU: SAUCE: (noup) ptrace: being capable wrt a process requires
+-      mapped uids/gids"
+-    - (upstream) mm: Add a user_ns owner to mm_struct and fix ptrace permission
+-      checks
+-
+-  * take 'P' command from upstream xmon (LP: #1637978)
+-    - powerpc/xmon: Add xmon command to dump process/task similar to ps(1)
+-
+-  * zfs: importing zpool with vdev on zvol hangs kernel (LP: #1636517)
+-    - SAUCE: (noup) Update zfs to 0.6.5.6-0ubuntu15
+-
+-  * I2C touchpad does not work on AMD platform (LP: #1612006)
+-    - pinctrl/amd: Configure GPIO register using BIOS settings
+-    - pinctrl/amd: switch to using a bool for level
+-
+-  * [LTCTest] vfio_pci not loaded on Ubuntu 16.10 by default (LP: #1636733)
+-    - [Config] CONFIG_VFIO_PCI=y for ppc64el
+-
+-  * QEMU throws failure msg while booting guest with SRIOV VF (LP: #1630554)
+-    - KVM: PPC: Always select KVM_VFIO, plus Makefile cleanup
+-
+-  * Allow fuse user namespace mounts by default in xenial (LP: #1634964)
+-    - (namespace) mnt: Move the FS_USERNS_MOUNT check into sget_userns
+-    - (namespace) Revert "UBUNTU: SAUCE: fs: Refuse uid/gid changes which don't
+-      map into s_user_ns"
+-    - (namespace) fs: Refuse uid/gid changes which don't map into s_user_ns
+-    - (namespace) Revert "UBUNTU: SAUCE: fs: Update posix_acl support to handle
+-      user namespace mounts"
+-    - (namespace) vfs: Verify acls are valid within superblock's s_user_ns.
+-    - SAUCE: (namespace) posix_acl: Export posix_acl_fix_xattr_userns() to modules
+-    - SAUCE: (namespace) fuse: Translate ids in posix acl xattrs
+-    - (namespace) vfs: Don't modify inodes with a uid or gid unknown to the vfs
+-    - (namespace) vfs: Don't create inodes with a uid or gid unknown to the vfs
+-    - (namespace) Revert "UBUNTU: SAUCE: quota: Require that qids passed to
+-      dqget() be valid and map into s_user_ns"
+-    - (namespace) Revert "UBUNTU: SAUCE: quota: Convert ids relative to s_user_ns"
+-    - (namespace) quota: Ensure qids map to the filesystem
+-    - (namespace) quota: Handle quota data stored in s_user_ns in quota_setxquota
+-    - (namespace) dquot: For now explicitly don't support filesystems outside of
+-      init_user_ns
+-    - (namespace) Revert "UBUNTU: SAUCE: ima/evm: Allow root in s_user_ns to set
+-      xattrs"
+-    - SAUCE: (namespace) security/integrity: Harden against malformed xattrs
+-    - (namespace) Revert "UBUNTU: SAUCE: fs: Allow superblock owner to change
+-      ownership of inodes with unmappable ids"
+-    - SAUCE: (namespace) fs: Allow superblock owner to change ownership of inodes
+-    - (namespace) Revert "UBUNTU: SAUCE: fs: Don't remove suid for CAP_FSETID in
+-      s_user_ns"
+-    - SAUCE: (namespace) fs: Don't remove suid for CAP_FSETID for userns root
+-    - SAUCE: (namespace) fuse: Allow user namespace mounts by default
+-
+-  * [Feature] KBL - New device ID for Kabypoint(KbP) (LP: #1591618)
+-    - SAUCE: mfd: lpss: Fix Intel Kaby Lake PCH-H properties
+-
+-  * hio: SSD data corruption under stress test (LP: #1638700)
+-    - SAUCE: hio: set bi_error field to signal an I/O error on a BIO
+-    - SAUCE: hio: splitting bio in the entry of .make_request_fn
+-
+-  * Module sha1-mb fails to load (LP: #1637165)
+-    - crypto: sha-mb - Fix load failure
+-    - crypto: mcryptd - Fix load failure
+-
+-  * please include mlx5_core modules in linux-image-generic package
+-    (LP: #1635223)
+-    - [Config] Include mlx5 in main package
+-
+-  * xgene i2c slimpro driver fails to load (LP: #1625232)
+-    - mailbox: Add support for APM X-Gene platform mailbox driver
+-    - mailbox/xgene-slimpro: Checking for IS_ERR instead of NULL
+-    - mailbox: xgene-slimpro: Fix wrong test for devm_kzalloc
+-    - [Config] Enabled XGENE_SLIMPRO_MBOX as a module
+-
+-  * [Dell][XPS]Touchscreen fails to function after resume from s3 by Lid
+-    close/open (LP: #1632527)
+-    - gpio/pinctrl: sunxi: stop poking around in private vars
+-    - pinctrl: intel: Only restore pins that are used by the driver
+-
+-  * Xenial update to v4.4.30 stable release (LP: #1638272)
+-    - Revert "x86/mm: Expand the exception table logic to allow new handling
+-      options"
+-    - Revert "fix minor infoleak in get_user_ex()"
+-    - Linux 4.4.30
+-
+-  * Xenial update to v4.4.29 stable release (LP: #1638267)
+-    - drm/prime: Pass the right module owner through to dma_buf_export()
+-    - drm/amdgpu: fix IB alignment for UVD
+-    - drm/amdgpu/dce10: disable hpd on local panels
+-    - drm/amdgpu/dce8: disable hpd on local panels
+-    - drm/amdgpu/dce11: disable hpd on local panels
+-    - drm/amdgpu/dce11: add missing drm_mode_config_cleanup call
+-    - drm/amdgpu: change vblank_time's calculation method to reduce computational
+-      error.
+-    - drm/radeon: narrow asic_init for virtualization
+-    - drm/radeon/si/dpm: fix phase shedding setup
+-    - drm/radeon: change vblank_time's calculation method to reduce computational
+-      error.
+-    - drm/vmwgfx: Limit the user-space command buffer size
+-    - drm/i915/gen9: fix the WaWmMemoryReadLatency implementation
+-    - Revert "drm/i915: Check live status before reading edid"
+-    - drm/i915: Account for TSEG size when determining 865G stolen base
+-    - drm/i915: Unalias obj->phys_handle and obj->userptr
+-    - mm/hugetlb: fix memory offline with hugepage size > memory block size
+-    - posix_acl: Clear SGID bit when setting file permissions
+-    - ipip: Properly mark ipip GRO packets as encapsulated.
+-    - powerpc/eeh: Null check uses of eeh_pe_bus_get
+-    - perf stat: Fix interval output values
+-    - genirq/generic_chip: Add irq_unmap callback
+-    - uio: fix dmem_region_start computation
+-    - ARM: clk-imx35: fix name for ckil clk
+-    - spi: spi-fsl-dspi: Drop extra spi_master_put in device remove function
+-    - mwifiex: correct aid value during tdls setup
+-    - crypto: gcm - Fix IV buffer size in crypto_gcm_setkey
+-    - crypto: arm/ghash-ce - add missing async import/export
+-    - hwrng: omap - Only fail if pm_runtime_get_sync returns < 0
+-    - ASoC: topology: Fix error return code in soc_tplg_dapm_widget_create()
+-    - ASoC: dapm: Fix possible uninitialized variable in snd_soc_dapm_get_volsw()
+-    - ASoC: dapm: Fix value setting for _ENUM_DOUBLE MUX's second channel
+-    - ASoC: dapm: Fix kcontrol creation for output driver widget
+-    - staging: r8188eu: Fix scheduling while atomic splat
+-    - power: bq24257: Fix use of uninitialized pointer bq->charger
+-    - dmaengine: ipu: remove bogus NO_IRQ reference
+-    - x86/mm: Expand the exception table logic to allow new handling options
+-    - s390/cio: fix accidental interrupt enabling during resume
+-    - s390/con3270: fix use of uninitialised data
+-    - s390/con3270: fix insufficient space padding
+-    - clk: qoriq: fix a register offset error
+-    - clk: divider: Fix clk_divider_round_rate() to use clk_readl()
+-    - perf hists browser: Fix event group display
+-    - perf symbols: Check symbol_conf.allow_aliases for kallsyms loading too
+-    - perf symbols: Fixup symbol sizes before picking best ones
+-    - mpt3sas: Don't spam logs if logging level is 0
+-    - powerpc/nvram: Fix an incorrect partition merge
+-    - ARM: pxa: pxa_cplds: fix interrupt handling
+-    - Linux 4.4.29
+-
+-  * KVM: PPC: Book3S HV: Migrate pinned pages out of CMA (LP: #1632045)
+-    - KVM: PPC: Book3S HV: Migrate pinned pages out of CMA
+-
+-  * Xenial update to v4.4.28 stable release (LP: #1637510)
+-    - gpio: mpc8xxx: Correct irq handler function
+-    - mei: me: add kaby point device ids
+-    - regulator: tps65910: Work around silicon erratum SWCZ010
+-    - clk: imx6: initialize GPU clocks
+-    - PM / devfreq: event: remove duplicate devfreq_event_get_drvdata()
+-    - rtlwifi: Fix missing country code for Great Britain
+-    - mmc: block: don't use CMD23 with very old MMC cards
+-    - mmc: sdhci: cast unsigned int to unsigned long long to avoid unexpeted error
+-    - PCI: Mark Atheros AR9580 to avoid bus reset
+-    - platform: don't return 0 from platform_get_irq[_byname]() on error
+-    - cpufreq: intel_pstate: Fix unsafe HWP MSR access
+-    - parisc: Increase KERNEL_INITIAL_SIZE for 32-bit SMP kernels
+-    - parisc: Fix kernel memory layout regarding position of __gp
+-    - parisc: Increase initial kernel mapping size
+-    - pstore/ramoops: fixup driver removal
+-    - pstore/core: drop cmpxchg based updates
+-    - pstore/ram: Use memcpy_toio instead of memcpy
+-    - pstore/ram: Use memcpy_fromio() to save old buffer
+-    - perf intel-pt: Fix snapshot overlap detection decoder errors
+-    - perf intel-pt: Fix estimated timestamps for cycle-accurate mode
+-    - perf intel-pt: Fix MTC timestamp calculation for large MTC periods
+-    - dm: mark request_queue dead before destroying the DM device
+-    - dm: return correct error code in dm_resume()'s retry loop
+-    - dm mpath: check if path's request_queue is dying in activate_path()
+-    - dm crypt: fix crash on exit
+-    - powerpc/vdso64: Use double word compare on pointers
+-    - powerpc/powernv: Pass CPU-endian PE number to opal_pci_eeh_freeze_clear()
+-    - powerpc/powernv: Use CPU-endian hub diag-data type in
+-      pnv_eeh_get_and_dump_hub_diag()
+-    - powerpc/powernv: Use CPU-endian PEST in pnv_pci_dump_p7ioc_diag_data()
+-    - ubi: Deal with interrupted erasures in WL
+-    - zfcp: fix fc_host port_type with NPIV
+-    - zfcp: fix ELS/GS request&response length for hardware data router
+-    - zfcp: close window with unblocked rport during rport gone
+-    - zfcp: retain trace level for SCSI and HBA FSF response records
+-    - zfcp: restore: Dont use 0 to indicate invalid LUN in rec trace
+-    - zfcp: trace on request for open and close of WKA port
+-    - zfcp: restore tracing of handle for port and LUN with HBA records
+-    - zfcp: fix D_ID field with actual value on tracing SAN responses
+-    - zfcp: fix payload trace length for SAN request&response
+-    - zfcp: trace full payload of all SAN records (req,resp,iels)
+-    - scsi: zfcp: spin_lock_irqsave() is not nestable
+-    - fbdev/efifb: Fix 16 color palette entry calculation
+-    - ovl: Fix info leak in ovl_lookup_temp()
+-    - ovl: copy_up_xattr(): use strnlen
+-    - mb86a20s: fix the locking logic
+-    - mb86a20s: fix demod settings
+-    - cx231xx: don't return error on success
+-    - cx231xx: fix GPIOs for Pixelview SBTVD hybrid
+-    - ALSA: hda - Fix a failure of micmute led when having multi adcs
+-    - MIPS: Fix -mabi=64 build of vdso.lds
+-    - MIPS: ptrace: Fix regs_return_value for kernel context
+-    - lib: move strtobool() to kstrtobool()
+-    - lib: update single-char callers of strtobool()
+-    - lib: add "on"/"off" support to kstrtobool
+-    - Input: i8042 - skip selftest on ASUS laptops
+-    - Input: elantech - force needed quirks on Fujitsu H760
+-    - Input: elantech - add Fujitsu Lifebook E556 to force crc_enabled
+-    - sunrpc: fix write space race causing stalls
+-    - NFSv4: Don't report revoked delegations as valid in nfs_have_delegation()
+-    - NFSv4: nfs4_copy_delegation_stateid() must fail if the delegation is invalid
+-    - NFSv4: Open state recovery must account for file permission changes
+-    - NFSv4.2: Fix a reference leak in nfs42_proc_layoutstats_generic
+-    - scsi: Fix use-after-free
+-    - metag: Only define atomic_dec_if_positive conditionally
+-    - mm: filemap: don't plant shadow entries without radix tree node
+-    - ipc/sem.c: fix complex_count vs. simple op race
+-    - arc: don't leak bits of kernel stack into coredump
+-    - fs/super.c: fix race between freeze_super() and thaw_super()
+-    - cifs: Limit the overall credit acquired
+-    - fs/cifs: keep guid when assigning fid to fileinfo
+-    - Clarify locking of cifs file and tcon structures and make more granular
+-    - Display number of credits available
+-    - Set previous session id correctly on SMB3 reconnect
+-    - SMB3: GUIDs should be constructed as random but valid uuids
+-    - Do not send SMB3 SET_INFO request if nothing is changing
+-    - Cleanup missing frees on some ioctls
+-    - blkcg: Unlock blkcg_pol_mutex only once when cpd == NULL
+-    - x86/e820: Don't merge consecutive E820_PRAM ranges
+-    - kvm: x86: memset whole irq_eoi
+-    - irqchip/gicv3: Handle loop timeout proper
+-    - sd: Fix rw_max for devices that report an optimal xfer size
+-    - hpsa: correct skipping masked peripherals
+-    - PKCS#7: Don't require SpcSpOpusInfo in Authenticode pkcs7 signatures
+-    - bnx2x: Prevent false warning for lack of FC NPIV
+-    - net/mlx4_core: Allow resetting VF admin mac to zero
+-    - acpi, nfit: check for the correct event code in notifications
+-    - mm: workingset: fix crash in shadow node shrinker caused by
+-      replace_page_cache_page()
+-    - mm: filemap: fix mapping->nrpages double accounting in fuse
+-    - Using BUG_ON() as an assert() is _never_ acceptable
+-    - s390/mm: fix gmap tlb flush issues
+-    - irqchip/gic-v3-its: Fix entry size mask for GITS_BASER
+-    - isofs: Do not return EACCES for unknown filesystems
+-    - memstick: rtsx_usb_ms: Runtime resume the device when polling for cards
+-    - memstick: rtsx_usb_ms: Manage runtime PM when accessing the device
+-    - arm64: percpu: rewrite ll/sc loops in assembly
+-    - arm64: kernel: Init MDCR_EL2 even in the absence of a PMU
+-    - ceph: fix error handling in ceph_read_iter
+-    - powerpc/mm: Prevent unlikely crash in copro_calculate_slb()
+-    - mmc: core: Annotate cmd_hdr as __le32
+-    - mmc: rtsx_usb_sdmmc: Avoid keeping the device runtime resumed when unused
+-    - mmc: rtsx_usb_sdmmc: Handle runtime PM while changing the led
+-    - ext4: do not advertise encryption support when disabled
+-    - jbd2: fix incorrect unlock on j_list_lock
+-    - ubifs: Fix xattr_names length in exit paths
+-    - target: Re-add missing SCF_ACK_KREF assignment in v4.1.y
+-    - target: Make EXTENDED_COPY 0xe4 failure return COPY TARGET DEVICE NOT
+-      REACHABLE
+-    - target: Don't override EXTENDED_COPY xcopy_pt_cmd SCSI status code
+-    - Linux 4.4.28
+-
+-  * Xenial update to v4.4.27 stable release (LP: #1637501)
+-    - serial: 8250_dw: Check the data->pclk when get apb_pclk
+-    - btrfs: assign error values to the correct bio structs
+-    - drivers: base: dma-mapping: page align the size when unmap_kernel_range
+-    - fuse: listxattr: verify xattr list
+-    - fuse: invalidate dir dentry after chmod
+-    - fuse: fix killing s[ug]id in setattr
+-    - i40e: avoid NULL pointer dereference and recursive errors on early PCI error
+-    - brcmfmac: fix memory leak in brcmf_fill_bss_param
+-    - ASoC: Intel: Atom: add a missing star in a memcpy call
+-    - reiserfs: Unlock superblock before calling reiserfs_quota_on_mount()
+-    - reiserfs: switch to generic_{get,set,remove}xattr()
+-    - async_pq_val: fix DMA memory leak
+-    - scsi: arcmsr: Simplify user_len checking
+-    - ext4: enforce online defrag restriction for encrypted files
+-    - ext4: reinforce check of i_dtime when clearing high fields of uid and gid
+-    - ext4: fix memory leak in ext4_insert_range()
+-    - ext4: allow DAX writeback for hole punch
+-    - ext4: release bh in make_indexed_dir
+-    - dlm: free workqueues after the connections
+-    - vfs: move permission checking into notify_change() for utimes(NULL)
+-    - cfq: fix starvation of asynchronous writes
+-    - Linux 4.4.27
+-
+-  * Xenial update to v4.4.26 stable release (LP: #1637500)
+-    - x86/build: Build compressed x86 kernels as PIE
+-    - Linux 4.4.26
+-
+-  * ISST-LTE:pVM nvme 0000:a0:00.0: iommu_alloc failed on NVMe card
+-    (LP: #1633128)
+-    - dma-mapping: introduce the DMA_ATTR_NO_WARN attribute
+-    - powerpc: implement the DMA_ATTR_NO_WARN attribute
+-    - nvme: use the DMA_ATTR_NO_WARN attribute
+-
+-  * CVE-2016-8658
+-    - brcmfmac: avoid potential stack overflow in brcmf_cfg80211_start_ap()
+-
+-  * Hotkey doesn't work on HP x360 (LP: #1620979)
+-    - gpiolib: Make it possible to exclude GPIOs from IRQ domain
+-    - pinctrl: cherryview: Do not mask all interrupts in probe
+-    - pinctrl: cherryview: Do not add all southwest and north GPIOs to IRQ domain
+-
+-  * Bad page state in process genwqe_gunzip pfn:3c275 in the genwqe device
+-    driver (LP: #1559194)
+-    - SAUCE: (noup) Bad page state in process genwqe_gunzip pfn:3c275 in the
+-      genwqe device driver
+-
+-  * CVE-2016-7425
+-    - scsi: arcmsr: Buffer overflow in arcmsr_iop_message_xfer()
+-
+-  * Add ipvlan module to 16.04 kernel (LP: #1634705)
+-    - [Config] Add ipvlan to the generic inclusion list
+-
+-  * kernel generates ACPI Exception: AE_NOT_FOUND, Evaluating _DOD incorrectly
+-    (LP: #1634607)
+-    - ACPI / video: skip evaluating _DOD when it does not exist
+-
+-  * BT still shows off after resume by wireless hotkey (LP: #1634380)
+-    - Bluetooth: btusb: Fix atheros firmware download error
+-
+-  * ghash-clmulni-intel module fails to load (LP: #1633058)
+-    - crypto: ghash-clmulni - Fix load failure
+-    - crypto: cryptd - Assign statesize properly
+-
+-  * Xenial update to v4.4.25 stable release (LP: #1634153)
+-    - timekeeping: Fix __ktime_get_fast_ns() regression
+-    - ALSA: ali5451: Fix out-of-bound position reporting
+-    - ALSA: usb-audio: Extend DragonFly dB scale quirk to cover other variants
+-    - ALSA: usb-line6: use the same declaration as definition in header for MIDI
+-      manufacturer ID
+-    - mfd: rtsx_usb: Avoid setting ucr->current_sg.status
+-    - mfd: atmel-hlcdc: Do not sleep in atomic context
+-    - mfd: 88pm80x: Double shifting bug in suspend/resume
+-    - mfd: wm8350-i2c: Make sure the i2c regmap functions are compiled
+-    - KVM: PPC: Book3s PR: Allow access to unprivileged MMCR2 register
+-    - KVM: MIPS: Drop other CPU ASIDs on guest MMU changes
+-    - KVM: PPC: BookE: Fix a sanity check
+-    - x86/boot: Fix kdump, cleanup aborted E820_PRAM max_pfn manipulation
+-    - x86/irq: Prevent force migration of irqs which are not in the vector domain
+-    - x86/dumpstack: Fix x86_32 kernel_stack_pointer() previous stack access
+-    - ARM: dts: mvebu: armada-390: add missing compatibility string and bracket
+-    - ARM: dts: MSM8064 remove flags from SPMI/MPP IRQs
+-    - ARM: cpuidle: Fix error return code
+-    - ima: use file_dentry()
+-    - tpm: fix a race condition in tpm2_unseal_trusted()
+-    - tpm_crb: fix crb_req_canceled behavior
+-    - Linux 4.4.25
+-
+-  * backport fwts UEFI test driver to Xenial (LP: #1633506)
+-    - efi: Add efi_test driver for exporting UEFI runtime service interfaces
+-    - [Config] CONFIG_EFI_TEST=m
+-
+-  * Fix alps driver for multitouch function. (LP: #1633321)
+-    - HID: alps: fix multitouch cursor issue
+-
+-  * xgene merlin crashes when running as iperf server (LP: #1632739)
+-    - drivers: net: xgene: optimizing the code
+-    - xgene: get_phy_device() doesn't return NULL anymore
+-    - drivers: net: xgene: Get channel number from device binding
+-    - drivers: net: xgene: constify xgene_cle_ops structure
+-    - drivers: net: xgene: Fix error handling
+-    - drivers: net: xgene: fix IPv4 forward crash
+-    - drivers: net: xgene: fix sharing of irqs
+-    - drivers: net: xgene: fix ununiform latency across queues
+-    - drivers: net: xgene: fix statistics counters race condition
+-    - drivers: net: xgene: fix register offset
+-    - drivers: net: xgene: Separate set_speed from mac_init
+-    - drivers: net: xgene: Fix module unload crash - hw resource cleanup
+-    - drivers: net: xgene: Fix module unload crash - change sw sequence
+-    - drivers: net: xgene: Fix module unload crash - clkrst sequence
+-    - drivers: net: phy: xgene: Add MDIO driver
+-    - drivers: net: xgene: Add backward compatibility
+-    - drivers: net: xgene: Enable MDIO driver
+-    - drivers: net: xgene: Use exported functions
+-    - drivers: net: xgene: ethtool: Use phy_ethtool_gset and sset
+-    - dtb: xgene: Add MDIO node
+-    - MAINTAINERS: xgene: Add driver and documentation path
+-    - [Config] Enable MDIO_XGENE as a modules
+-
+-  * Add support for KabeLake i219-LOM chips (LP: #1632578)
+-    - e1000e: Initial support for KabeLake
+-
+- -- Luis Henriques <luis.henriques@canonical.com>  Thu, 10 Nov 2016 11:08:11 +0000
+-
+-linux (4.4.0-47.68) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1636941
+-
+-  * Add a driver for Amazon Elastic Network Adapters (ENA) (LP: #1635721)
+-    - lib/bitmap.c: conversion routines to/from u32 array
+-    - net: ethtool: add new ETHTOOL_xLINKSETTINGS API
+-    - net: ena: Add a driver for Amazon Elastic Network Adapters (ENA)
+-    - [config] enable CONFIG_ENA_ETHERNET=m (Amazon ENA driver)
+-
+-  * unexpectedly large memory usage of mounted snaps (LP: #1636847)
+-    - [Config] switch squashfs to single threaded decode
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Wed, 26 Oct 2016 10:47:55 -0700
+-
+-linux (4.4.0-46.67) xenial; urgency=low
+-
+-  [ Seth Forshee ]
+-
+-  * Release Tracking Bug
+-    - LP: #1635242
+-
+-  * proc_keys_show crash when reading /proc/keys (LP: #1634496)
+-    - SAUCE: KEYS: ensure xbuf is large enough to fix buffer overflow in
+-      proc_keys_show (LP: #1634496)
+-
+-  * [Trusty->Yakkety] powerpc/64: Fix incorrect return value from
+-    __copy_tofrom_user (LP: #1632462)
+-    - SAUCE: (no-up) powerpc/64: Fix incorrect return value from
+-      __copy_tofrom_user
+-
+-  * Ubuntu 16.10: Oops panic in move_page_tables/page_remove_rmap after running
+-    memory_stress_ng. (LP: #1628976)
+-    - SAUCE: (no-up) powerpc/pseries: Fix stack corruption in htpe code
+-
+-  * Paths not failed properly when unmapping virtual FC ports in VIOS (using
+-    ibmvfc) (LP: #1632116)
+-    - scsi: ibmvfc: Fix I/O hang when port is not mapped
+-
+-  * PSL data cache should be flushed before resetting CAPI adapter
+-    (LP: #1632049)
+-    - cxl: Flush PSL cache before resetting the adapter
+-
+-  * thunder nic: avoid link delays due to RX_PACKET_DIS (LP: #1630038)
+-    - net: thunderx: Don't set RX_PACKET_DIS while initializing
+-
+-  * Support snaps inside of lxd containers (LP: #1611078)
+-    - Revert "UBUNTU: SAUCE: apparmor: fix sleep in critical section"
+-    - SAUCE: (no-up) apparmor: sync of apparmor 3.6 (from Ubuntu 16.10)
+-
+-  * crypto/vmx/p8_ghash memory corruption (LP: #1630970)
+-    - crypto: ghash-generic - move common definitions to a new header file
+-    - crypto: vmx - Fix memory corruption caused by p8_ghash
+-    - crypto: vmx - Ensure ghash-generic is enabled
+-
+-  * Xenial update to v4.4.24 stable release (LP: #1631468)
+-    - cpuset: handle race between CPU hotplug and cpuset_hotplug_work
+-    - mtd: nand: davinci: Reinitialize the HW ECC engine in 4bit hwctl
+-    - mm,ksm: fix endless looping in allocating memory when ksm enable
+-    - can: dev: fix deadlock reported after bus-off
+-    - x86/init: Fix cr4_init_shadow() on CR4-less machines
+-    - x86/boot: Initialize FPU and X86_FEATURE_ALWAYS even if we don't have CPUID
+-    - drm/nouveau/fifo/nv04: avoid ramht race against cookie insertion
+-    - drm/radeon/si/dpm: add workaround for for Jet parts
+-    - ARM: 8616/1: dt: Respect property size when parsing CPUs
+-    - ARM: 8617/1: dma: fix dma_max_pfn()
+-    - usb: musb: Fix DMA desired mode for Mentor DMA engine
+-    - usb: musb: fix DMA for host mode
+-    - iwlwifi: mvm: fix a few firmware capability checks
+-    - perf/core: Fix pmu::filter_match for SW-led groups
+-    - i40e: avoid null pointer dereference
+-    - pinctrl: uniphier: fix .pin_dbg_show() callback
+-    - pinctrl: Flag strict is a field in struct pinmux_ops
+-    - drivers/perf: arm_pmu: Fix leak in error path
+-    - mmc: pxamci: fix potential oops
+-    - tools/vm/slabinfo: fix an unintentional printf
+-    - ipvs: fix bind to link-local mcast IPv6 address in backup
+-    - nvmem: Declare nvmem_cell_read() consistently
+-    - hwmon: (adt7411) set bit 3 in CFG1 register
+-    - spi: sh-msiof: Avoid invalid clock generator parameters
+-    - iwlwifi: pcie: fix access to scratch buffer
+-    - iwlwifi: mvm: don't use ret when not initialised
+-    - ceph: fix race during filling readdir cache
+-    - usb: gadget: fsl_qe_udc: signedness bug in qe_get_frame()
+-    - gpio: sa1100: fix irq probing for ucb1x00
+-    - irqchip/gicv3: Silence noisy DEBUG_PER_CPU_MAPS warning
+-    - ARM: 8618/1: decompressor: reset ttbcr fields to use TTBR0 on ARMv7
+-    - arm64: debug: avoid resetting stepping state machine when TIF_SINGLESTEP
+-    - MIPS: uprobes: remove incorrect set_orig_insn
+-    - MIPS: fix uretprobe implementation
+-    - MIPS: Malta: Fix IOCU disable switch read for MIPS64
+-    - MIPS: uprobes: fix use of uninitialised variable
+-    - printk: fix parsing of "brl=" option
+-    - tpm: fix byte-order for the value read by tpm2_get_tpm_pt
+-    - regulator: qcom_spmi: Add support for S4 supply on pm8941
+-    - regulator: qcom_spmi: Add support for get_mode/set_mode on switches
+-    - regulator: qcom_spmi: Update mvs1/mvs2 switches on pm8941
+-    - regulator: qcom_smd: Fix voltage ranges for pm8x41
+-    - ARM: sun5i: Fix typo in trip point temperature
+-    - ARM: sa1100: register clocks early
+-    - ARM: sa1100: fix 3.6864MHz clock
+-    - ARM: sa1100: clear reset status prior to reboot
+-    - ARM: shmobile: fix regulator quirk for Gen2
+-    - ARM: sa1111: fix pcmcia suspend/resume
+-    - hwrng: omap - Fix assumption that runtime_get_sync will always succeed
+-    - blk-mq: actually hook up defer list when running requests
+-    - pstore: drop file opened reference count
+-    - tile: Define AT_VECTOR_SIZE_ARCH for ARCH_DLINFO
+-    - iwlmvm: mvm: set correct state in smart-fifo configuration
+-    - NFC: fdp: Detect errors from fdp_nci_create_conn()
+-    - em28xx-i2c: rt_mutex_trylock() returns zero on failure
+-    - gspca: avoid unused variable warnings
+-    - ath9k: Fix programming of minCCA power threshold
+-    - avr32: off by one in at32_init_pio()
+-    - fnic: pci_dma_mapping_error() doesn't return an error code
+-    - dmaengine: at_xdmac: fix debug string
+-    - svc: Avoid garbage replies when pc_func() returns rpc_drop_reply
+-    - NFS: Don't drop CB requests with invalid principals
+-    - pNFS/files: Fix layoutcommit after a commit to DS
+-    - pNFS/flexfiles: Fix layoutcommit after a commit to DS
+-    - ASoC: Intel: Skylake: Fix error return code in skl_probe()
+-    - brcmfmac: Fix glob_skb leak in brcmf_sdiod_recv_chain
+-    - brcmsmac: Free packet if dma_mapping_error() fails in dma_rxfill
+-    - brcmsmac: Initialize power in brcms_c_stf_ss_algo_channel_get()
+-    - powerpc/prom: Fix sub-processor option passed to ibm, client-architecture-
+-      support
+-    - sysctl: handle error writing UINT_MAX to u32 fields
+-    - ASoC: omap-mcpdm: Fix irq resource handling
+-    - kernel/fork: fix CLONE_CHILD_CLEARTID regression in nscd
+-    - dmaengine: at_xdmac: fix to pass correct device identity to free_irq()
+-    - KVM: nVMX: postpone VMCS changes on MSR_IA32_APICBASE write
+-    - IB/ipoib: Fix memory corruption in ipoib cm mode connect flow
+-    - IB/core: Fix use after free in send_leave function
+-    - IB/ipoib: Don't allow MC joins during light MC flush
+-    - IB/mlx4: Fix incorrect MC join state bit-masking on SR-IOV
+-    - IB/mlx4: Fix code indentation in QP1 MAD flow
+-    - IB/mlx4: Use correct subnet-prefix in QP1 mads under SR-IOV
+-    - batman-adv: remove unused callback from batadv_algo_ops struct
+-    - aio: mark AIO pseudo-fs noexec
+-    - clk: xgene: Add missing parenthesis when clearing divider value
+-    - dm log writes: fix bug with too large bios
+-    - USB: serial: cp210x: fix hardware flow-control disable
+-    - usb: misc: legousbtower: Fix NULL pointer deference
+-    - Staging: fbtft: Fix bug in fbtft-core
+-    - USB: serial: cp210x: Add ID for a Juniper console
+-    - Revert "usbtmc: convert to devm_kzalloc"
+-    - ALSA: hda - Adding one more ALC255 pin definition for headset problem
+-    - ACPICA: acpi_get_sleep_type_data: Reduce warnings
+-    - ALSA: hda - Fix headset mic detection problem for several Dell laptops
+-    - ALSA: hda - Add the top speaker pin config for HP Spectre x360
+-    - Linux 4.4.24
+-
+-  * sha1-powerpc returning wrong results (LP: #1629977)
+-    - crypto: sha1-powerpc - little-endian support
+-
+-  *  Dell Precision Trackpoint not working after suspend (LP: #1630857)
+-    - HID: alps: fix stick device not working after resume
+-
+-  * OOPS on beaglebone on boot of 4.4.0-36-generic under snappy ubuntu core
+-    xenial (LP: #1625177)
+-    - net: ethernet: ti: cpdma: fix lockup in cpdma_ctlr_destroy()
+-    - drivers: net: cpsw: fix wrong regs access in cpsw_remove
+-    - drivers: net: cpsw: use of_platform_depopulate()
+-    - ARM: OMAP2+: omap_device: fix crash on omap_device removal
+-    - ARM: OMAP2+: Fix omap_device for module reload on PM runtime forbid
+-    - ARM: OMAP2+: Fix typo in omap_device.c
+-    - drivers: net: cpsw: fix suspend when all ethX devices are down
+-    - drivers: net: cpsw: fix wrong regs access in cpsw_ndo_open
+-    - drivers: net: cpsw: check return code from pm runtime calls
+-    - drivers: net: cpsw: remove pm runtime calls from suspend callbacks
+-    - drivers: net: cpsw: ethtool: fix accessing to suspended device
+-    - drivers: net: cpsw: ndev: fix accessing to suspended device
+-    - drivers: net: cpsw: fix kmemleak false-positive reports for sk buffers
+-
+-  * Autofs parameter substitution broken in kernel 4.4.0-38 and 4.4.0-40
+-    (LP: #1629204)
+-    - SAUCE: (namespace) autofs4: Use real_cred for requestor's ids
+-
+-  * Xenial update to v4.4.23 stable release (LP: #1629386)
+-    - include/linux/kernel.h: change abs() macro so it uses consistent return type
+-    - Fix build warning in kernel/cpuset.c
+-    - reiserfs: fix "new_insert_key may be used uninitialized ..."
+-    - ipv4: panic in leaf_walk_rcu due to stale node pointer
+-    - ipv6: release dst in ping_v6_sendmsg
+-    - tcp: cwnd does not increase in TCP YeAH
+-    - tcp: properly scale window in tcp_v[46]_reqsk_send_ack()
+-    - crypto: arm64/aes-ctr - fix NULL dereference in tail processing
+-    - crypto: arm/aes-ctr - fix NULL dereference in tail processing
+-    - crypto: skcipher - Fix blkcipher walk OOM crash
+-    - crypto: echainiv - Replace chaining with multiplication
+-    - ocfs2/dlm: fix race between convert and migration
+-    - ocfs2: fix start offset to ocfs2_zero_range_for_truncate()
+-    - kbuild: Do not run modules_install and install in paralel
+-    - Makefile: revert "Makefile: Document ability to make file.lst and file.S"
+-      partially
+-    - tools: Support relative directory path for 'O='
+-    - kbuild: forbid kernel directory to contain spaces and colons
+-    - Kbuild: disable 'maybe-uninitialized' warning for
+-      CONFIG_PROFILE_ALL_BRANCHES
+-    - gcov: disable -Wmaybe-uninitialized warning
+-    - Disable "maybe-uninitialized" warning globally
+-    - Disable "frame-address" warning
+-    - Makefile: Mute warning for __builtin_return_address(>0) for tracing only
+-    - net: caif: fix misleading indentation
+-    - Add braces to avoid "ambiguous ‘else’" compiler warnings
+-    - am437x-vfpe: fix typo in vpfe_get_app_input_index
+-    - ath9k: fix misleading indentation
+-    - iwlegacy: avoid warning about missing braces
+-    - Staging: iio: adc: fix indent on break statement
+-    - nouveau: fix nv40_perfctr_next() cleanup regression
+-    - bonding: Fix bonding crash
+-    - Revert "af_unix: Fix splice-bind deadlock"
+-    - af_unix: split 'u->readlock' into two: 'iolock' and 'bindlock'
+-    - vti: flush x-netns xfrm cache when vti interface is removed
+-    - net/irda: handle iriap_register_lsap() allocation failure
+-    - tipc: fix NULL pointer dereference in shutdown()
+-    - net/mlx5: Added missing check of msg length in verifying its signature
+-    - net: dsa: bcm_sf2: Fix race condition while unmasking interrupts
+-    - Revert "phy: IRQ cannot be shared"
+-    - net: smc91x: fix SMC accesses
+-    - bridge: re-introduce 'fix parsing of MLDv2 reports'
+-    - autofs races
+-    - autofs: use dentry flags to block walks during expire
+-    - xfs: prevent dropping ioend completions during buftarg wait
+-    - fsnotify: add a way to stop queueing events on group shutdown
+-    - fanotify: fix list corruption in fanotify_get_response()
+-    - fix fault_in_multipages_...() on architectures with no-op access_ok()
+-    - mtd: maps: sa1100-flash: potential NULL dereference
+-    - mtd: pmcmsp-flash: Allocating too much in init_msp_flash()
+-    - power: reset: hisi-reboot: Unmap region obtained by of_iomap
+-    - fix memory leaks in tracing_buffers_splice_read()
+-    - tracing: Move mutex to protect against resetting of seq data
+-    - mm: delete unnecessary and unsafe init_tlb_ubc()
+-    - can: flexcan: fix resume function
+-    - nl80211: validate number of probe response CSA counters
+-    - btrfs: ensure that file descriptor used with subvol ioctls is a dir
+-    - i2c-eg20t: fix race between i2c init and interrupt enable
+-    - i2c: qup: skip qup_i2c_suspend if the device is already runtime suspended
+-    - MIPS: Fix pre-r6 emulation FPU initialisation
+-    - MIPS: SMP: Fix possibility of deadlock when bringing CPUs online
+-    - MIPS: vDSO: Fix Malta EVA mapping to vDSO page structs
+-    - MIPS: Remove compact branch policy Kconfig entries
+-    - MIPS: Avoid a BUG warning during prctl(PR_SET_FP_MODE, ...)
+-    - MIPS: Add a missing ".set pop" in an early commit
+-    - MIPS: paravirt: Fix undefined reference to smp_bootstrap
+-    - PM / hibernate: Restore processor state before using per-CPU variables
+-    - PM / hibernate: Fix rtree_next_node() to avoid walking off list ends
+-    - power_supply: tps65217-charger: fix missing platform_set_drvdata()
+-    - power: supply: max17042_battery: fix model download bug.
+-    - qxl: check for kmap failures
+-    - hostfs: Freeing an ERR_PTR in hostfs_fill_sb_common()
+-    - Linux 4.4.23
+-
+-  * Xenial update to v4.4.22 stable release (LP: #1627730)
+-    - ext4: use __GFP_NOFAIL in ext4_free_blocks()
+-    - fscrypto: add authorization check for setting encryption policy
+-    - clocksource/drivers/sun4i: Clear interrupts after stopping timer in probe
+-      function
+-    - MIPS: KVM: Check for pfn noslot case
+-    - fscrypto: require write access to mount to set encryption policy
+-    - lightnvm: put bio before return
+-    - powerpc/tm: do not use r13 for tabort_syscall
+-    - powerpc/mm: Don't alias user region to other regions below PAGE_OFFSET
+-    - kernfs: don't depend on d_find_any_alias() when generating notifications
+-    - pNFS: The client must not do I/O to the DS if it's lease has expired
+-    - NFSv4.x: Fix a refcount leak in nfs_callback_up_net
+-    - nfsd: Close race between nfsd4_release_lockowner and nfsd4_lock
+-    - pNFS: Ensure LAYOUTGET and LAYOUTRETURN are properly serialised
+-    - NFSv4.1: Fix the CREATE_SESSION slot number accounting
+-    - kexec: fix double-free when failing to relocate the purgatory
+-    - mm: introduce get_task_exe_file
+-    - audit: fix exe_file access in audit_exe_compare
+-    - dm flakey: fix reads to be issued if drop_writes configured
+-    - IB/uverbs: Fix race between uverbs_close and remove_one
+-    - ARC: mm: fix build breakage with STRICT_MM_TYPECHECKS
+-    - x86/paravirt: Do not trace _paravirt_ident_*() functions
+-    - x86/AMD: Apply erratum 665 on machines without a BIOS fix
+-    - kvm-arm: Unmap shadow pagetables properly
+-    - iio: accel: kxsd9: Fix raw read return
+-    - iio: proximity: as3935: set up buffer timestamps for non-zero values
+-    - iio: adc: rockchip_saradc: reset saradc controller before programming it
+-    - iio: adc: ti_am335x_adc: Protect FIFO1 from concurrent access
+-    - iio: adc: ti_am335x_adc: Increase timeout value waiting for ADC sample
+-    - iio: ad799x: Fix buffered capture for ad7991/ad7995/ad7999
+-    - iio: adc: at91: unbreak channel adc channel 3
+-    - iio: accel: bmc150: reset chip at init time
+-    - iio: fix pressure data output unit in hid-sensor-attributes
+-    - iio: accel: kxsd9: Fix scaling bug
+-    - iio:core: fix IIO_VAL_FRACTIONAL sign handling
+-    - iio: ensure ret is initialized to zero before entering do loop
+-    - serial: 8250_mid: fix divide error bug if baud rate is 0
+-    - serial: 8250: added acces i/o products quad and octal serial cards
+-    - USB: serial: simple: add support for another Infineon flashloader
+-    - usb: renesas_usbhs: fix clearing the {BRDY,BEMP}STS condition
+-    - usb: chipidea: udc: fix NULL ptr dereference in isr_setup_status_phase
+-    - ARM: dts: STiH410: Handle interconnect clock required by EHCI/OHCI (USB)
+-    - USB: change bInterval default to 10 ms
+-    - net: thunderx: Fix OOPs with ethtool --register-dump
+-    - cpuset: make sure new tasks conform to the current config of the cpuset
+-    - ARM: AM43XX: hwmod: Fix RSTST register offset for pruss
+-    - ARM: imx6: add missing BM_CLPCR_BYP_MMDC_CH0_LPM_HS setting for imx6ul
+-    - ARM: imx6: add missing BM_CLPCR_BYPASS_PMIC_READY setting for imx6sx
+-    - ARM: kirkwood: ib62x0: fix size of u-boot environment partition
+-    - ARM: OMAP3: hwmod data: Add sysc information for DSI
+-    - ARM: dts: imx6qdl: Fix SPDIF regression
+-    - ARM: dts: overo: fix gpmc nand cs0 range
+-    - ARM: dts: overo: fix gpmc nand on boards with ethernet
+-    - ARM: dts: STiH407-family: Provide interconnect clock for consumption in ST
+-      SDHCI
+-    - bus: arm-ccn: Fix PMU handling of MN
+-    - bus: arm-ccn: Do not attempt to configure XPs for cycle counter
+-    - bus: arm-ccn: Fix XP watchpoint settings bitmask
+-    - dm log writes: fix check of kthread_run() return value
+-    - dm log writes: move IO accounting earlier to fix error path
+-    - dm crypt: fix error with too large bios
+-    - pinctrl: pistachio: fix mfio pll_lock pinmux
+-    - pinctrl: sunxi: fix uart1 CTS/RTS pins at PG on A23/A33
+-    - arm64: spinlocks: implement smp_mb__before_spinlock() as smp_mb()
+-    - crypto: cryptd - initialize child shash_desc on import
+-    - Btrfs: remove root_log_ctx from ctx list before btrfs_sync_log returns
+-    - fuse: direct-io: don't dirty ITER_BVEC pages
+-    - xhci: fix null pointer dereference in stop command timeout function
+-    - md-cluster: make md-cluster also can work when compiled into kernel
+-    - ath9k: fix using sta->drv_priv before initializing it
+-    - Revert "wext: Fix 32 bit iwpriv compatibility issue with 64 bit Kernel"
+-    - sched/core: Fix a race between try_to_wake_up() and a woken up task
+-    - ipv6: addrconf: fix dev refcont leak when DAD failed
+-    - gma500: remove annoying deprecation warning
+-    - mpssd: fix buffer overflow warning
+-    - drm/i915: Avoid pointer arithmetic in calculating plane surface offset
+-    - mmc: dw_mmc: use resource_size_t to store physical address
+-    - pinctrl: at91-pio4: use %pr format string for resource
+-    - soc: qcom/spm: shut up uninitialized variable warning
+-    - kconfig: tinyconfig: provide whole choice blocks to avoid warnings
+-    - net: simplify napi_synchronize() to avoid warnings
+-    - drm: atmel-hlcdc: Fix vertical scaling
+-    - drm: Only use compat ioctl for addfb2 on X86/IA64
+-    - genirq: Provide irq_gc_{lock_irqsave,unlock_irqrestore}() helpers
+-    - irqchip/atmel-aic: Fix potential deadlock in ->xlate()
+-    - fix iov_iter_fault_in_readable()
+-    - microblaze: fix __get_user()
+-    - avr32: fix copy_from_user()
+-    - microblaze: fix copy_from_user()
+-    - fix minor infoleak in get_user_ex()
+-    - mn10300: failing __get_user() and get_user() should zero
+-    - m32r: fix __get_user()
+-    - sh64: failing __get_user() should zero
+-    - nios2: fix __get_user()
+-    - score: fix __get_user/get_user
+-    - s390: get_user() should zero on failure
+-    - ARC: uaccess: get_user to zero out dest in cause of fault
+-    - asm-generic: make get_user() clear the destination on errors
+-    - frv: fix clear_user()
+-    - cris: buggered copy_from_user/copy_to_user/clear_user
+-    - blackfin: fix copy_from_user()
+-    - score: fix copy_from_user() and friends
+-    - sh: fix copy_from_user()
+-    - hexagon: fix strncpy_from_user() error return
+-    - mips: copy_from_user() must zero the destination on access_ok() failure
+-    - asm-generic: make copy_from_user() zero the destination properly
+-    - alpha: fix copy_from_user()
+-    - metag: copy_from_user() should zero the destination on access_ok() failure
+-    - parisc: fix copy_from_user()
+-    - openrisc: fix copy_from_user()
+-    - nios2: copy_from_user() should zero the tail of destination
+-    - mn10300: copy_from_user() should zero on access_ok() failure...
+-    - sparc32: fix copy_from_user()
+-    - ppc32: fix copy_from_user()
+-    - genirq/msi: Fix broken debug output
+-    - ia64: copy_from_user() should zero the destination on access_ok() failure
+-    - avr32: fix 'undefined reference to `___copy_from_user'
+-    - openrisc: fix the fix of copy_from_user()
+-    - Linux 4.4.22
+-
+-  * AES-XTS poor performance in Ubuntu 16.04 (LP: #1613295)
+-    - crypto: vmx - fix null dereference in p8_aes_xts_crypt
+-
+-  * i40e/setting some ethtool features and remove module right after (modprobe
+-    -r) lead to crash in systems with more than 127 CPUs (LP: #1626782)
+-    - i40e: Fix errors resulted while turning off TSO
+-
+-  * STC860:alpine-pdq:alpdq5p03: kernel panic when adding vnic (LP: #1626222)
+-    - ibmvnic: fix to use list_for_each_safe() when delete items
+-
+-  * Stratton: ISST-LTE:UbuntuKVM: Failed to hotplug virtual devices to guest
+-    running Ubuntu 16.04.1 on UbuntuKVM16.04.1 #179 (LP: #1625986)
+-    - PCI: rpaphp: Fix slot registration for multiple slots under a PHB
+-
+-  * nvme: Missing patch in Ubuntu-4.4.0-41.61 (LP: #1628520)
+-    - nvme: Call pci_disable_device on the error path.
+-
+- -- Seth Forshee <seth.forshee@canonical.com>  Thu, 20 Oct 2016 08:09:34 -0500
+-
+-linux (4.4.0-45.66) xenial; urgency=low
+-
+-  * CVE-2016-5195
+-    - SAUCE: mm: remove gup_flags FOLL_WRITE games from __get_user_pages()
+-
+-  * srcname from mount rule corrupted under load (LP: #1634753)
+-    - SAUCE: apparmor: fix sleep in critical section
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Wed, 19 Oct 2016 11:24:20 +0200
+-
+-linux (4.4.0-43.63) xenial; urgency=low
+-
+-  [ Seth Forshee ]
+-
+-  * Release Tracking Bug
+-    - LP: #1632375
+-
+-  * kswapd0 100% CPU usage (LP: #1518457)
+-    - SAUCE: (no-up) If zone is so small that watermarks are the same, stop zone
+-      balance.
+-
+- -- Seth Forshee <seth.forshee@canonical.com>  Tue, 11 Oct 2016 07:54:56 -0500
+-
+-linux (4.4.0-42.62) xenial; urgency=low
+-
+-  * Fix GRO recursion overflow for tunneling protocols (LP: #1631287)
+-    - tunnels: Don't apply GRO to multiple layers of encapsulation.
+-    - gro: Allow tunnel stacking in the case of FOU/GUE
+-
+-  * CVE-2016-7039
+-    - SAUCE: net: add recursion limit to GRO
+-
+- -- Seth Forshee <seth.forshee@canonical.com>  Fri, 07 Oct 2016 12:03:55 -0500
+-
+-linux (4.4.0-41.61) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1628204
+-
+-  * nvme drive probe failure (LP: #1626894)
+-    - (fix) NVMe: Don't unmap controller registers on reset
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Tue, 27 Sep 2016 09:40:42 -0700
+-
+-linux (4.4.0-40.60) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1627074
+-
+-  * Permission denied in CIFS with kernel 4.4.0-38 (LP: #1626112)
+-    - Fix memory leaks in cifs_do_mount()
+-    - Compare prepaths when comparing superblocks
+-    - SAUCE: Fix regression which breaks DFS mounting
+-
+-  * Backlight does not change when adjust it higher than 50% after S3
+-    (LP: #1625932)
+-    - SAUCE: i915_bpo: drm/i915/backlight: setup and cache pwm alternate
+-      increment value
+-    - SAUCE: i915_bpo: drm/i915/backlight: setup backlight pwm alternate
+-      increment on backlight enable
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Fri, 23 Sep 2016 08:53:31 -0700
+-
+-linux (4.4.0-39.59) xenial; urgency=low
+-
+-  [ Joseph Salisbury ]
+-
+-  * Release Tracking Bug
+-    - LP: #1625303
+-
+-  * thunder: chip errata w/ multiple CQEs for a TSO packet (LP: #1624569)
+-    - net: thunderx: Fix for issues with multiple CQEs posted for a TSO packet
+-
+-  * thunder: faulty TSO padding (LP: #1623627)
+-    - net: thunderx: Fix for HW issue while padding TSO packet
+-
+-  * CVE-2016-6828
+-    - tcp: fix use after free in tcp_xmit_retransmit_queue()
+-
+-  * Sennheiser Officerunner - cannot get freq at ep 0x83 (LP: #1622763)
+-    - SAUCE: (no-up) ALSA: usb-audio: Add quirk for sennheiser officerunner
+-
+-  * Backport E3 Skylake Support in ie31200_edac to Xenial (LP: #1619766)
+-    - EDAC, ie31200_edac: Add Skylake support
+-
+-  * Ubuntu 16.04 - Full EEH Recovery Support for NVMe devices (LP: #1602724)
+-    - SAUCE: nvme: Don't suspend admin queue that wasn't created
+-
+-  * ISST-LTE:pNV: system ben is hung during ST (nvme) (LP: #1620317)
+-    - blk-mq: Allow timeouts to run while queue is freezing
+-    - blk-mq: improve warning for running a queue on the wrong CPU
+-    - blk-mq: don't overwrite rq->mq_ctx
+-
+-  * lsattr 32bit does not work on 64bit kernel (Inappropriate ioctl error)
+-    (LP: #1619918)
+-    - btrfs: bugfix: handle FS_IOC32_{GETFLAGS, SETFLAGS, GETVERSION} in
+-      btrfs_ioctl
+-
+-  * radeon: monitor connected to onboard VGA doesn't work with Xenial
+-    (LP: #1600092)
+-    - drm/radeon/dp: add back special handling for NUTMEG
+-
+-  * initramfs includes qle driver, but not firmware (LP: #1623187)
+-    - qed: add MODULE_FIRMWARE()
+-
+-  * [Hyper-V] Rebase Hyper-V to 4.7.2 (stable) (LP: #1616677)
+-    - hv_netvsc: Implement support for VF drivers on Hyper-V
+-    - hv_netvsc: Fix the list processing for network change event
+-    - Drivers: hv: vmbus: Introduce functions for estimating room in the ring
+-      buffer
+-    - Drivers: hv: vmbus: Use READ_ONCE() to read variables that are volatile
+-    - Drivers: hv: vmbus: Export the vmbus_set_event() API
+-    - lcoking/barriers, arch: Use smp barriers in smp_store_release()
+-    - asm-generic: guard smp_store_release/load_acquire
+-    - x86: reuse asm-generic/barrier.h
+-    - asm-generic: add __smp_xxx wrappers
+-    - x86: define __smp_xxx
+-    - asm-generic: implement virt_xxx memory barriers
+-    - Drivers: hv: vmbus: Move some ring buffer functions to hyperv.h
+-    - Drivers: hv: vmbus: Implement APIs to support "in place" consumption of
+-      vmbus packets
+-    - drivers:hv: Lock access to hyperv_mmio resource tree
+-    - drivers:hv: Make a function to free mmio regions through vmbus
+-    - drivers:hv: Track allocations of children of hv_vmbus in private resource
+-      tree
+-    - drivers:hv: Separate out frame buffer logic when picking MMIO range
+-    - Drivers: hv: vmbus: handle various crash scenarios
+-    - Drivers: hv: balloon: don't crash when memory is added in non-sorted order
+-    - Drivers: hv: balloon: reset host_specified_ha_region
+-    - tools: hv: lsvmbus: add pci pass-through UUID
+-    - hv_netvsc: move start_remove flag to net_device_context
+-    - hv_netvsc: use start_remove flag to protect netvsc_link_change()
+-    - hv_netvsc: untangle the pointer mess
+-    - hv_netvsc: get rid of struct net_device pointer in struct netvsc_device
+-    - hv_netvsc: synchronize netvsc_change_mtu()/netvsc_set_channels() with
+-      netvsc_remove()
+-    - hv_netvsc: set nvdev link after populating chn_table
+-    - hv_netvsc: Fix VF register on vlan devices
+-    - hv_netvsc: remove redundant assignment in netvsc_recv_callback()
+-    - hv_netvsc: introduce {net, hv}_device_to_netvsc_device() helpers
+-    - hv_netvsc: pass struct netvsc_device to rndis_filter_{open, close}()
+-    - hv_netvsc: pass struct net_device to rndis_filter_set_device_mac()
+-    - hv_netvsc: pass struct net_device to rndis_filter_set_offload_params()
+-    - netvsc: get rid of completion timeouts
+-    - PCI: hv: Don't leak buffer in hv_pci_onchannelcallback()
+-    - PCI: hv: Handle all pending messages in hv_pci_onchannelcallback()
+-    - netvsc: Use the new in-place consumption APIs in the rx path
+-    - x86/kernel: Audit and remove any unnecessary uses of module.h
+-    - PCI: hv: Fix interrupt cleanup path
+-    - hv_netvsc: Fix VF register on bonding devices
+-    - hv_netvsc: don't lose VF information
+-    - hv_netvsc: avoid deadlocks between rtnl lock and vf_use_cnt wait
+-    - hv_netvsc: reset vf_inject on VF removal
+-    - hv_netvsc: protect module refcount by checking net_device_ctx->vf_netdev
+-    - hv_netvsc: fix bonding devices check in netvsc_netdev_event()
+-    - Drivers: hv: vmbus: Use the new virt_xx barrier code
+-    - ixgbevf: call ndo_stop() instead of dev_close() when running offline
+-      selftest
+-    - ixgbevf: fix error code path when setting MAC address
+-    - ixgbevf: use bit operations for setting and checking resets
+-    - ixgbevf: Add support for generic Tx checksums
+-    - ixgbe/ixgbevf: Add support for bulk free in Tx cleanup & cleanup boolean
+-      logic
+-    - ixgbevf: refactor ethtool stats handling
+-    - ixgbevf: add support for per-queue ethtool stats
+-    - ixgbevf: make use of BIT() macro to avoid shift of signed values
+-    - ixgbevf: Move API negotiation function into mac_ops
+-    - ixgbevf: Add the device ID's presented while running on Hyper-V
+-    - ixgbevf: Support Windows hosts (Hyper-V)
+-    - ixgbevf: Change the relaxed order settings in VF driver for sparc
+-    - ixgbevf: Use mac_ops instead of trying to identify NIC type
+-
+-  * New device ID for Kabypoint (LP: #1622469)
+-    - mfd: lpss: Add Intel Kaby Lake PCH-H PCI IDs
+-    - SAUCE: i2c: i801: Add support for Kaby Lake PCH-H
+-
+-  * Xenial update to v4.4.21 stable release (LP: #1624037)
+-    - Revert "i40e: fix: do not sleep in netdev_ops"
+-    - fs: Check for invalid i_uid in may_follow_link()
+-    - netfilter: x_tables: check for size overflow
+-    - ext4: validate that metadata blocks do not overlap superblock
+-    - ext4: fix xattr shifting when expanding inodes
+-    - ext4: fix xattr shifting when expanding inodes part 2
+-    - ext4: properly align shifted xattrs when expanding inodes
+-    - ext4: avoid deadlock when expanding inode size
+-    - ext4: avoid modifying checksum fields directly during checksum verification
+-    - block: Fix race triggered by blk_set_queue_dying()
+-    - block: make sure a big bio is split into at most 256 bvecs
+-    - cgroup: reduce read locked section of cgroup_threadgroup_rwsem during fork
+-    - s390/sclp_ctl: fix potential information leak with /dev/sclp
+-    - drm/radeon: fix radeon_move_blit on 32bit systems
+-    - drm: Reject page_flip for !DRIVER_MODESET
+-    - drm/msm: fix use of copy_from_user() while holding spinlock
+-    - ASoC: atmel_ssc_dai: Don't unconditionally reset SSC on stream startup
+-    - xfs: fix superblock inprogress check
+-    - timekeeping: Cap array access in timekeeping_debug
+-    - timekeeping: Avoid taking lock in NMI path with CONFIG_DEBUG_TIMEKEEPING
+-    - lustre: remove unused declaration
+-    - wrappers for ->i_mutex access
+-    - ovl: don't copy up opaqueness
+-    - ovl: remove posix_acl_default from workdir
+-    - ovl: listxattr: use strnlen()
+-    - ovl: fix workdir creation
+-    - ubifs: Fix assertion in layout_in_gaps()
+-    - bcache: RESERVE_PRIO is too small by one when prio_buckets() is a power of
+-      two.
+-    - vhost/scsi: fix reuse of &vq->iov[out] in response
+-    - x86/apic: Do not init irq remapping if ioapic is disabled
+-    - uprobes: Fix the memcg accounting
+-    - crypto: caam - fix IV loading for authenc (giv)decryption
+-    - ALSA: usb-audio: Add sample rate inquiry quirk for B850V3 CP2114
+-    - ALSA: firewire-tascam: accessing to user space outside spinlock
+-    - ALSA: fireworks: accessing to user space outside spinlock
+-    - ALSA: rawmidi: Fix possible deadlock with virmidi registration
+-    - ALSA: hda - Add headset mic quirk for Dell Inspiron 5468
+-    - ALSA: hda - Enable subwoofer on Dell Inspiron 7559
+-    - ALSA: timer: fix NULL pointer dereference in read()/ioctl() race
+-    - ALSA: timer: fix division by zero after SNDRV_TIMER_IOCTL_CONTINUE
+-    - ALSA: timer: fix NULL pointer dereference on memory allocation failure
+-    - scsi: fix upper bounds check of sense key in scsi_sense_key_string()
+-    - metag: Fix atomic_*_return inline asm constraints
+-    - cpufreq: Fix GOV_LIMITS handling for the userspace governor
+-    - hwrng: exynos - Disable runtime PM on probe failure
+-    - regulator: anatop: allow regulator to be in bypass mode
+-    - lib/mpi: mpi_write_sgl(): fix skipping of leading zero limbs
+-    - Linux 4.4.21
+-
+-  * Headset mic detection on some variants of Dell Inspiron 5468 (LP: #1617900)
+-    - ALSA: hda - Add headset mic quirk for Dell Inspiron 5468
+-
+-  * Xenial update to v4.4.20 stable release (LP: #1621113)
+-    - hugetlb: fix nr_pmds accounting with shared page tables
+-    - x86/mm: Disable preemption during CR3 read+write
+-    - uprobes/x86: Fix RIP-relative handling of EVEX-encoded instructions
+-    - tools/testing/nvdimm: fix SIGTERM vs hotplug crash
+-    - SUNRPC: Handle EADDRNOTAVAIL on connection failures
+-    - SUNRPC: allow for upcalls for same uid but different gss service
+-    - powerpc/eeh: eeh_pci_enable(): fix checking of post-request state
+-    - ALSA: usb-audio: Add a sample rate quirk for Creative Live! Cam Socialize HD
+-      (VF0610)
+-    - ALSA: usb-audio: Add quirk for ELP HD USB Camera
+-    - arm64: Define AT_VECTOR_SIZE_ARCH for ARCH_DLINFO
+-    - parisc: Fix order of EREFUSED define in errno.h
+-    - virtio: fix memory leak in virtqueue_add()
+-    - vfio/pci: Fix NULL pointer oops in error interrupt setup handling
+-    - perf intel-pt: Fix occasional decoding errors when tracing system-wide
+-    - libnvdimm, nd_blk: mask off reserved status bits
+-    - ALSA: hda - Manage power well properly for resume
+-    - NVMe: Don't unmap controller registers on reset
+-    - PCI: Support PCIe devices with short cfg_size
+-    - PCI: Add Netronome vendor and device IDs
+-    - PCI: Limit config space size for Netronome NFP6000 family
+-    - PCI: Add Netronome NFP4000 PF device ID
+-    - PCI: Limit config space size for Netronome NFP4000
+-    - mmc: sdhci-acpi: Reduce Baytrail eMMC/SD/SDIO hangs
+-    - ACPI: CPPC: Return error if _CPC is invalid on a CPU
+-    - ACPI / CPPC: Prevent cpc_desc_ptr points to the invalid data
+-    - um: Don't discard .text.exit section
+-    - genirq/msi: Remove unused MSI_FLAG_IDENTITY_MAP
+-    - genirq/msi: Make sure PCI MSIs are activated early
+-    - crypto: caam - fix non-hmac hashes
+-    - crypto: caam - fix echainiv(authenc) encrypt shared descriptor
+-    - crypto: caam - defer aead_set_sh_desc in case of zero authsize
+-    - usb: ehci: change order of register cleanup during shutdown
+-    - usb: misc: usbtest: add fix for driver hang
+-    - usb: dwc3: pci: add Intel Kabylake PCI ID
+-    - usb: dwc3: gadget: increment request->actual once
+-    - usb: hub: Fix unbalanced reference count/memory leak/deadlocks
+-    - USB: hub: fix up early-exit pathway in hub_activate
+-    - USB: hub: change the locking in hub_activate
+-    - usb: renesas_usbhs: clear the BRDYSTS in usbhsg_ep_enable()
+-    - usb: renesas_usbhs: Use dmac only if the pipe type is bulk
+-    - USB: validate wMaxPacketValue entries in endpoint descriptors
+-    - usb: gadget: fsl_qe_udc: off by one in setup_received_handle()
+-    - usb/gadget: fix gadgetfs aio support.
+-    - xhci: always handle "Command Ring Stopped" events
+-    - usb: xhci: Fix panic if disconnect
+-    - xhci: don't dereference a xhci member after removing xhci
+-    - USB: serial: fix memleak in driver-registration error path
+-    - USB: serial: option: add D-Link DWM-156/A3
+-    - USB: serial: option: add support for Telit LE920A4
+-    - USB: serial: ftdi_sio: add device ID for WICED USB UART dev board
+-    - USB: serial: ftdi_sio: add PIDs for Ivium Technologies devices
+-    - iommu/dma: Don't put uninitialised IOVA domains
+-    - iommu/arm-smmu: Fix CMDQ error handling
+-    - iommu/arm-smmu: Don't BUG() if we find aborting STEs with disable_bypass
+-    - pinctrl/amd: Remove the default de-bounce time
+-    - EDAC: Increment correct counter in edac_inc_ue_error()
+-    - s390/dasd: fix hanging device after clear subchannel
+-    - mac80211: fix purging multicast PS buffer queue
+-    - arm64: dts: rockchip: add reset saradc node for rk3368 SoCs
+-    - of: fix reference counting in of_graph_get_endpoint_by_regs
+-    - sched/cputime: Fix NO_HZ_FULL getrusage() monotonicity regression
+-    - sched/nohz: Fix affine unpinned timers mess
+-    - iio: fix sched WARNING "do not call blocking ops when !TASK_RUNNING"
+-    - drm/amdgpu: Change GART offset to 64-bit
+-    - drm/amdgpu: fix amdgpu_move_blit on 32bit systems
+-    - drm/amdgpu: avoid a possible array overflow
+-    - drm/amdgpu: skip TV/CV in display parsing
+-    - drm/amd/amdgpu: sdma resume fail during S4 on CI
+-    - drm/amdgpu: record error code when ring test failed
+-    - drm/i915: fix aliasing_ppgtt leak
+-    - ARC: build: Better way to detect ISA compatible toolchain
+-    - ARC: use correct offset in pt_regs for saving/restoring user mode r25
+-    - ARC: Call trace_hardirqs_on() before enabling irqs
+-    - ARC: Elide redundant setup of DMA callbacks
+-    - aacraid: Check size values after double-fetch from user
+-    - mfd: cros_ec: Add cros_ec_cmd_xfer_status() helper
+-    - i2c: cros-ec-tunnel: Fix usage of cros_ec_cmd_xfer()
+-    - cdc-acm: fix wrong pipe type on rx interrupt xfers
+-    - mpt3sas: Fix resume on WarpDrive flash cards
+-    - megaraid_sas: Fix probing cards without io port
+-    - usb: renesas_usbhs: gadget: fix return value check in
+-      usbhs_mod_gadget_probe()
+-    - gpio: Fix OF build problem on UM
+-    - fs/seq_file: fix out-of-bounds read
+-    - btrfs: waiting on qgroup rescan should not always be interruptible
+-    - btrfs: properly track when rescan worker is running
+-    - Input: tegra-kbc - fix inverted reset logic
+-    - Input: i8042 - break load dependency between atkbd/psmouse and i8042
+-    - Input: i8042 - set up shared ps2_cmd_mutex for AUX ports
+-    - crypto: nx - off by one bug in nx_of_update_msc()
+-    - crypto: qat - fix aes-xts key sizes
+-    - dmaengine: usb-dmac: check CHCR.DE bit in usb_dmac_isr_channel()
+-    - USB: avoid left shift by -1
+-    - usb: chipidea: udc: don't touch DP when controller is in host mode
+-    - USB: fix typo in wMaxPacketSize validation
+-    - USB: serial: mos7720: fix non-atomic allocation in write path
+-    - USB: serial: mos7840: fix non-atomic allocation in write path
+-    - USB: serial: option: add WeTelecom WM-D200
+-    - USB: serial: option: add WeTelecom 0x6802 and 0x6803 products
+-    - staging: comedi: daqboard2000: bug fix board type matching code
+-    - staging: comedi: comedi_test: fix timer race conditions
+-    - staging: comedi: ni_mio_common: fix AO inttrig backwards compatibility
+-    - staging: comedi: ni_mio_common: fix wrong insn_write handler
+-    - ACPI / drivers: fix typo in ACPI_DECLARE_PROBE_ENTRY macro
+-    - ACPI / drivers: replace acpi_probe_lock spinlock with mutex
+-    - ACPI / sysfs: fix error code in get_status()
+-    - ACPI / SRAT: fix SRAT parsing order with both LAPIC and X2APIC present
+-    - ALSA: line6: Remove double line6_pcm_release() after failed acquire.
+-    - ALSA: line6: Give up on the lock while URBs are released.
+-    - ALSA: line6: Fix POD sysfs attributes segfault
+-    - hwmon: (iio_hwmon) fix memory leak in name attribute
+-    - sysfs: correctly handle read offset on PREALLOC attrs
+-    - Linux 4.4.20
+-
+-  * Failed to acknowledge elog: /sys/firmware/opal/elog/0x5018d709/acknowledge
+-    (2:No such file or directory) (LP: #1619552)
+-    - powerpc/powernv : Drop reference added by kset_find_obj()
+-
+-  * backport support for userspace access of DP aux devices (LP: #1619756)
+-    - drm/dp: Add a drm_aux-dev module for reading/writing dpcd registers.
+-    - drm/dp: Allow signals to interrupt drm_aux-dev reads/writes
+-    - [Config] CONFIG_DRM_DP_AUX_CHARDEV=y
+-
+-  * Enable virtual scsi server driver for Power (LP: #1615665)
+-    - SAUCE: Ibmvscsis: Properly deregister target sessions
+-    - SAUCE: Return TCMU-generated sense data to fabric module
+-    - SAUCE: Ibmvscsis: Code cleanup of print statements
+-    - SAUCE: Ibmvscsis: Fixed a bug reported by Dan Carpenter
+-
+-  * ISST-LTE: system dropped into xmon at pcibios_release_device+0x5c/0x80
+-    during running dlpar test on monklp3 (LP: #1618151)
+-    - powerpc/pseries: use pci_host_bridge.release_fn() to kfree(phb)
+-
+-  * Kernel Build Fails for Fuse Module (LP: #1617550)
+-    - SAUCE: (namespace) userns: Export current_in_userns to modules
+-
+-  * boot-time kernel panic introduced in 4.4.0-18, not present in 4.4.0-15
+-    (LP: #1572630)
+-    - blk-mq: Reuse hardware context cpumask for tags
+-    - blk-mq: Use proper cpumask iterator
+-
+- -- Joseph Salisbury <joseph.salisbury@canonical.com>  Mon, 19 Sep 2016 14:23:10 -0400
+-
+-linux (4.4.0-38.57) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1620658
+-
+-  * CIFS client: access problems after updating to kernel 4.4.0-29-generic
+-    (LP: #1612135)
+-    - Revert "UBUNTU: SAUCE: (namespace) Bypass sget() capability check for nfs"
+-    - fs: Call d_automount with the filesystems creds
+-
+-  * apt-key add fails in overlayfs (LP: #1618572)
+-    - SAUCE: overlayfs: fix regression in whiteout detection
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 30 Aug 2016 12:24:30 -0600
+-
+-linux (4.4.0-37.56) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1618040
+-
+-  * [Feature] Instruction decoder support for new SKX instructions- AVX512
+-    (LP: #1591655)
+-    - x86/insn: perf tools: Fix vcvtph2ps instruction decoding
+-    - x86/insn: Add AVX-512 support to the instruction decoder
+-    - perf tools: Add AVX-512 support to the instruction decoder used by Intel PT
+-    - perf tools: Add AVX-512 instructions to the new instructions test
+-
+-  * [Ubuntu 16.04] FCoE Lun not visible in OS with inbox driver - Issue with
+-    ioremap() call on 32bit kernel (LP: #1608652)
+-    - lpfc: Correct issue with ioremap() call on 32bit kernel
+-
+-  * [Feature] turbostat support for Skylake-SP server (LP: #1591802)
+-    - tools/power turbostat: decode more CPUID fields
+-    - tools/power turbostat: CPUID(0x16) leaf shows base, max, and bus frequency
+-    - tools/power turbostat: decode HWP registers
+-    - tools/power turbostat: Decode MSR_MISC_PWR_MGMT
+-    - tools/power turbostat: allow sub-sec intervals
+-    - tools/power turbostat: Intel Xeon x200: fix erroneous bclk value
+-    - tools/power turbostat: Intel Xeon x200: fix turbo-ratio decoding
+-    - tools/power turbostat: re-name "%Busy" field to "Busy%"
+-    - tools/power turbostat: add --out option for saving output in a file
+-    - tools/power turbostat: fix compiler warnings
+-    - tools/power turbostat: make fewer systems calls
+-    - tools/power turbostat: show IRQs per CPU
+-    - tools/power turbostat: show GFXMHz
+-    - tools/power turbostat: show GFX%rc6
+-    - tools/power turbostat: detect and work around syscall jitter
+-    - tools/power turbostat: indicate SMX and SGX support
+-    - tools/power turbostat: call __cpuid() instead of __get_cpuid()
+-    - tools/power turbostat: correct output for MSR_NHM_SNB_PKG_CST_CFG_CTL dump
+-    - tools/power turbostat: bugfix: TDP MSRs print bits fixing
+-    - tools/power turbostat: SGX state should print only if --debug
+-    - tools/power turbostat: print IRTL MSRs
+-    - tools/power turbostat: initial BXT support
+-    - tools/power turbostat: decode BXT TSC frequency via CPUID
+-    - tools/power turbostat: initial SKX support
+-
+-  * [BYT] display hotplug doesn't work on console (LP: #1616894)
+-    - drm/i915/vlv: Make intel_crt_reset() per-encoder
+-    - drm/i915/vlv: Reset the ADPA in vlv_display_power_well_init()
+-    - drm/i915/vlv: Disable HPD in valleyview_crt_detect_hotplug()
+-    - drm/i915: Enable polling when we don't have hpd
+-
+-  * [Feature]intel_idle enabling on Broxton-P (LP: #1520446)
+-    - intel_idle: add BXT support
+-
+-  * [Feature] EDAC: Update driver for SKX-SP (LP: #1591815)
+-    - [Config] CONFIG_EDAC_SKX=m
+-    - EDAC, skx_edac: Add EDAC driver for Skylake
+-
+-  * [Feature] KBL: Sandy Peak(3168) WiFi/BT support (LP: #1591648)
+-    - Bluetooth: Add support for Intel Bluetooth device 3168 [8087:0aa7]
+-
+-  * MacBookPro11,4 fails to poweroff or suspend (LP: #1587714)
+-    - SAUCE: PCI: Workaround to enable poweroff on Mac Pro 11
+-
+-  * Support Edge Gateway's Bluetooth LED (LP: #1512999)
+-    - SAUCE: Bluetooth: Support for LED on Edge Gateways
+-    - SAUCE: Bluetooth: Use host bridge subsystem IDs to identify Edge Gateways
+-
+-  * Please add support for alps touchpad. (LP: #1616813)
+-    - [Config] CONFIG_HID_ALPS=m
+-    - HID: add Alps I2C HID Touchpad-Stick support
+-    - HID: alps: struct u1_dev *priv is internal to the driver
+-    - HID: alps: pass correct sizes to hid_hw_raw_request()
+-    - HID: alps: match alps devices in core
+-    - HID: alps: a few cleanups
+-
+-  * DINO2M - System hangs with a black screen during s4 stress test
+-    (LP: #1616781)
+-    - x86/power/64: Fix kernel text mapping corruption during image restoration
+-
+-  * Xenial update to v4.4.17 stable release (LP: #1611833)
+-    - USB: OHCI: Don't mark EDs as ED_OPER if scheduling fails
+-    - x86/quirks: Apply nvidia_bugs quirk only on root bus
+-    - x86/quirks: Reintroduce scanning of secondary buses
+-    - x86/quirks: Add early quirk to reset Apple AirPort card
+-    - dmaengine: at_xdmac: align descriptors on 64 bits
+-    - dmaengine: at_xdmac: fix residue corruption
+-    - dmaengine: at_xdmac: double FIFO flush needed to compute residue
+-    - mm, sl[au]b: add __GFP_ATOMIC to the GFP reclaim mask
+-    - mm, compaction: abort free scanner if split fails
+-    - fs/nilfs2: fix potential underflow in call to crc32_le
+-    - mm, compaction: prevent VM_BUG_ON when terminating freeing scanner
+-    - mm, meminit: always return a valid node from early_pfn_to_nid
+-    - mm, meminit: ensure node is online before checking whether pages are
+-      uninitialised
+-    - vmlinux.lds: account for destructor sections
+-    - pps: do not crash when failed to register
+-    - kernel/sysrq, watchdog, sched/core: Reset watchdog on all CPUs while
+-      processing sysrq-w
+-    - arc: unwind: warn only once if DW2_UNWIND is disabled
+-    - ARC: unwind: ensure that .debug_frame is generated (vs. .eh_frame)
+-    - xen/pciback: Fix conf_space read/write overlap check.
+-    - xenbus: don't BUG() on user mode induced condition
+-    - xenbus: don't bail early from xenbus_dev_request_and_reply()
+-    - Input: vmmouse - remove port reservation
+-    - Input: elantech - add more IC body types to the list
+-    - Input: xpad - fix oops when attaching an unknown Xbox One gamepad
+-    - Input: wacom_w8001 - w8001_MAX_LENGTH should be 13
+-    - Input: xpad - validate USB endpoint count during probe
+-    - Input: tsc200x - report proper input_dev name
+-    - pvclock: Add CPU barriers to get correct version value
+-    - pinctrl: single: Fix missing flush of posted write for a wakeirq
+-    - pinctrl: imx: Do not treat a PIN without MUX register as an error
+-    - cgroup: set css->id to -1 during init
+-    - power_supply: power_supply_read_temp only if use_cnt > 0
+-    - locks: use file_inode()
+-    - Revert "ecryptfs: forbid opening files without mmap handler"
+-    - ecryptfs: don't allow mmap when the lower fs doesn't support it
+-    - ext4: verify extent header depth
+-    - 9p: use file_dentry()
+-    - namespace: update event counter when umounting a deleted dentry
+-    - spi: sunxi: fix transfer timeout
+-    - spi: sun4i: fix FIFO limit
+-    - clk: rockchip: initialize flags of clk_init_data in mmc-phase clock
+-    - platform/chrome: cros_ec_dev - double fetch bug in ioctl
+-    - block: fix use-after-free in sys_ioprio_get()
+-    - mmc: block: fix packed command header endianness
+-    - sched/fair: Fix effective_load() to consistently use smoothed load
+-    - ovl: handle ATTR_KILL*
+-    - perf/x86: fix PEBS issues on Intel Atom/Core2
+-    - can: at91_can: RX queue could get stuck at high bus load
+-    - can: c_can: Update D_CAN TX and RX functions to 32 bit - fix Altera Cyclone
+-      access
+-    - can: fix handling of unmodifiable configuration options fix
+-    - can: fix oops caused by wrong rtnl dellink usage
+-    - RDS: fix rds_tcp_init() error path
+-    - SCSI: fix new bug in scsi_dev_info_list string matching
+-    - ipr: Clear interrupt on croc/crocodile when running with LSI
+-    - posix_cpu_timer: Exit early when process has been reaped
+-    - i2c: mux: reg: wrong condition checked for of_address_to_resource return
+-      value
+-    - libata: LITE-ON CX1-JB256-HP needs lower max_sectors
+-    - libceph: apply new_state before new_up_client on incrementals
+-    - net: mvneta: set real interrupt per packet for tx_done
+-    - intel_th: pci: Add Kaby Lake PCH-H support
+-    - intel_th: Fix a deadlock in modprobing
+-    - vfs: fix deadlock in file_remove_privs() on overlayfs
+-    - Linux 4.4.17
+-    - xenbus: don't look up transaction IDs for ordinary writes
+-
+-  * Enable virtual scsi server driver for Power (LP: #1615665)
+-    - [Config] CONFIG_SCSI_IBMVSCSIS=m
+-    - target: Add target_alloc_session() helper function
+-    - ibmvscsis: Initial commit of IBM VSCSI Tgt Driver
+-
+-  * AES-XTS poor performance in Ubuntu 16.04 (LP: #1613295)
+-    - crypto: vmx: Only call enable_kernel_vsx()
+-    - powerpc: Create disable_kernel_{fp,altivec,vsx,spe}()
+-    - crypto: vmx - Adding asm subroutines for XTS
+-    - crypto: xts - consolidate sanity check for keys
+-    - crypto: vmx - Adding support for XTS
+-    - crypto: vmx - Fix aes_p8_xts_decrypt build failure
+-    - crypto: xts - fix compile errors
+-
+-  *  System hang when plug/pull USB 3.1 key via thunderbolt port over 5 times
+-    (LP: #1616318)
+-    - USB: don't free bandwidth_mutex too early
+-
+-  * Ubuntu 16.04 - Full EEH Recovery Support for NVMe devices (LP: #1602724)
+-    - nvme: Suspend all queues before deletion
+-
+-  * change_hat is logging failures during expected hat probing (LP: #1615893)
+-    - SAUCE: apparmor: Fix auditing behavior for change_hat probing
+-
+-  * deleted files outside of the namespace are not being treated as disconnected
+-    (LP: #1615892)
+-    - SAUCE: apparmor: deleted dentries can be disconnected
+-
+-  * stacking to unconfined in a child namespace confuses mediation
+-    (LP: #1615890)
+-    - SAUCE: apparmor: special case unconfined when determining the mode
+-
+-  * apparmor module parameters can be changed after the policy is locked
+-    (LP: #1615895)
+-    - SAUCE: apparmor: fix: parameters can be changed after policy is locked
+-
+-  * AppArmor profile reloading causes an intermittent kernel BUG (LP: #1579135)
+-    - SAUCE: apparmor: fix vec_unique for vectors larger than 8
+-
+-  * label vec reductions can result in reference labels instead of direct access
+-    to labels (LP: #1615889)
+-    - SAUCE: apparmor: reduction of vec to single entry is just that entry
+-
+-  * profiles from different namespaces can block other namespaces from being
+-    able to load a profile (LP: #1615887)
+-    - SAUCE: apparmor: profiles in one ns can affect mediation in another ns
+-
+-  * vmalloc failure leads to null ptr dereference in aa_dfa_next (LP: #1592547)
+-    - SAUCE: apparmor: oops in profile_unpack() when policy_db is not present
+-
+-  * vmalloc_addr is being checked on the failed return address of kvzalloc()
+-    (LP: #1615885)
+-    - SAUCE: apparmor: fix: don't check for vmalloc_addr if kvzalloc() failed
+-
+-  * dfa is missing a bounds check which can cause an oops (LP: #1615882)
+-    - SAUCE: apparmor: Add missing id bounds check on dfa verification
+-
+-  * The label build for onexec when stacking is wrong (LP: #1615881)
+-    - SAUCE: apparmor: Fix label build for onexec stacking.
+-
+-  * The inherit check for new to old label comparison for domain transitions is
+-    wrong (LP: #1615880)
+-    - SAUCE: apparmor: Fix new to old label comparison for domain transitions
+-
+-  * warning stack trace while playing with apparmor namespaces (LP: #1593874)
+-    - SAUCE: apparmor: fix stack trace when removing namespace with profiles
+-
+-  * __label_update proxy comparison test is wrong (LP: #1615878)
+-    - SAUCE: apparmor: Fix __label_update proxy comparison test
+-
+-  * Xenial update to v4.4.19 stable release (LP: #1615620)
+-    - usb: gadget: avoid exposing kernel stack
+-    - usb: f_fs: off by one bug in _ffs_func_bind()
+-    - usb: renesas_usbhs: protect the CFIFOSEL setting in usbhsg_ep_enable()
+-    - usb: dwc3: fix for the isoc transfer EP_BUSY flag
+-    - USB: serial: option: add support for Telit LE910 PID 0x1206
+-    - usb: renesas_usbhs: fix NULL pointer dereference in xfer_work()
+-    - arm64: kernel: Save and restore UAO and addr_limit on exception entry
+-    - arm64: debug: unmask PSTATE.D earlier
+-    - arm64: Fix incorrect per-cpu usage for boot CPU
+-    - tty: serial: msm: Don't read off end of tx fifo
+-    - serial: samsung: Fix ERR pointer dereference on deferred probe
+-    - tty/serial: atmel: fix RS485 half duplex with DMA
+-    - gpio: pca953x: Fix NBANK calculation for PCA9536
+-    - gpio: intel-mid: Remove potentially harmful code
+-    - Bluetooth: hci_intel: Fix null gpio desc pointer dereference
+-    - pinctrl: cherryview: prevent concurrent access to GPIO controllers
+-    - arm64: dts: rockchip: fixes the gic400 2nd region size for rk3368
+-    - arm64: mm: avoid fdt_check_header() before the FDT is fully mapped
+-    - KVM: PPC: Book3S HV: Pull out TM state save/restore into separate procedures
+-    - KVM: PPC: Book3S HV: Save/restore TM state in H_CEDE
+-    - KVM: MTRR: fix kvm_mtrr_check_gfn_range_consistency page fault
+-    - KVM: VMX: handle PML full VMEXIT that occurs during event delivery
+-    - KVM: nVMX: Fix memory corruption when using VMCS shadowing
+-    - intel_pstate: Fix MSR_CONFIG_TDP_x addressing in core_get_max_pstate()
+-    - mfd: qcom_rpm: Fix offset error for msm8660
+-    - mfd: qcom_rpm: Parametrize also ack selector size
+-    - media: usbtv: prevent access to free'd resources
+-    - media: dvb_ringbuffer: Add memory barriers
+-    - vb2: core: Skip planes array verification if pb is NULL
+-    - Fix RC5 decoding with Fintek CIR chipset
+-    - sur40: lower poll interval to fix occasional FPS drops to ~56 FPS
+-    - sur40: fix occasional oopses on device close
+-    - dm: set DMF_SUSPENDED* _before_ clearing DMF_NOFLUSH_SUSPENDING
+-    - hp-wmi: Fix wifi cannot be hard-unblocked
+-    - s5p-mfc: Set device name for reserved memory region devs
+-    - s5p-mfc: Add release callback for memory region devs
+-    - i2c: efm32: fix a failure path in efm32_i2c_probe()
+-    - spi: pxa2xx: Clear all RFT bits in reset_sccr1() on Intel Quark
+-    - Bluetooth: Fix l2cap_sock_setsockopt() with optname BT_RCVMTU
+-    - EDAC: Correct channel count limit
+-    - HID: uhid: fix timeout when probe races with IO
+-    - ovl: disallow overlayfs as upperdir
+-    - remoteproc: Fix potential race condition in rproc_add
+-    - ARC: mm: don't loose PTE_SPECIAL in pte_modify()
+-    - jbd2: make journal y2038 safe
+-    - fs/cifs: make share unaccessible at root level mountable
+-    - cifs: Check for existing directory when opening file with O_CREAT
+-    - cifs: fix crash due to race in hmac(md5) handling
+-    - CIFS: Fix a possible invalid memory access in smb2_query_symlink()
+-    - random: initialize the non-blocking pool via add_hwgenerator_randomness()
+-    - random: print a warning for the first ten uninitialized random users
+-    - random: add interrupt callback to VMBus IRQ handler
+-    - MIPS: KVM: Fix mapped fault broken commpage handling
+-    - MIPS: KVM: Add missing gfn range check
+-    - MIPS: KVM: Fix gfn range check in kseg0 tlb faults
+-    - MIPS: KVM: Propagate kseg0/mapped tlb fault errors
+-    - nfs: don't create zero-length requests
+-    - nfsd: Fix race between FREE_STATEID and LOCK
+-    - nfsd: don't return an unhashed lock stateid after taking mutex
+-    - drm/i915: Don't complain about lack of ACPI video bios
+-    - iommu/exynos: Suppress unbinding to prevent system failure
+-    - iommu/vt-d: Return error code in domain_context_mapping_one()
+-    - iommu/amd: Handle IOMMU_DOMAIN_DMA in ops->domain_free call-back
+-    - iommu/amd: Init unity mappings only for dma_ops domains
+-    - iommu/amd: Update Alias-DTE in update_device_table()
+-    - audit: fix a double fetch in audit_log_single_execve_arg()
+-    - ARM: dts: sunxi: Add a startup delay for fixed regulator enabled phys
+-    - netlabel: add address family checks to netlbl_{sock,req}_delattr()
+-    - w1:omap_hdq: fix regression
+-    - drm/amdgpu: add a delay after ATPX dGPU power off
+-    - drm/amdgpu: Poll for both connect/disconnect on analog connectors
+-    - drm/amdgpu: support backlight control for UNIPHY3
+-    - drm/amdgpu: Disable RPM helpers while reprobing connectors on resume
+-    - drm/amdgpu: fix firmware info version checks
+-    - drm/amdgpu/gmc7: add missing mullins case
+-    - drm/radeon: add a delay after ATPX dGPU power off
+-    - drm/radeon: Poll for both connect/disconnect on analog connectors
+-    - drm/radeon: fix firmware info version checks
+-    - drm/radeon: support backlight control for UNIPHY3
+-    - drm/nouveau/gr/nv3x: fix instobj write offsets in gr setup
+-    - drm/nouveau/fbcon: fix font width not divisible by 8
+-    - drm: Restore double clflush on the last partial cacheline
+-    - drm/edid: Add 6 bpc quirk for display AEO model 0.
+-    - drm/i915: Never fully mask the the EI up rps interrupt on SNB/IVB
+-    - drm/i915/dp: Revert "drm/i915/dp: fall back to 18 bpp when sink capability
+-      is unknown"
+-    - balloon: check the number of available pages in leak balloon
+-    - ftrace/recordmcount: Work around for addition of metag magic but not
+-      relocations
+-    - metag: Fix __cmpxchg_u32 asm constraint for CMP
+-    - block: add missing group association in bio-cloning functions
+-    - block: fix bdi vs gendisk lifetime mismatch
+-    - mtd: nand: fix bug writing 1 byte less than page size
+-    - mm/hugetlb: avoid soft lockup in set_max_huge_pages()
+-    - ALSA: hda: Fix krealloc() with __GFP_ZERO usage
+-    - ALSA: hda/realtek - Can't adjust speaker's volume on a Dell AIO
+-    - ALSA: hda: add AMD Bonaire AZ PCI ID with proper driver caps
+-    - ALSA: hda - Fix headset mic detection problem for two dell machines
+-    - IB/mlx5: Fix MODIFY_QP command input structure
+-    - IB/mlx5: Fix entries checks in mlx5_ib_create_cq
+-    - IB/mlx5: Fix returned values of query QP
+-    - IB/mlx5: Fix entries check in mlx5_ib_resize_cq
+-    - IB/mlx5: Fix post send fence logic
+-    - IB/mlx5: Return PORT_ERR in Active to Initializing tranisition
+-    - IB/SA: Use correct free function
+-    - IB/IPoIB: Don't update neigh validity for unresolved entries
+-    - IB/IWPM: Fix a potential skb leak
+-    - IB/mlx4: Fix the SQ size of an RC QP
+-    - IB/mlx4: Fix error flow when sending mads under SRIOV
+-    - IB/mlx4: Fix memory leak if QP creation failed
+-    - of: fix memory leak related to safe_name()
+-    - ubi: Make volume resize power cut aware
+-    - ubi: Fix early logging
+-    - ubi: Fix race condition between ubi device creation and udev
+-    - iscsi-target: Fix panic when adding second TCP connection to iSCSI session
+-    - target: Fix ordered task target_setup_cmd_from_cdb exception hang
+-    - target: Fix missing complete during ABORT_TASK + CMD_T_FABRIC_STOP
+-    - target: Fix race between iscsi-target connection shutdown + ABORT_TASK
+-    - target: Fix max_unmap_lba_count calc overflow
+-    - target: Fix ordered task CHECK_CONDITION early exception handling
+-    - Input: elan_i2c - properly wake up touchpad on ASUS laptops
+-    - SUNRPC: Don't allocate a full sockaddr_storage for tracing
+-    - MIPS: mm: Fix definition of R6 cache instruction
+-    - MIPS: Don't register r4k sched clock when CPUFREQ enabled
+-    - MIPS: hpet: Increase HPET_MIN_PROG_DELTA and decrease HPET_MIN_CYCLES
+-    - PCI: Mark Atheros AR9485 and QCA9882 to avoid bus reset
+-    - x86/platform/intel_mid_pci: Rework IRQ0 workaround
+-    - ACPI / EC: Work around method reentrancy limit in ACPICA for _Qxx
+-    - rtc: s3c: Add s3c_rtc_{enable/disable}_clk in s3c_rtc_setfreq()
+-    - dm flakey: error READ bios during the down_interval
+-    - module: Invalidate signatures on force-loaded modules
+-    - Documentation/module-signing.txt: Note need for version info if reusing a
+-      key
+-    - Linux 4.4.19
+-
+-  * xfrm: ipsec crash when updating spd thresholds (LP: #1613787)
+-    - xfrm: Ignore socket policies when rebuilding hash tables
+-
+-  * ISST-LTE:pKVM311:lotg5:Ubutu16041:lotg5 crashed @
+-    writeback_sb_inodes+0x30c/0x590 (LP: #1614565)
+-    - writeback: Write dirty times for WB_SYNC_ALL writeback
+-
+-  * IBM Power 720 Ethernet Not Seen (LP: #1612725)
+-    - [Config] CONFIG_IBMEBUS=y for powerpc
+-
+-  * CAPI: Update default setting for the psl_fir_cntl register (LP: #1612431)
+-    - cxl: Set psl_fir_cntl to production environment value
+-
+-  * Xenial update to v4.4.18 stable release (LP: #1614560)
+-    - tcp: enable per-socket rate limiting of all 'challenge acks'
+-    - ipv4: reject RTNH_F_DEAD and RTNH_F_LINKDOWN from user space
+-    - bonding: set carrier off for devices created through netlink
+-    - net: bgmac: Fix infinite loop in bgmac_dma_tx_add()
+-    - net/irda: fix NULL pointer dereference on memory allocation failure
+-    - qed: Fix setting/clearing bit in completion bitmap
+-    - tcp: consider recv buf for the initial window scale
+-    - ipath: Restrict use of the write() interface
+-    - scsi: ignore errors from scsi_dh_add_device()
+-    - HID: sony: do not bail out when the sixaxis refuses the output report
+-    - i2c: i801: Allow ACPI SystemIO OpRegion to conflict with PCI BAR
+-    - arm: oabi compat: add missing access checks
+-    - KEYS: 64-bit MIPS needs to use compat_sys_keyctl for 32-bit userspace
+-    - Revert "s390/kdump: Clear subchannel ID to signal non-CCW/SCSI IPL"
+-    - random: strengthen input validation for RNDADDTOENTCNT
+-    - devpts: clean up interface to pty drivers
+-    - x86/mm/pat: Add support of non-default PAT MSR setting
+-    - x86/mm/pat: Add pat_disable() interface
+-    - x86/mm/pat: Replace cpu_has_pat with boot_cpu_has()
+-    - x86/mtrr: Fix Xorg crashes in Qemu sessions
+-    - x86/mtrr: Fix PAT init handling when MTRR is disabled
+-    - x86/xen, pat: Remove PAT table init code from Xen
+-    - x86/pat: Document the PAT initialization sequence
+-    - x86/mm/pat: Fix BUG_ON() in mmap_mem() on QEMU/i386
+-    - drm/i915: Pretend cursor is always on for ILK-style WM calculations (v2)
+-    - x86/syscalls/64: Add compat_sys_keyctl for 32-bit userspace
+-    - block: fix use-after-free in seq file
+-    - sysv, ipc: fix security-layer leaking
+-    - fuse: fsync() did not return IO errors
+-    - fuse: fuse_flush must check mapping->flags for errors
+-    - fuse: fix wrong assignment of ->flags in fuse_send_init()
+-    - fs/dcache.c: avoid soft-lockup in dput()
+-    - crypto: gcm - Filter out async ghash if necessary
+-    - crypto: scatterwalk - Fix test in scatterwalk_done
+-    - ext4: check for extents that wrap around
+-    - ext4: fix deadlock during page writeback
+-    - ext4: don't call ext4_should_journal_data() on the journal inode
+-    - ext4: validate s_reserved_gdt_blocks on mount
+-    - ext4: short-cut orphan cleanup on error
+-    - ext4: fix reference counting bug on block allocation error
+-    - mm: memcontrol: fix cgroup creation failure after many small jobs
+-    - mm: memcontrol: fix swap counter leak on swapout from offline cgroup
+-    - mm: memcontrol: fix memcg id ref counter on swap charge move
+-    - Linux 4.4.18
+-
+-  * Ubuntu16.10:installation fails on Brazos system (31TB and 192 cores) No
+-    memory for flatten_device_tree (no room) (LP: #1614309)
+-    - SAUCE: powerpc/pseries: Increase RMA size to 512MB.
+-
+-  * [SRU] xgene_enet: 10g performance only hits ~75% on multi-client tests
+-    (LP: #1613157)
+-    - drivers: net: xgene: Add support for Classifier engine
+-    - drivers: net: xgene: Add support for RSS
+-    - drivers: net: xgene: Add support for multiple queues
+-
+-  * [SRU] xgene_enet: an extra interrupt may be pending for an interrupt
+-    controller that doesn't support irq_disable and hardware with level
+-    interrupt (LP: #1611399)
+-    - drivers: net: xgene: fix extra IRQ issue
+-
+-  * Mic mute hotkey does not work on usb keyboard [03f0:2f4a] (LP: #1609606)
+-    - HID: input: add mic mute key on HP slim keyboard
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Fri, 12 Aug 2016 09:05:59 +0200
+-
+-linux (4.4.0-36.55) xenial; urgency=low
+-
+-  [ Stefan Bader ]
+-
+-  * Release Tracking Bug
+-    - LP: #1612305
+-
+-  * I2C touchpad does not work on AMD platform (LP: #1612006)
+-    - SAUCE: pinctrl/amd: Remove the default de-bounce time
+-
+-  * CVE-2016-5696
+-    - tcp: make challenge acks less predictable
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Thu, 11 Aug 2016 17:34:14 +0200
+-
+-linux (4.4.0-35.54) xenial; urgency=low
+-
+-  [ Stefan Bader ]
+-
+-  * Release Tracking Bug
+-    - LP: #1611215
+-
+-  * [i915_bpo] Sync with v4.7 (LP: #1609742)
+-    - SAUCE: i915_bpo: Sync with v4.7
+-
+-  * s390/cio: fix reset of channel measurement block (LP: #1609415)
+-    - s390/cio: allow to reset channel measurement block
+-
+-  * in Ubuntu16.10: Hit on Call traces  and system goes down when transactional
+-    memory  tests are running in 32TB Brazos system (LP: #1606786)
+-    - powerpc/tm: Avoid SLB faults in treclaim/trecheckpoint when RI=0
+-    - powerpc/tm: Fix stack pointer corruption in __tm_recheckpoint()
+-
+-  *  Power Menu does not display after press the Power Button (LP: #1609204)
+-    - intel-vbtn: new driver for Intel Virtual Button
+-    - [config] enable CONFIG_INTEL_VBTN=m
+-
+-  * OptiPlex 7450 AIO hangs when rebooting (LP: #1608762)
+-    - x86/reboot: Add Dell Optiplex 7450 AIO reboot quirk
+-
+-  * virtualbox+usb 3.0 breaks boot, -28 kernel works (LP: #1604058)
+-    - SAUCE: xhci: Fix soft lockup in xhci_pci_probe path when XHCI_STATE_HALTED
+-
+-  * linux-kernel: Freeing IRQ from IRQ context (LP: #1597908)
+-    - block: defer timeouts to a workqueue
+-
+-  * Tunnel offload indications not stripped from encapsulated packets, causing
+-    performance overhead (LP: #1602755)
+-    - tunnels: Remove encapsulation offloads on decap.
+-
+-  * lm-sensors is throwing "ERROR: Can't get value of subfeature temp1_input:
+-    I/O error" for be2net driver (LP: #1607387)
+-    - be2net: perform temperature query in adapter regardless of its interface
+-      state
+-
+-  * Dell dock MAC Address pass through doesn't work in Ubuntu (LP: #1579984)
+-    - r8152: Add support for setting pass through MAC address on RTL8153-AD
+-
+-  * vmxnet3 LRO IPv6 performance issues (stalling TCP) (LP: #1605494)
+-    - Driver: Vmxnet3: set CHECKSUM_UNNECESSARY for IPv6 packets
+-
+-  * ISST-LTE:pVM:monklp5:Ubuntu16.04.1:system crashed at
+-    lpfc_sli4_scmd_to_wqidx_distr (LP: #1597974)
+-    - SAUCE: lpfc: fix oops in lpfc_sli4_scmd_to_wqidx_distr() from
+-      lpfc_send_taskmgmt()
+-
+-  * Backport cxlflash shutdown patch to Xenial SRU (LP: #1605405)
+-    - SAUCE: cxlflash: Verify problem state area is mapped before notifying
+-      shutdown
+-
+-  * Xenial update to v4.4.16 stable release (LP: #1607404)
+-    - mac80211: fix fast_tx header alignment
+-    - mac80211: mesh: flush mesh paths unconditionally
+-    - mac80211_hwsim: Add missing check for HWSIM_ATTR_SIGNAL
+-    - mac80211: Fix mesh estab_plinks counting in STA removal case
+-    - EDAC, sb_edac: Fix rank lookup on Broadwell
+-    - IB/cm: Fix a recently introduced locking bug
+-    - IB/mlx4: Properly initialize GRH TClass and FlowLabel in AHs
+-    - powerpc/pseries: Fix IBM_ARCH_VEC_NRCORES_OFFSET since POWER8NVL was added
+-    - powerpc/tm: Always reclaim in start_thread() for exec() class syscalls
+-    - usb: dwc2: fix regression on big-endian PowerPC/ARM systems
+-    - USB: EHCI: declare hostpc register as zero-length array
+-    - usb: common: otg-fsm: add license to usb-otg-fsm
+-    - mnt: fs_fully_visible test the proper mount for MNT_LOCKED
+-    - mnt: Account for MS_RDONLY in fs_fully_visible
+-    - mnt: If fs_fully_visible fails call put_filesystem.
+-    - of: fix autoloading due to broken modalias with no 'compatible'
+-    - of: irq: fix of_irq_get[_byname]() kernel-doc
+-    - locking/ww_mutex: Report recursive ww_mutex locking early
+-    - locking/qspinlock: Fix spin_unlock_wait() some more
+-    - locking/static_key: Fix concurrent static_key_slow_inc()
+-    - x86, build: copy ldlinux.c32 to image.iso
+-    - kprobes/x86: Clear TF bit in fault on single-stepping
+-    - x86/amd_nb: Fix boot crash on non-AMD systems
+-    - Revert "gpiolib: Split GPIO flags parsing and GPIO configuration"
+-    - uvc: Forward compat ioctls to their handlers directly
+-    - thermal: cpu_cooling: fix improper order during initialization
+-    - writeback: use higher precision calculation in domain_dirty_limits()
+-    - nfsd4/rpc: move backchannel create logic into rpc code
+-    - nfsd: Always lock state exclusively.
+-    - nfsd: Extend the mutex holding region around in nfsd4_process_open2()
+-    - posix_acl: Add set_posix_acl
+-    - nfsd: check permissions when setting ACLs
+-    - make nfs_atomic_open() call d_drop() on all ->open_context() errors.
+-    - NFS: Fix another OPEN_DOWNGRADE bug
+-    - ARM: imx6ul: Fix Micrel PHY mask
+-    - ARM: 8578/1: mm: ensure pmd_present only checks the valid bit
+-    - ARM: 8579/1: mm: Fix definition of pmd_mknotpresent
+-    - MIPS: KVM: Fix modular KVM under QEMU
+-    - mm: Export migrate_page_move_mapping and migrate_page_copy
+-    - UBIFS: Implement ->migratepage()
+-    - sched/fair: Fix cfs_rq avg tracking underflow
+-    - packet: Use symmetric hash for PACKET_FANOUT_HASH.
+-    - net_sched: fix mirrored packets checksum
+-    - cdc_ncm: workaround for EM7455 "silent" data interface
+-    - ipv6: Fix mem leak in rt6i_pcpu
+-    - ARCv2: Check for LL-SC livelock only if LLSC is enabled
+-    - ARCv2: LLSC: software backoff is NOT needed starting HS2.1c
+-    - kvm: Fix irq route entries exceeding KVM_MAX_IRQ_ROUTES
+-    - KVM: nVMX: VMX instructions: fix segment checks when L1 is in long mode.
+-    - HID: elo: kill not flush the work
+-    - HID: hiddev: validate num_values for HIDIOCGUSAGES, HIDIOCSUSAGES commands
+-    - tracing: Handle NULL formats in hold_module_trace_bprintk_format()
+-    - base: make module_create_drivers_dir race-free
+-    - iommu/arm-smmu: Wire up map_sg for arm-smmu-v3
+-    - iommu/vt-d: Enable QI on all IOMMUs before setting root entry
+-    - iommu/amd: Fix unity mapping initialization race
+-    - drm/mgag200: Black screen fix for G200e rev 4
+-    - ipmi: Remove smi_msg from waiting_rcv_msgs list before handle_one_recv_msg()
+-    - arm64: Rework valid_user_regs
+-    - vfs: add d_real_inode() helper
+-    - af_unix: fix hard linked sockets on overlay
+-    - btrfs: account for non-CoW'd blocks in btrfs_abort_transaction
+-    - drm/radeon: fix asic initialization for virtualized environments
+-    - drm/amdgpu/gfx7: fix broken condition check
+-    - ubi: Make recover_peb power cut aware
+-    - drm/amdkfd: unbind only existing processes
+-    - drm/amdkfd: destroy dbgmgr in notifier release
+-    - drm/dp/mst: Always clear proposed vcpi table for port.
+-    - drm/nouveau/disp/sor/gf119: both links use the same training register
+-    - drm/nouveau/gr/gf100-: update sm error decoding from gk20a nvgpu headers
+-    - drm/nouveau/fbcon: fix out-of-bounds memory accesses
+-    - drm/nouveau: fix for disabled fbdev emulation
+-    - drm/nouveau/disp/sor/gf119: select correct sor when poking training pattern
+-    - drm/i915/ilk: Don't disable SSC source if it's in use
+-    - drm/i915: Refresh cached DP port register value on resume
+-    - drm/i915: Update ifdeffery for mutex->owner
+-    - drm/i915: Update CDCLK_FREQ register on BDW after changing cdclk frequency
+-    - drm: add missing drm_mode_set_crtcinfo call
+-    - drm: make drm_atomic_set_mode_prop_for_crtc() more reliable
+-    - drm: atmel-hlcdc: actually disable scaling when no scaling is required
+-    - drm/ttm: Make ttm_bo_mem_compat available
+-    - drm/vmwgfx: Add an option to change assumed FB bpp
+-    - drm/vmwgfx: Work around mode set failure in 2D VMs
+-    - drm/vmwgfx: Check pin count before attempting to move a buffer
+-    - drm/vmwgfx: Delay pinning fbdev framebuffer until after mode set
+-    - drm/vmwgfx: Fix error paths when mapping framebuffer
+-    - memory: omap-gpmc: Fix omap gpmc EXTRADELAY timing
+-    - perf/x86: Fix undefined shift on 32-bit kernels
+-    - xen/balloon: Fix declared-but-not-defined warning
+-    - iio: Fix error handling in iio_trigger_attach_poll_func
+-    - iio:st_pressure: fix sampling gains (bring inline with ABI)
+-    - iio: light apds9960: Add the missing dev.parent
+-    - iio: proximity: as3935: correct IIO_CHAN_INFO_RAW output
+-    - iio: proximity: as3935: remove triggered buffer processing
+-    - iio: proximity: as3935: fix buffer stack trashing
+-    - iio: humidity: hdc100x: correct humidity integration time mask
+-    - iio: humidity: hdc100x: fix IIO_TEMP channel reporting
+-    - iio: hudmidity: hdc100x: fix incorrect shifting and scaling
+-    - staging: iio: accel: fix error check
+-    - iio: accel: kxsd9: fix the usage of spi_w8r8()
+-    - iio:ad7266: Fix broken regulator error handling
+-    - iio:ad7266: Fix support for optional regulators
+-    - iio:ad7266: Fix probe deferral for vref
+-    - tty/vt/keyboard: fix OOB access in do_compute_shiftstate()
+-    - hwmon: (dell-smm) Restrict fan control and serial number to CAP_SYS_ADMIN by
+-      default
+-    - hwmon: (dell-smm) Disallow fan_type() calls on broken machines
+-    - hwmon: (dell-smm) Cache fan_type() calls and change fan detection
+-    - ALSA: dummy: Fix a use-after-free at closing
+-    - ALSA: hda - Fix the headset mic jack detection on Dell machine
+-    - ALSA: hda / realtek - add two more Thinkpad IDs (5050,5053) for tpt460 fixup
+-    - ALSA: au88x0: Fix calculation in vortex_wtdma_bufshift()
+-    - ALSA: echoaudio: Fix memory allocation
+-    - ALSA: timer: Fix negative queue usage by racy accesses
+-    - ALSA: hda/realtek: Add Lenovo L460 to docking unit fixup
+-    - ALSA: hda - Add PCI ID for Kabylake-H
+-    - ALSA: hda - fix read before array start
+-    - ALSA: hda/realtek - add new pin definition in alc225 pin quirk table
+-    - ALSA: pcm: Free chmap at PCM free callback, too
+-    - ALSA: ctl: Stop notification after disconnection
+-    - ALSA: hda - fix use-after-free after module unload
+-    - ALSA: hda: add AMD Stoney PCI ID with proper driver caps
+-    - ARM: sunxi/dt: make the CHIP inherit from allwinner,sun5i-a13
+-    - ARM: dts: armada-38x: fix MBUS_ID for crypto SRAM on Armada 385 Linksys
+-    - ARM: mvebu: fix HW I/O coherency related deadlocks
+-    - ovl: Copy up underlying inode's ->i_mode to overlay inode
+-    - ovl: verify upper dentry in ovl_remove_and_whiteout()
+-    - scsi: fix race between simultaneous decrements of ->host_failed
+-    - 53c700: fix BUG on untagged commands
+-    - Fix reconnect to not defer smb3 session reconnect long after socket
+-      reconnect
+-    - cifs: dynamic allocation of ntlmssp blob
+-    - File names with trailing period or space need special case conversion
+-    - xen/acpi: allow xen-acpi-processor driver to load on Xen 4.7
+-    - crypto: qat - make qat_asym_algs.o depend on asn1 headers
+-    - tmpfs: don't undo fallocate past its last page
+-    - tmpfs: fix regression hang in fallocate undo
+-    - drm/i915: Revert DisplayPort fast link training feature
+-    - ovl: verify upper dentry before unlink and rename
+-    - Linux 4.4.16
+-
+-  * Regression caused by `fuse: Add support for pid namespaces` in 4.4.0-6.21
+-    (LP: #1605344)
+-    - SAUCE: (namespace) fuse: Permit requests from other pid namespaces
+-
+-  * CVE-2016-5400
+-    - media: fix airspy usb probe error path
+-
+-  * Cannot mount proc in unprivileged containers if /proc/xen is mounted
+-    (LP: #1607374)
+-    - SAUCE: xenbus: Use proc_create_mount_point() to create /proc/xen
+-
+-  * Mic mute key does not work for Ideapad laptops (LP: #1607153)
+-    - ideapad_laptop: Add an event for mic mute hotkey
+-
+-  * NVMe stress test fails after 12 hours on Ubuntu 16.04 (LP: #1604995)
+-    - block: atari: Return early for unsupported sector size
+-
+-  * Console extremely slow with 4.4 kernels for servers with Matrox G200er2 or
+-    similar (LP: #1605662)
+-    - SAUCE: vesafb: Set mtrr:3 (write-combining) as default
+-
+-  * Ubuntu 16.04 - Full EEH Recovery Support for NVMe devices (LP: #1602724)
+-    - nvme: use a work item to submit async event requests
+-    - nvme: don't poll the CQ from the kthread
+-    - nvme: replace the kthread with a per-device watchdog timer
+-    - NVMe: Fix reset/remove race
+-    - nvme: Avoid reset work on watchdog timer function during error recovery
+-    - NVMe: Always use MSI/MSI-x interrupts
+-
+-  * [LTC-Test] - NMI watchdog Bug and call traces when trinity is executed.
+-    (LP: #1602524)
+-    - ext4: factor out determining of hole size
+-    - ext4: return hole from ext4_map_blocks()
+-    - ext4: more efficient SEEK_DATA implementation
+-
+-  * changelog: add CVEs as first class citizens (LP: #1604344)
+-    - avoid duplicate CVE numbers in changelog
+-
+-  * [LTCTest][Opal][OP820] Machine crashed with Oops: Kernel access of bad area,
+-    sig: 11 [#1] while executing Froze PE Error injection (LP: #1603449)
+-    - powerpc/eeh: Fix invalid cached PE primary bus
+-
+-  * Hotplug remove and re-add adds PCI adapter to next PCI domain (PCI)
+-    (LP: #1603574)
+-    - powerpc/pci: Assign fixed PHB number based on device-tree properties
+-
+-  * nvme - reset_controller is not working after adapter's firmware upgrade
+-    (adapter quirk is needed) (LP: #1602726)
+-    - NVMe: Create discard zero quirk white list
+-    - nvme/quirk: Add a delay before checking for adapter readiness
+-
+-  * ovs nat: conntrack netlink event are missing (LP: #1603468)
+-    - openvswitch: fix conntrack netlink event delivery
+-
+-  * FlashGT - In Tuleta 8284-22A with card in card slot P1-C9, system Fails to
+-    boot operating system (LP: #1602785)
+-    - cxl: Ignore CAPI adapters misplaced in switched slots
+-
+-  * CVE-2016-5728
+-    - misc: mic: Fix for double fetch security bug in VOP driver
+-
+-  * CVE-2016-5244 (LP: #1589041)
+-    - rds: fix an infoleak in rds_inc_info_copy
+-
+-  * Miscellaneous Ubuntu changes
+-    - Added Snapcraft files
+-    - SAUCE: snapcraft: cleanup and remove unnecessary elements
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Tue, 09 Aug 2016 15:11:33 +0200
+-
+-linux (4.4.0-34.53) xenial; urgency=low
+-
+-  [ Seth Forshee ]
+-
+-  * Release Tracking Bug
+-    - LP: #1606960
+-
+-  * [APL][SAUCE] Slow system response time due to a monitor bug (LP: #1606147)
+-    - x86/cpu/intel: Introduce macros for Intel family numbers
+-    - SAUCE: x86/cpu: Add workaround for MONITOR instruction erratum on Goldmont
+-      based CPUs
+-
+- -- Seth Forshee <seth.forshee@canonical.com>  Wed, 27 Jul 2016 10:01:20 -0500
+-
+-linux (4.4.0-33.52) xenial; urgency=low
+-
+-  [ Seth Forshee ]
+-
+-  * Release Tracking Bug
+-    - LP: #1605709
+-
+-  * [regression] NFS client: access problems after updating to kernel
+-    4.4.0-31-generic (LP: #1603719)
+-    - SAUCE: (namespace) Bypass sget() capability check for nfs
+-
+- -- Seth Forshee <seth.forshee@canonical.com>  Fri, 22 Jul 2016 13:10:08 -0500
+-
+-linux (4.4.0-32.51) xenial; urgency=low
+-
+-  [ Seth Forshee ]
+-
+-  * Release Tracking Bug
+-    - LP: #1604443
+-
+-  * thinkpad yoga 260 wacom touchscreen not working (LP: #1603975)
+-    - HID: wacom: break out parsing of device and registering of input
+-    - HID: wacom: Initialize hid_data.inputmode to -1
+-    - HID: wacom: Support switching from vendor-defined device mode on G9 and G11
+-
+-  * changelog: add CVEs as first class citizens (LP: #1604344)
+-    - use CVE numbers in changelog
+-
+-  * [Xenial] Include Huawei PCIe SSD hio kernel driver (LP: #1603483)
+-    - SAUCE: import Huawei ES3000_V2 (2.1.0.23)
+-    - SAUCE: hio: bio_endio() no longer takes errors arg
+-    - SAUCE: hio: blk_queue make_request_fn now returns a blk_qc_t
+-    - SAUCE: hio: use alloc_cpumask_var to avoid -Wframe-larger-than
+-    - SAUCE: hio: fix mask maybe-uninitialized warning
+-    - [config] enable CONFIG_HIO (Huawei ES3000_V2 PCIe SSD driver)
+-    - SAUCE: hio: Makefile and Kconfig
+-
+-  * CVE-2016-5243 (LP: #1589036)
+-    - tipc: fix an infoleak in tipc_nl_compat_link_dump
+-    - tipc: fix nl compat regression for link statistics
+-
+-  * CVE-2016-4470
+-    - KEYS: potential uninitialized variable
+-
+-  * integer overflow in xt_alloc_table_info (LP: #1555353)
+-    - netfilter: x_tables: check for size overflow
+-
+-  * CVE-2016-3135:
+-    - Revert "UBUNTU: SAUCE: (noup) netfilter: x_tables: check for size overflow"
+-
+-  * CVE-2016-4440 (LP: #1584192)
+-    - kvm:vmx: more complete state update on APICv on/off
+-
+-  * the system hangs in the dma driver when reboot or shutdown on a baytrail-m
+-    laptop (LP: #1602579)
+-    - dmaengine: dw: platform: power on device on shutdown
+-    - ACPI / LPSS: override power state for LPSS DMA device
+-
+-  * Add proper  palm detection support for MS Precision Touchpad (LP: #1593124)
+-    - Revert "HID: multitouch: enable palm rejection if device implements
+-      confidence usage"
+-    - HID: multitouch: enable palm rejection for Windows Precision Touchpad
+-
+-  * Add support for Intel 8265 Bluetooth ([8087:0A2B]) (LP: #1599068)
+-    - Bluetooth: Add support for Intel Bluetooth device 8265 [8087:0a2b]
+-
+-  * CVE-2016-4794 (LP: #1581871)
+-    - percpu: fix synchronization between chunk->map_extend_work and chunk
+-      destruction
+-    - percpu: fix synchronization between synchronous map extension and chunk
+-      destruction
+-
+-  * Xenial update to v4.4.15 stable release (LP: #1601952)
+-    - net_sched: fix pfifo_head_drop behavior vs backlog
+-    - net: Don't forget pr_fmt on net_dbg_ratelimited for CONFIG_DYNAMIC_DEBUG
+-    - sit: correct IP protocol used in ipip6_err
+-    - esp: Fix ESN generation under UDP encapsulation
+-    - netem: fix a use after free
+-    - ipmr/ip6mr: Initialize the last assert time of mfc entries.
+-    - Bridge: Fix ipv6 mc snooping if bridge has no ipv6 address
+-    - sock_diag: do not broadcast raw socket destruction
+-    - bpf, perf: delay release of BPF prog after grace period
+-    - neigh: Explicitly declare RCU-bh read side critical section in neigh_xmit()
+-    - net: macb: fix default configuration for GMAC on AT91
+-    - net: alx: Work around the DMA RX overflow issue
+-    - bpf: try harder on clones when writing into skb
+-    - AX.25: Close socket connection on session completion
+-    - crypto: ux500 - memmove the right size
+-    - crypto: user - re-add size check for CRYPTO_MSG_GETALG
+-    - USB: uas: Fix slave queue_depth not being set
+-    - usb: quirks: Fix sorting
+-    - usb: quirks: Add no-lpm quirk for Acer C120 LED Projector
+-    - usb: musb: only restore devctl when session was set in backup
+-    - usb: musb: Stop bulk endpoint while queue is rotated
+-    - usb: musb: Ensure rx reinit occurs for shared_fifo endpoints
+-    - usb: musb: host: correct cppi dma channel for isoch transfer
+-    - usb: xhci-plat: properly handle probe deferral for devm_clk_get()
+-    - USB: xhci: Add broken streams quirk for Frescologic device id 1009
+-    - xhci: Fix handling timeouted commands on hosts in weird states.
+-    - USB: mos7720: delete parport
+-    - usb: gadget: fix spinlock dead lock in gadgetfs
+-    - usb: host: ehci-tegra: Grab the correct UTMI pads reset
+-    - usb: dwc3: exynos: Fix deferred probing storm.
+-    - Linux 4.4.15
+-
+-  * qeth: delete napi struct when removing a qeth device (LP: #1601831)
+-    - qeth: delete napi struct when removing a qeth device
+-
+-  * Adjust KBL PCI-ID's (LP: #1600124)
+-    - drm/i915: Add more Kabylake PCI IDs.
+-    - drm/i915: Removing PCI IDs that are no longer listed as Kabylake.
+-
+-  * [i915_bpo] Rebase driver to v4.7-rc6 + gen9 workarounds + KBP PCH support
+-    (LP: #1599109)
+-    - drm/kms_helper: Add a common place to call init and exit functions.
+-    - drm: Add helper for DP++ adaptors
+-    - GPU-DRM: Delete unnecessary checks before drm_property_unreference_blob()
+-    - drm: introduce pipe color correction properties
+-    - drm: fix blob pointer check
+-    - drm: atomic helper: do not unreference error pointer
+-    - drm: fix lut value extraction function
+-    - drm/dsi: Add a helper to get bits per pixel of MIPI DSI pixel format
+-    - SAUCE: drm: Introduce drm_malloc_gfp()
+-    - SAUCE: i915_bpo: Rebase to v4.7-rc6
+-    - SAUCE: i915_bpo: Add backported workarounds for gen9
+-    - SAUCE: i915_bpo: Revert "drm/i915: Get panel_type from OpRegion panel
+-      details"
+-    - SAUCE: i915_bpo: Introduce Kabypoint PCH for Kabylake H/DT.
+-
+-  * Baytrail-I got black screen with HDMI output (LP: #1599379)
+-    - drm/i915: Only ignore eDP ports that are connected
+-    - drm/i915: Check VBT for port presence in addition to the strap on VLV/CHV
+-
+-  * [Hyper-V] storvsc messages for CD-ROM medium not present tray closed
+-    (LP: #1590655)
+-    - SAUCE: (no-up) scsi: storvsc: Filter out storvsc messages CD-ROM medium not
+-      present
+-
+-  * Hotplug device addition issue - missing patches on Xenial kernel
+-    (LP: #1599250)
+-    - Revert "UBUNTU: SAUCE: powerpc/eeh: Validate arch in eeh_add_device_early()"
+-    - Revert "powerpc/eeh: Fix crash in eeh_add_device_early() on Cell"
+-    - powerpc/iommu: Remove the dependency on EEH struct in DDW mechanism
+-    - powerpc/pseries: Fix PCI config address for DDW
+-
+-  * kernel: signal return with invalid floating-point control (LP: #1597971)
+-    - s390: fix test_fp_ctl inline assembly contraints
+-
+-  * [Toshiba P50W-B00F] Touchscreen no longer working (LP: #1498667)
+-    - SAUCE: (no-up) usb: quirks: Add no-lpm quirk for Elan Microelectronics
+-      Touchpad
+-
+-  * [yakkety] d-i does not support (ehci_msm) Qualcomm  On-Chip EHCI Host
+-    Controller (LP: #1599347)
+-    - d-i: Add ehci_msm to usb-modules
+-
+-  * [Bug] Legacy audio couldn't work after S3 resume on Kabylake (LP: #1596871)
+-    - ALSA: hda - Skip ELD notification during PM process
+-    - ALSA: hda - hdmi add wmb barrier for audio component
+-    - ALSA: hda - hdmi defer to register acomp eld notifier
+-
+-  * sync spl  0.6.5.6-0ubuntu4 changes into Xenial kernel source (LP: #1599257)
+-    - SAUCE: (noup) Update spl to 0.6.5.6-0ubuntu4
+-
+-  * Config: missing AMD Seattle platform support (LP: #1597574)
+-    - [Config] Enable the AMD Seattle platform
+-
+-  * Network installer fails to detect network on AMD Overdrive (ARM64)
+-    (LP: #1597573)
+-    - [Config] Add amd-xgbe to nic-modules udeb
+-
+-  * exercising ptys causes a kernel oops (LP: #1586418)
+-    - devpts: fix null pointer dereference on failed memory allocation
+-
+-  * Regression (constant vibration of device) in xpad driver in Ubuntu 16.04
+-    (LP: #1574102)
+-    - Input: xpad - move pending clear to the correct location
+-
+-  * thunderx nics fail to establish link (LP: #1597867)
+-    - net: thunderx: Fix link status reporting
+-
+-  * Xenial update to v4.4.14 stable release (LP: #1596575)
+-    - scsi_lib: correctly retry failed zero length REQ_TYPE_FS commands
+-    - scsi: Add QEMU CD-ROM to VPD Inquiry Blacklist
+-    - netlink: Fix dump skb leak/double free
+-    - tipc: fix nametable publication field in nl compat
+-    - switchdev: pass pointer to fib_info instead of copy
+-    - tuntap: correctly wake up process during uninit
+-    - udp: prevent skbs lingering in tunnel socket queues
+-    - uapi glibc compat: fix compilation when !__USE_MISC in glibc
+-    - sfc: on MC reset, clear PIO buffer linkage in TXQs
+-    - team: don't call netdev_change_features under team->lock
+-    - vxlan: Accept user specified MTU value when create new vxlan link
+-    - tcp: record TLP and ER timer stats in v6 stats
+-    - bridge: Don't insert unnecessary local fdb entry on changing mac address
+-    - l2tp: fix configuration passed to setup_udp_tunnel_sock()
+-    - ipv6: Skip XFRM lookup if dst_entry in socket cache is valid
+-    - vxlan: Relax MTU constraints
+-    - geneve: Relax MTU constraints
+-    - vxlan, gre, geneve: Set a large MTU on ovs-created tunnel devices
+-    - KVM: x86: fix OOPS after invalid KVM_SET_DEBUGREGS
+-    - KVM: irqfd: fix NULL pointer dereference in kvm_irq_map_gsi
+-    - ALSA: hda - Add PCI ID for Kabylake
+-    - ALSA: hda - Fix headset mic detection problem for Dell machine
+-    - ALSA: hda/realtek - ALC256 speaker noise issue
+-    - ALSA: hda/realtek - Add support for new codecs ALC700/ALC701/ALC703
+-    - ALSA: hda/realtek: Add T560 docking unit fixup
+-    - ARM: fix PTRACE_SETVFPREGS on SMP systems
+-    - gpio: bcm-kona: fix bcm_kona_gpio_reset() warnings
+-    - s390/bpf: fix recache skb->data/hlen for skb_vlan_push/pop
+-    - s390/bpf: reduce maximum program size to 64 KB
+-    - irqchip/gic-v3: Fix ICC_SGI1R_EL1.INTID decoding mask
+-    - crypto: public_key: select CRYPTO_AKCIPHER
+-    - crypto: ccp - Fix AES XTS error for request sizes above 4096
+-    - arm64: Provide "model name" in /proc/cpuinfo for PER_LINUX32 tasks
+-    - arm64: mm: always take dirty state from new pte in ptep_set_access_flags
+-    - powerpc/pseries/eeh: Handle RTAS delay requests in configure_bridge
+-    - powerpc: Fix definition of SIAR and SDAR registers
+-    - powerpc: Use privileged SPR number for MMCR2
+-    - powerpc/pseries: Add POWER8NVL support to ibm,client-architecture-support
+-      call
+-    - pinctrl: mediatek: fix dual-edge code defect
+-    - parisc: Fix pagefault crash in unaligned __get_user() call
+-    - memcg: add RCU locking around css_for_each_descendant_pre() in
+-      memcg_offline_kmem()
+-    - wext: Fix 32 bit iwpriv compatibility issue with 64 bit Kernel
+-    - x86/entry/traps: Don't force in_interrupt() to return true in IST handlers
+-    - fix d_walk()/non-delayed __d_free() race
+-    - sparc: Fix system call tracing register handling.
+-    - sparc64: Fix bootup regressions on some Kconfig combinations.
+-    - sparc64: Fix numa node distance initialization
+-    - sparc64: Fix sparc64_set_context stack handling.
+-    - sparc/PCI: Fix for panic while enabling SR-IOV
+-    - sparc64: Reduce TLB flushes during hugepte changes
+-    - sparc64: Take ctx_alloc_lock properly in hugetlb_setup().
+-    - sparc: Harden signal return frame checks.
+-    - sparc64: Fix return from trap window fill crashes.
+-    - MIPS: Fix 64k page support for 32 bit kernels.
+-    - crypto: qat - fix adf_ctl_drv.c:undefined reference to adf_init_pf_wq
+-    - drm/core: Do not preserve framebuffer on rmfb, v4.
+-    - Linux 4.4.14
+-
+-  * [Hyper-V] Rebase Hyper-V to 4.6 kernel (LP: #1583357)
+-    - hv_netvsc: rework link status change handling
+-    - hv_netvsc: Resize some of the variables in hv_netvsc_packet
+-    - hv_netvsc: Rearrange the hv_negtvsc_packet to be space efficient
+-    - hv_netvsc: Eliminate the channel field in hv_netvsc_packet structure
+-    - hv_netvsc: Eliminate rndis_msg pointer from hv_netvsc_packet structure
+-    - hv_netvsc: Eliminatte the data field from struct hv_netvsc_packet
+-    - hv_netvsc: Eliminate send_completion from struct hv_netvsc_packet
+-    - hv_netvsc: Eliminate send_completion_ctx from struct hv_netvsc_packet
+-    - hv_netvsc: Don't ask for additional head room in the skb
+-    - hv_netvsc: move subchannel existence check to netvsc_select_queue()
+-    - hv_netvsc: remove locking in netvsc_send()
+-    - hv_netvsc: Eliminate page_buf from struct hv_netvsc_packet
+-    - hv_netvsc: Eliminate send_completion_tid from struct hv_netvsc_packet
+-    - hv_netvsc: Eliminate is_data_pkt from struct hv_netvsc_packet
+-    - hv_netvsc: Eliminate completion_func from struct hv_netvsc_packet
+-    - hv_netvsc: Eliminate xmit_more from struct hv_netvsc_packet
+-    - hv_netvsc: Eliminate status from struct hv_netvsc_packet
+-    - hv_netvsc: Eliminate vlan_tci from struct hv_netvsc_packet
+-    - storvsc: add logging for error/warning messages
+-    - hv_netvsc: Fix race condition on Multi-Send Data field
+-    - kvm/x86: split ioapic-handled and EOI exit bitmaps
+-    - kvm/x86: per-vcpu apicv deactivation support
+-    - kvm/x86: Hyper-V synthetic interrupt controller
+-    - kvm/x86: Hyper-V kvm exit
+-    - kvm/x86: Rearrange func's declarations inside Hyper-V header
+-    - kvm/x86: Added Hyper-V vcpu_to_hv_vcpu()/hv_vcpu_to_vcpu() helpers
+-    - kvm/x86: Hyper-V internal helper to read MSR HV_X64_MSR_TIME_REF_COUNT
+-    - kvm/x86: Hyper-V SynIC message slot pending clearing at SINT ack
+-    - kvm/x86: Hyper-V SynIC timers
+-    - storvsc: Fix a bug in the layout of the hv_fc_wwn_packet
+-    - storvsc: Properly support Fibre Channel devices
+-    - storvsc: Refactor the code in storvsc_channel_init()
+-    - storvsc: Tighten up the interrupt path
+-    - storvsc: Fix typo in MODULE_PARM_DESC
+-    - Revert "hv_netvsc: use skb_get_hash() instead of a homegrown implementation"
+-    - hv_netvsc: use skb_get_hash() instead of a homegrown implementation
+-    - hv_netvsc: Fix book keeping of skb during batching process
+-    - storvsc: Install the storvsc specific timeout handler for FC devices
+-    - storvsc: Use the specified target ID in device lookup
+-    - Revert "Drivers: hv: vmbus: Cleanup vmbus_set_event()"
+-    - Drivers: hv: vmbus: Cleanup vmbus_set_event()
+-    - Revert "Drivers: hv: vmbus: Eliminate the spin lock on the read path"
+-    - Drivers: hv: vmbus: Eliminate the spin lock on the read path
+-    - Revert "hv_netvsc: cleanup netdev feature flags for netvsc"
+-    - hv_netvsc: cleanup netdev feature flags for netvsc
+-    - hv_netvsc: Restore needed_headroom request
+-    - kvm/x86: Rename Hyper-V long spin wait hypercall
+-    - hv_netvsc: add software transmit timestamp support
+-    - hv_netvsc: add ethtool support for set and get of settings
+-    - hv_netvsc: Fix accessing freed memory in netvsc_change_mtu()
+-    - hv_netvsc: Fix the array sizes to be max supported channels
+-    - hv_netvsc: Fix the order of num_sc_offered decrement
+-    - x86/hyperv: Avoid reporting bogus NMI status for Gen2 instances
+-    - Drivers: hv: vmbus: Fix signaling logic in hv_need_to_signal_on_read()
+-    - Drivers: hv: kvp: fix IP Failover
+-
+- -- Seth Forshee <seth.forshee@canonical.com>  Tue, 19 Jul 2016 11:18:32 -0500
+-
+-linux (4.4.0-31.50) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1602449
+-
+-  * nouveau: boot hangs at blank screen with unsupported graphics cards
+-    (LP: #1602340)
+-    - SAUCE: drm: check for supported chipset before booting fbdev off the hw
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Tue, 12 Jul 2016 16:28:12 -0700
+-
+-linux (4.4.0-30.49) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1597897
+-
+-  * FCP devices are not detected correctly nor deterministically (LP: #1567602)
+-    - scsi_dh_alua: Disable ALUA handling for non-disk devices
+-    - scsi_dh_alua: Use vpd_pg83 information
+-    - scsi_dh_alua: improved logging
+-    - scsi_dh_alua: sanitze sense code handling
+-    - scsi_dh_alua: use standard logging functions
+-    - scsi_dh_alua: return standard SCSI return codes in submit_rtpg
+-    - scsi_dh_alua: fixup description of stpg_endio()
+-    - scsi_dh_alua: use flag for RTPG extended header
+-    - scsi_dh_alua: use unaligned access macros
+-    - scsi_dh_alua: rework alua_check_tpgs() to return the tpgs mode
+-    - scsi_dh_alua: simplify sense code handling
+-    - scsi: Add scsi_vpd_lun_id()
+-    - scsi: Add scsi_vpd_tpg_id()
+-    - scsi_dh_alua: use scsi_vpd_tpg_id()
+-    - scsi_dh_alua: Remove stale variables
+-    - scsi_dh_alua: Pass buffer as function argument
+-    - scsi_dh_alua: separate out alua_stpg()
+-    - scsi_dh_alua: Make stpg synchronous
+-    - scsi_dh_alua: call alua_rtpg() if stpg fails
+-    - scsi_dh_alua: switch to scsi_execute_req_flags()
+-    - scsi_dh_alua: allocate RTPG buffer separately
+-    - scsi_dh_alua: Use separate alua_port_group structure
+-    - scsi_dh_alua: use unique device id
+-    - scsi_dh_alua: simplify alua_initialize()
+-    - revert commit a8e5a2d593cb ("[SCSI] scsi_dh_alua: ALUA handler attach should
+-      succeed while TPG is transitioning")
+-    - scsi_dh_alua: move optimize_stpg evaluation
+-    - scsi_dh_alua: remove 'rel_port' from alua_dh_data structure
+-    - scsi_dh_alua: Use workqueue for RTPG
+-    - scsi_dh_alua: Allow workqueue to run synchronously
+-    - scsi_dh_alua: Add new blacklist flag 'BLIST_SYNC_ALUA'
+-    - scsi_dh_alua: Recheck state on unit attention
+-    - scsi_dh_alua: update all port states
+-    - scsi_dh_alua: Send TEST UNIT READY to poll for transitioning
+-    - scsi_dh_alua: do not fail for unknown VPD identification
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Thu, 30 Jun 2016 12:52:15 -0700
+-
+-linux (4.4.0-29.48) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1597015
+-
+-  * Wireless hotkey fails on Dell XPS 15 9550 (LP: #1589886)
+-    - intel-hid: new hid event driver for hotkeys
+-    - intel-hid: fix incorrect entries in intel_hid_keymap
+-    - intel-hid: allocate correct amount of memory for private struct
+-    - intel-hid: add a workaround to ignore an event after waking up from S4.
+-    - [Config] CONFIG_INTEL_HID_EVENT=m
+-
+-  * cgroupfs mounts can hang (LP: #1588056)
+-    - Revert "UBUNTU: SAUCE: (namespace) mqueue: Super blocks must be owned by the
+-      user ns which owns the ipc ns"
+-    - Revert "UBUNTU: SAUCE: kernfs: Do not match superblock in another user
+-      namespace when mounting"
+-    - Revert "UBUNTU: SAUCE: cgroup: Use a new super block when mounting in a
+-      cgroup namespace"
+-    - (namespace) bpf: Use mount_nodev not mount_ns to mount the bpf filesystem
+-    - (namespace) bpf, inode: disallow userns mounts
+-    - (namespace) ipc: Initialize ipc_namespace->user_ns early.
+-    - (namespace) vfs: Pass data, ns, and ns->userns to mount_ns
+-    - SAUCE: (namespace) Sync with upstream s_user_ns patches
+-    - (namespace) kernfs: The cgroup filesystem also benefits from SB_I_NOEXEC
+-    - (namespace) ipc/mqueue: The mqueue filesystem should never contain
+-      executables
+-
+-  * KVM system crashes after starting guest (LP: #1596635)
+-    - xhci: Cleanup only when releasing primary hcd
+-
+-  * Upstream patch "crypto: vmx - IV size failing on skcipher API" for Ubuntu
+-    16.04 (LP: #1596557)
+-    - crypto: vmx - IV size failing on skcipher API
+-
+-  * [Bug]tpm initialization fails on x86 (LP: #1596469)
+-    - tpm_crb: drop struct resource res from struct crb_priv
+-    - tpm_crb: fix mapping of the buffers
+-
+-  * Device shutdown notification for CAPI Flash cards (LP: #1592114)
+-    - cxlflash: Fix regression issue with re-ordering patch
+-    - cxlflash: Fix to drain operations from previous reset
+-    - cxlflash: Add device dependent flags
+-    - cxlflash: Shutdown notify support for CXL Flash cards
+-
+-  * scsi-modules udeb should include pm80xx (LP: #1595628)
+-    - [Config] Add pm80xx scsi driver to d-i
+-
+-  * Sync up latest relevant upstream bug fixes (LP: #1594871)
+-    - SAUCE: (noup) Update zfs to 0.6.5.6-0ubuntu10
+-
+-  * Cannot compile module tda10071 (LP: #1592531)
+-    - [media] tda10071: Fix dependency to REGMAP_I2C
+-
+-  * lsvpd doesn't show correct location code for devices attached to a CAPI card
+-    (LP: #1594847)
+-    - cxl: Make vPHB device node match adapter's
+-
+-  * enable CRC32 and AES ARM64 by default or as module (LP: #1594455)
+-    - [Config] Enable arm64 AES and CRC32 crypto
+-
+-  * VMX kernel crypto module exhibits poor performance in Ubuntu 16.04
+-    (LP: #1592481)
+-    - crypto: vmx - comply with ABIs that specify vrsave as reserved.
+-    - crypto: vmx - Fix ABI detection
+-    - crypto: vmx - Increase priority of aes-cbc cipher
+-
+-  * build squashfs into xenial kernels by default (LP: #1593134)
+-    - [Config] CONFIG_SQUASHFS=y
+-
+-  * Restore irqfd fast path for PPC (LP: #1592809)
+-    - KVM: PPC: Book3S HV: Re-enable XICS fast path for irqfd-generated interrupts
+-
+-  * Unable to start guests with memballoon default. (LP: #1592042)
+-    - virtio_balloon: fix PFN format for virtio-1
+-
+-  * Key 5 automatically pressed on some Logitech wireless keyboards
+-    (LP: #1579190)
+-    - HID: core: prevent out-of-bound readings
+-
+-  * ZFS: Running ztest repeatedly for long periods of time eventually results in
+-    "zdb: can't open 'ztest': No such file or directory" (LP: #1587686)
+-    - Fix ztest truncated cache file
+-
+-  * STC840.20:Alpine:alp7fp1:Ubuntu 16.04, BlueFin (SAN) EEH 6 times during boot
+-    then disabled SRC BA188002:b0314a_1612.840 (LP: #1587316)
+-    - lpfc: Fix DMA faults observed upon plugging loopback connector
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Tue, 28 Jun 2016 10:17:41 -0700
+-
+-linux (4.4.0-28.47) xenial; urgency=low
+-
+-  [ Luis Henriques ]
+-
+-  * Release Tracking Bug
+-    - LP: #1595874
+-
+-  * Linux netfilter local privilege escalation issues (LP: #1595350)
+-    - netfilter: x_tables: don't move to non-existent next rule
+-    - netfilter: x_tables: validate targets of jumps
+-    - netfilter: x_tables: add and use xt_check_entry_offsets
+-    - netfilter: x_tables: kill check_entry helper
+-    - netfilter: x_tables: assert minimum target size
+-    - netfilter: x_tables: add compat version of xt_check_entry_offsets
+-    - netfilter: x_tables: check standard target size too
+-    - netfilter: x_tables: check for bogus target offset
+-    - netfilter: x_tables: validate all offsets and sizes in a rule
+-    - netfilter: x_tables: don't reject valid target size on some architectures
+-    - netfilter: arp_tables: simplify translate_compat_table args
+-    - netfilter: ip_tables: simplify translate_compat_table args
+-    - netfilter: ip6_tables: simplify translate_compat_table args
+-    - netfilter: x_tables: xt_compat_match_from_user doesn't need a retval
+-    - netfilter: x_tables: do compat validation via translate_table
+-    - netfilter: x_tables: introduce and use xt_copy_counters_from_user
+-
+-  * Linux netfilter IPT_SO_SET_REPLACE memory corruption (LP: #1555338)
+-    - netfilter: x_tables: validate e->target_offset early
+-    - netfilter: x_tables: make sure e->next_offset covers remaining blob size
+-    - netfilter: x_tables: fix unconditional helper
+-
+- -- Luis Henriques <luis.henriques@canonical.com>  Fri, 24 Jun 2016 09:57:21 +0100
+-
+-linux (4.4.0-27.46) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1594906
+-
+-  * Support Edge Gateway's Bluetooth LED (LP: #1512999)
+-    - Revert "UBUNTU: SAUCE: Bluetooth: Support for LED on Marvell modules"
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Tue, 21 Jun 2016 10:17:00 -0700
+-
+-linux (4.4.0-26.45) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1594442
+-
+-  * linux: Implement secure boot state variables (LP: #1593075)
+-    - SAUCE: UEFI: Add secure boot and MOK SB State disabled sysctl
+-
+-  * failures building userspace packages that include ethtool.h (LP: #1592930)
+-    - ethtool.h: define INT_MAX for userland
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Mon, 20 Jun 2016 09:43:47 -0700
+-
+-linux (4.4.0-25.44) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1591289
+-
+-  * Xenial update to v4.4.13 stable release (LP: #1590455)
+-    - MIPS64: R6: R2 emulation bugfix
+-    - MIPS: math-emu: Fix jalr emulation when rd == $0
+-    - MIPS: MSA: Fix a link error on `_init_msa_upper' with older GCC
+-    - MIPS: Don't unwind to user mode with EVA
+-    - MIPS: Avoid using unwind_stack() with usermode
+-    - MIPS: Fix siginfo.h to use strict posix types
+-    - MIPS: Fix uapi include in exported asm/siginfo.h
+-    - MIPS: Fix watchpoint restoration
+-    - MIPS: Flush highmem pages in __flush_dcache_page
+-    - MIPS: Handle highmem pages in __update_cache
+-    - MIPS: Sync icache & dcache in set_pte_at
+-    - MIPS: ath79: make bootconsole wait for both THRE and TEMT
+-    - MIPS: Reserve nosave data for hibernation
+-    - MIPS: Loongson-3: Reserve 32MB for RS780E integrated GPU
+-    - MIPS: Use copy_s.fmt rather than copy_u.fmt
+-    - MIPS: Fix MSA ld_*/st_* asm macros to use PTR_ADDU
+-    - MIPS: Prevent "restoration" of MSA context in non-MSA kernels
+-    - MIPS: Disable preemption during prctl(PR_SET_FP_MODE, ...)
+-    - MIPS: ptrace: Fix FP context restoration FCSR regression
+-    - MIPS: ptrace: Prevent writes to read-only FCSR bits
+-    - MIPS: Fix sigreturn via VDSO on microMIPS kernel
+-    - MIPS: Build microMIPS VDSO for microMIPS kernels
+-    - MIPS: lib: Mark intrinsics notrace
+-    - MIPS: VDSO: Build with `-fno-strict-aliasing'
+-    - affs: fix remount failure when there are no options changed
+-    - ASoC: ak4642: Enable cache usage to fix crashes on resume
+-    - Input: uinput - handle compat ioctl for UI_SET_PHYS
+-    - ARM: mvebu: fix GPIO config on the Linksys boards
+-    - ARM: dts: at91: fix typo in sama5d2 PIN_PD24 description
+-    - ARM: dts: exynos: Add interrupt line to MAX8997 PMIC on exynos4210-trats
+-    - ARM: dts: imx35: restore existing used clock enumeration
+-    - ath9k: Add a module parameter to invert LED polarity.
+-    - ath9k: Fix LED polarity for some Mini PCI AR9220 MB92 cards.
+-    - ath10k: fix debugfs pktlog_filter write
+-    - ath10k: fix firmware assert in monitor mode
+-    - ath10k: fix rx_channel during hw reconfigure
+-    - ath10k: fix kernel panic, move arvifs list head init before htt init
+-    - ath5k: Change led pin configuration for compaq c700 laptop
+-    - hwrng: exynos - Fix unbalanced PM runtime put on timeout error path
+-    - rtlwifi: rtl8723be: Add antenna select module parameter
+-    - rtlwifi: btcoexist: Implement antenna selection
+-    - rtlwifi: Fix logic error in enter/exit power-save mode
+-    - rtlwifi: pci: use dev_kfree_skb_irq instead of kfree_skb in
+-      rtl_pci_reset_trx_ring
+-    - aacraid: Relinquish CPU during timeout wait
+-    - aacraid: Fix for aac_command_thread hang
+-    - aacraid: Fix for KDUMP driver hang
+-    - hwmon: (ads7828) Enable internal reference
+-    - mfd: intel-lpss: Save register context on suspend
+-    - mfd: intel_soc_pmic_core: Terminate panel control GPIO lookup table
+-      correctly
+-    - PM / Runtime: Fix error path in pm_runtime_force_resume()
+-    - cpuidle: Indicate when a device has been unregistered
+-    - cpuidle: Fix cpuidle_state_is_coupled() argument in cpuidle_enter()
+-    - clk: bcm2835: Fix PLL poweron
+-    - clk: at91: fix check of clk_register() returned value
+-    - clk: bcm2835: pll_off should only update CM_PLL_ANARST
+-    - clk: bcm2835: divider value has to be 1 or more
+-    - pinctrl: exynos5440: Use off-stack memory for pinctrl_gpio_range
+-    - PCI: Disable all BAR sizing for devices with non-compliant BARs
+-    - media: v4l2-compat-ioctl32: fix missing reserved field copy in
+-      put_v4l2_create32
+-    - mm: use phys_addr_t for reserve_bootmem_region() arguments
+-    - wait/ptrace: assume __WALL if the child is traced
+-    - QE-UART: add "fsl,t1040-ucc-uart" to of_device_id
+-    - powerpc/book3s64: Fix branching to OOL handlers in relocatable kernel
+-    - powerpc/eeh: Don't report error in eeh_pe_reset_and_recover()
+-    - powerpc/eeh: Restore initial state in eeh_pe_reset_and_recover()
+-    - xen/events: Don't move disabled irqs
+-    - xen: use same main loop for counting and remapping pages
+-    - sunrpc: fix stripping of padded MIC tokens
+-    - drm/gma500: Fix possible out of bounds read
+-    - drm/vmwgfx: Enable SVGA_3D_CMD_DX_SET_PREDICATION
+-    - drm/vmwgfx: use vmw_cmd_dx_cid_check for query commands.
+-    - drm/vmwgfx: Fix order of operation
+-    - drm/amdgpu: use drm_mode_vrefresh() rather than mode->vrefresh
+-    - drm/amdgpu: Fix hdmi deep color support.
+-    - drm/i915/fbdev: Fix num_connector references in intel_fb_initial_config()
+-    - drm/fb_helper: Fix references to dev->mode_config.num_connector
+-    - drm/atomic: Verify connector->funcs != NULL when clearing states
+-    - drm/i915: Don't leave old junk in ilk active watermarks on readout
+-    - drm/imx: Match imx-ipuv3-crtc components using device node in platform data
+-    - ext4: fix hang when processing corrupted orphaned inode list
+-    - ext4: clean up error handling when orphan list is corrupted
+-    - ext4: fix oops on corrupted filesystem
+-    - ext4: address UBSAN warning in mb_find_order_for_block()
+-    - ext4: silence UBSAN in ext4_mb_init()
+-    - PM / sleep: Handle failures in device_suspend_late() consistently
+-    - dma-debug: avoid spinlock recursion when disabling dma-debug
+-    - scripts/package/Makefile: rpmbuild add support of RPMOPTS
+-    - gcov: disable tree-loop-im to reduce stack usage
+-    - xfs: disallow rw remount on fs with unknown ro-compat features
+-    - xfs: Don't wrap growfs AGFL indexes
+-    - xfs: xfs_iflush_cluster fails to abort on error
+-    - xfs: fix inode validity check in xfs_iflush_cluster
+-    - xfs: skip stale inodes in xfs_iflush_cluster
+-    - xfs: print name of verifier if it fails
+-    - xfs: handle dquot buffer readahead in log recovery correctly
+-    - Linux 4.4.13
+-
+-  * 168c:001c [HP Compaq Presario C700 Notebook PC] Wireless led button doesn't
+-    switch colors (LP: #972604)
+-    - ath5k: Change led pin configuration for compaq c700 laptop
+-
+-  * Extended statistics from balloon for proper memory management (LP: #1587091)
+-    - mm/page_alloc.c: calculate 'available' memory in a separate function
+-    - virtio_balloon: export 'available' memory to balloon statistics
+-
+-  * CAPI: CGZIP AFU contexts do not receive interrupts after heavy afu
+-    open/close (LP: #1588468)
+-    - misc: cxl: use kobj_to_dev()
+-    - cxl: Move common code away from bare-metal-specific files
+-    - cxl: Move bare-metal specific code to specialized files
+-    - cxl: Define process problem state area at attach time only
+-    - cxl: Introduce implementation-specific API
+-    - cxl: Rename some bare-metal specific functions
+-    - cxl: Isolate a few bare-metal-specific calls
+-    - cxl: Update cxl_irq() prototype
+-    - cxl: IRQ allocation for guests
+-    - powerpc: New possible return value from hcall
+-    - cxl: New hcalls to support cxl adapters
+-    - cxl: Separate bare-metal fields in adapter and AFU data structures
+-    - cxlflash: Simplify PCI registration
+-    - cxlflash: Unmap problem state area before detaching master context
+-    - cxlflash: Split out context initialization
+-    - cxlflash: Simplify attach path error cleanup
+-    - cxlflash: Reorder user context initialization
+-    - cxl: Add guest-specific code
+-    - cxl: sysfs support for guests
+-    - cxl: Support to flash a new image on the adapter from a guest
+-    - cxl: Parse device tree and create cxl device(s) at boot
+-    - cxl: Support the cxl kernel API from a guest
+-    - cxl: Adapter failure handling
+-    - cxl: Add tracepoints around the cxl hcall
+-    - cxlflash: Use new cxl_pci_read_adapter_vpd() API
+-    - cxl: Remove cxl_get_phys_dev() kernel API
+-    - cxl: Ignore probes for virtual afu pci devices
+-    - cxl: Poll for outstanding IRQs when detaching a context
+-
+-  * NVMe max_segments queue parameter gets set to 1 (LP: #1588449)
+-    - nvme: set queue limits for the admin queue
+-    - nvme: fix max_segments integer truncation
+-    - block: fix blk_rq_get_max_sectors for driver private requests
+-
+-  * workaround cavium thunderx silicon erratum 23144 (LP: #1589704)
+-    - irqchip/gicv3-its: numa: Enable workaround for Cavium thunderx erratum 23144
+-
+-  * Xenial update to v4.4.12 stable release (LP: #1588945)
+-    - Btrfs: don't use src fd for printk
+-    - perf/x86/intel/pt: Generate PMI in the STOP region as well
+-    - perf/core: Fix perf_event_open() vs. execve() race
+-    - perf test: Fix build of BPF and LLVM on older glibc libraries
+-    - ext4: iterate over buffer heads correctly in move_extent_per_page()
+-    - arm64: Fix typo in the pmdp_huge_get_and_clear() definition
+-    - arm64: Ensure pmd_present() returns false after pmd_mknotpresent()
+-    - arm64: Implement ptep_set_access_flags() for hardware AF/DBM
+-    - arm64: Implement pmdp_set_access_flags() for hardware AF/DBM
+-    - arm64: cpuinfo: Missing NULL terminator in compat_hwcap_str
+-    - arm/arm64: KVM: Enforce Break-Before-Make on Stage-2 page tables
+-    - kvm: arm64: Fix EC field in inject_abt64
+-    - remove directory incorrectly tries to set delete on close on non-empty
+-      directories
+-    - fs/cifs: correctly to anonymous authentication via NTLMSSP
+-    - fs/cifs: correctly to anonymous authentication for the LANMAN authentication
+-    - fs/cifs: correctly to anonymous authentication for the NTLM(v1)
+-      authentication
+-    - fs/cifs: correctly to anonymous authentication for the NTLM(v2)
+-      authentication
+-    - asix: Fix offset calculation in asix_rx_fixup() causing slow transmissions
+-    - ring-buffer: Use long for nr_pages to avoid overflow failures
+-    - ring-buffer: Prevent overflow of size in ring_buffer_resize()
+-    - crypto: caam - fix caam_jr_alloc() ret code
+-    - crypto: talitos - fix ahash algorithms registration
+-    - crypto: sun4i-ss - Replace spinlock_bh by spin_lock_irq{save|restore}
+-    - clk: qcom: msm8916: Fix crypto clock flags
+-    - sched/loadavg: Fix loadavg artifacts on fully idle and on fully loaded
+-      systems
+-    - mfd: omap-usb-tll: Fix scheduling while atomic BUG
+-    - Input: pwm-beeper - fix - scheduling while atomic
+-    - irqchip/gic: Ensure ordering between read of INTACK and shared data
+-    - irqchip/gic-v3: Configure all interrupts as non-secure Group-1
+-    - can: fix handling of unmodifiable configuration options
+-    - mmc: mmc: Fix partition switch timeout for some eMMCs
+-    - mmc: sdhci-acpi: Remove MMC_CAP_BUS_WIDTH_TEST for Intel controllers
+-    - ACPI / osi: Fix an issue that acpi_osi=!* cannot disable ACPICA internal
+-      strings
+-    - dell-rbtn: Ignore ACPI notifications if device is suspended
+-    - mmc: longer timeout for long read time quirk
+-    - mmc: sdhci-pci: Remove MMC_CAP_BUS_WIDTH_TEST for Intel controllers
+-    - Bluetooth: vhci: fix open_timeout vs. hdev race
+-    - Bluetooth: vhci: purge unhandled skbs
+-    - Bluetooth: vhci: Fix race at creating hci device
+-    - mei: fix NULL dereferencing during FW initiated disconnection
+-    - mei: amthif: discard not read messages
+-    - mei: bus: call mei_cl_read_start under device lock
+-    - USB: serial: mxuport: fix use-after-free in probe error path
+-    - USB: serial: keyspan: fix use-after-free in probe error path
+-    - USB: serial: quatech2: fix use-after-free in probe error path
+-    - USB: serial: io_edgeport: fix memory leaks in attach error path
+-    - USB: serial: io_edgeport: fix memory leaks in probe error path
+-    - USB: serial: option: add support for Cinterion PH8 and AHxx
+-    - USB: serial: option: add more ZTE device ids
+-    - USB: serial: option: add even more ZTE device ids
+-    - usb: gadget: f_fs: Fix EFAULT generation for async read operations
+-    - usb: f_mass_storage: test whether thread is running before starting another
+-    - usb: misc: usbtest: fix pattern tests for scatterlists.
+-    - usb: gadget: udc: core: Fix argument of dev_err() in
+-      usb_gadget_map_request()
+-    - staging: comedi: das1800: fix possible NULL dereference
+-    - KVM: x86: fix ordering of cr0 initialization code in vmx_cpu_reset
+-    - MIPS: KVM: Fix timer IRQ race when freezing timer
+-    - MIPS: KVM: Fix timer IRQ race when writing CP0_Compare
+-    - KVM: x86: mask CPUID(0xD,0x1).EAX against host value
+-    - xen/x86: actually allocate legacy interrupts on PV guests
+-    - tty: vt, return error when con_startup fails
+-    - TTY: n_gsm, fix false positive WARN_ON
+-    - tty/serial: atmel: fix hardware handshake selection
+-    - Fix OpenSSH pty regression on close
+-    - serial: 8250_pci: fix divide error bug if baud rate is 0
+-    - serial: 8250_mid: use proper bar for DNV platform
+-    - serial: 8250_mid: recognize interrupt source in handler
+-    - serial: samsung: Reorder the sequence of clock control when call
+-      s3c24xx_serial_set_termios()
+-    - locking,qspinlock: Fix spin_is_locked() and spin_unlock_wait()
+-    - clk: bcm2835: add locking to pll*_on/off methods
+-    - mcb: Fixed bar number assignment for the gdd
+-    - ALSA: hda/realtek - New codecs support for ALC234/ALC274/ALC294
+-    - ALSA: hda - Fix headphone noise on Dell XPS 13 9360
+-    - ALSA: hda/realtek - Add support for ALC295/ALC3254
+-    - ALSA: hda - Fix headset mic detection problem for one Dell machine
+-    - IB/srp: Fix a debug kernel crash
+-    - thunderbolt: Fix double free of drom buffer
+-    - SIGNAL: Move generic copy_siginfo() to signal.h
+-    - UBI: Fix static volume checks when Fastmap is used
+-    - hpfs: fix remount failure when there are no options changed
+-    - hpfs: implement the show_options method
+-    - scsi: Add intermediate STARGET_REMOVE state to scsi_target_state
+-    - Revert "scsi: fix soft lockup in scsi_remove_target() on module removal"
+-    - kbuild: move -Wunused-const-variable to W=1 warning level
+-    - Linux 4.4.12
+-
+-  * [Hyper-V] fixes for kdump when running on a VM (LP: #1588965)
+-    - clocksource: Allow unregistering the watchdog
+-
+-  * net_admin apparmor denial when using Go (LP: #1465724)
+-    - SAUCE: kernel: Add noaudit variant of ns_capable()
+-    - SAUCE: net: Use ns_capable_noaudit() when determining net sysctl permissions
+-
+-  * [Hyper-V] Put tools/hv/lsvmbus in /usr/sbin (LP: #1585311)
+-    - [Debian] Install lsvmbus in cloud tools
+-    - SAUCE: tools/hv/lsvmbus -- convert to python3
+-    - SAUCE: tools/hv/lsvmbus -- add manual page
+-
+-  * btrfs: file write crashes with false ENOSPC during snapshot creation since
+-    kernel 4.4 - fix available (LP: #1584052)
+-    - btrfs: Continue write in case of can_not_nocow
+-
+-  * boot stalls on USB detection errors (LP: #1437492)
+-    - usb: core: hub: hub_port_init lock controller instead of bus
+-
+-  * [Bug]KNL:Spread MWAIT cache lines over all nodes (LP: #1585850)
+-    - kernek/fork.c: allocate idle task for a CPU always on its local node
+-
+-  * [Hyper-V] PCI Passthrough kernel hang and explicit barriers (LP: #1581243)
+-    - PCI: hv: Report resources release after stopping the bus
+-    - PCI: hv: Add explicit barriers to config space access
+-
+-  * Kernel 4.2.X and 4.4.X - Fix USB3.0 link power management (LPM)
+-    claim/release logic in USBFS (LP: #1577024)
+-    - USB: leave LPM alone if possible when binding/unbinding interface drivers
+-
+-  * STC840.20:tuleta:tul516p01 panic after injecting Leaf EEH (LP: #1581034)
+-    - NVMe: Fix namespace removal deadlock
+-    - NVMe: Requeue requests on suspended queues
+-    - NVMe: Move error handling to failed reset handler
+-    - blk-mq: End unstarted requests on dying queue
+-
+-  * conflicting modules in udebs - arc4.ko (LP: #1582991)
+-    - [Config] Remove arc4 from nic-modules
+-
+-  * CVE-2016-4482 (LP: #1578493)
+-    - USB: usbfs: fix potential infoleak in devio
+-
+-  * mlx5_core kexec fail  (LP: #1585978)
+-    - net/mlx5: Add pci shutdown callback
+-
+-  * backport fix for /proc/net issues with containers (LP: #1584953)
+-    - netfilter: Set /proc/net entries owner to root in namespace
+-
+-  * CVE-2016-4951 (LP: #1585365)
+-    - tipc: check nl sock before parsing nested attributes
+-
+-  * CVE-2016-4578 (LP: #1581866)
+-    - ALSA: timer: Fix leak in events via snd_timer_user_ccallback
+-    - ALSA: timer: Fix leak in events via snd_timer_user_tinterrupt
+-
+-  * CVE-2016-4569 (LP: #1580379)
+-    - ALSA: timer: Fix leak in SNDRV_TIMER_IOCTL_PARAMS
+-
+-  * s390/pci: fix use after free in dma_init (LP: #1584828)
+-    - s390/pci: fix use after free in dma_init
+-
+-  * s390/mm: fix asce_bits handling with dynamic pagetable levels (LP: #1584827)
+-    - s390/mm: fix asce_bits handling with dynamic pagetable levels
+-
+-  * CAPI: CGZIP Wrong CAPI MMIO timeout (256usec desired but 1usec default
+-    setting in cxl.ko driver) (LP: #1584066)
+-    - powerpc: Define PVR value for POWER8NVL processor
+-    - cxl: Configure the PSL for two CAPI ports on POWER8NVL
+-    - cxl: Increase timeout for detection of AFU mmio hang
+-
+-  * ThunderX: soft lockup in cursor_timer_handler() (LP: #1574814)
+-    - SAUCE: tty: vt: Fix soft lockup in fbcon cursor blink timer.
+-
+-  * debian.master/.../getabis bogus warnings "inconsistant compiler versions"
+-    and "not a git repository" (LP: #1584890)
+-    - [debian] getabis: Only git add $abidir if running in local repo
+-    - [debian] getabis: Fix inconsistent compiler versions check
+-
+-  * Backport cxlflash patch related to EEH recovery into Xenial SRU stream
+-    (LP: #1584935)
+-    - cxlflash: Fix to resolve dead-lock during EEH recovery
+-
+-  * Xenial update to 4.4.11 stable release (LP: #1584912)
+-    - decnet: Do not build routes to devices without decnet private data.
+-    - route: do not cache fib route info on local routes with oif
+-    - packet: fix heap info leak in PACKET_DIAG_MCLIST sock_diag interface
+-    - net: sched: do not requeue a NULL skb
+-    - bpf/verifier: reject invalid LD_ABS | BPF_DW instruction
+-    - cdc_mbim: apply "NDP to end" quirk to all Huawei devices
+-    - net: use skb_postpush_rcsum instead of own implementations
+-    - vlan: pull on __vlan_insert_tag error path and fix csum correction
+-    - openvswitch: use flow protocol when recalculating ipv6 checksums
+-    - ipv4/fib: don't warn when primary address is missing if in_dev is dead
+-    - net/mlx4_en: fix spurious timestamping callbacks
+-    - bpf: fix check_map_func_compatibility logic
+-    - samples/bpf: fix trace_output example
+-    - net: Implement net_dbg_ratelimited() for CONFIG_DYNAMIC_DEBUG case
+-    - gre: do not pull header in ICMP error processing
+-    - net_sched: introduce qdisc_replace() helper
+-    - net_sched: update hierarchical backlog too
+-    - sch_htb: update backlog as well
+-    - sch_dsmark: update backlog as well
+-    - netem: Segment GSO packets on enqueue
+-    - net: fec: only clear a queue's work bit if the queue was emptied
+-    - VSOCK: do not disconnect socket when peer has shutdown SEND only
+-    - net: bridge: fix old ioctl unlocked net device walk
+-    - bridge: fix igmp / mld query parsing
+-    - uapi glibc compat: fix compile errors when glibc net/if.h included before
+-      linux/if.h MIME-Version: 1.0
+-    - net: fix a kernel infoleak in x25 module
+-    - net: thunderx: avoid exposing kernel stack
+-    - tcp: refresh skb timestamp at retransmit time
+-    - net/route: enforce hoplimit max value
+-    - ocfs2: revert using ocfs2_acl_chmod to avoid inode cluster lock hang
+-    - ocfs2: fix posix_acl_create deadlock
+-    - zsmalloc: fix zs_can_compact() integer overflow
+-    - crypto: qat - fix invalid pf2vf_resp_wq logic
+-    - crypto: hash - Fix page length clamping in hash walk
+-    - crypto: testmgr - Use kmalloc memory for RSA input
+-    - ALSA: usb-audio: Quirk for yet another Phoenix Audio devices (v2)
+-    - ALSA: usb-audio: Yet another Phoneix Audio device quirk
+-    - ALSA: hda - Fix subwoofer pin on ASUS N751 and N551
+-    - ALSA: hda - Fix white noise on Asus UX501VW headset
+-    - ALSA: hda - Fix broken reconfig
+-    - spi: pxa2xx: Do not detect number of enabled chip selects on Intel SPT
+-    - spi: spi-ti-qspi: Fix FLEN and WLEN settings if bits_per_word is overridden
+-    - spi: spi-ti-qspi: Handle truncated frames properly
+-    - pinctrl: at91-pio4: fix pull-up/down logic
+-    - regmap: spmi: Fix regmap_spmi_ext_read in multi-byte case
+-    - perf/core: Disable the event on a truncated AUX record
+-    - vfs: add vfs_select_inode() helper
+-    - vfs: rename: check backing inode being equal
+-    - ARM: dts: at91: sam9x5: Fix the memory range assigned to the PMC
+-    - workqueue: fix rebind bound workers warning
+-    - regulator: s2mps11: Fix invalid selector mask and voltages for buck9
+-    - regulator: axp20x: Fix axp22x ldo_io voltage ranges
+-    - atomic_open(): fix the handling of create_error
+-    - qla1280: Don't allocate 512kb of host tags
+-    - tools lib traceevent: Do not reassign parg after collapse_tree()
+-    - get_rock_ridge_filename(): handle malformed NM entries
+-    - Input: max8997-haptic - fix NULL pointer dereference
+-    - Revert "[media] videobuf2-v4l2: Verify planes array in buffer dequeueing"
+-    - drm/radeon: fix PLL sharing on DCE6.1 (v2)
+-    - drm/i915: Bail out of pipe config compute loop on LPT
+-    - drm/i915/bdw: Add missing delay during L3 SQC credit programming
+-    - drm/radeon: fix DP link training issue with second 4K monitor
+-    - nf_conntrack: avoid kernel pointer value leak in slab name
+-    - Linux 4.4.11
+-
+-  * Support Edge Gateway's Bluetooth LED (LP: #1512999)
+-    - SAUCE: Bluetooth: Support for LED on Marvell modules
+-
+-  * Support Edge Gateway's WIFI LED (LP: #1512997)
+-    - SAUCE: mwifiex: Switch WiFi LED state according to the device status
+-
+-  * Marvell wireless driver update for FCC regulation (LP: #1528910)
+-    - mwifiex: parse adhoc start/join result
+-    - mwifiex: handle start AP error paths correctly
+-    - mwifiex: set regulatory info from EEPROM
+-    - mwifiex: don't follow AP if country code received from EEPROM
+-    - mwifiex: correction in region code to country mapping
+-    - mwifiex: update region_code_index array
+-    - mwifiex: use world for unidentified region code
+-    - SAUCE: mwifiex: add iw vendor command support
+-
+-  * Kernel can be oopsed using remap_file_pages (LP: #1558120)
+-    - Revert "UBUNTU: SAUCE: mm/mmap: fix oopsing on remap_file_pages"
+-    - SAUCE: AUFS: mm/mmap: fix oopsing on remap_file_pages aufs mmap: bugfix,
+-      mainly for linux-4.5-rc5, remap_file_pages(2) emulation
+-
+-  * cgroup namespace update (LP: #1584163)
+-    - Revert "UBUNTU: SAUCE: cgroup mount: ignore nsroot="
+-    - Revert "UBUNTU: SAUCE: (noup) cgroup namespaces: add a 'nsroot=' mountinfo
+-      field"
+-    - cgroup, kernfs: make mountinfo show properly scoped path for cgroup
+-      namespaces
+-    - kernfs: kernfs_sop_show_path: don't return 0 after seq_dentry call
+-    - cgroup: fix compile warning
+-
+-  * Missing libunwind support in perf (LP: #1248289)
+-    - [Config] add binutils-dev to the Build-Depends: to fix perf unwinding
+-
+-  * e1000 Tx Unit Hang  (LP: #1582328)
+-    - e1000: Double Tx descriptors needed check for 82544
+-    - e1000: Do not overestimate descriptor counts in Tx pre-check
+-
+-  * Unsharing user and ipc namespaces simultaneously makes mqueue unmountable
+-    (LP: #1582378)
+-    - SAUCE: (namespace) mqueue: Super blocks must be owned by the user ns which
+-      owns the ipc ns
+-
+-  * Pull in the amdgpu/radeon code from Linux 4.5.3 (LP: #1580526)
+-    - drm/radeon: rework fbdev handling on chips with no connectors
+-    - drm/radeon/mst: fix regression in lane/link handling.
+-    - drm/amd/powerplay: add uvd/vce dpm enabling flag to fix the performance
+-      issue for CZ
+-    - drm/amd/powerplay: fix segment fault issue in multi-display case.
+-    - drm/ttm: fix kref count mess in ttm_bo_move_to_lru_tail
+-
+-  * aufs CONFIG_AUFS_EXPORT build option should be enabled (LP: #1121699)
+-    - [Config] enable CONFIG_AUFS_EXPORT
+-
+-  * promote *_diag modules from linux-image-extra to linux-image (LP: #1580355)
+-    - [Config] Update inclusion list for CRIU
+-
+-  * [Xenial] net: updates to ethtool and virtio_net for speed/duplex support
+-    (LP: #1581132)
+-    - ethtool: add speed/duplex validation functions
+-    - ethtool: make validate_speed accept all speeds between 0 and INT_MAX
+-    - virtio_net: add ethtool support for set and get of settings
+-    - virtio_net: validate ethtool port setting and explain the user validation
+-
+-  * perf tool: Display event codes for Generic HW (PMU) events (LP: #1578211)
+-    - powerpc/perf: Remove PME_ prefix for power7 events
+-    - powerpc/perf: Export Power8 generic and cache events to sysfs
+-
+-  * Mellanox ConnectX4 MTU limits: max and min (LP: #1528466)
+-    - net/mlx5: Introduce a new header file for physical port functions
+-    - net/mlx5e: Device's mtu field is u16 and not int
+-    - net/mlx5e: Fix minimum MTU
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Config] CONFIG_CAVIUM_ERRATUM_23144=y
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Fri, 10 Jun 2016 10:07:13 -0700
+-
+-linux (4.4.0-24.43) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * CVE-2016-1583 (LP: #1588871)
+-    - ecryptfs: fix handling of directory opening
+-    - SAUCE: proc: prevent stacking filesystems on top
+-    - SAUCE: ecryptfs: forbid opening files without mmap handler
+-    - SAUCE: sched: panic on corrupted stack end
+-
+-  * arm64: statically link rtc-efi (LP: #1583738)
+-    - [Config] Link rtc-efi statically on arm64
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 08 Jun 2016 20:01:12 +0100
+-
+-linux (4.4.0-23.41) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1582431
+-
+-  * zfs: disable module checks for zfs when cross-compiling (LP: #1581127)
+-    - [Packaging] disable zfs module checks when cross-compiling
+-
+-  * Xenial update to v4.4.10 stable release (LP: #1580754)
+-    - Revert "UBUNTU: SAUCE: (no-up) ACPICA: Dispatcher: Update thread ID for
+-      recursive method calls"
+-    - Revert "UBUNTU: SAUCE: nbd: ratelimit error msgs after socket close"
+-    - Revert: "powerpc/tm: Check for already reclaimed tasks"
+-    - RDMA/iw_cxgb4: Fix bar2 virt addr calculation for T4 chips
+-    - ipvs: handle ip_vs_fill_iph_skb_off failure
+-    - ipvs: correct initial offset of Call-ID header search in SIP persistence
+-      engine
+-    - ipvs: drop first packet to redirect conntrack
+-    - mfd: intel-lpss: Remove clock tree on error path
+-    - nbd: ratelimit error msgs after socket close
+-    - ata: ahci_xgene: dereferencing uninitialized pointer in probe
+-    - mwifiex: fix corner case association failure
+-    - CNS3xxx: Fix PCI cns3xxx_write_config()
+-    - clk-divider: make sure read-only dividers do not write to their register
+-    - soc: rockchip: power-domain: fix err handle while probing
+-    - clk: rockchip: free memory in error cases when registering clock branches
+-    - clk: meson: Fix meson_clk_register_clks() signature type mismatch
+-    - clk: qcom: msm8960: fix ce3_core clk enable register
+-    - clk: versatile: sp810: support reentrance
+-    - clk: qcom: msm8960: Fix ce3_src register offset
+-    - lpfc: fix misleading indentation
+-    - ath9k: ar5008_hw_cmn_spur_mitigate: add missing mask_m & mask_p
+-      initialisation
+-    - mac80211: fix statistics leak if dev_alloc_name() fails
+-    - tracing: Don't display trigger file for events that can't be enabled
+-    - MD: make bio mergeable
+-    - Minimal fix-up of bad hashing behavior of hash_64()
+-    - mm, cma: prevent nr_isolated_* counters from going negative
+-    - mm/zswap: provide unique zpool name
+-    - ARM: EXYNOS: Properly skip unitialized parent clock in power domain on
+-    - ARM: SoCFPGA: Fix secondary CPU startup in thumb2 kernel
+-    - xen: Fix page <-> pfn conversion on 32 bit systems
+-    - xen/balloon: Fix crash when ballooning on x86 32 bit PAE
+-    - xen/evtchn: fix ring resize when binding new events
+-    - HID: wacom: Add support for DTK-1651
+-    - HID: Fix boot delay for Creative SB Omni Surround 5.1 with quirk
+-    - Input: zforce_ts - fix dual touch recognition
+-    - proc: prevent accessing /proc/<PID>/environ until it's ready
+-    - mm: update min_free_kbytes from khugepaged after core initialization
+-    - batman-adv: fix DAT candidate selection (must use vid)
+-    - batman-adv: Check skb size before using encapsulated ETH+VLAN header
+-    - batman-adv: Fix broadcast/ogm queue limit on a removed interface
+-    - batman-adv: Reduce refcnt of removed router when updating route
+-    - writeback: Fix performance regression in wb_over_bg_thresh()
+-    - MAINTAINERS: Remove asterisk from EFI directory names
+-    - x86/tsc: Read all ratio bits from MSR_PLATFORM_INFO
+-    - ARM: cpuidle: Pass on arm_cpuidle_suspend()'s return value
+-    - ARC: Add missing io barriers to io{read,write}{16,32}be()
+-    - x86/sysfb_efi: Fix valid BAR address range check
+-    - ACPICA: Dispatcher: Update thread ID for recursive method calls
+-    - powerpc: Fix bad inline asm constraint in create_zero_mask()
+-    - libahci: save port map for forced port map
+-    - ata: ahci-platform: Add ports-implemented DT bindings.
+-    - USB: serial: cp210x: add ID for Link ECU
+-    - USB: serial: cp210x: add Straizona Focusers device ids
+-    - nvmem: mxs-ocotp: fix buffer overflow in read
+-    - gpu: ipu-v3: Fix imx-ipuv3-crtc module autoloading
+-    - drm/amdgpu: make sure vertical front porch is at least 1
+-    - drm/amdgpu: set metadata pointer to NULL after freeing.
+-    - iio: ak8975: Fix NULL pointer exception on early interrupt
+-    - iio: ak8975: fix maybe-uninitialized warning
+-    - drm/radeon: make sure vertical front porch is at least 1
+-    - drm/i915/ddi: Fix eDP VDD handling during booting and suspend/resume
+-    - drm/i915: Fix eDP low vswing for Broadwell
+-    - drm/i915: Make RPS EI/thresholds multiple of 25 on SNB-BDW
+-    - drm/i915: Fake HDMI live status
+-    - lib/test-string_helpers.c: fix and improve string_get_size() tests
+-    - drm/i915/skl: Fix DMC load on Skylake J0 and K0
+-    - Linux 4.4.10
+-
+-  * HDMI audio playback noise  observed on AMD Polaris 10/11 GPU (LP: #1577288)
+-    - ALSA: hda: add AMD Polaris-10/11 AZ PCI IDs with proper driver caps
+-
+-  * [i915_bpo] Update i915 backport driver (LP: #1580114)
+-    - SAUCE: i915_bpo: Drop is_preliminary from BXT/KBL.
+-    - SAUCE: i915_bpo: Sync with v4.6-rc7
+-
+-  * CVE-2016-4486 (LP: #1578497)
+-    - net: fix infoleak in rtnetlink
+-
+-  * CVE-2016-4485 (LP: #1578496)
+-    - net: fix infoleak in llc
+-
+-  * drm.ko < kernel version 4.5 has a dead lock bug (LP: #1579610)
+-    - drm: Balance error path for GEM handle allocation
+-
+-  * Cannot use CONFIG_CC_STACKPROTECTOR_STRONG: -fstack-protector-strong not
+-    supported by compiler (LP: #1574982)
+-    - SAUCE: (no-up) disable -pie when gcc has it enabled by default
+-
+-  * system freeze after vt switching (LP: #1542939)
+-    - drm/atomic: Add __drm_atomic_helper_connector_reset, v2.
+-    - drm/atomic: Remove drm_atomic_connectors_for_crtc.
+-
+-  * CVE-2016-4558 (LP: #1579140)
+-    - bpf: fix refcnt overflow
+-
+-  * Kernel Panic on EC2 After Upgrading from 14.04 to 16.04 via do-release-
+-    upgrade -d (LP: #1573231)
+-    - SAUCE: (no-up) x86/topology: Handle CPUID bogosity gracefully
+-
+-  * PCI Call Traces  hw csum failure in dmesg with  4.4.0-2-generic
+-    (LP: #1544978)
+-    - net/mlx4_en: Fix endianness bug in IPV6 csum calculation
+-
+-  * Missing libunwind support in perf (LP: #1248289)
+-    - [Config] Add liblzma-dev to enable libunwind support in perf
+-
+-  * thunderbolt hotplug is broken (LP: #1577898)
+-    - SAUCE: (no-up) ACPICA: Dispatcher: Update thread ID for recursive method
+-      calls
+-
+-  * Kernel can be oopsed using remap_file_pages (LP: #1558120)
+-    - SAUCE: mm/mmap: fix oopsing on remap_file_pages
+-
+-  * ZFS is confused by user namespaces (uid/gid mapping) when used with
+-    acltype=posixac (LP: #1567558)
+-    - zfs: Fix user namespaces uid/gid mapping
+-
+-  * oops when propagating mounts into containers - RIP:
+-    0010:[<ffffffff8123cb3e>] [<ffffffff8123cb3e>] propagate_one+0xbe/0x1c0
+-    (LP: #1572316)
+-    - fs/pnode.c: treat zero mnt_group_id-s as unequal
+-    - propogate_mnt: Handle the first propogated copy being a slave
+-
+-  * OOPS on wily+ for Haswell-ULT and Broadwell (LP: #1577748)
+-    - PNP: Add Broadwell to Intel MCH size workaround
+-    - PNP: Add Haswell-ULT to Intel MCH size workaround
+-
+-  * Xenial update to v4.4.9 stable release (LP: #1578798)
+-    - block: loop: fix filesystem corruption in case of aio/dio
+-    - x86/mce: Avoid using object after free in genpool
+-    - kvm: x86: do not leak guest xcr0 into host interrupt handlers
+-    - ARM: dts: AM43x-epos: Fix clk parent for synctimer
+-    - ARM: mvebu: Correct unit address for linksys
+-    - ARM: OMAP2: Fix up interconnect barrier initialization for DRA7
+-    - ARM: OMAP2+: hwmod: Fix updating of sysconfig register
+-    - assoc_array: don't call compare_object() on a node
+-    - usb: xhci: applying XHCI_PME_STUCK_QUIRK to Intel BXT B0 host
+-    - xhci: resume USB 3 roothub first
+-    - usb: xhci: fix wild pointers in xhci_mem_cleanup
+-    - xhci: fix 10 second timeout on removal of PCI hotpluggable xhci controllers
+-    - usb: hcd: out of bounds access in for_each_companion
+-    - usb: gadget: f_fs: Fix use-after-free
+-    - dm cache metadata: fix READ_LOCK macros and cleanup WRITE_LOCK macros
+-    - dm cache metadata: fix cmd_read_lock() acquiring write lock
+-    - lib: lz4: fixed zram with lz4 on big endian machines
+-    - debugfs: Make automount point inodes permanently empty
+-    - dmaengine: dw: fix master selection
+-    - dmaengine: hsu: correct use of channel status register
+-    - dmaengine: pxa_dma: fix the maximum requestor line
+-    - sched/cgroup: Fix/cleanup cgroup teardown/init
+-    - x86/mm/xen: Suppress hugetlbfs in PV guests
+-    - x86 EDAC, sb_edac.c: Repair damage introduced when "fixing" channel address
+-    - ALSA: hda - Don't trust the reported actual power state
+-    - ALSA: hda/realtek - Add ALC3234 headset mode for Optiplex 9020m
+-    - ALSA: hda - Keep powering up ADCs on Cirrus codecs
+-    - ALSA: hda - add PCI ID for Intel Broxton-T
+-    - ALSA: pcxhr: Fix missing mutex unlock
+-    - ALSA: hda - Add dock support for ThinkPad X260
+-    - asm-generic/futex: Re-enable preemption in futex_atomic_cmpxchg_inatomic()
+-    - futex: Handle unlock_pi race gracefully
+-    - futex: Acknowledge a new waiter in counter before plist
+-    - drm/nouveau/core: use vzalloc for allocating ramht
+-    - drm/qxl: fix cursor position with non-zero hotspot
+-    - drm/i915: Fix race condition in intel_dp_destroy_mst_connector()
+-    - Revert "drm/radeon: disable runtime pm on PX laptops without dGPU power
+-      control"
+-    - Revert "drm/amdgpu: disable runtime pm on PX laptops without dGPU power
+-      control"
+-    - cpufreq: intel_pstate: Fix processing for turbo activation ratio
+-    - iwlwifi: pcie: lower the debug level for RSA semaphore access
+-    - iwlwifi: mvm: fix memory leak in paging
+-    - crypto: ccp - Prevent information leakage on export
+-    - crypto: sha1-mb - use corrcet pointer while completing jobs
+-    - crypto: talitos - fix crash in talitos_cra_init()
+-    - crypto: talitos - fix AEAD tcrypt tests
+-    - powerpc: scan_features() updates incorrect bits for REAL_LE
+-    - powerpc: Update cpu_user_features2 in scan_features()
+-    - powerpc: Update TM user feature bits in scan_features()
+-    - nl80211: check netlink protocol in socket release notification
+-    - netlink: don't send NETLINK_URELEASE for unbound sockets
+-    - Input: pmic8xxx-pwrkey - fix algorithm for converting trigger delay
+-    - xen kconfig: don't "select INPUT_XEN_KBDDEV_FRONTEND"
+-    - pinctrl: mediatek: correct debounce time unit in mtk_gpio_set_debounce
+-    - pinctrl: single: Fix pcs_parse_bits_in_pinctrl_entry to use __ffs than ffs
+-    - iommu/amd: Fix checking of pci dma aliases
+-    - iommu/dma: Restore scatterlist offsets correctly
+-    - drm/amdgpu: when suspending, if uvd/vce was running. need to cancel delay
+-      work.
+-    - drm/amdgpu: use defines for CRTCs and AMFT blocks
+-    - drm/amdgpu: bump the afmt limit for CZ, ST, Polaris
+-    - amdgpu/uvd: add uvd fw version for amdgpu
+-    - drm/amdgpu: fix regression on CIK (v2)
+-    - drm/radeon: add a quirk for a XFX R9 270X
+-    - drm/radeon: fix initial connector audio value
+-    - drm/radeon: forbid mapping of userptr bo through radeon device file
+-    - drm/radeon: fix vertical bars appear on monitor (v2)
+-    - drm: Loongson-3 doesn't fully support wc memory
+-    - drm/nouveau/gr/gf100: select a stream master to fixup tfb offset queries
+-    - drm/dp/mst: Validate port in drm_dp_payload_send_msg()
+-    - drm/dp/mst: Restore primary hub guid on resume
+-    - drm/dp/mst: Get validated port ref in drm_dp_update_payload_part1()
+-    - pwm: brcmstb: Fix check of devm_ioremap_resource() return code
+-    - drm/i915: Cleanup phys status page too
+-    - drm/i915: skl_update_scaler() wants a rotation bitmask instead of bit number
+-    - drm/amdkfd: uninitialized variable in dbgdev_wave_control_set_registers()
+-    - drm/i915: Fixup the free space logic in ring_prepare
+-    - drm/i915: Use fw_domains_put_with_fifo() on HSW
+-    - perf intel-pt: Fix segfault tracing transactions
+-    - i2c: cpm: Fix build break due to incompatible pointer types
+-    - i2c: exynos5: Fix possible ABBA deadlock by keeping I2C clock prepared
+-    - toshiba_acpi: Fix regression caused by hotkey enabling value
+-    - EDAC: i7core, sb_edac: Don't return NOTIFY_BAD from mce_decoder callback
+-    - ASoC: s3c24xx: use const snd_soc_component_driver pointer
+-    - ASoC: ssm4567: Reset device before regcache_sync()
+-    - ASoC: dapm: Make sure we have a card when displaying component widgets
+-    - ASoC: rt5640: Correct the digital interface data select
+-    - vb2-memops: Fix over allocation of frame vectors
+-    - v4l2-dv-timings.h: fix polarity for 4k formats
+-    - cxl: Keep IRQ mappings on context teardown
+-    - IB/mlx5: Expose correct max_sge_rd limit
+-    - IB/security: Restrict use of the write() interface
+-    - efi: Fix out-of-bounds read in variable_matches()
+-    - efi: Expose non-blocking set_variable() wrapper to efivars
+-    - x86/apic: Handle zero vector gracefully in clear_vector_irq()
+-    - workqueue: fix ghost PENDING flag while doing MQ IO
+-    - slub: clean up code for kmem cgroup support to kmem_cache_free_bulk
+-    - cgroup, cpuset: replace cpuset_post_attach_flush() with
+-      cgroup_subsys->post_attach callback
+-    - memcg: relocate charge moving from ->attach to ->post_attach
+-    - mm/huge_memory: replace VM_NO_THP VM_BUG_ON with actual VMA check
+-    - numa: fix /proc/<pid>/numa_maps for THP
+-    - mm: vmscan: reclaim highmem zone if buffer_heads is over limit
+-    - mm/hwpoison: fix wrong num_poisoned_pages accounting
+-    - cgroup: make sure a parent css isn't freed before its children
+-    - videobuf2-core: Check user space planes array in dqbuf
+-    - videobuf2-v4l2: Verify planes array in buffer dequeueing
+-    - Revert "regulator: core: Fix nested locking of supplies"
+-    - regulator: core: fix regulator_lock_supply regression
+-    - regulator: core: Ensure we lock all regulators
+-    - regulator: core: Fix nested locking of supplies
+-    - locking/mcs: Fix mcs_spin_lock() ordering
+-    - spi/rockchip: Make sure spi clk is on in rockchip_spi_set_cs
+-    - irqchip/sunxi-nmi: Fix error check of of_io_request_and_map()
+-    - irqchip/mxs: Fix error check of of_io_request_and_map()
+-    - regulator: s5m8767: fix get_register() error handling
+-    - paride: make 'verbose' parameter an 'int' again
+-    - scsi_dh: force modular build if SCSI is a module
+-    - fbdev: da8xx-fb: fix videomodes of lcd panels
+-    - misc/bmp085: Enable building as a module
+-    - misc: mic/scif: fix wrap around tests
+-    - PM / OPP: Initialize u_volt_min/max to a valid value
+-    - PM / Domains: Fix removal of a subdomain
+-    - rtc: hym8563: fix invalid year calculation
+-    - rtc: vr41xx: Wire up alarm_irq_enable
+-    - rtc: ds1685: passing bogus values to irq_restore
+-    - rtc: rx8025: remove rv8803 id
+-    - rtc: max77686: Properly handle regmap_irq_get_virq() error code
+-    - drivers/misc/ad525x_dpot: AD5274 fix RDAC read back errors
+-    - perf evlist: Reference count the cpu and thread maps at set_maps()
+-    - x86/mm/kmmio: Fix mmiotrace for hugepages
+-    - ext4: fix NULL pointer dereference in ext4_mark_inode_dirty()
+-    - serial: sh-sci: Remove cpufreq notifier to fix crash/deadlock
+-    - mtd: spi-nor: remove micron_quad_enable()
+-    - mtd: brcmnand: Fix v7.1 register offsets
+-    - mtd: nand: Drop mtd.owner requirement in nand_scan
+-    - perf hists browser: Only offer symbol scripting when a symbol is under the
+-      cursor
+-    - perf tools: handle spaces in file names obtained from /proc/pid/maps
+-    - perf stat: Document --detailed option
+-    - ext4: fix races between page faults and hole punching
+-    - ext4: move unlocked dio protection from ext4_alloc_file_blocks()
+-    - ext4: fix races between buffered IO and collapse / insert range
+-    - ext4: fix races of writeback with punch hole and zero range
+-    - ARM: OMAP3: Add cpuidle parameters table for omap3430
+-    - ARM: prima2: always enable reset controller
+-    - ARM: EXYNOS: select THERMAL_OF
+-    - ARM: dts: armada-375: use armada-370-sata for SATA
+-    - ARM: dts: pxa: fix dma engine node to pxa3xx-nand
+-    - bus: imx-weim: Take the 'status' property value into account
+-    - jme: Do not enable NIC WoL functions on S0
+-    - jme: Fix device PM wakeup API usage
+-    - unbreak allmodconfig KCONFIG_ALLCONFIG=...
+-    - thermal: rockchip: fix a impossible condition caused by the warning
+-    - sunrpc/cache: drop reference when sunrpc_cache_pipe_upcall() detects a race
+-    - megaraid_sas: add missing curly braces in ioctl handler
+-    - stm class: Select CONFIG_SRCU
+-    - extcon: max77843: Use correct size for reading the interrupt register
+-    - Linux 4.4.9
+-
+-  * Stoney powerplay support (LP: #1578305)
+-    - amdgpu/powerplay: Add Stoney to list of early init cases
+-
+-  * CVE-2016-2117 (LP: #1561403)
+-    - atl2: Disable unimplemented scatter/gather feature
+-
+-  * CVE-2016-2187 (LP: #1575706)
+-    - Input: gtco - fix crash on detecting device without endpoints
+-
+-  * zfs posix default permissions lost on reboot or unmount (LP: #1574801)
+-    - Fix ZPL miswrite of default POSIX ACL
+-
+-  * WARNING: at /build/linux-aWXT0l/linux-4.4.0/drivers/pci/pci.c:1595
+-    [travis3EN] (LP: #1574697)
+-    - net/mlx4_core: Implement pci_resume callback
+-    - net/mlx4_core: Avoid repeated calls to pci enable/disable
+-
+-  * Add support to thinkpad keyboard backlight (LP: #1574498)
+-    - thinkpad_acpi: Add support for keyboard backlight
+-
+-  * Please enable kconfig X86_LEGACY_VM86 for i386 (LP: #1499089)
+-    - [Config] CONFIG_VM86=y, CONFIG_X86_LEGACY_VM86=y
+-
+-  * Miscellaneous Ubuntu changes
+-    - updateconfigs for Linux v4.4.9
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Mon, 16 May 2016 15:16:29 -0700
+-
+-linux (4.4.0-22.40) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * CVE-2016-3713 (LP: #1581201)
+-    - SAUCE: KVM: MTRR: remove MSR 0x2f8
+-
+-  * CVE-2016-0758 (LP: #1581202)
+-    - SAUCE: KEYS: Fix ASN.1 indefinite length object parsing
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Thu, 12 May 2016 13:38:45 -0700
+-
+-linux (4.4.0-22.39) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1578721
+-
+-  * LP: #1578705
+-    - bpf: fix double-fdput in replace_map_fd_with_map_ptr()
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Thu, 05 May 2016 09:30:58 -0700
+-
+-linux (4.4.0-22.38) xenial; urgency=low
+-
+-  [ Kamal Mostafa ]
+-
+-  * Release Tracking Bug
+-    - LP: #1573817
+-
+-  * autoreconstruct: need to also generate extend-diff-ignore options for links
+-    (LP: #1574362)
+-    - [Packaging] autoreconstruct -- generate extend-diff-ignore for links
+-
+-  * tipc: missing linearization of sk_buff (LP: #1567064)
+-    - tipc: move linearization of buffers to generic code
+-
+-  * [Hyper-V] In-flight PCI Passthrough Patches (LP: #1570124)
+-    - SAUCE:(noup) drivers:hv: Lock access to hyperv_mmio resource tree
+-    - SAUCE:(noup) drivers:hv: Call vmbus_mmio_free() to reverse
+-      vmbus_mmio_allocate()
+-    - SAUCE:(noup) drivers:hv: Reverse order of resources in hyperv_mmio
+-    - SAUCE:(noup) drivers:hv: Track allocations of children of hv_vmbus in
+-      private resource tree
+-    - SAUCE:(noup) drivers:hv: Record MMIO range in use by frame buffer
+-    - SAUCE:(noup) drivers:hv: Separate out frame buffer logic when picking MMIO
+-      range
+-
+-  * vbox: resync with 5.0.18-dfsg-2build1 (LP: #1571156)
+-    - ubuntu: vbox -- update to 5.0.18-dfsg-2build1
+-
+-  * CONFIG_AUFS_XATTR is not set (LP: #1557776)
+-    - [Config] CONFIG_AUFS_XATTR=y
+-
+-  * CVE-2016-3672 (LP: #1568523)
+-    - x86/mm/32: Enable full randomization on i386 and X86_32
+-
+-  * CVE-2016-3955 (LP: #1572666)
+-    - USB: usbip: fix potential out-of-bounds write
+-
+-  * Xenial update to v4.4.8 stable release (LP: #1573034)
+-    - hwmon: (max1111) Return -ENODEV from max1111_read_channel if not
+-      instantiated
+-    - PKCS#7: pkcs7_validate_trust(): initialize the _trusted output argument
+-    - parisc: Avoid function pointers for kernel exception routines
+-    - parisc: Fix kernel crash with reversed copy_from_user()
+-    - parisc: Unbreak handling exceptions from kernel modules
+-    - ALSA: timer: Use mod_timer() for rearming the system timer
+-    - ALSA: hda - Asus N750JV external subwoofer fixup
+-    - ALSA: hda - Fix white noise on Asus N750JV headphone
+-    - ALSA: hda - Apply fix for white noise on Asus N550JV, too
+-    - mm: fix invalid node in alloc_migrate_target()
+-    - powerpc/mm: Fixup preempt underflow with huge pages
+-    - libnvdimm: fix smart data retrieval
+-    - libnvdimm, pfn: fix uuid validation
+-    - compiler-gcc: disable -ftracer for __noclone functions
+-    - arm64: opcodes.h: Add arm big-endian config options before including arm
+-      header
+-    - drm/dp: move hw_mutex up the call stack
+-    - drm/udl: Use unlocked gem unreferencing
+-    - drm/radeon: add a dpm quirk for sapphire Dual-X R7 370 2G D5
+-    - drm/radeon: add another R7 370 quirk
+-    - drm/radeon: add a dpm quirk for all R7 370 parts
+-    - drm/amdgpu/gmc: move vram type fetching into sw_init
+-    - drm/amdgpu/gmc: use proper register for vram type on Fiji
+-    - xen/events: Mask a moving irq
+-    - tcp: convert cached rtt from usec to jiffies when feeding initial rto
+-    - tunnel: Clear IPCB(skb)->opt before dst_link_failure called
+-    - net: jme: fix suspend/resume on JMC260
+-    - net: vrf: Remove direct access to skb->data
+-    - net: qca_spi: Don't clear IFF_BROADCAST
+-    - net: qca_spi: clear IFF_TX_SKB_SHARING
+-    - net: fix bridge multicast packet checksum validation
+-    - sctp: lack the check for ports in sctp_v6_cmp_addr
+-    - mld, igmp: Fix reserved tailroom calculation
+-    - tipc: Revert "tipc: use existing sk_write_queue for outgoing packet chain"
+-    - qmi_wwan: add Sierra Wireless EM74xx device ID
+-    - ipv6: re-enable fragment header matching in ipv6_find_hdr
+-    - vxlan: fix missing options_len update on RX with collect metadata
+-    - cdc_ncm: toggle altsetting to force reset before setup
+-    - udp6: fix UDP/IPv6 encap resubmit path
+-    - tcp: fix tcpi_segs_in after connection establishment
+-    - ppp: release rtnl mutex when interface creation fails
+-    - net: validate variable length ll headers
+-    - ax25: add link layer header validation function
+-    - packet: validate variable length ll headers
+-    - bpf: avoid copying junk bytes in bpf_get_current_comm()
+-    - sh_eth: fix NULL pointer dereference in sh_eth_ring_format()
+-    - sh_eth: advance 'rxdesc' later in sh_eth_ring_format()
+-    - qlcnic: Remove unnecessary usage of atomic_t
+-    - qlcnic: Fix mailbox completion handling during spurious interrupt
+-    - macvtap: always pass ethernet header in linear
+-    - mlxsw: spectrum: Check requested ageing time is valid
+-    - rocker: set FDB cleanup timer according to lowest ageing time
+-    - bridge: allow zero ageing time
+-    - ipv4: Don't do expensive useless work during inetdev destroy.
+-    - net: Fix use after free in the recvmmsg exit path
+-    - mlx4: add missing braces in verify_qp_parameters
+-    - farsync: fix off-by-one bug in fst_add_one
+-    - ath9k: fix buffer overrun for ar9287
+-    - ppp: ensure file->private_data can't be overridden
+-    - tcp/dccp: remove obsolete WARN_ON() in icmp handlers
+-    - qlge: Fix receive packets drop.
+-    - net: bcmgenet: fix dma api length mismatch
+-    - bonding: fix bond_get_stats()
+-    - ipv4: fix broadcast packets reception
+-    - ipv4: initialize flowi4_flags before calling fib_lookup()
+-    - ppp: take reference on channels netns
+-    - xfrm: Fix crash observed during device unregistration and decryption
+-    - qmi_wwan: add "D-Link DWM-221 B1" device id
+-    - ipv6: udp: fix UDP_MIB_IGNOREDMULTI updates
+-    - bridge: Allow set bridge ageing time when switchdev disabled
+-    - rtnl: fix msg size calculation in if_nlmsg_size()
+-    - tun, bpf: fix suspicious RCU usage in tun_{attach, detach}_filter
+-    - tuntap: restore default qdisc
+-    - ipv4: l2tp: fix a potential issue in l2tp_ip_recv
+-    - ipv6: l2tp: fix a potential issue in l2tp_ip6_recv
+-    - ip6_tunnel: set rtnl_link_ops before calling register_netdevice
+-    - ipv6: Count in extension headers in skb->network_header
+-    - mpls: find_outdev: check for err ptr in addition to NULL check
+-    - USB: uas: Limit qdepth at the scsi-host level
+-    - USB: uas: Add a new NO_REPORT_LUNS quirk
+-    - cdc-acm: fix NULL pointer reference
+-    - KVM: x86: Inject pending interrupt even if pending nmi exist
+-    - KVM: x86: reduce default value of halt_poll_ns parameter
+-    - MIPS: Fix MSA ld unaligned failure cases
+-    - pinctrl: pistachio: fix mfio84-89 function description and pinmux.
+-    - pinctrl: sh-pfc: only use dummy states for non-DT platforms
+-    - pinctrl: sunxi: Fix A33 external interrupts not working
+-    - pinctrl: nomadik: fix pull debug print inversion
+-    - pinctrl: freescale: imx: fix bogus check of of_iomap() return value
+-    - au0828: fix au0828_v4l2_close() dev_state race condition
+-    - au0828: Fix dev_state handling
+-    - coda: fix error path in case of missing pdata on non-DT platform
+-    - v4l: vsp1: Set the SRU CTRL0 register when starting the stream
+-    - pcmcia: db1xxx_ss: fix last irq_to_gpio user
+-    - rbd: use GFP_NOIO consistently for request allocations
+-    - virtio: virtio 1.0 cs04 spec compliance for reset
+-    - mac80211: properly deal with station hashtable insert errors
+-    - mac80211: avoid excessive stack usage in sta_info
+-    - mac80211: fix ibss scan parameters
+-    - mac80211: fix unnecessary frame drops in mesh fwding
+-    - mac80211: fix txq queue related crashes
+-    - usb: renesas_usbhs: avoid NULL pointer derefernce in usbhsf_pkt_handler()
+-    - usb: renesas_usbhs: disable TX IRQ before starting TX DMAC transfer
+-    - usb: renesas_usbhs: fix to avoid using a disabled ep in usbhsg_queue_done()
+-    - iio: st_magn: always define ST_MAGN_TRIGGER_SET_STATE
+-    - iio: accel: bmc150: fix endianness when reading axes
+-    - iio: gyro: bmg160: fix buffer read values
+-    - iio: gyro: bmg160: fix endianness when reading axes
+-    - sd: Fix excessive capacity printing on devices with blocks bigger than 512
+-      bytes
+-    - fs: add file_dentry()
+-    - nfs: use file_dentry()
+-    - btrfs: fix crash/invalid memory access on fsync when using overlayfs
+-    - ext4: add lockdep annotations for i_data_sem
+-    - ext4: ignore quota mount options if the quota feature is enabled
+-    - iommu: Don't overwrite domain pointer when there is no default_domain
+-    - Btrfs: fix file/data loss caused by fsync after rename and new inode
+-    - arm64: replace read_lock to rcu lock in call_step_hook
+-    - perf: Do not double free
+-    - perf: Cure event->pending_disable race
+-    - mmc: sdhci-pci: Add support and PCI IDs for more Broxton host controllers
+-    - ALSA: hda - Fixup speaker pass-through control for nid 0x14 on ALC225
+-    - ALSA: hda - Fix headset support and noise on HP EliteBook 755 G2
+-    - ALSA: hda/realtek - Enable the ALC292 dock fixup on the Thinkpad T460s
+-    - ALSA: usb-audio: Add a sample rate quirk for Phoenix Audio TMX320
+-    - ALSA: usb-audio: Add a quirk for Plantronics BT300
+-    - ALSA: usb-audio: Skip volume controls triggers hangup on Dell USB Dock
+-    - HID: wacom: fix Bamboo ONE oops
+-    - HID: usbhid: fix inconsistent reset/resume/reset-resume behavior
+-    - Revert "x86/PCI: Don't alloc pcibios-irq when MSI is enabled"
+-    - Revert "PCI: Add helpers to manage pci_dev->irq and pci_dev->irq_managed"
+-    - Revert "PCI, x86: Implement pcibios_alloc_irq() and pcibios_free_irq()"
+-    - staging: android: ion: Set the length of the DMA sg entries in buffer
+-    - usbvision: fix crash on detecting device with invalid configuration
+-    - Revert "usb: hub: do not clear BOS field during reset device"
+-    - Linux 4.4.8
+-
+-  * Fix speaker volume on a Dell machine (LP: #1549660)
+-    - ALSA: hda - Fixup speaker pass-through control for nid 0x14 on ALC225
+-
+-  * Xenial update to v4.4.7 stable release (LP: #1572722)
+-    - regulator: core: avoid unused variable warning
+-    - regulator: core: Fix nested locking of supplies
+-    - ASoC: samsung: pass DMA channels as pointers
+-    - mmc: sh_mmcif: rework dma channel handling
+-    - mmc: sh_mmcif: Correct TX DMA channel allocation
+-    - x86/microcode/intel: Make early loader look for builtin microcode too
+-    - x86/microcode: Untangle from BLK_DEV_INITRD
+-    - x86/entry/compat: Keep TS_COMPAT set during signal delivery
+-    - perf/x86/intel: Add definition for PT PMI bit
+-    - x86/PCI: Mark Broadwell-EP Home Agent & PCU as having non-compliant BARs
+-    - KVM: i8254: change PIT discard tick policy
+-    - KVM: fix spin_lock_init order on x86
+-    - KVM: VMX: avoid guest hang on invalid invept instruction
+-    - KVM: VMX: avoid guest hang on invalid invvpid instruction
+-    - KVM: VMX: fix nested vpid for old KVM guests
+-    - perf/core: Fix perf_sched_count derailment
+-    - perf tools: Dont stop PMU parsing on alias parse error
+-    - perf tools: Fix checking asprintf return value
+-    - perf tools: Fix python extension build
+-    - sched/cputime: Fix steal_account_process_tick() to always return jiffies
+-    - sched/preempt, sh: kmap_coherent relies on disabled preemption
+-    - EDAC, amd64_edac: Shift wrapping issue in f1x_get_norm_dct_addr()
+-    - s390: fix floating pointer register corruption (again)
+-    - s390/cpumf: add missing lpp magic initialization
+-    - pinctrl-bcm2835: Fix cut-and-paste error in "pull" parsing
+-    - PCI: Disable IO/MEM decoding for devices with non-compliant BARs
+-    - PCI: ACPI: IA64: fix IO port generic range check
+-    - x86/irq: Cure live lock in fixup_irqs()
+-    - x86/apic: Fix suspicious RCU usage in smp_trace_call_function_interrupt()
+-    - x86/iopl/64: Properly context-switch IOPL on Xen PV
+-    - x86/iopl: Fix iopl capability check on Xen PV
+-    - x86/mm: TLB_REMOTE_SEND_IPI should count pages
+-    - sg: fix dxferp in from_to case
+-    - aacraid: Fix RRQ overload
+-    - aacraid: Fix memory leak in aac_fib_map_free
+-    - aacraid: Set correct msix count for EEH recovery
+-    - sd: Fix discard granularity when LBPRZ=1
+-    - scsi: storvsc: fix SRB_STATUS_ABORTED handling
+-    - be2iscsi: set the boot_kset pointer to NULL in case of failure
+-    - aic7xxx: Fix queue depth handling
+-    - libnvdimm: Fix security issue with DSM IOCTL.
+-    - dm snapshot: disallow the COW and origin devices from being identical
+-    - dm: fix excessive dm-mq context switching
+-    - dm thin metadata: don't issue prefetches if a transaction abort has failed
+-    - dm cache: make sure every metadata function checks fail_io
+-    - dm: fix rq_end_stats() NULL pointer in dm_requeue_original_request()
+-    - usb: retry reset if a device times out
+-    - usb: hub: fix a typo in hub_port_init() leading to wrong logic
+-    - USB: uas: Reduce can_queue to MAX_CMNDS
+-    - USB: cdc-acm: more sanity checking
+-    - USB: iowarrior: fix oops with malicious USB descriptors
+-    - USB: usb_driver_claim_interface: add sanity checking
+-    - USB: mct_u232: add sanity checking in probe
+-    - USB: digi_acceleport: do sanity checking for the number of ports
+-    - USB: cypress_m8: add endpoint sanity check
+-    - USB: serial: cp210x: Adding GE Healthcare Device ID
+-    - USB: serial: ftdi_sio: Add support for ICP DAS I-756xU devices
+-    - USB: option: add "D-Link DWM-221 B1" device id
+-    - pwc: Add USB id for Philips Spc880nc webcam
+-    - Input: powermate - fix oops with malicious USB descriptors
+-    - ALSA: usb-audio: Fix NULL dereference in create_fixed_stream_quirk()
+-    - ALSA: usb-audio: Add sanity checks for endpoint accesses
+-    - ALSA: usb-audio: add Microsoft HD-5001 to quirks
+-    - ALSA: usb-audio: Minor code cleanup in create_fixed_stream_quirk()
+-    - ALSA: usb-audio: Fix double-free in error paths after
+-      snd_usb_add_audio_stream() call
+-    - Bluetooth: btusb: Add new AR3012 ID 13d3:3395
+-    - Bluetooth: btusb: Add a new AR3012 ID 04ca:3014
+-    - Bluetooth: btusb: Add a new AR3012 ID 13d3:3472
+-    - crypto: ccp - Add hash state import and export support
+-    - crypto: ccp - Limit the amount of information exported
+-    - crypto: ccp - Don't assume export/import areas are aligned
+-    - crypto: ccp - memset request context to zero during import
+-    - crypto: keywrap - memzero the correct memory
+-    - crypto: atmel - fix checks of error code returned by devm_ioremap_resource()
+-    - crypto: ux500 - fix checks of error code returned by devm_ioremap_resource()
+-    - crypto: marvell/cesa - forward devm_ioremap_resource() error code
+-    - X.509: Fix leap year handling again
+-    - mei: bus: check if the device is enabled before data transfer
+-    - HID: logitech: fix Dual Action gamepad support
+-    - HID: i2c-hid: fix OOB write in i2c_hid_set_or_send_report()
+-    - HID: multitouch: force retrieving of Win8 signature blob
+-    - HID: fix hid_ignore_special_drivers module parameter
+-    - staging: comedi: ni_tiocmd: change mistaken use of start_src for start_arg
+-    - staging: android: ion_test: fix check of platform_device_register_simple()
+-      error code
+-    - staging: comedi: ni_mio_common: fix the ni_write[blw]() functions
+-    - tty: Fix GPF in flush_to_ldisc(), part 2
+-    - net: irda: Fix use-after-free in irtty_open()
+-    - 8250: use callbacks to access UART_DLL/UART_DLM
+-    - saa7134: Fix bytesperline not being set correctly for planar formats
+-    - adv7511: TX_EDID_PRESENT is still 1 after a disconnect
+-    - bttv: Width must be a multiple of 16 when capturing planar formats
+-    - coda: fix first encoded frame payload
+-    - media: v4l2-compat-ioctl32: fix missing length copy in put_v4l2_buffer32
+-    - mtip32xx: Avoid issuing standby immediate cmd during FTL rebuild
+-    - mtip32xx: Fix broken service thread handling
+-    - mtip32xx: Remove unwanted code from taskfile error handler
+-    - mtip32xx: Print exact time when an internal command is interrupted
+-    - mtip32xx: Fix for rmmod crash when drive is in FTL rebuild
+-    - mtip32xx: Handle safe removal during IO
+-    - mtip32xx: Handle FTL rebuild failure state during device initialization
+-    - mtip32xx: Implement timeout handler
+-    - mtip32xx: Cleanup queued requests after surprise removal
+-    - ALSA: pcm: Avoid "BUG:" string for warnings again
+-    - ALSA: intel8x0: Add clock quirk entry for AD1981B on IBM ThinkPad X41.
+-    - ALSA: hda - Don't handle ELD notify from invalid port
+-    - ALSA: hda - fix the mic mute button and led problem for a Lenovo AIO
+-    - ALSA: hda - Fix unconditional GPIO toggle via automute
+-    - tools/hv: Use include/uapi with __EXPORTED_HEADERS__
+-    - jbd2: fix FS corruption possibility in jbd2_journal_destroy() on umount path
+-    - brd: Fix discard request processing
+-    - IB/srpt: Simplify srpt_handle_tsk_mgmt()
+-    - bcache: cleaned up error handling around register_cache()
+-    - bcache: fix race of writeback thread starting before complete initialization
+-    - bcache: fix cache_set_flush() NULL pointer dereference on OOM
+-    - mm: memcontrol: reclaim when shrinking memory.high below usage
+-    - mm: memcontrol: reclaim and OOM kill when shrinking memory.max below usage
+-    - ia64: define ioremap_uc()
+-    - watchdog: don't run proc_watchdog_update if new value is same as old
+-    - watchdog: rc32434_wdt: fix ioctl error handling
+-    - Bluetooth: Add new AR3012 ID 0489:e095
+-    - Bluetooth: Fix potential buffer overflow with Add Advertising
+-    - cgroup: ignore css_sets associated with dead cgroups during migration
+-    - net: mvneta: enable change MAC address when interface is up
+-    - of: alloc anywhere from memblock if range not specified
+-    - vfs: show_vfsstat: do not ignore errors from show_devname method
+-    - splice: handle zero nr_pages in splice_to_pipe()
+-    - xtensa: ISS: don't hang if stdin EOF is reached
+-    - xtensa: fix preemption in {clear,copy}_user_highpage
+-    - xtensa: clear all DBREAKC registers on start
+-    - ARC: [BE] readl()/writel() to work in Big Endian CPU configuration
+-    - ARC: bitops: Remove non relevant comments
+-    - quota: Fix possible GPF due to uninitialised pointers
+-    - xfs: fix two memory leaks in xfs_attr_list.c error paths
+-    - raid1: include bio_end_io_list in nr_queued to prevent freeze_array hang
+-    - md/raid5: Compare apples to apples (or sectors to sectors)
+-    - RAID5: check_reshape() shouldn't call mddev_suspend
+-    - RAID5: revert e9e4c377e2f563 to fix a livelock
+-    - raid10: include bio_end_io_list in nr_queued to prevent freeze_array hang
+-    - md/raid5: preserve STRIPE_PREREAD_ACTIVE in break_stripe_batch_list
+-    - md: multipath: don't hardcopy bio in .make_request path
+-    - Revert "UBUNTU: SAUCE: (noup) fuse: Add reference counting for fuse_io_priv"
+-    - Revert "UBUNTU: SAUCE: (noup) fuse: do not use iocb after it may have been
+-      freed"
+-    - fuse: do not use iocb after it may have been freed
+-    - fuse: Add reference counting for fuse_io_priv
+-    - fs/coredump: prevent fsuid=0 dumps into user-controlled directories
+-    - rapidio/rionet: fix deadlock on SMP
+-    - ipr: Fix out-of-bounds null overwrite
+-    - ipr: Fix regression when loading firmware
+-    - iwlwifi: mvm: Fix paging memory leak
+-    - drm/radeon: disable runtime pm on PX laptops without dGPU power control
+-    - drm/radeon: Don't drop DP 2.7 Ghz link setup on some cards.
+-    - drm/amdgpu: disable runtime pm on PX laptops without dGPU power control
+-    - drm/amdgpu: include the right version of gmc header files for iceland
+-    - IB/ipoib: fix for rare multicast join race condition
+-    - tracing: Have preempt(irqs)off trace preempt disabled functions
+-    - tracing: Fix crash from reading trace_pipe with sendfile
+-    - tracing: Fix trace_printk() to print when not using bprintk()
+-    - bitops: Do not default to __clear_bit() for __clear_bit_unlock()
+-    - scripts/coccinelle: modernize &
+-    - scripts/kconfig: allow building with make 3.80 again
+-    - kbuild/mkspec: fix grub2 installkernel issue
+-    - MAINTAINERS: Update mailing list and web page for hwmon subsystem
+-    - ideapad-laptop: Add ideapad Y700 (15) to the no_hw_rfkill DMI list
+-    - mmc: block: fix ABI regression of mmc_blk_ioctl
+-    - mmc: mmc_spi: Add Card Detect comments and fix CD GPIO case
+-    - mmc: sdhci: fix data timeout (part 1)
+-    - mmc: sdhci: fix data timeout (part 2)
+-    - mmc: sdhci: Fix override of timeout clk wrt max_busy_timeout
+-    - clk: rockchip: rk3368: fix cpuclk mux bit of big cpu-cluster
+-    - clk: rockchip: rk3368: fix cpuclk core dividers
+-    - clk: rockchip: rk3368: fix parents of video encoder/decoder
+-    - clk: rockchip: rk3368: fix hdmi_cec gate-register
+-    - clk: rockchip: add hclk_cpubus to the list of rk3188 critical clocks
+-    - clk: bcm2835: Fix setting of PLL divider clock rates
+-    - target: Fix target_release_cmd_kref shutdown comp leak
+-    - iser-target: Fix identification of login rx descriptor type
+-    - iser-target: Add new state ISER_CONN_BOUND to isert_conn
+-    - iser-target: Separate flows for np listeners and connections cma events
+-    - iser-target: Rework connection termination
+-    - nfsd4: fix bad bounds checking
+-    - nfsd: fix deadlock secinfo+readdir compound
+-    - ARM: dts: at91: sama5d3 Xplained: don't disable hsmci regulator
+-    - ARM: dts: at91: sama5d4 Xplained: don't disable hsmci regulator
+-    - ACPI / PM: Runtime resume devices when waking from hibernate
+-    - writeback, cgroup: fix premature wb_put() in
+-      locked_inode_to_wb_and_lock_list()
+-    - writeback, cgroup: fix use of the wrong bdi_writeback which mismatches the
+-      inode
+-    - Revert "UBUNTU: SAUCE: (noup) Input: synaptics - handle spurious release of
+-      trackstick buttons, again"
+-    - Input: synaptics - handle spurious release of trackstick buttons, again
+-    - Input: ims-pcu - sanity check against missing interfaces
+-    - Input: ati_remote2 - fix crashes on detecting device with invalid descriptor
+-    - ocfs2/dlm: fix race between convert and recovery
+-    - ocfs2/dlm: fix BUG in dlm_move_lockres_to_recovery_list
+-    - mm/page_alloc: prevent merging between isolated and other pageblocks
+-    - mtd: onenand: fix deadlock in onenand_block_markbad
+-    - PM / sleep: Clear pm_suspend_global_flags upon hibernate
+-    - scsi_common: do not clobber fixed sense information
+-    - sched/cputime: Fix steal time accounting vs. CPU hotplug
+-    - perf/x86/pebs: Add workaround for broken OVFL status on HSW+
+-    - perf/x86/intel: Fix PEBS warning by only restoring active PMU in pmi
+-    - perf/x86/intel: Fix PEBS data source interpretation on Nehalem/Westmere
+-    - Linux 4.4.7
+-
+-  * QCA9565 / AR9565 bluetooth not work (LP: #1542944)
+-    - Bluetooth: Add new AR3012 ID 0489:e095
+-
+-  * The mic mute key and led can't work on a Lenovo AIO machine (LP: #1555912)
+-    - ALSA: hda - fix the mic mute button and led problem for a Lenovo AIO
+-
+-  * 13d3:3472 bluetooth not working, 4.2 low latency kernel 14.04.1 on asus ROG
+-    gl552jx (LP: #1552925)
+-    - Bluetooth: btusb: Add a new AR3012 ID 13d3:3472
+-
+-  * Bluetooth cannot detect other devices (Lite-on 3014 + Atheros AR9565)
+-    (LP: #1546694)
+-    - Bluetooth: btusb: Add a new AR3012 ID 04ca:3014
+-
+-  * Atheros AR9462 Bluetooth cannot detect other devices  (LP: #1542564)
+-    - Bluetooth: btusb: Add new AR3012 ID 13d3:3395
+-
+-  * s390/pci: add extra padding to function measurement block (LP: #1572291)
+-    - s390/pci: add extra padding to function measurement block
+-
+-  * CVE-2016-3951 (LP: #1567191)
+-    - cdc_ncm: do not call usbnet_link_change from cdc_ncm_bind
+-    - usbnet: cleanup after bind() in probe()
+-
+-  * linux: Add UEFI keyring for externally signed modules (LP: #1569924)
+-    - efi: Remove redundant efi_set_variable_nonblocking() prototype
+-    - efi/runtime-wrappers: Add a nonblocking version of QueryVariableInfo()
+-    - efi: Add nonblocking option to efi_query_variable_store()
+-    - efi: Add NV memory attribute
+-    - efi: Reformat GUID tables to follow the format in UEFI spec
+-    - efi: stub: implement efi_get_random_bytes() based on EFI_RNG_PROTOCOL
+-    - SAUCE: (noup) Add EFI signature data types
+-    - crypto: KEYS: convert public key and digsig asym to the akcipher api
+-    - [Config] CONFIG_EFI_SIGNATURE_LIST_PARSER=y
+-    - SAUCE: (noup) Add an EFI signature blob parser and key loader.
+-    - [Config] CONFIG_IMA_MOK_KEYRING=y
+-    - IMA: create machine owner and blacklist keyrings
+-    - KEYS: Add an alloc flag to convey the builtinness of a key
+-    - [Config] CONFIG_MODULE_SIG_UEFI=y, CONFIG_SYSTEM_BLACKLIST_KEYRING=y
+-    - SAUCE: (noup) KEYS: Add a system blacklist keyring
+-    - SAUCE: (noup) MODSIGN: Support not importing certs from db
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Config] CONFIG_PUBLIC_KEY_ALGO_RSA=y
+-
+- -- Kamal Mostafa <kamal@canonical.com>  Sun, 24 Apr 2016 12:12:13 -0700
+-
+-linux (4.4.0-21.37) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1571791
+-
+-  * linux: MokSBState is ignored (LP: #1571691)
+-    - SAUCE: (noup) MODSIGN: Import certificates from UEFI Secure Boot
+-    - SAUCE: (noup) efi: Disable secure boot if shim is in insecure mode
+-    - SAUCE: (noup) Display MOKSBState when disabled
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 18 Apr 2016 07:00:22 -0600
+-
+-linux (4.4.0-20.36) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1571069
+-
+-  * sysfs mount failure during stateful lxd snapshots (LP: #1570906)
+-    - SAUCE: kernfs: Do not match superblock in another user namespace when
+-      mounting
+-
+-  * Kernel Panic in Ubuntu 16.04 netboot installer (LP: #1570441)
+-    - x86/topology: Fix logical package mapping
+-    - x86/topology: Fix Intel HT disable
+-    - x86/topology: Use total_cpus not nr_cpu_ids for logical packages
+-    - xen/apic: Provide Xen-specific version of cpu_present_to_apicid APIC op
+-    - x86/topology: Fix AMD core count
+-
+-  * [regression]: Failed to call clock_adjtime(): Invalid argument
+-    (LP: #1566465)
+-    - ntp: Fix ADJ_SETOFFSET being used w/ ADJ_NANO
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 14 Apr 2016 06:31:56 -0600
+-
+-linux (4.4.0-19.35) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1570348
+-
+-  * CVE-2016-2847 (LP: #1554260)
+-    - pipe: limit the per-user amount of pages allocated in pipes
+-
+-  * xenial kernel crash on HP BL460c G7 (qla24xx problem?) (LP: #1554003)
+-    - SAUCE: (noup) qla2xxx: Add irq affinity notification V2
+-
+-  * arm64: guest hangs when ntpd is running (LP: #1549494)
+-    - SAUCE: (noup) KVM: arm/arm64: Handle forward time correction gracefully
+-
+-  * linux: Enforce signed module loading when UEFI secure boot (LP: #1566221)
+-    - [Config] CONFIG_EFI_SECURE_BOOT_SIG_ENFORCE=y
+-
+-  * s390/cpumf: Fix lpp detection (LP: #1555344)
+-    - s390/facilities: use stfl mnemonic instead of insn magic
+-    - s390/facilities: always use lowcore's stfle field for storing facility bits
+-    - s390/cpumf: Fix lpp detection
+-
+-  * s390x kernel image needs weightwatchers (LP: #1536245)
+-    - [Config] s390x: Use compressed kernel bzImage
+-
+-  * Surelock GA2 SP1: surelock02p05: Not seeing sgX devices for LUNs after
+-    upgrading to Ubuntu 16.04 (LP: #1567581)
+-    - Revert "UBUNTU: SAUCE: (noup) powerpc/pci: Assign fixed PHB number based on
+-      device-tree properties"
+-
+-  * Backport upstream bugfixes to ubuntu-16.04 (LP: #1555765)
+-    - cpufreq: powernv: Define per_cpu chip pointer to optimize hot-path
+-    - Revert "cpufreq: postfix policy directory with the first CPU in related_cpus"
+-    - cpufreq: powernv: Add sysfs attributes to show throttle stats
+-
+-  * systemd-modules-load.service: Failing due to missing module 'ib_iser' (LP: #1566468)
+-    - [Config] Add ib_iser to generic inclusion list
+-
+-  * thunderx nic performance improvements (LP: #1567093)
+-    - net: thunderx: Set recevie buffer page usage count in bulk
+-    - net: thunderx: Adjust nicvf structure to reduce cache misses
+-
+-  * fixes for thunderx nic in multiqueue mode (LP: #1567091)
+-    - net: thunderx: Fix for multiqset not configured upon interface toggle
+-    - net: thunderx: Fix for HW TSO not enabled for secondary qsets
+-    - net: thunderx: Fix receive packet stats
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Config] updateconfigs after CONFIG_DRM_I915_BPO_PRELIMINARY_HW_SUPPORT=n
+-
+-  * Miscellaneous upstream changes (LP: #1564901)
+-    - Input: xpad - correctly handle concurrent LED and FF requests
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 07 Apr 2016 07:32:16 +0100
+-
+-linux (4.4.0-18.34) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1566868
+-
+-  * [i915_bpo] Fix RC6 on SKL GT3 & GT4 (LP: #1564759)
+-    - SAUCE: i915_bpo: drm/i915/skl: Fix rc6 based gpu/system hang
+-    - SAUCE: i915_bpo: drm/i915/skl: Fix spurious gpu hang with gt3/gt4 revs
+-
+-  * CONFIG_ARCH_ROCKCHIP not enabled in armhf generic kernel (LP: #1566283)
+-    - [Config] CONFIG_ARCH_ROCKCHIP=y
+-
+-  * [Feature] Memory Bandwidth Monitoring (LP: #1397880)
+-    - perf/x86/cqm: Fix CQM handling of grouping events into a cache_group
+-    - perf/x86/cqm: Fix CQM memory leak and notifier leak
+-    - x86/cpufeature: Carve out X86_FEATURE_*
+-    - Merge branch 'timers-core-for-linus' of git://git.kernel.org/pub/scm/linux/kernel/git/tip/tip
+-    - x86/topology: Create logical package id
+-    - perf/x86/mbm: Add Intel Memory B/W Monitoring enumeration and init
+-    - perf/x86/mbm: Add memory bandwidth monitoring event management
+-    - perf/x86/mbm: Implement RMID recycling
+-    - perf/x86/mbm: Add support for MBM counter overflow handling
+-
+-  * User namespace mount updates (LP: #1566505)
+-    - SAUCE: quota: Require that qids passed to dqget() be valid and map into s_user_ns
+-    - SAUCE: fs: Allow superblock owner to change ownership of inodes with unmappable ids
+-    - SAUCE: fuse: Don't initialize user_id or group_id in mount options
+-    - SAUCE: cgroup: Use a new super block when mounting in a cgroup namespace
+-    - SAUCE: fs: fix a posible leak of allocated superblock
+-
+-  * [arm64] kernel BUG at /build/linux-StrpB2/linux-4.4.0/fs/ext4/inode.c:2394!
+-    (LP: #1566518)
+-    - arm64: Honour !PTE_WRITE in set_pte_at() for kernel mappings
+-    - arm64: Update PTE_RDONLY in set_pte_at() for PROT_NONE permission
+-
+-  * [Feature]USB core and xHCI tasks for USB 3.1 SuperSpeedPlus (SSP) support
+-    for Alpine Ridge on SKL (LP: #1519623)
+-    - usb: define USB_SPEED_SUPER_PLUS speed for SuperSpeedPlus USB3.1 devices
+-    - usb: set USB 3.1 roothub device speed to USB_SPEED_SUPER_PLUS
+-    - usb: show speed "10000" in sysfs for USB 3.1 SuperSpeedPlus devices
+-    - usb: add device descriptor for usb 3.1 root hub
+-    - usb: Support USB 3.1 extended port status request
+-    - xhci: Make sure xhci handles USB_SPEED_SUPER_PLUS devices.
+-    - xhci: set roothub speed to USB_SPEED_SUPER_PLUS for USB3.1 capable controllers
+-    - xhci: USB 3.1 add default Speed Attributes to SuperSpeedPlus device capability
+-    - xhci: set slot context speed field to SuperSpeedPlus for USB 3.1 SSP devices
+-    - usb: Add USB3.1 SuperSpeedPlus Isoc Endpoint Companion descriptor
+-    - usb: Parse the new USB 3.1 SuperSpeedPlus Isoc endpoint companion descriptor
+-    - usb: Add USB 3.1 Precision time measurement capability descriptor support
+-    - xhci: refactor and cleanup endpoint initialization.
+-    - xhci: Add SuperSpeedPlus high bandwidth isoc support to xhci endpoints
+-    - xhci: cleanup isoc tranfers queuing code
+-    - xhci: Support extended burst isoc TRB structure used by xhci 1.1 for USB 3.1
+-    - SAUCE: (noup) usb: fix regression in SuperSpeed endpoint descriptor parsing
+-
+-  * wrong/missing permissions for device file /dev/prandom (prng.ko)
+-    (LP: #1558275)
+-    - s390/crypto: provide correct file mode at device register.
+-
+-  * The Front MIC jack can't work on a HP desktop machine (LP: #1564712)
+-    - ALSA: hda - fix front mic problem for a HP desktop
+-
+-  * HP Notebook Probook 440 G3  HDA Intel PCH horrible sounds while booting
+-    (LP: #1556228)
+-    - ALSA: hda - Apply reboot D3 fix for CX20724 codec, too
+-
+-  * please provide mmc-modules udeb (LP: #1565765)
+-    - [Config] Add mmc block drivers to d-i
+-
+-  * linux: Enforce signed module loading when UEFI secure boot (LP: #1566221)
+-    - Add secure_modules() call
+-    - PCI: Lock down BAR access when module security is enabled
+-    - x86: Lock down IO port access when module security is enabled
+-    - ACPI: Limit access to custom_method
+-    - asus-wmi: Restrict debugfs interface when module loading is restricted
+-    - Restrict /dev/mem and /dev/kmem when module loading is restricted
+-    - acpi: Ignore acpi_rsdp kernel parameter when module loading is restricted
+-    - kexec: Disable at runtime if the kernel enforces module loading restrictions
+-    - x86: Restrict MSR access when module loading is restricted
+-    - [Config] CONFIG_EFI_SECURE_BOOT_SIG_ENFORCE=n
+-    - Add option to automatically enforce module signatures when in Secure Boot mode
+-    - efi: Make EFI_SECURE_BOOT_SIG_ENFORCE depend on EFI
+-    - efi: Add EFI_SECURE_BOOT bit
+-    - hibernate: Disable in a signed modules environment
+-
+-  * [Hyper-V] Additional PCI passthrough commits (LP: #1565967)
+-    - PCI: Add fwnode_handle to x86 pci_sysdata
+-    - PCI: Look up IRQ domain by fwnode_handle
+-    - [Config] CONFIG_PCI_HYPERV=m
+-    - PCI: hv: Add paravirtual PCI front-end for Microsoft Hyper-V VMs
+-
+-  * [Bug]Lenovo Yoga 260 and Carbon X1 4th gen freeze on HWP enable
+-    (LP: #1559923)
+-    - ACPI / processor: Request native thermal interrupt handling via _OSC
+-
+-  * Sync kernel zfs 0.6.5.6 - align with zfsutils-linux and spl packages
+-    (LP: #1564591)
+-    - SAUCE: (noup) Update spl to 0.6.5.6-0ubuntu1, zfs to 0.6.5.6-0ubuntu3
+-
+-  * [Ubuntu 16.04.1] RELEASE and ACQUIRE atomics on Power (LP: #1556096)
+-    - atomics: Allow architectures to define their own __atomic_op_* helpers
+-    - powerpc: atomic: Implement atomic{, 64}_*_return_* variants
+-    - powerpc: atomic: Implement acquire/release/relaxed variants for xchg
+-    - powerpc: atomic: Implement acquire/release/relaxed variants for cmpxchg
+-
+-  * fix for do_tools_cpupower when cross-compiling (LP: #1564206)
+-    - [Debian] cpupower uses non-standard CROSS
+-
+-  * ISST:LTE: Regression: roselp2 Oops in kernel during setup io (LP: #1546439)
+-    - SAUCE: block: partition: initialize percpuref before sending out KOBJ_ADD
+-
+-  * Unable to migrate container (LP: #1563921)
+-    - SAUCE: cgroup mount: ignore nsroot=
+-
+-  * [Hyper-V] patch inclusion in 16.04 for NIC hot add/remove (LP: #1563688)
+-    - hv_netvsc: Move subchannel waiting to rndis_filter_device_remove()
+-
+-  * /proc/$pid/maps performance regression (LP: #1547231)
+-    - proc: revert /proc/<pid>/maps [stack:TID] annotation
+-
+-  * TPM2.0 trusted keys fixes (LP: #1398274)
+-    - tpm: remove unneeded include of actbl2.h
+-    - tpm: fix checks for policy digest existence in tpm2_seal_trusted()
+-    - tpm_crb: Use the common ACPI definition of struct acpi_tpm2
+-    - tpm_tis: Disable interrupt auto probing on a per-device basis
+-    - tpm_tis: Do not fall back to a hardcoded address for TPM2
+-    - tpm_tis: Use devm_ioremap_resource
+-    - tpm_tis: Clean up the force=1 module parameter
+-    - tpm_crb: Drop le32_to_cpu(ioread32(..))
+-    - tpm_crb: Use devm_ioremap_resource
+-    - tpm: fix the rollback in tpm_chip_register()
+-    - tpm: fix the cleanup of struct tpm_chip
+-    - tpm: fix: set continueSession attribute for the unseal operation
+-    - tpm: fix: return rc when devm_add_action() fails
+-    - tpm_eventlog.c: fix binary_bios_measurements
+-    - tpm_crb/tis: fix: use dev_name() for /proc/iomem
+-    - tpm_crb: tpm2_shutdown() must be called before tpm_chip_unregister()
+-    - tpm_tis: fix build warning with tpm_tis_resume
+-
+-  * [Feature]intel_idle driver support for Knights Landing (LP: #1461365)
+-    - intel_idle: Support for Intel Xeon Phi Processor x200 Product Family
+-
+-  * cxlflash: Backport upstream cxlflash commits and submitting a noup patch to
+-    Xenial (LP: #1563485)
+-    - cxlflash: Fix to avoid unnecessary scan with internal LUNs
+-    - cxlflash: Increase cmd_per_lun for better throughput
+-    - SAUCE: (noup) cxlflash: Move to exponential back-off when cmd_room is not available
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Config] do_zfs_powerpc64-smp  = true
+-    - [Debian] fix linux_tools when cross-compiling
+-    - [Config] do_zfs_powerpc64-smp use default value
+-    - SAUCE: apparmor: Fix FTBFS due to bad include path
+-    - SAUCE: i915_bpo: Disable preliminary hw support
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 29 Mar 2016 15:31:33 -0600
+-
+-linux (4.4.0-17.33) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1563441
+-
+-  * ISST-LTE: pVM:high cpus number need a high crashkernel value in kdump
+-    (LP: #1560552)
+-    - SAUCE: (noup) ppc64 boot: Wait for boot cpu to show up if nr_cpus limit is
+-      about to hit.
+-
+-  * Predictable naming mechanism is leading to issues in DLPAR operations of
+-    NICs (LP: #1560514)
+-    - SAUCE: (noup) powerpc/pci: Assign fixed PHB number based on device-tree
+-      properties
+-
+-  * ThunderX: support alternative phy implementations (LP: #1562968)
+-    - net: thunderx: Cleanup PHY probing code.
+-    - [Config] CONFIG_MDIO_CAVIUM=m
+-    - phy: mdio-octeon: Refactor into two files/modules
+-    - [Config] CONFIG_MDIO_THUNDER=m
+-    - phy: mdio-thunder: Add driver for Cavium Thunder SoC MDIO buses.
+-    - phy: mdio-cavium: Add missing MODULE_* annotations.
+-    - net: cavium: For Kconfig THUNDER_NIC_BGX, select MDIO_THUNDER.
+-    - phy: mdio-thunder: Fix some Kconfig typos
+-    - [d-i] Add phy drivers for Cavium ThunderX to nic-modules udeb
+-
+-  * linux: exclude ZONE_DEVICE from GFP_ZONE_TABLE (LP: #1563293)
+-    - Revert "mm: CONFIG_NR_ZONES_EXTENDED"
+-    - mm: exclude ZONE_DEVICE from GFP_ZONE_TABLE
+-
+-  * lots of printk to serial console can hang system for long time
+-    (LP: #1534216)
+-    - printk: set may_schedule for some of console_trylock() callers
+-
+-  * [i915_bpo] Update i915 backport driver (LP: #1560395)
+-    - SAUCE: i915_bpo: Update to drm-intel-next-fixes-2016-03-16
+-    - PM / runtime: Add new helper for conditional usage count incrementation
+-    - drm/core: Add drm_for_each_encoder_mask, v2.
+-    - drm/atomic-helper: Implement subsystem-level suspend/resume
+-
+-  * [Hyper-V] VM Sockets (LP: #1541585)
+-    - Drivers: hv: vmbus: Cleanup vmbus_set_event()
+-    - Drivers: hv: vmbus: Add vendor and device atttributes
+-    - Drivers: hv: vmbus: avoid infinite loop in init_vp_index()
+-    - Drivers: hv: vmbus: avoid scheduling in interrupt context in vmbus_initiate_unload()
+-    - Drivers: hv: vmbus: don't manipulate with clocksources on crash
+-    - Drivers: hv: vmbus: add a helper function to set a channel's pending send size
+-    - Drivers: hv: vmbus: define the new offer type for Hyper-V socket (hvsock)
+-    - Drivers: hv: vmbus: vmbus_sendpacket_ctl: hvsock: avoid unnecessary signaling
+-    - Drivers: hv: vmbus: define a new VMBus message type for hvsock
+-    - Drivers: hv: vmbus: add a hvsock flag in struct hv_driver
+-    - Drivers: hv: vmbus: add a per-channel rescind callback
+-    - Drivers: hv: vmbus: add an API vmbus_hvsock_device_unregister()
+-    - Drivers: hv: vmbus: Eliminate the spin lock on the read path
+-    - Drivers: hv: vmbus: Give control over how the ring access is serialized
+-    - drivers/hv: Move VMBus hypercall codes into Hyper-V UAPI header
+-    - Drivers: hv: vmbus: don't loose HVMSG_TIMER_EXPIRED messages
+-    - Drivers: hv: vmbus: avoid wait_for_completion() on crash
+-    - Drivers: hv: vmbus: remove code duplication in message handling
+-    - Drivers: hv: vmbus: avoid unneeded compiler optimizations in vmbus_wait_for_unload()
+-    - Drivers: hv: util: Pass the channel information during the init call
+-    - Drivers: hv: utils: Remove util transport handler from list if registration fails
+-    - Revert "Drivers: hv: vmbus: Support handling messages on multiple CPUs"
+-    - Drivers: hv: vmbus: Support handling messages on multiple CPUs
+-
+-  * [Bug]SKL-H boot hang when c8+c9+c10 enabled by intel_idle driver
+-    (LP: #1559918)
+-    - intel_idle: prevent SKL-H boot failure when C8+C9+C10 enabled
+-
+-  * ixgbe: Update to Fortville SW5 release (LP: #1562326)
+-    - net: add tc offload feature flag
+-    - net: tc: helper functions to query action types
+-    - sctp: Rename NETIF_F_SCTP_CSUM to NETIF_F_SCTP_CRC
+-    - net: rework ndo tc op to consume additional qdisc handle parameter
+-    - net: rework setup_tc ndo op to consume general tc operand
+-    - net: sched: add cls_u32 offload hooks for netdevs
+-    - net: ixgbe: add support for tc_u32 offload
+-    - net: ixgbe: abort with cls u32 divisor groups greater than 1
+-
+-  * Bring fm10k up to Fortville SW5 (LP: #1562310)
+-    - net: add netif_is_team_master helper
+-    - net: add netif_is_team_port helper
+-    - net: add netif_is_lag_master helper
+-    - net: add netif_is_lag_port helper
+-    - ethtool: correctly ensure {GS}CHANNELS doesn't conflict with GS{RXFH}
+-    - fm10k: don't reinitialize RSS flow table when RXFH configured
+-
+-  * [Feature]Always Running Timer (ART) to System Time translation
+-    (LP: #1519625)
+-    - time: Verify time values in adjtimex ADJ_SETOFFSET to avoid overflow
+-    - timekeeping: Provide internal function __ktime_get_real_seconds
+-    - timekeeping: Cap adjustments so they don't exceed the maxadj value
+-    - clocksource: Make clocksource validation work for all clocksources
+-    - time: Add cycles to nanoseconds translation
+-    - time: Add timekeeping snapshot code capturing system time and counter
+-    - time: Remove duplicated code in ktime_get_raw_and_real()
+-    - time: Add driver cross timestamp interface for higher precision time synchronization
+-    - time: Add history to cross timestamp interface supporting slower devices
+-    - time/timekeeping: Work around false positive GCC warning
+-    - x86/tsc: Always Running Timer (ART) correlated clocksource
+-    - ptp: Add PTP_SYS_OFFSET_PRECISE for driver crosstimestamping
+-    - [Config] CONFIG_E1000E_HWTS=y
+-    - e1000e: Adds hardware supported cross timestamp on e1000e nic
+-
+-  * x-gene2: add SoC v2 support to clock (LP: #1561604)
+-    - clk: xgene: Add SoC and PMD PLL clocks with v2 hardware
+-
+-  * [Bug]Disable multi-record PEBS on Merom (LP: #1559914)
+-    - perf/x86: Move perf_event.c ............... => x86/events/core.c
+-    - perf/x86: Move perf_event_amd.c ........... => x86/events/amd/core.c
+-    - perf/x86: Move perf_event_amd_ibs.c ....... => x86/events/amd/ibs.c
+-    - perf/x86: Move perf_event_amd_iommu.[ch] .. => x86/events/amd/iommu.[ch]
+-    - perf/x86: Move perf_event_amd_uncore.c .... => x86/events/amd/uncore.c
+-    - perf/x86: Move perf_event_intel_bts.c ........ => x86/events/intel/bts.c
+-    - perf/x86: Move perf_event_intel.c ............ => x86/events/intel/core.c
+-    - perf/x86: Move perf_event_intel_cqm.c ........ => x86/events/intel/cqm.c
+-    - perf/x86: Move perf_event_intel_cstate.c ..... => x86/events/intel/cstate.c
+-    - perf/x86: Move perf_event_intel_ds.c ......... => x86/events/intel/ds.c
+-    - perf/x86: Move perf_event_intel_lbr.c ........ => x86/events/intel/lbr.c
+-    - perf/x86: Move perf_event_intel_pt.[ch] ...... => x86/events/intel/pt.[ch]
+-    - perf/x86: Move perf_event_intel_rapl.c ....... => x86/events/intel/rapl.c
+-    - perf/x86: Move perf_event_intel_uncore.[ch] .. =>
+-      x86/events/intel/uncore.[ch]
+-    - perf/x86: Move perf_event_intel_uncore_nhmex.c =>
+-      x86/events/intel/uncore_nmhex.c
+-    - perf/x86: Move perf_event_intel_uncore_snb.c =>
+-      x86/events/intel/uncore_snb.c
+-    - perf/x86: Move perf_event_intel_uncore_snbep.c =>
+-      x86/events/intel/uncore_snbep.c
+-    - perf/x86: Move perf_event_knc.c .............. => x86/events/intel/knc.c
+-    - perf/x86: Move perf_event_p4.c ............... => x86/events/intel/p4.c
+-    - perf/x86: Move perf_event_p6.c ............... => x86/events/intel/p6.c
+-    - perf/x86: Move perf_event_msr.c .............. => x86/events/msr.c
+-    - perf/x86: Move perf_event.h to its new home
+-    - perf/x86/intel: Use PAGE_SIZE for PEBS buffer size on Core2
+-
+-  * [Feature] Enable I2C on Broxton-P (LP: #1520139)
+-    - mfd: intel-lpss: Pass I2C configuration via properties on BXT
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 24 Mar 2016 20:40:27 -0600
+-
+-linux (4.4.0-16.32) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1561727
+-
+-  * fix thermal throttling due to commit "Thermal: initialize thermal zone
+-    device correctly"  (LP: #1561676)
+-    - Thermal: Ignore invalid trip points
+-
+-  * Thinkpad T460: Trackpoint mouse buttons instantly generate "release" event
+-    on press (LP: #1553811)
+-    - SAUCE: (noup) Input: synaptics - handle spurious release of trackstick
+-      buttons, again
+-
+-  * reading /sys/kernel/security/apparmor/profiles requires CAP_MAC_ADMIN
+-    (LP: #1560583)
+-    - SAUCE: apparmor: Allow ns_root processes to open profiles file
+-    - SAUCE: apparmor: Consult sysctl when reading profiles in a user ns
+-
+-  * linux: sync virtualbox drivers to 5.0.16-dfsg-2 (LP: #1561492)
+-    - ubuntu: vbox -- update to 5.0.16-dfsg-2
+-
+-  * s390/kconfig: CONFIG_NUMA without CONFIG_NUMA_EMU does not make any sense on
+-    s390x (LP: #1557690)
+-    - [Config] CONFIG_NUMA_BALANCING_DEFAULT_ENABLED=n for s390x
+-
+-  * spl/zfs fails to build on s390x (LP: #1519814)
+-    - [Config] s390x -- re-enable zfs
+-    - [Config] zfs -- disable powerpc until the test failures can be resolved
+-
+-  * linux: sync to ZFS 0.6.5.6 stable release (LP: #1561483)
+-    - SAUCE: (noup) Update spl to 0.6.5.6-0ubuntu1, zfs to 0.6.5.6-0ubuntu1
+-
+-  * zfs: enable zfs for 64bit powerpc kernels (LP: #1558871)
+-    - [Packaging] zfs -- handle rprovides via dpkg-gencontrol
+-    - [Config] powerpc -- convert zfs configuration to custom_override
+-
+-  * Memory arena corruption with FUSE (was Memory allocation failure crashes
+-    kernel hard, presumably related to FUSE) (LP: #1505948)
+-    - SAUCE: (noup) fuse: do not use iocb after it may have been freed
+-    - SAUCE: (noup) fuse: Add reference counting for fuse_io_priv
+-
+-  * cgroup namespaces: add a 'nsroot=' mountinfo field (LP: #1560489)
+-    - SAUCE: (noup) cgroup namespaces: add a 'nsroot=' mountinfo field
+-
+-  * linux packaging: clear remaining redundant delta (LP: #1560445)
+-    - [Debian] Remove generated intermediate files on clean
+-
+-  * arm64: guest hangs when ntpd is running (LP: #1549494)
+-    - Revert "hrtimer: Add support for CLOCK_MONOTONIC_RAW"
+-    - Revert "hrtimer: Catch illegal clockids"
+-    - Revert "KVM: arm/arm64: timer: Switch to CLOCK_MONOTONIC_RAW"
+-
+-  * Need enough contiguous memory to support GICv3 ITS table (LP: #1558828)
+-    - [Config] CONFIG_FORCE_MAX_ZONEORDER=13 on arm64
+-    - SAUCE: (no-up) arm64: gicv3: its: Increase FORCE_MAX_ZONEORDER for Cavium
+-      ThunderX
+-
+-  * update arcmsr to version v1.30.00.22-20151126 to fix card timeouts
+-    (LP: #1559609)
+-    - arcmsr: fixed getting wrong configuration data
+-    - arcmsr: fixes not release allocated resource
+-    - arcmsr: make code more readable
+-    - arcmsr: adds code to support new Areca adapter ARC1203
+-    - arcmsr: changes driver version number
+-    - arcmsr: more readability improvements
+-    - arcmsr: Split dma resource allocation to a new function
+-    - arcmsr: change driver version to v1.30.00.22-20151126
+-
+-  * server image has no keyboard, desktop image works (LP: #1559692)
+-    - [Config] Rework input-modules (d-i) list
+-
+-  * PMU support for Cavium ThunderX (LP: #1559349)
+-    - arm64: perf: Rename Cortex A57 events
+-    - arm64/perf: Add Cavium ThunderX PMU support
+-    - arm64: perf: Enable PMCR long cycle counter bit
+-    - arm64: perf: Extend event mask for ARMv8.1
+-    - arm64: dts: Add Cavium ThunderX specific PMU
+-
+-  * Show ARM PMU events in perf stat (LP: #1559350)
+-    - drivers/perf: kill armpmu_register
+-    - arm: perf: Convert event enums to #defines
+-    - arm: perf: Add event descriptions
+-    - arm64: perf: Convert event enums to #defines
+-    - arm64: perf: Add event descriptions
+-    - ARM: perf: add format entry to describe event -> config mapping
+-    - arm64: perf: add format entry to describe event -> config mapping
+-
+-  * [Bug]HSW/BDW EDAC driver reports wrong DIMM (LP: #1559904)
+-    - EDAC/sb_edac: Fix computation of channel address
+-
+-  * 5-10 second delay in kernel boot with kernel command line ip= (LP: #1259861)
+-    - [Config] disable CONFIG_IP_PNP
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Debian] Silence the reconstruct script
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 21 Mar 2016 10:15:31 -0600
+-
+-linux (4.4.0-15.31) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1559252
+-
+-  * Xilinx KU3 Capi card does not show up in Ubuntu  16.04 (LP: #1557001)
+-    - SAUCE: (noup) cxl: Allow initialization on timebase sync failures
+-
+-  * policy namespace stacking (LP: #1379535)
+-    - Revert "UBUNTU: SAUCE: Move replacedby allocation into label_alloc"
+-    - Revert "UBUNTU: SAUCE: Fixup: __label_update() still doesn't handle some cases correctly."
+-    - Revert "UBUNTU: SAUCE: fix: audit "no_new_privs" case for exec failure"
+-    - Revert "UBUNTU: SAUCE: fixup: warning about aa_label_vec_find_or_create not being static"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix refcount race when finding a child profile"
+-    - Revert "UBUNTU: SAUCE: fixup: cast poison values to remove warnings"
+-    - Revert "UBUNTU: SAUCE: fixup: get rid of unused var build warning"
+-    - Revert "UBUNTU: SAUCE: fixup: 20/23 locking issue around in __label_update"
+-    - Revert "UBUNTU: SAUCE: fixup: make __share_replacedby private to get rid of build warning"
+-    - Revert "UBUNTU: SAUCE: fix: replacedby forwarding is not being properly update when ns is destroyed"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix log of apparmor audit message when kern_path() fails"
+-    - Revert "UBUNTU: SAUCE: fixup: cleanup return handling of labels"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix: ref count leak when profile sha1 hash is read"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: query label file permission"
+-    - Revert "UBUNTU: SAUCE: apparmor: Don't remove label on rcu callback if the label has already been removed"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: break circular refcount for label that is directly freed."
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: refcount bug when inserting label update that transitions ns"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: now that insert can force replacement use it instead of remove_and_insert"
+-    - Revert "UBUNTU: SAUCE: apparmor Fix: refcount bug in pivotroot mediation"
+-    - Revert "UBUNTU: SAUCE: apparmor: ensure that repacedby sharing is done correctly"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: update replacedby allocation to take a gfp parameter"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: convert replacedby update to be protected by the labelset lock"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: add required locking of __aa_update_replacedby on merge path"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: deadlock in aa_put_label() call chain"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: label_vec_merge insertion"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: ensure new labels resulting from merge have a replacedby"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: refcount leak in aa_label_merge"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: refcount race between locating in labelset and get"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: label merge handling of marking unconfined and stale"
+-    - Revert "UBUNTU: SAUCE: apparmor: add underscores to indicate aa_label_next_not_in_set() use needs locking"
+-    - Revert "UBUNTU: SAUCE: apparmor: debug: POISON label and replaceby pointer on free"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: ensure aa_get_newest will trip debugging if the replacedby is not setup"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: insert race between label_update and label_merge"
+-    - Revert "UBUNTU: SAUCE: apparmor: rework retrieval of the current label in the profile update case"
+-    - Revert "UBUNTU: SAUCE: apparmor: Disallow update of cred when then subjective != the objective cred"
+-    - Revert "UBUNTU: SAUCE: apparmor: Fix: oops do to invalid null ptr deref in label print fns"
+-    - Revert "UBUNTU: SAUCE: fix-up: kern_mount fail path should not be doing put_buffers()"
+-    - Revert "UBUNTU: SAUCE: apparmor: fix sleep from invalid context"
+-    - Revert "UBUNTU: SAUCE: (no-up): apparmor: fix for failed mediation of socket that is being shutdown"
+-    - Revert "UBUNTU: SAUCE: (no-up) apparmor: Fix incompatible pointer type warnings"
+-    - Revert "UBUNTU: SAUCE: (no-up) apparmor: fix mount not handling disconnected paths"
+-    - Revert "UBUNTU: SAUCE: (no-up): apparmor: fix mediation of fs unix sockets"
+-    - Revert "UBUNTU: apparmor -- follow change to this_cpu_ptr"
+-    - Revert "UBUNTU: SAUCE: (no-up) fix: bad unix_addr_fs macro"
+-    - Revert "UBUNTU: SAUCE: Revert: fix: only allow a single threaded process to ..."
+-    - Revert "UBUNTU: SAUCE: (no-up) apparmor: Sync to apparmor3 - RC1 snapshot"
+-    - Revert "UBUNTU: SAUCE: (no-up) apparmor: add parameter to control whether policy hashing is used"
+-    - SAUCE: (no-up) apparmor: sync of apparmor3.5-beta1 snapshot
+-    - SAUCE: add a sysctl to enable unprivileged user ns AppArmor policy loading
+-
+-  * Add arm64 NUMA support (LP: #1558765)
+-    - SAUCE: (noup) efi: ARM/arm64: ignore DT memory nodes instead of removing them
+-    - SAUCE: (noup) Documentation, dt, numa: dt bindings for NUMA.
+-    - [Config] CONFIG_OF_NUMA=y
+-    - SAUCE: (noup) of, numa: Add NUMA of binding implementation.
+-    - SAUCE: (noup) arm64: Move unflatten_device_tree() call earlier.
+-    - [Config] CONFIG_NUMA=y and CONFIG_NODES_SHIFT=2 on arm64
+-    - SAUCE: (noup) arm64, numa: Add NUMA support for arm64 platforms.
+-    - SAUCE: (noup) arm64, mm, numa: Add NUMA balancing support for arm64.
+-
+-  * vivid/linux: total ADT test failures (LP: #1558447)
+-    - Revert "Revert "af_unix: Revert 'lock_interruptible' in stream receive code""
+-
+-  * [Hyper-V] patches to allow kdump crash through NMI (LP: #1558720)
+-    - Drivers: hv: vmbus: Support handling messages on multiple CPUs
+-    - Drivers: hv: vmbus: Support kexec on ws2012 r2 and above
+-
+-  * s390/pci: enforce fmb page boundary rule (LP: #1558625)
+-    - s390/pci: enforce fmb page boundary rule
+-
+-  * s390/pci: backport upstream commits since v4.4 (LP: #1558624)
+-    - s390/pci_dma: fix DMA table corruption with > 4 TB main memory
+-    - page_to_phys() always returns a multiple of PAGE_SIZE
+-    - s390/pci: provide ZPCI_ADDR macro
+-    - s390/pci: improve ZPCI_* macros
+-    - s390/pci: resize iomap
+-    - s390/pci: fix bar check
+-    - s390/pci: set error state for unusable functions
+-    - s390/pci: remove iomap sanity checks
+-    - s390/pci: remove pdev pointer from arch data
+-    - s390/pci: add ioctl interface for CLP
+-
+-  * IMA-appraisal is unusable in Ubuntu 16.04 (LP: #1558553)
+-    - [Config] CONFIG_SYSTEM_EXTRA_CERTIFICATE=y, CONFIG_SYSTEM_EXTRA_CERTIFICATE_SIZE=4096
+-    - KEYS: Use the symbol value for list size, updated by scripts/insert-sys-cert
+-    - KEYS: Reserve an extra certificate symbol for inserting without recompiling
+-    - SAUCE: (noup) KEYS: Support for inserting a certificate into x86 bzImage
+-
+-  * skb_warn_bad_offload Crash (LP: #1558025)
+-    - ipv4: only create late gso-skb if skb is already set up with CHECKSUM_PARTIAL
+-
+-  * Add PCIe root complex to Cavium arm64 (LP: #1558342)
+-    - [Config] CONFIG_PCI_HOST_COMMON=y
+-    - [Config] CONFIG_PCI_HOST_THUNDER_PEM=y
+-    - [Config] CONFIG_PCI_HOST_THUNDER_ECAM=y
+-    - PCI: generic: Move structure definitions to separate header file
+-    - PCI: generic: Add pci_host_common_probe(), based on gen_pci_probe()
+-    - PCI: generic: Expose pci_host_common_probe() for use by other drivers
+-    - PCI: thunder: Add PCIe host driver for ThunderX processors
+-    - PCI: thunder: Add driver for ThunderX-pass{1,2} on-chip devices
+-
+-  * [Hyper-V] vmbus: Fix a bug in hv_need_to_signal_on_read() (LP: #1556264)
+-    - SAUCE: (noup) Drivers: hv: vmbus: Fix a bug in hv_need_to_signal_on_read()
+-
+-  * Xenial update to v4.4.6 stable release (LP: #1558330)
+-    - arm64: account for sparsemem section alignment when choosing vmemmap offset
+-    - ARM: mvebu: fix overlap of Crypto SRAM with PCIe memory window
+-    - ARM: dts: dra7: do not gate cpsw clock due to errata i877
+-    - ARM: OMAP2+: hwmod: Introduce ti,no-idle dt property
+-    - PCI: Allow a NULL "parent" pointer in pci_bus_assign_domain_nr()
+-    - kvm: cap halt polling at exactly halt_poll_ns
+-    - KVM: VMX: disable PEBS before a guest entry
+-    - KVM: s390: correct fprs on SIGP (STOP AND) STORE STATUS
+-    - KVM: PPC: Book3S HV: Sanitize special-purpose register values on guest exit
+-    - KVM: MMU: fix ept=0/pte.u=1/pte.w=0/CR0.WP=0/CR4.SMEP=1/EFER.NX=0 combo
+-    - KVM: MMU: fix reserved bit check for ept=0/CR0.WP=0/CR4.SMEP=1/EFER.NX=0
+-    - s390/dasd: fix diag 0x250 inline assembly
+-    - tracing: Fix check for cpu online when event is disabled
+-    - dmaengine: at_xdmac: fix residue computation
+-    - jffs2: reduce the breakage on recovery from halfway failed rename()
+-    - ncpfs: fix a braino in OOM handling in ncp_fill_cache()
+-    - ASoC: dapm: Fix ctl value accesses in a wrong type
+-    - ASoC: samsung: Use IRQ safe spin lock calls
+-    - ASoC: wm8994: Fix enum ctl accesses in a wrong type
+-    - ASoC: wm8958: Fix enum ctl accesses in a wrong type
+-    - ovl: ignore lower entries when checking purity of non-directory entries
+-    - ovl: fix working on distributed fs as lower layer
+-    - wext: fix message delay/ordering
+-    - cfg80211/wext: fix message ordering
+-    - can: gs_usb: fixed disconnect bug by removing erroneous use of kfree()
+-    - iwlwifi: mvm: inc pending frames counter also when txing non-sta
+-    - mac80211: minstrel: Change expected throughput unit back to Kbps
+-    - mac80211: fix use of uninitialised values in RX aggregation
+-    - mac80211: minstrel_ht: set default tx aggregation timeout to 0
+-    - mac80211: minstrel_ht: fix a logic error in RTS/CTS handling
+-    - mac80211: check PN correctly for GCMP-encrypted fragmented MPDUs
+-    - mac80211: Fix Public Action frame RX in AP mode
+-    - gpu: ipu-v3: Do not bail out on missing optional port nodes
+-    - drm/amdgpu: Fix error handling in amdgpu_flip_work_func.
+-    - drm/radeon: Fix error handling in radeon_flip_work_func.
+-    - Revert "drm/radeon/pm: adjust display configuration after powerstate"
+-    - userfaultfd: don't block on the last VM updates at exit time
+-    - ovl: fix getcwd() failure after unsuccessful rmdir
+-    - MIPS: Fix build error when SMP is used without GIC
+-    - MIPS: smp.c: Fix uninitialised temp_foreign_map
+-    - block: don't optimize for non-cloned bio in bio_get_last_bvec()
+-    - target: Drop incorrect ABORT_TASK put for completed commands
+-    - ld-version: Fix awk regex compile failure
+-    - Linux 4.4.6
+-
+-  * linux fails to load x.509 built-in certificate (LP: #1557250)
+-    - lib/mpi: Endianness fix
+-
+-  * s390/kconfig: setting for CONFIG...9P.... (LP: #1557994)
+-    - [Config] CONFIG_NET_9P=m for s390x
+-
+-  * mlx5_core kernel trace after "ethtool -C eth1 adaptive-rx on" flow
+-    (LP: #1557950)
+-    - net/mlx5e: Don't try to modify CQ moderation if it is not supported
+-    - net/mlx5e: Don't modify CQ before it was created
+-
+-  * [Feature]SD/SDIO/eMMC support for Broxton-P (LP: #1520454)
+-    - mmc: sdhci: Do not BUG on invalid vdd
+-    - mmc: enable MMC/SD/SDIO device to suspend/resume asynchronously
+-    - mmc: It is not an error for the card to be removed while suspended
+-
+-  * s390/kconfig: disable CONFIG_VIRTIO_MMIO (LP: #1557689)
+-    - [Config] CONFIG_VIRTIO_MMIO=n for s390x
+-
+-  * s390/kconfig: CONFIG_NUMA without CONFIG_NUMA_EMU does not make any sense on s390x (LP: #1557690)
+-    - [Config] CONFIG_NUMA_EMU=y for s390x
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Debian] git-ubuntu-log -- prevent bug references being split
+-    - [Debian] git-ubuntu-log -- git log output is UTF-8
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Mar 2016 13:18:58 -0600
+-
+-linux (4.4.0-14.30) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1557508
+-
+-  * Current 4.4 kernel won't boot on powerpc (LP: #1557130)
+-    - powerpc: Fix dedotify for binutils >= 2.26
+-
+-  * ZFS: send fails to transmit some holes [corruption] (LP: #1557151)
+-    - Illumos 6370 - ZFS send fails to transmit some holes
+-
+-  * Request to cherry-pick uvcvideo patch for Xenial kernel support of RealSense
+-    camera (LP: #1557138)
+-    - UVC: Add support for ds4 depth camera
+-
+-  * use after free of task_struct->numa_faults in task_numa_find_cpu (LP: #1527643)
+-    - sched/numa: Fix use-after-free bug in the task_numa_compare
+-
+-  * overlay fs regression: chmod fails with "Operation not permitted" on chowned
+-    files (LP: #1555997)
+-    - ovl: copy new uid/gid into overlayfs runtime inode
+-
+-  * Miscellaneous Ubuntu changes
+-    - SAUCE: Dump stack when X.509 certificates cannot be loaded
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 14 Mar 2016 07:16:19 -0600
+-
+-linux (4.4.0-13.29) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1556247
+-
+-  * s390/mm: four page table levels vs. fork (LP: #1556141)
+-    - s390/mm: four page table levels vs. fork
+-
+-  * [Hyper-V] network performance patches for Xenial 16.04 (LP: #1556037)
+-    - hv_netvsc: use skb_get_hash() instead of a homegrown implementation
+-    - hv_netvsc: cleanup netdev feature flags for netvsc
+-
+-  * fails to boot on megaraid (LP: #1552903)
+-    - SAUCE: (noup) megaraid_sas: Don't issue kill adapter for MFI controllers in
+-      case of PD list DCMD failure
+-
+-  * ALSA: hda - add codec support for Kabylake display audio codec (LP: #1556002)
+-    - ALSA: hda - add codec support for Kabylake display audio codec
+-
+-  * Backport upstream bugfixes to ubuntu-16.04 (LP: #1555765)
+-    - cpufreq: powernv: Free 'chips' on module exit
+-    - cpufreq: powernv: Hot-plug safe the kworker thread
+-    - cpufreq: powernv: Remove cpu_to_chip_id() from hot-path
+-    - cpufreq: powernv/tracing: Add powernv_throttle tracepoint
+-    - cpufreq: powernv: Replace pr_info with trace print for throttle event
+-    - SAUCE: (noup) cpufreq: powernv: Fix bugs in powernv_cpufreq_{init/exit}
+-
+-  * Linux netfilter IPT_SO_SET_REPLACE memory corruption (LP: #1555338)
+-    - SAUCE: [nf,v2] netfilter: x_tables: don't rely on well-behaving userspace
+-
+-  * integer overflow in xt_alloc_table_info (LP: #1555353)
+-    - SAUCE: (noup) netfilter: x_tables: check for size overflow
+-
+-  * linux: auto-generate the reconstruct information from the git tag (LP: #1555543)
+-    - [Packaging] reconstruct -- automatically reconstruct against base tag
+-    - [Config] reconstruct -- update to autoreconstruct output
+-    - [Packaging] reconstruct -- update when inserting final changes
+-
+-  * Xenial update to v4.4.5 stable release (LP: #1555640)
+-    - use ->d_seq to get coherency between ->d_inode and ->d_flags
+-    - drivers: sh: Restore legacy clock domain on SuperH platforms
+-    - Btrfs: fix deadlock running delayed iputs at transaction commit time
+-    - btrfs: Fix no_space in write and rm loop
+-    - btrfs: async-thread: Fix a use-after-free error for trace
+-    - block: Initialize max_dev_sectors to 0
+-    - PCI: keystone: Fix MSI code that retrieves struct pcie_port pointer
+-    - parisc: Fix ptrace syscall number and return value modification
+-    - mips/kvm: fix ioctl error handling
+-    - kvm: x86: Update tsc multiplier on change.
+-    - fbcon: set a default value to blink interval
+-    - cifs: fix out-of-bounds access in lease parsing
+-    - CIFS: Fix SMB2+ interim response processing for read requests
+-    - Fix cifs_uniqueid_to_ino_t() function for s390x
+-    - vfio: fix ioctl error handling
+-    - KVM: x86: fix root cause for missed hardware breakpoints
+-    - arm/arm64: KVM: Fix ioctl error handling
+-    - iommu/amd: Apply workaround for ATS write permission check
+-    - iommu/amd: Fix boot warning when device 00:00.0 is not iommu covered
+-    - iommu/vt-d: Use BUS_NOTIFY_REMOVED_DEVICE in hotplug path
+-    - target: Fix WRITE_SAME/DISCARD conversion to linux 512b sectors
+-    - drm/ast: Fix incorrect register check for DRAM width
+-    - drm/radeon/pm: update current crtc info after setting the powerstate
+-    - drm/amdgpu/pm: update current crtc info after setting the powerstate
+-    - drm/amdgpu: apply gfx_v8 fixes to gfx_v7 as well
+-    - drm/amdgpu/gfx8: specify which engine to wait before vm flush
+-    - drm/amdgpu: return from atombios_dp_get_dpcd only when error
+-    - libata: fix HDIO_GET_32BIT ioctl
+-    - libata: Align ata_device's id on a cacheline
+-    - block: bio: introduce helpers to get the 1st and last bvec
+-    - writeback: flush inode cgroup wb switches instead of pinning super_block
+-    - Adding Intel Lewisburg device IDs for SATA
+-    - arm64: vmemmap: use virtual projection of linear region
+-    - PM / sleep / x86: Fix crash on graph trace through x86 suspend
+-    - ata: ahci: don't mark HotPlugCapable Ports as external/removable
+-    - tracing: Do not have 'comm' filter override event 'comm' field
+-    - pata-rb532-cf: get rid of the irq_to_gpio() call
+-    - Btrfs: fix loading of orphan roots leading to BUG_ON
+-    - Revert "jffs2: Fix lock acquisition order bug in jffs2_write_begin"
+-    - jffs2: Fix page lock / f->sem deadlock
+-    - Fix directory hardlinks from deleted directories
+-    - dmaengine: pxa_dma: fix cyclic transfers
+-    - adv7604: fix tx 5v detect regression
+-    - ALSA: usb-audio: Add a quirk for Plantronics DA45
+-    - ALSA: ctl: Fix ioctls for X32 ABI
+-    - ALSA: hda - Fix mic issues on Acer Aspire E1-472
+-    - ALSA: rawmidi: Fix ioctls X32 ABI
+-    - ALSA: timer: Fix ioctls for X32 ABI
+-    - ALSA: pcm: Fix ioctls for X32 ABI
+-    - ALSA: seq: oss: Don't drain at closing a client
+-    - ALSA: hdspm: Fix wrong boolean ctl value accesses
+-    - ALSA: hdsp: Fix wrong boolean ctl value accesses
+-    - ALSA: hdspm: Fix zero-division
+-    - ALSA: timer: Fix broken compat timer user status ioctl
+-    - usb: chipidea: otg: change workqueue ci_otg as freezable
+-    - USB: cp210x: Add ID for Parrot NMEA GPS Flight Recorder
+-    - USB: qcserial: add Dell Wireless 5809e Gobi 4G HSPA+ (rev3)
+-    - USB: qcserial: add Sierra Wireless EM74xx device ID
+-    - USB: serial: option: add support for Telit LE922 PID 0x1045
+-    - USB: serial: option: add support for Quectel UC20
+-    - MIPS: scache: Fix scache init with invalid line size.
+-    - MIPS: traps: Fix SIGFPE information leak from `do_ov' and `do_trap_or_bp'
+-    - ubi: Fix out of bounds write in volume update code
+-    - i2c: brcmstb: allocate correct amount of memory for regmap
+-    - thermal: cpu_cooling: fix out of bounds access in time_in_idle
+-    - block: check virt boundary in bio_will_gap()
+-    - block: get the 1st and last bvec via helpers
+-    - drm/i915: more virtual south bridge detection
+-    - drm/i915: refine qemu south bridge detection
+-    - modules: fix longstanding /proc/kallsyms vs module insertion race.
+-    - drm/amdgpu: fix topaz/tonga gmc assignment in 4.4 stable
+-    - Linux 4.4.5
+-
+-  * QEMU: causes vCPU steal time overflow on live migration (LP: #1494350)
+-    - x86/mm: Fix slow_virt_to_phys() for X86_PAE again
+-
+-  * TPM2.0 trusted keys fixes (LP: #1398274)
+-    - tpm_tis: further simplify calculation of ordinal duration
+-    - tpm_tis: Use devm_free_irq not free_irq
+-    - tpm_tis: Ensure interrupts are disabled when the driver starts
+-    - tpm: rework tpm_get_timeouts()
+-    - tpm_tis: Get rid of the duplicate IRQ probing code
+-    - tpm_tis: Refactor the interrupt setup
+-    - tpm_tis: Tighten IRQ auto-probing
+-    - tpm_ibmvtpm: properly handle interrupted packet receptions
+-
+-  * linux: review all versioned depends/conflicts/replaces/breaks for validility (LP: #1555033)
+-    - [Config] control.stub.in -- review versioned Build-Depends:
+-    - [Config] control.stub.in -- review versioned
+-      Depends/Breaks/Conflicts/Replaces
+-    - [Config] flavour-control.stub -- review versioned Breaks/Conflicts/Replaces
+-    - [Config] x86 vars.* -- review versioned Breaks/Conflicts/Replaces
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 09 Mar 2016 05:11:51 -0700
+-
+-linux (4.4.0-12.28) xenial; urgency=low
+-
+-  * Miscellaneous Ubuntu changes
+-    - reconstruct: Work around orig tarball packaging limitiations
+-      Fixes FTBS
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 08 Mar 2016 13:26:08 -0700
+-
+-linux (4.4.0-12.27) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1554704
+-
+-  * Fails to detect (second) display (LP: #1543683)
+-    - drm/i915: Fix hpd live status bits for g4x
+-
+-  * s390x -- various configuration changes (LP: #1543165)
+-    - [Config] s390x -- enable CONFIG_NUMA
+-    - [Config] s390x -- disable CONFIG_NET_VENDOR_EMULEX
+-    - [Config] s390x -- disable CONFIG_NET_VENDOR_SYNOPSYS
+-    - [Config] s390x -- disable CONFIG_NVMEM
+-    - [Config] s390x -- switch preempt mode to none
+-
+-  * Radeon hybrid graphics problem on resume (LP: #1554608)
+-    - Revert "drm/radeon: call hpd_irq_event on resume"
+-
+-  * Pull in upstream AMD code (amdgpu) in Xenial (LP: #1546572)
+-    - [Config] CONFIG_DRM_AMD_POWERPLAY=y
+-    - drm/amdgpu: use $(src) in Makefile (v2)
+-    - drm/radeon: constify radeon_asic_ring structures
+-    - drm/amdgpu: add a callback for reading the bios from the rom directly
+-    - drm/amdgpu: add read_bios_from_rom callback for CI parts
+-    - drm/amdgpu: add read_bios_from_rom callback for VI parts
+-    - drm/amdgpu: Use new read bios from rom callback
+-    - drm/amdgpu: Use unlocked gem unreferencing
+-    - drm/radeon: Use unlocked gem unreferencing
+-    - drm/amd: add new gfx8 register definitions for EDC
+-    - drm/amdgpu: add EDC support for CZ (v3)
+-    - drm/amd: abstract kernel rq and normal rq to priority of run queue
+-    - drm/amdgpu/gfx8: Enable interrupt on ME1_PIPE3
+-    - drm/amdgpu/gfx8: update PA_SC_RASTER_CONFIG:PKR_MAP only
+-    - drm/amdgpu: update rev id register for VI
+-    - drm/amdgpu: add more debugging output for driver failures
+-    - drm/amdgpu: add entity only when first job come
+-    - drm/amdgpu: handle error case for ctx
+-    - drm/amdgpu: unify AMDGPU_CTX_MAX_CS_PENDING and amdgpu_sched_jobs
+-    - drm/amdgpu: change default sched jobs to 32
+-    - drm/amdgpu: limit visible vram if it's smaller than the BAR
+-    - drm/amdgpu: restrict the sched jobs number to power of two
+-    - drm/amdgpu: put VM page tables directly into duplicates list
+-    - drm/amdgpu: split VM PD and PT handling during CS
+-    - drm/amdgpu: keep the PTs validation list in the VM v2
+-    - drm/radeon: Update radeon_get_vblank_counter_kms()
+-    - drm/radeon: only increment sync_seq when a fence is really emitted
+-    - drm/fb-helper: Use proper plane mask for fb cleanup
+-    - drm/amdgpu: fix dp link rate selection (v2)
+-    - drm/radeon: fix dp link rate selection (v2)
+-    - drm/amdgpu: share struct amdgpu_pm_state_type with powerplay module
+-    - drm/amdgpu: mv some definition from amdgpu_acpi.c to amdgpu_acpi.h
+-    - drm/amdgpu: mv amdgpu_acpi.h to amd/include/amd_acpi.h
+-    - drm/amdgpu: implement new cgs interface for acpi function
+-    - drm/amdgpu: implement cgs interface to query system info
+-    - drm/amdgpu: add new cgs interface to get display info (v2)
+-    - drm/amd/powerplay: add basic powerplay framework
+-    - drm/amdgpu: disable legacy path of firmware check if powerplay is enabled
+-    - drm/amdgpu: export amd_powerplay_func to amdgpu and other ip block
+-    - drm/amd/powerplay: add SMU manager sub-component
+-    - drm/amd/powerplay: add hardware manager sub-component
+-    - SAUCE: amd: Include errno.h
+-    - drm/amd/powerplay: add Carrizo smu support
+-    - drm/amd/powerplay: add Carrizo dpm support
+-    - drm/amd/powerplay: add CG and PG support for carrizo
+-    - drm/amd/powerplay: add event manager sub-component
+-    - drm/amd/powerplay: implement functions of amd_powerplay_func
+-    - drm/amd/powerplay: Add ixSWRST_COMMAND_1 in bif_5_0_d.h
+-    - drm/amd/powerplay: Move smu7*.h from amdgpu to powerplay.
+-    - drm/amd/powerplay: add header file for tonga smu and dpm
+-    - drm/amd/powerplay: Add Tonga SMU support
+-    - drm/amd/powerplay: add Tonga dpm support (v3)
+-    - drm/amd/powerplay: add/update headers for Fiji SMU and DPM
+-    - drm/amd/powerplay: update atomctrl for fiji
+-    - drm/amd/powerplay: add Fiji SMU support.
+-    - drm/amd/powerplay: add Fiji DPM support.
+-    - drm/amdgpu: add amdgpu.powerplay module option
+-    - drm/amd/amdgpu: enable powerplay and smc firmware loading for Fiji.
+-    - drm/amdgpu/powerplay: add function point in hwmgr_funcs for program display gap
+-    - drm/amdgpu/poweprlay: export program display gap function to eventmgr
+-    - drm/amdgpu/powerplay: implement pem_task for display_configuration_change
+-    - drm/amdgpu/powerplay: program display gap for tonga.
+-    - drm/amdgpu: enable powerplay module by default for tonga.
+-    - drm/amdgpu: enable powerplay module by default for fiji.
+-    - drm/amdgpu/powerplay: add some definition for other ip block to update cg pg.
+-    - drm/amd/powerplay: add new function point in hwmgr_func for CG/PG.
+-    - drm/amd/powerplay: Add CG and PG support for tonga
+-    - drm/amdgpu/powerplay: add new function point in hwmgr_funcs for thermal control
+-    - drm/amdgpu/powerplay: mv ppinterrupt.h to inc folder to share with other submodule.
+-    - drm/amdgpu/powerplay: add thermal control interface in hwmgr.
+-    - drm/amdgpu/powerplay: enable thermal interrupt task in eventmgr.
+-    - drm/amdgpu/powerplay: implement thermal control for tonga.
+-    - drm/amdgpu/powerplay: implement fan control interface in amd_powerplay_funcs
+-    - drm/amdgpu: export fan control functions to amdgpu
+-    - drm/amdgpu: enable sysfs interface for powerplay
+-    - drm/amdgpu: support per device powerplay enablement (v2)
+-    - drm/amd/powerplay: add and export hwmgr interface to eventmgr to check hw states.
+-    - drm/amd/powerplay: implement new funcs to check current states for tonga.
+-    - drm/amd/powerplay: refine the logic of whether need to update power state.
+-    - drm/amd/powerplay/tonga: enable pcie and mclk forcing for low
+-    - drm/amd/powerplay/fiji: enable pcie and mclk forcing for low
+-    - drm/amdgpu: extract pcie helpers to common header
+-    - drm: add drm_pcie_get_max_link_width helper (v2)
+-    - drm/amdgpu: store pcie gen mask and link width
+-    - drm/amdgpu/cgs: add sys info query for pcie gen and link width
+-    - drm/amdgpu/powerplay/tonga: query supported pcie info from cgs (v2)
+-    - drm/amdgpu/powerplay/fiji: query supported pcie info from cgs (v2)
+-    - drm/amd/powerplay: fix boolreturn.cocci warnings
+-    - drm/amd/powerplay/tonga: Add UVD DPM init
+-    - drm/amd/amdgpu: add gfx clock gating support for Fiji.
+-    - drm/amd/amdgpu: add gmc clock gating support for Fiji.
+-    - drm/amdgpu: add sdma clock gating support for Fiji.
+-    - drm/amd/powerplay: add parts of system clock gating support for Fiji. (v2)
+-    - drm/amd/powerplay: enable clock gating for Fiji.
+-    - drm/amd/powerplay: add atomctrl function to calculate CZ sclk dividers
+-    - drm/amd/powerplay: implement smc state upload for CZ
+-    - drm/amd/powerplay: fix warning of cast to pointer from integer of different size.
+-    - drm/amd/powerplay: fix warning of cast to pointer from integer of different size.
+-    - drm/amd/powerplay: add new function point in hwmgr.
+-    - drm/amd/powerplay: add smc msg for NB P-State switch
+-    - drm/amd/powerplay: export interface to DAL to init/change display configuration.
+-    - drm/amd/powerplay: enable set_cpu_power_state task. (v2)
+-    - drm/amd/powerplay: enable/disable NB pstate feature for Carrizo.
+-    - drm/amd/powerplay: Add PPLib debug print macro.
+-    - drm/amdgpu: rename tonga_smumgr.h to tonga_smum.h
+-    - drm/amdgpu: rename fiji_smumgr.h to fiji_smum.h
+-    - drm/amd/powerplay: add multimedia power gating support for Fiji.
+-    - drm/amd/amdgpu: add uvd6.0 clock gating support. (v2)
+-    - drm/amd/amdgpu: add vce3.0 clock gating support. (v2)
+-    - drm/amd/amdgpu: enable uvd&vce clock gating for Fiji.
+-    - drm/amdgpu: Prepare DKMS build for powerplay module.
+-    - drm/amd/powerplay: add display configeration changed function in hwmgr for Fiji.
+-    - drm/amd/powerplay: Add thermal protection support for Fiji.
+-    - drm/amd/powerplay: Fix a bug in fan control setting default mode for Tonga and Fiji.
+-    - drm/amd/powerplay: add functions set/get_fan_control_mode in hwmgr for Tonga.
+-    - drm/amd/powerplay: add functions set/get_fan_control_mode in hwmgr for Fiji.
+-    - drm/amd/powerplay: fix boolreturn.cocci warnings
+-    - drm/amd/powerplay: fix bug that dpm funcs in debugfs/sysfs missing.
+-    - drm/amd/powerplay: check whether enable dpm in powerplay.
+-    - drm/amd/powerplay: move shared function of vi to hwmgr. (v2)
+-    - drm/amdgpu/powerplay: enable sysfs and debugfs interfaces late
+-    - drm/amd/powerplay: display gpu load when print performance for tonga.
+-    - drm/powerplay: add debugging output to tonga_processpptables.c
+-    - drm/powerplay: add debugging output to processpptables.c
+-    - drm/powerplay/hwmgr: log errors in tonga_hwmgr_backend_init
+-    - drm/amd/powerplay: Don't return an error if fan table is missing
+-    - amd\powerplay Implement get dal power level
+-    - amd/powerplay: Fix get dal power level
+-    - amd/powerplay: Add structures required to report configuration change
+-    - drm/amdgpu/powerplay: Program a calculated value as Deep Sleep clock.
+-    - drm/amd/powerplay: add point check to avoid NULL point hang.
+-    - drm/amd/powerplay: check whether need to enable thermal control. (v2)
+-    - drm/amd/powerplay: show gpu load when print gpu performance for Cz. (v2)
+-    - drm: powerplay: use div64_s64 instead of do_div
+-    - drm/amd/powerplay: fix a reversed condition
+-    - drm/amdgpu/cgs: cleanup some indenting
+-    - drm/amd/powerplay: precedence bug in init_non_clock_fields()
+-    - drm/amdgpu: fix NULL in vm_grab_id while S3 back
+-    - drm/amd/powerplay: fix bug that NULL checks are reversed.
+-    - drm/amd/powerplay: fix Smatch static checker warnings with indenting (v2)
+-    - drm/amd/powerplay: fix Smatch static checker warnings
+-    - drm/amd/powerplay: add powerplay valid check to avoid null point. (v2)
+-    - drm/amd/powerplay: Reload and initialize the smc firmware on powerplay resume.
+-    - drm/amdgpu: Show gpu load when display gpu performance for Ci.
+-    - drm/amdgpu: Show gpu load when display gpu performance for Fiji of VI.
+-    - drm/amdgpu: fix hex/decimal bug when show gpu load.
+-    - drm/amd/powerplay: add thermal control task when resume.
+-    - drm/amd/powerplay: enable set boot state task
+-    - drm/amd/powerplay: enable power down asic task. (v2)
+-    - drm/amd/powerplay: implement power down asic task for CZ
+-    - drm/amdgpu: add warning to amdgpu_bo_gpu_offset() v2
+-    - drm/amdgpu/cgs: add an interface to access PCI resources
+-    - drm/amdgpu: add irq domain support
+-    - drm/amdgpu/powerplay: include asm/div64.h for do_div()
+-    - drm/sysfs: use kobj_to_dev()
+-    - drm/amd/powerplay: fix static checker warning for return meaningless value.
+-    - drm/amdgpu/cz: add code to enable forcing UVD clocks
+-    - drm/amdgpu/cz: add code to enable forcing VCE clocks
+-    - drm/amdgpu/cz: force uvd clocks when sclks are forced
+-    - drm/amdgpu/cz: force vce clocks when sclks are forced
+-    - drm/amdgpu: use kobj_to_dev()
+-    - drm/radeon: use kobj_to_dev()
+-    - drm/ttm: fix adding foreign BOs to the LRU during init v2
+-    - drm/ttm: fix adding foreign BOs to the swap LRU
+-    - drm/ttm: add ttm_bo_move_to_lru_tail function v2
+-    - drm/amdgpu: move VM page tables to the LRU end on CS v2
+-    - drm/amdgpu: validate duplicates first
+-    - drm/amdgpu: add missing irq.h include
+-    - drm/fb_cma_helper: Remove implicit call to disable_unused_functions
+-    - drm/amdgpu: Add some tweaks to gfx 8 soft reset
+-    - amdkfd: don't open-code memdup_user()
+-    - amdkfd: Copy from the proper user command pointer
+-    - drm/amdgpu: Use drm_calloc_large for VM page_tables array
+-    - amd/powerplay: disable powerplay by default initially
+-    - drm/amdgpu: Allow the driver to load if amdgpu.powerplay=1 on asics without powerplay support
+-    - drm/atomic-helper: Export framebuffer_changed()
+-    - drm/amd/amdgpu: Improve amdgpu_dpm* macros to avoid unexpected result (v2)
+-    - drm/amdgpu: add a message to indicate when powerplay is enabled (v2)
+-    - drm/amdgpu: fix next_rptr handling for debugfs
+-    - drm/radeon: Ensure radeon bo is unreserved in radeon_gem_va_ioctl
+-    - drm/radeon: only init fbdev if we have connectors
+-    - drm/amdgpu: don't init fbdev if we don't have any connectors
+-    - drm/amd/powerplay: Update SMU firmware loading for Stoney
+-    - drm/amdgpu: fix non-ANSI declaration of amdgpu_amdkfd_gfx_*_get_functions()
+-    - drm/amdkfd: Remove unnecessary cast in kfree
+-    - drm/amdgpu: only move pt bos in LRU list on success
+-    - drm/amdgpu: mask out WC from BO on unsupported arches
+-    - drm/amdgpu/gfx8: enable cp inst/reg error interrupts
+-    - drm/amdgpu/gfx7: enable cp inst/reg error interrupts
+-    - drm/amdgpu: load MEC ucode manually on iceland
+-    - drm/amdgpu: disable uvd and vce clockgating on Fiji
+-    - drm/amdgpu: add pcie cap module parameters (v2)
+-    - drm/amdgpu/cik: don't mess with aspm if gpu is root bus
+-    - drm/amdgpu/dpm/ci: switch over to the common pcie caps interface
+-    - drm/amdgpu: handle uvd pg flags properly
+-    - drm/amdgpu: handle vce pg flags properly
+-    - drm/amdgpu: clean up vce pg flags for cz/st
+-    - drm/amdgpu: be consistent with uvd cg flags
+-    - drm/amd/powerplay/cz: disable uvd pg
+-    - drm/amd/powerplay/cz: disable vce pg
+-    - drm/amd/powerplay/tonga: disable uvd pg
+-    - drm/amd/powerplay/tonga: disable vce pg
+-    - drm/amdgpu: add a cgs interface to fetch cg and pg flags
+-    - drm/amdgpu: remove unused cg defines
+-    - drma/dmgpu: move cg and pg flags into shared headers
+-    - drm/amdgpu/tonga: plumb pg flags through to powerplay
+-    - drm/amdgpu/cz: plumb pg flags through to powerplay
+-    - SAUCE: drm/amdgpu/cz: enable/disable vce dpm even if vce pg is disabled
+-
+-  * mlx4_core Set UAR page size to 4KB regardless of system page size (LP:
+-    #1552632)
+-    - net/mlx4_core: Set UAR page size to 4KB regardless of system page size
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Config] CONFIG_CAVIUM_ERRATUM_27456=y
+-
+-  * Miscellaneous upstream changes
+-    - net: thunderx: Fix for Qset error due to CQ full
+-    - ahci: Workaround for ThunderX Errata#22536
+-    - arm64: Add workaround for Cavium erratum 27456
+-    - tipc: fix nullptr crash during subscription cancel
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 07 Mar 2016 05:04:22 -0700
+-
+-linux (4.4.0-11.26) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1553391
+-
+-  * Xenial update to v4.4.4 stable release (LP: #1553179)
+-    - af_iucv: Validate socket address length in iucv_sock_bind()
+-    - gro: Make GRO aware of lightweight tunnels.
+-    - net: dp83640: Fix tx timestamp overflow handling.
+-    - tunnels: Allow IPv6 UDP checksums to be correctly controlled.
+-    - lwt: fix rx checksum setting for lwt devices tunneling over ipv6
+-    - tcp: fix NULL deref in tcp_v4_send_ack()
+-    - af_unix: fix struct pid memory leak
+-    - pptp: fix illegal memory access caused by multiple bind()s
+-    - sctp: allow setting SCTP_SACK_IMMEDIATELY by the application
+-    - net: dsa: fix mv88e6xxx switches
+-    - tipc: fix connection abort during subscription cancel
+-    - inet: frag: Always orphan skbs inside ip_defrag()
+-    - switchdev: Require RTNL mutex to be held when sending FDB notifications
+-    - tcp: beware of alignments in tcp_get_info()
+-    - ipv6: enforce flowi6_oif usage in ip6_dst_lookup_tail()
+-    - ipv6/udp: use sticky pktinfo egress ifindex on connect()
+-    - ipv6: addrconf: Fix recursive spin lock call
+-    - ipv6: fix a lockdep splat
+-    - unix: correctly track in-flight fds in sending process user_struct
+-    - tcp: do not drop syn_recv on all icmp reports
+-    - net:Add sysctl_max_skb_frags
+-    - tg3: Fix for tg3 transmit queue 0 timed out when too many gso_segs
+-    - enic: increment devcmd2 result ring in case of timeout
+-    - sctp: translate network order to host order when users get a hmacid
+-    - net: Copy inner L3 and L4 headers as unaligned on GRE TEB
+-    - flow_dissector: Fix unaligned access in __skb_flow_dissector when used by
+-      eth_get_headlen
+-    - bpf: fix branch offset adjustment on backjumps after patching ctx expansion
+-    - bonding: Fix ARP monitor validation
+-    - ipv4: fix memory leaks in ip_cmsg_send() callers
+-    - af_unix: Don't set err in unix_stream_read_generic unless there was an error
+-    - af_unix: Guard against other == sk in unix_dgram_sendmsg
+-    - tipc: fix premature addition of node to lookup table
+-    - tcp: md5: release request socket instead of listener
+-    - qmi_wwan: add "4G LTE usb-modem U901"
+-    - net/mlx4_en: Count HW buffer overrun only once
+-    - net/mlx4_en: Avoid changing dev->features directly in run-time
+-    - l2tp: Fix error creating L2TP tunnels
+-    - pppoe: fix reference counting in PPPoE proxy
+-    - net_sched fix: reclassification needs to consider ether protocol changes
+-    - route: check and remove route cache when we get route
+-    - tcp/dccp: fix another race at listener dismantle
+-    - IFF_NO_QUEUE: Fix for drivers not calling ether_setup()
+-    - rtnl: RTM_GETNETCONF: fix wrong return value
+-    - tipc: unlock in error path
+-    - unix_diag: fix incorrect sign extension in unix_lookup_by_ino
+-    - sctp: Fix port hash table size computation
+-    - ext4: fix bh->b_state corruption
+-    - ARM: debug-ll: fix BCM63xx entry for multiplatform
+-    - arm64: errata: Add -mpc-relative-literal-loads to build flags
+-    - KVM: s390: fix guest fprs memory leak
+-    - devm_memremap: Fix error value when memremap failed
+-    - drm/gma500: Use correct unref in the gem bo create function
+-    - ARM: 8457/1: psci-smp is built only for SMP
+-    - lib/ucs2_string: Add ucs2 -> utf8 helper functions
+-    - efi: Use ucs2_as_utf8 in efivarfs instead of open coding a bad version
+-    - efi: Do variable name validation tests in utf8
+-    - efi: Make our variable validation list include the guid
+-    - efi: Make efivarfs entries immutable by default
+-    - efi: Add pstore variables to the deletion whitelist
+-    - lib/ucs2_string: Correct ucs2 -> utf8 conversion
+-    - bcache: fix a livelock when we cause a huge number of cache misses
+-    - bcache: Add a cond_resched() call to gc
+-    - bcache: clear BCACHE_DEV_UNLINK_DONE flag when attaching a backing device
+-    - bcache: fix a leak in bch_cached_dev_run()
+-    - bcache: unregister reboot notifier if bcache fails to unregister device
+-    - bcache: allows use of register in udev to avoid "device_busy" error.
+-    - bcache: Change refill_dirty() to always scan entire disk if necessary
+-    - dm thin: fix race condition when destroying thin pool workqueue
+-    - can: ems_usb: Fix possible tx overflow
+-    - usb: dwc3: Fix assignment of EP transfer resources
+-    - USB: cp210x: add IDs for GE B650V3 and B850V3 boards
+-    - USB: option: add support for SIM7100E
+-    - USB: option: add "4G LTE usb-modem U901"
+-    - drivers: android: correct the size of struct binder_uintptr_t for
+-      BC_DEAD_BINDER_DONE
+-    - spi: omap2-mcspi: Prevent duplicate gpio_request
+-    - iw_cxgb3: Fix incorrectly returning error on success
+-    - drm/i915: shut up gen8+ SDE irq dmesg noise
+-    - ocfs2: unlock inode if deleting inode from orphan fails
+-    - mm: thp: fix SMP race condition between THP page fault and MADV_DONTNEED
+-    - mm: numa: quickly fail allocations for NUMA balancing on full nodes
+-    - genirq: Validate action before dereferencing it in handle_irq_event_percpu()
+-    - clocksource/drivers/vt8500: Increase the minimum delta
+-    - s390/kvm: remove dependency on struct save_area definition
+-    - KVM: s390: fix memory overwrites when vx is disabled
+-    - Btrfs: add missing brelse when superblock checksum fails
+-    - Btrfs: igrab inode in writepage
+-    - btrfs: statfs: report zero available if metadata are exhausted
+-    - Btrfs: send, don't BUG_ON() when an empty symlink is found
+-    - Btrfs: fix number of transaction units required to create symlink
+-    - Btrfs: fix transaction handle leak on failure to create hard link
+-    - Btrfs: Initialize btrfs_root->highest_objectid when loading tree root and
+-      subvolume roots
+-    - btrfs: initialize the seq counter in struct btrfs_device
+-    - s390: fix normalization bug in exception table sorting
+-    - s390/dasd: prevent incorrect length error under z/VM after PAV changes
+-    - s390/dasd: fix refcount for PAV reassignment
+-    - s390/dasd: fix performance drop
+-    - uml: flush stdout before forking
+-    - uml: fix hostfs mknod()
+-    - um: link with -lpthread
+-    - locks: fix unlock when fcntl_setlk races with a close
+-    - rtlwifi: rtl_pci: Fix kernel panic
+-    - rtlwifi: rtl8192cu: Add missing parameter setup
+-    - rtlwifi: rtl8192ce: Fix handling of module parameters
+-    - rtlwifi: rtl8192de: Fix incorrect module parameter descriptions
+-    - rtlwifi: rtl8723ae: Fix initialization of module parameters
+-    - rtlwifi: rtl8192se: Fix module parameter initialization
+-    - rtlwifi: rtl8188ee: Fix module parameter initialization
+-    - rtlwifi: rtl8723be: Fix module parameter initialization
+-    - mei: fix fasync return value on error
+-    - mei: validate request value in client notify request ioctl
+-    - namei: ->d_inode of a pinned dentry is stable only for positives
+-    - rc: sunxi-cir: Initialize the spinlock properly
+-    - media: dvb-core: Don't force CAN_INVERSION_AUTO in oneshot mode
+-    - si2157: return -EINVAL if firmware blob is too big
+-    - gspca: ov534/topro: prevent a division by 0
+-    - vb2: fix a regression in poll() behavior for output,streams
+-    - tda1004x: only update the frontend properties if locked
+-    - dm space map metadata: remove unused variable in brb_pop()
+-    - dm snapshot: fix hung bios when copy error occurs
+-    - dm: fix dm_rq_target_io leak on faults with .request_fn DM w/ blk-mq paths
+-    - coresight: checking for NULL string in coresight_name_match()
+-    - irqchip/omap-intc: Add support for spurious irq handling
+-    - irqchip/mxs: Add missing set_handle_irq()
+-    - irqchip/atmel-aic: Fix wrong bit operation for IRQ priority
+-    - irqchip/gic-v3-its: Fix double ICC_EOIR write for LPI in EOImode==1
+-    - posix-clock: Fix return code on the poll method's error path
+-    - clockevents/tcb_clksrc: Prevent disabling an already disabled clock
+-    - mmc: usdhi6rol0: handle NULL data in timeout
+-    - mmc: sdhci-pci: Do not default to 33 Ohm driver strength for Intel SPT
+-    - mmc: sdio: Fix invalid vdd in voltage switch power cycle
+-    - mmc: mmc: Fix incorrect use of driver strength switching HS200 and HS400
+-    - mmc: sdhci: Fix sdhci_runtime_pm_bus_on/off()
+-    - mmc: core: Enable tuning according to the actual timing
+-    - mmc: mmci: fix an ages old detection error
+-    - mmc: sdhci-acpi: Fix card detect race for Intel BXT/APL
+-    - mmc: pxamci: fix again read-only gpio detection polarity
+-    - mmc: sdhci-pci: Fix card detect race for Intel BXT/APL
+-    - mmc: sdhci: Allow override of mmc host operations
+-    - mmc: sdhci: Allow override of get_cd() called from sdhci_request()
+-    - Bluetooth: Use continuous scanning when creating LE connections
+-    - Bluetooth: Add support of Toshiba Broadcom based devices
+-    - Bluetooth: Fix incorrect removing of IRKs
+-    - Bluetooth: 6lowpan: Fix kernel NULL pointer dereferences
+-    - Bluetooth: 6lowpan: Fix handling of uncompressed IPv6 packets
+-    - time: Avoid signed overflow in timekeeping_get_ns()
+-    - cputime: Prevent 32bit overflow in time[val|spec]_to_cputime()
+-    - Revert "MIPS: Fix PAGE_MASK definition"
+-    - MIPS: Loongson-3: Fix SMP_ASK_C0COUNT IPI handler
+-    - MIPS: hpet: Choose a safe value for the ETIME check
+-    - MIPS: Fix some missing CONFIG_CPU_MIPSR6 #ifdefs
+-    - MIPS: Fix buffer overflow in syscall_get_arguments()
+-    - EDAC: Robustify workqueues destruction
+-    - EDAC, mc_sysfs: Fix freeing bus' name
+-    - sparc64: fix incorrect sign extension in sys_sparc64_personality
+-    - clk: exynos: use irqsave version of spin_lock to avoid deadlock with irqs
+-    - regulator: axp20x: Fix GPIO LDO enable value for AXP22x
+-    - regulator: mt6311: MT6311_REGULATOR needs to select REGMAP_I2C
+-    - virtio_balloon: fix race by fill and leak
+-    - virtio_balloon: fix race between migration and ballooning
+-    - virtio_pci: fix use after free on release
+-    - drm/vmwgfx: Fix an incorrect lock check
+-    - drm/vmwgfx: Fix a width / pitch mismatch on framebuffer updates
+-    - drm/vmwgfx: respect 'nomodeset'
+-    - drm/amdgpu: Fix off-by-one errors in amdgpu_vm_bo_map
+-    - drm/amdgpu: call hpd_irq_event on resume
+-    - drm/amdgpu: fix lost sync_to if scheduler is enabled.
+-    - drm/amdgpu: fix tonga smu resume
+-    - drm/amdgpu: fix amdgpu_bo_pin_restricted VRAM placing v2
+-    - drm/amdgpu: no need to load MC firmware on fiji
+-    - drm/amdgpu: move gmc7 support out of CIK dependency
+-    - drm/amdgpu: iceland use CI based MC IP
+-    - drm/amdgpu: The VI specific EXE bit should only apply to GMC v8.0 above
+-    - drm/amdgpu: pull topaz gmc bits into gmc_v7
+-    - drm/amdgpu: drop topaz support from gmc8 module
+-    - drm/amdgpu: don't load MEC2 on topaz
+-    - drm/amdgpu: remove exp hardware support from iceland
+-    - drm/amdgpu: fix s4 resume
+-    - drm/amdgpu: remove unnecessary forward declaration
+-    - drm/amdgpu: hold reference to fences in amdgpu_sa_bo_new (v2)
+-    - drm/amdgpu: fix issue with overlapping userptrs
+-    - drm/amdgpu: use post-decrement in error handling
+-    - drm/amdgpu: Don't hang in amdgpu_flip_work_func on disabled crtc.
+-    - drm/amdgpu/pm: adjust display configuration after powerstate
+-    - drm/nouveau/kms: take mode_config mutex in connector hotplug path
+-    - drm/nouveau/display: Enable vblank irqs after display engine is on again.
+-    - drm/nouveau/disp/dp: ensure sink is powered up before attempting link
+-      training
+-    - drm/nouveau: platform: Fix deferred probe
+-    - drm/dp/mst: process broadcast messages correctly
+-    - drm/dp/mst: always send reply for UP request
+-    - drm/dp/mst: fix in MSTB RAD initialization
+-    - drm/dp/mst: fix in RAD element access
+-    - drm: Add drm_fixp_from_fraction and drm_fixp2int_ceil
+-    - drm/dp/mst: Calculate MST PBN with 31.32 fixed point
+-    - drm/dp/mst: move GUID storage from mgr, port to only mst branch
+-    - drm/dp/mst: Reverse order of MST enable and clearing VC payload table.
+-    - drm/dp/mst: deallocate payload on port destruction
+-    - drm/radeon: Fix off-by-one errors in radeon_vm_bo_set_addr
+-    - drm/radeon: call hpd_irq_event on resume
+-    - drm/radeon: Fix "slow" audio over DP on DCE8+
+-    - drm/radeon: clean up fujitsu quirks
+-    - drm/radeon: properly byte swap vce firmware setup
+-    - drm/radeon: cleaned up VCO output settings for DP audio
+-    - drm/radeon: Add a common function for DFS handling
+-    - drm/radeon: fix DP audio support for APU with DCE4.1 display engine
+-    - drm: add helper to check for wc memory support
+-    - drm/radeon: mask out WC from BO on unsupported arches
+-    - drm/radeon: hold reference to fences in radeon_sa_bo_new
+-    - drm: fix missing reference counting decrease
+-    - drm/i915: Restore inhibiting the load of the default context
+-    - drm/i915: intel_hpd_init(): Fix suspend/resume reprobing
+-    - drm/i915: Init power domains early in driver load
+-    - drm/i915: Make sure DC writes are coherent on flush.
+-    - drm/i915/dp: fall back to 18 bpp when sink capability is unknown
+-    - drm/i915: Don't reject primary plane windowing with color keying enabled on
+-      SKL+
+-    - drm/i915/skl: Don't skip mst encoders in skl_ddi_pll_select()
+-    - drm/i915/dsi: defend gpio table against out of bounds access
+-    - drm/i915/dsi: don't pass arbitrary data to sideband
+-    - drm/i915: fix error path in intel_setup_gmbus()
+-    - drm/qxl: use kmalloc_array to alloc reloc_info in qxl_process_single_command
+-    - drm/radeon: use post-decrement in error handling
+-    - drm: No-Op redundant calls to drm_vblank_off() (v2)
+-    - drm: Prevent vblank counter bumps > 1 with active vblank clients. (v2)
+-    - drm: Fix drm_vblank_pre/post_modeset regression from Linux 4.4
+-    - drm: Fix treatment of drm_vblank_offdelay in drm_vblank_on() (v2)
+-    - drm/radeon: Don't hang in radeon_flip_work_func on disabled crtc. (v2)
+-    - drm/radeon/pm: adjust display configuration after powerstate
+-    - make sure that freeing shmem fast symlinks is RCU-delayed
+-    - toshiba_acpi: Fix blank screen at boot if transflective backlight is
+-      supported
+-    - ideapad-laptop: Add Lenovo ideapad Y700-17ISK to no_hw_rfkill dmi list
+-    - ideapad-laptop: Add Lenovo Yoga 700 to no_hw_rfkill dmi list
+-    - uapi: update install list after nvme.h rename
+-    - lib: sw842: select crc32
+-    - ACPI / video: Add disable_backlight_sysfs_if quirk for the Toshiba Portege
+-      R700
+-    - ACPI / video: Add disable_backlight_sysfs_if quirk for the Toshiba Satellite
+-      R830
+-    - ACPI: Revert "ACPI / video: Add Dell Inspiron 5737 to the blacklist"
+-    - ACPI / PCI / hotplug: unlock in error path in acpiphp_enable_slot()
+-    - nfit: fix multi-interface dimm handling, acpi6.1 compatibility
+-    - dmaengine: dw: fix cyclic transfer setup
+-    - dmaengine: dw: fix cyclic transfer callbacks
+-    - dmaengine: at_xdmac: fix resume for cyclic transfers
+-    - dmaengine: dw: disable BLOCK IRQs for non-cyclic xfer
+-    - IB/cm: Fix a recently introduced deadlock
+-    - IB/qib: fix mcast detach when qp not attached
+-    - IB/qib: Support creating qps with GFP_NOIO flag
+-    - IB/mlx5: Expose correct maximum number of CQE capacity
+-    - Thermal: initialize thermal zone device correctly
+-    - Thermal: handle thermal zone device properly during system sleep
+-    - Thermal: do thermal zone update after a cooling device registered
+-    - hwmon: (dell-smm) Blacklist Dell Studio XPS 8000
+-    - hwmon: (gpio-fan) Remove un-necessary speed_index lookup for thermal hook
+-    - hwmon: (ads1015) Handle negative conversion values correctly
+-    - cpufreq: pxa2xx: fix pxa_cpufreq_change_voltage prototype
+-    - cpufreq: Fix NULL reference crash while accessing policy->governor_data
+-    - seccomp: always propagate NO_NEW_PRIVS on tsync
+-    - libceph: fix ceph_msg_revoke()
+-    - libceph: don't bail early from try_read() when skipping a message
+-    - libceph: use the right footer size when skipping a message
+-    - libceph: don't spam dmesg with stray reply warnings
+-    - sd: Optimal I/O size is in bytes, not sectors
+-    - Staging: speakup: Fix getting port information
+-    - Revert "Staging: panel: usleep_range is preferred over udelay"
+-    - cdc-acm:exclude Samsung phone 04e8:685d
+-    - perf stat: Do not clean event's private stats
+-    - tick/nohz: Set the correct expiry when switching to nohz/lowres mode
+-    - rfkill: fix rfkill_fop_read wait_event usage
+-    - mac80211: Requeue work after scan complete for all VIF types.
+-    - workqueue: handle NUMA_NO_NODE for unbound pool_workqueue lookup
+-    - Revert "workqueue: make sure delayed work run in local cpu"
+-    - ALSA: hda - Apply clock gate workaround to Skylake, too
+-    - ALSA: hda - Fixing background noise on Dell Inspiron 3162
+-    - target: Fix LUN_RESET active I/O handling for ACK_KREF
+-    - target: Fix LUN_RESET active TMR descriptor handling
+-    - target: Fix TAS handling for multi-session se_node_acls
+-    - target: Fix remote-port TMR ABORT + se_cmd fabric stop
+-    - target: Fix race with SCF_SEND_DELAYED_TAS handling
+-    - spi: atmel: fix gpio chip-select in case of non-DT platform
+-    - libata: fix sff host state machine locking while polling
+-    - ARCv2: STAR 9000950267: Handle return from intr to Delay Slot #2
+-    - ARCv2: SMP: Emulate IPI to self using software triggered interrupt
+-    - PCI/AER: Flush workqueue on device remove to avoid use-after-free
+-    - cpuset: make mm migration asynchronous
+-    - cgroup: make sure a parent css isn't offlined before its children
+-    - writeback: keep superblock pinned during cgroup writeback association
+-      switches
+-    - phy: core: fix wrong err handle for phy_power_on
+-    - i2c: i801: Adding Intel Lewisburg support for iTCO
+-    - bio: return EINTR if copying to user space got interrupted
+-    - block: fix use-after-free in dio_bio_complete
+-    - nfs: fix nfs_size_to_loff_t
+-    - NFSv4: Fix a dentry leak on alias use
+-    - of/irq: Fix msi-map calculation for nonzero rid-base
+-    - KVM: async_pf: do not warn on page allocation failures
+-    - KVM: arm/arm64: vgic: Ensure bitmaps are long enough
+-    - KVM: x86: fix missed hardware breakpoints
+-    - KVM: x86: MMU: fix ubsan index-out-of-range warning
+-    - powerpc/eeh: Fix partial hotplug criterion
+-    - tracing: Fix showing function event in available_events
+-    - sunrpc/cache: fix off-by-one in qword_get()
+-    - kernel/resource.c: fix muxed resource handling in __request_region()
+-    - do_last(): don't let a bogus return value from ->open() et.al. to confuse us
+-    - ARM: OMAP2+: Fix onenand initialization to avoid filesystem corruption
+-    - ARM: at91/dt: fix typo in sama5d2 pinmux descriptions
+-    - xen/arm: correctly handle DMA mapping of compound pages
+-    - xen/scsiback: correct frontend counting
+-    - xen/pciback: Check PF instead of VF for PCI_COMMAND_MEMORY
+-    - xen/pciback: Save the number of MSI-X entries to be copied later.
+-    - xen/pcifront: Fix mysterious crashes when NUMA locality information was
+-      extracted.
+-    - should_follow_link(): validate ->d_seq after having decided to follow
+-    - do_last(): ELOOP failure exit should be done after leaving RCU mode
+-    - hpfs: don't truncate the file when delete fails
+-    - x86/irq: Call chip->irq_set_affinity in proper context
+-    - x86/irq: Fix a race in x86_vector_free_irqs()
+-    - x86/irq: Validate that irq descriptor is still active
+-    - x86/irq: Do not use apic_chip_data.old_domain as temporary buffer
+-    - x86/irq: Reorganize the return path in assign_irq_vector
+-    - x86/irq: Reorganize the search in assign_irq_vector
+-    - x86/irq: Check vector allocation early
+-    - x86/irq: Copy vectormask instead of an AND operation
+-    - x86/irq: Get rid of code duplication
+-    - x86/irq: Remove offline cpus from vector cleanup
+-    - x86/irq: Clear move_in_progress before sending cleanup IPI
+-    - x86/irq: Remove the cpumask allocation from send_cleanup_vector()
+-    - x86/irq: Remove outgoing CPU from vector cleanup mask
+-    - x86/irq: Call irq_force_move_complete with irq descriptor
+-    - x86/irq: Plug vector cleanup race
+-    - IB/cma: Fix RDMA port validation for iWarp
+-    - iwlwifi: dvm: fix WoWLAN
+-    - iwlwifi: pcie: properly configure the debug buffer size for 8000
+-    - iwlwifi: update and fix 7265 series PCI IDs
+-    - iwlwifi: mvm: don't allow sched scans without matches to be started
+-    - Revert "UBUNTU: SAUCE: bcache: prevent crash on changing writeback_running"
+-    - bcache: prevent crash on changing writeback_running
+-    - Linux 4.4.4
+-
+-  * mlx4_en didn't choose time-stamping shift value according to HW frequency
+-    (LP: #1552627)
+-    - net/mlx4_en: Choose time-stamping shift value according to HW frequency
+-
+-  * [Ubuntu 16.04] Help to flush kernel panics to console (LP: #1552332)
+-    - target/transport: add flag to indicate CPU Affinity is observed
+-    - powerpc/powernv: Add a kmsg_dumper that flushes console output on panic
+-    - powerpc/powernv: Fix OPAL_CONSOLE_FLUSH prototype and usages
+-
+-  * [Ubuntu 16.04] Update qla2xxx driver for POWER (QLogic) (LP: #1541456)
+-    - qla2xxx: Fix warning reported by static checker
+-    - qla2xxx: Fix TMR ABORT interaction issue between qla2xxx and TCM
+-    - qla2xxx: Fix stale pointer access.
+-    - qla2xxx: Use ATIO type to send correct tmr response
+-    - qla2xxx: use TARGET_SCF_USE_CPUID flag to indiate CPU Affinity
+-
+-  * [s390x] zfcp.ko missing from scsi-modules udeb (LP: #1552314)
+-    - [Config] Add s390x zfcp to scsi-modules udeb
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 02 Mar 2016 08:08:16 -0700
+-
+-linux (4.4.0-10.25) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1552247
+-
+-  * linux:  4.4.0-9.X fails yama ptrace restrictions tests (LP: #1551894)
+-    - security: let security modules use PTRACE_MODE_* with bitmasks
+-
+-  * [wily][regression] systemtap script compilation broken by new kernels (LP: #1545330)
+-    - SAUCE: (noup) locking/qspinlock: Move __ARCH_SPIN_LOCK_UNLOCKED to qspinlock_types.h
+-
+-  * [Feature]SD/SDIO/eMMC support for Broxton-P (LP: #1520454)
+-    - mmc: sdhci: 64-bit DMA actually has 4-byte alignment
+-    - mmc: sdhci: Fix DMA descriptor with zero data length
+-
+-  * Miscellaneous Ubuntu changes
+-    - SAUCE: (noup) cgroup: fix and restructure error handling in copy_cgroup_ns()
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Feb 2016 13:04:14 -0700
+-
+-linux (4.4.0-9.24) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1551319
+-
+-  * AppArmor logs denial for when the device path is ENOENT (LP: #1482943)
+-    - SAUCE: apparmor: fix log of apparmor audit message when kern_path() fails
+-
+-  * BUG: unable to handle kernel NULL pointer dereference (aa_label_merge) (LP:
+-    #1448912)
+-    - SAUCE: apparmor: Fix: insert race between label_update and label_merge
+-    - SAUCE: apparmor: Fix: ensure aa_get_newest will trip debugging if the
+-      replacedby is not setup
+-    - SAUCE: apparmor: Fix: label merge handling of marking unconfined and stale
+-    - SAUCE: apparmor: Fix: refcount race between locating in labelset and get
+-    - SAUCE: apparmor: Fix: ensure new labels resulting from merge have a
+-      replacedby
+-    - SAUCE: apparmor: Fix: label_vec_merge insertion
+-    - SAUCE: apparmor: Fix: deadlock in aa_put_label() call chain
+-    - SAUCE: apparmor: Fix: add required locking of __aa_update_replacedby on
+-      merge path
+-    - SAUCE: apparmor: Fix: convert replacedby update to be protected by the
+-      labelset lock
+-    - SAUCE: apparmor: Fix: update replacedby allocation to take a gfp parameter
+-
+-  * apparmor kernel BUG kills firefox (LP: #1430546)
+-    - SAUCE: apparmor: Disallow update of cred when then subjective != the
+-      objective cred
+-    - SAUCE: apparmor: rework retrieval of the current label in the profile update
+-      case
+-
+-  * sleep from invalid context in aa_move_mount (LP: #1539349)
+-    - SAUCE: apparmor: fix sleep from invalid context
+-
+-  * s390x: correct restore of high gprs on signal return (LP: #1550468)
+-    - s390/compat: correct restore of high gprs on signal return
+-
+-  * missing SMAP support (LP: #1550517)
+-    - x86/entry/compat: Add missing CLAC to entry_INT80_32
+-
+-  * Floating-point exception handler receives empty Data-Exception Code in
+-    Floating Point Control register (LP: #1548414)
+-    - s390/fpu: signals vs. floating point control register
+-
+-  * kvm fails to boot GNU Hurd kernels with 4.4 Xenial kernel (LP: #1550596)
+-    - KVM: x86: fix conversion of addresses to linear in 32-bit protected mode
+-
+-  * Surelock GA2 SP1: capiredp01: cxl_init_adapter fails for CAPI devices
+-    0000:01:00.0 and 0005:01:00.0 after upgrading to 840.10 Platform firmware
+-    build fips840/b1208b_1604.840 (LP: #1532914)
+-    - cxl: Fix PSL timebase synchronization detection
+-
+-  * [Feature]EDAC support for Knights Landing (LP: #1519631)
+-    - EDAC, sb_edac: Set fixed DIMM width on Xeon Knights Landing
+-
+-  * Various failures of kernel_security suite on Xenial kernel on s390x arch
+-    (LP: #1531327)
+-    - [config] s390x -- CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
+-
+-  * Unable to install VirtualBox Guest Service in 15.04 (LP: #1434579)
+-    - [Config] Provides: virtualbox-guest-modules when appropriate
+-
+-  * linux is missing provides for virtualbox-guest-modules [i386 amd64 x32] (LP:
+-    #1507588)
+-    - [Config] Provides: virtualbox-guest-modules when appropriate
+-
+-  * Backport more recent driver for SKL, KBL and BXT graphics (LP: #1540390)
+-    - SAUCE: i915_bpo: Provide a backport driver for SKL, KBL & BXT graphics
+-    - SAUCE: i915_bpo: Update intel_ips.h file location
+-    - SAUCE: i915_bpo: Rename the backport driver to i915_bpo
+-    - SAUCE: i915_bpo: Add i915_bpo_*() calls for ubuntu/i915
+-    - drm/i915: remove an extra level of indirection in PCI ID list
+-    - drm/i915/kbl: Add Kabylake PCI ID
+-    - drm/i915/kbl: Add Kabylake GT4 PCI ID
+-    - mm: Export nr_swap_pages
+-    - async: export current_is_async()
+-    - drm: fix potential dangling else problems in for_each_ macros
+-    - dp/mst: add SDP stream support
+-    - drm: Implement drm_modeset_lock_all_ctx()
+-    - drm: Add "prefix" parameter to drm_rect_debug_print()
+-    - drm/i915: Set connector_state->connector using the helper.
+-    - drm/atomic: add connector mask to drm_crtc_state.
+-    - drm/i915: Report context GTT size
+-    - drm/i915: Add get_eld audio component
+-    - SAUCE: Backport I915_PARAM_HAS_EXEC_SOFTPIN and EXEC_OBJECT_PINNED
+-    - SAUCE: i915_bpo: Revert passing plane/encoder name
+-    - SAUCE: sound/hda: Load i915_bpo from the hda driver on SKL/KBL/BXT
+-    - SAUCE: i915_bpo: Support only SKL, KBL and BXT with the backport driver
+-    - drm/i915/bxt: update list of PCIIDs
+-    - drm/i915/skl: Add missing SKL ids
+-    - SAUCE: i915_bpo: Revert "drm/i915: Defer probe if gmux is present but its
+-      driver isn't"
+-    - SAUCE: uapi/drm/i915: Backport I915_EXEC_BSD_MASK
+-    - drm/atomic: Do not unset crtc when an encoder is stolen
+-    - drm/i915: Update connector_mask during readout, v2.
+-    - drm/atomic: Add encoder_mask to crtc_state, v3.
+-    - SAUCE: drm/core: Add drm_encoder_index.
+-    - SAUCE: i915_bpo: Revert "drm/i915: Switch DDC when reading the EDID"
+-    - i915_bpo: [Config] Enable CONFIG_DRM_I915_BPO=m
+-
+-  * arm64: guest hangs when ntpd is running (LP: #1549494)
+-    - hrtimer: Add support for CLOCK_MONOTONIC_RAW
+-    - hrtimer: Catch illegal clockids
+-    - KVM: arm/arm64: timer: Switch to CLOCK_MONOTONIC_RAW
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Debian] git-ubuntu-log -- wrap long bug and commit titles
+-    - [Config] CONFIG_ARM_SMMU=y on arm64
+-    - rebase to v4.4.3
+-    - [Debian] git-ubuntu-log -- ensure we get the last commit
+-    - [Config] fix up spelling of probably again
+-    - [Debian] perf -- build in the context of the full generated local headers
+-    - SAUCE: tools: lib/bpf -- add generated headers to search path
+-    - SAUCE: proc: Always set super block owner to init_user_ns
+-    - SAUCE: fix-up: kern_mount fail path should not be doing put_buffers()
+-    - SAUCE: apparmor: Fix: oops do to invalid null ptr deref in label print fns
+-    - SAUCE: apparmor: debug: POISON label and replaceby pointer on free
+-    - SAUCE: apparmor: add underscores to indicate aa_label_next_not_in_set() use
+-      needs locking
+-    - SAUCE: apparmor: Fix: refcount leak in aa_label_merge
+-    - SAUCE: apparmor: ensure that repacedby sharing is done correctly
+-    - SAUCE: apparmor Fix: refcount bug in pivotroot mediation
+-    - SAUCE: apparmor: Fix: now that insert can force replacement use it instead
+-      of remove_and_insert
+-    - SAUCE: apparmor: Fix: refcount bug when inserting label update that
+-      transitions ns
+-    - SAUCE: apparmor: Fix: break circular refcount for label that is directly
+-      freed.
+-    - SAUCE: apparmor: Don't remove label on rcu callback if the label has already
+-      been removed
+-    - SAUCE: apparmor: Fix: query label file permission
+-    - SAUCE: apparmor: fix: ref count leak when profile sha1 hash is read
+-    - SAUCE: fixup: cleanup return handling of labels
+-    - SAUCE: fix: replacedby forwarding is not being properly update when ns is
+-      destroyed
+-    - SAUCE: fixup: make __share_replacedby private to get rid of build warning
+-    - SAUCE: fixup: 20/23 locking issue around in __label_update
+-    - SAUCE: fixup: get rid of unused var build warning
+-    - SAUCE: fixup: cast poison values to remove warnings
+-    - SAUCE: apparmor: fix refcount race when finding a child profile
+-    - SAUCE: fixup: warning about aa_label_vec_find_or_create not being static
+-    - SAUCE: fix: audit "no_new_privs" case for exec failure
+-    - SAUCE: Fixup: __label_update() still doesn't handle some cases correctly.
+-    - SAUCE: Move replacedby allocation into label_alloc
+-    - [Debian] supply zfs dkms Provides: based on do_zfs
+-    - [Config] supply zfs dkms Provides: based on do_zfs
+-    - [Config] drop linux-image-3.0 provides
+-
+-  * Miscellaneous upstream changes
+-    - x86/mpx: Fix off-by-one comparison with nr_registers
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.4.3
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 25 Feb 2016 19:47:55 -0700
+-
+-linux (4.4.0-8.23) xenial; urgency=low
+-
+-  * cgroup namespace mounts broken in containers (LP: #1549398)
+-    - SAUCE: kernfs: Always set super block owner to init_user_ns
+-
+-  * 4.4.0-7.22 no longer boots on arm64 (LP: #1547718)
+-    - arm64: mm: avoid calling apply_to_page_range on empty range
+-    - UBUNTU SAUCE: arm: mm: avoid calling apply_to_page_range on empty range
+-
+-  * kernel install failed /bin/cp: cannot stat ‘/boot/initrd.img-4.3.0-7-generic’: No such file or directory (LP: #1536810)
+-    - [Config] postinst -- handle recreating symlinks when a real file is present
+-
+-  * insecure overlayfs xattrs handling in copy_up (LP: #1534961)
+-    - SAUCE: cred: Add clone_cred() interface
+-    - SAUCE: overlayfs: Use mounter's credentials instead of selectively raising caps
+-    - SAUCE: overlayfs: Skip permission checking for trusted.overlayfs.* xattrs
+-    - SAUCE: overlayfs: Be more careful about copying up sxid files
+-    - SAUCE: overlayfs: Propogate nosuid from lower and upper mounts
+-
+-  * overlayfs over fuse should refuse copy_up of files if uid/gid not mapped (LP: #1535150)
+-    - SAUCE: cred: Add clone_cred() interface
+-    - SAUCE: overlayfs: Use mounter's credentials instead of selectively raising caps
+-    - SAUCE: overlayfs: Skip permission checking for trusted.overlayfs.* xattrs
+-    - SAUCE: overlayfs: Be more careful about copying up sxid files
+-    - SAUCE: overlayfs: Propogate nosuid from lower and upper mounts
+-
+-  * overlay: mkdir fails if directory exists in lowerdir in a user namespace (LP: #1531747)
+-    - SAUCE: cred: Add clone_cred() interface
+-    - SAUCE: overlayfs: Use mounter's credentials instead of selectively raising caps
+-    - SAUCE: overlayfs: Skip permission checking for trusted.overlayfs.* xattrs
+-
+-  * Update Intel ethernet drivers to Fortville SW5 (LP: #1547674)
+-    - net: bulk free infrastructure for NAPI context, use napi_consume_skb
+-    - net: Add eth_platform_get_mac_address() helper.
+-    - i40e: Add mac_filter_element at the end of the list instead of HEAD
+-    - i40e/i40evf: Fix RSS rx-flow-hash configuration through ethtool
+-    - i40e: Replace X722 mac check in ethtool get_settings
+-    - i40evf: allow channel bonding of VFs
+-    - i40e: define function capabilities in only one place
+-    - i40evf: null out ring pointers on free
+-    - i40e: Cleanup the code with respect to restarting autoneg
+-    - i40e: update features with right offload
+-    - i40e: bump version to 1.4.10
+-    - i40e: add new device IDs for X722
+-    - i40e: Extend ethtool RSS hooks for X722
+-    - i40e/i40evf: Fix for UDP/TCP RSS for X722
+-    - i40evf: add new write-back mode
+-    - i40e/i40evf: Use private workqueue
+-    - i40e: add new proxy-wol bit for X722
+-    - i40e: Limit DCB FW version checks to X710/XL710 devices
+-    - i40e: AQ Add Run PHY Activity struct
+-    - i40e: AQ Geneve cloud tunnel type
+-    - i40e: AQ Add external power class to get link status
+-    - i40e: add 100Mb ethtool reporting
+-    - ixgbe: bulk free SKBs during TX completion cleanup cycle
+-    - igb: Remove unnecessary flag setting in igb_set_flag_queue_pairs()
+-    - igb: Unpair the queues when changing the number of queues
+-    - igb/igbvf: don't give up
+-    - igb: clean up code for setting MAC address
+-    - igb: Refactor VFTA configuration
+-    - igb: Allow asymmetric configuration of MTU versus Rx frame size
+-    - igb: Do not factor VLANs into RLPML calculation
+-    - igb: Always enable VLAN 0 even if 8021q is not loaded
+-    - igb: Merge VLVF configuration into igb_vfta_set
+-    - igb: Clean-up configuration of VF port VLANs
+-    - igb: Add support for VLAN promiscuous with SR-IOV and NTUPLE
+-    - igb: Drop unnecessary checks in transmit path
+-    - igb: Enable use of "bridge fdb add" to set unicast table entries
+-    - igb: Add workaround for VLAN tag stripping on 82576
+-    - i40e: AQ Shared resource flags
+-    - i40e: AQ Add set_switch_config
+-    - i40e: AQ Add VXLAN-GPE tunnel type
+-    - i40e: AQ thermal sensor control struct
+-    - i40e: Bump AQ minor version to 1.5 for new FW features
+-    - i40e: Store lan_vsi_idx and lan_vsi_id in the right size
+-    - i40e: fix write-back-on-itr to work with legacy itr
+-    - i40e: add counter for arq overflows
+-    - i40e: add 20G speed for Tx bandwidth calculations
+-    - i40e: refactor DCB function
+-    - i40e: add a little more to an NVM update debug message
+-    - i40evf: enable bus master after reset
+-    - i40e: add netdev info to VSI dump
+-    - i40e: remove VF device IDs from PF
+-    - i40e: trivial: remove unnecessary local var
+-    - i40e/i40evf: Bump i40e to 1.4.11 and i40evf to 1.4.7
+-    - net: ixgbe: add minimal parser details for ixgbe
+-    - i40e: trivial: drop duplicate definition
+-    - i40e: trivial: fix missing space
+-    - i40e: fix bug in dma sync
+-    - i40e: do TSO only if CHECKSUM_PARTIAL is set
+-    - i40e: allocate memory safer
+-    - i40e: fix: do not sleep in netdev_ops
+-    - i40e: APIs to Add/remove port mirroring rules
+-    - i40e: negate PHY int mask bits
+-    - i40e: drop unused function
+-    - i40e: count allocation errors
+-    - i40e: avoid large memcpy by assigning struct
+-    - i40e/i40evf: bump version to 1.4.12/1.4.8
+-    - i40e: Enable Geneve offload for FW API ver > 1.4 for XL710/X710 devices
+-    - i40e: add priv flag for automatic rule eviction
+-    - i40e: use eth_platform_get_mac_address()
+-    - i40e: move sync_vsi_filters up in service_task
+-    - i40e: Make the DCB firmware checks for X710/XL710 only
+-    - i40e: set shared bit for multicast filters
+-    - i40e: add VEB stat control and remove L2 cloud filter
+-    - i40e: use new add_veb calling with VEB stats control
+-    - i40e: Refactor force_wb and WB_ON_ITR functionality code
+-    - i40evf: Change vf driver string to reflect all products i40evf supports
+-    - i40e/i40evf: don't lose interrupts
+-    - i40e/i40evf: try again after failure
+-    - i40e: dump descriptor indexes in hex
+-    - i40e/i40evf: use __GFP_NOWARN
+-    - i40e/i40evf: use pages correctly in Rx
+-    - i40e/i40evf: use logical operators, not bitwise
+-    - i40e: properly show packet split status in debugfs
+-    - i40e/i40evf: Bump version
+-    - ixgbe: use u32 instead of __u32 in model header
+-    - ixgbe: fix dates on header of ixgbe_model.h
+-    - i40e: get rid of magic number
+-    - i40e: drop unused debugfs file "dump"
+-    - i40evf: support packet split receive
+-    - i40e: trivial: cleanup use of pf->hw
+-    - i40e: Add a SW workaround for lost interrupts
+-    - i40e: Fix PROMISC mode for Multi-function per port (MFP) devices
+-    - i40e: Removal of code which relies on BASE VEB SEID
+-    - i40e/i40evf: avoid atomics
+-    - i40e: Do not disable queues in the Legacy/MSI Interrupt handler
+-    - i40e: expand comment
+-    - i40e: better error reporting for nvmupdate
+-    - i40evf: set adapter state on reset failure
+-    - i40e: clean event descriptor before use
+-    - i40e: When in promisc mode apply promisc mode to Tx Traffic as well
+-    - i40e/i40evf: Bump i40e to 1.4.15 and i40evf to 1.4.11.
+-    - i40e/i40evf: Drop outer checksum offload that was not requested
+-    - i40e/i40evf: Use u64 values instead of casting them in TSO function
+-    - i40e/i40evf: Factor out L4 header and checksum from L3 bits in TSO path
+-    - i40e/i40evf: Consolidate all header changes into TSO function
+-    - i40e/i40evf: Replace header pointers with unions of pointers in Tx checksum path
+-    - i40e/i40evf: Add support for IPv4 encapsulated in IPv6
+-    - i40e/i40evf: Handle IPv6 extension headers in checksum offload
+-    - i40e/i40evf: Do not write to descriptor unless we complete
+-    - i40e/i40evf: Add exception handling for Tx checksum
+-    - i40e/i40evf: Clean-up Rx packet checksum handling
+-    - i40e/i40evf: Enable support for SKB_GSO_UDP_TUNNEL_CSUM
+-    - i40e: Fix ATR in relation to tunnels
+-    - i40e: Do not drop support for IPv6 VXLAN or GENEVE tunnels
+-    - i40e: Update feature flags to reflect newly enabled features
+-    - i40evf: Update feature flags to reflect newly enabled features
+-    - i40e: Add support for ATR w/ IPv6 extension headers
+-    - i40e/i40evf: Break up xmit_descriptor_count from maybe_stop_tx
+-    - i40e/i40evf: Rewrite logic for 8 descriptor per packet check
+-    - i40e/i40evf: Move Tx checksum closer to TSO
+-    - i40e: Add functions to blink led on 10GBaseT PHY
+-    - i40e: Fix led blink capability for 10GBaseT PHY
+-    - i40e: Increase timeout when checking GLGEN_RSTAT_DEVSTATE bit
+-    - i40e: Do not wait for Rx queue disable in DCB reconfig
+-    - i40e: Fix for unexpected messaging
+-    - i40e: Expose some registers to program parser, FD and RSS logic
+-    - i40e: add check for null VSI
+-    - i40e: add adminq commands for Rx CTL registers
+-    - i40e: implement and use Rx CTL helper functions
+-    - i40e: Use the new rx ctl register helpers. Don't use AQ calls from clear_hw.
+-    - i40e: suspend scheduling during driver unload
+-    - i40e: let go of the past
+-    - i40e/i40evf: Bump i40e to 1.4.25 and i40evf to 1.4.15
+-
+-  * MPT3SAS Driver update for next kernel release (LP: #1512221)
+-    - mpt3sas: A correction in unmap_resources
+-    - mpt3sas: Added support for high port count HBA variants.
+-    - mpt3sas: Used IEEE SGL instead of MPI SGL while framing a SMP Passthrough request message.
+-    - mpt3sas: Fix static analyzer(coverity) tool identified defects
+-    - mpt3sas: Never block the Enclosure device
+-    - mpt3sas: Make use of additional HighPriority credit message frames for sending SCSI IO's
+-    - mpt3sas: Added smp_affinity_enable module parameter.
+-    - mpt3sas: Add support for configurable Chain Frame Size
+-    - mpt3sas: Updated MPI Header to 2.00.42
+-    - mpt3sas: Fix for Asynchronous completion of timedout IO and task abort of timedout IO.
+-    - mpt3sas: Updating mpt3sas driver version to 12.100.00.00
+-    - mpt3sas: Remove cpumask_clear for zalloc_cpumask_var and don't free free_cpu_mask_var before reply_q
+-
+-  * /sys/class/scsi_host/hostN/partition_number and .../mad_version showing up BE on LE Ubuntu. (ibmvscsi) (LP: #1547153)
+-    - ibmvscsi: Add endian conversions to sysfs attribute show functions
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Packaging] git-ubuntu-log -- output should be utf-8
+-    - [Packaging] git-ubuntu-log -- handle invalid or private bugs
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 24 Feb 2016 20:34:49 +0000
+-
+-linux (4.4.0-7.22) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1547205
+-
+-  * need arm64 acpi parking protocol support in xenial (LP: #1547047)
+-    - [Config] Enabled ARM64_ACPI_PARKING_PROTOCOL
+-    - arm64: kernel: implement ACPI parking protocol
+-
+-  * Please pull cgroup namespaces (LP: #1546775)
+-    - SAUCE: (noup) kernfs: Add API to generate relative kernfs path
+-    - SAUCE: (noup) sched: new clone flag CLONE_NEWCGROUP for cgroup namespace
+-    - SAUCE: (noup) cgroup: introduce cgroup namespaces
+-    - SAUCE: (noup) cgroup: cgroup namespace setns support
+-    - SAUCE: (noup) kernfs: define kernfs_node_dentry
+-    - SAUCE: (noup) cgroup: mount cgroupns-root when inside non-init cgroupns
+-    - SAUCE: (noup) Add FS_USERNS_FLAG to cgroup fs
+-    - SAUCE: (noup) cgroup: Add documentation for cgroup namespaces
+-
+-  * [Feature]Pulse-Width Modulation enabling on Broxton-P (LP: #1520436)
+-    - [Config] CONFIG_PWM_OMAP_DMTIMER=m
+-    - pwm: lpss: Remove ->free() callback
+-    - pwm: bcm2835: Calculate scaler in ->config()
+-    - pwm: bcm2835: Prevent division by zero
+-    - pwm: bcm2835: Fix email address specification
+-    - pwm: lpss: Update PWM setting for Broxton
+-    - pwm: lpss: Select core part automatically
+-    - pwm: lpss: Rework the sequence of programming PWM_SW_UPDATE
+-    - pwm: fsl-ftm: Fix clock enable/disable when using PM
+-    - pwm: lpc32xx: correct number of PWM channels from 2 to 1
+-    - pwm: lpc32xx: make device usable with common clock framework
+-    - pwm: lpc32xx: fix and simplify duty cycle and period calculations
+-    - pwm: lpc32xx: return ERANGE, if requested period is not supported
+-    - pwm: rcar: Improve accuracy of frequency division setting
+-    - pwm: Add PWM driver for OMAP using dual-mode timers
+-    - pwm: add HAS_IOMEM dependency to PWM_FSL_FTM
+-    - pwm: omap-dmtimer: Potential NULL dereference on error
+-    - pwm: Mark all devices as "might sleep"
+-
+-  * [Hyper-V] Netmask value is not parsed by hv_set_ifconfig - IP injection (LP: #1540586)
+-    - [Debian] hv: hv_set_ifconfig -- switch to approved indentation
+-    - [Debian] hv: hv_set_ifconfig -- fix numerous parameter handling issues
+-
+-  * Update megaraid driver to MR6.10 (LP: #1544679)
+-    - megaraid_sas: Do not allow PCI access during OCR
+-    - megaraid_sas: MFI IO timeout handling
+-    - megaraid_sas: Syncing request flags macro names with firmware
+-    - megaraid_sas: Task management support
+-    - megaraid_sas: Update device queue depth based on interface type
+-    - megaraid_sas: Fastpath region lock bypass
+-    - megaraid_sas: Reply Descriptor Post Queue (RDPQ) support
+-    - megaraid_sas: Code optimization build_and_issue_cmd return-type
+-    - megaraid_sas: Dual queue depth support
+-    - megaraid_sas: IO throttling support
+-    - megaraid_sas: Make adprecovery variable atomic
+-    - megaraid_sas: MFI adapter OCR changes
+-    - megaraid_sas: Introduce module parameter for SCSI command timeout
+-    - megaraid_sas: SPERC OCR changes
+-    - megaraid_sas: driver version upgrade
+-    - megaraid: fix null pointer check in megasas_detach_one().
+-    - megaraid_sas: Fix for IO failing post OCR in SRIOV environment
+-    - megaraid_sas: Fix SMAP issue
+-    - megaraid_sas: Add an i/o barrier
+-
+-  * Surelock-GA2:kernel panic @ cxl_configure_adapter+0x418/0x8b0 (LP: #1546145)
+-    - powerpc/powernv: Fix stale PE primary bus
+-
+-  * In A Single Power VM LPAR : Network Configuration Fails in Ubuntu16.04 while installation (LP: #1544321)
+-    - [Config] Update bnx2x d-i firmware to 7.12.30
+-
+-  * Miscellaneous Ubuntu changes
+-    - rebase to v4.4.2
+-
+-  * Miscellaneous upstream changes
+-    - openvswitch: allow management from inside user namespaces
+-    - net: thunderx: nicvf_queues: nivc_*_intr: remove duplication
+-    - net, thunderx: Remove unnecessary rcv buffer start address management
+-    - net: thunderx: HW TSO support for pass-2 hardware
+-    - net: thunderx: Enable CQE count threshold interrupt
+-    - net: cavium: liquidio: use helpers ns_to_timespec64()
+-    - irqchip/gic-v3: Make sure read from ICC_IAR1_EL1 is visible on redestributor
+-    - arm64: KVM: Configure TCR_EL2.PS at runtime
+-    - arm64: prefetch: don't provide spin_lock_prefetch with LSE
+-    - arm64: prefetch: add alternative pattern for CPUs without a prefetcher
+-    - arm64: lib: improve copy_page to deal with 128 bytes at a time
+-    - arm64: lib: patch in prfm for copy_page if requested
+-    - arm64: prefetch: add missing #include for spin_lock_prefetch
+-    - net, thunderx: Add TX timeout and RX buffer alloc failure stats.
+-    - net: thunderx: Use napi_schedule_irqoff()
+-    - net: thunderx: Assign affinity hints to vf's interrupts
+-    - net: thunderx: bgx: Use standard firmware node infrastructure.
+-    - net: thunderx: bgx: Add log message when setting mac address
+-    - net: thunderx: Alloc higher order pages when pagesize is small
+-    - net: cavium: liquidio: Return correct error code
+-    - net: cavium: liquidio: fix check for in progress flag
+-    - livepatch: add old_sympos as disambiguator field to klp_func
+-    - livepatch: add sympos as disambiguator field to klp_reloc
+-    - livepatch: function,sympos scheme in livepatch sysfs directory
+-    - module: Use the same logic for setting and unsetting RO/NX
+-    - gcov: use within_module() helper.
+-    - module: use a structure to encapsulate layout.
+-    - module: clean up RO/NX handling.
+-    - module: keep percpu symbols in module's symtab
+-    - livepatch: Cleanup module page permission changes
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.4.2
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 16 Feb 2016 14:24:45 -0700
+-
+-linux (4.4.0-6.21) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1546283
+-
+-  *  Naples/Zen, NTB Driver  (LP: #1542071)
+-    - [Config] CONFIG_NTB_AMD=m
+-    - NTB: Add support for AMD PCI-Express Non-Transparent Bridge
+-
+-  * [Hyper-V] kernel panic occurs when installing Ubuntu Server x32 (LP: #1495983)
+-    - SAUCE: storvsc: use small sg_tablesize on x86
+-
+-  * Enable arm64 emulation of removed ARMv7 instructions (LP: #1545542)
+-    - [Config] CONFIG_ARMV8_DEPRECATED=y
+-
+-  * Surelock-GA2:kernel panic/ exception @ pcibios_set_pcie_reset_state+0x118/0x280 + cxl_reset+0x5c/0xc0 (LP: #1545037)
+-    - powerpc/eeh: Fix stale cached primary bus
+-
+-  * Miscellaneous Ubuntu changes
+-    - SAUCE: fs: Add user namesapace member to struct super_block
+-    - SAUCE: fs: Limit file caps to the user namespace of the super block
+-    - SAUCE: Smack: Add support for unprivileged mounts from user namespaces
+-    - SAUCE: block_dev: Support checking inode permissions in lookup_bdev()
+-    - SAUCE: block_dev: Check permissions towards block device inode when mounting
+-    - SAUCE: fs: Treat foreign mounts as nosuid
+-    - SAUCE: selinux: Add support for unprivileged mounts from user namespaces
+-    - SAUCE: userns: Replace in_userns with current_in_userns
+-    - SAUCE: Smack: Handle labels consistently in untrusted mounts
+-    - SAUCE: fs: Check for invalid i_uid in may_follow_link()
+-    - SAUCE: cred: Reject inodes with invalid ids in set_create_file_as()
+-    - SAUCE: fs: Refuse uid/gid changes which don't map into s_user_ns
+-    - SAUCE: fs: Update posix_acl support to handle user namespace mounts
+-    - SAUCE: fs: Ensure the mounter of a filesystem is privileged towards its inodes
+-    - SAUCE: fs: Don't remove suid for CAP_FSETID in s_user_ns
+-    - SAUCE: fs: Allow superblock owner to access do_remount_sb()
+-    - SAUCE: capabilities: Allow privileged user in s_user_ns to set security.* xattrs
+-    - SAUCE: fuse: Add support for pid namespaces
+-    - SAUCE: fuse: Support fuse filesystems outside of init_user_ns
+-    - SAUCE: fuse: Restrict allow_other to the superblock's namespace or a descendant
+-    - SAUCE: fuse: Allow user namespace mounts
+-    - SAUCE: mtd: Check permissions towards mtd block device inode when mounting
+-    - SAUCE: fs: Update i_[ug]id_(read|write) to translate relative to s_user_ns
+-    - SAUCE: quota: Convert ids relative to s_user_ns
+-    - SAUCE: evm: Translate user/group ids relative to s_user_ns when computing HMAC
+-    - SAUCE: fs: Allow CAP_SYS_ADMIN in s_user_ns to freeze and thaw filesystems
+-    - SAUCE: quota: Treat superblock owner as privilged
+-    - SAUCE: ima/evm: Allow root in s_user_ns to set xattrs
+-    - SAUCE: block_dev: Forbid unprivileged mounting when device is opened for writing
+-    - SAUCE: ext4: Add support for unprivileged mounts from user namespaces
+-    - SAUCE: ext4: Add module parameter to enable user namespace mounts
+-    - SAUCE: fuse: Add module parameter to enable user namespace mounts
+-
+-  * Miscellaneous upstream changes
+-    - megaraid: Fix possible NULL pointer deference in mraid_mm_ioctl
+-    - libahci: Implement the capability to override the generic ahci interrupt handler.
+-    - ata: Remove the AHCI_HFLAG_EDGE_IRQ support from libahci.
+-    - ahci_xgene: Implement the workaround to fix the missing of the edge interrupt for the HOST_IRQ_STAT.
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 12 Feb 2016 09:49:05 -0700
+-
+-linux (4.4.0-5.20) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1544637
+-
+-  * s390/cio: update measurement characteristics (LP: #1541534)
+-    - s390/cio: fix measurement characteristics memleak
+-    - s390/cio: ensure consistent measurement state
+-    - s390/cio: update measurement characteristics
+-
+-  * qeth: layer2 reports unknown state to network tools. (LP: #1541907)
+-    - qeth: initialize net_device with carrier off
+-
+-  * Collateral damage due to kernel configuration change enabling CONFIG_ZONE_DEVICE (Kernel 4.4 amd64) (LP: #1534647)
+-    - [Config] CONFIG_ZONE_DMA=y
+-    - mm: CONFIG_NR_ZONES_EXTENDED
+-
+-  * perf enahancements for ppc64 (LP: #1521678)
+-    - perf kvm/{x86,s390}: Remove dependency on uapi/kvm_perf.h
+-    - perf kvm/{x86,s390}: Remove const from kvm_events_tp
+-    - perf kvm/powerpc: Port perf kvm stat to powerpc
+-    - perf kvm/powerpc: Add support for HCALL reasons
+-
+-  * Soft lockup with "block nbdX: Attempted send on closed socket" spam (LP: #1505564)
+-    - SAUCE: nbd: ratelimit error msgs after socket close
+-
+-  * sleep from invalid context in aa_move_mount (LP: #1539349)
+-    - SAUCE: apparmor: fix sleep from invalid context
+-
+-  * Introducing ConnectX-4 Ethernet SRIOV (LP: #1540435)
+-    - net/mlx5_core: Modify enable/disable hca functions
+-    - net/mlx5_core: Add base sriov support
+-    - net/mlx5: Add HW capabilities and structs for SR-IOV E-Switch
+-    - net/mlx5: Update access functions to Query/Modify vport MAC address
+-    - net/mlx5: Introduce access functions to modify/query vport mac lists
+-    - net/mlx5: Introduce access functions to modify/query vport state
+-    - net/mlx5: Introduce access functions to modify/query vport promisc mode
+-    - net/mlx5: Introduce access functions to modify/query vport vlans
+-    - net/mlx5e: Write UC/MC list and promisc mode into vport context
+-    - net/mlx5e: Write vlan list into vport context
+-    - net/mlx5: Introducing E-Switch and l2 table
+-    - net/mlx5: E-Switch, Introduce FDB hardware capabilities
+-    - net/mlx5: E-Switch, Add SR-IOV (FDB) support
+-    - net/mlx5: E-Switch, Introduce Vport administration functions
+-    - net/mlx5: E-Switch, Introduce HCA cap and E-Switch vport context
+-    - net/mlx5: E-Switch, Introduce set vport vlan (VST mode)
+-    - net/mlx5: E-Switch, Introduce get vf statistics
+-    - net/mlx5e: Add support for SR-IOV ndos
+-    - net/mlx5: Fix query E-Switch capabilities
+-    - net/mlx5e: Assign random MAC address if needed
+-
+-  * make wacom_w8001 work well in xenial (LP: #1542771)
+-    - Input: wacom_w8001 - use __set_bit for evbits
+-    - Input: wacom_w8001 - set BTN_TOOL_DOUBLETAP if we have 2fg support
+-    - Input: wacom_w8001 - handle touch error case correctly
+-    - Input: wacom_w8001 - split pen and touch initialization up
+-    - Input: wacom_w8001 - split the touch and pen devices into two devices
+-    - Input: wacom_w8001 - drop use of ABS_MT_TOOL_TYPE
+-
+-  * virtualbox: update to 5.0.14-dfsg-2 (LP: #1542728)
+-    - ubuntu: vbox -- update to 5.0.14-dfsg-2
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Packaging] git-ubuntu-log -- fix empty section formatting
+-    - SAUCE: (noup) Update spl to 0.6.5.4-0ubuntu2, zfs to 0.6.5.4-0ubuntu2
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 06 Feb 2016 22:32:10 +0000
+-
+-linux (4.4.0-4.19) xenial; urgency=low
+-
+-  * update ZFS and SPL to 0.6.5.4 (LP: #1542296)
+-    - [Config] update spl/zfs version
+-    - SAUCE: (noup) Update spl to 0.6.5.4-0ubuntu2, zfs to 0.6.5.4-0ubuntu1
+-    - [Config] reconstruct -- drop links for zfs userspace components
+-    - [Config] reconstruct -- drop links for zfs userspace components -- restore spec links
+-
+-  * recvmsg() fails SCM_CREDENTIALS request with EOPNOTSUPP. (LP: #1540731)
+-    - Revert "af_unix: Revert 'lock_interruptible' in stream receive code"
+-
+-  * lxc: ADT exercise test failing with linux-4.4.0-3.17  (LP: #1542049)
+-    - Revert "UBUNTU: SAUCE: apparmor: fix sleep from invalid context"
+-
+-  * WARNING: at /build/linux-lts-wily-W0lTWH/linux-lts-wily-4.2.0/net/core/skbuff.c:4174 (Travis IB) (LP: #1541326)
+-    - SAUCE: IB/IPoIB: Do not set skb truesize since using one linearskb
+-
+-  * backport Microsoft Precision Touchpad palm rejection patch (LP: #1541671)
+-    - HID: multitouch: enable palm rejection if device implements confidence usage
+-
+-  * [Ubuntu 16.04] Update qla2xxx driver for POWER (QLogic) (LP: #1541456)
+-    - qla2xxx: Remove unavailable firmware files
+-    - qla2xxx: Enable Extended Logins support
+-    - qla2xxx: Enable Exchange offload support.
+-    - qla2xxx: Enable Target counters in DebugFS.
+-    - qla2xxx: Add FW resource count in DebugFS.
+-    - qla2xxx: Added interface to send explicit LOGO.
+-    - qla2xxx: Delete session if initiator is gone from FW
+-    - qla2xxx: Wait for all conflicts before ack'ing PLOGI
+-    - qla2xxx: Replace QLA_TGT_STATE_ABORTED with a bit.
+-    - qla2xxx: Remove dependency on hardware_lock to reduce lock contention.
+-    - qla2xxx: Add irq affinity notification
+-    - qla2xxx: Add selective command queuing
+-    - qla2xxx: Move atioq to a different lock to reduce lock contention
+-    - qla2xxx: Disable ZIO at start time.
+-    - qla2xxx: Set all queues to 4k
+-    - qla2xxx: Check for online flag instead of active reset when transmitting responses
+-    - scsi: qla2xxxx: avoid type mismatch in comparison
+-
+-  * [Hyper-V] PCI Passthrough (LP: #1541120)
+-    - x86/irq: Export functions to allow MSI domains in modules
+-    - genirq/msi: Export functions to allow MSI domains in modules
+-
+-  * Update lpfc driver to 11.0.0.10 (LP: #1541592)
+-    - lpfc: Fix FCF Infinite loop in lpfc_sli4_fcf_rr_next_index_get.
+-    - lpfc: Fix the FLOGI discovery logic to comply with T11 standards
+-    - lpfc: Fix RegLogin failed error seen on Lancer FC during port bounce
+-    - lpfc: Fix driver crash when module parameter lpfc_fcp_io_channel set to 16
+-    - lpfc: Fix crash in fcp command completion path.
+-    - lpfc: Modularize and cleanup FDMI code in driver
+-    - lpfc: Fix RDP Speed reporting.
+-    - lpfc: Fix RDP ACC being too long.
+-    - lpfc: Make write check error processing more resilient
+-    - lpfc: Use new FDMI speed definitions for 10G, 25G and 40G FCoE.
+-    - lpfc: Fix mbox reuse in PLOGI completion
+-    - lpfc: Fix external loopback failure.
+-    - lpfc: Add logging for misconfigured optics.
+-    - lpfc: Delete unnecessary checks before the function call "mempool_destroy"
+-    - lpfc: Use kzalloc instead of kmalloc
+-    - lpfc: Update version to 11.0.0.10 for upstream patch set
+-
+-  * Miscellaneous Ubuntu changes
+-    - [Config] CONFIG_ARM64_VA_BITS=48
+-    - [Config] Fixed Vcs-Git
+-
+-  * Miscellaneous upstream changes
+-    - cxl: Fix possible idr warning when contexts are released
+-    - cxl: use correct operator when writing pcie config space values
+-    - cxlflash: drop unlikely before IS_ERR_OR_NULL
+-    - cxl: Fix DSI misses when the context owning task exits
+-    - cxlflash: Removed driver date print
+-    - cxlflash: Fix to resolve cmd leak after host reset
+-    - cxlflash: Resolve oops in wait_port_offline
+-    - cxlflash: Enable device id for future IBM CXL adapter
+-    - cxl: fix build for GCC 4.6.x
+-    - cxl: use -Werror only with CONFIG_PPC_WERROR
+-    - cxl: Enable PCI device ID for future IBM CXL adapter
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Feb 2016 14:58:51 +0000
+-
+-linux (4.4.0-3.17) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1541058
+-  * [Config] CONFIG_BLK_DEV_NVME_SCSI=y
+-    - LP: #1531539
+-  * SAUCE: nvme merge cleanup
+-    - LP: #1531539
+-  * rebase to v4.4.1
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: dm: introduce a target_ioctl op to allow target specific
+-    ioctls"
+-    - LP: #1538618
+-  * postinst -- detect symlinks correctly
+-    - LP: #1536810
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: apparmor: fix sleep from invalid context
+-    - LP: #1539349
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * powerpc/eeh: Fix PE location code
+-    - LP: #1538909
+-  * powerpc/pseries: Limit EPOW reset event warnings
+-    - LP: #1539102
+-  * lightnvm: fix bio submission issue
+-    - LP: #1531539
+-  * lightnvm: fix incorrect nr_free_blocks stat
+-    - LP: #1531539
+-  * lightnvm: add check after mempool allocation
+-    - LP: #1531539
+-  * lightnvm: unlock rq and free ppa_list on submission fail
+-    - LP: #1531539
+-  * lightnvm: move ppa erase logic to core
+-    - LP: #1531539
+-  * lightnvm: refactor rqd ppa list into set/free
+-    - LP: #1531539
+-  * lightnvm: refactor end_io functions for sync
+-    - LP: #1531539
+-  * lightnvm: return the get_bb_tbl return value
+-    - LP: #1531539
+-  * lightnvm: check bi_error in gc
+-    - LP: #1531539
+-  * lightnvm: put block back to gc list on its reclaim fail
+-    - LP: #1531539
+-  * lightnvm: fix locking and mempool in rrpc_lun_gc
+-    - LP: #1531539
+-  * lightnvm: sectors first in ppa list
+-    - LP: #1531539
+-  * lightnvm: move the pages per block check out of the loop
+-    - LP: #1531539
+-  * lightnvm: support multiple ppas in nvm_erase_ppa
+-    - LP: #1531539
+-  * lightnvm: move rq->error to nvm_rq->error
+-    - LP: #1531539
+-  * lightnvm: introduce nvm_submit_ppa
+-    - LP: #1531539
+-  * lightnvm: reference rrpc lun in rrpc block
+-    - LP: #1531539
+-  * lightnvm: fix missing grown bad block type
+-    - LP: #1531539
+-  * lightnvm: manage open and closed blocks separately
+-    - LP: #1531539
+-  * lightnvm: add mccap support
+-    - LP: #1531539
+-  * lightnvm: introduce mlc lower page table mappings
+-    - LP: #1531539
+-  * lightnvm: core on-disk initialization
+-    - LP: #1531539
+-  * lightnvm: introduce ioctl to initialize device
+-    - LP: #1531539
+-  * lightnvm: use system block for mm initialization
+-    - LP: #1531539
+-  * lightnvm: introduce factory reset
+-    - LP: #1531539
+-  * lightnvm: ensure that nvm_dev_ops can be used without CONFIG_NVM
+-    - LP: #1531539
+-  * blk-mq: add a flags parameter to blk_mq_alloc_request
+-    - LP: #1531539
+-  * nvme: move struct nvme_iod to pci.c
+-    - LP: #1531539
+-  * nvme: split command submission helpers out of pci.c
+-    - LP: #1531539
+-  * nvme: use offset instead of a struct for registers
+-    - LP: #1531539
+-  * nvme: split nvme_trans_device_id_page
+-    - LP: #1531539
+-  * nvme: use vendor it from identify
+-    - LP: #1531539
+-  * nvme: split a new struct nvme_ctrl out of struct nvme_dev
+-    - LP: #1531539
+-  * nvme: simplify nvme_setup_prps calling convention
+-    - LP: #1531539
+-  * nvme: refactor nvme_queue_rq
+-    - LP: #1531539
+-  * nvme: factor out a nvme_unmap_data helper
+-    - LP: #1531539
+-  * nvme: move nvme_error_status to common code
+-    - LP: #1531539
+-  * nvme: move nvme_setup_flush and nvme_setup_rw to common code
+-    - LP: #1531539
+-  * nvme: split __nvme_submit_sync_cmd
+-    - LP: #1531539
+-  * nvme: use the block layer for userspace passthrough metadata
+-    - LP: #1531539
+-  * nvme: move block_device_operations and ns/ctrl freeing to common code
+-    - LP: #1531539
+-  * nvme: add explicit quirk handling
+-    - LP: #1531539
+-  * nvme: move remaining CC setup into nvme_enable_ctrl
+-    - LP: #1531539
+-  * nvme: move nvme_{enable,disable,shutdown}_ctrl to common code
+-    - LP: #1531539
+-  * nvme: add a common helper to read Identify Controller data
+-    - LP: #1531539
+-  * nvme: move the call to nvme_init_identify earlier
+-    - LP: #1531539
+-  * nvme: move namespace scanning to common code
+-    - LP: #1531539
+-  * nvme: move chardev and sysfs interface to common code
+-    - LP: #1531539
+-  * nvme: refactor set_queue_count
+-    - LP: #1531539
+-  * blk-integrity: empty implementation when disabled
+-    - LP: #1531539
+-  * NVMe: fix build with CONFIG_NVM enabled
+-    - LP: #1531539
+-  * nvme: fix another 32-bit build warning
+-    - LP: #1531539
+-  * nvme: precedence bug in nvme_pr_clear()
+-    - LP: #1531539
+-  * nvme: only ignore hardware errors in nvme_create_io_queues
+-    - LP: #1531539
+-  * nvme: only add a controller to dev_list after it's been fully
+-    initialized
+-    - LP: #1531539
+-  * nvme: protect against simultaneous shutdown invocations
+-    - LP: #1531539
+-  * nvme: don't take the I/O queue q_lock in nvme_timeout
+-    - LP: #1531539
+-  * nvme: merge nvme_abort_req and nvme_timeout
+-    - LP: #1531539
+-  * nvme: add NVME_SC_CANCELLED
+-    - LP: #1531539
+-  * nvme: simplify resets
+-    - LP: #1531539
+-  * nvme: do not restart the request timeout if we're resetting the
+-    controller
+-    - LP: #1531539
+-  * nvme: merge probe_work and reset_work
+-    - LP: #1531539
+-  * nvme: remove dead controllers from a work item
+-    - LP: #1531539
+-  * nvme: switch abort_limit to an atomic_t
+-    - LP: #1531539
+-  * NVMe: Implement namespace list scanning
+-    - LP: #1531539
+-  * NVMe: Use unbounded work queue for all work
+-    - LP: #1531539
+-  * NVMe: Remove device management handles on remove
+-    - LP: #1531539
+-  * NVMe: Simplify metadata setup
+-    - LP: #1531539
+-  * nvme: fix admin queue depth
+-    - LP: #1531539
+-  * nvme: factor out a few helpers from req_completion
+-    - LP: #1531539
+-  * nvme: switch delete SQ/CQ to blk_execute_rq_nowait
+-    - LP: #1531539
+-  * nvme: switch abort to blk_execute_rq_nowait
+-    - LP: #1531539
+-  * nvme: special case AEN requests
+-    - LP: #1531539
+-  * nvme: simplify completion handling
+-    - LP: #1531539
+-  * nvme: properly free resources for cancelled command
+-    - LP: #1531539
+-  * nvme: meta_sg doesn't have to be an array
+-    - LP: #1531539
+-  * nvme: merge iod and cmd_info
+-    - LP: #1531539
+-  * NVMe: Add pci error handlers
+-    - LP: #1531539
+-  * NVMe: Export namespace attributes to sysfs
+-    - LP: #1531539
+-  * nvme: Move nvme_freeze/unfreeze_queues to nvme core
+-    - LP: #1531539
+-  * nvme: synchronize access to ctrl->namespaces
+-    - LP: #1531539
+-  * nvme: fixes for NVME_IOCTL_IO_CMD on the char device
+-    - LP: #1531539
+-  * nvme: make SG_IO support optional
+-    - LP: #1531539
+-  * NVMe: Fix admin queue ring wrap
+-    - LP: #1531539
+-  * NVMe: Use a retryable error code on reset
+-    - LP: #1531539
+-  * NVMe: Remove queue freezing on resets
+-    - LP: #1531539
+-  * NVMe: IO queue deletion re-write
+-    - LP: #1531539
+-  * NVMe: Shutdown controller only for power-off
+-    - LP: #1531539
+-  * NVMe: Export NVMe attributes to sysfs group
+-    - LP: #1531539
+-  * i40e: fix build warnings
+-  * net: i40e: shut up uninitialized variable warnings
+-  * Drivers: hv: vmbus: fix build warning
+-  * Drivers: hv: util: Increase the timeout for util services
+-  * Drivers: hv: utils: run polling callback always in interrupt context
+-  * tools: hv: report ENOSPC errors in hv_fcopy_daemon
+-  * tools: hv: remove repeated HV_FCOPY string
+-  * Drivers: hv: util: catch allocation errors
+-  * Drivers: hv: utils: use memdup_user in hvt_op_write
+-  * drivers/hv: cleanup synic msrs if vmbus connect failed
+-  * drivers:hv: Export a function that maps Linux CPU num onto Hyper-V proc
+-    num
+-  * drivers:hv: Export the API to invoke a hypercall on Hyper-V
+-  * drivers:hv: Define the channel type for Hyper-V PCI Express
+-    pass-through
+-  * Drivers: hv: vss: run only on supported host versions
+-  * Drivers: hv: vmbus: Use uuid_le type consistently
+-  * Drivers: hv: vmbus: Use uuid_le_cmp() for comparing GUIDs
+-  * Drivers: hv: vmbus: Get rid of the unused macro
+-  * Drivers: hv: vmbus: Get rid of the unused irq variable
+-  * Drivers: hv: vmbus: serialize process_chn_event() and
+-    vmbus_close_internal()
+-  * Drivers: hv: vmbus: do sanity check of channel state in
+-    vmbus_close_internal()
+-  * Drivers: hv: vmbus: fix rescind-offer handling for device without a
+-    driver
+-  * Drivers: hv: vmbus: release relid on error in vmbus_process_offer()
+-  * Drivers: hv: vmbus: channge vmbus_connection.channel_lock to mutex
+-  * drivers:hv: Allow for MMIO claims that span ACPI _CRS records
+-  * Drivers: hv: vmbus: Fix a Host signaling bug
+-  * drivers/hv: correct tsc page sequence invalid value
+-  * Drivers: hv: vmbus: Force all channel messages to be delivered on CPU 0
+-  * Drivers: hv: utils: Invoke the poll function after handshake
+-  * tools: hv: vss: fix the write()'s argument: error -> vss_msg
+-  * Drivers: hv: utils: fix memory leak on on_msg() failure
+-  * Drivers: hv: utils: rename outmsg_lock
+-  * Drivers: hv: utils: introduce HVUTIL_TRANSPORT_DESTROY mode
+-  * Drivers: hv: utils: fix crash when device is removed from host side
+-  * Drivers: hv: ring_buffer.c: fix comment style
+-  * Drivers: hv: ring_buffer: remove stray smp_read_barrier_depends()
+-  * Drivers: hv: ring_buffer: remove code duplication from
+-    hv_ringbuffer_peek/read()
+-  * Drivers: hv: remove code duplication between
+-    vmbus_recvpacket()/vmbus_recvpacket_raw()
+-  * Drivers: hv: ring_buffer: eliminate hv_ringbuffer_peek()
+-  * drivers/hv: replace enum hv_message_type by u32
+-  * drivers/hv: Move HV_SYNIC_STIMER_COUNT into Hyper-V UAPI x86 header
+-  * drivers/hv: Move struct hv_message into UAPI Hyper-V x86 header
+-  * drivers/hv: Move struct hv_timer_message_payload into UAPI Hyper-V x86
+-    header
+-  * Drivers: hv: vmbus: fix the building warning with hyperv-keyboard
+-  * Drivers: hv: utils: fix hvt_op_poll() return value on transport destroy
+-  * Drivers: hv: vmbus: Treat Fibre Channel devices as performance critical
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.4.1
+-    - LP: #1533461
+-    - LP: #1529624
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 29 Jan 2016 08:06:37 -0700
+-
+-linux (4.4.0-2.16) xenial; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Release Tracking Bug
+-    - LP: #1539090
+-  * SAUCE: hv: hv_set_ifconfig -- convert to python3
+-    - LP: #1506521
+-  * SAUCE: dm: introduce a target_ioctl op to allow target specific ioctls
+-    - LP: #1538618
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: ACPI / tables: Add acpi_force_32bit_fadt_addr option to force 32
+-    bit FADT addresses (LP: #1529381)
+-    - LP: #1529381
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: (no-up): apparmor: fix for failed mediation of socket that is
+-    being shutdown
+-    - LP: #1446906
+-
+-  [ Mahesh Salgaonkar ]
+-
+-  * SAUCE: Powernv: Remove the usage of PACAR1 from opal wrappers
+-    - LP: #1537881
+-  * SAUCE: powerpc/book3s: Fix TB corruption in guest exit path on HMI
+-    interrupt.
+-    - LP: #1537881
+-  * SAUCE: KVM: PPC: Book3S HV: Fix soft lockups in KVM on HMI for time
+-    base errors
+-    - LP: #1537881
+-
+-  [ Paolo Pisati ]
+-
+-  * SAUCE: arm64: errata: Add -mpc-relative-literal-loads to erratum
+-    #843419 build flags
+-    - LP: #1533009
+-  * [Config] MFD_TPS65217=y && REGULATOR_TPS65217=y
+-  * [Config] disable ARCH_ZX (ZTE ZX Soc)
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "SAUCE: (noup) cxlflash: a couple off by one bugs"
+-  * SAUCE: (no-up) Update bnx2x firmware to 7.12.30.0
+-    - LP: #1536719
+-  * SAUCE: drop obsolete bnx2x firmware
+-  * SAUCE: i40e: Silence 'may be used uninitialized' warnings
+-    - LP: #1536474
+-  * [Config] CONFIG_ZONE_DMA=y for amd64 lowlatency
+-    - LP: #1534647
+-  * [Config] Add pvpanic to virtual flavour
+-    - LP: #1537923
+-  * [Config] CONFIG_INTEL_PUNIT_IPC=m, CONFIG_INTEL_TELEMETRY=m
+-    - LP: #1520457
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * i40evf: fix compiler warning of unused variable
+-    - LP: #1536474
+-  * intel: i40e: fix confused code
+-    - LP: #1536474
+-  * i40e/i40evf: remove unused tunnel parameter
+-    - LP: #1536474
+-  * i40e: Change BUG_ON to WARN_ON in service event complete
+-    - LP: #1536474
+-  * i40e: remove BUG_ON from feature string building
+-    - LP: #1536474
+-  * i40e: remove BUG_ON from FCoE setup
+-    - LP: #1536474
+-  * i40e: Workaround fix for mss < 256 issue
+-    - LP: #1536474
+-  * i40e/i40evf: Add a stat to track how many times we have to do a force
+-    WB
+-    - LP: #1536474
+-  * i40e: Move the saving of old link info from handle_link_event to
+-    link_event
+-    - LP: #1536474
+-  * i40e/i40evf: Add comment to #endif
+-    - LP: #1536474
+-  * i40e/i40evf: clean up error messages
+-    - LP: #1536474
+-  * i40evf: handle many MAC filters correctly
+-    - LP: #1536474
+-  * i40e: return the number of enabled queues for ETHTOOL_GRXRINGS
+-    - LP: #1536474
+-  * i40e: rework the functions to configure RSS with similar parameters
+-    - LP: #1536474
+-  * i40e: create a generic configure rss function
+-    - LP: #1536474
+-  * i40e: Bump version to 1.4.2
+-    - LP: #1536474
+-  * i40e: add new fields to store user configuration
+-    - LP: #1536474
+-  * i40e: rename rss_size to alloc_rss_size in i40e_pf
+-    - LP: #1536474
+-  * i40e/i40evf: Fix RS bit update in Tx path and disable force WB
+-    workaround
+-    - LP: #1536474
+-  * i40e/i40evf: prefetch skb data on transmit
+-    - LP: #1536474
+-  * i40evf: rename VF adapter specific RSS function
+-    - LP: #1536474
+-  * i40evf: create a generic config RSS function
+-    - LP: #1536474
+-  * i40evf: create a generic get RSS function
+-    - LP: #1536474
+-  * i40evf: add new fields to store user configuration of RSS
+-    - LP: #1536474
+-  * i40e: Update error messaging
+-    - LP: #1536474
+-  * i40e: fix confusing message
+-    - LP: #1536474
+-  * i40e: make error message more useful
+-    - LP: #1536474
+-  * i40evf: quoth the VF driver, Nevermore
+-    - LP: #1536474
+-  * i40evf: allocate queue vectors dynamically
+-    - LP: #1536474
+-  * i40evf: allocate ring structs dynamically
+-    - LP: #1536474
+-  * i40e/i40evf: Bump i40e version to 1.4.4 and i40evf to 1.4.1
+-    - LP: #1536474
+-  * i40e: fix: do not sleep in netdev_ops
+-    - LP: #1536474
+-  * i40e: remove unused argument
+-    - LP: #1536474
+-  * i40evf: increase max number of queues
+-    - LP: #1536474
+-  * i40evf: set real num queues
+-    - LP: #1536474
+-  * i40evf: remove duplicate string
+-    - LP: #1536474
+-  * i40e: Detection and recovery of TX queue hung logic moved to
+-    service_task from tx_timeout
+-    - LP: #1536474
+-  * i40e: Fix memory leaks, sideband filter programming
+-    - LP: #1536474
+-  * i40evf: don't use atomic allocation
+-    - LP: #1536474
+-  * i40e: propagate properly
+-    - LP: #1536474
+-  * i40evf: use correct types
+-    - LP: #1536474
+-  * i40e: use priv flags to control packet split
+-    - LP: #1536474
+-  * i40e: Remove separate functions gathering XOFF Rx stats
+-    - LP: #1536474
+-  * i40e: fix whitespace
+-    - LP: #1536474
+-  * i40e/i40evf: use logical operator
+-    - LP: #1536474
+-  * i40e/i40evf: Bump version to 1.4.7 for i40e and 1.4.3 for i40evf
+-    - LP: #1536474
+-  * i40e: trivial fixes
+-    - LP: #1536474
+-  * i40e: Fix i40e_print_features() VEB mode output
+-    - LP: #1536474
+-  * i40e: chomp the BIT(_ULL)
+-    - LP: #1536474
+-  * i40e: properly delete VF MAC filters
+-    - LP: #1536474
+-  * i40e: don't add zero MAC filter
+-    - LP: #1536474
+-  * i40evf: check rings before freeing resources
+-    - LP: #1536474
+-  * i40e: use explicit cast from u16 to u8
+-    - LP: #1536474
+-  * i40e: Opcode and structures required by OEM Post Update AQ command and
+-    add new NVM arq message
+-    - LP: #1536474
+-  * i40e: hush little warnings
+-    - LP: #1536474
+-  * i40e/i40evf: Add a new offload for RSS PCTYPE V2 for X722
+-    - LP: #1536474
+-  * i40e: clean whole mac filter list
+-    - LP: #1536474
+-  * i40evf: change version string generation
+-    - LP: #1536474
+-  * i40e/i40evf: Bump i40e to 1.4.8 and i40evf to 1.4.4
+-    - LP: #1536474
+-  * geneve: UDP checksum configuration via netlink
+-    - LP: #1536474
+-  * geneve: Add geneve udp port offload for ethernet devices
+-    - LP: #1536474
+-  * i40e: geneve tunnel offload support
+-    - LP: #1536474
+-  * geneve: Add geneve_get_rx_port support
+-    - LP: #1536474
+-  * i40e: Call geneve_get_rx_port to get the existing Geneve ports
+-    - LP: #1536474
+-  * i40e: change log messages and error returns
+-    - LP: #1536474
+-  * i40e: allow zero MAC address for VFs
+-    - LP: #1536474
+-  * i40e: Look up MAC address in Open Firmware or IDPROM
+-    - LP: #1536474
+-  * i40e: Fix Rx hash reported to the stack by our driver
+-    - LP: #1536474
+-  * i40e: remove forever unused ID
+-    - LP: #1536474
+-  * igb: add 88E1543 initialization code
+-  * igb: don't unmap NULL hw_addr
+-  * igb: use the correct i210 register for EEMNGCTL
+-  * igb: fix NULL derefs due to skipped SR-IOV enabling
+-  * igb: improve handling of disconnected adapters
+-  * igb: Remove GS40G specific defines/functions
+-  * igb: Don't add PHY address to PCDL address
+-  * igb: Improve cable length function for I210, etc.
+-  * igb: Explicitly label self-test result indices
+-  * ixgbe: drop null test before destroy functions
+-    - LP: #1536473
+-  * ixgbe: Delete redundant include file
+-    - LP: #1536473
+-  * ixgbe: fix multiple kernel-doc errors
+-    - LP: #1536473
+-  * ixgbe: Fix handling of NAPI budget when multiple queues are enabled per
+-    vector
+-    - LP: #1536473
+-  * ixgbe: Add KR mode support for CS4227 chip
+-    - LP: #1536473
+-  * ixgbevf: Limit lowest interrupt rate for adaptive interrupt moderation
+-    to 12K
+-    - LP: #1536473
+-  * ixgbe/ixgbevf: use napi_schedule_irqoff()
+-    - LP: #1536473
+-  * ixgbe: Remove CS4227 diagnostic code
+-    - LP: #1536473
+-  * ixgbevf: use ether_addr_copy instead of memcpy
+-    - LP: #1536473
+-  * ixgbevf: fix spoofed packets with random MAC
+-    - LP: #1536473
+-  * ixgbe: Prevent KR PHY reset in ixgbe_init_phy_ops_x550em
+-    - LP: #1536473
+-  * ixgbe: Add support for newer thermal alarm
+-    - LP: #1536473
+-  * ixgbe: Use private workqueue to avoid certain possible hangs
+-    - LP: #1536473
+-  * ixgbevf: Use a private workqueue to avoid certain possible hangs
+-    - LP: #1536473
+-  * ixgbevf: Minor cleanups
+-    - LP: #1536473
+-  * ixgbe: Refactor MAC address configuration code
+-    - LP: #1536473
+-  * ixgbe: Use __dev_uc_sync and __dev_uc_unsync for unicast addresses
+-    - LP: #1536473
+-  * ixgbe: Allow FDB entries access to more RAR filters
+-    - LP: #1536473
+-  * ixgbe: Update PTP to support X550EM_x devices
+-    - LP: #1536473
+-  * ixgbe: Correct spec violations by waiting after reset
+-    - LP: #1536473
+-  * ixgbe: Wait for master disable to be set
+-    - LP: #1536473
+-  * ixgbe: Save VF info and take references
+-    - LP: #1536473
+-  * ixgbe: Handle extended IPv6 headers in Tx path
+-    - LP: #1536473
+-  * ixgbe: Always turn PHY power on when requested
+-    - LP: #1536473
+-  * ixgbevf: Handle extended IPv6 headers in Tx path
+-    - LP: #1536473
+-  * ixgbe: Return error on failure to allocate mac_table
+-    - LP: #1536473
+-  * ixgbe: Fix SR-IOV VLAN pool configuration
+-    - LP: #1536473
+-  * ixgbe: Simplify definitions for regidx and bit in set_vfta
+-    - LP: #1536473
+-  * ixgbe: Reduce VT code indent in set_vfta by introducing jump label
+-    - LP: #1536473
+-  * ixgbe: Simplify configuration of setting VLVF and VLVFB
+-    - LP: #1536473
+-  * ixgbe: Add support for adding/removing VLAN on PF bypassing the VLVF
+-    - LP: #1536473
+-  * ixgbe: Reorder search to work from the top down instead of bottom up
+-    - LP: #1536473
+-  * ixgbe: Add support for VLAN promiscuous with SR-IOV
+-    - LP: #1536473
+-  * ixgbe: Fix VLAN promisc in relation to SR-IOV
+-    - LP: #1536473
+-  * ixgbe: Clear stale pool mappings
+-    - LP: #1536473
+-  * ixgbe: Clean stale VLANs when changing port VLAN or resetting
+-    - LP: #1536473
+-  * ixgbe: do not report 2.5 Gbps as supported
+-    - LP: #1536473
+-  * ixgbevf: Fix handling of NAPI budget when multiple queues are enabled
+-    per vector
+-    - LP: #1536473
+-  * ixgbevf: minor cleanups for ixgbevf_set_itr()
+-    - LP: #1536473
+-  * ixgbe: add support for QSFP PHY types in ixgbe_get_settings()
+-    - LP: #1536473
+-  * ixgbe: report correct media type for KR, KX and KX4 interfaces
+-    - LP: #1536473
+-  * ixgbe: Clean up redundancy in hw_enc_features
+-    - LP: #1536473
+-  * ixgbe: fix RSS limit for X550
+-    - LP: #1536473
+-  * ixgbe: Correct X550EM_x revision check
+-    - LP: #1536473
+-  * ixgbe: Fix bugs in ixgbe_clear_vf_vlans()
+-    - LP: #1536473
+-  * ixgbe: Fill at least min credits to a TC credit refills
+-    - LP: #1536473
+-  * ixgbe: use correct FCoE DDP max check
+-    - LP: #1536473
+-  * ixgbe: fix broken PFC with X550
+-    - LP: #1536473
+-  * ixgbe: do not call check_link for ethtool in ixgbe_get_settings()
+-    - LP: #1536473
+-  * ixgbe: Correct handling of any outer UDP checksum setting
+-    - LP: #1536473
+-  * ixgbe: Fix to get FDMI HBA attributes information with X550
+-    - LP: #1536473
+-  * ixgbe: Fix MDD events generated when FCoE+SRIOV are enabled
+-    - LP: #1536473
+-  * ixgbe: Make ATR recognize IPv6 extended headers
+-    - LP: #1536473
+-  * e1000: make eeprom read/write scheduler friendly
+-  * e1000: fix data race between tx_ring->next_to_clean
+-  * e1000: Remove checkpatch coding style errors
+-  * e1000: clean up the checking logic
+-  * e1000: fix a typo in the comment
+-  * e1000e: clean up the local variable
+-  * e1000: fix kernel-doc argument being missing
+-  * e1000: get rid of duplicate exit path
+-  * e1000: Elementary checkpatch warnings and checks removed
+-  * e1000e: fix division by zero on jumbo MTUs
+-  * e1000e: Increase timeout of polling bit RSPCIPHY
+-  * e1000e: initial support for i219-LM (3)
+-  * e1000e: Switch e1000e_up to void, drop code checking for error result
+-  * e1000e: Remove unreachable code
+-  * e1000e: Do not read ICR in Other interrupt
+-  * e1000e: Do not write lsc to ics in msi-x mode
+-  * e1000e: Fix msi-x interrupt automask
+-  * acpi: pci: Setup MSI domain for ACPI based pci devices
+-  * irqdomain: Introduce is_fwnode_irqchip helper
+-  * irqchip/gic-v2m: Refactor to prepare for ACPI support
+-  * irqchip/gic-v2m: acpi: Introducing GICv2m ACPI support
+-  * clk: xgene: Fix divider with non-zero shift value
+-  * i2c: designware: Do not require clock when SSCN and FFCN are provided
+-  * fm10k: do not assume VF always has 1 queue
+-    - LP: #1536475
+-  * fm10k: Correct MTU for jumbo frames
+-    - LP: #1536475
+-  * fm10k: Fix handling of NAPI budget when multiple queues are enabled per
+-    vector
+-    - LP: #1536475
+-  * fm10k: use napi_schedule_irqoff()
+-    - LP: #1536475
+-  * fm10k: set netdev features in one location
+-    - LP: #1536475
+-  * fm10k: reset max_queues on init_hw_vf failure
+-    - LP: #1536475
+-  * fm10k: always check init_hw for errors
+-    - LP: #1536475
+-  * fm10k: reinitialize queuing scheme after calling init_hw
+-    - LP: #1536475
+-  * fm10k: Correct typecast in fm10k_update_xc_addr_pf
+-    - LP: #1536475
+-  * fm10k: explicitly typecast vlan values to u16
+-    - LP: #1536475
+-  * fm10k: add statistics for actual DWORD count of mbmem mailbox
+-    - LP: #1536475
+-  * fm10k: rename mbx_tx_oversized statistic to mbx_tx_dropped
+-    - LP: #1536475
+-  * fm10k: Add support for ITR scaling based on PCIe link speed
+-    - LP: #1536475
+-  * fm10k: introduce ITR_IS_ADAPTIVE macro
+-    - LP: #1536475
+-  * fm10k: Update adaptive ITR algorithm
+-    - LP: #1536475
+-  * fm10k: use macro for default Tx and Rx ITR values
+-    - LP: #1536475
+-  * fm10k: change default Tx ITR to 25usec
+-    - LP: #1536475
+-  * fm10k: TRIVIAL fix typo of hardware
+-    - LP: #1536475
+-  * fm10k: TRIVIAL cleanup order at top of fm10k_xmit_frame
+-    - LP: #1536475
+-  * fm10k: use ether_addr_copy to copy MAC address
+-    - LP: #1536475
+-  * fm10k: do not use CamelCase
+-    - LP: #1536475
+-  * fm10k: remove unnecessary else block from if statements with return
+-    - LP: #1536475
+-  * fm10k: remove namespace pollution of fm10k_iov_msg_data_pf
+-    - LP: #1536475
+-  * fm10k: consistently refer to VLANs and VLAN IDs
+-    - LP: #1536475
+-  * fm10k: bump driver version
+-    - LP: #1536475
+-  * fm10k: conditionally compile DCB and DebugFS support
+-    - LP: #1536475
+-  * fm10k: Cleanup MSI-X interrupts in case of failure
+-    - LP: #1536475
+-  * fm10k: Cleanup exception handling for mailbox interrupt
+-    - LP: #1536475
+-  * fm10k: do not inline fm10k_iov_select_vid()
+-    - LP: #1536475
+-  * fm10k: whitespace cleanups
+-    - LP: #1536475
+-  * fm10k: use BIT() macro instead of open-coded bit-shifting
+-    - LP: #1536475
+-  * fm10k: cleanup namespace pollution
+-    - LP: #1536475
+-  * fm10k: cleanup overly long lines
+-    - LP: #1536475
+-  * fm10k: initialize xps at driver load
+-    - LP: #1536475
+-  * fm10k: don't initialize fm10k_workqueue at global level
+-    - LP: #1536475
+-  * fm10k: correctly pack TLV structures and explain reasoning
+-    - LP: #1536475
+-  * fm10k: Cleanup exception handling for changing queues
+-    - LP: #1536475
+-  * fm10k: use ether_addr_equal instead of memcmp
+-    - LP: #1536475
+-  * fm10k: address operator not needed when declaring function pointers
+-    - LP: #1536475
+-  * fm10k: constify fm10k_mac_ops, fm10k_iov_ops and fm10k_info structures
+-    - LP: #1536475
+-  * fm10k: remove unused struct element
+-    - LP: #1536475
+-  * fm10k: use true/false for boolean get_host_state
+-    - LP: #1536475
+-  * fm10k: cleanup mailbox code comments etc
+-    - LP: #1536475
+-  * fm10k: IS_ENABLED() is not appropriate for boolean kconfig option
+-    - LP: #1536475
+-  * device property: always check for fwnode type
+-    - LP: #1533035
+-  * device property: rename helper functions
+-    - LP: #1533035
+-  * device property: refactor built-in properties support
+-    - LP: #1533035
+-  * device property: keep single value inplace
+-    - LP: #1533035
+-  * device property: helper macros for property entry creation
+-    - LP: #1533035
+-  * device property: improve readability of macros
+-    - LP: #1533035
+-  * device property: return -EINVAL when property isn't found in ACPI
+-    - LP: #1533035
+-  * device property: Fallback to secondary fwnode if primary misses the
+-    property
+-    - LP: #1533035
+-  * device property: Take a copy of the property set
+-    - LP: #1533035
+-  * driver core: platform: Add support for built-in device properties
+-    - LP: #1533035
+-  * driver core: Do not overwrite secondary fwnode with NULL if it is set
+-    - LP: #1533035
+-  * mfd: core: propagate device properties to sub devices drivers
+-    - LP: #1533035
+-  * mfd: intel-lpss: Add support for passing device properties
+-    - LP: #1533035
+-  * mfd: intel-lpss: Pass SDA hold time to I2C host controller driver
+-    - LP: #1533035
+-  * mfd: intel-lpss: Pass HSUART configuration via properties
+-    - LP: #1533035
+-  * i2c: designware: Convert to use unified device property API
+-    - LP: #1533035
+-  * keys, trusted: fix: *do not* allow duplicate key options
+-    - LP: #1398274
+-  * keys, trusted: select hash algorithm for TPM2 chips
+-    - LP: #1398274
+-  * keys, trusted: seal with a TPM2 authorization policy
+-    - LP: #1398274
+-  * perf/x86/intel: Add perf core PMU support for Intel Knights Landing
+-    - LP: #1461360
+-  * perf/x86/intel/uncore: Add Knights Landing uncore PMU support
+-    - LP: #1461360
+-  * perf/x86/intel/uncore: Remove hard coding of PMON box control MSR
+-    offset
+-    - LP: #1461360
+-  * drm/i915: WaRsDisableCoarsePowerGating
+-    - LP: #1527462
+-  * drm/i915/skl: Add SKL GT4 PCI IDs
+-    - LP: #1527462
+-  * drm/i915/skl: Disable coarse power gating up until F0
+-    - LP: #1527462
+-  * platform:x86: add Intel P-Unit mailbox IPC driver
+-    - LP: #1520457
+-  * intel_punit_ipc: add NULL check for input parameters
+-    - LP: #1520457
+-  * platform/x86: Add Intel Telemetry Core Driver
+-    - LP: #1520457
+-  * intel_pmc_ipc: update acpi resource structure for Punit
+-    - LP: #1520457
+-  * platform:x86: Add Intel telemetry platform device
+-    - LP: #1520457
+-  * platform:x86: Add Intel telemetry platform driver
+-    - LP: #1520457
+-  * platform:x86: Add Intel Telemetry Debugfs interfaces
+-    - LP: #1520457
+-  * cxlflash: a couple off by one bugs
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 28 Jan 2016 13:56:00 +0000
+-
+-linux (4.4.0-1.15) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1536803
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "[SCSI] libiscsi: Reduce locking contention in fast path"
+-    - LP: #1517142
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 20 Jan 2016 07:41:40 -0700
+-
+-linux (4.4.0-0.14) xenial; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "powerpc/pci: Remove unused struct pci_dn.pcidev field"
+-    - LP: #1522415
+-  * powerpc: Add __raw_rm_writeq() function
+-    - LP: #1522415
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 19 Jan 2016 11:24:26 -0700
+-
+-linux (4.4.0-0.13) xenial; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] s390x -- the kernel provides ppp-modules such as there are
+-  * SAUCE: (no-up) add compat_uts_machine= kernel command line override
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Update annotations for VIRTIO_{NET,BLK}
+-    - LP: #1533382
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * powerpc/powernv: Add support for Nvlink NPUs
+-    - LP: #1522415
+-  * powerpc/powernv: Fix update of NVLink DMA mask
+-    - LP: #1522415
+-  * powerpc/powernv: Change NPU PE# assignment
+-    - LP: #1522415
+-  * powerpc/powernv: Reserve PE#0 on NPU
+-    - LP: #1522415
+-  * KEYS: Fix keyring ref leak in join_session_keyring()
+-    - LP: #1534887
+-    - CVE-2016-0728
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 19 Jan 2016 05:49:09 -0700
+-
+-linux (4.4.0-0.12) xenial; urgency=low
+-
+-  [ Eric Dumazet ]
+-
+-  * SAUCE: (no-up) udp: properly support MSG_PEEK with truncated buffers
+-    - LP: #1527902
+-
+-  [ Guilherme G. Piccoli ]
+-
+-  * SAUCE: powerpc/eeh: Validate arch in eeh_add_device_early()
+-    - LP: #1486180
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: AUFS - update to aufs4.x-rcN 20160111
+-  * [Config] CONFIG_VIRTIO_BLK=y, CONFIG_VIRTIO_NET=y for s390
+-    - LP: #1532886
+-  * [Config] nvme.ko moved to drivers/nvme/host
+-  * [Config] scsi_dh morphed into 4 modules
+-  * [Config] CONFIG_IBMVNIC=m
+-  * [Config] Add DRM ast driver to udeb installer image
+-    - LP: #1514711
+-  * [Config] CONFIG_KVM=y for s390x
+-    - LP: #1532886
+-  * [Config] Install spl/zfs under the kernel modules directory
+-    Fixes some errors in generic.inclusion-list.log
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * perf/x86/intel/uncore: Add Broadwell-EP uncore support
+-    - LP: #1524574
+-  * EDAC: Add DDR4 flag
+-    - LP: #1519631
+-  * EDAC, sb_edac: Virtualize several hard-coded functions
+-    - LP: #1519631
+-  * EDAC, sb_edac: Add support for duplicate device IDs
+-    - LP: #1519631
+-  * EDAC, sb_edac: Add Knights Landing (Xeon Phi gen 2) support
+-    - LP: #1519631
+-  * Driver for IBM System i/p VNIC protocol
+-    - LP: #1532303
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 11 Jan 2016 09:57:16 -0700
+-
+-linux (4.4.0-0.11) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Fix bogus reconstruct script
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 11 Jan 2016 07:29:17 -0700
+-
+-linux (4.4.0-0.10) xenial; urgency=low
+-
+-  [ Haren Myneni ]
+-
+-  * SAUCE: crypto: nx-842 - Mask XERS0 bit in return value
+-    - LP: #1529666
+-
+-  [ Serge Hallyn ]
+-
+-  * SAUCE: add a sysctl to disable unprivileged user namespace unsharing
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_ZONE_DEVICE=y for amd64
+-  * [Config] CONFIG_BLK_DEV_LOOP=y for s390x
+-    - LP: #1526869
+-  * SAUCE: (no-up) apparmor: Fix incompatible pointer type warnings
+-  * SAUCE: radeon: r100: Silence 'may be used uninitialized' warnings
+-  * SAUCE: dmaengine: ioatdma: Squelch framesize warnings
+-  * rebase to v4.4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.4
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 04 Jan 2016 17:43:51 -0700
+-
+-linux (4.4.0-0.9) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v4.4-rc8
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.4-rc8
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Sun, 03 Jan 2016 18:50:33 -0700
+-
+-linux (4.4.0-0.8) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v4.4-rc7
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.4-rc7
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 28 Dec 2015 16:13:11 -0700
+-
+-linux (4.4.0-0.7) xenial; urgency=low
+-
+-  [ Hui Wang ]
+-
+-  * [Config] CONFIG_I2C_DESIGNWARE_BAYTRAIL=y, CONFIG_IOSF_MBI=y
+-    - LP: #1527096
+-
+-  [ Jann Horn ]
+-
+-  * SAUCE: (noup) ptrace: being capable wrt a process requires mapped
+-    uids/gids
+-    - LP: #1527374
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v4.4-rc6
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.4-rc6
+-    - LP: #1526330
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 17 Dec 2015 05:28:27 -0700
+-
+-linux (4.4.0-0.6) xenial; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] disable CONFIG_ARM64_LSE_ATOMICS to avoid issues with ARMv8.1
+-    support in latest compilers
+-  * [Config] disable CONFIG_CRYPTO_AES_ARM64_CE* to avoid issues with
+-    ARMv8.1 support in latest compilers
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] s390 -> s390x
+-  * SAUCE: include/linux/mmdebug.h: #include <linux/bug.h>
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Dec 2015 06:46:26 -0700
+-
+-linux (4.4.0-0.5) xenial; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] s390x -- enable tools
+-    - LP: #1524319
+-  * [Config] s390x -- add architecture to getabis
+-  * [Config] s390x -- add s390x ABI information
+-  * [Config] s390x -- enable ABI checks
+-
+-  [ Tim Gardner ]
+-
+-  * [Debian] config-check and prepare using ${DEBIAN}/config/annotations
+-  * [Config] Add s390 modules to nic-modules udeb
+-    - LP: #1525297
+-  * rebase to v4.4-rc5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.4-rc5
+-    - LP: #1523517
+-    - LP: #1523232
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 14 Dec 2015 05:28:05 -0700
+-
+-linux (4.4.0-0.4) xenial; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * cgroup: make css_set pin its css's to avoid use-afer-free
+-  * cgroup_freezer: simplify propagation of CGROUP_FROZEN clearing in
+-    freezer_attach()
+-  * cgroup: fix handling of multi-destination migration from
+-    subtree_control enabling
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 08 Dec 2015 11:20:41 -0700
+-
+-linux (4.4.0-0.3) xenial; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.4-rc4
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Sun, 06 Dec 2015 16:50:15 -0700
+-
+-linux (4.4.0-0.2) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add spl/zfs provides to generic and powerpc64-smp
+-  * [Config] Add zfs to d-i fs-core-modules
+-  * [Config] Include all s390 specific drivers in linux-image
+-    - LP: #1522210
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 03 Dec 2015 07:05:56 -0700
+-
+-linux (4.4.0-0.1) xenial; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Tests] gcc-multilib does not exist on ppc64el redux
+-    - LP: #1515541
+-  * [Config] libunwind8-dev is not available on s390x
+-  * [Debian] Disable SPL/ZFS for cross compiling -- redux
+-  * [Config] s390x -- add dasd udebs
+-    - LP: #1519833
+-  * [Config] s390x -- include dasd modules in linux-image
+-    - LP: #1519833
+-  * [Config] s390x -- disable ZFS temporarily
+-    - LP: #1519820
+-  * [Config] s390s -- disable ABI/module checks
+-  * [Config] make IBMVETH consistent on powerpc/ppc64el
+-    - LP: #1521712
+-  * [Config] follow ibmvscsi name change
+-    - LP: #1521712
+-  * [Config] move ibm disk and ethernet drivers to linux-image
+-    - LP: #1521712
+-  * [Config] include ibmveth in nic-modules for ppc64el
+-    - LP: #1521712
+-  * [Config] s390x -- disable abi/module checks for s390x
+-
+-  [ Joseph Salisbury ]
+-
+-  * SAUCE: scsi_sysfs: protect against double execution of
+-    __scsi_remove_device()
+-    - LP: #1509029
+-
+-  [ Seth Forshee ]
+-
+-  * [Config] CONFIG_DRM_AMDGPU_CIK=n
+-    - LP: #1510405
+-
+-  [ Tim Gardner ]
+-
+-  * [Debian] Disable SPL/ZFS for cross compiling
+-  * [Config] CONFIG_SCSI_IBMVSCSI=m
+-    - LP: #1515872
+-  * rebase to v4.4-rc2
+-  * [Config] updateconfigs
+-  * [Config] CONFIG_WILC1000_DRIVER=n for FTBS
+-  * SAUCE: do_zfs=false temporarily
+-  * [Config] CONFIG_LUSTRE_FS=n
+-  * [Debian] Disable udebs when cross compiling
+-  * rebase to v4.4-rc3
+-  * [Config] CONFIG_AUFS_FS=m
+-  * SAUCE: AUFS
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ZFS: Update with 4.4 support
+-  * SPL: Update with 4.4 support
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.4-rc3
+-    - LP: #1519168
+-  * rebase to v4.4-rc2
+-    - LP: #1506615
+-    - LP: #1502781
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 23 Nov 2015 13:22:37 -0700
+-
+-linux (4.3.0-0.8) xenial; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] re-enable OSS support and blacklist
+-    - LP: #1434842
+-  * [Config] enable CONFIG_CC_STACKPROTECTOR_STRONG=y
+-  * [Packaging] config-check -- improve syntax diagnostics
+-  * [Packaging] module-inclusion -- add dependency inclusion for a list
+-  * [Packaging] config-check -- accumulate multi-line annotations correctly
+-  * [Packaging] config-check -- handle V2 annotations format
+-  * [Packaging] s390x -- add architecture to kernelconfig
+-    - LP: #1488653
+-  * [Config] s390x -- initial configuration
+-  * [Config] s390x -- add initial binary image
+-  * [Config] s390x -- initial configuration update
+-  * [Config] s390x -- produce linux-image
+-  * [Config] s390x -- d-i module exclusions
+-  * [Config] apply Device Drivers >> LED Support >> LED Class Support
+-  * [Config] apply File systems >> Miscellaneous filesystems >> SquashFS 4.0 - Squashed file system support
+-  * [Config] apply Device Drivers >> Generic Driver Options >> Userspace firmware loading support
+-  * SAUCE: leds: lp55xx -- do not force use of the fallback loader
+-  * [Config] -- s390x -- configuration review updates
+-  * [Config] annotations -- add review marks
+-  * [Config] annotations -- config review 4.3 updates
+-  * [Config] annotations -- expose reviews
+-  * [Config] updateconfigs following incoporation of s390x configs
+-  * [Tests] gcc-multilib does not exist on ppc64el
+-    - LP: #1515541
+-
+-  [ Dan Carpenter ]
+-
+-  * SAUCE: (noup) cxlflash: a couple off by one bugs
+-    - LP: #1499849
+-
+-  [ Haren Myneni ]
+-
+-  * Revert "SAUCE: (noup) crypto: 842 - Add CRC and validation support"
+-
+-  [ Jay Vosburgh ]
+-
+-  * SAUCE: fan: add VXLAN implementation
+-
+-  [ Manoj Kumar ]
+-
+-  * SAUCE: (noup) cxlflash: Fix to escalate LINK_RESET also on port 1
+-    - LP: #1513583
+-
+-  [ Matthew R. Ochs ]
+-
+-  * SAUCE: (noup) cxlflash: Fix to avoid virtual LUN failover failure
+-    - LP: #1513583
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_AUFS_EXPORT=y
+-    - LP: #1121699
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * misc/genwqe: get rid of atomic allocations
+-  * crypto: 842 - Add CRC and validation support
+-    - LP: #1497878
+-  * cxlflash: Fix to avoid invalid port_sel value
+-  * cxlflash: Replace magic numbers with literals
+-  * cxlflash: Fix read capacity timeout
+-  * cxlflash: Fix potential oops following LUN removal
+-  * cxlflash: Fix data corruption when vLUN used over multiple cards
+-  * cxlflash: Fix to avoid sizeof(bool)
+-  * cxlflash: Fix context encode mask width
+-  * cxlflash: Fix to avoid CXL services during EEH
+-  * cxlflash: Correct naming of limbo state and waitq
+-  * cxlflash: Make functions static
+-  * cxlflash: Refine host/device attributes
+-  * cxlflash: Fix to avoid spamming the kernel log
+-  * cxlflash: Fix to avoid stall while waiting on TMF
+-  * cxlflash: Fix location of setting resid
+-  * cxlflash: Fix host link up event handling
+-  * cxlflash: Fix async interrupt bypass logic
+-  * cxlflash: Remove dual port online dependency
+-  * cxlflash: Fix AFU version access/storage and add check
+-  * cxlflash: Correct usage of scsi_host_put()
+-  * cxlflash: Fix to prevent workq from accessing freed memory
+-  * cxlflash: Correct behavior in device reset handler following EEH
+-  * cxlflash: Remove unnecessary scsi_block_requests
+-  * cxlflash: Fix function prolog parameters and return codes
+-  * cxlflash: Fix MMIO and endianness errors
+-  * cxlflash: Fix to prevent EEH recovery failure
+-  * cxlflash: Correct spelling, grammar, and alignment mistakes
+-  * cxlflash: Fix to prevent stale AFU RRQ
+-  * cxlflash: Fix to double the delay each time
+-  * cxlflash: Fix to avoid corrupting adapter fops
+-  * cxlflash: Correct trace string
+-  * cxlflash: Fix to avoid potential deadlock on EEH
+-  * cxlflash: Fix to avoid leaving dangling interrupt resources
+-  * cxlflash: Fix to escalate to LINK_RESET on login timeout
+-  * cxlflash: Fix to avoid corrupting port selection mask
+-  * cxlflash: Fix to avoid lock instrumentation rejection
+-  * cxlflash: Fix to avoid bypassing context cleanup
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 06 Nov 2015 10:15:07 -0600
+-
+-linux (4.3.0-0.7) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "Bypass spl/zfs config"
+-    Causes unresolved symbols on load.
+-  * [Config] Enable ZFS for powerpc64-smp
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 05 Nov 2015 11:42:37 -0600
+-
+-linux (4.3.0-0.6) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1512704
+-  * UBUNTU: SAUCE: AUFS aufs4.x-rcN 20151102
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] add feature interlock with mainline builds
+-  * apparmor -- follow change to this_cpu_ptr
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: (no-up) apparmor: add parameter to control whether policy hashing is used
+-    - LP: #1383886
+-  * SAUCE: (no-up) apparmor: Sync to apparmor3 - RC1 snapshot
+-    - LP: #1362199
+-  * SAUCE: Revert: fix: only allow a single threaded process to ...
+-    - LP: #1371310
+-  * SAUCE: (no-up) fix: bad unix_addr_fs macro
+-    - LP: #1390223
+-  * SAUCE: (no-up): apparmor: fix mediation of fs unix sockets
+-    - LP: #1408833
+-  * SAUCE: (no-up) apparmor: fix mount not handling disconnected paths
+-    - LP: #1496430
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add iscsi_ibft and iscsi_boot_sysfs to generic inclusion list
+-    - LP: #1511006
+-  * rebase to v4.3
+-  * Bypass spl/zfs config
+-  * SPL/ZFS: Add Makefiles in order to avoid the lengthy config
+-  * [Config] Default AppArmor settings
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.3
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 29 Oct 2015 09:16:26 -0600
+-
+-linux (4.3.0-0.5) xenial; urgency=low
+-
+-  * Update spl to 0.6.5.3-0ubuntu1, zfs to 0.6.5.3-0ubuntu1
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.3-rc7
+-    - LP: #1504778
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 23 Oct 2015 13:59:52 -0600
+-
+-linux (4.3.0-0.4) xenial; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Debian] Update to new signing key type and location
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 21 Oct 2015 13:07:30 -0600
+-
+-linux (4.3.0-0.3) wily; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Debian] sign-file is now compiled
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 21 Oct 2015 09:26:34 -0600
+-
+-linux (4.3.0-0.2) wily; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Added libssl-dev to Build-Depends
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 20 Oct 2015 14:01:55 -0600
+-
+-linux (4.3.0-0.1) wily; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.3-rc6
+-  * rebase to v4.3-rc5
+-  * rebase to v4.3-rc4
+-  * rebase to v4.3-rc3
+-  * rebase to v4.3-rc2
+-  * rebase to v4.3-rc1
+-    - LP: #1492132
+-    - LP: #1481575
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 14 Sep 2015 07:30:36 -0600
+-
+-linux (4.2.0-10.11) wily; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Release Tracking Bug
+-    - LP: #1495208
+-  * No change rebuild to avoid issues with leading zero bytes on
+-    internal module signing key.  (see launchpad bug 1494943)
+-
+-  [ Ming Lei ]
+-
+-  * [Config] SERIAL_8250_DW=y for arm64
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drm/i915: Move WaBarrierPerformanceFixDisable:skl to skl code from chv
+-    code
+-    - LP: #1484486
+-  * drm/i915/gen8: Add infrastructure to initialize WA batch buffers
+-    - LP: #1484486
+-  * drm/i915/gen8: Re-order init pipe_control in lrc mode
+-    - LP: #1484486
+-  * drm/i915/gen8: Add WaDisableCtxRestoreArbitration workaround
+-    - LP: #1484486
+-  * drm/i915/gen8: Add WaFlushCoherentL3CacheLinesAtContextSwitch
+-    workaround
+-    - LP: #1484486
+-  * drm/i915: Bail out early if WA batch is not available for given Gen
+-    - LP: #1484486
+-  * drm/i915/gen8: Add WaClearSlmSpaceAtContextSwitch workaround
+-    - LP: #1484486
+-  * drm/i915: Update WaFlushCoherentL3CacheLinesAtContextSwitch
+-    - LP: #1484486
+-  * drm/i915/gen9: Implement WaDisableKillLogic for gen 9
+-    - LP: #1484486
+-  * drm/i915: Enable WA batch buffers for Gen9
+-    - LP: #1484486
+-  * drm/i915/gen9: Add WaDisableCtxRestoreArbitration workaround
+-    - LP: #1484486
+-  * drm/i915: Update wa_ctx_emit() macro as per kernel coding guidelines
+-    - LP: #1484486
+-  * drm/i915/gen9: Add WaFlushCoherentL3CacheLinesAtContextSwitch
+-    workaround
+-    - LP: #1484486
+-  * drm/i915/gen9: Add
+-    WaSetDisablePixMaskCammingAndRhwoInCommonSliceChicken
+-    - LP: #1484486
+-  * drm/i915:skl: Add WaEnableGapsTsvCreditFix
+-    - LP: #1484486
+-  * drm/i915/skl: revert duplicated WaBarrierPerformanceFixDisable:skl
+-    - LP: #1484486
+-  * drm/i915/skl: Don't expose the top most plane on gen9 display
+-    - LP: #1484486
+-  * drm/i915/skl WaDisableSbeCacheDispatchPortSharing
+-    - LP: #1484486
+-  * drm/i915/skl: WaIgnoreDDIAStrap is forever, always init DDI A
+-    - LP: #1484486
+-  * drm/i915: reduce indent in i9xx_hpd_irq_handler
+-    - LP: #1484531
+-  * drm/i915: reduce duplicate conditions in i9xx_hpd_irq_handler
+-    - LP: #1484531
+-  * drm/i915: reduce indent in intel_hpd_irq_handler
+-    - LP: #1484531
+-  * drm/i915: group all hotplug related fields into a new struct in
+-    dev_priv
+-    - LP: #1484531
+-  * drm/i915: add for_each_hpd_pin to iterate over hotplug pins
+-    - LP: #1484531
+-  * drm/i915: simplify conditions for skipping the 2nd hpd loop iterations
+-    - LP: #1484531
+-  * drm/i915: put back the indent in intel_hpd_irq_handler
+-    - LP: #1484531
+-  * drm/i915: merge the two hpd loops in intel_hpd_irq_handler to one
+-    - LP: #1484531
+-  * drm/i915: simplify condition for digital port
+-    - LP: #1484531
+-  * drm/i915: abstract away platform specific parts from hpd handling
+-    - LP: #1484531
+-  * drm/i915: Handle HPD when it has actually occurred
+-    - LP: #1484531
+-  * drm/i915: Set power domain for DDI-E
+-    - LP: #1484531
+-  * drm/i915: Set alternate aux for DDI-E
+-    - LP: #1484531
+-  * drm/i915/skl: enable DDI-E hotplug
+-    - LP: #1484531
+-  * drm/i915/bxt: fix DDI PHY vswing scale value setting
+-    - LP: #1494163
+-  * drm/i915/skl: Buffer translation improvements
+-    - LP: #1494163
+-  * drm/i915: Per-DDI I_boost override
+-    - LP: #1494163
+-  * drm/i915: fix VBT parsing for SDVO child device mapping
+-    - LP: #1494163
+-  * drm/i915/bxt: edp1.4 Intermediate Freq support
+-    - LP: #1494163
+-  * drm/i915: fix link rates reported for SKL
+-    - LP: #1494163
+-  * drm/i915: Allow parsing of variable size child device entries from VBT
+-    - LP: #1494163
+-  * drm/i915/skl: Update DDI buffer translation programming.
+-    - LP: #1494163
+-  * drm/i915: Enable HDMI on DDI-E
+-    - LP: #1484531
+-  * drm/i915/skl: Enable DDI-E
+-    - LP: #1484531
+-  * drm/i915: eDP can be present on DDI-E
+-    - LP: #1484531
+-  * drm/i915/skl: Adding DDI_E power well domain
+-    - LP: #1484531
+-  * drm/i915: set CDCLK if DPLL0 enabled during resuming from S3
+-    - LP: #1490035
+-  * drm/i915: Split atomic wm update to pre and post variants
+-    - LP: #1493746
+-  * drm/i915/skl: Drop the preliminary_hw_support flag
+-    - LP: #1486868
+-  * drm/i915: set FDI translations to NULL on SKL
+-    - LP: #1494163
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sun, 13 Sep 2015 11:32:02 +0100
+-
+-linux (4.2.0-9.9) wily; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1493970
+-  * [Config] CONFIG_MFD_INTEL_LPSS=m
+-    - LP: #1397876
+-
+-  [ dann frazier ]
+-
+-  * [Config] Disable CONFIG_IPMI_SI_PROBE_DEFAULTS on armhf and arm64
+-    - LP: #1388952
+-
+-  [ Michael Ellerman ]
+-
+-  * SAUCE: crypto: vmx - VMX crypto should depend on CONFIG_VSX
+-    Fixes FTBS on 32 bit powerpc, patch sent upstream.
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * thermal/powerclamp: add cpu id for skylake h/s
+-    - LP: #1398269
+-  * perf/x86/intel/uncore: Add Broadwell-DE uncore support
+-    - LP: #1397852
+-  * mfd: watchdog: iTCO_wdt: Expose watchdog properties using platform data
+-    - LP: #1460905
+-  * i2c: i801: Create iTCO device on newer Intel PCHs
+-    - LP: #1460905
+-  * watchdog: iTCO_wdt: Add support for TCO on Intel Sunrisepoint
+-    - LP: #1460905
+-  * perf/x86: Add a native_perf_sched_clock_from_tsc()
+-    - LP: #1397867
+-  * perf/x86/intel: Add support for PEBSv3 profiling
+-    - LP: #1397867
+-  * perf/x86/intel/lbr: Allow time stamp for free running PEBSv3
+-    - LP: #1397867
+-  * x86: Add new MSRs and MSR bits used for Intel Skylake PMU support
+-    - LP: #1397867
+-  * perf: Add cycles to branch_info
+-    - LP: #1397867
+-  * perf/x86/intel/lbr: Add support for LBRv5
+-    - LP: #1397867
+-  * perf/x86/intel: Handle new arch perfmon v4 status bits
+-    - LP: #1397867
+-  * perf/x86/intel: Move PMU ACK to after LBR read
+-    - LP: #1397867
+-  * perf/x86/intel/lbr: Optimize v4 LBR unfreezing
+-    - LP: #1397867
+-  * perf/x86/intel: Add Intel Skylake PMU support
+-    - LP: #1397867
+-  * perf/x86/intel/lbr: Use correct index to save/restore LBR_INFO with
+-    call stack
+-    - LP: #1397867
+-  * perf/x86/intel/lbr: Limit LBR accesses to TOS in callstack mode
+-    - LP: #1397867
+-  * perf/x86: Make merge_attr() global to use from perf_event_intel
+-    - LP: #1397867
+-  * perf/x86/intel: Use 0x11 as extra reg test value
+-    - LP: #1397867
+-  * perf tools: Add support for cycles, weight branch_info field
+-    - LP: #1397867
+-  * perf report: Add flag for non ANY branch mode
+-    - LP: #1397867
+-  * perf report: Add infrastructure for a cycles histogram
+-    - LP: #1397867
+-  * perf report: Add processing for cycle histograms
+-    - LP: #1397867
+-  * perf annotate: Compute IPC and basic block cycles
+-    - LP: #1397867
+-  * perf annotate: Finally display IPC and cycle accounting
+-    - LP: #1397867
+-  * perf top: Add branch annotation code to top
+-    - LP: #1397867
+-  * perf report: Display cycles in branch sort mode
+-    - LP: #1397867
+-  * perf annotate: Fix 32-bit compilation error in util/annotate.c
+-    - LP: #1397867
+-  * PM / QoS: Make it possible to expose device latency tolerance to
+-    userspace
+-    - LP: #1460908
+-  * ACPI / PM: Attach ACPI power domain only once
+-    - LP: #1460908
+-  * Driver core: wakeup the parent device before trying probe
+-    - LP: #1460908
+-  * klist: implement klist_prev()
+-    - LP: #1460908
+-  * driver core: implement device_for_each_child_reverse()
+-    - LP: #1460908
+-  * mfd: make mfd_remove_devices() iterate in reverse order
+-    - LP: #1460908
+-  * dmaengine: add a driver for Intel integrated DMA 64-bit
+-    - LP: #1460908
+-  * mfd: Add support for Intel Sunrisepoint LPSS devices
+-    - LP: #1460908
+-  * spi: pxa2xx: Add support for Intel Sunrisepoint
+-    - LP: #1397876
+-  * spi: spi-pxa2xx: Remove unused legacy PXA DMA API channel numbers
+-    - LP: #1397876
+-  * spi: pxa2xx: Add terminating entry for pxa2xx_spi_pci_compound_match
+-    - LP: #1397876
+-  * spi: spi-pxa2xx: Remove unused legacy null dma buffer and allocation
+-    for it
+-    - LP: #1397876
+-  * intel_idle: Skylake Client Support
+-    - LP: #1397877
+-  * powerpc/kernel: Switch to using MAX_ERRNO
+-    - LP: #1458876
+-  * powerpc/kernel: Change the do_syscall_trace_enter() API
+-    - LP: #1458876
+-  * powerpc: Drop unused syscall_get_error()
+-    - LP: #1458876
+-  * powerpc: Don't negate error in syscall_set_return_value()
+-    - LP: #1458876
+-  * powerpc: Rework syscall_get_arguments() so there is only one loop
+-    - LP: #1458876
+-  * powerpc: Use orig_gpr3 in syscall_get_arguments()
+-    - LP: #1458876
+-  * powerpc: Change syscall_get_nr() to return int
+-    - LP: #1458876
+-  * powerpc/kernel: Add SIG_SYS support for compat tasks
+-    - LP: #1458876
+-  * powerpc/kernel: Enable seccomp filter
+-    - LP: #1458876
+-  * selftests/seccomp: Make seccomp tests work on big endian
+-    - LP: #1458876
+-  * selftests/seccomp: Add powerpc support
+-    - LP: #1458876
+-  * eCryptfs: Invalidate dcache entries when lower i_nlink is zero
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 08 Sep 2015 19:17:57 -0600
+-
+-linux (4.2.0-8.8) wily; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1493357
+-  * [Config] CONFIG_CRYPTO_DEV_NX_COMPRESS_CRYPTO obsolete
+-    - LP: #1488495
+-  * [Config] CONFIG_CXLFLASH=m
+-  * [Config] CONFIG_CXL_EEH=y for ppc64el, powerpc64-smp
+-
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] standardise on stage1 for the bootstrap stage in line with debian
+-  * [Packaging] mark up control for stage1
+-  * [Config] kernel-versions -- clean up deps field
+-  * [Config] s390x -- build linux-libc-dev
+-    - LP: #1488653
+-  * [Packaging] control -- prepare for new kernel-wedge semantics
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * crypto: vmx - Fixing AES-CTR counter bug
+-    - LP: #1484519
+-  * crypto: vmx - Fixing GHASH Key issue on little endian
+-    - LP: #1484519
+-  * powerpc: Uncomment and make enable_kernel_vsx() routine available
+-    - LP: #1484519
+-  * crypto: vmx - Adding enable_kernel_vsx() to access VSX instructions
+-    - LP: #1484519
+-  * crypto: nx - nx842_OF_upd_status should return ENODEV if device is not
+-    'okay'
+-    - LP: #1488495
+-  * crypto: nx - rename nx842_{init, exit} to nx842_pseries_{init, exit}
+-    - LP: #1488495
+-  * crypto: nx - do not emit extra output if status is disabled
+-    - LP: #1488495
+-  * crypto: nx - reduce chattiness of platform drivers
+-    - LP: #1488495
+-  * crypto: nx/842 - Fix context corruption
+-    - LP: #1488495
+-  * crypto: nx - remove __init/__exit from VIO functions
+-    - LP: #1488495
+-  * crypto: nx - remove pSeries NX 'status' field
+-    - LP: #1488495
+-  * crypto: nx - move kzalloc() out of spinlock
+-    - LP: #1488495
+-  * crypto: nx - don't register pSeries driver if ENODEV
+-    - LP: #1488495
+-  * crypto: nx - use common code for both NX decompress success cases
+-    - LP: #1488495
+-  * crypto: nx - merge nx-compress and nx-compress-crypto
+-    - LP: #1488495
+-  * crypto: nx - rename nx-842-crypto.c to nx-842.c
+-    - LP: #1488495
+-  * crypto: nx - make platform drivers directly register with crypto
+-    - LP: #1488495
+-  * cxlflash: Base support for IBM CXL Flash Adapter
+-    - LP: #1449121
+-  * cxlflash: Base error recovery support
+-    - LP: #1449121
+-  * cxlflash: Superpipe support
+-    - LP: #1449121
+-  * cxlflash: Virtual LUN support
+-    - LP: #1449121
+-  * cxlflash: off by one bug in cxlflash_show_port_status()
+-    - LP: #1449121
+-  * cxlflash: shift wrapping bug in afu_link_reset()
+-    - LP: #1449121
+-  * cxlflash: Remove unused variable from queuecommand
+-    - LP: #1449121
+-  * powerpc/powernv: move dma_get_required_mask from pnv_phb to
+-    pci_controller_ops
+-  * powerpc/eeh: Probe after unbalanced kref check
+-  * misc: cxl: clean up afu_read_config()
+-  * cxl: Add explicit precision specifiers
+-  * cxl: use more common format specifier
+-  * cxl: Destroy cxl_adapter_idr on module_exit
+-  * cxl: Destroy afu->contexts_idr on release of an afu
+-  * cxl: Don't ignore add_process_element() result when attaching context
+-  * cxl: Compile with -Werror
+-  * cxl: sparse: Make declarations static
+-  * cxl: sparse: Silence iomem warning in debugfs file creation
+-  * cxl: Convert MMIO read/write macros to inline functions
+-  * cxl: Drop commands if the PCI channel is not in normal state
+-  * cxl: Allocate and release the SPA with the AFU
+-  * cxl: Make IRQ release idempotent
+-  * cxl: Clean up adapter MMIO unmap path.
+-  * cxl: Refactor adaptor init/teardown
+-  * cxl: Refactor AFU init/teardown
+-  * cxl: Don't remove AFUs/vPHBs in cxl_reset
+-  * cxl: Allow the kernel to trust that an image won't change on PERST.
+-  * cxl: EEH support
+-  * cxl: Add CONFIG_CXL_EEH symbol
+-  * cxl: Plug irq_bitmap getting leaked in cxl_context
+-  * cxl: Add alternate MMIO error handling
+-  * cxl: Allow release of contexts which have been OPENED but not STARTED
+-  * cxl: Remove use of macro DEFINE_PCI_DEVICE_TABLE
+-  * cxl: Release irqs if memory allocation fails
+-  * cxl: Remove racy attempt to force EEH invocation in reset
+-  * cxl: Fix + cleanup error paths in cxl_dev_context_init
+-  * cxl: Fix force unmapping mmaps of contexts allocated through the kernel api
+-  * cxl: Set up and enable PSL Timebase
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 01 Sep 2015 07:38:43 -0600
+-
+-linux (4.2.0-7.7) wily; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1490564
+-  * rebase to v4.2
+-
+-  [ Wen Xiong ]
+-
+-  * SAUCE: ipr: Byte swapping for device_id attribute in sysfs
+-    - LP: #1453892
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.2
+-    - LP: #1487345
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 26 Aug 2015 07:06:10 -0600
+-
+-linux (4.2.0-6.6) wily; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1488138
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v4.2-rc8
+-
+-  [ Shilpasri G Bhat ]
+-
+-  * SAUCE: cpufreq: powernv: Handle throttling due to Pmax capping at chip
+-    level
+-    - LP: #1480894
+-  * SAUCE: powerpc/powernv: Add definition of OPAL_MSG_OCC message type
+-    - LP: #1480894
+-  * SAUCE: cpufreq: powernv: Register for OCC related opal_message
+-    notification
+-    - LP: #1480894
+-  * SAUCE: cpufreq: powernv: Call throttle_check() on receiving
+-    OCC_THROTTLE
+-    - LP: #1480894
+-  * SAUCE: cpufreq: powernv: Report Psafe only if PMSR.psafe_mode_active
+-    bit is set
+-    - LP: #1480894
+-  * SAUCE: cpufreq: powernv: Restore cpu frequency to policy->cur on
+-    unthrottling
+-    - LP: #1480894
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.2-rc8
+-    - LP: #1483440
+-    - LP: #1484334
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 21 Aug 2015 07:12:11 -0600
+-
+-linux (4.2.0-5.5) wily; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1487173
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] correct spelling of probabaly on the tools packages
+-    - LP: #1256822
+-  * rebase to v4.2-rc7
+-
+-  [ dann frazier ]
+-
+-  * d-i: Add nicpf and nicvf to nic-modules
+-  * d-i: Enable usb modules on arm64
+-
+-  [ Mahesh Salgaonkar ]
+-
+-  * SAUCE: powerpc/powernv: display reason for Malfunction Alert HMI.
+-    - LP: #1482343
+-  * SAUCE: powerpc/powernv: Pull all HMI events before panic.
+-    - LP: #1482343
+-  * SAUCE: powerpc/powernv: Invoke opal_cec_reboot2() on unrecoverable
+-    machine check errors.
+-    - LP: #1482343
+-  * SAUCE: powerpc/powernv: Invoke opal_cec_reboot2() on unrecoverable HMI.
+-    - LP: #1482343
+-
+-  [ Vipin K Parashar ]
+-
+-  * SAUCE: powerpc/powernv: Add poweroff (EPOW, DPO) events support for
+-    PowerNV platform
+-    - LP: #1469771
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.2-rc7
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 11 Aug 2015 09:48:40 -0600
+-
+-linux (4.2.0-4.4) wily; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1483677
+-
+-  [ Achiad Shochat ]
+-
+-  * SAUCE: net/mlx5e: Support TX packet copy into WQE
+-  * SAUCE: net/mlx5e: TX latency optimization to save DMA reads
+-  * SAUCE: net/mlx5e: Cosmetics: use BIT() instead of "1 <<", and others
+-  * SAUCE: net/mlx5e: Input IPSEC.SPI into the RX RSS hash function
+-
+-  [ Adam Lee ]
+-
+-  * SAUCE: serial: 8250_pci: Add support for Pericom PI7C9X795[1248]
+-    - LP: #1480142
+-
+-  [ dann frazier ]
+-
+-  * [Config] CONFIG_NR_CPUS=128 on arm64
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] d-i -- Add sfc to nic-modules udeb
+-    - LP: #1481490
+-
+-  [ Saeed Mahameed ]
+-
+-  * SAUCE: net/mlx5e: Support ETH_RSS_HASH_XOR
+-  * SAUCE: net/mlx5e: Allocate DMA coherent memory on reader NUMA node
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_X86_INTEL_MPX=y
+-    - LP: #1460902
+-  * [Debian] change dependency on module-init-tools to kmod
+-    - LP: #1481986
+-  * rebase to v4.2-rc6
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.2-rc6
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 04 Aug 2015 16:59:45 -0600
+-
+-linux (4.2.0-3.3) wily; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1481462
+-  * SAUCE: workqueue: Make flush_workqueue() available again to non GPL modules
+-    Fixes an FTBS for at least one DKMS package.
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 04 Aug 2015 11:26:53 -0600
+-
+-linux (4.2.0-2.2) wily; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1481067
+-  * rebase to v4.2-rc5
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] module-inclusion -- commonise copy code and simplify
+-  * [Packaging] module-inclusion -- add manual command entries
+-  * [Packaging] module blacklists -- add support for manual blacklists
+-  * [Packaging] do_common_tools should always be on
+-  * [Packaging] initscripts need installing when making the package
+-  * [Packaging] initscripts work around bug in debhelper systemd support
+-  * [Config] exclude oss modules from linux-image
+-    - LP: #1434842
+-  * hyper-v -- add hid and fb drivers to linux-virtual
+-    - LP: #1444179
+-  * ubuntu: (no-squash) vbox -- infrastructure and updater
+-  * ubuntu: vbox -- elide the new symlinks and reconstruct on clean:
+-    - LP: #1426113
+-  * ubuntu: vbox -- update to 5.0.0-dfsg-1
+-    - LP: #1480879
+-  * SAUCE: vbox: follow v4.2 updates to follow_link()/put_link() API
+-  * [Config] move vbox modules into linux-image
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.2-rc5
+-    - LP: #1478497
+-    - LP: #1477900
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 03 Aug 2015 12:20:10 +0100
+-
+-linux (4.2.0-1.1~rc1) wily; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Release Tracking Bug
+-    - LP: #1479903
+-  * Initial upload of v4.2 based kernel (currently v4.-rc4)
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.2-rc4
+-    - LP: #1476987
+-    - LP: #1476888
+-  * rebase to v4.2-rc3
+-  * rebase to v4.2-rc2
+-  * rebase to v4.2-rc1
+-    - LP: #1394368
+-    - LP: #1427680
+-    - LP: #1462614
+-    - LP: #1397021
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 30 Jul 2015 18:42:46 +0100
+-
+-linux (4.1.0-3.3) wily; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Release Tracking Bug
+-    - LP: #1478897
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: KEYS: ensure we free the assoc array edit if edit is valid
+-    - CVE-2015-1333
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: overlayfs: Enable user namespace mounts for the "overlay" fstype
+-    - LP: #1478578
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * sched/stop_machine: Fix deadlock between multiple stop_two_cpus()
+-    - LP: #1461620
+-  * x86/nmi: Enable nested do_nmi() handling for 64-bit kernels
+-  * x86/nmi/64: Remove asm code that saves cr2
+-  * x86/nmi/64: Switch stacks on userspace NMI entry
+-  * x86/nmi/64: Reorder nested NMI checks
+-  * x86/nmi/64: Use DF to avoid userspace RSP confusing nested NMI
+-    detection
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 28 Jul 2015 11:59:03 +0100
+-
+-linux (4.1.0-2.4) wily; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: overlayfs: when copying up and reading directories ensure
+-    mounter had permissions V2
+-    - CVE-2015-1328
+-
+-  [ Leann Ogasawara ]
+-
+-  * Release Tracking Bug
+-    - LP: #1465419
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 15 Jun 2015 14:09:22 -0700
+-
+-linux (4.1.0-2.2) wily; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v4.1.3
+-  * [Config] Add i40e[vf] to d-i
+-    - LP: #1476393
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.1.3
+-    - LP: #1427680
+-    - LP: #1462614
+-    - LP: #1394368
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 22 Jul 2015 09:13:02 -0600
+-
+-linux (4.1.0-1.1) wily; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: overlay: add backwards compatible overlayfs format support V3
+-    - LP: #1395877, #1410480
+-  * SAUCE: overlayfs: when copying up and reading directories ensure
+-    mounter had permissions V2
+-    - CVE-2015-1328
+-  * [Packaging] fix up Vcs-Git: to point to launchpad
+-  * [Config] correct linux-initramfs-tool virtual linkage
+-    - LP: #1474810
+-
+-  [ Chris J Arges ]
+-
+-  * [Config] Add dm-service-time to multipath-modules
+-    - LP: #1469240
+-  * [Config] Add MTD_POWERNV_FLASH and OPAL_PRD
+-    - LP: #1464560
+-
+-  [ Jay Vosburgh ]
+-
+-  * SAUCE: fan: Proof of concept implementation (v2)
+-    - LP: #1439706
+-  * SAUCE: fan: tunnel multiple mapping mode (v3)
+-    - LP: #1470091
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: ext4: disable ext4_punch_hole for indirect filesystems"
+-  * Revert "SAUCE: intel_pstate: inform user that thermald is worth
+-    considering"
+-  * Revert "SAUCE: Work around broken ACPI backlight on Dell Inspiron 5537"
+-  * Revert "SAUCE: dm-crypt: never use write same"
+-  * Release Tracking Bug
+-    - LP: #1476333
+-
+-  [ Tim Gardner ]
+-
+-  * Rebase to v4.1
+-    - LP: #1443371
+-  * [Config] Enable Apparmor
+-  * [Config] CONFIG_OVERLAY_FS_V1=y
+-  * [Config] DEFAULT_IOSCHED="deadline" for ppc64el
+-    - LP: #1469829
+-  * [Config] CONFIG_VM86=n
+-    - LP: #1473447
+-  * [Config] ACORN_PARTITION=n
+-    - LP: #1453117
+-
+-  [ Timo Aaltonen ]
+-
+-  * [Config] Disable CONFIG_DRM_I915_PRELIMINARY_HW_SUPPORT
+-    - LP: #1473319
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * efi: efivar_create_sysfs_entry() should return negative error codes
+-  * efi: Add esrt support
+-  * x86, doc: Remove cmdline_size from list of fields to be filled in for
+-    EFI handover
+-  * efi/esrt: Fix some compiler warnings
+-  * efi: dmi: List SMBIOS3 table before SMBIOS table
+-  * efi: Add 'systab' information to Documentation/ABI
+-  * ALSA: hda - restore the MIC FIXUP for some Dell machines
+-    - LP: #1473560
+-  * mtd: powernv: Add powernv flash MTD abstraction driver
+-    - LP: #1464560
+-  * powerpc/powernv: Expose OPAL APIs required by PRD interface
+-    - LP: #1464560
+-  * powerpc/powernv: Add opal-prd channel
+-    - LP: #1464560
+-  * powerpc/powernv: fix construction of opal PRD messages
+-    - LP: #1464560
+-  * powerpc/include: Add opal-prd to installed uapi headers
+-    - LP: #1464560
+-  * powerpc/powernv: Fix vma page prot flags in opal-prd driver
+-    - LP: #1464560
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 20 Jul 2015 10:16:06 -0700
+-
+-linux (4.0.0-2.4) wily; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: overlayfs: when copying up and reading directories ensure
+-    mounter had permissions V2
+-    - CVE-2015-1328
+-
+-  [ Leann Ogasawara ]
+-
+-  * Release Tracking Bug
+-    - LP: #1465419
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 15 Jun 2015 14:09:22 -0700
+-
+-linux (4.0.0-1.2) wily; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: overlay: add backwards compatible overlayfs format support V3
+-    - LP: #1395877, #1410480
+-  * [Config] enable CONFIG_OVERLAY_FS_V1
+-
+-  [ Tai Nguyen ]
+-
+-  * SAUCE: power: reset: Add syscon reboot device node for APM X-Gene platform
+-    - LP: #1463211
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_HIBERNATION=n for ppc64el
+-    - LP: #1463836
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 12 Jun 2015 06:11:53 -0600
+-
+-linux (4.0.0-1.1) wily; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "md/raid0: fix bug with chunksize not a power of 2."
+-    - LP: #1457510
+-  * powerpc/powernv: Check image loaded or not before calling flash
+-    - LP: #1461553
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] armhf: CPUFREQ_DT=y
+-    - LP: #1457781
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v4.0.5
+-    - LP: #1429756
+-    - LP: #1452175
+-    - LP: #1454656
+-    - LP: #1447909
+-    - LP: #1446517
+-    - LP: #1428947
+-    - LP: #1410704
+-    - LP: #1412800
+-    - LP: #1400215
+-    - LP: #1411193
+-    - LP: #1412800
+-    - LP: #1408295
+-    - LP: #1436745
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 09 Jun 2015 05:58:46 -0700
+-
+-linux (3.19.0-10.10) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] control -- make element ordering deterministic
+-  * [Config] allow dracult to support initramfs as well
+-    - LP: #1109029
+-  * [Packaging] generate live watchdog blacklists
+-    - LP: #1432837
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] CONFIG_KVM_GENERIC_DIRTYLOG_READ_PROTECT=y
+-    - LP: #1397860
+-  * rebase to v3.19.2
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * thinkpad_acpi: support new BIOS version string pattern
+-    - LP: #1417915
+-  * arm64: Invalidate the TLB corresponding to intermediate page table
+-    levels
+-    - LP: #1432546
+-  * perf tools: Support parsing parameterized events
+-    - LP: #1430341
+-  * perf tools: Extend format_alias() to include event parameters
+-    - LP: #1430341
+-  * perf Documentation: Add event parameters
+-    - LP: #1430341
+-  * perf tools: Document parameterized and symbolic events
+-    - LP: #1430341
+-  * perf: provide sysfs_show for struct perf_pmu_events_attr
+-    - LP: #1430341
+-  * perf: add PMU_EVENT_ATTR_STRING() helper
+-    - LP: #1430341
+-  * perf: define EVENT_DEFINE_RANGE_FORMAT_LITE helper
+-    - LP: #1430341
+-  * powerpc/perf/hv-24x7: parse catalog and populate sysfs with events
+-    - LP: #1430341
+-  * powerpc/perf/{hv-gpci, hv-common}: generate requests with counters
+-    annotated
+-    - LP: #1430341
+-  * powerpc/perf/hv-gpci: add the remaining gpci requests
+-    - LP: #1430341
+-  * powerpc/perf/hv-24x7: Document sysfs event description entries
+-    - LP: #1430341
+-  * powerpc/iommu: Remove IOMMU device references via bus notifier
+-    - LP: #1425202
+-  * powerpc/pseries: Fix endian problems with LE migration
+-    - LP: #1428351
+-  * intel_idle: support additional Broadwell model
+-    - LP: #1400970
+-  * tools/power turbostat: support additional Broadwell model
+-    - LP: #1400970
+-  * KVM: x86: flush TLB when D bit is manually changed.
+-    - LP: #1397860
+-  * Optimize TLB flush in kvm_mmu_slot_remove_write_access.
+-    - LP: #1397860
+-  * KVM: Add generic support for dirty page logging
+-    - LP: #1397860
+-  * KVM: x86: switch to kvm_get_dirty_log_protect
+-    - LP: #1397860
+-  * KVM: Rename kvm_arch_mmu_write_protect_pt_masked to be more generic for
+-    log dirty
+-    - LP: #1397860
+-  * KVM: MMU: Add mmu help functions to support PML
+-    - LP: #1397860
+-  * KVM: MMU: Explicitly set D-bit for writable spte.
+-    - LP: #1397860
+-  * KVM: x86: Change parameter of kvm_mmu_slot_remove_write_access
+-    - LP: #1397860
+-  * KVM: x86: Add new dirty logging kvm_x86_ops for PML
+-    - LP: #1397860
+-  * KVM: VMX: Add PML support in VMX
+-    - LP: #1397860
+-  * HID: multitouch: add support of clickpads
+-  * HID: multitouch: Add support for button type usage
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.19.2
+-    - LP: #1428947
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 23 Mar 2015 15:28:16 +0000
+-
+-linux (3.19.0-9.9) vivid; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Release Tracking Bug
+-    - LP: #1430930
+-
+-  [ Shachar Raindel ]
+-
+-  * SAUCE: IB/core: Prevent integer overflow in ib_umem_get address
+-    arithmetic
+-    - LP: #1413741
+-    - CVE-2014-8159
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 11 Mar 2015 10:29:17 -0700
+-
+-linux (3.19.0-8.8) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: vbox -- elide the new symlinks and reconstruct on clean:
+-    - LP: #1426113
+-  * rebase to stable v3.19.1
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: (no-up): apparmor: fix mediation of fs unix sockets
+-    - LP: #1408833
+-
+-  [ Leann Ogasawara ]
+-
+-  * Release Tracking Bug
+-    - LP: #1429940
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * xen: correct bug in p2m list initialization
+-  * net/mlx5_core: Fix configuration of log_uar_page_sz
+-    - LP: #1419938
+-  * tpm/ibmvtpm: Additional LE support for tpm_ibmvtpm_send
+-    - LP: #1420575
+-  * net/mlx4_core: Maintain a persistent memory for mlx4 device
+-    - LP: #1422481
+-  * net/mlx4_core: Set device configuration data to be persistent across
+-    reset
+-    - LP: #1422481
+-  * net/mlx4_core: Refactor the catas flow to work per device
+-    - LP: #1422481
+-  * net/mlx4_core: Enhance the catas flow to support device reset
+-    - LP: #1422481
+-  * net/mlx4_core: Activate reset flow upon fatal command cases
+-    - LP: #1422481
+-  * net/mlx4_core: Manage interface state for Reset flow cases
+-    - LP: #1422481
+-  * net/mlx4_core: Handle AER flow properly
+-    - LP: #1422481
+-  * net/mlx4_core: Enable device recovery flow with SRIOV
+-    - LP: #1422481
+-  * net/mlx4_core: Reset flow activation upon SRIOV fatal command cases
+-    - LP: #1422481
+-  * tg3: Hold tp->lock before calling tg3_halt() from tg3_init_one()
+-    - LP: #1428111
+-  * rebase to v3.19.1
+-    - LP: #1410704
+-    - LP: #1411193
+-    - LP: #1400215
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 09 Mar 2015 10:08:29 -0700
+-
+-linux (3.19.0-7.7) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Release Tracking Bug
+-    - LP: #1426013
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86/irq: Fix regression caused by commit b568b8601f05
+-  * cxl: Fix leaking interrupts if attach process fails
+-    - LP: #1415102
+-  * cxl: Early return from cxl_handle_fault for a shut down context
+-    - LP: #1415102
+-  * cxl: Disable AFU debug flag
+-    - LP: #1415102
+-  * cxl: Disable SPAP register when freeing SPA
+-    - LP: #1415102
+-  * cxl: remove redundant increment of hwirq
+-    - LP: #1415102
+-  * cxl: Add tracepoints
+-    - LP: #1415102
+-  * cxl: Update CXL ABI documentation
+-    - LP: #1415102
+-  * cxl: Use image state defaults for reloading FPGA
+-    - LP: #1415102
+-  * cxl: Add image control to sysfs
+-    - LP: #1415102
+-  * cxl: Enable CAPP recovery
+-    - LP: #1415102
+-  * cxl: Add ability to reset the card
+-    - LP: #1415102
+-  * cxl: Fix device_node reference counting
+-    - LP: #1415102
+-  * cxl: Export optional AFU configuration record in sysfs
+-    - LP: #1415102
+-  * cxl: Fail AFU initialisation if an invalid configuration record is
+-    found
+-    - LP: #1415102
+-  * cxl: Add missing return statement after handling AFU errror
+-    - LP: #1415102
+-  * powerpc/eeh: Introduce flag EEH_PE_REMOVED
+-    - LP: #1415102
+-  * powerpc/eeh: Allow to set maximal frozen times
+-    - LP: #1415102
+-  * HID: i2c-hid: Limit reads to wMaxInputLength bytes for input events
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 26 Feb 2015 16:00:18 +0000
+-
+-linux (3.19.0-6.6) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * systemd -- fix hyper-v units to be non-forking
+-    - LP: #1401525
+-  * [Config] move vbox modules into linux-image
+-  * ubuntu: vbox -- update to 4.3.22-dfsg-1
+-
+-  [ Brad Figg ]
+-
+-  * SAUCE: DEP8 test to run our regression tests
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] I2C_CHARDEV=y
+-    - LP: #1417032
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * PCI: Fix infinite loop with ROM image of size 0
+-  * tpm: Fix NULL return in tpm_ibmvtpm_get_desired_dma
+-  * Bluetooth: ath3k: workaround the compatibility issue with xHCI
+-    controller
+-    - LP: #1400215
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 19 Feb 2015 12:44:43 +0000
+-
+-linux (3.19.0-5.5) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_FA_DUMP=y
+-    - LP: #1415562
+-  * ubuntu: (no-squash) vbox -- infrastructure and updater
+-  * ubuntu: vbox -- update to 4.3.20-dfsg-1ubuntu1
+-  * rebase to v3.19 final
+-
+-  [ Chris J Arges ]
+-
+-  * [Config] Add ibmvfc to d-i
+-    - LP: #1416001
+-  * SAUCE: ext4: disable ext4_punch_hole for indirect filesystems
+-    - LP: #1292234
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.19
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 09 Feb 2015 10:41:11 +0000
+-
+-linux (3.19.0-4.4) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] apply Kernel hacking >> Tracers config defaults
+-  * hyper-v -- fix comment handing in /etc/network/interfaces
+-    - LP: #1413020
+-  * rebase to v3.19-rc7
+-  * updateconfigs following rebase to v3.19-rc7
+-
+-  [ Ben Hutchings ]
+-
+-  * SAUCE: rtsx_usb_ms: Use msleep_interruptible() in polling loop
+-    - LP: #1413149
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.19-rc7
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 02 Feb 2015 17:03:07 +0200
+-
+-linux (3.19.0-3.3) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Debian] arm64 -- build ubuntu drivers
+-    - LP: #1411284
+-  * [Packaging] config-check -- add support for enforced annotations
+-  * [Config] annotations -- switch to ENFORCED annotations
+-  * [Packaging] config-check -- drop support for enforce file
+-  * [Packaging] enforce -- drop empty enforce file
+-  * rebase to v3.19-rc5
+-  * [Config] add modules removed due to tighter dependencies
+-  * [Config] updateconfigs following rebase to v3.19-rc5
+-  * [Config] enforce CONFIG_FHANDLE=y
+-    - LP: #1412543
+-  * [Packaging] hyper-v -- daemons now require -n for non-forking startup
+-    - LP: #1408355
+-  * [Config] CONFIG_DEBUG_INFO_SPLIT=n
+-    - LP: #1413646
+-  * [Config] apply Device Drivers >> Character devices >> IPMI top-level
+-    message handler config defaults
+-  * [Config] apply Device Drivers >> Character devices >> Serial drivers
+-    config defaults
+-  * [Config] apply Device Drivers >> GPIO Support config defaults
+-  * [Config] apply Device Drivers >> Graphics support >> Direct Rendering
+-    Manager >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI
+-    support) config defaults
+-  * [Config] apply Device Drivers >> Graphics support >> Frame buffer
+-    Devices >> Support for frame buffer devices config defaults
+-  * [Config] apply Device Drivers >> HID support >> HID bus support >>
+-    Special HID drivers config defaults
+-  * [Config] apply Device Drivers >> Hardware Monitoring support config
+-    defaults
+-  * [Config] apply Device Drivers >> I2C support >> I2C support >> I2C
+-    Hardware Bus support config defaults
+-  * [Config] apply Device Drivers >> Industrial I/O support >> Analog to
+-    digital converters config defaults
+-  * [Config] apply Device Drivers >> Industrial I/O support >> Humidity
+-    sensors config defaults
+-  * [Config] apply Device Drivers >> Industrial I/O support >> Pressure
+-    sensors config defaults
+-  * [Config] apply Device Drivers >> Input device support >> Generic input
+-    layer (needed for keyboard, mouse, ...) >> Mice config defaults
+-  * [Config] apply Device Drivers >> Input device support >> Generic input
+-    layer (needed for keyboard, mouse, ...) >> Touchscreens config defaults
+-  * [Config] apply Device Drivers >> LED Support >> LED Class Support
+-    config defaults
+-  * [Config] apply Device Drivers >> MMC/SD/SDIO card support config
+-    defaults
+-  * [Config] apply Device Drivers >> Multifunction device drivers config
+-    defaults
+-  * [Config] apply Device Drivers >> Multimedia support >> Cameras/video
+-    grabbers support >> Media test drivers config defaults
+-  * [Config] apply Device Drivers >> Multimedia support >> Media PCI
+-    Adapters config defaults
+-  * [Config] apply Device Drivers >> Multimedia support >> Remote
+-    Controller devices config defaults
+-  * [Config] apply Device Drivers >> Network device support >> Distributed
+-    Switch Architecture drivers config defaults
+-  * [Config] apply Device Drivers >> Network device support >> Network core
+-    driver support config defaults
+-  * [Config] apply Device Drivers >> Network device support >> Wireless LAN
+-    >> Hermes chipset 802.11b support (Orinoco/Prism2/Symbol) config
+-    defaults
+-  * [Config] apply Device Drivers >> Network device support >> Wireless LAN
+-    >> Intel PRO/Wireless 2200BG and 2915ABG Network Connection config
+-    defaults
+-  * [Config] apply Device Drivers >> PHY Subsystem config defaults
+-  * [Config] apply Device Drivers >> Pin controllers config defaults
+-  * [Config] apply Device Drivers >> SPI support config defaults
+-  * [Config] apply Device Drivers >> Sound card support >> Advanced Linux
+-    Sound Architecture >> ALSA for SoC audio support config defaults
+-  * [Config] apply Device Drivers >> Sound card support >> Advanced Linux
+-    Sound Architecture >> FireWire sound devices config defaults
+-  * [Config] apply Device Drivers >> Sound card support >> Advanced Linux
+-    Sound Architecture >> HD-Audio config defaults
+-  * [Config] apply Device Drivers >> Staging drivers >> Lustre file system
+-    client support config defaults
+-  * [Config] apply Device Drivers >> Staging drivers >> Media staging
+-    drivers config defaults
+-  * [Config] apply Device Drivers >> USB support >> USB Gadget Support >>
+-    USB Gadget Drivers >> USB functions configurable through configfs
+-    config defaults
+-  * [Config] apply Device Drivers >> USB support >> USB Gadget Support >>
+-    USB Peripheral Controller config defaults
+-  * [Config] apply Networking support >> NFC subsystem support >> Near
+-    Field Communication (NFC) devices config defaults
+-  * [Config] apply Networking support >> Networking options >> Network
+-    packet filtering framework (Netfilter) >> Core Netfilter Configuration
+-    >> Netfilter nf_tables support config defaults
+-  * [Config] apply Networking support >> Networking options >> QoS and/or
+-    fair queueing >> Actions config defaults
+-  * [Config] apply Networking support >> Networking options >> TCP/IP
+-    networking config defaults
+-  * [Config] apply Networking support >> Wireless >> Generic IEEE 802.11
+-    Networking Stack (mac80211) config defaults
+-  * [Config] apply Device Drivers >> Input device support >> Generic input
+-    layer (needed for keyboard, mouse, ...) >> Keyboards config defaults
+-  * [Config] apply Device Drivers >> Input device support >> Generic input
+-    layer (needed for keyboard, mouse, ...) >> Mice config defaults
+-  * [Config] apply Device Drivers >> Pulse-Width Modulation (PWM) Support
+-    config defaults
+-  * [Config] apply Networking support >> Networking options >> Network
+-    packet filtering framework (Netfilter) >> IP: Netfilter Configuration
+-    >> IPv4 NAT config defaults
+-  * [Config] apply Networking support >> Networking options >> Network
+-    packet filtering framework (Netfilter) >> IPv6: Netfilter Configuration
+-    >> IPv6 NAT config defaults
+-  * [Config] apply Kernel hacking >> Kernel debugging config defaults
+-  * [Config] apply General setup >> Timers subsystem >> Timer tick handling
+-    config defaults
+-  * SAUCE: arm64 -- psci tell the compiler which registers we are needing
+-    values in
+-    - LP: #1414002
+-  * [Config] apply Device Drivers >> Network device support >> Wireless LAN
+-    >> Intel Wireless WiFi Next Gen AGN - Wireless-N/Advanced-N/Ultimate-N
+-    (iwlwifi) config defaults
+-  * [Config] apply Device Drivers >> Real Time Clock config defaults
+-  * [Config] apply Device Drivers >> SCSI device support >> SCSI device
+-    support >> SCSI low-level drivers config defaults
+-  * [Config] apply General setup >> CPU/Task time and stats accounting >>
+-    Cputime accounting config defaults
+-  * [Config] apply Device Drivers >> Mailbox Hardware Support config
+-    defaults
+-  * rebase to v3.19-rc6
+-  * [Config] updateconfigs following rebase to v3.19-rc6
+-
+-  [ Kamal Mostafa ]
+-
+-  * [Packaging] force "dpkg-source -I -i" behavior
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable CONFIG_USB_OTG
+-    - LP: #1411295
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * overlay: add backwards compatible overlayfs format support (fixes)
+-    - LP: #1410480
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.19-rc5
+-  * rebase to v3.19-rc6
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 26 Jan 2015 11:37:39 +0000
+-
+-linux (3.19.0-2.2) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.19-rc4
+-  * [Config] updateconfigs following rebase to v3.19-rc4
+-  * [Packaging] install all dtb files
+-    - LP: #1408002
+-  * [Config] switch on "all" dtbs
+-    - LP: #1408002
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: drivers/rtc/interface.c: ignore exprired times when enqueing new
+-    timers
+-    - LP: #1333569
+-
+-  [ Joseph Salisbury ]
+-
+-  * [Config] Enable CONFIG_N_GSM as module.
+-    - LP: #1404670
+-
+-  [ K. Y. Srinivasan ]
+-
+-  * SAUCE: storvsc: force SPC-3 compliance on win8 and win8 r2 hosts
+-    - LP: #1406867
+-
+-  [ Steve McIntyre ]
+-
+-  * SAUCE: efi: Expose underlying UEFI firmware platform size to userland
+-    - LP: #1409750
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.19-rc4
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 13 Jan 2015 12:35:58 +0000
+-
+-linux (3.19.0-1.1) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: AUFS -- aufs3-standalone.patch"
+-  * Revert "SAUCE: AUFS -- aufs3-mmap.patch"
+-  * Revert "SAUCE: AUFS -- aufs3-base.patch"
+-  * ubuntu: AUFS3 -- follow switch to vfs_fallocate
+-  * rebase to v3.19-rc1
+-  * rebase to v3.19-rc2
+-  * [Config] defaultconfigs following rebase to v3.19-rc2
+-  * ubuntu: aufs3 -- follow rename of d_child
+-  * ubuntu: aufs3 -- follow switch to d_splice_alias
+-  * ubuntu: aufs3 -- follow switch to get_unused_fd_flags()
+-  * ubuntu: aufs3 -- follow rename for d_alias
+-  * apparmor -- follow change to this_cpu_ptr
+-  * disable module checks for rebase
+-  * ubuntu: AUFS -- substrate: aufs3-base.patch
+-  * ubuntu: AUFS -- substrate: aufs3-mmap.patch
+-  * ubuntu: AUFS -- substrate: aufs3-standalone.patch
+-  * ubuntu: AUFS -- update to 92ad9cc8bd289bf8e59b6bd8d83137d8e1a58c1c
+-  * [Configs] updateconfigs following aufs update
+-  * v3.19 series start
+-  * rebase to v3.19-rc3
+-  * [Configs] updateconfigs following rebase to v3.19-rc3
+-  * [Packaging] uploadnum should be the remainder of the version
+-    - LP: #1407755
+-  * [Packaging] handle dts directories
+-    - LP: #1408004
+-  * [Config] follow move of arm64 dts' into vendor directories
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * arm64: optimized copy_to_user and copy_from_user assembly code
+-    - LP: #1400349
+-  * iommu/ipmmu-vmsa: follow flag switch to IOMMU_NOEXEC
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.19-rc1
+-    - LP: #1173681
+-  * rebase to v3.19-rc2
+-  * rebase to v3.19-rc3
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 06 Jan 2015 14:30:02 +0000
+-
+-linux (3.18.0-7.8) vivid; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Release Tracking Bug
+-    - LP: #1401590
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: (no-up) apparmor: Sync to apparmor3 - RC1 snapshot
+-    - LP: #1362199
+-  * SAUCE: Revert: fix: only allow a single threaded process to ...
+-    - LP: #1371310
+-  * SAUCE: (no-up) fix: bad unix_addr_fs macro
+-    - LP: #1390223
+-  * SAUCE: (no-up) apparmor: add parameter to control whether policy
+-    hashing is used
+-    - LP: #1383886
+-  * [config] set apparmor config options
+-
+-  [ Seth Forshee ]
+-
+-  * [Config] CONFIG_FW_LOADER_USER_HELPER_FALLBACK=n
+-    - LP: #1398458
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * mfd: rtsx: Fix PM suspend for 5227 & 5249
+-    - LP: #1359052
+-  * mmc: sdhci-pci-o2micro: Fix Dell E5440 issue
+-    - LP: #1346067
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 11 Dec 2014 08:36:36 -0800
+-
+-linux (3.18.0-6.7) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: (no-up) arm64: optimized copy_to_user and copy_from_user
+-    assembly code"
+-    - LP: #1398596
+-  * rebase to v3.18
+-
+-  [ Chris J Arges ]
+-
+-  * [Config] CONFIG_PCIEASPM_DEBUG=y
+-    - LP: #1398544
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] armhf: VIRTIO_[BALLOON|MMIO]=y
+-    - LP: #1396470
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drivers:scsi:storvsc: Fix a bug in handling ring buffer failures that
+-    may result in I/O freeze
+-    - LP: #1400289
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.18
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 08 Dec 2014 09:15:17 -0800
+-
+-linux (3.18.0-5.6) vivid; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Release Tracking Bug
+-    - LP: #1398109
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_SCSI_MQ_DEFAULT=n
+-    - LP: #1397061
+-  * rebase to v3.18-rc7
+-
+-  [ Chris J Arges ]
+-
+-  * [Config] CONFIG_SCOM_DEBUGFS=y for powerpc/powerpc64-smp
+-    ppc64el/generic
+-    - LP: #1395855
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.18-rc7
+-    - LP: #1389497
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 01 Dec 2014 10:09:09 -0800
+-
+-linux (3.18.0-4.5) vivid; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Release Tracking Bug
+-    - LP: #1395891
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.18-rc6
+-  * [Config] update configs following rebase to v3.18-rc6
+-  * [Config] enable overlayfs v1 support
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.18-rc5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * overlay: add backwards compatible overlayfs format support
+-    - LP: #1395877
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.18-rc5
+-  * rebase to v3.18-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 24 Nov 2014 13:12:48 -0800
+-
+-linux (3.18.0-3.4) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Config] CONFIG_AUFS_FS=n for FTBS"
+-  * Revert "SAUCE: AUFS -- update to
+-    dcf336a754c86d5ee1c3d50699fd75c586d037cb"
+-  * Revert "SAUCE: aufs3 -- (no-up) aufs3-standalone.patch"
+-  * Revert "SAUCE: aufs3 -- (no-up) aufs3-base.patch"
+-  * [Config] amd64 is now the indep architecture
+-  * [Debian] basic hook support
+-  * SAUCE: AUFS -- aufs3-base.patch
+-  * SAUCE: AUFS -- aufs3-mmap.patch
+-  * SAUCE: AUFS -- aufs3-standalone.patch
+-  * ubuntu: AUFS -- update to 9d5c349d5c452170b8e813d86956f896a0aef170
+-  * [Config] updateconfigs following aufs3 update
+-  * SAUCE: AUFS (no-squash): basic framework and update machinary -- part 2
+-
+-  [ dann frazier ]
+-
+-  * [Config] Disable CONFIG_IPMI_SI_PROBE_DEFAULTS on armhf and arm64
+-    - LP: #1388952
+-  * [Config] disable CONFIG_ARM64_RANDOMIZE_TEXT_OFFSET
+-  * [Config] Disable CONFIG_RCU_USER_QS on arm64
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.18-rc4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.18-rc4
+-    - LP: #1389497
+-    - LP: #1387128
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 11 Nov 2014 17:16:13 +0000
+-
+-linux (3.18.0-2.2) vivid; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: nft_reject_bridge.c: Include net/ip6_checksum.h
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.18-rc3
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 03 Nov 2014 06:09:06 -0700
+-
+-linux (3.18.0-1.1) vivid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Config] Switch kernel to vmlinuz (from vmlinux) on ppc64el"
+-  * [Config] tools -- only build common tools when enabled
+-  * [Config] follow rename of DEB_BUILD_PROFILES
+-  * [Config] linux-image-extra is additive to linux-image
+-    - LP: #1375310
+-  * [Config] linux-image-extra postrm is not needed on purge
+-  * [Config] enable cloud tools on i386
+-    - LP: #1367399
+-
+-  [ Marc Dietrich ]
+-
+-  * [Config] arm/tegra/d-i: framebuffer and usb support for Tegra SoCs
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] armhf: REGULATOR_TWL4030=y
+-  * [Config] armhf: disable JUMP_LABEL
+-    - LP: #1378856
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.17-rc2
+-  * updateconfigs
+-  * [Config] CONFIG_NFC_ST21NFCB=n
+-  * [Config] Added net/6lowpan/* to generic inclusion list
+-  * [Config] Add arm64 to enforcer CONFIG_CC_STACKPROTECTOR
+-  * rebase to v3.17-rc3
+-  * rebase to v3.17-rc4
+-  * rebase to v3.17-rc5
+-  * [Config] armhf: USB_[E|O]HCI_EXYNOS=y
+-  * [Config] CONFIG_XMON=y
+-    - LP: #1365655
+-  * [Config] CONFIG_KVM_BOOK3S_64=m for ppc64el
+-    - LP: #1362514
+-  * [Config] CONFIG_KVM_BOOK3S_64_HV=m
+-    - LP: #1362514
+-  * [Config] CONFIG_DMA_CMA=n
+-    - LP: #1362261
+-  * [Config] Add mpt3sas to d-i
+-    - LP: #1368907
+-  * [Debian] set do_*_tools after stage1 or bootstrap is determined
+-    - LP: #1370211
+-  * [Config] CONFIG_USB_OHCI_HCD_PCI=y
+-    - LP: #1244176
+-  * rebase to v3.17-rc6
+-  * SAUCE: usbip: Update include path
+-  * [Debian] usbip tools packaging
+-    - LP: #898003
+-  * [Config] Enable usbip tools
+-    - LP: #898003
+-  * [Config] CONFIG_CRASH_DUMP=n for powerpc-smp
+-    - LP: #1363180
+-  * [Config] Correct annotation regarding CONFIG_DMA_CMA
+-    - LP: #1362261
+-  * [Config] CONFIG_SND_HDA_INTEL=n for ppc64el
+-    - LP: #1374438
+-  * [Config] CONFIG_HOTPLUG_PCI_SHPC=n for ppc64el
+-    - LP: #1374440
+-  * [Debian] Don't fail if a symlink already exists
+-  * rebase to v3.17-rc7
+-  * [Config] CONFIG_HOTPLUG_PCI_PCIE=n for ppc64el
+-    - LP: #1374440
+-  * rebase to v3.17
+-  * rebase to v3.18-rc1
+-  * [Config] CONFIG_AUFS_FS=n for FTBS
+-  * Enable vivid
+-  * [Config] CONFIG_SOUND_OSS_CORE_PRECLAIM=n
+-    - LP: #1385510
+-  * rebase to v3.18-rc2
+-  * [Debian] Fix linux-doc dangling symlinks
+-    - LP: #661306
+-  * CONFIG_MODULE_COMPRESS=n
+-  * [Config] dropped scsi_tgt from generic inclusion list
+-  * [Config] Added drivers/uio to generic inclusion list
+-  * [Config] CONFIG_PATA_MACIO=y
+-    - LP: #1378894
+-  * [Config] CONFIG_DRM_BOCHS=n
+-  * [Debian] install usbipd
+-    - LP: #898003
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.18-rc2
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.18-rc1
+-    - LP: #1316518
+-    - LP: #1371591
+-    - LP: #1357928
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.17
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.17-rc7
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.17-rc6
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.17-rc5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.17-rc4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.17-rc3
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.17-rc2
+-    - LP: #1358116
+-    - LP: #1350148
+-    - LP: #1334950
+-    - LP: #1329580
+-    - LP: #1329580
+-    - LP: #1329580
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.17-rc2
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 26 Aug 2014 10:36:19 -0600
+-
+-linux (3.17.0-0.0) utopic; urgency=medium
+-
+-  * Empty entry
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 26 Aug 2014 10:34:44 -0600
+-
+-linux (3.16.0-11.16) utopic; urgency=low
+-
+-  [ Mauricio Faria de Oliveira ]
+-
+-  * [Config] Switch kernel to vmlinuz (from vmlinux) on ppc64el
+-    - LP: #1358920
+-
+-  [ Peter Zijlstra ]
+-
+-  * SAUCE: (no-up) mmu_notifier: add call_srcu and sync function for listener to delay call and sync
+-    - LP: #1361300
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_ZPOOL=y
+-    - LP: #1360428
+-  * Release Tracking Bug
+-    - LP: #1361308
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "net/mlx4_en: Fix bad use of dev_id"
+-    - LP: #1347012
+-  * net/mlx4_en: Reduce memory consumption on kdump kernel
+-    - LP: #1347012
+-  * net/mlx4_en: Fix mac_hash database inconsistency
+-    - LP: #1347012
+-  * net/mlx4_en: Disable blueflame using ethtool private flags
+-    - LP: #1347012
+-  * net/mlx4_en: current_mac isn't updated in port up
+-    - LP: #1347012
+-  * net/mlx4_core: Use low memory profile on kdump kernel
+-    - LP: #1347012
+-  * Drivers: scsi: storvsc: Change the limits to reflect the values on the host
+-    - LP: #1347169
+-  * Drivers: scsi: storvsc: Set cmd_per_lun to reflect value supported by the Host
+-    - LP: #1347169
+-  * Drivers: scsi: storvsc: Filter commands based on the storage protocol version
+-    - LP: #1347169
+-  * Drivers: scsi: storvsc: Fix a bug in handling VMBUS protocol version
+-    - LP: #1347169
+-  * Drivers: scsi: storvsc: Implement a eh_timed_out handler
+-    - LP: #1347169
+-  * drivers: scsi: storvsc: Set srb_flags in all cases
+-    - LP: #1347169
+-  * drivers: scsi: storvsc: Correctly handle TEST_UNIT_READY failure
+-    - LP: #1347169
+-  * namespaces: Use task_lock and not rcu to protect nsproxy
+-    - LP: #1328088
+-  * net: xgene: Check negative return value of xgene_enet_get_ring_size()
+-  * mm/zbud: change zbud_alloc size type to size_t
+-    - LP: #1360428
+-  * mm/zpool: implement common zpool api to zbud/zsmalloc
+-    - LP: #1360428
+-  * mm/zpool: zbud/zsmalloc implement zpool
+-    - LP: #1360428
+-  * mm/zpool: update zswap to use zpool
+-    - LP: #1360428
+-  * ideapad-laptop: Change Lenovo Yoga 2 series rfkill handling
+-    - LP: #1341296
+-  * iommu/amd: Fix for pasid initialization
+-    - LP: #1361300
+-  * iommu/amd: Moving PPR fault flags macros definitions
+-    - LP: #1361300
+-  * iommu/amd: Drop oprofile dependency
+-    - LP: #1361300
+-  * iommu/amd: Fix typo in amd_iommu_v2 driver
+-    - LP: #1361300
+-  * iommu/amd: Don't call mmu_notifer_unregister in __unbind_pasid
+-    - LP: #1361300
+-  * iommu/amd: Don't free pasid_state in mn_release path
+-    - LP: #1361300
+-  * iommu/amd: Get rid of __unbind_pasid
+-    - LP: #1361300
+-  * iommu/amd: Drop pasid_state reference in ppr_notifer error path
+-    - LP: #1361300
+-  * iommu/amd: Add pasid_state->invalid flag
+-    - LP: #1361300
+-  * iommu/amd: Don't hold a reference to mm_struct
+-    - LP: #1361300
+-  * iommu/amd: Don't hold a reference to task_struct
+-    - LP: #1361300
+-  * iommu/amd: Don't call the inv_ctx_cb when pasid is not set up
+-    - LP: #1361300
+-  * iommu/amd: Don't set pasid_state->mm to NULL in unbind_pasid
+-    - LP: #1361300
+-  * iommu/amd: Remove change_pte mmu_notifier call-back
+-    - LP: #1361300
+-  * iommu/amd: Fix device_state reference counting
+-    - LP: #1361300
+-  * iommu/amd: Fix 2 typos in comments
+-    - LP: #1361300
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 22 Aug 2014 08:45:54 -0400
+-
+-linux (3.16.0-10.15) utopic; urgency=low
+-
+-  [ dann frazier ]
+-
+-  * [debian] Fix regression with ABI subversions and backport
+-
+-  [ Feng Kan ]
+-
+-  * SAUCE: (no-up) irqchip:gic: change access of gicc_ctrl register to read
+-    modify write.
+-    - LP: #1357527
+-  * SAUCE: (no-up) arm64: optimized copy_to_user and copy_from_user
+-    assembly code
+-    - LP: #1358949
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: bcache: prevent crash on changing writeback_running
+-    - LP: #1357295
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_XFRM_STATISTICS=y
+-  * [Config] CONFIG_SECURITY_NETWORK_XFRM=y
+-  * [Config] CONFIG_SENSORS_IBMPOWERNV=m
+-    - LP: #1353005
+-  * Release Tracking Bug
+-    - LP: #1359783
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * intel_idle: Broadwell support
+-    - LP: #1256170
+-  * powerpc/book3s: Add basic infrastructure to handle HMI in Linux.
+-    - LP: #1357108
+-  * powerpc/powernv: Invoke opal call to handle hmi.
+-    - LP: #1357108
+-  * powerpc/book3s: handle HMIs for cpus in nap mode.
+-    - LP: #1357108
+-  * powerpc/book3s: Fix endianess issue for HMI handling on napping cpus.
+-    - LP: #1357108
+-  * powerpc: Add smp_mb() to arch_spin_is_locked()
+-    - LP: #1358569
+-  * powerpc: Add smp_mb()s to arch_spin_unlock_wait()
+-    - LP: #1358569
+-  * hwmon: (powerpc/powernv) hwmon driver for power, fan rpm, voltage and
+-    temperature
+-    - LP: #1353005
+-  * tools/testing/selftests/ptrace/peeksiginfo.c: add PAGE_SIZE definition
+-    - LP: #1358855
+-  * printk: Add function to return log buffer address and size
+-    - LP: #1359423
+-  * powerpc/powernv: Interface to register/unregister opal dump region
+-    - LP: #1359423
+-  * bcache: fix crash on shutdown in passthrough mode
+-    - LP: #1357295
+-  * bcache: fix uninterruptible sleep in writeback thread
+-    - LP: #1357295
+-
+-  [ Vinayak Kale ]
+-
+-  * SAUCE: (no-up) dt-bindings: Add Potenza PMU binding
+-    - LP: #1357527
+-  * SAUCE: (no-up) arm64: dts: Add PMU node for APM X-Gene Storm SOC
+-    - LP: #1357527
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 15 Aug 2014 12:34:33 -0600
+-
+-linux (3.16.0-9.14) utopic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1357370
+-
+-  [ Serge Hallyn ]
+-
+-  * SAUCE: Overlayfs: allow unprivileged mounts
+-    - LP: #1357025
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * MAINTAINERS: Add entry for APM X-Gene SoC ethernet driver
+-  * Documentation: dts: Add bindings for APM X-Gene SoC ethernet driver
+-  * dts: Add bindings for APM X-Gene SoC ethernet driver
+-  * drivers: net: Add APM X-Gene SoC ethernet driver support.
+-  * powerpc/thp: Add write barrier after updating the valid bit
+-    - LP: #1357014
+-  * powerpc/thp: Don't recompute vsid and ssize in loop on invalidate
+-    - LP: #1357014
+-  * powerpc/thp: Invalidate old 64K based hash page mapping before insert
+-    of 4k pte
+-    - LP: #1357014
+-  * powerpc/thp: Handle combo pages in invalidate
+-    - LP: #1357014
+-  * powerpc/thp: Invalidate with vpn in loop
+-    - LP: #1357014
+-  * powerpc/thp: Use ACCESS_ONCE when loading pmdp
+-    - LP: #1357014
+-  * powerpc/mm: Use read barrier when creating real_pte
+-    - LP: #1357014
+-  * powerpc/thp: Add tracepoints to track hugepage invalidate
+-    - LP: #1357014
+-  * rebase to v3.16.1
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 14 Aug 2014 08:18:02 -0400
+-
+-linux (3.16.0-8.13) utopic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1356403
+-
+-  [ dann frazier ]
+-
+-  * [debian] Allow for package revisions condusive for branching
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ahci_xgene: Fix the watermark threshold for the APM X-Gene SATA host controller driver.
+-    - LP: #1350087
+-  * ahci_xgene: Use correct OOB tunning parameters for APM X-Gene SoC AHCI SATA Host controller driver.
+-    - LP: #1350087
+-  * powerpc/powernv: Enable M64 aperatus for PHB3
+-    - LP: #1355469
+-  * powerpc: Fail remap_4k_pfn() if PFN doesn't fit inside PTE
+-    - LP: #1352994
+-  * powerpc: Add machine_early_initcall()
+-    - LP: #1352640
+-  * powerpc/powernv: Switch powernv drivers to use machine_xxx_initcall()
+-    - LP: #1352640
+-  * powerpc/eeh: Avoid event on passed PE
+-    - LP: #1352640
+-  * powerpc/eeh: EEH support for VFIO PCI device
+-    - LP: #1352640
+-  * powerpc/eeh: sysfs entries lost
+-    - LP: #1352640
+-  * powerpc/powernv: Fix IOMMU table for VFIO dev
+-    - LP: #1352640
+-  * powerpc/eeh: Fetch IOMMU table in reliable way
+-    - LP: #1352640
+-  * powerpc/eeh: Refactor EEH flag accessors
+-    - LP: #1352640
+-  * powerpc/eeh: Selectively enable IO for error log
+-    - LP: #1352640
+-  * powerpc/eeh: Reduce lines of log dump
+-    - LP: #1352640
+-  * powerpc/eeh: Replace pr_warning() with pr_warn()
+-    - LP: #1352640
+-  * powerpc/eeh: Make diag-data not endian dependent
+-    - LP: #1352640
+-  * powerpc/eeh: Aux PE data for error log
+-    - LP: #1352640
+-  * PCI: Support BAR sizes up to 128GB
+-    - LP: #1352640
+-  * powerpc/powernv: Allow to freeze PE
+-    - LP: #1352640
+-  * powerpc/powernv: Split ioda_eeh_get_state()
+-    - LP: #1352640
+-  * powerpc/powernv: Handle compound PE
+-    - LP: #1352640
+-  * powerpc/powernv: Handle compound PE for EEH
+-    - LP: #1352640
+-  * powerpc/powernv: Handle compound PE in config accessors
+-    - LP: #1352640
+-  * mnt: Only change user settable mount flags in remount
+-    - LP: #1356318
+-    - CVE-2014-5206
+-  * mnt: Move the test for MNT_LOCK_READONLY from change_mount_flags into do_remount
+-    - LP: #1356318
+-    - CVE-2014-5206
+-  * mnt: Correct permission checks in do_remount
+-    - LP: #1356323
+-    - CVE-2014-5207
+-  * mnt: Change the default remount atime from relatime to the existing value
+-    - LP: #1356323
+-    - CVE-2014-5207
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Sun, 10 Aug 2014 09:10:51 -0600
+-
+-linux (3.16.0-7.12) utopic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.16 final
+-  * [Config] d-i -- add virtio_scsi to virtio-modules
+-    - LP: #1342000
+-
+-  [ dann frazier ]
+-
+-  * [Packaging] Fix 'printchanges' to work with versions containing '+'
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_MICROCODE=y
+-    - LP: #1084373
+-  * [Config] CONFIG_CONTEXT_TRACKING_FORCE=n
+-    - LP: #1349028
+-  * [Config] Add hv_balloon to d-i virtio-modules
+-    - LP: #1292216
+-  * Release Tracking Bug
+-    - LP: #1354530
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.16
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 29 Jul 2014 09:55:15 -0400
+-
+-linux (3.16.0-6.11) utopic; urgency=low
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] armhf: MXS_DMA=y && MTD_NAND_GPMI_NAND=m
+-  * [Config] armhf: KEYBOARD_IMX=m
+-  * [Config] armhf: build cubox & imx6 DTBs
+-  * [Config] armhf: RTC_DRV_PCF8523=y
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_KEYS_DEBUG_PROC_KEYS=y
+-    - LP: #1344405
+-  * [Config] CONFIG_SCSI_IPR_TRACE=y, CONFIG_SCSI_IPR_DUMP=y
+-    - LP: #1343109
+-  * Release Tracking Bug
+-    - LP: #1349196
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.16-rc7
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 24 Jul 2014 09:08:55 -0400
+-
+-linux (3.16.0-5.10) utopic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1346298
+-  * [Config] CONFIG_GPIO_SYSFS=y
+-    - LP: #1342153
+-  * rebase to v3.16-rc6
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] enable ARCH_MVEBU*
+-  * [Config] AHCI_MVEBU=m
+-  * [Config] ARMADA_THERMAL=y
+-  * [Config] ARM_ARMADA_370_XP_CPUIDLE=y
+-  * [Config] CRYPTO_DEV_MV_CESA=m
+-  * [Config] I2C_MV64XXX=m
+-  * [Config] MMC_MVSDIO=m
+-  * [Config] MMC_SDHCI_DOVE=m
+-  * [Config] MTD_NAND_ORION=m
+-  * [Config] MTD_NAND_PXA3xx=m
+-  * [Config] MVNETA=m
+-  * [Config] MV_XOR=y
+-  * [Config] ORION_WATCHDOG=m
+-  * [Config] PCI_MVEBU=y
+-  * [Config] RTC_DRV_MV=y
+-  * [Config] SND_KIRKWOOD_SOC*=m
+-  * [Config] SPI_ORION=m
+-  * [Config] USB_XHCI_MVEBU=m
+-  * [Config] armhf: build all Armada and Dove DTBs
+-  * [Config] armhf: SERIAL_8250_DW=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.16-rc6
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Jul 2014 07:49:42 -0400
+-
+-linux (3.16.0-4.9) utopic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1341543
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.16-rc5
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Sun, 13 Jul 2014 21:30:27 -0400
+-
+-linux (3.16.0-3.8) utopic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1340091
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 10 Jul 2014 10:06:47 +0100
+-
+-linux (3.16.0-2.7) utopic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: aufs3 -- avoid aufs3-mmap.patch include hell for arm64
+-    ubuntu: aufs3 -- (no-up) aufs3-mmap.patch
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 09 Jul 2014 16:16:28 +0100
+-
+-linux (3.16.0-2.6) utopic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: aufs3 -- (no-up) aufs3-mmap.patch"
+-    Fixes FTBS.
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 08 Jul 2014 17:29:26 +0100
+-
+-linux (3.16.0-2.5) utopic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu -- fix basic format for ubuntu/Makefile
+-  * ubuntu: AUFS (no-squash): basic framework and update machinary
+-  * ubuntu: aufs3 -- update update scripting
+-  * ubuntu: aufs3 -- (no-up) aufs3-base.patch
+-  * ubuntu: aufs3 -- (no-up) aufs3-mmap.patch
+-  * ubuntu: aufs3 -- (no-up) aufs3-standalone.patch
+-  * ubuntu: AUFS -- update to dcf336a754c86d5ee1c3d50699fd75c586d037cb
+-  * [Configs] AUFS configs
+-  * ubuntu: aufs3 -- reenable
+-
+-  [ Tim Gardner ]
+-
+-  * CONFIG_LATENCYTOP=n
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 08 Jul 2014 15:27:35 +0100
+-
+-linux (3.16.0-2.4) utopic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] flip VIRTIO*=y
+-  * [Config] commonise CONFIG_SWIOTLB=y
+-  * [Config] apply Bus options (PCI etc.) >> PCI support config defaults
+-  * [Config] apply Device Drivers >> ATA/ATAPI/MFM/RLL support (DEPRECATED)
+-    config defaults
+-  * [Config] apply Device Drivers >> Block devices config defaults
+-  * [Config] apply Device Drivers >> Character devices config defaults
+-  * [Config] apply Device Drivers >> DMA Engine support config defaults
+-  * [Config] apply Device Drivers >> EDAC (Error Detection And Correction)
+-    reporting config defaults
+-  * [Config] apply Device Drivers >> Graphics support >> Direct Rendering
+-    Manager >> Direct Rendering Manager (XFree86 4.1.0 and higher DRI
+-    support) config defaults
+-  * [Config] apply Device Drivers >> GPIO Support config defaults
+-  * [Config] apply Device Drivers >> Graphics support >> Console display
+-    driver support config defaults
+-  * [Config] apply Device Drivers >> IIO staging drivers >> Accelerometers
+-    config defaults
+-  * [Config] apply Device Drivers >> IOMMU Hardware Support config defaults
+-  * [Config] apply Device Drivers >> Input device support >> Generic input
+-    layer (needed for keyboard, mouse, ...) >> Miscellaneous devices config
+-    defaults
+-  * [Config] apply Device Drivers >> Input device support >> Hardware I/O
+-    ports config defaults
+-  * [Config] apply Device Drivers >> LED Support >> LED Class Support
+-    config defaults
+-  * [Config] apply Device Drivers >> Hardware Spinlock drivers config
+-    defaults
+-  * [Config] apply Device Drivers >> Multimedia support >> Cameras/video
+-    grabbers support config defaults
+-  * [Config] apply Security options config defaults
+-  * [Config] apply Networking options >> Network packet filtering framework
+-    (Netfilter) >> Core Netfilter Configuration config defaults
+-  * [Config] apply Device Drivers >> MMC/SD/SDIO card support config
+-    defaults
+-  * [Config] apply Device Drivers >> Graphics support >> Frame buffer
+-    Devices >> Support for frame buffer devices config defaults
+-  * [Config] apply Power management and ACPI options >> CPU Frequency
+-    scaling config defaults
+-  * [Config] apply Processor type and features config defaults
+-  * [Config] apply Partition Types config defaults
+-  * [Config] apply Power management and ACPI options config defaults
+-  * [Config] apply Device Drivers >> InfiniBand support config defaults
+-  * [Config] apply Device Drivers >> Misc devices config defaults
+-  * [Config] apply Device Drivers >> Multifunction device drivers config
+-    defaults
+-  * [Config] apply Device Drivers >> SCSI device support >> SCSI device
+-    support >> SCSI low-level drivers config defaults
+-  * [Config] apply Device Drivers >> Network device support >> Ethernet
+-    driver support config defaults
+-  * [Config] apply Device Drivers >> Network device support >> Network core
+-    driver support config defaults
+-  * [Config] apply Device Drivers >> Network device support >> PHY Device
+-    support and infrastructure config defaults
+-  * [Config] apply File systems >> Network File Systems config defaults
+-  * [Config] apply Device Drivers >> Input device support >> Generic input
+-    layer (needed for keyboard, mouse, ...) >> Touchscreens config defaults
+-  * [Config] apply Device Drivers >> Memory Technology Device (MTD) support
+-    >> NAND Device Support config defaults
+-  * [Config] apply Device Drivers >> Network device support >> Wireless LAN
+-    >> Ralink driver support config defaults
+-  * [Config] apply Device Drivers >> Staging drivers config defaults
+-  * [Config] apply Cryptographic API >> Hardware crypto devices config
+-    defaults
+-  * [Config] apply Device Drivers >> Macintosh device drivers config
+-    defaults
+-  * [Config] apply Device Drivers >> Network device support >> Wireless LAN
+-    config defaults
+-  * [Config] apply Device Drivers >> PPS support config defaults
+-  * [Config] apply Device Drivers >> Sound card support config defaults
+-  * [Config] apply Networking support >> RF switch subsystem support config
+-    defaults
+-  * [Config] apply Library routines config defaults
+-  * [Config] apply Device Drivers >> CODEC drivers config defaults
+-  * [Config] apply Device Drivers >> PHY Subsystem config defaults
+-  * [Config] apply Device Drivers >> Pulse-Width Modulation (PWM) Support
+-    config defaults
+-  * [Config] apply Kernel hacking >> Tracers config defaults
+-  * [Config] apply Kernel hacking >> Runtime Testing config defaults
+-  * [Config] apply Kernel hacking >> Architecture: powerpc config defaults
+-  * [Config] apply Device Drivers >> USB support config defaults
+-  * [Config] apply Device Drivers >> Power supply class support config
+-    defaults
+-  * [Config] apply Device Drivers >> USB Network Adapters config defaults
+-  * [Config] apply General setup >> IRQ subsystem config defaults
+-  * [Config] apply General setup config defaults
+-  * [Config] apply File systems >> Miscellaneous filesystems config
+-    defaults
+-  * [Config] apply File systems config defaults
+-  * [Config] apply Device Drivers >> Userspace I/O drivers config defaults
+-  * [Config] apply Device Drivers >> Virtio drivers config defaults
+-  * [Config] apply Device Drivers >> USB Peripheral Controller config
+-    defaults
+-  * [Config] apply Device Drivers >> SCSI device support >> SCSI device
+-    support >> SCSI Transports config defaults
+-  * [Config] apply Device Drivers >> Real Time Clock config defaults
+-  * [Config] apply Device Drivers >> Serial ATA and Parallel ATA drivers
+-    (libata) config defaults
+-  * [Config] apply Device Drivers >> SoC Audio for Freescale CPUs config
+-    defaults
+-  * [Config] apply Device Drivers >> Voltage and Current Regulator Support
+-    config defaults
+-  * [Config] apply Device Drivers >> USB Physical Layer drivers config
+-    defaults
+-  * [Config] apply Device Drivers >> Watchdog Timer Support config defaults
+-  * [Config] powerpc-powerpc-e500mc FTBFS -- CONFIG_CRASH_DUMP=n
+-  * [Config] powerpc-powerpc64-emb FTBFS -- CONFIG_IMA=n
+-  * [Config] powerpc-powerpc64-emb FTBFS -- CONFIG_HIBERNATION=n
+-    CONFIG_HOTPLUG_CPU=n
+-  * [Config] ppc64el-generic FTBFS -- CONFIG_LUSTRE_FS=n
+-  * [Config] drivers/message/fusion needs scsi_transport_spi in virtual
+-  * [Config] drivers/acpi/acpi_ipmi.ko needs
+-    drivers/char/ipmi/ipmi_msghandler.ko in virtual
+-  * [Config] armhf-* FTBFS -- CONFIG_STACK_TRACER=n
+-    CONFIG_FUNCTION_TRACER=n
+-  * [Config] ignore modules changing following major config changes
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.16-rc4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.16-rc4
+-    - LP: #1297581
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 03 Jul 2014 11:00:43 +0100
+-
+-linux (3.16.0-1.3) utopic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "Disable do_tools_perf for FTBS"
+-  * SAUCE: fix perf_regs definitions for arm64
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] armhf: ARCH_EXYNOS5* support
+-  * [Config] armhf: CPU_IDLE=y and ARM_EXYNOS_CPUIDLE=y
+-  * [Config] armhf: EXYNOS_THERMAL=y
+-  * [Config] armhf: EXYNOS_IOMMU=y
+-  * [Config] armhf: EXYNOS_ADC=m
+-  * [Config] armhf: EXYNOS_I2C_EXYNOS5=m
+-  * [Config] armhf: MMC_SDHCI_S3C=m
+-  * [Config] armhf: PCI_EXYNOS=y
+-  * [Config] armhf: PHY_EXYNOS5250_SATA=y
+-  * [Config] armhf: USB_[E|O]HCI_EXYNOS=y && SAMSUNG_USBPHY=y
+-  * [Config] armhf: PWM_SAMSUNG=m
+-  * [Config] armhf: RTC_DRV_S3C=y
+-  * [Config] armhf: S3C2410_WATCHDOG=m
+-  * [Config] armhf: MMC_DW_EXYNOS=m
+-  * [Config] armhf: SERIAL_SAMSUNG=y
+-  * [Config] armhf: SND_SOC_SAMSUNG=m
+-  * [Config] armhf: SPI_S3C64XX=m
+-  * [Config] armhf: EXYNOS_VIDEO=y and VIDEO_SAMSUNG*=m
+-  * [Config] armhf: FB_S3C=m
+-  * [Config] armhf: build all Exynos 5 DTBs
+-  * [Config] armhf: disable CPUFREQ_EXYNOS
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.16-rc3
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.16-rc3
+-    - LP: #1331915
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 24 Jun 2014 08:58:09 -0600
+-
+-linux (3.16.0-0.2) utopic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "SAUCE: intel_pstate -- toggle default to disable"
+-    - LP: #1333322
+-  * CONFIG_BOOKE_WDT=y
+-  * Disable do_tools_perf for FTBS (just until I can figure it out)
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 23 Jun 2014 13:37:53 -0600
+-
+-linux (3.16.0-0.1) utopic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1333265
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] cloud-tools -- add systemd units
+-    - LP: #1329027
+-
+-  [ dann frazier ]
+-
+-  * [Config] CONFIG_RTC_DRV_XGENE=y for arm64
+-  * [Config] CONFIG_NET_XGENE=m for arm64
+-  * [Config] Restrict CONFIG_POWER_RESET_SYSCON to arm64 only
+-
+-  [ Feng Kan ]
+-
+-  * SAUCE: (no-up) arm64: dts: Add X-Gene reboot driver dts node
+-  * SAUCE: (no-up) Add documentation for generic SYSCON reboot driver.
+-  * SAUCE: (no-up) Select reboot driver for X-Gene platform.
+-
+-  [ Iyappan Subramanian ]
+-
+-  * SAUCE: (no-up) MAINTAINERS: Add entry for APM X-Gene SoC ethernet driver
+-  * SAUCE: (no-up) Documentation: dts: Add bindings for APM X-Gene SoC ethernet driver
+-  * SAUCE: (no-up) dts: Add bindings for APM X-Gene SoC ethernet driver
+-  * SAUCE: (no-up) drivers: net: Add APM X-Gene SoC ethernet driver support.
+-
+-  [ Tim Gardner ]
+-
+-  * updateconfigs
+-  * Fix arm64 crypto Makefile
+-  * [Config] CONFIG_BOOKE_WDT=n for FTBS
+-  * [Debian] Add UTS_UBUNTU_RELEASE_ABI to utsrelease.h
+-    - LP: #1327619
+-  * Disabled powerpc64-emb for FTBS
+-  * [Config] CONFIG_DRM_TEGRA=m
+-  * [Config] CONFIG_CMA_SIZE_MBYTES=64
+-  * rebase to v3.16-rc2
+-  * Clean up generic.inclusion-list warnings
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.16-rc2
+-    - LP: #1328587
+-    - LP: #1319291
+-    - LP: #1310512
+-    - LP: #1310512
+-    - LP: #1305480
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 12 Jun 2014 12:26:09 +0000
+-
+-linux (3.15.0-6.11) utopic; urgency=low
+-
+-  [ Adam Conrad ]
+-
+-  * Enable building the sata-modules udeb on ppc64el.
+-    - LP: #1323980
+-  * [Packaging] Set bootloader and loader on ppc64el to grub
+-
+-  [ Adam Lee ]
+-
+-  * SAUCE: (no-up) rtlwifi: rtl8723be: disable MSI interrupts mode
+-    - LP: #1310512, #1320070
+-
+-  [ Alex Hung ]
+-
+-  * SAUCE: (no-up) dell-led: add mic mute led interface
+-    - LP: #1308297
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] d-i -- add hyperv_keyboard to serial-modules udeb
+-    - LP: #1285434
+-  * [Config] tools -- enable cpupower on ppc64el
+-  * [Config] ppc64el -- enable perf tools
+-  * [Config] powerpc -- enable perf tools
+-  * [Config] ppc64el -- reduce MAX_ORDER with 64k pages
+-  * [Config] arm64 -- enable tools
+-    - LP: #1326050
+-  * [Config] switch hyper-keyboard to virtual
+-    - LP: #1325306
+-  * [Config] fix up Breaks/Replaces on linux-cloud-tools-common to fix
+-    upgrades
+-  * SAUCE: kvm: BIOS disabled kvm support should be a warning
+-    - LP: #1300247
+-  * SAUCE: nouveau: missing outputs should be warnings
+-    - LP: #1300244
+-  * [Config] d-i -- add nvme devices to block-modules udeb
+-    - LP: #1303710
+-
+-  [ Anton Blanchard ]
+-
+-  * SAUCE: (no-up) powerpc: 64bit sendfile is capped at 2GB
+-    - LP: #1328230
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: intel_pstate: inform user that thermald is worth considering
+-
+-  [ Dave Chiluk ]
+-
+-  * [Config] Enable CONFIG_IP_VS_IPV6=y
+-    - LP: #1300739
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] build vexpress a9 dtb
+-    - LP: #1303657
+-
+-  [ Tetsuo Handa ]
+-
+-  * SAUCE: kthread: Do not leave kthread_create() immediately upon SIGKILL.
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1329045
+-  * [Debian] Treat vdso install as an environment variable
+-    - LP: #1325713
+-  * [Config] Treat vdso install as an environment variable
+-    - LP: #1325713
+-  * [config] Set IPMI suppoort default to "y"
+-  * [Config] powerpc -- CONFIG_SCSI_IBMVSCSI=y
+-  * [Config] CONFIG_RT_GROUP_SCHED=n
+-    - LP: #1284731
+-  * [Config] ppc64el -- switch to 64K system pages
+-  * [Config] CONFIG_MICROCODE_EARLY=y
+-  * [Config] SND_DAVINCI_SOC && SND_AM33XX_SOC_EVM =m
+-  * [Config] armhf: DRM_TILCDC=m
+-  * SAUCE: (no-up) mei_me: Add module parameter to disable MSI
+-  * [Config] arm64: KVM=y
+-  * [Config] armhf: LEDS_TRIGGER_HEARTBEAT=y
+-  * [Config] armhf: generic: disable CPU_IDLE
+-  * [Config] armhf: CPU_FREQ=y
+-  * [Config] Add new mlx modules to d-i
+-  * [Config] Added Muti-Arch support for linux-headers-PKGVER-ABINUM, linux-tools-common, and linux-cloud-tools-common
+-    - LP: #1295112
+-  * [Config] CONFIG_EXYNOS_ADC=n, CONFIG_HW_RANDOM_EXYNOS=n, CONFIG_MMC_DW_EXYNOS=n, CONFIG_USB_DWC3_EXYNOS=n
+-    - LP: #1294353
+-  * [Config] CONFIG_ABX500_CORE=y for ppc64el
+-  * [Config] CONFIG_ALX=m for powerpc
+-  * [Config] CONFIG_ACENIC_OMIT_TIGON_I=n for ppc64el
+-  * [Config] CONFIG_ACORN_PARTITION_*=n for ppc64el
+-  * [Config] CONFIG_ANDROID=n for powerpc
+-  * [Config] CONFIG_ASYNC_RAID6_TEST=m for ppc64el
+-  * [Config] CONFIG_BIG_KEYS=y for ppc64el
+-  * [Config] CONFIG_BSD_PROCESS_ACCT=y for ppc64el
+-  * rebase to v3.15
+-  * [Config] CONFIG_PHY_XGENE=y
+-  * [Config] CONFIG_MLX4_DEBUG=y
+-    - LP: #1328256
+-  * [Config] CONFIG_POWERNV_CPUFREQ=y for powerpc, ppc64el
+-    - LP: #1324571
+-  * [Config] CONFIG_BLK_DEV_SR_VENDOR=n for ppc64el
+-  * [Config] CONFIG_CFG80211=m for ppc64el
+-  * [Config] CONFIG_CHARGER_BQ24190=m for powerpc
+-  * [Config] CONFIG_CHARGER_BQ24735=m for powerpc
+-  * [Config] CONFIG_EXPERT=y for ppc64el
+-  * [Config] CONFIG_ATA_SFF=y on ppc64el
+-  * [Config] CONFIG_ATA_GENERIC=y for ppc64el, powerpc
+-  * [Config] CONFIG_CHR_DEV_ST=m for ppc64el
+-  * [Config] CONFIG_CHECKPOINT_RESTORE=y for ppc64el
+-  * [Config] CONFIG_CHELSIO_T1_1G=y for ppc64el
+-  * [Config] CONFIG_CHR_DEV_OSST=m for ppc64el
+-  * [Config] CONFIG_CHR_DEV_SCH=m for ppc64el
+-  * [Config] CONFIG_CPU_FREQ_STAT=y for powerpc
+-  * [Config] CONFIG_DDR=y for ppc64el
+-  * [Config] CONFIG_DEBUG_BUGVERBOSE=y for powerpc
+-  * [Config] CONFIG_E100=m, CONFIG_E1000=m, CONFIG_E1000E=m for ppc64el
+-  * [Config] CONFIG_EZX_PCAP=n for all arches
+-  * [Config] CONFIG_DYNAMIC_DEBUG=y for powerpc
+-  * [Config] CONFIG_ENABLE_MUST_CHECK=n for ppc64el
+-  * [Config] CONFIG_ENABLE_WARN_DEPRECATED=n for ppc64el
+-  * [Config] CONFIG_FB_3DFX=m for all arches
+-  * [Config] CONFIG_FB_MATROX=m for ppc64el
+-  * [Config] CONFIG_FB_RADEON=m for ppc64el
+-  * [Config] CONFIG_FB_SAVAGE_I2C=y for all arches
+-  * [Config] CONFIG_FIREWIRE=m for ppc64el
+-  * [Config] CONFIG_FTR_FIXUP_SELFTEST=n for ppc64el
+-  * [Config] CONFIG_HAMRADIO=y for ppc64el
+-  * [Config] CONFIG_I2C_CHARDEV=m for ppc64el
+-  * [Config] CONFIG_I2C_MUX=m for ppc64el
+-  * [Config] CONFIG_I2C_STUB=m for ppc64el
+-  * [Config] CONFIG_I2O=m for ppc64el
+-  * [Config] CONFIG_INET_XFRM_MODE_BEET=m, CONFIG_INET_XFRM_MODE_TRANSPORT=m, CONFIG_INET_XFRM_MODE_TUNNEL=m for ppc64el
+-  * [Config] CONFIG_INFINIBAND_IPOIB_DEBUG=n, CONFIG_INFINIBAND_MTHCA_DEBUG=n for ppc64el
+-  * [Config] CONFIG_INFINIBAND_NES=m, CONFIG_INFINIBAND_OCRDMA=m, CONFIG_INFINIBAND_QIB=m for ppc64el
+-  * [Config] CONFIG_INPUT_FF_MEMLESS=m for ppc64el
+-  * [Config] CONFIG_INTERVAL_TREE_TEST=m for ppc64el
+-  * [Config] CONFIG_IPACK_BUS=m for ppc64el
+-  * [Config] CONFIG_ISDN=y for ppc64el
+-  * [Config] CONFIG_ISO9660_FS=m for ppc64el
+-  * [Config] CONFIG_KGDB=y for ppc64el
+-  * [Config] CONFIG_KVM_GUEST=y for ppc64el
+-  * [Config] CONFIG_L2TP_V3=y for powerpc
+-  * [Config] CONFIG_MAILBOX=y for ppc64el
+-  * [Config] CONFIG_MD_LINEAR=m, CONFIG_MD_RAID0=m, CONFIG_MD_RAID1=m for ppc64el
+-  * [Config] CONFIG_MEDIA_SUPPORT=m for ppc64el
+-  * [Config] CONFIG_MEMORY=y for ppc64el
+-  * [Config] CONFIG_MEMSTICK=m for ppc64el
+-  * [Config] CONFIG_MFD_SM501_GPIO=n for ppc64el
+-  * [Config] CONFIG_MMC_BLOCK=m for ppc64el
+-  * [Config] CONFIG_MOUSE_PS2=m for ppc64el
+-  * [Config] CONFIG_NET_9P=m for ppc64el
+-  * [Config] CONFIG_MSDOS_FS=m for ppc64el
+-  * [Config] CONFIG_MSI_BITMAP_SELFTEST=n for ppc64el
+-  * [Config] CONFIG_MTD=m for arm64
+-  * [Config] CONFIG_NETCONSOLE=m for ppc64el
+-  * [Config] CONFIG_NETFILTER_XT_TARGET_NOTRACK=m for ppc64el
+-  * [Config] CONFIG_NET_IPIP=m for ppc64el
+-  * [Config] CONFIG_NET_TEAM=m for all arches
+-  * [Config] CONFIG_NFC=m for ppc64el
+-  * [Config] CONFIG_NL80211_TESTMODE=n for all arches
+-  * [Config] CONFIG_NLS_CODEPAGE_437=y for powerpc
+-  * [Config] CONFIG_NLS_ASCII=m, CONFIG_NLS_ISO8859_1=m, CONFIG_NLS_UTF8=m for ppc64el
+-  * [Config] CONFIG_NOP_USB_XCEIV=m for ppc64el
+-  * [Config] CONFIG_NOTIFIER_ERROR_INJECTION=m for ppc64el
+-  * [Config] CONFIG_OPROFILE=m for ppc64el
+-  * [Config] CONFIG_PARPORT_1284=y for ppc64el
+-  * [Config] CONFIG_PARPORT_AX88796=m, CONFIG_PARPORT_PC_FIFO=y, CONFIG_PARPORT_SERIAL=m for ppc64el
+-  * [Config] CONFIG_8723AU_P2P=n
+-  * [Config] CONFIG_PCI_IOV=y, CONFIG_PCI_PASID=y, CONFIG_PCI_PRI=y, CONFIG_PCI_REALLOC_ENABLE_AUTO=y, CONFIG_PCI_STUB=m for ppc64el
+-  * [Config] CONFIG_PCNET32=m for ppc64el
+-  * [Config] CONFIG_SCSI_DH_EMC=m for ppc64el
+-  * [Config] CONFIG_SCSI_DH_HP_SW=m for ppc64el
+-  * [Config] CONFIG_SCSI_FC_ATTRS=m for ppc64el
+-  * [Config] CONFIG_SCSI_IPR=m for ppc64el
+-  * [Config] CONFIG_SCSI_LOGGING=y for ppc64el
+-  * [Config] CONFIG_SCSI_OSD_INITIATOR=m for ppc64el
+-  * [Config] CONFIG_SCSI_SCAN_ASYNC=y for ppc64el
+-  * [Config] CONFIG_SCSI_SYM53C8XX_2=m for ppc64el
+-  * [Config] CONFIG_XILINX_LL_TEMAC=m for powerpc
+-  * [Config] CONFIG_WQ_POWER_EFFICIENT_DEFAULT=y for ppc64el
+-  * [Config] CONFIG_WLAN=y for arm64
+-  * [Config] CONFIG_VORTEX=m for ppc64el
+-  * [Config] CONFIG_WIMAX=m for ppc64el
+-  * [Config] CONFIG_WATCHDOG=y for ppc64el
+-  * [Config] CONFIG_VIRT_DRIVERS=y for ppc64el
+-  * [Config] CONFIG_VERSION_SIGNATURE="" for powerpc64-emb
+-  * [Config] CONFIG_UWB=m for ppc64el
+-  * [Config] CONFIG_USB_STORAGE=y
+-  * [Config] CONFIG_SATA_AHCI_PLATFORM=y for armhf
+-  * [Config] CONFIG_HID_RMI=m
+-  * [Config] CONFIG_HVC_DCC=n
+-    - LP: #1303657
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * mm/numa: Remove BUG_ON() in __handle_mm_fault()
+-    - LP: #1323165
+-  * powerpc/powernv: Add calls to support little endian host
+-    - LP: #1327400
+-  * HID: rmi: introduce RMI driver for Synaptics touchpads
+-  * HID: rmi: do not stop the device at the end of probe
+-  * HID: rmi: check for the existence of some optional queries before reading query 12
+-  * HID: rmi: do not fetch more than 16 bytes in a query
+-  * HID: rmi: fix wrong struct field name
+-  * HID: rmi: fix masks for x and w_x data
+-  * HID: rmi: do not handle touchscreens through hid-rmi
+-  * ALSA: pcm: 'BUG:' message unnecessarily triggers kerneloops
+-    - LP: #1305480
+-  * rebase to v3.15
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 03 Jun 2014 17:02:49 +0000
+-
+-linux (3.15.0-5.10) utopic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1325596
+-  * [Config] CONFIG_POWERNV_CPUFREQ=y for ppc64el
+-  * rebase to v3.15-rc8
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.15-rc8
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 02 Jun 2014 12:59:34 +0000
+-
+-linux (3.15.0-4.9) utopic; urgency=low
+-
+-  * no change rebuild to fix embeded debhelper.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 29 May 2014 12:41:58 +0100
+-
+-linux (3.15.0-4.8) utopic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Release Tracking Bug
+-    - LP: #1324107
+-  * [Config] enable SECURITY_APPARMOR_UNCONFINED_INIT
+-
+-  [ Javier Martinez Canillas ]
+-
+-  * SAUCE: (no-up) apparmor: fix bug that constantly spam the console
+-    - LP: #1323526
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: (no-up) apparmor: Sync to apparmor3 - alpha6 snapshot
+-    - LP: #1323528
+-  * SAUCE: (no-up) apparmor: fix apparmor spams log with warning message
+-    - LP: #1308761
+-  * SAUCE: (no-up) apparmor: fix refcount bug in apparmor pivotroot
+-    - LP: #1308765
+-  * SAUCE: (no-up): apparmor: fix apparmor refcount bug in apparmor_kill
+-    - LP: #1308764
+-  * SAUCE: (no-up): apparmor: use custom write_is_locked macro
+-    - LP: #1323530
+-
+-  [ Kamal Mostafa ]
+-
+-  * [Config] add debian/gbp.conf
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_SATA_AHCI=m for ppc64el
+-    - LP: #1323980
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 28 May 2014 12:47:17 +0100
+-
+-linux (3.15.0-3.7) utopic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1323189
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] autopkgtest -- need fakeroot for tests
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.15-rc7
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 26 May 2014 08:12:50 +0200
+-
+-linux (3.15.0-2.6) utopic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] remove the kernel-image firmware list on clean
+-
+-  [ Martin Pitt ]
+-
+-  * [Config] autopkgtest -- switch to significantly faster rebuild
+-
+-  [ Stefan Bader ]
+-
+-  * [Config]: Add missing modules to inclusion list
+-
+-  [ Tim Gardner ]
+-
+-  * [debian] Dynamically generate the kernel-image udebs firmware list
+-  * [d-i] firmware/kernel-image is generated
+-  * rebase to v3.15-rc6
+-  * Release Tracking Bug
+-    - LP: #1322251
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.15-rc6
+-    - LP: #1297581
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 21 May 2014 10:51:29 -0700
+-
+-linux (3.15.0-1.5) utopic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add apm-mustang.dtb to kernel-image udeb
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 19 May 2014 14:47:42 -0700
+-
+-linux (3.15.0-1.4) utopic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: (no-up) hv -- bodge hv_vss_daemon so it can use the
+-    local linux/hyperv.h"
+-  * Revert "SAUCE: (no-up) hv -- bodge hv_kvp_daemon so it can use the
+-    local linux/hyperv.h"
+-  * [Packaging] tools -- hv tools build correctly against the built headers
+-  * [Packaging] cloud-tools -- add the hv_fcopy_daemon to the package
+-  * cloud-tools -- pull in init scripts for Hyper-V daemons
+-  * cloud-tools -- detect Hyper-V VM to avoid starting
+-  * cloud-tools -- update IF_NAME to DEVICE in hv_* scripts
+-    - LP: #1295401
+-  * [Config] cloud-tools: reenable cloud-tools
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sun, 18 May 2014 19:21:04 +0100
+-
+-linux (3.15.0-1.3) utopic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] ppc64el is a powerpc kernel arch and needs its quirks
+-    - LP: #1318848
+-
+-  [ Ben Collins ]
+-
+-  * [Config] Switch to grub-ieee1275 as recommended on book3e systems
+-    - LP: #1318629
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_FSL_PAMU=n
+-    - LP: #1311738
+-  * Release Tracking Bug
+-    - LP: #1320239
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 16 May 2014 07:37:07 -0600
+-
+-linux (3.15.0-1.2) utopic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1318171
+-  * Add rpcsec_gss_krb5 to generic inclusion list
+-    - LP: #769527
+-  * rebase to v3.15-rc5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.15-rc5
+-    - LP: #1297581
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 06 May 2014 15:20:10 -0500
+-
+-linux (3.15.0-0.1) utopic; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.15-rc4
+-    - LP: #1297581
+-    - LP: #1297581
+-    - LP: #1305133
+-    - LP: #1297581
+-    - LP: #1297581
+-    - LP: #871808
+-    - LP: #1260303
+-    - LP: #1268468
+-    - LP: #1248116
+-    - LP: #1211920
+-    - LP: #1259790
+-    - LP: #1259437
+-    - LP: #1259435
+-    - LP: #1268468
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 07 Feb 2014 09:35:13 -0700
+-
+-linux (3.15.0-0.0) utopic; urgency=low
+-
+-  * Initial version for 3.15.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 02 May 2014 15:06:39 +0100
+-
+-linux (3.13.0-8.27) trusty; urgency=low
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: Add config option to disable new apparmor 3 semantics
+-    -LP: #1270215
+-
+-  [ Tim Gardner ]
+-
+-  * [debian] Fix indep_hdrs_pkg_name
+-    - LP: #1134441
+-  * Update lttng to 00808267d3ba7cdcddfed7bec7e62a40463c1307 Version 2.4.0-rc3
+-  * Enabled lttng build
+-  * Don't build lttng for armhf
+-    lttng hates gcc-4.8 for armhf
+-  * Release Tracking Bug
+-    - LP: #1277309
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.13.2
+-    - LP: #1260303
+-    - LP: #1260303
+-    - LP: #1268468
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 06 Feb 2014 09:25:51 -0700
+-
+-linux (3.13.0-7.26) trusty; urgency=low
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: apparmor: fix uninitialized lsm_audit membe
+-    - LP: #1268727
+-  * Add config option to optionally enable new apparmor 3 semantics
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add lowlatency to getabis
+-  * [Config] CONFIG_SECURITY_APPARMOR_AA3_SEMANTICS=y
+-    - LP: #1270215
+-  * Release Tracking Bug
+-    - LP: #1276810
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86, x32: Correct invalid use of user timespec in the kernel
+-    - LP: #1274349
+-    - CVE-2014-0038
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 05 Feb 2014 15:49:44 -0500
+-
+-linux (3.13.0-7.25) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: fix fmd headers"
+-  * SAUCE: fix fmd headers
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 04 Feb 2014 09:36:09 +0000
+-
+-linux (3.13.0-7.24) trusty; urgency=low
+-
+-  [ Stefan Bader ]
+-
+-  * [Config] Make vmwgfx driver enable the framebuffer device
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.13.1
+-  * [Config] CONFIG_NFS_FS=m for ppc64el
+-  * [Config] CONFIG_X86_SYSFB=n
+-    https://lists.ubuntu.com/archives/kernel-team/2014-February/038166.html
+-  * Release Tracking Bug
+-    - LP: #1275898
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * i2c: piix4: Add support for AMD ML and CZ SMBus changes
+-    - LP: #1272525
+-  * i2c: piix4: Use different message for AMD Auxiliary SMBus Controller
+-    - LP: #1272525
+-  * mm: ignore VM_SOFTDIRTY on VMA merging
+-    - LP: #1274917
+-  * drm/radeon: disable dpm on BTC
+-    - LP: #1266984
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.13.1
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 30 Jan 2014 15:24:48 +0000
+-
+-linux (3.13.0-6.23) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] fix up architecture for linux-tools
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 30 Jan 2014 09:00:41 +0000
+-
+-linux (3.13.0-6.22) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] limit linux-udebs-<flavour> to matching arch
+-  * [Config] powerpc -- disable perf to fix FTBFS
+-  * [Config] ppc64el -- fix up missing udebs
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 29 Jan 2014 16:00:28 +0000
+-
+-linux (3.13.0-6.21) trusty; urgency=low
+-
+-  [ Andy Fleming ]
+-
+-  * SAUCE: net: Add support for handling queueing in hardware
+-  * SAUCE: of_mdio: Add of_phy_attach function
+-  * SAUCE: phylib: Add generic 10G driver
+-  * SAUCE: phylib: Support attaching to gen10g_driver
+-  * SAUCE: phylib: Add Clause 45 read/write functions
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: fix fmd headers
+-  * [Packaging] lowlatency -- merge out of tree flavours
+-  * SAUCE: allow IRQs to be irq-threaded by default via config
+-  * [Config]: enable CONFIG_IRQ_FORCED_THREADING_DEFAULT for lowlatency
+-  * [Config] powerpc -- fix up Build-depends:
+-  * Release Tracking Bug
+-    - LP: #1273747
+-
+-  [ Ben Collins ]
+-
+-  * SAUCE: PPC: PCI: Fix pcibios_io_space_offset() so it works for 32-bit
+-    ptr/64-bit rsrcs
+-  * SAUCE: Revert "phy: vitesse make vsc824x_add_skew static"
+-  * SAUCE: Fixup freescale usb phy driver to work on ppc64
+-  * SAUCE: xgmac_mdio: Silence read errors
+-  * SAUCE: Provide booke stub for kvmppc_is_bigendian()
+-  * SAUCE: Fix stack overflow on ppc32
+-  * SAUCE: Use resource_size_t instead of long for PCI resource address
+-  * SAUCE: net/phy: Export function for use by dpaa_eth
+-  * [Packaging] powerpc -- merge out of tree powerpc arch
+-
+-  [ Bjorn Helgaas ]
+-
+-  * SAUCE: Revert "EISA: Log device resources in dmesg"
+-    - LP: #1251816
+-  * SAUCE: Revert "EISA: Initialize device before its resources"
+-    - LP: #1251816
+-
+-  [ Emil Medve ]
+-
+-  * SAUCE: phylib: Minimum hack to get the generic 10G PHY driver to work
+-    with 10G "fixed-link"s
+-
+-  [ Kumar Gala ]
+-
+-  * SAUCE: fsl_qbman: Add drivers for Freescale DPAA Qman & Bman
+-  * SAUCE: fsl_pme2: Add support for DPAA PME
+-  * SAUCE: fmd: FMD14 integration
+-  * SAUCE: dpaa_eth: Ethernet driver for Freescale QorIQ DPA Architecture
+-  * SAUCE: powerpc/85xx: Add DPAA/networking support for CoreNet
+-
+-  [ Madalin Bucur ]
+-
+-  * SAUCE: net/flow: remove sleeping and deferral mechanism from
+-    flow_cache_flush
+-  * SAUCE: net/phy: abort genphy_read_status when link changes during speed
+-    and duplex reading
+-
+-  [ Stefan Bader ]
+-
+-  * [Config] move some VMWare related modules into main package
+-    - LP: #1271669
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add r815x to nic-modules
+-    - LP: #1273735
+-  * [Config] CONFIG_FRAMEBUFFER_CONSOLE_ROTATION=y
+-    - LP: #239479
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * mmc: sdhci-pci: break out definitions to header file
+-    - LP: #1239938
+-  * mmc: sdhci-pci: add support of O2Micro/BayHubTech SD hosts
+-    - LP: #1239938
+-  * powerpc/book3e: rename interrupt_end_book3e with __end_interrupts
+-  * powerpc/book3e: support CONFIG_RELOCATABLE
+-  * book3e/kexec/kdump: enable kexec for kernel
+-  * book3e/kexec/kdump: create a 1:1 TLB mapping
+-  * book3e/kexec/kdump: introduce a kexec kernel flag
+-  * book3e/kexec/kdump: implement ppc64 kexec specfic
+-  * book3e/kexec/kdump: redefine VIRT_PHYS_OFFSET
+-  * book3e/kexec/kdump: recover "r4 = 0" to create the initial TLB
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 28 Jan 2014 22:59:46 +0000
+-
+-linux (3.13.0-5.20) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] tools -- do not make symlinks when not making packages
+-  * [Packaging] tools -- tidy up control.stub.in ordering
+-  * [Packaging] tools -- tools-common is shared and not conditional
+-  * rebase to v3.13
+-
+-  [ Dirk Brandewie ]
+-
+-  * SAUCE: intel_pstate: Add setting voltage value for baytrail P states.
+-
+-  [ KY Srinivasan ]
+-
+-  * SAUCE: Drivers: hv: vmbus: Specify the target CPU that should receive
+-    notification
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.13
+-   - LP: #1270603
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 17 Jan 2014 15:45:31 +0000
+-
+-linux (3.13.0-4.19) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] libunwind8-dev is now available for ppc64el
+-  * [Packaging] tools -- make cpupower optional
+-  * [Packaging] tools -- enable correctly for x86
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1269872
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * SAUCE: ARM: OMAP: hwmod: Add SYSC offsets for AES IP
+-  * SAUCE: ARM: OMAP4: hwmod: Add hwmod data for AES IP
+-  * SAUCE: OMAP: AM33xx: hwmod: Correct AES module SYSC type
+-  * SAUCE: crypto: omap-aes: add error check for pm_runtime_get_sync
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to 85ce70fdf48aa290b4845311c2dd815d7f8d1fa5
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 15 Jan 2014 13:23:05 +0000
+-
+-linux (3.13.0-3.18) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.13-rc8
+-  * [Packaging] efi -- allow EFI signatures on any arch
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Fix vcs-git path
+-  * Release Tracking Bug
+-    - LP: #1268683
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.13-rc8
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sun, 12 Jan 2014 11:58:01 +0000
+-
+-linux (3.13.0-2.17) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Release Tracking Bug
+-    - LP: #1267809
+-  * [Config] apply Platform support>>CPUIdle driver>>CPU Idle config
+-    defaults
+-  * [Config] apply Platform support>>CPU Frequency scaling config defaults
+-  * [Config] CONFIG_PARIDE_EPATC8=y
+-  * [Config] apply Device Drivers >> Broadcom specific AMBA config defaults
+-  * [Config] apply Bus options >> PCI support >> RapidIO support >> RapidIO
+-    Switch drivers config defaults
+-  * [Config] apply Cryptographic API config defaults
+-  * [Config] apply Device Drivers >> Common Clock Framework config defaults
+-  * [Config] apply Device Drivers >> Distributed Switch Architecture
+-    drivers config defaults
+-  * [Config] apply Device Drivers >> Graphics support >> Backlight & LCD
+-    device support config defaults
+-  * [Config] apply Device Drivers >> Graphics support >> Support for frame
+-    buffer devices >> Bootup logo config defaults
+-  * annotations -- update in tree annotations
+-  * [Config] apply Bus options >> PCI support >> RapidIO support config
+-    defaults
+-  * [Config] CONFIG_POWER_AVS=y CONFIG_RESET_CONTROLLER=y
+-  * [Config] apply Device Drivers >> 1-wire Bus Masters config defaults
+-  * [Config] apply CAN Device Drivers >> Platform CAN drivers with Netlink
+-    support config defaults
+-  * [Config] apply Device Drivers >> Character devices >> Serial drivers
+-    config defaults
+-  * [Config] apply Device Drivers >> Generic Thermal sysfs driver config
+-    defaults
+-  * [Config] apply Device Drivers >> Character devices >> TPM Hardware
+-    Support config defaults
+-  * [Config] apply Device Drivers >> Character devices config defaults
+-  * [Config] apply Device Drivers >> HID support >> USB HID support >> USB
+-    HID transport layer config defaults
+-  * [Config] apply Device Drivers >> HID support >> HID bus support config
+-    defaults
+-  * [Config] apply Device Drivers >> HID support >> USB HID support config
+-    defaults
+-  * annotations -- update in tree annotations
+-  * [Config] apply Device Drivers >> GPIO Support config defaults
+-  * [Config] update configs for apparmour update
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: (no-up) apparmor: Sync to apparmor 3 - alpha 4 snapshot
+-  * SAUCE: apparmor: fix unix domain sockets to be mediated on connection
+-    - LP: #1208988
+-  * SAUCE: apparmor: allocate path lookup buffers during init
+-    - LP: #1208988
+-  * SAUCE: (no-up) apparmor: Fix tasks not subject to, reloaded policy
+-    - LP: #1236455
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "[Debian] getabis: Preface module with package name"
+-  * [Config] Added ppc64el to getabis
+-  * [packaging] Bump ABI for every new release
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 10 Jan 2014 11:48:39 +0000
+-
+-linux (3.13.0-1.16) trusty; urgency=low
+-
+-  * First 3.13 upload.
+-  * Release tracker
+-    - LP: #1266852
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 07 Jan 2014 09:21:26 -0700
+-
+-linux (3.13.0-0.15) trusty; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.13-rc7
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.13-rc7
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Sun, 05 Jan 2014 06:13:33 -0700
+-
+-linux (3.13.0-0.14) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to 7a262d2ed9fa42fad8c4f243f8025580b58cf2f6
+-
+-  [ Tim Gardner ]
+-
+-  * Remove ubuntu/dm-raid4-5 in favor of CONFIG_MD_RAID456
+-  * Update lttng to Version 2.4.0-rc2
+-  * lttng: Disabled trace_kvm_async_pf_completed
+-  * [Config] CONFIG_IMA=y
+-    - LP: #1244627
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to 7a262d2ed9fa42fad8c4f243f8025580b58cf2f6
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 02 Jan 2014 12:57:13 -0700
+-
+-linux (3.13.0-0.13) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: aufs3 -- (no-up) aufs3-base.patch
+-  * ubuntu: aufs3 -- (no-up) aufs3-mmap.patch
+-  * ubuntu: aufs3 -- (no-up) aufs3-standalone.patch
+-  * ubuntu: AUFS (no-squash): basic framework and update machinary
+-  * ubuntu: AUFS -- update to 7b136a27b021da9010d8b6c101939dd298e46be7
+-  * ubuntu: aufs3 -- enable
+-  * ubuntu: aufs3 -- update configs
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 02 Jan 2014 09:41:02 +0000
+-
+-linux (3.13.0-0.12) trusty; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.13-rc6
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 31 Dec 2013 06:16:03 -0700
+-
+-linux (3.13.0-0.11) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: suspicious unlocked ->status reading and writing in ipc/sem.c
+-  * [Config] ppc64el -- initial defconfig based -generic flavour
+-  * [Config] initial defconfig for ppc64el
+-  * [Config] ubuntuise ppc64el config
+-  * [Config] ubuntuise ppc64el config part 2
+-  * [Config] d-i -- update empty udebs list
+-  * [Config] ppc64el -- split extras package
+-
+-  [ Anton Blanchard ]
+-
+-  * SAUCE: KVM: PPC: Book3S HV: Add little-endian guest support
+-
+-  [ Benjamin Herrenschmidt ]
+-
+-  * SAUCE: powerpc/powernv: Add calls to support little endian
+-
+-  [ Cédric Le Goater ]
+-
+-  * SAUCE: KVM: PPC: Book3S: add helper routine to load guest instructions
+-  * SAUCE: KVM: PPC: Book3S: add helper routines to detect endian order
+-  * SAUCE: KVM: PPC: Book3S: MMIO emulation support for little endian
+-    guests
+-
+-  [ Paul E. McKenney ]
+-
+-  * SAUCE: powerpc: Make 64-bit non-VMX copy_tofrom_user() bi-endian
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 27 Dec 2013 16:48:55 +0000
+-
+-linux (3.13.0-0.10) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.13-rc5
+-  * [Config] updateconfigs following rebase to v3.13-rc5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.13-rc5
+-    - LP: #1260303
+-    - LP: #1260303
+-    - LP: #1260225
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 23 Dec 2013 12:48:28 +0000
+-
+-linux (3.13.0-0.9) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] d-i -- allow missing firmware
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 20 Dec 2013 17:57:06 +0000
+-
+-linux (3.13.0-0.8) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] annotations -- first pass over entire config
+-  * [Config] drop libunwind8-dev from Build-Depends for ppc64el
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add arm64 device tree files
+-    - LP: #1262901
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 19 Dec 2013 18:36:43 +0000
+-
+-linux (3.13.0-0.7) trusty; urgency=low
+-
+-  [ Rajesh B Prathipati ]
+-
+-  * SAUCE: powerpc: Make unaligned accesses endian-safe for powerpc
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_REGULATOR_S2MPS11=n for FTBS
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.13-rc4
+-    - LP: #1259790
+-    - LP: #1259437
+-    - LP: #1259435
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 13 Dec 2013 07:56:34 -0700
+-
+-linux (3.13.0-0.6) trusty; urgency=low
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] armhf: arm64: VIRTIO_[BLK|MMIO|NET|CONSOLE|BALLOON]=y
+-  * [Config] i386: amd64: VIRTIO_CONSOLE=y
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS=y
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Sun, 08 Dec 2013 09:22:01 -0700
+-
+-linux (3.13.0-0.5) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * correct bug listing for v3.13-rc2 rebase
+-  * [Config] ppc64el -- create linux-libc-dev
+-  * [Debian] Improve tools version message
+-    - LP: #1257715
+-
+-  [ Serge Hallyn ]
+-
+-  * SAUCE: fork: Allow CLONE_PARENT after setns(CLONE_NEWPID)]
+-    - LP: #1248590
+-  * SAUCE: vfs: Fix a regression in mounting proc
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Build-in ohci-pci
+-    - LP: #1244176
+-  * Rebase to v3.13-rc3
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "Revert "fork: unify and tighten up CLONE_NEWUSER/CLONE_NEWPID
+-    checks""
+-    - LP: #1248590
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.13-rc3
+-    - LP: #1256840
+-    - LP: #1256212
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Sat, 07 Dec 2013 07:55:39 -0700
+-
+-linux (3.13.0-0.4) trusty; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Rebase to v3.13-rc2
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.13-rc2
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 29 Nov 2013 23:54:05 -0500
+-
+-linux (3.13.0-0.3) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: Fix DocBook FTBS"
+-
+-  [ Tim Gardner ]
+-
+-  * [Debian] Re-sign modules after debug objcopy
+-    - LP: #1253155
+-  * [Config] CONFIG_EXT4_USE_FOR_EXT23=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * doc: fix generation of device-drivers
+-  * rebase to b975dc3689fc6a3718ad288ce080924f9cb7e176
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 26 Nov 2013 12:24:42 -0700
+-
+-linux (3.13.0-0.2) trusty; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: Fix DocBook FTBS
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 25 Nov 2013 13:24:15 -0700
+-
+-linux (3.13.0-0.1) trusty; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to 7e3528c3660a2e8602abc7858b0994d611f74bc3
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 12 Nov 2013 07:28:53 -0700
+-
+-linux (3.13.0-0.0) trusty; urgency=low
+-
+-  * Major release bump.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 12 Nov 2013 21:37:52 +0000
+-
+-linux (3.12.0-2.7) trusty; urgency=low
+-
+-  * Fixed armhf ABI build failure.
+-  * Release tracker
+-    - LP: #1249477
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 08 Nov 2013 16:22:45 -0700
+-
+-linux (3.12.0-2.6) trusty; urgency=low
+-
+-  [ Joseph Salisbury ]
+-
+-  * SAUCE: tg3: Add support for new 57786 device id.
+-    - LP: #1242610
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_OABI_COMPAT=n
+-  * [Config] add the wandboard to shipped dtb
+-    - LP: #1249421
+-  * Release tracker
+-    - LP: #1249477
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 08 Nov 2013 12:23:18 -0700
+-
+-linux (3.12.0-2.5) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to mainline v3.12
+-  * [Config] updateconfigs following rebase to v3.12
+-  * postinst -- improve relative symlink detection with missing files
+-    - LP: #1248053
+-  * postinst -- fix unchanged link detection
+-  * [Config] update configs following addition of apparmor fixes
+-
+-  [ Anthony Wong ]
+-
+-  * SAUCE: Work around broken ACPI backlight on Dell Inspiron 5537
+-    - LP: #1231305
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: (no-up) apparmor: Sync to apparmor 3 - alpha 4 snapshot
+-  * SAUCE: apparmor: fix unix domain sockets to be mediated on connection
+-    - LP: #1208988
+-  * SAUCE: apparmor: allocate path lookup buffers during init
+-    - LP: #1208988
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Remove superfluous ubuntu/lttng-modules
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "fork: unify and tighten up CLONE_NEWUSER/CLONE_NEWPID checks"
+-    - LP: #1248590
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.12
+-    - LP: #1222850
+-
+-  [ Adam Conrad ]
+-  * etc/getabis: Fetch arm64/generic abis as well
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 06 Nov 2013 21:00:21 +0000
+-
+-linux (3.12.0-1.3) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] arm64 -- add arch to the configuration handlers
+-  * [Config] arm64 -- add generic flavour
+-  * [Config] arm64 -- default config
+-  * [Config] arm64 -- fix up various FTBFS config options
+-  * SAUCE: arm64: export __copy_in_user to modules
+-  * [Config] arm64 -- disable ABI/module checks
+-  * [Config] arm64 -- enforcer -- add arm64 to the enforcer
+-  * [Config] arm64 -- enable udebs for arm64
+-
+-  [ Colin Watson ]
+-
+-  * [Config] Clean up various udeb Provides
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] AHCI_IMX=y
+-  * [Config] build imx*-wandboard dtbs
+-
+-  [ Serge Hallyn ]
+-
+-  * SAUCE: device_cgroup: remove can_attach
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.12-rc7
+-  * SAUCE: KVM: Fix modprobe failure for kvm_intel/kvm_amd
+-  * Release tracker
+-    - LP: #1245932
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.12-rc7
+-    - LP: #1180881
+-    - LP: #1180881
+-    - LP: #1217957
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Sun, 27 Oct 2013 22:08:55 -0600
+-
+-linux (3.12.0-0.2) trusty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: (no-up) scsi: hyper-v storage -- mark as preferring READ
+-    CAPACITY (16) at SPC-2"
+-  * Revert "SAUCE: (no-up) scsi: hyper-v storage -- mark as VPD capable at
+-    SPC-2"
+-  * Revert "SAUCE: (no-up) scsi: add scsi device flag to request READ
+-    CAPACITY (16) be preferred"
+-  * Revert "SAUCE: (no-up) scsi: add scsi device flag to request VPD pages
+-    be used at SPC-2"
+-  * Revert "overlayfs: Update to v19"
+-  * Revert "ubuntu: overlayfs v18 -- -- overlayfs: implement show_options"
+-  * Revert "ubuntu: overlayfs v18 -- -- overlayfs: add statfs support"
+-  * Revert "ubuntu: overlayfs v18 -- -- overlay filesystem"
+-  * Revert "ubuntu: overlayfs v18 -- -- vfs: introduce
+-    clone_private_mount()"
+-  * Revert "ubuntu: overlayfs v18 -- -- vfs: export do_splice_direct() to
+-    modules"
+-  * Revert "ubuntu: overlayfs v18 -- -- overlay: overlay filesystem
+-    documentation"
+-  * ubuntu: overlayfs v20 -- overlayfs: add statfs support
+-  * [Config] fix linux-libc-dev generation for arm64
+-  * [Config] fix linux-libc-dev generation for x32
+-  * [Config] add linux-libc-dev generation for ppc64el
+-
+-  [ Erez Zadok ]
+-
+-  * ubuntu: overlayfs v20 -- overlayfs: implement show_options
+-
+-  [ Miklos Szeredi ]
+-
+-  * ubuntu: overlayfs v20 -- vfs: add i_op->dentry_open()
+-  * ubuntu: overlayfs v20 -- vfs: export do_splice_direct() to modules
+-  * ubuntu: overlayfs v20 -- vfs: export __inode_permission() to modules
+-  * ubuntu: overlayfs v20 -- vfs: introduce clone_private_mount()
+-  * ubuntu: overlayfs v20 -- overlay filesystem
+-  * ubuntu: overlayfs v20 -- fs: limit filesystem stacking depth
+-
+-  [ Neil Brown ]
+-
+-  * ubuntu: overlayfs v20 -- overlay: overlay filesystem documentation
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] arm: VIRTIO_[BLK|NET|MMIO]=y
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: (no-up) ACPI: Disable Windows 8 compatibility for some Lenovo
+-    ThinkPads
+-    - LP: #1183856
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_CRYPTO_CRCT10DIF=y, CONFIG_CRYPTO_CRCT10DIF_PCLMUL=m
+-  * rebase to v3.12-rc2
+-  * updateconfigs
+-  * [Config] disable CONFIG_FB_VESA enforcer check
+-  * [Config] Disable lttng for FTBS
+-  * rebase to v3.12-rc3
+-  * rebase to v3.12-rc4
+-  * [Config] CONFIG_ANDROID=n
+-    - LP: #1235161
+-  * [Config] CONFIG_L2TP_V3=y
+-    - LP: #1235914
+-  * [Config] CONFIG_USB_OTG=n for all arches
+-  * Release tracker
+-    - LP: #1242811
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * scsi: hyper-v storsvc switch up to SPC-3
+-
+-  * rebase to v3.12-rc6
+-    - LP: #1235977
+-    - LP: #1235523
+-    - LP: #1239392
+-    - LP: #1227491
+-
+-  * rebase to v3.12-rc3
+-    - LP: #1231931
+-
+-  * rebase to v3.12-rc2
+-    - LP: #1213820
+-    - LP: #1213055
+-    - LP: #1198030
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 23 Sep 2013 07:41:07 -0600
+-
+-linux (3.11.0-8.15) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release tracker
+-    - LP: #1227969
+-
+-  * Update lttng
+-    Updated to git://git.lttng.org/lttng-modules.git 9998f5216f4641a79e158135
+-    Version 2.3.0+
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * igb: Add additional get_phy_id call for i354 devices
+-    - LP: #1219619
+-  * igb: Read flow control for i350 from correct EEPROM section
+-    - LP: #1219619
+-  * timekeeping: Fix HRTICK related deadlock from ntp lock changes
+-    Required for lttng update.
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 19 Sep 2013 07:41:49 -0600
+-
+-linux (3.11.0-7.14) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] sort out linux-tools naming
+-    - LP: #1205284
+-  * [Packaging] linux-tools: switch to common generic version helper
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] highbank: ecx1000: CPU_IDLE causes instabilities, disable it
+-
+-  [ Tim Gardner ]
+-
+-  * Release tracker
+-    - LP: #1226160
+-
+-  [ Tony Lindgren ]
+-
+-  * SAUCE: ARM: dts: Fix muxing and regulator for wl12xx on the SDIO bus
+-    for pandaboard
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * USB: handle LPM errors during device suspend correctly
+-    - LP: #1011415
+-  * usb: don't check pm qos NO_POWER_OFF flag in usb_port_suspend()
+-    - LP: #1011415
+-  * usb: Don't fail port power resume on device disconnect.
+-    - LP: #1011415
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.11.1
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 11 Sep 2013 07:30:17 -0600
+-
+-linux (3.11.0-7.13) saucy; urgency=low
+-
+-  * Release tracker
+-    - LP: #1223545
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: (no-up) scsi: add scsi device flag to request VPD pages be used at SPC-2
+-    - LP: #1223499
+-  * SAUCE: (no-up) scsi: add scsi device flag to request READ CAPACITY (16) be preferred
+-    - LP: #1223499
+-  * SAUCE: (no-up) scsi: hyper-v storage -- mark as VPD capable at SPC-2
+-    - LP: #1223499
+-  * SAUCE: (no-up) scsi: hyper-v storage -- mark as preferring READ CAPACITY (16) at SPC-2
+-    - LP: #1223499
+-
+-  [ Maximiliano Curia ]
+-
+-  * SAUCE: (no-up) Only let characters through when there are active readers.
+-    - LP: #1208740
+-
+-  [ Tim Gardner ]
+-
+-  * [Debian] getabis: Commit new ABI directory, remove the old
+-  * [Config] CONFIG_EFIVAR_FS=y
+-    - LP: #1223195
+-  * [Config] CONFIG_EFI_VARS_PSTORE=m,
+-    CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE=n
+-  * SAUCE: (no-up) USB: input: cm109.c: Convert high volume dev_err() to dev_err_ratelimited()
+-    - LP: #1222850
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Intel xhci: refactor EHCI/xHCI port switching
+-    - LP: #1210858
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 10 Sep 2013 09:00:19 -0600
+-
+-linux (3.11.0-6.12) saucy; urgency=low
+-
+-  * Release tracker
+-    - LP: #1222893
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch"
+-  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-base.patch"
+-  * ubuntu: (no-squash) AUFS3 -- aufs3-base.patch
+-  * ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch
+-    - LP: #1222407
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] restore mmc boot on panda
+-
+-  [ Tyler Hicks ]
+-
+-  * SAUCE: apparmor: Use shash crypto API interface for profile hashes
+-    - LP: #1216294
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * net: calxedaxgmac: remove NETIF_F_FRAGLIST setting
+-  * net: calxedaxgmac: read correct field in xgmac_desc_get_buf_len
+-  * net: calxedaxgmac: fix race between xgmac_tx_complete and xgmac_tx_err
+-  * net: calxedaxgmac: fix possible skb free before tx complete
+-  * net: calxedaxgmac: update ring buffer tx_head after barriers
+-  * net: calxedaxgmac: fix race with tx queue stop/wake
+-  * net: calxedaxgmac: enable interrupts after napi_enable
+-  * net: calxedaxgmac: fix various errors in xgmac_set_rx_mode
+-  * net: calxedaxgmac: remove some unused statistic counters
+-  * net: calxedaxgmac: fix rx DMA mapping API size mismatches
+-  * net: calxedaxgmac: fix xgmac_xmit DMA mapping error handling
+-  * mfd: rtsx: Read vendor setting from config space
+-    - LP: #1201698
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 09 Sep 2013 07:21:06 -0600
+-
+-linux (3.11.0-5.11) saucy; urgency=low
+-
+-  * Release tracker
+-    - LP: #1221886
+-
+-  [ Adam Lee ]
+-
+-  * SAUCE: Bluetooth: Add support for 04ca:2007
+-    - LP: #1153448
+-  * SAUCE: Bluetooth: Add support for 105b:e065
+-    - LP: #1161261
+-
+-  [ Gavin Guo ]
+-
+-  * SAUCE: Bluetooth: Add support for Broadcom 413c:8143
+-    - LP: #1166113
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * igb: Reset the link when EEE setting changed
+-    - LP: #1219619
+-  * igb: Read register for latch_on without return value
+-    - LP: #1219619
+-  * igb: Added rcu_lock to avoid race
+-    - LP: #1219619
+-  * igb: don't allow SR-IOV without MSI-X
+-    - LP: #1219619
+-  * igb: Update MTU so that it is always at least a standard frame size
+-    - LP: #1219619
+-  * igb: Refactor of init_nvm_params
+-    - LP: #1219619
+-  * igb: Refactor NVM read functions to accommodate devices with no flash
+-    - LP: #1219619
+-  * igb: Add device support for flashless SKU of i210 device
+-    - LP: #1219619
+-  * igb: Fix get_fw_version function for all parts
+-    - LP: #1219619
+-  * igb: Add macro for size of RETA indirection table
+-    - LP: #1219619
+-  * igb: Expose RSS indirection table for ethtool
+-    - LP: #1219619
+-  * igb: Don't look for a PBA in the iNVM when flashless
+-    - LP: #1219619
+-  * igb: Implementation of 1-sec delay for i210 devices
+-    - LP: #1219619
+-  * igb: New PHY_ID for i354 device
+-    - LP: #1219619
+-  * igb: M88E1543 PHY downshift implementation
+-    - LP: #1219619
+-  * igb: No PHPM support in i354 devices
+-    - LP: #1219619
+-  * igb: Support to get 2_5G link status for appropriate media type
+-    - LP: #1219619
+-  * igb: Get speed and duplex for 1G non_copper devices
+-    - LP: #1219619
+-  * igb: Implementation to report advertised/supported link on i354 devices
+-    - LP: #1219619
+-  * igb: Update version number
+-    - LP: #1219619
+-  * Bluetooth: Take proper tty_struct references
+-    - LP: #1189998
+-  * Bluetooth: Remove the device from the list in the destructor
+-    - LP: #1189998
+-  * Bluetooth: Move the tty initialization and cleanup out of open/close
+-    - LP: #1189998
+-  * Bluetooth: Implement .activate, .shutdown and .carrier_raised methods
+-    - LP: #1189998
+-  * Bluetooth: Fix the reference counting of tty_port
+-    - LP: #1189998
+-  * Bluetooth: Purge the dlc->tx_queue to avoid circular dependency
+-    - LP: #1189998
+-
+-  [ Wen-chien Jesse Sung ]
+-
+-  * SAUCE: Bluetooth: Support for loading broadcom patchram firmware
+-    - LP: #1065400
+-  * SAUCE: Bluetooth: Add support for 13d3:3388 and 13d3:3389
+-    - LP: #1065400
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 05 Sep 2013 08:06:17 -0600
+-
+-linux (3.11.0-5.10) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Release tracker
+-    - LP: #1220222
+-  * Revert "[Config] Fix ubuntu directoy Kbuilds"
+-  * Revert "aufs update dropped some Kbuild files"
+-  * Revert "ubuntu: AUFS -- follow rename of loop.h into drivers/block"
+-  * Revert "ubuntu: AUFS -- update to
+-    8e503d4142c189ed6c47a2177ad2cd058e8d340e"
+-  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch"
+-  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-base.patch"
+-  * rebase to v3.11 final
+-  * [Config] clean up ubuntu/Kconfig and ubuntu/Makefile
+-  * ubuntu: AUFS (no-squash): basic framework and update machinary
+-  * ubuntu: (no-squash) AUFS3 -- aufs3-base.patch
+-  * ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch
+-  * ubuntu: AUFS -- update to 5ac5fe26a90a818218310e208d17688fddb07622
+-  * ubuntu: (no-squash) AUFS -- enable aufs
+-  * ubuntu: AUFS -- fix remaining d_count references to use accessor
+-  * ubuntu: lttng -- follow rename of pid_ns
+-  * SAUCE: disable stack-protector for ARM compressed bootloader
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] ARM_ATAG_DTB_COMPAT=y
+-
+-  [ Rob Herring ]
+-
+-  * [Config] Enable KVM and virtio for armhf generic-lpae
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_ARPD=y
+-  * [Config] CONFIG_ZSWAP=y
+-    - LP: #1215379
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * uvcvideo: quirk PROBE_DEF for Dell SP2008WFP monitor.
+-    - LP: #1217957
+-  * ARM: use phys_addr_t for DMA zone sizes
+-  * ARM: highbank: enable DMA zone for LPAE
+-  * ARM: highbank: select ARCH_HAS_HOLES_MEMORYMODEL
+-  * ARM: highbank: select required errata work-arounds
+-  * DMA: fix AMBA PL08x compilation issue with 64bit DMA address type
+-  * DMA: fix printk warning in AMBA PL08x DMA driver
+-  * ARM: highbank: select ARCH_DMA_ADDR_T_64BIT for LPAE
+-  * ARM: move outer_cache declaration out of ifdef
+-  * ARM: highbank: avoid L2 cache smc calls when PL310 is not present
+-  * ARM: highbank: clean-up some unused includes
+-  * ARM: xen: only set pm function ptrs for Xen guests
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.11
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 03 Sep 2013 17:08:06 +0100
+-
+-linux (3.11.0-4.9) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.11-rc7
+-  * Release tracker
+-    - LP: #1216962
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * mwifiex: do not create AP and P2P interfaces upon driver loading
+-    - LP: #1212720
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 26 Aug 2013 06:25:35 -0600
+-
+-linux (3.11.0-3.8) saucy; urgency=low
+-
+-  [ Johannes Berg ]
+-
+-  * SAUCE: mac80211: ignore (E)CSA in probe response frames
+-    - LP: #1201470
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 23 Aug 2013 09:47:36 -0600
+-
+-linux (3.11.0-3.7) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: (no-up) hv_vss_daemon -- prevent self-daemonising to allow
+-    upstart to track
+-  * SAUCE: (no-up) hv -- bodge hv_vss_daemon so it can use the local
+-    linux/hyperv.h
+-  * SAUCE: hv: Add vss daemon to Makefile
+-  * [Debian] Add hv_vss_daemon to tools package
+-    - LP: #1213282
+-  * [Config] Fix ubuntu directoy Kbuilds
+-    - LP: #1181755
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 20 Aug 2013 08:34:05 -0600
+-
+-linux (3.11.0-3.6) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] tools: conditionalise x86 and hyper-v tools sensibly
+-  * [Config] tools: enable x86 and hyper-v
+-
+-  [ John Johansen ]
+-
+-  * Revert "SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable
+-    snapshot"
+-  * Revert "SAUCE: (no-up) apparmor: fix apparmor module status for none
+-    root users"
+-  * SAUCE: (no-up) apparmor: Sync to apparmor 3 - alpha 4 snapshot
+-
+-  [ Joseph Salisbury ]
+-
+-  * SAUCE: (no-up) intel_ips: blacklist ASUSTek G60JX laptops
+-    - LP: #1210848
+-
+-  [ Kamal Mostafa ]
+-
+-  * [debian] tools: ship 'cpupower' in linux-tools
+-    - LP: #1158668
+-  * [Config] Build-dep on libpci-dev for cpu tools
+-    - LP: #1158668
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.11-rc6
+-  * Release tracker
+-    - LP: #1213941
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 16 Aug 2013 07:02:07 -0600
+-
+-linux (3.11.0-2.5) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_PM_DEBUG=y
+-    - LP: #1210539
+-  * rebase to v3.11-rc5
+-  * Release tracker
+-    - LP: #1211378
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 12 Aug 2013 06:10:39 -0600
+-
+-linux (3.11.0-1.4) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Bump ABI when making changes to the inclusion list lest
+-    you cause conflicts with existing installed kernel
+-    packages.
+-    - LP: #1210331
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 09 Aug 2013 03:03:51 +0100
+-
+-linux (3.11.0-0.3) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Include rbd and kvm in the virtual inclusion list
+-    - LP: #1206961
+-  * [Config] Removed obsolete inclusion list entries
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 06 Aug 2013 08:52:14 +0100
+-
+-linux (3.11.0-0.2) saucy; urgency=low
+-
+-  [ Bruce Allan ]
+-
+-  * SAUCE: (no-up) e1000e: fix I217/I218 PHY initialization flow
+-    - LP: #1206757
+-  * SAUCE: (no-up) e1000e: enable support for new device IDs
+-    - LP: #1206757
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable snapshot
+-
+-  [ Paolo Pisati ]
+-
+-  * build vexpress a15 dtb
+-  * [Config] disable Broadcom bcm support (ARCH_BCM)
+-  * [Config] disable Allwinner a1x support (ARCH_SUNXI)
+-  * [Config] disable WonderMedia WM8850 support (ARCH_WM8850)
+-  * [Config] disable Rockchip support (ARCH_ROCKCHIP)
+-  * [Config] disable STMicroelectronics STiH41x SOCs (ARCH_STI)
+-  * [Config] disable TI Keystone, AM43xx and OMAP5 support
+-  * [Config] ARM_APPENDED_DTB=y
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.11-rc4
+-  * overlayfs: Update to v19
+-  * [Config] Enable overlayfs
+-  * SAUCE: Fix lttng compile errors
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.11-rc4
+-    - LP: #1163720
+-    - LP: #1162026
+-    - LP: #1195636
+-    - LP: #1195597
+-    - LP: #1180409
+-    - LP: #1168430
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Sun, 04 Aug 2013 03:45:31 -0600
+-
+-linux (3.11.0-0.1) saucy; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to 64ccccf8525fee499625b517c0faadf784c79e93
+-    - LP: #1163720
+-    - LP: #1162026
+-    - LP: #1195636
+-    - LP: #1195597
+-    - LP: #1180409
+-    - LP: #1168430
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 08 Jul 2013 08:50:46 -0600
+-
+-linux (3.10.0-2.10) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_INTEL_MEI*=m
+-    - LP: #1196155
+-  * [Config] CONFIG_DEBUG_INFO=y
+-
+-  [ Stephen Warren ]
+-
+-  * [Config] fix Calxeda xgmac module filename
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "serial: 8250_pci: add support for another kind of NetMos
+-    Technology PCI 9835 Multi-I/O Controller"
+-    - LP: #1190967
+-  * mfd: lpc_ich: Add support for Intel Avoton SoC
+-    - LP: #1196658
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Jul 2013 18:08:02 +0100
+-
+-linux (3.10.0-2.9) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.10
+-
+-  [ John Johansen ]
+-
+-  * Revert "SAUCE: (no-up) apparmor: Fix quieting of audit messages for
+-    network mediation"
+-  * Revert "SAUCE: (no-up) apparmor: Fix compile warnings"
+-  * Revert "SAUCE: (no-up) AppArmor: basic networking rules"
+-  * Revert "SAUCE: (no-up) apparmor: Add the ability to mediate mount"
+-  * Revert "SAUCE: (no-up) AppArmor: Add profile introspection file to
+-    interface"
+-  * Revert "SAUCE: (no-up) AppArmor: Disable Add PR_{GET,SET}_NO_NEW_PRIVS
+-    to prevent execve from granting privs"
+-  * SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable snapshot
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 01 Jul 2013 17:42:29 +0100
+-
+-linux (3.10.0-1.8) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Release Tracking Bug
+-    - LP: #1195717
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: overlayfs -- follow change to do_splice_direct
+-    interface"
+-  * Revert "ubuntu: overlayfs -- expose do_splice_direct prototype"
+-  * Revert "SAUCE: ubuntu: overlayfs -- ovl_path_open should not take path
+-    reference"
+-  * Revert "ubuntu: overlayfs -- add FS_ALIAS"
+-  * Revert "ubuntu: overlayfs --
+-    overlayfs-copy-up-i_uid-i_gid-from-the-underlying-inode"
+-  * Revert "ubuntu: overlayfs -- ovl-switch-to-inode_permission"
+-  * Revert "ubuntu: overlayfs -- vfs-export-inode_permission-to-modules"
+-  * Revert "ubuntu: overlayfs -- overlayfs-create-new-inode-in-ovl_link"
+-  * Revert "ubuntu: overlayfs --
+-    overlayfs-fix-possible-leak-in-ovl_new_inode"
+-  * Revert "ubuntu: overlayfs -- fs-limit-filesystem-stacking-depth"
+-  * Revert "ubuntu: overlayfs -- overlay-overlay-filesystem-documentation"
+-  * Revert "ubuntu: overlayfs -- overlayfs-implement-show_options"
+-  * Revert "ubuntu: overlayfs -- overlayfs-add-statfs-support"
+-  * Revert "ubuntu: overlayfs -- overlay filesystem"
+-  * Revert "ubuntu: overlayfs -- vfs-introduce-clone_private_mount"
+-  * Revert "ubuntu: overlayfs -- vfs-export-do_splice_direct-to-modules"
+-  * Revert "ubuntu: overlayfs -- vfs-add-i_op-dentry_open"
+-  * ubuntu: overlayfs v18 -- -- overlayfs: add statfs support
+-
+-  [ Erez Zadok ]
+-
+-  * ubuntu: overlayfs v18 -- -- overlayfs: implement show_options
+-
+-  [ Miklos Szeredi ]
+-
+-  * ubuntu: overlayfs v18 -- -- vfs: add i_op->dentry_open()
+-  * ubuntu: overlayfs v18 -- -- vfs: export do_splice_direct() to modules
+-  * ubuntu: overlayfs v18 -- -- vfs: export __inode_permission() to modules
+-  * ubuntu: overlayfs v18 -- -- vfs: introduce clone_private_mount()
+-  * ubuntu: overlayfs v18 -- -- overlay filesystem
+-  * ubuntu: overlayfs v18 -- -- fs: limit filesystem stacking depth
+-
+-  [ Neil Brown ]
+-
+-  * ubuntu: overlayfs v18 -- -- overlay: overlay filesystem documentation
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_SUNRPC_DEBUG=y
+-    - LP: #1127319
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jun 2013 10:26:52 +0100
+-
+-linux (3.10.0-0.7) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * autopkgtest: switch Depends: to build-essential
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 25 Jun 2013 08:40:55 +0100
+-
+-linux (3.10.0-0.6) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_ARCH_TEGRA to fix FTBFS on armhf
+-  * SAUCE: ubuntu: overlayfs -- ovl_path_open should not take path reference
+-    - LP: #1098378
+-  * ubuntu: AUFS -- update to 4f14cef47eb7c23eda7198931fbab1040866b6ee
+-  * ubuntu: overlayfs -- expose do_splice_direct prototype
+-  * ubuntu: overlayfs -- follow change to do_splice_direct interface
+-  * [Config] flip CONFIG_NO_HZ_FULL_ALL off as it is overheating machines
+-    - LP: #1192691
+-
+-  [ Stefan Bader ]
+-
+-  * (d-i) Add dm-snapshot to md-modules
+-    - LP: #1191726
+-
+-  [ Tim Gardner ]
+-
+-  * Release tracker
+-    - LP: #1194149
+-  * [Config] CONFIG_WIL6210=n for armhf
+-  * [Config] d-i: Add calxedaxgmac to nic-modules
+-    - LP: #1192358
+-  * [debian] Use dh_strip
+-    - LP: #1192759
+-  * [Config] Enable perf for armhf
+-  * do_tools=false when cross compiling
+-  * [Config] CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS=y
+-    - LP: #1108082
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * nsp32: switch reset delay to msleep() as it is tooo long
+-  * alx: add a simple AR816x/AR817x device driver
+-    Plucked from linux-next. replaces ubuntu/alx in favor of
+-    'to be merged' version in 3.11.
+-  * rebase to v3.10-rc7
+-    - LP: #1189363
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Sat, 22 Jun 2013 18:10:31 -0600
+-
+-linux (3.10.0-0.5) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.10-rc6
+-  * [Config] updateconfigs following rebase to v3.10-rc6
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10-rc6
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 17 Jun 2013 11:12:39 +0100
+-
+-linux (3.10.0-0.4) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] updateconfigs following rebase to v3.10-rc4
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 10 Jun 2013 11:42:28 +0100
+-
+-linux (3.10.0-0.3) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.10-rc5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10-rc5
+-    - LP: #1186170
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 10 Jun 2013 09:23:31 +0100
+-
+-linux (3.10.0-0.2) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.10-rc4
+-  * [Config] CONFIG_BINFMT_SCRIPT=y to fix booting initramfs scripts
+-  * [Config] enable SND_PCM_DEBUG SND_PCM_XRUN_DEBUG
+-    - LP: #1187744
+-  * [Config] enforce CONFIG_BINFMT_SCRIPT=y
+-
+-  [ Dave Chiluk ]
+-
+-  * SAUCE: ncpfs: fix rmdir returns Device or resource busy
+-    - LP: #1035226
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.10-rc3
+-  * [Config] sparc be gone
+-  * [Config] ia64 be gone
+-  * d-i: block-modules provides nbd-modules
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10-rc4
+-  * rebase to v3.10-rc3
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 28 May 2013 06:16:46 -0600
+-
+-linux (3.10.0-0.1) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * UBUNTU: Disabled lttng
+-  * UBUNTU: Disable aufs for FTBS
+-  * UBUNTU: Disabled alx
+-  * UBUNTU: alx: rename NETIF_F_HW_VLAN_* feature flags to NETIF_F_HW_VLAN_CTAG_*
+-  * UBUNTU: rebase to v3.10-rc2
+-  * UBUNTU: SAUCE: uvcvideo: quirk PROBE_DEF for Alienware X51 OmniVision webcam
+-
+-  [ Andy Whitcroft ]
+-
+-  * UBUNTU: [Config] update standards version to 3.9.4.0
+-  * UBUNTU: [Config] squash duplicate package description (long and short)
+-  * UBUNTU: [Config] fix up Vcs-git: to point to saucy
+-  * UBUNTU: [Config] drop depenancy on util-linux as is Essential
+-  * UBUNTU: [Config] drop redundant Build-Conficts:
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10-rc2
+-    - LP: #1180351
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10-rc1
+-    - LP: #1172151
+-    - LP: #1089795
+-    - LP: #1167270
+-    - LP: #1128840
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 14 May 2013 13:41:07 -0600
+-
+-linux (3.10.0-0.0) saucy; urgency=low
+-
+-  * Dummy
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 09 May 2013 20:30:40 +0100
+-
+-linux (3.9.0-2.6) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.9.2
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 09 May 2013 20:30:40 +0100
+-
+-linux (3.9.0-1.5) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.9.1
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 08 May 2013 12:49:45 -0400
+-
+-linux (3.9.0-0.4) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: overlayfs -- add FS_ALIAS
+-
+-  [ Tim Gardner ]
+-
+-  * Added lttng
+-    - LP: #1175784
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 02 May 2013 17:17:13 -0400
+-
+-linux (3.9.0-0.3) saucy; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Apr 2013 18:20:00 -0400
+-
+-linux (3.9.0-0.2) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Enable extras packaging for amd64/i386.
+-    Fixes build depenencies with brittany and linux-meta.
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Apr 2013 05:37:01 -0600
+-
+-linux (3.9.0-0.1) saucy; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc8
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc7
+-    - LP: #1128840
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc6
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc4
+-    - LP: #1095315
+-    - LP: #886975
+-    - LP: #1086921
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc3
+-    - LP: #1155016
+-    - LP: #1103594
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc2
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc1
+-    - LP: #901105
+-    - LP: #961286
+-    - LP: #1011792
+-    - LP: #1128934
+-    - LP: #886975
+-    - LP: #978807
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 20 Feb 2013 09:12:39 -0700
+-
+-linux (3.8.0-7.14) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_RCU_USER_QS=n
+-  * [Config] CONFIG_MTD_ONENAND_SIM=n
+-  * annotations: add annotations for CONFIG_CC_STACKPROTECTOR
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8
+-
+-  [Tim Gardner]
+-
+-  * Release Tracking Bug
+-    - LP: #1130111
+-  * UBUNTU: SAUCE: rt2x00: rt2x00pci_regbusy_read() - only print register access failure once
+-    - LP: #1128840
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 18 Feb 2013 09:25:56 -0700
+-
+-linux (3.8.0-6.13) raring; urgency=low
+-
+-  [Tim Gardner]
+-
+-  * Release Tracking Bug
+-    - LP: #1125364
+-  * Add ahci modules to d-i
+-    - LP: #1124415
+-
+-
+-  [ Chris Wilson ]
+-
+-  * SAUCE: drm/i915: Wait for pending flips to complete before tearing down
+-    the encoders
+-    - LP: #1097315
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 13 Feb 2013 12:16:48 -0700
+-
+-linux (3.8.0-6.12) raring; urgency=low
+-
+-  [Tim Gardner]
+-
+-  * perf: NO_LIBPERL=1
+-  * Fix linux-headers dependency
+-  * Release Tracking Bug
+-    - LP: #1124362
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_AUFS_EXPORT to allow nfs exports
+-    - LP: #1121699
+-
+-  [ Daniel Vetter ]
+-
+-  * SAUCE: drm/i915: write backlight harder
+-    - LP: #954661
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 13 Feb 2013 10:25:11 -0700
+-
+-linux (3.8.0-6.11) raring; urgency=low
+-
+-  [Tim Gardner]
+-
+-  * Release Tracking Bug
+-    - LP: #1122071
+-  * rebase to v3.8-rc7
+-  * Add libaudit-dev as a build dependency
+-  * Build perf with NO_LIBPYTHON=1 to avoid a python build dependency.
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Remove CONFIG_SATA_AHCI annotation
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 08 Feb 2013 07:41:13 -0500
+-
+-linux (3.8.0-5.10) raring; urgency=low
+-
+-  [Tim Gardner]
+-
+-  * Release Tracking Bug
+-    - LP: #1118568
+-
+-  * Bump ABI to fix install issue with 3.8.0-4.8.
+-    Moving drivers/ata/*ahci* to linux-image caused an
+-    install conflict with linux-image-extras without an
+-    ABI bump.
+-
+-  [ Jan Beulich ]
+-
+-  * SAUCE: xen-pciback: rate limit error messages from
+-    xen_pcibk_enable_msi{, x}()
+-    - LP: #1117336
+-    - CVE-2013-0231
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 07 Feb 2013 05:38:12 -0700
+-
+-linux (3.8.0-4.9) raring; urgency=low
+-
+-  [ Herton Ronaldo Krzesinski ]
+-
+-  * d-i: Add mellanox ethernet drivers to nic-modules
+-    - LP: #1015339
+-
+-  [ Joseph Salisbury ]
+-
+-  * SAUCE: ACPI: Add DMI entry for Sony VGN-FW41E_H
+-    - LP: #1113547
+-
+-  [ Kamal Mostafa ]
+-
+-  * SAUCE: alx driver import script
+-
+-  [ Qualcomm Atheros, Inc ]
+-
+-  * SAUCE: alx: Update to heads/master
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1117673
+-
+-  * [debian] Remove dangling symlink from headers package
+-    - LP: #1112442
+-  * [config] CONFIG_ALX=m
+-  * [Config] Add alx to d-i nic-modules
+-  * [Config] CONFIG_SATA_AHCI=m
+-    - LP: #1056563
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 05 Feb 2013 05:54:32 -0800
+-
+-linux (3.8.0-4.8) raring; urgency=low
+-
+-  [ Allen Ibara ]
+-
+-  * SAUCE: imx6: dts: Add IMX6Q AHCI support
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.8-rc6
+-  * updateconfigs following rebase to v3.8-rc6
+-
+-  [Leann Ogasawara]
+-
+-  * Release Tracking Bug
+-    - LP: #1112573
+-
+-  [ Paolo Pisati ]
+-
+-  * SAUCE: imx6: enable sata clk if SATA_AHCI_PLATFORM
+-  * [Config] SERIAL_AMBA_PL011=y (vexpress serial console)
+-  * [Config] MMC_ARMMMCI=y (vexpress mmc)
+-  * [Config] FB_ARMCLCD=y (vexpress framebuffer)
+-
+-  [ Seth Forshee ]
+-
+-  * [Config] CONFIG_MAC80211_MESSAGE_TRACING=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc6
+-    - LP: #1107477
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 01 Feb 2013 07:20:59 -0800
+-
+-linux (3.8.0-3.7) raring; urgency=low
+-
+-  [ Andy Green ]
+-
+-  * SAUCE: ARM: OMAP2+: add cpu id register to MAC address helper
+-  * SAUCE: ARM: omap2 add mac address allocation register api
+-  * SAUCE: ARM: omap2 panda register ethernet and wlan for automatic mac
+-    allocation
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.8-rc5
+-  * Release Tracking Bug
+-    - LP: #1111486
+-
+-  [ Paolo Pisati ]
+-
+-  * SAUCE: davinci: vpss: compilation fix
+-  * [Config] enable TI OMAP4 support (Pandaboard/ES)
+-  * [Config] OMAP_USB2=y (since TWL6030_USB depends on it)
+-  * [Config] enable Freescale IMX6 support (SabreLite)
+-  * [Config] SERIAL_IMX_CONSOLE=y
+-  * [Config] MMC_*_IMX=y
+-  * [Config] disable USB_SUSPEND
+-  * [Config] USB_MXS_PHY=y
+-  * [Config] USB_CHIPIDEA=y
+-  * SAUCE: DTB: add support for multiple DTBs
+-  * SAUCE: DTB: build imx6q-sabrelite
+-  * SAUCE: DTB: build beaglexm
+-  * SAUCE: DTB: build panda/panda es
+-  * [Config] disable CPU_FREQ
+-  * [Config] PANEL_TFP410=y (video DVI output)
+-  * [Config] SND_OMAP_SOC*=y
+-  * [Config] SND_IMX_SOC*=y
+-  * [Config] I2C_IMX=y
+-  * [Config] SPI_IMX=m
+-
+-  [ Stefan Bader ]
+-
+-  * [Config] Move 9p modules into generic package
+-    - LP: #1107658
+-
+-  [ Tony Lindgren ]
+-
+-  * SAUCE: ARM: OMAP2+: Limit omap initcalls to omap only on multiplatform
+-    kernels
+-  * SAUCE: ARM: OMAP2+: Use omap initcalls
+-  * SAUCE: ARM: OMAP: Fix i2c cmdline initcall for multiplatform
+-  * SAUCE: ARM: OMAP: Fix dmaengine init for multiplatform
+-  * SAUCE: ARM: OMAP2+: Add multiplatform debug_ll support
+-  * SAUCE: ARM: OMAP2+: Disable code that currently does not work with
+-    multiplaform
+-  * SAUCE: ARM: OMAP2+: Enable ARCH_MULTIPLATFORM support
+-  * SAUCE: ARM: OMAP2+: Add minimal support for booting vexpress
+-  * SAUCE: ARM: OMAP2+: Remove now obsolete uncompress.h and debug-macro.S
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc5
+-    - LP: #1096789
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Jan 2013 06:44:52 -0800
+-
+-linux (3.8.0-2.6) raring; urgency=low
+-
+-  [ Adam Conrad ]
+-
+-  * Fix up linux-tools -> SRCPKGNAME-tools rename
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] re-disable CONFIG_SOUND_OSS
+-    - LP: #1105230
+-
+-  [ Arend van Spriel ]
+-
+-  * SAUCE: brcmsmac: fix tx status processing
+-
+-  [Leann Ogasawara]
+-
+-  * Release Tracking Bug
+-    - LP: #1105104
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 25 Jan 2013 11:56:30 -0800
+-
+-linux (3.8.0-1.5) raring; urgency=low
+-
+-  [Tim Gardner]
+-
+-  * Release Tracking Bug
+-    - LP: #1101235
+-
+-  [ Dudley Du ]
+-
+-  * SAUCE: Input: add support for Cypress PS/2 Trackpads
+-    - LP: #978807
+-
+-  [ Kamal Mostafa ]
+-
+-  * SAUCE: Input: increase struct ps2dev cmdbuf[] to 8 bytes
+-  * SAUCE: Input: Cypress PS/2 Trackpad simulated multitouch
+-  * [Config] Add CONFIG_PS2_CYPRESS
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.8-rc4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc4
+-    - LP: #1095315
+-    - LP: #886975
+-    - LP: #1086921
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 17 Jan 2013 10:50:22 -0800
+-
+-linux (3.8.0-0.4) raring; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Update CONFIG_TOUCHSCREEN_EGALAX build annotation
+-  * [Config] Update CONFIG_IIO build annotation
+-  * [Config] Update CONFIG_TOUCHSCREEN_EETI annotation
+-  * [Config] Remove CONFIG_SPI_DW_MMIO annotation
+-  * [Config] Remove CONFIG_SPI_PL022 annotation
+-  * [Config] Update CONFIG_EZX_PCAP annotation
+-  * [Config] Update CONFIG_SENSORS_AK8975 annotation
+-  * [Config] Disable CONFIG_DRM_MGAG200
+-    - LP: #1042903
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 14 Jan 2013 10:01:50 -0800
+-
+-linux (3.8.0-0.3) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: (no-up) trace: add trace events for open(), exec() and
+-    uselib()"
+-
+-  [ Scott James Remnant ]
+-
+-  * SAUCE: (no-up) trace: add trace events for open(), exec() and uselib()
+-    (for v3.7+)
+-    - LP: #1085766, #462111
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Jan 2013 16:57:27 +0000
+-
+-linux (3.8.0-0.2) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [packaging] Add macro to selectively disable building perf
+-  * [packaging] Cannot depend on universe package libaudit-dev
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 10 Jan 2013 12:43:24 -0700
+-
+-linux (3.8.0-0.1) raring; urgency=low
+-
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc3
+-    - LP: #1096789
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc2
+-    - LP: #1082357
+-    - LP: #1075882
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 17 Dec 2012 10:35:09 +0000
+-
+-linux (3.7.0-7.15) raring; urgency=low
+-
+-  [ Chris J Arges ]
+-
+-  * SAUCE: add eeprom_bad_csum_allow module parameter
+-    - LP: #1070182
+-
+-  [ Leann Ogasawara ]
+-
+-  * Add ceph to linux-image for virtual instances
+-    - LP: #1063784
+-
+-  [ Serge Hallyn ]
+-
+-  * SAUCE: net: dev_change_net_namespace: send a KOBJ_REMOVED/KOBJ_ADD
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_SLUB_DEBUG=y
+-    - LP: #1090308
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "[SCSI] sd: Implement support for WRITE SAME"
+-    - LP: #1089818
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 12 Dec 2012 06:50:20 -0800
+-
+-linux (3.7.0-6.14) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] annotations: all new annotations scheme including defaults
+-  * [Configs] apply annotation updates to main configs (top section)
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: include <linux/printk.h> and <stdarg.h> for mmc_core arm
+-    build"
+-  * Revert "SAUCE: [arm] fixup __aeabi_uldivmod undefined build error"
+-  * Temporarily disable module check for build
+-
+-  [ Stefan Bader ]
+-
+-  * ubuntu: dm-raid45: Adapt to upstream interface changes
+-  * Re-enable build of dm-raid45
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: Moved scripts/fw-to-ihex.sh to debian/scripts/misc
+-  * SAUCE: ACPICA: Fix ACPI mutex object allocation memory leak on error
+-  * SAUCE: drm: Fix possible EDID memory allocation oops
+-  * SAUCE: ttm: Fix possible _manager memory allocation oops
+-  * SAUCE: iwlwifi: iwlagn_request_scan: Fix check for priv->scan_request
+-  * SAUCE: i915: intel_set_mode: Reduce stack allocation from 500 bytes to
+-    2 pointers
+-
+-  [ Tomas Hozza ]
+-
+-  * SAUCE: tools: hv: Netlink source address validation allows DoS
+-    - LP: #1084777
+-    - CVE-2012-5532
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 05 Dec 2012 14:11:12 -0800
+-
+-linux (3.7.0-5.13) raring; urgency=low
+-
+-  [ Lino Sanfilippo ]
+-
+-  * SAUCE: inotify, fanotify: replace fsnotify_put_group() with
+-    fsnotify_destroy_group()
+-    - LP: #922906
+-  * SAUCE: fsnotify: introduce fsnotify_get_group()
+-    - LP: #922906
+-  * SAUCE: fsnotify: use reference counting for groups
+-    - LP: #922906
+-  * SAUCE: fsnotify: take groups mark_lock before mark lock
+-    - LP: #922906
+-  * SAUCE: fanotify: add an extra flag to mark_remove_from_mask that
+-    indicates wheather a mark should be destroyed
+-    - LP: #922906
+-  * SAUCE: fsnotify: use a mutex instead of a spinlock to protect a groups
+-    mark list
+-    - LP: #922906
+-  * SAUCE: fsnotify: pass group to fsnotify_destroy_mark()
+-    - LP: #922906
+-  * SAUCE: fsnotify: introduce locked versions of fsnotify_add_mark() and
+-    fsnotify_remove_mark()
+-    - LP: #922906
+-  * SAUCE: fsnotify: dont put marks on temporary list when clearing marks
+-    by group
+-    - LP: #922906
+-  * SAUCE: fsnotify: change locking order
+-    - LP: #922906
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_NFC_LLCP=y
+-  * [Config] get-firmware: Filter new files through fwinfo
+-  * [Config] CONFIG_MTD_NAND_DOCG4=m for all arches
+-  * [Config] CONFIG_DRM_EXYNOS_HDMI=y
+-  * [Config] CONFIG_XEN=y for all arches
+-  * [Config] CONFIG_SND_OMAP_SOC_ZOOM2=m
+-  * [Config] CONFIG_MMC_DW_EXYNOS=m
+-  * [Config] CONFIG_GPIO_ADNP=m
+-  * [Config] find-obsolete-firmware: Use correct path
+-  * rebase to v3.7-rc8
+-    - LP: #1084640
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "VFS: don't do protected {sym,hard}links by default"
+-    - LP: #1084192
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 28 Nov 2012 16:07:08 +0000
+-
+-linux (3.7.0-4.12) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "[Config] Use -j1 for headers_install"
+-  * Revert "[Config] install-arch-headers needs a valid config"
+-    Strayed into the weeds in search of the root cause of the periodic
+-    build failure.
+-    Fixes powerpc FTBS introduced in -4.11.
+-  * [Config] hmake -j1
+-    The kernel makefile appears to have parallel dependency
+-    problems for the install_headers target. This appears to be root
+-    cause for a periodic build failure on N-way machines.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 27 Nov 2012 12:33:06 -0800
+-
+-linux (3.7.0-4.11) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Use -j1 for headers_install
+-    Also fixes a powerpc FTBS introduced by
+-    "[Config] install-arch-headers needs a valid config".
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 27 Nov 2012 10:19:30 -0700
+-
+-linux (3.7.0-4.10) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] add rebuild-test support for autopkgtest
+-    - LP: #1081500
+-  * [tests] move build tests out of the way
+-    - LP: #1081500
+-  * [tests] add an autopkgtest rebuild test
+-    - LP: #1081500
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.7-rc7
+-  * SAUCE: Remove emi62 files duplicated in linux-firmware
+-  * SAUCE: Remove sb16 files duplicated in linux-firmware
+-  * SAUCE: Remove whiteheat files duplicated in linux-firmware
+-  * SAUCE: Remove yamaha files duplicated in linux-firmware
+-  * SAUCE: Remove dsp56k files used only by m68k
+-  * SAUCE: firmware: Remove last vestiges of dabusb
+-  * SAUCE: Remove vicam files duplicated in linux-firmware
+-  * [Config] install-arch-headers needs a valid config
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7-rc7
+-    - LP: #1076840
+-    - LP: #1081466
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 21 Nov 2012 06:07:23 -0800
+-
+-linux (3.7.0-3.9) raring; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_X86_CPUFREQ_NFORCE2=y
+-    - LP: #1079900
+-  * Add nfsv3 to nfs-modules udeb
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] SND_OMAP_SOC*=y
+-    - LP: #1019321
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: (no-up) xen/netfront: handle compound page fragments on transmit
+-    - LP: #1078926
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "SAUCE: SECCOMP: audit: always report seccomp violations"
+-    - LP: #1079469
+-  * Revert "SAUCE: omap3 clocks .dev_id = NULL"
+-  * rebase to v3.7-rc6
+-  * SAUCE: script to detect obsolete firmware
+-  * SAUCE: Remove yam files duplicated in linux-firmware
+-  * SAUCE: Remove tehuti files duplicated in linux-firmware
+-  * SAUCE: Remove matrox files duplicated in linux-firmware
+-  * SAUCE: Remove cxgb3 files duplicated in linux-firmware
+-  * SAUCE: Remove r128 files duplicated in linux-firmware
+-  * SAUCE: Remove acenic files duplicated in linux-firmware
+-  * SAUCE: Remove keyspan files duplicated in linux-firmware
+-  * SAUCE: Remove sun files duplicated in linux-firmware
+-  * SAUCE: Remove radeon files duplicated in linux-firmware
+-  * SAUCE: Update bnx2x firmware to 7.8.2.0
+-  * [Config] generic.inclusion-list: econet has disappeared
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * seccomp: forcing auditing of kill condition
+-    - LP: #1079469
+-  * rebase to v3.7-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 20 Nov 2012 12:28:55 -0800
+-
+-linux (3.7.0-2.8) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "overlayfs: disable until FTBS is fixed"
+-  * Revert "ubuntu: overlayfs"
+-  * Revert "ubuntu: AUFS"
+-  * ubuntu: overlayfs -- overlayfs: add statfs support
+-  * ubuntu: overlayfs -- ovl: switch to __inode_permission()
+-  * ubuntu: overlayfs -- overlayfs: copy up i_uid/i_gid from the underlying
+-    inode
+-    - LP: #944386
+-  * ubuntu: AUFS (no-squash): basic framework and update machinary
+-  * ubuntu: AUFS (no-squash) -- aufs3-base.patch
+-  * ubuntu: AUFS (no-squash) -- aufs3-standalone.patch
+-  * ubuntu: AUFS: aufs-update -- follow the uapi header changes
+-  * ubuntu: AUFS -- update to f2873474324d0a31af4340554b9715f51331bc7f
+-  * ubuntu: AUFS (no-squash) -- reenable
+-    - LP: #1079193
+-
+-  [ Erez Zadok ]
+-
+-  * ubuntu: overlayfs -- overlayfs: implement show_options
+-
+-  [ Miklos Szeredi ]
+-
+-  * ubuntu: overlayfs -- vfs: add i_op->dentry_open()
+-  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
+-  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
+-  * ubuntu: overlayfs -- overlay filesystem
+-  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
+-  * ubuntu: overlayfs -- vfs: export __inode_permission() to modules
+-
+-  [ Neil Brown ]
+-
+-  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
+-
+-  [ Robin Dong ]
+-
+-  * ubuntu: overlayfs -- overlayfs: fix possible leak in ovl_new_inode
+-  * ubuntu: overlayfs -- overlayfs: create new inode in ovl_link
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 15 Nov 2012 13:35:12 +0000
+-
+-linux (3.7.0-1.7) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Drop dependency on libaudit-dev
+-    Its a universe package which causes an FTBS on the builders.
+-    libaudit-dev is not strictly required for the perf tools build.
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 14 Nov 2012 10:08:13 -0700
+-
+-linux (3.7.0-1.6) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enforce -- switch CONFIG_NVRAM to more readable form
+-  * [Config] better encode the CONFIG_NVRAM constaint
+-  * enforcer -- fix debugging output
+-
+-  [ Ben Collins ]
+-
+-  * [Config] Add custom_override rule to allow for alternate kernel
+-    file/install
+-  * [Config] Use SRCPKGNAME as prefix for indep linux headers package
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Dropped armel
+-  * Drop highbank from ABI fetch list
+-  * [Config] Use dh_prep instead of 'dh_clean -k'
+-  * [Config] Build depend on libaudit-dev, libunwind8-dev for tools
+-  * [Config] Document binary-indep dependency chain
+-  * rebase to v3.7-rc5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7-rc5
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 13 Nov 2012 07:13:37 -0500
+-
+-linux (3.7.0-0.5) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_AMD_IOMMU_V2=m
+-    - LP: #1071520
+-  * [Config] CONFIG_MTD_ONENAND_SIM=n for armel
+-    Fixes FTBS
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Nov 2012 15:45:39 -0500
+-
+-linux (3.7.0-0.4) raring; urgency=low
+-
+-  [ Ben Collins ]
+-
+-  * [Config] Update enforce rule for CONFIG_NVRAM to better suit flavours
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] do_tools=false for arm
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Nov 2012 05:39:51 -0700
+-
+-linux (3.7.0-0.3) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_DRM_EXYNOS_HDMI=n for armhf
+-  * [Config] CONFIG_MTD_NAND_DOCG4=n for armel/armhf
+-  * [Config] Drop highbank harder
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 07 Nov 2012 18:11:45 +0000
+-
+-linux (3.7.0-0.2) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] add fs/udf to linux-image to support DVD/CD formats in virtual
+-    instances
+-    - LP: #1066921
+-  * [Config] drop highbank builds
+-
+-  [ Jeremy Kerr ]
+-
+-  * SAUCE: efivarfs: Implement exclusive access for {get, set}_variable
+-    - LP: #1063061
+-
+-  [ Leann Ogasawara ]
+-
+-  * Reinstate dropped.txt from Ubuntu-3.7.0-0.1-rc1
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Dropped powerpc/ppc64 in favour of the community kernel
+-  * [Config] CONFIG_MODULE_SIG=y for amd64,i386, and highbank
+-  * rebase to v3.7-rc4
+-  * SAUCE: MODSIGN: Emit error for incorrectly signed module
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7-rc4
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 05 Nov 2012 05:35:41 -0700
+-
+-linux (3.7.0-0.1) raring; urgency=low
+-
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7-rc3
+-    - LP: #1056078
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7-rc2
+-    - LP: #1060729
+-    - LP: #1059523
+-    - LP: #1006690
+-    - LP: #1049623
+-    - LP: #1046512
+-    - LP: #1052499
+-    - LP: #1037642
+-    - LP: #559939
+-    - LP: #1052460
+-    - LP: #939161
+-    - LP: #1046734
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 02 Oct 2012 08:13:07 -0600
+-
+-linux (3.6.0-0.1) UNRELEASED; urgency=low
+-
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6-rc7
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6-rc6
+-    - LP: #1000424
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6-rc5
+-    - LP: #1040077
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6-rc4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6-rc3
+-    - LP: #1038651
+-    - LP: #1034779
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 24 Jul 2012 06:37:09 -0700
+-
+-linux (3.5.0-6.6) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_INET6_XFRM_MODE_ROUTEOPTIMIZATION enable IPv6
+-    experimental features
+-  * SAUCE: highbank -- export clock functions for modules
+-  * [Config] highbank -- reenable CONFIG_TOUCHSCREEN_W90X900
+-  * [Config] highbank -- renenable CONFIG_SERIO_AMBAKMI
+-  * [Config] highbank -- reenable CONFIG_RFKILL_GPIO
+-  * [Config] highbank -- reenable CONFIG_MMC_SDHCI_PXAV3
+-  * [Config] highbank -- reenable CONFIG_MMC_SDHCI_PXAV3
+-  * [Config] highbank -- reenable CONFIG_KEYBOARD_SAMSUNG
+-  * [Config] highbank -- reenable CONFIG_FB_ARMCLCD
+-  * [Config] highbank -- reenable CONFIG_DW_DMAC
+-  * [Config] highbank -- reenable CONFIG_USB_R8A66597_HCD
+-  * [Config] highbank -- reenable CONFIG_USB_MV_UDC
+-  * [Config] highbank -- reenable CONFIG_USB_DWC3
+-  * [Config] highbank -- reenable CONFIG_SATA_MV
+-  * [Config] highbank -- reenable CONFIG_PATA_ARASAN_CF
+-  * [Config] highbank -- CONFIG_CAN_C_CAN_PLATFORM
+-  * [Config] highbank -- reenable CONFIG_MMC_ARMMMCI
+-  * [Config] highbank -- reenable CONFIG_SERIAL_AMBA_PL010
+-  * [Config] highbank -- reenable CONFIG_ATMEL_PWM
+-  * [Config] highbank -- enable CONFIG_CHECKPOINT_RESTORE
+-  * [Config] highbank -- enable CONFIG_EXPERT
+-  * [Config] highbank -- enable CONFIG_CHECKPOINT_RESTORE
+-  * [Config] enable CONFIG_USB_DYNAMIC_MINORS
+-  * [Config] enable CONFIG_USB_EHCI_TT_NEWSCHED
+-  * [Config] enable CONFIG_USB_ETH_EEM
+-  * [Config] enable CONFIG_USB_HCD_BCMA/CONFIG_USB_HCD_SSB
+-  * [Config] disable CONFIG_USB_M66592
+-  * [Config] enable CONFIG_USB_NET2272
+-  * [Config] enable CONFIG_USB_R8A66597
+-  * [Config] annotate: CONFIG_USB_OMAP not required for our h/w
+-  * [Config] set CONFIG_USB_MUSB_HDRC=m for omap
+-  * [Config] annotate: CONFIG_USB_G_MULTI fix rule
+-  * [Config] CONFIG_USB_GPIO_VBUS=m for OMAP
+-  * [Config] Enable CONFIG_DRM_AST/_CIRRUS_QEMU/_MGAG200
+-  * [Config] sync configuration armhf omap -> armel omap
+-  * [Config] annotate: CONFIG_IIO triggers build failures on OMAP4
+-  * [Config] disable CONFIG_OMAP_IOVMM is deprecated
+-
+-  [ Bryan Wu ]
+-
+-  * [Config] change default IO scheduler from CFQ to Deadline
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Config] Temporarily disable CONFIG_MV643XX_ETH on powerpc"
+-  * [Config] Disable CONFIG_MOUSE_INPORT
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: firmware: Update bnx2x to current firmware version 7.2.51
+-  * [Config] Add bnx2x firmware to nic-modules udeb
+-  * SAUCE: Add script to convert firmware to ihex format
+-  * SAUCE: firmware: Upgrade bnx2 to current versions
+-  * [Config] Add tigon firmware to nic-modules udeb
+-  * [Config] CONFIG_EARLY_PRINTK_DBGP=y
+-    - LP: #1026761
+-  * SAUCE: Remove redundant cis firmware
+-  * SAUCE: Remove redundant emi26 firmware
+-  * SAUCE: Remove redundant ttusb-budget firmware
+-  * SAUCE: Remove redundant sun/cassini firmware
+-  * SAUCE: Remove redundant ositech/Xilinx7OD firmware
+-  * SAUCE: Remove redundant 3com/typhoon.bin firmware
+-  * SAUCE: Remove redundant yamaha/ds1 firmware
+-  * SAUCE: Remove redundant keyspan_pda firmware
+-  * rebase to v3.5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5
+-    - LP: #1027828
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 Jul 2012 05:57:04 -0700
+-
+-linux (3.5.0-5.5) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] annotations: initial import of configuration annotations
+-
+-  [ Bryan Wu ]
+-
+-  * [Config] enforcer -- add CONFIG_I2C_DESIGNWARE_PLATFORM enforce checker
+-
+-  [ Leann Ogasawara ]
+-
+-  * Rebase to v3.5-rc7
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Bluetooth: btusb: Add vendor specific ID (0a5c:21f4) BCM20702A0
+-    - LP: #1010281
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] enable CONFIG_I2C_HELPER_AUTO for all flavours as policy
+-    expects
+-  * [Config] CONFIG_I2O_CONFIG_OLD_IOCTL=n
+-  * [Config] CONFIG_BRIDGE_EBT_ULOG=n
+-  * [Config] CONFIG_IP_NF_QUEUE=n
+-  * [Config] CONFIG_MTD_DOC2000=n
+-  * [Config] CONFIG_PRINT_QUOTA_WARNING=n
+-  * [Config] CONFIG_PRISM54=n
+-  * [Config] CONFIG_SCx200_I2C=n
+-  * [Config] CONFIG_USB_ANNOUNCE_NEW_DEVICES=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5-rc7
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 Jul 2012 15:38:41 -0700
+-
+-linux (3.5.0-4.4) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] getabis should be extracting all packages
+-    - LP: #1021174
+-  * [Config] getabis -- series uses linux-image-extra
+-    - LP: #1021174
+-  * rebase to v3.5-rc6
+-
+-  [ Bryan Wu ]
+-
+-  * [Config] built-in CONFIG_MICREL_PHY as other PHY drivers for all
+-    flavours
+-  * [Config] sync CONFIG_MOUSE_PS2_ config for all flavours
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_RT2800USB_RT35XX and CONFIG_RT2800USB_RT53XX
+-    - LP: #1019561
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] SND_OMAP_SOC, SND_OMAP_SOC_MCBSP and SND_OMAP_SOC_OMAP3_BEAGLE =y
+-    - LP: #1019321
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: (pre-up) net: dont use __netdev_alloc_skb for bounce buffer
+-    - LP: #1018456
+-  * (config) Disable ACPI_PROCFS_POWER
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_ACPI_BGRT=y
+-  * Extract firmware module info during getabi
+-    - LP: #1021174
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 09 Jul 2012 08:50:20 -0700
+-
+-linux (3.5.0-3.3) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_MEMTEST=y
+-    - LP: #1004535
+-  * [Config] config-check: add support for a cut operation
+-  * [Config] enforcer -- switch to cut where appropriate
+-
+-  [ Leann Ogasawara ]
+-
+-  * Rebase to v3.5-rc5
+-  * [Config] Updateconfigs after rebase to v3.5-rc5
+-
+-  [ Luis Henriques ]
+-
+-  * SAUCE: ocfs2: Fix NULL pointer dereferrence in
+-    __ocfs2_change_file_space
+-    - LP: #1006012
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: (drop after 3.5) drm/i915: ignore pipe select bit when checking
+-    for LVDS register initialization
+-    - LP: #1012800
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5-rc5
+-    - LP: #1013183
+-    - LP: #1017017
+-    - LP: #884652
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 02 Jul 2012 06:41:58 -0700
+-
+-linux (3.5.0-2.2) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.5-rc4
+-
+-  [ Arend van Spriel ]
+-
+-  * SAUCE: (drop after 3.5) brcmsmac: fix NULL pointer crash in
+-    brcms_c_regd_init()
+-    - LP: #950320
+-
+-  [ Bryan Wu ]
+-
+-  * [Config] Sync CONFIG_CGROUP_MEM_RES_CTLR_SWAP for ARM
+-
+-  [ Chris J Arges ]
+-
+-  * PACKAGING: add .gnu_debuglink sections to .ko files
+-    - LP: #669641
+-
+-  [ Leann Ogasawara ]
+-
+-  * d-i: Add hid-generic to input-modules
+-    - LP: #1017879
+-
+-  [ Ming Lei ]
+-
+-  * SAUCE: Revert "mmc: omap_hsmmc: Enable Auto CMD12"
+-    - LP: #1017717, #225
+-
+-  [ Paolo Pisati ]
+-
+-  * SAUCE: Revert "Fix OMAP EHCI suspend/resume failure (i693)"
+-    - LP: #1017718
+-  * [Config] Disable generic USB_EHCI_HCD_PLATFORM on omap3
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: (drop after 3.5) brcm80211: smac: don't set up tx power limits
+-    during initialization
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: always set channel specified
+-    by mac80211
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: remove unused code for 40MHz
+-    channels
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: clean up channel.c
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: inform mac80211 of the X2
+-    regulatory domain
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: enable/disable radio on
+-    regulatory updates
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: use mac80211 channel data for
+-    tx power limits
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: don't validate channels
+-    against internal regulatory data
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: use current regulatory domain
+-    when checking whether OFDM is allowed
+-    - LP: #950320
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enable CONFIG_CGROUPS for highbank
+-    - LP: #1014692
+-  * [Config] FB_OMAP*=y and PANEL_TFP410=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 26 Jun 2012 06:21:05 -0700
+-
+-linux (3.5.0-1.1) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] highbank -- enable CONFIG_RFKILL=y and CONFIG_CAN=m
+-
+-  [ Leann Ogasawara ]
+-
+-  * Rebase to v3.5-rc1
+-  * [Config] Remove USB_DEVICEFS from the config enforcer
+-  * [Config] Updateconfigs after rebase to v3.5-rc1
+-  * [Config] Temporarily disable CONFIG_MACH_NOKIA_RX51 on arm
+-  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EETI on arm
+-  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EGALAX on arm
+-  * [Config] Temporarily disable CONFIG_EZX_PCAP on arm
+-  * [Config] Temporarily disable CONFIG_LIS3L02DQ on arm
+-  * [Config] Temporarily disable CONFIG_TI_CPSW on arm
+-  * [Config] Temporarily disable CONFIG_GPIO_EM on arm
+-  * [Config] Temporarily disable CONFIG_SERIAL_8250_EM on armhf
+-  * [Config] Temporarily disable CONFIG_STMMAC_ETH on armhf
+-  * [Config] Temporarily disable CONFIG_HW_RANDOM_ATMEL on armhf
+-  * Rebase to v3.5-rc2
+-  * [Config] Updateconfigs after rebase to v3.5-rc2
+-  * [Config] Temporarily disable CONFIG_MV643XX_ETH on powerpc
+-  * Rebase to v3.5-rc3
+-  * [Config] Updateconfigs after rebase to v3.5-rc3
+-
+-  [ Paul Mundt ]
+-
+-  * SAUCE: fix bug.h's inclusion of kernel.h
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: Fix compile failures of dm-raid45
+-  * [Config] Enable dm-raid45
+-  * Move dependency on crda to extra package
+-    - LP: #657901
+-  * SAUCE: Mask CR4 writes on older Xen hypervisors
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5-rc3
+-    - LP: #993162
+-    - LP: #925577
+-  * rebase to v3.5-rc2
+-  * rebase to v3.5-rc1
+-    - LP: #955892
+-    - LP: #978038
+-    - LP: #987371
+-    - LP: #929545
+-    - LP: #942316
+-    - LP: #903853
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 08 Jun 2012 14:28:46 -0700
+-
+-linux (3.4.0-5.11) quantal-proposed; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable CONFIG_ARM_LPAE
+-    - LP: #1009061
+-
+-  [ Oleksij Rempel ]
+-
+-  * SAUCE: b43: do not call ieee80211_unregister_hw if we are not registred
+-    - LP: #1008905
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] omap3: MFD_OMAP_USB_HOST is usb host in omap2+.
+-    - LP: #1009061
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 05 Jun 2012 08:06:28 -0700
+-
+-linux (3.4.0-4.10) quantal; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Temporarily disable ABI and module check
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 04 Jun 2012 20:27:31 -0700
+-
+-linux (3.4.0-4.9) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] fix config split to avoid the shared config
+-  * [Config] updateconfigs following split config fix
+-  * [Config] linux-image-extras needs full postinst
+-  * [Config] CONFIG_BLK_DEV_NVME commonise across architectures
+-  * [Config] CONFIG_HP_WATCHDOG enable as module
+-  * [Config] CONFIG_PDC_ADMA is not boot essential
+-  * [Config] CONFIG_XEN_ACPI_PROCESSOR should be enabled on x86
+-  * [Config] CONFIG_VT6655/CONFIG_VT6656=m
+-  * [Config] CONFIG_TRANZPORT=m commonise
+-  * [Config] CONFIG_R3964=m commonise
+-  * [Config] CONFIG_SCSI_DH=m commonise
+-  * [Config] CONFIG_SCSI_IBMVSCSIS=m commonise
+-  * [Config] CONFIG_AMD_PHY=y phys are not autoloadable
+-  * [Config] CONFIG_SCSI_QLA_ISCSI=m commonise
+-  * [Config] CONFIG_SCSI_SPI_ATTR=m commonise
+-  * [Config] CONFIG_USB_SN9C102 is deprecated disable
+-  * [Config] CONFIG_USB_SI470X=m commonise
+-  * [Config] CONFIG_USB_ET61X251=m commonise
+-  * [Config] CONFIG_RTS_PSTOR=m commonise
+-  * [Config] CONFIG_SCANLOG=m commonise
+-  * [Config] CONFIG_SCSI_SYM53C8XX_2=m commonise
+-  * [Config] CONFIG_SM_FTL=m commonise
+-  * [Config] CONFIG_SOLO6X10=m commonise
+-  * [Config] CONFIG_SND_PCM_OSS=n using pulseaudio emulation instead
+-  * [Config] CONFIG_SPI_DESIGNWARE=m commonise
+-  * [Config] CONFIG_SPI_SPIDEV=m commonise
+-  * [Config] CONFIG_TABLET_USB_WACOM=m commonise
+-  * [Config] CONFIG_TPS65010=m commonise
+-  * [Config] CONFIG_STE10XP=y commonise
+-  * [Config] CONFIG_X25_ASY=m commonise
+-  * [Config] CONFIG_USB_MON=m commonise
+-  * [Config] CONFIG_VME_BUS=m commonise
+-  * [Config] CONFIG_W35UND=m commonise
+-  * [Config] -CONFIG_TCG_TPM=y commonise
+-  * [Config] highbank -- commonise filesystems
+-  * [Config] highbank -- commonise subsystems
+-  * [Config] highbank -- commonise network protocols
+-  * [Config] highbank -- commonise input drivers
+-  * [Config] highbank -- commonise CRYPTO options
+-  * [Config] highbank -- commonise HID options
+-  * [Config] highbank -- commonise sensors options
+-  * [Config] highbank -- commonise EXPORTFS/FHANDLE
+-  * [Config] highbank -- commonise CONFIG_CRYPTO_LZO
+-  * [Config] highbank -- commonise ENCRYPTED_KEYS
+-  * [Config] highbank -- commonise CONFIG_ATALK
+-  * [Config] highbank -- commonise INET/INET6
+-  * [Config] highbank -- commonise NLS
+-  * [Config] highbank -- commonise BLK/CHR
+-  * [Config] highbank -- CONFIG_EXT2_FS=y boot essential on highbank
+-  * [Config] highbank -- commonise INET/INET6 part 2
+-  * [Config] highbank -- commonise PHY settings
+-  * [Config] highbank -- commonise CRC settings
+-  * [Config] highbank -- commonise BINFMT settings
+-  * [Config] highbank -- commonise DM settings
+-  * [Config] highbank -- commonise RTC_DRV settings
+-  * [Config] highbank -- commonise KEYBOARD/MOUSE settings
+-  * [Config] highbank -- commonise USB settings
+-  * [Config] highbank -- commonise GPIO settings
+-  * [Config] highbank -- commonise I2C settings
+-  * [Config] highbank -- commonise numerous subsystem selectors
+-  * [Config] highbank -- commonise A-C modules missmatches
+-  * [Config] highbank -- commonise D-F modules missmatches
+-  * [Config] CONFIG_AUDIT_LOGINUID_IMMUTABLE incompatible with upstart
+-  * [Config] highbank -- commonise G-I modules missmatches
+-  * [Config] highbank -- commonise J-L modules missmatches
+-  * [Config] highbank -- commonise M modules missmatches
+-  * [Config] highbank -- commonise N-P modules missmatches
+-  * [Config] highbank -- commonise Q-R modules missmatches
+-  * [Config] highbank -- commonise S modules missmatches -- part 1
+-  * [Config] highbank -- commonise S modules missmatches -- part 2
+-  * [Config] highbank -- commonise T modules missmatches
+-  * [Config] highbank -- commonise U-Z modules missmatches
+-
+-  [ Ike Panhc ]
+-
+-  * [Config] add highbank flavour
+-    - LP: #1000831
+-
+-  [ Mark Langsdorf ]
+-
+-  * SAUCE: arm highbank: add support for pl320-ipc driver
+-    - LP: #1000831
+-
+-  [ Rob Herring ]
+-
+-  * SAUCE: input: add a key driver for highbank
+-    - LP: #1000831
+-  * SAUCE: ARM: highbank: Add smc calls to enable/disable the L2
+-    - LP: #1000831
+-  * SAUCE: force DMA buffers to non-bufferable on highbank
+-    - LP: #1000831
+-  * SAUCE: net: calxedaxgmac: fix net timeout recovery
+-    - LP: #1000831
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_IWLWIFI_EXPERIMENTAL_MFP=n
+-  * [Config] CONFIG_PCI_REALLOC_ENABLE_AUTO=y
+-  * [Config] CONFIG_CIFS_EXPERIMENTAL has disappeared
+-  * [Config] Homogenize CIFS configs across all arches
+-  * [Config] armhf should not be skipabi or skipmodules
+-    - LP: #1006913
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 04 Jun 2012 05:52:49 -0700
+-
+-linux (3.4.0-3.8) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] include include/generated/compile.h
+-    - LP: #942569
+-  * [Config] fix up postinst to ensure we know which error is which
+-    - LP: #1002388
+-
+-  [ Herton Ronaldo Krzesinski ]
+-
+-  * SAUCE: async_populate_rootfs: fix build warnings
+-    - LP: #1003417
+-
+-  [ John Johansen ]
+-
+-  * Revert "SAUCE: AppArmor: Add the ability to mediate mount"
+-  * SAUCE: apparmor: Add the ability to mediate mount
+-  * SAUCE: AppArmor: basic networking rules
+-  * SAUCE: apparmor: fix profile lookup for unconfined
+-    - LP: #978038, #987371
+-  * SAUCE: apparmor: fix long path failure due to disconnected path
+-    - LP: #955892
+-
+-  [ Mario Limonciello ]
+-
+-  * SAUCE: dell-laptop: rfkill blacklist Dell XPS 13z, 15
+-    - LP: #901410
+-
+-  [ Stefan Bader ]
+-
+-  * (config) Built-in xen-acpi-processor
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_NET_DSA=m
+-    - LP: #1004148
+-  * [Config] Ensure CONFIG_XEN_ACPI_PROCESSOR=y for amd64
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 25 May 2012 11:38:33 -0700
+-
+-linux (3.4.0-3.7) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] drop the virtual flavour in favour of a split generic et al
+-  * [Config] enforcer -- drop IDLE enforcement
+-  * [Config] enable CONFIG_SCSI_VIRTIO=m for amd64
+-  * [Config] updateconfigs following removal of -virtual
+-
+-  [ Leann Ogasawara ]
+-
+-  * Rebase to v3.4
+-
+-  [ Seth Forshee ]
+-
+-  * [Config] disable CONFIG_B43_BCMA_EXTRA
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Check for extras when building udebs
+-  * [Config] Collapsed generic-pae into generic [i386]
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 May 2012 07:23:47 -0700
+-
+-linux (3.4.0-2.6) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: overlayfs -- overlayfs: update touch_atime() usage"
+-  * Revert "ubuntu: overlayfs -- overlayfs: switch from d_alloc_root() to
+-    d_make_root()"
+-  * Revert "ubuntu: overlayfs -- overlayfs: follow header cleanup"
+-  * Revert "ubuntu: overlayfs -- overlayfs: apply device cgroup and
+-    security permissions to overlay files"
+-  * Revert "ubuntu: overlayfs -- fs: limit filesystem stacking depth"
+-  * Revert "ubuntu: overlayfs -- overlay: overlay filesystem documentation"
+-  * Revert "ubuntu: overlayfs -- overlayfs: implement show_options"
+-  * Revert "ubuntu: overlayfs -- overlayfs: add statfs support"
+-  * Revert "ubuntu: overlayfs -- overlay filesystem"
+-  * Revert "ubuntu: overlayfs -- vfs: introduce clone_private_mount()"
+-  * Revert "ubuntu: overlayfs -- vfs: export do_splice_direct() to modules"
+-  * Revert "ubuntu: overlayfs -- vfs: add i_op->open()"
+-  * Revert "ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()"
+-  * ubuntu: overlayfs -- overlayfs: add statfs support
+-  * ubuntu: overlayfs -- inode_only_permission: export inode level
+-    permissions checks
+-  * ubuntu: overlayfs -- overlayfs: switch to use inode_only_permissions
+-
+-  [ Erez Zadok ]
+-
+-  * ubuntu: overlayfs -- overlayfs: implement show_options
+-
+-  [ Miklos Szeredi ]
+-
+-  * ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()
+-  * ubuntu: overlayfs -- vfs: add i_op->open()
+-  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
+-  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
+-  * ubuntu: overlayfs -- overlay filesystem
+-  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
+-
+-  [ Neil Brown ]
+-
+-  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
+-
+-  [ Robin Dong ]
+-
+-  * ubuntu: overlayfs -- overlayfs: fix possible leak in ovl_new_inode
+-  * ubuntu: overlayfs -- overlayfs: create new inode in ovl_link
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] perarch and indep tools builds need separate build directories
+-  * Prevent upgrading a non-PAE CPU
+-  * perf is not parallel build safe
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 16 May 2012 08:43:18 -0700
+-
+-linux (3.4.0-2.5) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] perarch and indep tools builds need separate build directories
+-
+-  [ Tim Gardner ]
+-
+-  * Prevent upgrading a non-PAE CPU
+-  * [Config] build debug
+-  * [Config] perf tools are not parallel build safe
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 15 May 2012 11:37:53 -0700
+-
+-linux (3.4.0-2.4) quantal; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: fsam7400: use UMH_WAIT_PROC consistently"
+-  * Revert "ubuntu: fsam7400 select CHECK_SIGNATURE and depend on X86"
+-  * Revert "ubuntu: fsam7400: Depend on CHECK_SIGNATURE"
+-  * Revert "ubuntu: fsam7400 -- Cleanup Makefile"
+-  * Revert "ubuntu: fsam7400 -- kill switch for Fujitsu Siemens Amilo M
+-    7400"
+-  * Revert "ubuntu: omnibook: fix source file newline"
+-  * Revert "ubuntu: omnibook -- update BOM"
+-  * Revert "SAUCE: Make CONFIG_{OMNIBOOK, AVERATEC_5100P, PACKARDBELL_E5}
+-    depend on X86"
+-  * Revert "ubuntu: omnibook -- Added missing BOM file"
+-  * Revert "ubuntu: omnibook -- support Toshiba (HP) netbooks"
+-  * Revert "ubuntu: nx-emu - i386: mmap randomization for executable
+-    mappings"
+-  * Revert "SAUCE: disable_nx should not be in __cpuinitdata section for
+-    X86_32"
+-  * Revert "ubuntu: nx-emu - i386: NX emulation"
+-  * Revert "ubuntu: rfkill drivers -- version 1.3"
+-  * Temporarily disable module check
+-  * [Config] Remove CONFIG_FSAM7400
+-  * [Config] Remove CONFIG_OMNIBOOK
+-  * [Config] Update configs
+-  * Rebase to v3.4-rc7
+-  * SAUCE: genirq: export handle_edge_irq() and irq_to_desc()
+-
+-  [ Tim Gardner ]
+-
+-  * Updated generic-pae description
+-  * Rebase to v3.4-rc6
+-  * install-tools depends on build targets
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * kconfig: in debug mode some 0 length message prints occur
+-  * rebase to v3.4-rc7
+-  * rebase to v3.3-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 14 May 2012 08:22:56 -0700
+-
+-linux (3.4.0-1.3) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] control.stub is an intermediate product not a dependancy
+-    - LP: #992414
+-
+-  [ Leann Ogasawara ]
+-
+-  * remove i386 generic from getabis
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) b43: only reload config after successful initialization
+-    - LP: #950295
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 May 2012 09:48:14 -0700
+-
+-linux (3.4.0-1.2) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] add build depends for flex, bison and pkg-config
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 01 May 2012 13:15:41 +0100
+-
+-linux (3.4.0-1.1) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: overlayfs -- overlayfs: apply device cgroup and security
+-    permissions to overlay files
+-    - LP: #915941, #918212
+-    - CVE-2012-0055
+-
+-  [ Leann Ogasawara ]
+-
+-  * Open Q
+-  * Rebase to v3.4-rc5
+-  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EETI on arm
+-  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EGALAX on arm
+-  * [Config] Temporarily disable CONFIG_EZX_PCAP on arm
+-  * [Config] Temporarily disable CONFIG_MFD_OMAP_USB_HOST on arm
+-  * [Config] Temporarily disable CONFIG_LIS3L02DQ on arm
+-  * [Config] Temporarily disable CONFIG_USB_EHCI_HCD_PLATFORM on arm
+-  * [Config] Temporarily disable CONFIG_TI_CPSW on arm
+-  * [Config] Temporarily disable CONFIG_AX88796 on arm
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * vfs: pass struct path to __dentry_open()
+-  * vfs: add i_op->open()
+-  * vfs: export do_splice_direct() to modules
+-  * vfs: introduce clone_private_mount()
+-  * overlay filesystem
+-  * overlayfs: add statfs support
+-  * overlayfs: implement show_options
+-  * overlay: overlay filesystem documentation
+-  * fs: limit filesystem stacking depth
+-  * overlayfs: follow header cleanup
+-  * overlayfs: switch from d_alloc_root() to d_make_root()
+-  * overlayfs: update touch_atime() usage
+-  * rebase to v3.4-rc5
+-    - LP: #950490
+-  * rebase to v3.4-rc4
+-  * rebase to v3.4-rc3
+-  * rebase to v3.4-rc2
+-  * rebase to v3.4-rc1
+-  * rebase to v3.3
+-  * rebase to v3.3-rc7
+-  * rebase to v3.3-rc6
+-  * rebase to v3.3-rc5
+-  * rebase to v3.3-rc4
+-    - LP: #900802
+-    - LP: #930842
+-  * rebase to v3.3-rc3
+-    - LP: #924320
+-    - LP: #923316
+-    - LP: #923409
+-    - LP: #918254
+-  * rebase to v3.3-rc2
+-  * rebase to v3.3-rc1
+-    - LP: #795823
+-    - LP: #909419
+-    - LP: #910792
+-    - LP: #878701
+-    - LP: #724831
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 25 Jan 2012 06:50:04 -0800
+-
+-linux (3.2.0-10.18) precise; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: ecryptfs: Print inode on metadata error
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "proc: enable writing to /proc/pid/mem"
+-    - LP: #919115
+-    - CVE-2012-0056
+-  * (pre-stable) ALSA: HDA: Use LPIB position fix for Macbook Pro 7, 1
+-    - LP: #909419
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 24 Jan 2012 10:15:12 +0000
+-
+-linux (3.2.0-10.17) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: overlayfs -- fs: limit filesystem stacking depth"
+-  * Revert "SAUCE: overlayfs -- overlay: overlay filesystem documentation"
+-  * Revert "SAUCE: overlayfs -- overlayfs: implement show_options"
+-  * Revert "SAUCE: overlayfs -- overlayfs: add statfs support"
+-  * Revert "SAUCE: overlayfs -- overlay filesystem"
+-  * Revert "SAUCE: overlayfs -- vfs: introduce clone_private_mount()"
+-  * Revert "SAUCE: overlayfs -- vfs: export do_splice_direct() to modules"
+-  * Revert "SAUCE: overlayfs -- vfs: add i_op->open()"
+-  * ensure debian/ is not excluded from git by default
+-  * add new scripting to handle buglinks in rebases
+-  * ubuntu: overlayfs -- overlayfs: add statfs support
+-  * ubuntu: overlayfs -- overlayfs: apply device cgroup and security
+-    permissions to overlay files
+-    - LP: #915941, #918212
+-    - CVE-2012-0055
+-
+-  [ Erez Zadok ]
+-
+-  * ubuntu: overlayfs -- overlayfs: implement show_options
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: dmar: disable if ricoh multifunction detected"
+-  * [Config] Disable CONFIG_INTEL_IOMMU_DEFAULT_ON
+-    - LP: #907377, #911236
+-  * [Config] Enable CONFIG_IRQ_REMAP
+-
+-  [ Miklos Szeredi ]
+-
+-  * ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()
+-  * ubuntu: overlayfs -- vfs: add i_op->open()
+-  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
+-  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
+-  * ubuntu: overlayfs -- overlay filesystem
+-  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
+-
+-  [ Neil Brown ]
+-
+-  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) x86/PCI: amd: factor out MMCONFIG discovery
+-    - LP: #647043
+-  * (pre-stable) PNP: work around Dell 1536/1546 BIOS MMCONFIG bug that
+-    breaks USB
+-    - LP: #647043
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 Jan 2012 07:10:08 -0800
+-
+-linux (3.2.0-9.16) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] Enable numerous CONFIG_VIDEO_* cards on ARM
+-  * [Config] pull ARM sound modules =m
+-  * [Config] CONFIG_RTC_DRV_TEST is for testing only
+-  * [Config] CONFIG_USB_DUMMY_HCD is testing only
+-  * [Config] CONFIG_USB_FILE_STORAGE is deprecated
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Config] Temporarily disable CONFIG_CAN_TI_HECC on armel"
+-  * [Config] Enable CONFIG_HW_RANDOM_PASEMI=m
+-  * [Config] Enable CONFIG_MMC_TMIO=m
+-  * [Config] Enable CONFIG_MTD_NAND_FSL_ELBC=m
+-  * [Config] Enable CONFIG_ISI=m
+-  * [Config] Enable CONFIG_MMC=y
+-  * [Config] Enable CONFIG_LIRC_PARALLEL=m
+-  * [Config] Enable CONFIG_MAC_EMUMOUSEBTN=m
+-  * [Config] Enable CONFIG_CHR_DEV_SG=y
+-  * [Config] Enable CONFIG_GPIO_PCA953X=m
+-  * [Config] Enable CONFIG_GPIO_TWL4030=m
+-  * [Config] Enable CONFIG_INET_DIAG=m
+-  * [Config] Enable CONFIG_NLS_ISO8859_1=m
+-  * [Config] Enable CONFIG_NVRAM=m
+-  * [Config] Enable CONFIG_SLIP=m
+-  * [Config] Enable CONFIG_PC300TOO=m
+-  * [Config] Enable CONFIG_TUN=y
+-  * [Config] Enable CONFIG_NET_CLS_CGROUP=m
+-  * [Config] Enable CONFIG_THERMAL=y
+-  * [Config] Enable CONFIG_PPP=y
+-  * [Config] Enable CONFIG_PCI_STUB=m
+-  * Rebase to v3.2.1
+-  * [Config] Enable CONFIG_RTL8192E=m
+-  * [Config] Enable CONFIG_RTS5139=m
+-
+-  [ Stefan Bader ]
+-
+-  * [Config] Make CONFIG_VIRTIO_(NET|BLK)=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ARM: restart: add restart hook to machine_desc record
+-  * ARM: restart: allow platforms more flexibility specifying restart mode
+-  * ARM: restart: move reboot failure handing into machine_restart()
+-  * ARM: restart: remove argument to setup_mm_for_reboot()
+-  * ARM: 7159/1: OMAP: Introduce local common.h files
+-  * ARM: restart: only perform setup for restart when soft-restarting
+-  * ARM: 7189/1: OMAP3: Fix build break in cpuidle34xx.c because of irq
+-    function
+-  * ARM: idmap: populate identity map pgd at init time using .init.text
+-  * ARM: suspend: use idmap_pgd instead of suspend_pgd
+-  * ARM: proc-*.S: place cpu_reset functions into .idmap.text section
+-  * ARM: idmap: use idmap_pgd when setting up mm for reboot
+-  * ARM: head.S: only include __turn_mmu_on in the initial identity mapping
+-  * ARM: SMP: use idmap_pgd for mapping MMU enable during secondary booting
+-  * ARM: 7194/1: OMAP: Fix build after a merge between v3.2-rc4 and ARM
+-    restart changes
+-  * ARM: lib: add call_with_stack function for safely changing stack
+-  * ARM: reset: implement soft_restart for jumping to a physical address
+-  * ARM: stop: execute platform callback from cpu_stop code
+-  * ARM: kexec: use soft_restart for branching to the reboot buffer
+-  * ARM: restart: omap: use new restart hook
+-  * topdown mmap support
+-    - LP: #861296
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Rebase to v3.2.1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 13 Jan 2012 20:32:08 +0100
+-
+-linux (3.2.0-8.15) precise; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable CONFIG_ACPI_PROCFS
+-  * Remove server from getabis
+-  * Temporarily disable module check
+-  * [Config] Disable CONFIG_MTD_TESTS
+-  * [Config] Disable CONFIG_X86_E_POWERSAVER
+-  * [Config] Set CONFIG_ARCNET=m
+-  * [Config] Enable CONFIG_ATM_DUMMY=m
+-  * [Config] Enable CONFIG_BLK_DEV_MD=y
+-  * ubuntu: fsam7400 select CHECK_SIGNATURE and depend on X86
+-  * [Config] Enable CONFIG_BLK_DEV_SD=y
+-  * [Config] Enable CONFIG_BLK_DEV_SR=y
+-  * [Config] Enable CONFIG_BLK_DEV_UB=m
+-  * [Config] Enable CONFIG_COPS=m
+-  * [Config] Enable CONFIG_DVB_USB_EC168=m
+-  * [Config] Enable CONFIG_ENC28J60=m
+-  * [Config] Enable CONFIG_FB_UVESA=m
+-  * [Config] Enable CONFIG_FB_ATY=m
+-  * [Config] Enable CONFIG_BROADCOM_PHY=y
+-  * [Config] Enable CONFIG_CICADA_PHY=y
+-  * [Config] Enable CONFIG_DAVICOM_PHY=y
+-  * [Config] Enable CONFIG_ICPLUS_PHY=y
+-  * [Config] Enable CONFIG_LSI_ET1011C_PHY=y
+-  * [Config] Enable CONFIG_LXT_PHY=y
+-  * [Config] Enable CONFIG_MARVELL_PHY=y
+-  * [Config] Enable CONFIG_NATIONAL_PHY=y
+-  * [Config] Enable CONFIG_QSEMI_PHY=y
+-  * [Config] Enable CONFIG_SMSC_PHY=y
+-  * [Config] Enable CONFIG_VITESSE_PHY=y
+-  * Add 3w-sas to scsi-modules
+-    - LP: #776542
+-
+-  [ Mathieu Trudel-Lapierre ]
+-
+-  * SAUCE: ipv6: make the net.ipv6.conf.all.use_tempaddr sysctl propagate
+-    to interface settings
+-
+-  [ Paolo Pisati ]
+-
+-  * Revert "SAUCE: omap3: beagle: if rev unknown, assume xM revision C"
+-    - LP: #912199
+-  * Revert "SAUCE: omap3: beagle: detect new xM revision B"
+-    - LP: #912199
+-  * Revert "SAUCE: omap3: beaglexm: fix DVI initialization"
+-    - LP: #912199
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Bluetooth: Add support for BCM20702A0 [0a5c:21e3]
+-    - LP: #906832
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 06 Jan 2012 10:02:03 -0800
+-
+-linux (3.2.0-8.14) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_SND_USB_6FIRE
+-    - LP: #912197
+-  * rebase to mainline v3.2 final release
+-  * updateconfigs following rebase to v3.2 final
+-  * ubuntu: AUFS -- add BOM and automated update script
+-  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
+-    - LP: #684666
+-  * ubuntu: AUFS -- update aufs-update to track new locations of headers
+-  * ubuntu: AUFS -- clean up the aufs updater and BOM
+-  * ubuntu: AUFS -- documentation on updating aufs2
+-  * ubuntu: AUFS -- aufs3-base.patch
+-  * ubuntu: AUFS -- aufs3-standalone.patch
+-  * ubuntu: AUFS -- fix undefined __devcgroup_inode_permission
+-  * ubuntu: AUFS -- fix undefined security_path_link
+-  * ubuntu: AUFS -- update to 4cf5db36bcd9748e8e7270022f295f84d1fc2245
+-  * ubuntu: AUFS -- updateconfigs following update
+-  * ubuntu: AUFS -- suppress benign plink warning messages
+-    - LP: #621195
+-  * ubuntu: AUFS -- enable in config and makefile
+-  * ubuntu: AUFS -- disable in favor of overlayfs
+-  * [Config] linux-virtual -- should include the extX modules
+-    - LP: #912308
+-
+-  [ Tyler Hicks ]
+-
+-  * SAUCE: eCryptfs: Improve statfs reporting
+-    - LP: #885744
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to upstream v3.2
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 26 Dec 2011 20:24:30 -0800
+-
+-linux (3.2.0-7.13) precise; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to upstream 3.2-rc7
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 19 Dec 2011 09:14:34 -0800
+-
+-linux (3.2.0-6.12) precise; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to upstream v3.2-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 16 Dec 2011 10:19:02 -0800
+-
+-linux (3.2.0-5.11) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * enforcer -- allow arch and flavour predicates to take lists
+-  * enforcer -- simplify armel/armhf specific options
+-  * enforcer -- fix incorrectly specified flavour matches
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable IRQ_REMAP
+-  * [Config] Enable CONFIG_SENSORS_LM95245=m
+-  * [Config] Enable CONFIG_SENSORS_MAX1668=m
+-  * [Config] Enable CONFIG_SENSORS_NTC_THERMISTOR=m
+-  * [Config] Enable CONFIG_SENSORS_MAX6639=m
+-  * [Config] Enable CONFIG_SENSORS_MAX6642=m
+-  * [Config] Enable CONFIG_SENSORS_LINEAGE=m
+-  * [Config] Enable CONFIG_CRYPTO_SALSA20=m
+-  * [Config] Enable CONFIG_PATA_TOSHIBA=m
+-  * [Config] Enable CONFIG_POHMELFS=m
+-  * [Config] Enable CONFIG_NET_PACKET_ENGINE=y
+-  * [Config] Enable CONFIG_PATA_OPTI=m
+-  * add overlayfs to virtual inclusion list
+-    - LP: #903897
+-  * add veth to virtual inclusion list
+-    - LP: #903897
+-  * SAUCE: resolve WARNING: at drivers/block/floppy.c:2929 do_fd_request
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] DEFAULT_MMAP_MIN_ADDR=32k on arm
+-    - LP: #903346
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_LOCKUP_DETECTOR=y
+-    - LP: #903615
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to upstream 55b02d2f
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 12 Dec 2011 07:08:10 -0800
+-
+-linux (3.2.0-4.10) precise; urgency=low
+-
+-  [ Kyle McMartin ]
+-
+-  * SAUCE: dmar: disable if ricoh multifunction detected
+-    - LP: #894070
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: dell-wmi: Demote unknown WMI event message to pr_debug
+-    - LP: #581312
+-
+-  [ Tim Gardner ]
+-
+-  * Start new release, Bump ABI, rebase to 3.2-rc5
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_SENSORS_AK8975=m
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Sat, 10 Dec 2011 08:57:04 -0700
+-
+-linux (3.2.0-3.9) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: ext4: correct partial write discard size calculation
+-    - LP: #894768
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: x86, microcode, AMD: Restrict microcode reporting"
+-    - LP: #892615
+-
+-  [ Matthew Garrett ]
+-
+-  * SAUCE: pci: Rework ASPM disable code
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86: Fix boot failures on older AMD CPU's
+-    - LP: #892615
+-  * EHCI : Fix a regression in the ISO scheduler
+-    - LP: #899165
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 05 Dec 2011 10:37:36 -0800
+-
+-linux (3.2.0-3.8) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * armhf -- add d-i configuration
+-  * armhf -- disable ABI checks for armhf
+-  * armhf -- add arch to getabis config
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 03 Dec 2011 14:22:52 +0000
+-
+-linux (3.2.0-3.7) precise; urgency=low
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: x86/paravirt: PTE updates in k(un)map_atomic need to be
+-    synchronous, regardless of lazy_mmu mode
+-    - LP: #854050
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.2-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 02 Dec 2011 11:53:56 -0800
+-
+-linux (3.2.0-2.6) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * armhf -- fix omap flavour to build on armhf
+-  * [Config] CONFIG_PATA_MACIO=y to fix MAC qemu boot
+-
+-  [ Borislav Petkov ]
+-
+-  * SAUCE: x86, microcode, AMD: Restrict microcode reporting
+-    - LP: #892615
+-
+-  [ Colin Watson ]
+-
+-  * Add pata_macio to pata-modules
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Prefer crda over wireless-crda
+-  * [Config] Fix virtual inclusion list.
+-    - LP: #897795
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 30 Nov 2011 06:09:35 -0800
+-
+-linux (3.2.0-2.5) precise; urgency=low
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] PANEL_DVI=y
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 28 Nov 2011 09:13:24 -0800
+-
+-linux (3.2.0-2.4) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.2-rc3
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: xen: Do not use pv spinlocks on HVM"
+-  * Revert "fix ERROR: __devcgroup_inode_permission undefined"
+-  * Revert "olpc_dcon_xo_1_5 needs delay.h"
+-  * Revert "olpc_dcon_xo_1 needs delay.h"
+-  * rebase to 6fe4c6d4
+-  * [Config] updateconfigs after rebase to 6fe4c6d4
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Replace wireless-crda with crda,wireless-regdb
+-    - LP: #856421
+-  * [Config] Relax the dependencies on crda
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) HID: bump maximum global item tag report size to 96 bytes
+-    - LP: #724831
+-  * Ubuntu: remove coreutils|fileutils package dependency
+-    - LP: #892814
+-  * iio: iio_event_getfd -- fix ev_int build failure
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Rebase to v3.2-rc3
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 24 Nov 2011 16:20:45 +0000
+-
+-linux (3.2.0-1.3) precise; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Ubuntu: Add ext2 to fs-core-modules
+-    - LP: #893395
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 Nov 2011 20:42:33 -0800
+-
+-linux (3.2.0-1.2) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_NFC and associated devices
+-  * SAUCE: allow brcmsmac and b43 to both build
+-
+-  [ Soren Hansen ]
+-
+-  * Add ixgbe driver to d-i
+-    - LP: #891969
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 Nov 2011 08:33:46 -0800
+-
+-linux (3.2.0-1.1) precise; urgency=low
+-  [ Andy Whitcroft ]
+-
+-  * armhf -- enable armhf and create the first flavours
+-  * SAUCE: ensure root is ready before running usermodehelpers in it
+-  * [Config] enforcer -- ensure CONFIG_FAT_FS is built-in on arm
+-
+-  [ Leann Ogasawara ]
+-
+-  * Temporarily ignore module check
+-  * [Config] Enable PCI_IOV on powerpc
+-  * [Config] Temporarily disable CONFIG_PASEMI_MAC on powerpc
+-  * rebase to v3.2-rc2
+-  * SAUCE: include <linux/export.h> for cpuidle34xx arm build
+-  * SAUCE: include <linux/kernel.h> for linux/mtd/map.h arm build
+-  * SAUCE: include <linux/printk.h> and <stdarg.h> for mmc_core arm build
+-  * SAUCE: select ARM_AMBA if OMAP3_EMU
+-  * [Config] updateconfigs after select ARM_AMBA
+-  * [Config] Temporarily disable CONFIG_KVM_BOOK3S_32 on powerpc
+-  * [Config] Enable CONFIG_EXT2_FS=m
+-  * [Config] Build in CONFIG_SATA_AHCI=y
+-  * Resolve linux-image-extra's install dependency
+-
+-  [ Seth Forshee ]
+-
+-  * [Config] Enable EVENT_POWER_TRACING_DEPRECATED=y for powertop
+-  * SAUCE: (drop after 3.2) Input: ALPS - move protocol information to
+-    Documentation
+-  * SAUCE: (drop after 3.2) Input: ALPS - add protocol version field in
+-    alps_model_info
+-  * SAUCE: (drop after 3.2) Input: ALPS - remove assumptions about packet
+-    size
+-  * SAUCE: (drop after 3.2) Input: ALPS - add support for protocol versions
+-    3 and 4
+-  * SAUCE: (drop after 3.2) Input: ALPS - add semi-MT support for v3
+-    protocol
+-  * SAUCE: (drop after 3.2) Input: ALPS - add documentation for protocol
+-    versions 3 and 4
+-
+-  [ Stefan Bader ]
+-
+-  * [Config] Built-in xen-netfront and xen-blkfront
+-  * Fix build of dm-raid45 and re-enable it
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_USB_XHCI_HCD=y
+-    - LP: #886167
+-  * [Config] CONFIG_R6040=m
+-    - LP: #650899
+-  * SAUCE: Add a new entry (413c:8197) to Bluetooth USB device ID table
+-    - LP: #854399
+-  * [Config] Consolidated amd64 server flavour into generic
+-  * [Config] updateconfigs after rebase to 3.2-rc1
+-  * [Config] Disabled dm-raid4-5
+-  * [Config] Disabled ndiswrapper
+-  * [Config] Disable vt6656
+-  * [Config] exclude ppp-modules for virtual flavour
+-  * [Config] CONFIG_MEMSTICK_R592=m
+-    - LP: #238208
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * CHROMIUM: seccomp_filter: new mode with configurable syscall filters
+-    - LP: #887780
+-  * CHROMIUM: seccomp_filter: add process state reporting
+-    - LP: #887780
+-  * CHROMIUM: seccomp_filter: Document what seccomp_filter is and how it
+-    works.
+-    - LP: #887780
+-  * CHROMIUM: x86: add HAVE_SECCOMP_FILTER and seccomp_execve
+-    - LP: #887780
+-  * CHROMIUM: arm: select HAVE_SECCOMP_FILTER
+-    - LP: #887780
+-  * CHROMIUM: seccomp_filters: move to btrees
+-  * CHROMIUM: enable CONFIG_BTREE
+-  * CHROMIUM: seccomp_filter: kill NR_syscall references
+-  * CHROMIUM: seccomp_filters: guard all ftrace wrapper code
+-  * CHROMIUM: seccomp_filters: clean up warnings; kref mistake
+-  * CHROMIUM: seccomp_filter: remove "skip" from copy and add drop helper
+-  * CHROMIUM: seccomp_filter: allow CAP_SYS_ADMIN management of execve
+-  * CHROMIUM: seccomp_filter: inheritance documentation
+-  * CHROMIUM: seccomp_filter: make inherited filters composable
+-  * CHROMIUM: Fix seccomp_t compile error
+-    - LP: #887780
+-  * CHROMIUM: Fix kref usage
+-    - LP: #887780
+-  * CHROMIUM: enable CONFIG_SECCOMP_FILTER and CONFIG_HAVE_SECCOMP_FILTER
+-  * rebase to v3.2-rc2
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 31 Oct 2011 09:24:39 -0400
+-
+-linux (3.1.0-2.3) precise; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Add postinit and postrm scripts to the extras package
+-    - LP: #882120
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 28 Oct 2011 12:48:33 -0700
+-
+-linux (3.1.0-2.2) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * debian: add locking to protect debian/files from parallel update
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.1
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 19 Oct 2011 07:12:38 -0700
+-
+-linux (3.1.0-1.1) precise; urgency=low
+-
+-  [ Andiry Xu ]
+-
+-  * SAUCE: (drop during 3.2 merge) xHCI: AMD isoc link TRB chain bit quirk
+-    - LP: #872811
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: compcache -- follow changes to bd_claim/bd_release"
+-    - LP: #832694
+-  * Revert "ubuntu: compcache -- version 0.5.3"
+-    - LP: #832694
+-  * [Config] standardise CONFIG_NETFILTER_XT_TARGET_TCPOPTSTRIP=m
+-  * [Config] Enable CONFIG_MACVTAP=m
+-    - LP: #822601
+-  * record the compiler in the ABI and check for inconsistant builds
+-  * [Config] move ECRYPT_FS back to =y for all architectures
+-    - LP: #827197
+-  * [Config] enable CONFIG_DRM_VMWGFX=m
+-    - LP: #698009
+-  * [Config] re-fix ECRYPT_FS=y
+-    - LP: #827197
+-  * enforcer -- ensure we have CONFIG_ECRYPT_FS=y
+-    - LP: #827197
+-  * [Config] dropping compcache configuration options
+-  * [Config] standardise on HZ=250
+-  * SAUCE: headers_install: fix #include "..." usage for userspace
+-    - LP: #824377
+-  * make module-inclusion selection retain the left overs
+-  * add a new linux-image-extras package for virtual
+-
+-  [ Colin Watson ]
+-
+-  * Deliver more Atheros, Ralink, and iwlagn NIC drivers to d-i
+-
+-  [ edwin_rong ]
+-
+-  * SAUCE: Staging: add driver for Realtek RTS5139 cardreader
+-    - LP: #824273
+-
+-  [ Greg Kroah-Hartman ]
+-
+-  * SAUCE: staging: rts5139: add vmalloc.h to some files to fix the build.
+-    - LP: #824273
+-
+-  [ Jesse Sung ]
+-
+-  * SAUCE: Unregister input device only if it is registered
+-    - LP: #839238
+-
+-  [ Jiri Kosina ]
+-
+-  * SAUCE: HID: add MacBookAir4, 2 to hid_have_special_driver[]
+-
+-  [ Joshua V. Dillon ]
+-
+-  * SAUCE: HID: add support for MacBookAir4,2 keyboard.
+-
+-  [ Kees Cook ]
+-
+-  * [Config] enable and enforce SECCOMP_FILTER on x86
+-
+-  [ Keng-Yu Lin ]
+-
+-  * [Config] Enable CONFIG_RTS5139=m on i386/amd64
+-    - LP: #824273
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "ubuntu: overlayfs -- ovl: make lower mount read-only"
+-  * Revert "ubuntu: overlayfs -- fs: limit filesystem stacking depth"
+-  * Revert "ubuntu: overlayfs -- ovl: improve stack use of lookup and
+-    readdir"
+-  * Revert "ubuntu: overlayfs -- ovl: fix overlayfs over overlayfs"
+-  * Revert "ubuntu: overlayfs -- overlayfs: implement show_options"
+-  * Revert "ubuntu: overlayfs -- overlayfs: add statfs support"
+-  * Revert "ubuntu: overlayfs -- overlay filesystem"
+-  * Revert "ubuntu: overlayfs -- overlay: overlay filesystem documentation"
+-  * Revert "SAUCE: ARM: OMAP: Add macros for comparing silicon revision"
+-  * Revert "SAUCE: OMAP: DSS2: check for both cpu type and revision, rather
+-    than just revision"
+-  * Revert "SAUCE: OMAP: DSS2: enable hsclk in dsi_pll_init for OMAP36XX"
+-  * Revert "ubuntu: fsam7400 disable driver"
+-    - LP: #876030
+-  * rebase to v3.1-rc1
+-  * [Config] updateconfigs after rebase to v3.1-rc1
+-  * rebase to v3.1-rc2
+-  * [Config] Updateconfigs after rebase to v3.1-rc2
+-  * ubuntu: Yama - update calls to generic_permission() and
+-    inode->i_op->permission()
+-  * ubuntu: ndiswrapper -- remove netdev_priv macro
+-  * ubuntu: aufs -- Temporarily disable due to build failure
+-  * [Config] Diable INTEL_MID_PTI on armel
+-  * [Config] Temporarily disable CONFIG_FTMAC100 on armel
+-  * [Config] Temporarily disable CONFIG_FTGMAC100 on armel
+-  * [Config] Temporarily disable CONFIG_CAN_TI_HECC on armel
+-  * [Config] Temporarily disable CONFIG_VIDEO_OMAP2_VOUT on armel
+-  * [Config] Set CONFIG_DM_MIRROR=m on amd64, i386, and arm
+-  * [Config] Set CONFIG_DM_MULTIPATH=m on amd64, i386, and arm
+-  * [Config] Set CONFIG_DM_SNAPSHOT=m on amd64, i386, and arm
+-  * [Config] Enable CONFIG_EDAC_AMD8111=m on powerpc
+-  * [Config] Enable CONFIG_EDAC_AMD8131=m on powerpc
+-  * [Config] Enable CONFIG_EDAC_CPC925=m on powerpc
+-  * [Config] Enable CONFIG_EDAC_PASEMI=m on powerpc
+-  * [Config] Enable CONFIG_ECHO=m on powerpc
+-  * [Config] Enable CONFIG_ET131X=m on powerpc
+-  * [Config] Set CONFIG_FB_MATROX=m
+-  * [Config] Enable CONFIG_FB_UDL=m on powerpc
+-  * [Config] Set CONFIG_FB_VIRTUAL=n
+-  * [Config] Enable CONFIG_FB_VGA16=m on powerpc
+-  * [Config] Enable CONFIG_GPIO_MAX732X=m on arm
+-  * [Config] Enable CONFIG_GPIO_PCF857X=m on arm
+-  * [Config] Set CONFIG_HOTPLUG_PCI_FAKE=m
+-  * [Config] Enable CONFIG_HOTPLUG_PCI=y on powerpc
+-  * [Config] Enable CONFIG_HOTPLUG_PCI_CPCI=y on powerpc
+-  * [Config] Enable CONFIG_HP_ILO=m on powerpc-smp
+-  * [Config] Enable CONFIG_I2C_PASEMI=m on powerpc
+-  * [Config] Enable CONFIG_IBM_BSR=m on powerpc
+-  * [Config] Enable CONFIG_IBMVETH=m on powerpc
+-  * [Config] Enable CONFIG_IDE_PHISON=m on powerpc
+-  * [Config] Enable CONFIG_IGB=m on powerpc
+-  * [Config] Enable CONFIG_IIO=m on powerpc
+-  * [Config] Enable CONFIG_INFINIBAND_NES=m
+-  * [Config] Enable CONFIG_IPMI_HANDLER=m on arm
+-  * [Config] Enable CONFIG_IWL3945=m on powerpc
+-  * [Config] Disable CONFIG_KVM_BOOK3S_64
+-  * [Config] Enable CONFIG_LAPBETHER=m on arm
+-  * [Config] Enable CONFIG_LEDS_GPIO=m on powerpc
+-  * [Config] Enable CONFIG_LEDS_CLEVO_MAIL=m all arch's
+-  * [Config] Enable CONFIG_LEDS_PCA9532=m on powerpc
+-  * [Config] Enable CONFIG_LEDS_PCA955X=m on powerpc
+-  * [Config] Enable CONFIG_LEDS_TRIGGER_DEFAULT_ON=m on powerpc
+-  * [Config] Set CONFIG_LEDS_TRIGGER_HEARTBEAT=m on arm and powerpc
+-  * [Config] Set CONFIG_LEDS_TRIGGER_TIMER=m on powerpc
+-  * [Config] Enable CONFIG_LINE6_USB=m on arm and powerpc
+-  * [Config] Enable CONFIG_MEMSTICK=m on arm
+-  * [Config] Enable CONFIG_MTD_AFS_PARTS=m on arm
+-  * [Config] Enable CONFIG_MTD_ALAUDA=m on arm
+-  * [Config] Enable CONFIG_MTD_AR7_PARTS=m on arm
+-  * [Config] Enable CONFIG_MTD_ARM_INTEGRATOR=m on arm
+-  * [Config] Enable CONFIG_MOXA_SMARTIO=m on powerpc
+-  * [Config] Enable CONFIG_MTD_DATAFLASH=m on arm
+-  * [Config] Enable CONFIG_MTD_GPIO_ADDR=m on arm
+-  * [Config] Enable CONFIG_MTD_IMPA7=m on arm
+-  * [Config] Enable CONFIG_MTD_NAND_GPIO=m on arm
+-  * [Config] Enable CONFIG_MTD_NAND_NANDSIM=m on arm
+-  * [Config] Enable CONFIG_MTD_NAND_PASEMI=m on powerpc
+-  * [Config] Enable CONFIG_MTD_NAND_PLATFORM=m on arm
+-  * [Config] Enable CONFIG_MTD_NAND_TMIO=m on arm
+-  * [Config] Enable CONFIG_MTD_SST25L=m on arm
+-  * [Config] Enable CONFIG_NET_CLS_CGROUP=y on arm
+-  * [Config] Enable CONFIG_NET_CLS_FLOW=m on arm
+-  * [Config] Enable CONFIG_NET_CLS_U32=m on arm
+-  * [Config] Enable CONFIG_NET_DCCPPROBE=m on arm
+-  * [Config] Enable CONFIG_NET_SCH_INGRESS=m on arm
+-  * [Config] Enable CONFIG_NET_TCPPROBE=m on arm
+-  * [Config] Enable CONFIG_PASEMI_MAC=m on powerpc
+-  * [Config] Enable CONFIG_PATA_NS87410=m on powerpc
+-  * [Config] Enable CONFIG_I2C_GPIO=m on powerpc64-smp
+-  * [Config] Enable CONFIG_PANEL=m on powerpc
+-  * [Config] Enable CONFIG_PATA_CMD640_PCI=m on powerpc
+-  * SAUCE: x86: reboot: Make Dell Latitude E6520 use reboot=pci
+-    - LP: #833705
+-  * [Config] Add CONFIG_EFI_VARS=y to the enforcer
+-    - LP: #837332
+-  * [Config] Update CONFIG_EFI_VARS enforcer check
+-  * [Config] Add aufs to virtual flavor inclusion list
+-    - LP: #844159
+-  * SAUCE: x86: reboot: Make Dell Optiplex 790 use reboot=pci
+-    - LP: #818933
+-  * SAUCE: x86: reboot: Make Dell Optiplex 990 use reboot=pci
+-    - LP: #768039
+-  * SAUCE: x86: reboot: Make Dell Latitude E6220 use reboot=pci
+-    - LP: #838402
+-  * [Config] Add igbvf to the virtual flavor inclusion list
+-    - LP: #794570
+-  * [Config] Add ixgbevf to the virtual inclusion list
+-    - LP: #872411
+-  * [Config] Transition -generic and -server to be identical
+-  * rebase to v3.1-rc10
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Disable legacy IDE drivers on powerpc
+-
+-  [ Ming Lei ]
+-
+-  * SAUCE: fireware: add NO_MSI quirks for o2micro controller
+-    - LP: #801719
+-  * SAUCE: ata_piix: make DVD Drive recognisable on systems with Intel
+-    Sandybridge chipsets(v2)
+-    - LP: #737388, #782389, #794642
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] Compile-in vfat support for armel
+-    - LP: #853783
+-
+-  [ Randy Dunlap ]
+-
+-  * SAUCE: staging: fix rts5139 depends & build
+-    - LP: #824273
+-
+-  [ Rene Bolldorf ]
+-
+-  * SAUCE: (drop after 3.0) ideapad: Check if acpi already handle backlight
+-    power in 'ideapad_backlight_notify_power' to avoid a page fault
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: (no-up) Input: elantech - Add v3 hardware support
+-    - LP: #681904
+-  * SAUCE: (drop after 3.1) usb_storage: Don't freeze in usb-stor-scan
+-    - LP: #810020
+-
+-  [ Stefan Bader ]
+-
+-  * (config) Package macvlan and macvtap for virtual
+-  * [Config] Force perf to use libiberty for demangling
+-    - LP: #783660
+-  * SAUCE: xen: Do not use pv spinlocks on HVM
+-    - LP: #838026
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Clean up tools rules
+-  * [Config] Package x86_energy_perf_policy and turbostat
+-    - LP: #797556
+-  * rebase to v3.1-rc3
+-  * [Config] Simplify binary-udebs dependencies
+-  * [Config] kernel preparation cannot be parallelized
+-  * [Config] Linearize module/abi checks
+-  * [Config] Linearize and simplify tree preparation rules
+-  * [Config] Build kernel image in parallel with modules
+-  * [Config] Set concurrency for kmake invocations
+-  * [Config] Improve install-arch-headers speed
+-  * [Config] Fix binary-perarch dependencies
+-  * [Config] Removed stamp-flavours target
+-  * [Config] Serialize binary indep targets
+-  * [Config] Use build stamp directly
+-  * [Config] Restore prepare-% target
+-  * rebase to v3.1-rc4
+-  * rebase to v3.1-rc5
+-  * [Config] Disable makedumpfile for i386/amd64
+-  * rebase to v3.1-rc6
+-  * [Config] Fix binary-% build target
+-  * rebase to v3.1-rc7
+-  * rebase to v3.1-rc8
+-  * SAUCE: Add a new entry (413c:8197) to Bluetooth USB device ID table
+-    - LP: #854399
+-  * [Config] Enable ftrace support in the mac80211 layer
+-    - LP: #865171
+-  * rebase to v3.1-rc9
+-  * SAUCE: usb/core/devio.c: Check for printer class specific request
+-    - LP: #872711
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * overlay filesystem
+-  * overlayfs: add statfs support
+-  * overlayfs: implement show_options
+-  * overlay: overlay filesystem documentation
+-  * fs: limit filesystem stacking depth
+-
+-  [ Will Drewry ]
+-
+-  * SAUCE: seccomp_filter: new mode with configurable syscall filters
+-  * SAUCE: seccomp_filter: add process state reporting
+-  * SAUCE: seccomp_filter: Document what seccomp_filter is and how it
+-    works.
+-  * SAUCE: seccomp_filter: add HAVE_SECCOMP_FILTER and seccomp_execve
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.1-rc1
+-  * rebase to v3.1-rc2
+-  * rebase to v3.1-rc3
+-    +CONFIG_BLK_DEV_BSGLIB=y
+-    +CONFIG_BLK_DEV_LOOP_MIN_COUNT=8
+-    -CONFIG_VIDEO_OMAP2_VOUT_VRFB=y
+-  * rebase to v3.1-rc4
+-  * rebase to v3.1-rc5
+-  * rebase to v3.1-rc6
+-  * rebase to v3.1-rc7
+-  * rebase to v3.1-rc8
+-  * rebase to v3.1-rc9
+-  * rebase to v3.1-rc10
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 10 Aug 2011 15:43:38 -0700
+-
+-linux (3.1.0-1.0) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Open P-series
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 10 Aug 2011 13:42:40 -0700
+-
+-linux (3.0.0-8.10) oneiric; urgency=low
+-
+-  [ Adam Jackson ]
+-
+-  * SAUCE: drm/i915/pch: Fix integer math bugs in panel fitting
+-    - LP: #753994
+-
+-  [ John Johansen ]
+-
+-  * [Config] Enable missing IPv6 options
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable config IWLWIFI_DEVICE_SVTOOL
+-    - LP: #819925
+-  * Rebase to 3.0.1
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86, intel, power: Correct the MSR_IA32_ENERGY_PERF_BIAS message
+-  * ALSA: hda - Turn on extra EAPDs on Conexant codecs
+-    - LP: #783582
+-  * KVM: Remove SMEP bit from CR4_RESERVED_BITS
+-    - LP: #796476
+-  * KVM: Add SMEP support when setting CR4
+-    - LP: #796476
+-  * KVM: Mask function7 ebx against host capability word9
+-    - LP: #796476
+-  * KVM: Add instruction fetch checking when walking guest page table
+-    - LP: #796476
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.0.1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 05 Aug 2011 11:32:25 -0700
+-
+-linux (3.0.0-7.9) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Upstream] add local prefix to oss local change_bits"
+-  * Revert "SAUCE: add tracing for user initiated readahead requests"
+-  * Revert "SAUCE: vfs: Add a trace point in the mark_inode_dirty function"
+-  * Revert "SAUCE: Input: ALPS - Enable Intellimouse mode for Lenovo
+-    Zhaoyang E47"
+-  * Revert "SAUCE: fix documentation strings for struct input_keymap_entry"
+-  * Revert "SAUCE: vt -- fix handoff numbering to 1..n and add range checks
+-    (grub)"
+-  * Revert "SAUCE: vt -- fix handoff numbering to 1..n and add range
+-    checks"
+-  * Revert "SAUCE: vt -- allow grub to request automatic vt_handoff"
+-  * Revert "SAUCE: vt -- maintain bootloader screen mode and content until
+-    vt switch"
+-  * [Config] enable CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT=1
+-    - LP: #816035
+-  * ubuntu: Yama: if an underlying filesystem provides a permissions op use
+-    it
+-  * SAUCE: (no-up) add tracing for user initiated readahead requests
+-  * SAUCE: vt -- maintain bootloader screen mode and content until vt
+-    switch
+-  * SAUCE: vt -- allow grub to request automatic vt_handoff
+-
+-  [ Arjan van de Ven ]
+-
+-  * SAUCE: (no-up) vfs: Add a trace point in the mark_inode_dirty function
+-
+-  [ Kees Cook ]
+-
+-  * Revert "SAUCE: (no-up) Disable building the ACPI debugfs source"
+-  * [Config] enforce ACPI_CUSTOM_METHOD disabled
+-
+-  [ Keng-Yu Lin ]
+-
+-  * SAUCE: (no-up) Input: ALPS - Enable Intellimouse mode for Lenovo
+-    Zhaoyang E47
+-    - LP: #632884, #803005
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_BLK_DEV_CMD64X=m on powerpc
+-    - LP: #513131
+-  * [Config] Enable CONFIG_RT2800PCI_RT53XX=y
+-    - LP: #815064
+-
+-  [ Rezwanul Kabir ]
+-
+-  * SAUCE: (no-up) Add support for Intellimouse Mode in ALPS touchpad on
+-    Dell E2 series Laptops
+-    - LP: #632884
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "yama: if an underlying filesystem provides a permissions op use
+-    it"
+-  * Revert "Add support for Intellimouse Mode in ALPS touchpad on Dell E2
+-    series Laptops"
+-  * Revert "tty: include linux/slab.h for kfree"
+-  * Revert "gpio/ml_ioh_gpio: include linux/slab.h for kfree"
+-  * Revert "pch_dma: add include/slab.h for kfree"
+-  * mmc: Added quirks for Ricoh 1180:e823 lower base clock frequency
+-    - LP: #773524
+-  * oss: rename local change_bits to avoid powerpc bitsops.h definition
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 25 Jul 2011 09:08:01 -0700
+-
+-linux (3.0.0-7.8) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: overlayfs -- overlayfs: add statfs support
+-  * [Config] enable CONFIG_OVERLAYFS
+-
+-  [ Erez Zadok ]
+-
+-  * ubuntu: overlayfs -- overlayfs: implement show_options
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_ALIM7101_WDT=m on powerpc
+-  * [Config] Enable CONFIG_ASUS_OLED=m on powerpc
+-  * [Config] Disable CONFIG_ATM_DUMMY on arm
+-  * [Config] Enable CONFIG_BLK_DEV_DRBD=m on powerpc
+-  * Temporarily disable module check on arm
+-  * Rebase to 3.0 final
+-  * [Config] Enable CONFIG_CAN_TI_HECC=m on arm
+-  * [Config] Set CONFIG_CDROM_PKTCDVD=m on amd64 and i386
+-  * [Config] Enable CONFIG_CRYPTO_CCM=m on powerpc
+-  * [Config] Enable CONFIG_CRYPTO_DEV_HIFN_795X=m on powerpc
+-  * [Config] Enable CONFIG_CRYPTO_GCM=m on powerpc
+-  * [Config] Set CRYPTO_LZO=m on powerpc64-smp
+-  * [Config] Enable CONFIG_DM9000=m on arm
+-  * [Config] Set CONFIG_DISPLAY_SUPPORT=m on arm
+-  * [Config] Enable CONFIG_DL2K=m on amd64 and i386
+-
+-  [ Miklos Szeredi ]
+-
+-  * ubuntu: overlayfs -- vfs: add i_op->open()
+-  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
+-  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
+-  * ubuntu: overlayfs -- overlay filesystem
+-  * ubuntu: overlayfs -- ovl: fix overlayfs over overlayfs
+-  * ubuntu: overlayfs -- ovl: improve stack use of lookup and readdir
+-  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
+-  * ubuntu: overlayfs -- ovl: make lower mount read-only
+-
+-  [ Neil Brown ]
+-
+-  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add enic/fnic to udebs
+-    - LP: #801610
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * yama: if an underlying filesystem provides a permissions op use it
+-
+-  [ Major Kernel Changes ]
+-
+-  * Rebase to 3.0 final
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 21 Jul 2011 07:01:32 -0700
+-
+-linux (3.0.0-6.7) oneiric; urgency=low
+-
+-  [ Eagon Yager ]
+-
+-  * [Config] Fix misspelled 'skipmodule' in arm makefile.
+-
+-  [ Keng-Yu Lin ]
+-
+-  * SAUCE: Input: ALPS - Enable Intellimouse mode for Lenovo Zhaoyang E47
+-    - LP: #632884, #803005
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Config] Temporarily disable CONFIG_SMC91X on armel-omap"
+-  * Revert "[Config] Temporarily Disable CONFIG_BRCMSMAC on arm"
+-  * Revert "[Config] Temporarily Disable CONFIG_RTL8192SE on powerpc"
+-  * Revert "[Config] Temporarily Disable CONFIG_RTL8192SE on arm"
+-  * Revert "[Config] Temporarily disable CONFIG_BRCMSMAC on powerpc"
+-  * [Config] Set CONFIG_ACPI_PCI_SLOT=m
+-  * [Config] Set CONFIG_ACPI_SBS=m
+-  * [Config] Set CONFIG_ACPI_WMI=m
+-  * [Config] Set CONFIG_AD7150=m on arm
+-  * [Config] Set CONFIG_AD7152=m on arm
+-  * [Config] Drop CONFIG_GPIO_S5PV210
+-  * [Config] Drop CONFIG_GPIO_S5PC100
+-  * [Config] Drop CONFIG_GPIO_PLAT_SAMSUNG
+-  * [Config] Drop CONFIG_GPIO_EXYNOS4
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: Re-enable RODATA for i386 virtual
+-    - LP: #809838
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "Quirk to fix suspend/resume on Lenovo Edge 11,13,14,15"
+-  * (drop after 3.0.0) acer-wmi: Add support for Aspire 1830 wlan hotkey
+-    - LP: #771758
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 20 Jul 2011 06:36:02 -0700
+-
+-linux (3.0.0-5.6) oneiric; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_RTL8192CU=m
+-  * Rebase to -rc7
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 11 Jul 2011 22:13:50 +0100
+-
+-linux (3.0.0-4.5) oneiric; urgency=low
+-
+-  [ Ming Lei ]
+-
+-  * SAUCE: fix yama_ptracer_del lockdep warning
+-    - LP: #791019
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: (drop after 3.0) asus-wmi: Add callback for hotkey filtering
+-  * SAUCE: (drop after 3.0) eeepc-wmi: Add support for T101MT Home/Express Gate key
+-  * SAUCE: (drop after 3.0) asus-wmi: Enable autorepeat for hotkey input device
+-  * [Config] CONFIG_{ASUS,ASUS_NB,EEEPC}_WMI=m
+-    - LP: #805218
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] updateconfigs after rebase to -rc6+
+-    Rebased against 4dd1b49c6d215dc41ce50c80b4868388b93f31a3
+-  * Adopt a 3 digit verion, e.g., 3.0.0-x.x
+-  * Revert "UBUNTU: add dependancies for module-init-tools"
+-    This dependency is no longer required for a 3 digit version.
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 05 Jul 2011 14:03:04 +0100
+-
+-linux (3.0-3.4) oneiric; urgency=low
+-
+-  [ Keng-Yu Lin ]
+-
+-  * SAUCE: Revert: "dell-laptop: Toggle the unsupported hardware
+-    killswitch"
+-    - LP: #775281
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc5
+-  * [Config] updateconfigs after rebase to 3.0-rc5
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Remove ubuntu/rtl8192se
+-  * [Config] Added armel ABI files
+-  * [Config] Removed armel versatile flavour
+-  * [Config] CONFIG_INTEL_MEI=m
+-    - LP: #716867
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ALSA: hda - Enable auto-parser as default for Conexant codecs
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.0-rc5
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 30 Jun 2011 14:27:10 +0100
+-
+-linux (3.0-2.3) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: AUFS -- update to 0e2bafab74f0d1463383faeb93f9fc5eb8c2c54e
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc4
+-  * [Config] updateconfigs after rebase to 3.0-rc4
+-  * fix ERROR: __devcgroup_inode_permission undefined
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: iscsitarget: Remove driver from the kernel
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: rtl8192se: Force a build for a 2.6/3.0 kernel
+-  * [Config] Add grub-efi as a recommended bootloader for server and
+-    generic
+-    - LP: #800910
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Fix node_start/end_pfn() definition for mm/page_cgroup.c
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 24 Jun 2011 11:51:12 -0700
+-
+-linux (3.0-1.2) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_CAN_CALC_BITTIMING
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc3
+-  * [Config] updateconfigs after rebase to 3.0-rc3
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * perf: clear out make flags when calling kernel make kernelver
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc3
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 14 Jun 2011 07:25:35 -0700
+-
+-linux (3.0-0.1) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * use the packaging version in the kernel
+-  * use the kernels idea of its version for version_signature
+-  * add dependancies for module-init-tools
+-  * update control files to version 3
+-  * printchanges/insertchanges allow override of prev_release
+-  * correct Vcs-Git: to point to oneiric
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc1
+-  * [Config] updateconfigs after rebase to 3.0-rc1
+-  * ubuntu: dm-raid4-5 fix up build failure
+-  * [Config] Temporarily Disable CONFIG_GPIO_EXYNOS4 on arm
+-  * [Config] Temporarily Disable CONFIG_GPIO_PLAT_SAMSUNG on arm
+-  * [Config] Temporarily Disable CONFIG_GPIO_S5PC100 on arm
+-  * [Config] Temporarily Disable CONFIG_GPIO_S5PV210 on arm
+-  * [Config] Temporarily disable CONFIG_BRCMSMAC on powerpc
+-  * [Config] Temporarily Disable CONFIG_BRCMSMAC on arm
+-  * [Config] Temporarily Disable CONFIG_RTL8192SE on arm
+-  * [Config] Temporarily Disable CONFIG_RTL8192SE on powerpc
+-  * [Config] Temporarily disable CONFIG_SMC91X on armel-omap
+-  * rebase to v3.0-rc2
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: mmc: Enable MMC card reader for RICOH [1180:e823]
+-    - LP: #790754
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "x86 idle: EXPORT_SYMBOL(default_idle, pm_idle) only when APM
+-    demands it"
+-  * drm/i915: fix regression after clock gating init split
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39 to v3.0-rc1
+-  * rebase from v3.0-rc1 to v3.0-rc2
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 09 Jun 2011 15:18:33 +0100
+-
+-linux (2.6.39-3.10) oneiric; urgency=low
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: S3 early resume debug via keyboard LEDs
+-
+-  [ Ingo Molnar ]
+-
+-  * ubuntu: nx-emu - i386: NX emulation
+-  * ubuntu: nx-emu - i386: mmap randomization for executable mappings
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Config] Disable CONFIG_FT1000 on powerpc64-smp"
+-  * Revert "[Config] Disable CONFIG_DM_RAID45"
+-  * [Config] enable CONFIG_BRCMFMAC=y
+-  * [Config] enable CONFIG_MDIO_BITBANG=m across all arch's and flavors
+-  * [Config] enable CONFIG_VIDEO_OUTPUT_CONTROL=m on armel-omap
+-
+-  [ Robert Nelson ]
+-
+-  * SAUCE: omap3: beagle: detect new xM revision B
+-    - LP: #770679
+-  * SAUCE: omap3: beagle: detect new xM revision C
+-    - LP: #770679
+-  * SAUCE: omap3: beagle: if rev unknown, assume xM revision C
+-    - LP: #770679
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: Convert dm-raid45 to new block plugging
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 May 2011 11:46:43 -0700
+-
+-linux (2.6.39-3.9) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable CONFIG_SCSI_LPFC_DEBUG_FS
+-  * rebase to v2.6.39
+-  * [Config] enable CONFIG_LLC2=m across all arch's and flavours
+-  * [Config] enable CONFIG_INPUT_APANEL=m
+-
+-  [ Thomas Schlichter ]
+-
+-  * SAUCE: vesafb: mtrr module parameter is uint, not bool
+-    - LP: #778043
+-  * SAUCE: vesafb: enable mtrr WC by default
+-    - LP: #778043
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc7 to v2.6.39
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 20 May 2011 09:52:32 +0100
+-
+-linux (2.6.39-2.8) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-37"
+-  * Revert "ubuntu: AUFS -- aufs2-base.patch aufs2.1-37"
+-  * Revert "[Config] Disable CONFIG_AUFS_FS"
+-  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-39
+-  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-39
+-  * ubuntu: AUFS -- update to c6b76974311efc5bf3eddf921cd015b6aae46935
+-  * ubuntu: AUFS -- clean up the aufs updater and BOM
+-  * ubuntu: AUFS -- documentation on updating aufs2
+-
+-  [ Kees Cook ]
+-
+-  * ubuntu: Yama - LSM hooks
+-  * ubuntu: Yama - create task_free security callback
+-  * ubuntu: Yama - add ptrace relationship tracking interface
+-  * ubuntu: Yama - unconditionally chain to Yama LSM
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: Fix drivers/staging/easycap FTBS"
+-  * Revert "[Config] Disable CONFIG_EASYCAP"
+-  * ubuntu: fsam7400 disable driver
+-  * ubuntu: omnibook disable driver
+-  * ubuntu: rfkill disable driver
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: Fix extra reference in fb_open()
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 May 2011 09:23:56 -0700
+-
+-linux (2.6.39-2.7) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc7
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc6 to v2.6.39-rc7
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 10 May 2011 10:18:28 +0200
+-
+-linux (2.6.39-1.6) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc6
+-  * SAUCE: [arm] fixup __aeabi_uldivmod undefined build error
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] updateconfigs after rebase to 2.6.39-rc6
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc5 to v2.6.39-rc6
+-    - LP: #740126
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 05 May 2011 09:46:12 -0700
+-
+-linux (2.6.39-0.5) oneiric; urgency=low
+-
+-  [ Herton Ronaldo Krzesinski ]
+-
+-  * SAUCE: Revert "x86, hibernate: Initialize mmu_cr4_features during boot"
+-    - LP: #764758
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc5
+-  * [Config] updateconfigs following rebase to v2.6.39-rc5
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] s/USB_MUSB_TUSB6010/USB_MUSB_OMAP2PLUS/ on omap3 to get musb
+-    - LP: #759913
+-
+-  [ Stefan Bader ]
+-
+-  * Include nls_iso8859-1 for virtual images
+-    - LP: #732046
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc4 to v2.6.39-rc5
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 27 Apr 2011 06:39:42 -0700
+-
+-linux (2.6.39-0.4) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc4
+-  * [Config] updateconfigs following rebase to v2.6.39-rc4
+-  * fixup powerpc implicit declaration of function
+-    'crash_kexec_wait_realmode'
+-  * [Config] Disable CONFIG_FT1000 on powerpc64-smp
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_TRANSPARENT_HUGEPAGE=y
+-    - LP: #769503
+-  * [Config] Add cachefiles.ko to virtual flavour
+-    - LP: #770430
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc3 to v2.6.39-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 19 Apr 2011 06:25:20 -0700
+-
+-linux (2.6.39-0.3) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc3
+-  * crash_kexec_wait_realmode() undefined when !SMP
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_PM_ADVANCED_DEBUG=y for i386/amd64
+-    - LP: #632327
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc2 to v2.6.39-rc3
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 12 Apr 2011 06:52:24 -0700
+-
+-linux (2.6.39-0.2) oneiric; urgency=low
+-
+-  [ Gustavo F. Padovan ]
+-
+-  * SAUCE: Revert "Bluetooth: Add new PID for Atheros 3011"
+-    - LP: #720949
+-
+-  [ John Johansen ]
+-
+-  * AppArmor: Fix masking of capabilities in complain mode
+-    - LP: #748656
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc2
+-  * [Config] updateconfigs following rebase to v2.6.39-rc2
+-  * hv_mouse needs delay.h
+-  * olpc_dcon_xo_1 needs delay.h
+-  * olpc_dcon_xo_1_5 needs delay.h
+-  * Update dropped.txt for Oneiric
+-
+-  [ Steve Langasek ]
+-
+-  * [Config] Make linux-libc-dev coinstallable under multiarch
+-    - LP: #750585
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86, hibernate: Initialize mmu_cr4_features during boot
+-    - LP: #752870
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc1 to v2.6.39-rc2
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 06 Apr 2011 11:04:15 -0700
+-
+-linux (2.6.39-0.1) oneiric; urgency=low
+-
+-  [ Brad Figg ]
+-
+-  * [Config] Set CONFIG_NR_CPUS=256 for amd64 generic
+-    - LP: #737124
+-
+-  [ Henrik Rydberg ]
+-
+-  * SAUCE: HID: hid-ntrig: add support for 1b96:0006 model
+-  * SAUCE: HID: ntrig: fix suspend/resume on recent models
+-
+-  [ Herton Ronaldo Krzesinski ]
+-
+-  * SAUCE: (drop after 2.6.39) v4l: make sure drivers supply a zeroed
+-    struct v4l2_subdev
+-    - LP: #745213
+-
+-  [ Kees Cook ]
+-
+-  * [Config] packaging: adjust perms on vmlinuz as well
+-  * SAUCE: nx-emu: further clarify dmesg reporting
+-    - LP: #745181
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc1
+-  * [Config] updateconfigs following rebase to v2.6.39-rc1
+-  * [Config] Disable CONFIG_DM_RAID45
+-  * [Config] Disable CONFIG_SCSI_ISCSITARGET
+-  * [Config] Disable CONFIG_EASYCAP
+-  * [Config] Disable CONFIG_AUFS_FS
+-  * update bnx2 firmware files in d-i/firmware/nic-modules
+-  * xhci-pci.c resolve implicit declaration of kzalloc
+-  * [Config] Enable CONFIG_DRM_PSB for only x86
+-  * [Config] Enable CONFIG_RTS_PSTOR for only x86
+-  * mfd/asic3: Fix typo, s/irq_data/data/
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Disable CONFIG_CRASH_DUMP on 32-bit powerpc kernels
+-    - LP: #745358
+-  * [Config] Disable CONFIG_DRM_RADEON_KMS on powerpc kernels
+-  * [Config] Build some framebuffer drivers as modules for powerpc kernels.
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: thinkpad-acpi: module autoloading for newer Lenovo ThinkPads.
+-    - LP: #745217
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: INR_OPEN=4096
+-    - LP: #663090
+-  * SAUCE: Increase the default hard limit for open FDs to 4096
+-    - LP: #663090
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (drop after 2.6.39-rc1) arm: versatile : Fix typo introduced in irq
+-    namespace cleanup
+-  * (drop after 2.6.39-rc1) [media] staging: altera-jtag needs delay.h
+-  * ALSA: pcm: fix infinite loop in snd_pcm_update_hw_ptr0()
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38 to v2.6.39-rc1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Mar 2011 12:50:10 -0700
+-
+-linux (2.6.39-0.0) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Open Oneiric 
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Mar 2011 12:29:23 -0700
+-
+-linux (2.6.38-7.39) natty; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * No change upload.  This is just to rebuild with gcc-4.5.2-7ubuntu1.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 24 Mar 2011 09:27:45 -0700
+-
+-linux (2.6.38-7.38) natty; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * No change upload take 2.  2.6.38-7.37 was accidentally uploaded before
+-    gcc-4.5.2-6ubuntu5 finished building on all arches.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 22 Mar 2011 06:12:47 -0700
+-
+-linux (2.6.38-7.37) natty; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * No change upload.  This is just to rebuild with gcc-4.5.2-6ubuntu5.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 20 Mar 2011 16:02:48 -0700
+-
+-linux (2.6.38-7.36) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: KLUDGE: work around failed 'shrink-wrap' compiler
+-    optimisation"
+-  * purge last vestiges of maverick
+-  * [Config] switch CONFIG_FB_VESA back to module
+-
+-  [ Chris Wilson ]
+-
+-  * SAUCE: drm/i915: Fix pipelined fencing
+-    - LP: #717114
+-
+-  [ Loïc Minier ]
+-
+-  * Include nls_cp437 module in virtual for fat
+-    - LP: #732046
+-  * Support arch= cross-compilation for any arch
+-  * Fix couple of typos in 0-common-vars.mk
+-  * Enforce DEFAULT_MMAP_MIN_ADDR on armhf
+-  * Add armhf to Debian -> Linux arch map
+-  * Add initial armhf.mk
+-  * Enable common packages for armhf
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Yama: fix default relationship to check thread group
+-    - LP: #737676
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 18 Mar 2011 18:18:02 +0000
+-
+-linux (2.6.38-7.35) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to 2fbfac4e053861925fa3fffcdc327649b09af54c
+-  * rebase fixes bug #715330
+-  * [Config] disable CONFIG_SCSI_QLA_ISCSI for powerpc 32bit to fix FTBS
+-  * rebase to v2.6.38 final
+-
+-  [ Herton Ronaldo Krzesinski ]
+-
+-  * SAUCE: Apply OPTION_BLACKLIST_SENDSETUP also for ZTE MF626
+-    - LP: #636091
+-
+-  [ Tim Gardner ]
+-
+-  * [Confg] CONFIG_BOOT_PRINTK_DELAY=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Yama: use thread group leader when creating match
+-    - LP: #729839
+-  * (drop after 2.6.38) ahci: AHCI mode SATA patch for Intel Patsburg SATA
+-    RAID controller
+-    - LP: #735240
+-  * (drop after v2.6.38) x86, quirk: Fix SB600 revision check
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc8 to v2.6.38 final
+-    - LP: #715330
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 15 Mar 2011 19:04:19 +0000
+-
+-linux (2.6.38-6.34) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] normalise CONFIG_INTEL_TXT
+-  * SAUCE: KLUDGE: work around failed 'shrink-wrap' compiler optimisation
+-    - LP: #730860
+-  * rebase to mainline v2.6.38-rc8
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc7 + fb62c00a6d8942775abc23d1621db1252e2d93d1
+-    to v2.6.38-rc8
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 08 Mar 2011 11:54:48 +0000
+-
+-linux (2.6.38-6.33) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * d-i -- enable speakup-modules udeb
+-    - LP: #672699
+-  * rebase to 493f3358cb289ccf716c5a14fa5bb52ab75943e5
+-  * [Config] debian PPC64 configuration
+-  * [Config] cleanup powerpc config fixing unexpected inconsistancies
+-  * [Config] resync ppc64 configuration
+-  * SAUCE: match up ENTRY/END naming for 32/64 bit
+-  * rebase to fb62c00a6d8942775abc23d1621db1252e2d93d1
+-  * [Config] update configs after rebase to
+-    fb62c00a6d8942775abc23d1621db1252e2d93d1
+-  * [Config] pps_gen_parport no longer built
+-
+-  [ Corentin Chary ]
+-
+-  * SAUCE: (drop after 2.6.38) eeepc-wmi: reorder keymap
+-    - LP: #689393
+-  * SAUCE: (drop after 2.6.38) eeepc-wmi: add wlan key found on 1015P
+-    - LP: #689393
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: Fix aufs calling of security_path_mknod
+-    - LP: #724456
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: proc: hide kernel addresses via %pK in /proc/<pid>/stack
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to 2.6.38-rc7
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "drm/i915: fix corruptions on i8xx due to relaxed fencing"
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc6 to v2.6.38-rc7 +
+-    fb62c00a6d8942775abc23d1621db1252e2d93d1
+-    - LP: #721389
+-    - LP: #722925
+-    - LP: #723672
+-    - LP: #723676
+-    - LP: #715318
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 07 Mar 2011 15:33:17 +0000
+-
+-linux (2.6.38-5.32) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to mainline 6f576d57f1fa0d6026b495d8746d56d949989161
+-  * [Config] updateconfigs following rebase to v2.6.38-rc6
+-  * [Config] enable CONFIG_DMAR
+-    - LP: #552311
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drm/i915: skip FDI & PCH enabling for DP_A
+-    - LP: #561802, #600453, #681877
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc5 to v2.6.38-rc6
+-    - LP: #718402
+-    - LP: #719524
+-    - LP: #721126
+-    - LP: #719691
+-    - LP: #722689
+-    - LP: #722310
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 22 Feb 2011 13:28:39 +0000
+-
+-linux (2.6.38-4.31) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * add in bugs closed by upstream patches pulled in by rebases
+-  * rebase to 795abaf1e4e188c4171e3cd3dbb11a9fcacaf505
+-  * [Config] enable CONFIG_VSX to allow use of vector instuctions
+-  * resync with maverick 98defa1c5773a3d7e4c524967eb01d5bae035816
+-  * rebase to mainline v2.6.38-rc5
+-  * SAUCE: ecryptfs: read on a directory should return EISDIR if not
+-    supported
+-    - LP: #719691
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: Dell All-In-One: Remove need for Dell module alias
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: (drop after 2.6.38) add ricoh 0xe823 pci id.
+-    - LP: #717435
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_CRYPTO_CRC32C_INTEL=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Quirk to fix suspend/resume on Lenovo Edge 11,13,14,15
+-    - LP: #702434
+-  * vfs: fix BUG_ON() in fs/namei.c:1461
+-
+-  [ Vladislav P ]
+-
+-  * SAUCE: Release BTM while sleeping to avoid deadlock.
+-    - LP: #713837
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc4 to v2.6.38-rc5
+-    - LP: #579276
+-    - LP: #715877
+-    - LP: #713769
+-    - LP: #716811
+-  * resync with Maverick Ubuntu-2.6.35-27.47
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Feb 2011 17:24:09 +0000
+-
+-linux (2.6.38-3.30) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.38-rc4
+-  * ppc64 -- add basic architecture
+-  * ubuntu: AUFS -- update to 65835da20b77c98fb538c9114fc31f5de1328230
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: Add WMI hotkeys support for Dell All-In-One series
+-    - LP: #676997
+-  * SAUCE: Add WMI hotkeys support for another Dell All-In-One series
+-    - LP: #701530
+-  * SAUCE: Dell WMI: Use sparse keymaps and tidy up code.
+-    - LP: #701530
+-
+-  [ Dan Rosenberg ]
+-
+-  * SAUCE: (drop after 2.6.38) Convert net %p usage %pK
+-
+-  [ Kees Cook ]
+-
+-  * Revert "SAUCE: kernel: make /proc/kallsyms mode 400 to reduce ease of
+-    attacking"
+-  * SAUCE: (drop after 2.6.38) use %pK for /proc/kallsyms and /proc/modules
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_BLK_CGROUP=y
+-    - LP: #706394
+-  * [Config] CONFIG_DELL_WMI_AIO=m
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drm/i915/lvds: Restore dithering on native modes for gen2/3
+-    - LP: #711568
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc3 to v2.6.38-rc4.
+-    - LP: #701271
+-    - LP: #708521
+-    - LP: #710371
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 08 Feb 2011 02:07:18 +0000
+-
+-linux (2.6.38-2.29) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to 1f0324caefd39985e9fe052fac97da31694db31e
+-  * [Config] updateconfigs following rebase to
+-    1f0324caefd39985e9fe052fac97da31694db31e
+-  * rebase to 70d1f365568e0cdbc9f4ab92428e1830fdb09ab0
+-  * [Config] reenable HIBERNATE
+-    - LP: #710877
+-  * rebase to v2.6.38-rc3
+-  * [Config] reenable CONFIG_CRASH_DUMP
+-
+-  [ Kamal Mostafa ]
+-
+-  * SAUCE: rtl8192se: fix source file perms
+-  * SAUCE: rtl8192se: fix source file newline
+-  * SAUCE: omnibook: fix source file newline
+-
+-  [ Kees Cook ]
+-
+-  * [Config] packaging: really make System.map mode 0600
+-
+-  [ Ricardo Salveti de Araujo ]
+-
+-  * SAUCE: OMAP3630: PM: don't warn the user with a trace in case of
+-    PM34XX_ERRATUM
+-
+-  [ Soren Hansen ]
+-
+-  * SAUCE: nbd: Remove module-level ioctl mutex
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: Disable building the ACPI debugfs source
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Set physical start and alignment 1M for virtual i386
+-    - LP: #710754
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc2 + c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
+-    to v2.6.38-rc3
+-    - LP: #707902
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jan 2011 16:30:32 +0000
+-
+-linux (2.6.38-1.28) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: AUFS -- update to b1cee06249dfa0ab30951e7f06490a75c155b620
+-
+-  [ Ricardo Salveti de Araujo ]
+-
+-  * SAUCE: omap3: beaglexm: fix DVI initialization
+-  * [Config] omap: move CONFIG_PANEL_GENERIC_DPI to build in to make
+-    display work at Beagle
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jan 2011 10:51:57 +0000
+-
+-linux (2.6.38-1.27) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: AUFS -- update aufs-update to track new locations of headers
+-  * ubuntu: AUFS -- update to c5021514085a5d96364e096dbd34cadb2251abfd
+-  * SAUCE: ensure root is ready before running usermodehelpers in it
+-  * correct the Vcs linkage to point to natty
+-  * rebase to linux tip e78bf5e6cbe837daa6ab628a5f679548742994d3
+-  * [Config] update configs following rebase
+-    e78bf5e6cbe837daa6ab628a5f679548742994d3
+-  * SAUCE: Yama: follow changes to generic_permission
+-  * ubuntu: compcache -- follow changes to bd_claim/bd_release
+-  * ubuntu: iscsitarget -- follow changes to open_bdev_exclusive
+-  * ubuntu: ndiswrapper -- fix interaction between __packed and packed
+-  * ubuntu: AUFS -- update to 806051bcbeec27748aae2b7957726a4e63ff308e
+-  * update package version to match payload version
+-  * rebase to e6f597a1425b5af64917be3448b29e2d5a585ac8
+-  * rebase to v2.6.38-rc1
+-  * [Config] updateconfigs following rebase to v2.6.38-rc1
+-  * SAUCE: x86 fix up jiffies/jiffies_64 handling
+-  * rebase to linus tip 2b1caf6ed7b888c95a1909d343799672731651a5
+-  * [Config] updateconfigs following rebase to
+-    2b1caf6ed7b888c95a1909d343799672731651a5
+-  * [Config] disable CONFIG_TRANSPARENT_HUGEPAGE to fix i386 boot crashes
+-  * ubuntu: AUFS -- suppress benign plink warning messages
+-    - LP: #621195
+-  * [Config] CONFIG_NR_CPUS=256 for amd64 -server flavour
+-  * rebase to v2.6.38-rc2
+-  * rebase to mainline d315777b32a4696feb86f2a0c9e9f39c94683649
+-  * rebase to c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
+-  * [Config] update configs following rebase to
+-    c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
+-  * [Config] disable CONFIG_AD7152 to fix FTBS on armel versatile
+-  * [Config] disable CONFIG_AD7150 to fix FTBS on armel versatile
+-  * [Config] disable CONFIG_RTL8192CE to fix FTBS on armel omap
+-  * [Config] disable CONFIG_MANTIS_CORE to fix FTBS on armel versatile
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: kernel: make /proc/kallsyms mode 400 to reduce ease of attacking
+-
+-  [ Stefan Bader ]
+-
+-  * Temporarily disable RODATA for virtual i386
+-    - LP: #699828
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_NLS_DEFAULT=utf8
+-    - LP: #683690
+-  * [Config] CONFIG_HIBERNATION=n
+-  * update bnx2 firmware files in d-i/firmware/nic-modules
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "drm/radeon/bo: add some fallback placements for VRAM only
+-    objects."
+-  * packaging: make System.map mode 0600
+-  * thinkpad_acpi: Always report scancodes for hotkeys
+-    - LP: #702407
+-  * sched: tg->se->load should be initialised to tg->shares
+-  * Input: sysrq -- ensure sysrq_enabled and __sysrq_enabled are consistent
+-  * brcm80211: include linux/slab.h for kfree
+-  * pch_dma: add include/slab.h for kfree
+-  * i2c-eg20t: include linux/slab.h for kfree
+-  * gpio/ml_ioh_gpio: include linux/slab.h for kfree
+-  * tty: include linux/slab.h for kfree
+-  * winbond: include linux/delay.h for mdelay et al
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * mark the start of v2.6.38 versioning
+-  * rebase v2.6.37 to v2.6.38-rc2 + c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
+-    - LP: #689886
+-    - LP: #702125
+-    - LP: #608775
+-    - LP: #215802
+-    - LP: #686333
+-    - LP: #677830
+-    - LP: #677652
+-    - LP: #696493
+-    - LP: #697240
+-    - LP: #689036
+-    - LP: #705323
+-    - LP: #686692
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sun, 09 Jan 2011 13:44:52 +0000
+-
+-linux (2.6.37-12.26) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.37-rc8
+-  * [Config] armel -- reenable omap flavour
+-  * [Config] disable CONFIG_MACH_OMAP3517EVM to fix FTBS on armel omap
+-  * [Config] disable CONFIG_GPIO_VX855 to fix FTBS on omap armel
+-  * [Config] disable CONFIG_WESTBRIDGE_ASTORIA to fix FTBS on omap armel
+-  * [Config] disable CONFIG_TI_DAVINCI_EMAC to fix FTBS on omap armel
+-  * rebase to mainline 989d873fc5b6a96695b97738dea8d9f02a60f8ab
+-  * [Config] track missing modules
+-  * rebase to v2.6.37 final
+-
+-  [ Chase Douglas ]
+-
+-  * SAUCE: (drop after 2.6.37) HID: magicmouse: Don't report REL_{X, Y} for
+-    Magic Trackpad
+-
+-  [ Stefan Bader ]
+-
+-  * Revert "SAUCE: blkfront: default to sd devices"
+-    - LP: #684875
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "SAUCE: (no-up) libata: Ignore HPA by default."
+-    - LP: #380138
+-  * [Config] Added autofs4.ko to -virtual flavour
+-    - LP: #692917
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Add support for Intellimouse Mode in ALPS touchpad on Dell E2 series
+-    Laptops
+-    - LP: #632884
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.37-rc8
+-  * rebase to mainline 989d873fc5b6a96695b97738dea8d9f02a60f8ab
+-  * rebase to v2.6.37 final
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Dec 2010 18:34:13 +0000
+-
+-linux (2.6.37-11.25) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] d-i -- add hpsa to the list of block devices
+-    - LP: #684304
+-  * [Config] add vmw-balloon driver to -virtual flavour
+-    - LP: #592039
+-  * rebase to v2.6.37-rc7
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.37-rc7
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 21 Dec 2010 13:35:28 +0000
+-
+-linux (2.6.37-10.24) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.37-rc6
+-  * updateconfigs following rebase to v2.6.37-rc6
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.37-rc6
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 16 Dec 2010 12:34:19 +0000
+-
+-linux (2.6.37-9.23) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: vt -- fix handoff numbering to 1..n and add range checks
+-    - LP: #689606
+-  * SAUCE: vt -- fix handoff numbering to 1..n and add range checks (grub)
+-    - LP: #689606
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: RO/NX protection for loadable kernel, fix ftrace
+-    - LP: #690190
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 15 Dec 2010 19:29:57 +0000
+-
+-linux (2.6.37-9.22) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.35-rc5
+-  * [Config] updateconfigs following rebase to v2.6.37-rc5
+-  * (no-up) add support for installed header files to ubuntu directory
+-    - LP: #684666
+-  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
+-    - LP: #684666
+-  * ubuntu: dm-raid4-5 -- follow changes to bio flags
+-  * ubuntu: dm-raid4-5 -- re-enable
+-  * ubuntu: omnibook -- update BOM
+-  * ubuntu: ndiswrapper -- update BOM to match actual version
+-  * ubuntu: ndiswrapper -- follow removal of the BKL and locked ioctl
+-  * ubuntu: ndiswrapper -- re-enable
+-  * ubuntu: iscsitarget -- re-instate copy_io_context
+-  * ubuntu: iscsitarget -- follow changes to semaphore initialisation
+-  * ubuntu: iscsitarget -- convert NIPQUAD to %pI4
+-  * ubuntu: iscsitarget -- re-enable
+-
+-  [ Kees Cook ]
+-
+-  * [Config] update config for CONFIG_DEBUG_SET_MODULE_RONX
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Enable jack sense for Thinkpad Edge 13
+-    - LP: #685015
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_9P_FSCACHE=y,CONFIG_9P_FS_POSIX_ACL=y
+-  * [Config] CONFIG_CRYPTO_CRC32C=y
+-    - LP: #681819
+-  * [Config] CONFIG_9P_FSCACHE=n
+-  * [Config] Add nfsd modules to -virtual flavour
+-    - LP: #688070
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "Staging: zram: work around oops due to startup ordering snafu"
+-  * NFS: Fix panic after nfs_umount()
+-    - LP: #683938
+-  * x86: Add NX protection for kernel data
+-  * x86: Add RO/NX protection for loadable kernel modules
+-  * x86: Resume trampoline must be executable
+-  * x86: RO/NX protection for loadable kernel, jump_table fix
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.37-rc5
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 09 Dec 2010 18:15:35 +0000
+-
+-linux (2.6.37-8.21) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: AUFS -- include the aufs_types.h file in
+-    linux-libc-headers"
+-  * Revert "(no-up) add support for installed header files to ubuntu
+-    directory"
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sun, 05 Dec 2010 17:33:28 +0000
+-
+-linux (2.6.37-8.20) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Upstream] drivers/serial/mfd.c: Fix ARM compile error"
+-  * Revert "SAUCE: Nouveau: Disable acceleration on MacBook Pros"
+-  * Revert "SAUCE: Nouveau: Add quirk framework to disable acceleration"
+-  * Revert "SAUCE: i915 -- disable powersave by default"
+-  * SAUCE: enable Marvell 9128 PCIe SATA controller
+-    - LP: #658521
+-  * [Config] evtchn has been renamed
+-  * (no-up) add support for installed header files to ubuntu directory
+-    - LP: #684666
+-  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
+-    - LP: #684666
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] MISS: evtchn, NEW : xen-evtchn
+-  * rebase to v2.6.37-rc4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drm/i915: Clean conflicting modesetting registers upon init
+-    - LP: #683775
+-  * rebase to v2.6.37-rc4
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 03 Dec 2010 18:42:07 +0000
+-
+-linux (2.6.37-7.19) natty; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add bnx2 firmware to nic-modules udeb
+-    - LP: #676245
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 26 Nov 2010 17:53:45 +0000
+-
+-linux (2.6.37-7.18) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Upstream] USB: option: Remove duplicate AMOI_VENDOR_ID"
+-  * Revert "SAUCE: Add extra headers to linux-libc-dev"
+-  * Revert "SAUCE: Enable speedstep for sonoma processors."
+-  * [Config] enable CONFIG_BT_HCIUART_ATH3K
+-  * [Config] enable CONFIG_IWLWIFI_DEBUGFS
+-  * [Config] standardise CONFIG_MII
+-  * [Config] standardise CONFIG_PRISM2_USB
+-  * [Config] standardise CONFIG_SCSI_QLA_ISCSI
+-  * [Config] build in CONFIG_AGP
+-  * [Config] build in CONFIG_AGP_INTEL
+-  * [Config] build in CONFIG_AGP_AMD
+-  * [Config] build in CONFIG_AGP_AMD64
+-  * [Config] build in CONFIG_AGP_NVIDIA
+-  * [Config] build in CONFIG_AGP_VIA
+-  * [Config] disable CONFIG_SCSI_QLA_ISCSI for FTBS (arm)
+-  * (no-up): document the new ## scheme
+-  * [Config] harmonise CONFIG_SERIAL_8250_NR_UARTS
+-  * [Config] update CONFIG_SERIAL_8250_RUNTIME_UARTS=32
+-    - LP: #675453
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * SAUCE: ARM: Adding vdd_sdi regulator supply to OMAP3EVM
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * nx-emu: fix inverted report of disable_nx
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 23 Nov 2010 21:00:39 +0000
+-
+-linux (2.6.37-6.17) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: AUFS -- aufs2-standalone.patch
+-    aufs2.1-36-UNRELEASED-20101103"
+-  * Revert "ubuntu: AUFS -- aufs2-base.patch
+-    aufs2.1-36-UNRELEASED-20101103"
+-  * [Config] standardise CONFIG_BT
+-  * [Config] standardise CONFIG_IRDA
+-  * [Config] standardise CONFIG_LAPB
+-  * [Config] standardise CONFIG_RDS
+-  * [Config] standardise CONFIG_RFKILL
+-  * [Config] standardise CONFIG_TIPC
+-  * [Config] standardise CONFIG_X25
+-  * [Config] standardise CONFIG_INPUT_EVDEV
+-  * [Config] standardise CONFIG_INPUT_JOYDEV
+-  * [Config] standardise CONFIG_INPUT_JOYSTICK
+-  * [Config] standardise CONFIG_INPUT_TOUCHSCREEN
+-  * [Config] CONFIG_INPUT_TOUCHSCREEN=n for FTBS (arm)
+-  * [Config] CONFIG_IRDA=n for FTBS (arm)
+-  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-37
+-  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-37
+-  * ubuntu: AUFS -- update to 097bf62d6f49619359d34bf17f242df38562489a
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: Fix drivers/staging/easycap FTBS
+-  * [Config] CONFIG_EASYCAP=m after fixing FTBS
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "x86: Add NX protection for kernel data"
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 22 Nov 2010 18:09:10 +0000
+-
+-linux (2.6.37-6.16) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Config] update config for CONFIG_DEBUG_SET_MODULE_RONX"
+-  * rebase to v2.6.37-rc3
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_SCHED_AUTOGROUP=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "x86: Add RO/NX protection for loadable kernel modules"
+-  * sched: automated per session task groups
+-  * rebase to v2.6.37-rc3
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 22 Nov 2010 10:11:13 +0000
+-
+-linux (2.6.37-6.15) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] standardise CONFIG_CEPH_FS
+-  * [Config] standardise CONFIG_SCSI_LPFC_DEBUG_FS
+-  * [Config] standardise CONFIG_SCSI_PROC_FS
+-  * [Config] standardise CONFIG_UBIFS_FS
+-  * [Config] standardise CONFIG_USB_GADGET_DEBUG_FS
+-
+-  [ Kees Cook ]
+-
+-  * [Config] update config for CONFIG_DEBUG_SET_MODULE_RONX
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Enable jack sense for Thinkpad Edge 11
+-    - LP: #677210
+-  * SAUCE: enable rfkill for rtl8192se driver
+-    - LP: #640992
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_EASYCAP=n for FTBS
+-  * Rebase to v2.6.32-rc2+git
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86: Fix improper large page preservation
+-  * x86: Add NX protection for kernel data
+-  * x86: Add RO/NX protection for loadable kernel modules
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Rebase to Linus 2.6.37-rc2+git
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 20 Nov 2010 11:40:00 +0000
+-
+-linux (2.6.37-5.14) natty; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * PCI: fix offset check for sysfs mmapped files
+-    - LP: #676963
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 18 Nov 2010 18:12:27 +0000
+-
+-linux (2.6.37-5.13) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebased to v2.6.37-rc2
+-  * updateconfigs following rebase to v2.6.37-rc2
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Added NFS and related modules to virtual flavour
+-    - LP: #659084
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86, cpu: Rename verify_cpu_64.S to verify_cpu.S
+-  * x86, cpu: Clear XD_DISABLED flag on Intel to regain NX
+-  * x86, cpu: Call verify_cpu during 32bit CPU startup
+-  * x86, cpu: Only CPU features determine NX capabilities
+-
+-  [ Upstream Changes ]
+-
+-  * rebased to v2.67.37-rc2
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 16 Nov 2010 13:13:29 +0000
+-
+-linux (2.6.37-4.12) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Upstream] HID: magicmouse: add param for scroll speed"
+-  * Revert "[Upstream] HID: magicmouse: properly account for scroll
+-    movement in state"
+-  * Revert "[Upstream] HID: magicmouse: disable and add module param for
+-    scroll acceleration"
+-  * Revert "[Upstream] HID: magicmouse: scroll on entire surface, not just
+-    middle of mouse"
+-
+-  [ Henrik Rydberg ]
+-
+-  * SAUCE: hid: ntrig: remove sysfs nodes
+-  * SAUCE: hid: ntrig: Setup input filtering manually
+-  * SAUCE: hid: ntrig: New ghost-filtering event logic
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
+-    - LP: #348861
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "mmc: fix all hangs related to mmc/sd card insert/removal during
+-    suspend/resume"
+-  * Revert "[ARM] implement arch_randomize_brk()"
+-  * Revert "ARM: stack protector: change the canary value per task"
+-  * Revert "ARM: initial stack protector (-fstack-protector) support"
+-  * Revert "ALSA: hda - Handle pin NID 0x1a on ALC259/269"
+-  * Revert "ALSA: hda - Handle missing NID 0x1b on ALC259 codec"
+-  * Revert "perf probe: Add kernel source path option"
+-  * hid: ntrig: Support single-touch devices
+-  * hid: ntrig: Mask pen switch events
+-  * net: rtnetlink.h -- only include linux/netdevice.h when used by the
+-    kernel
+-    - LP: #673073
+-  * Fix userspace build of linux/fs.h
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 15 Nov 2010 19:31:44 +0000
+-
+-linux (2.6.37-3.11) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: AUFS -- update to
+-    b37c575759dc4535ccc03241c584ad5fe69e3b25"
+-  * Revert "ubuntu: AUFS -- track changes to the arguements to fop fsync()"
+-  * Revert "ubuntu: AUFS -- update to standalone 2.6.35-rcN as at 20100601"
+-  * Revert "ubuntu: AUFS -- update to standalone 2.6.34 as at 20100601"
+-  * Revert "ubuntu: AUFS -- aufs2 base patch for linux-2.6.34"
+-  * [Config] Disable intel_idle for -virtual kernels
+-    - LP: #651370
+-  * [Config] enforcer -- ensure we never enable CONFIG_IMA
+-  * debian -- pass the correct flavour name when checking configs
+-  * [Config] enforcer -- ensure CONFIG_INTEL_IDLE is off for -virtual
+-  * [Config] ensure CONFIG_IPV6=y for powerpc
+-  * [Config] enforcer -- ensure CONFIG_IPV6=y
+-  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-36-UNRELEASED-20101103
+-  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-36-UNRELEASED-20101103
+-  * ubuntu: AUFS -- update to aufs2.1-36-UNRELEASED-20101103
+-  * ubuntu: AUFS -- re-enable
+-  * ubuntu: AUFS -- track changes to work queue initialisation
+-  * ubuntu: AUFS -- track changes to llseek in v2.6.37-rc1
+-  * SAUCE: fbcon -- fix race between open and removal of framebuffers
+-  * SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
+-    - LP: #614008
+-  * SAUCE: drm -- stop early access to drm devices
+-
+-  [ Jeremy Kerr ]
+-
+-  * [Config] Build-in powermac ZILOG serial driver
+-    - LP: #673346
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: nx-emu: use upstream ASLR when possible
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Use correct be2iscsi module name in d-i/modules/scsi-modules
+-    - LP: #628776
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * i386: NX emulation
+-  * nx-emu: drop exec-shield sysctl, merge with disable_nx
+-  * nx-emu: standardize boottime message prefix
+-  * mmap randomization for executable mappings on 32-bit
+-  * exec-randomization: brk away from exec rand area
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 11 Nov 2010 23:46:37 +0000
+-
+-linux (2.6.37-2.10) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * reinstate armel config changes:
+-   * [Config] CONFIG_GPIO_PCH=n for armel FTBS
+-   * [Config] CONFIG_GPIO_VX855=n for armel FTBS
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 03 Nov 2010 22:20:35 +0000
+-
+-linux (2.6.37-2.9) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * config -- fix genportsconfig
+-  * [Config] move powerpc over from ports to distro
+-  * bump master version number to match contained kernel
+-  * SAUCE: fix documentation strings for struct input_keymap_entry
+-  * usb: gadget: goku_udc: add registered flag bit
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 02 Nov 2010 15:14:11 +0000
+-
+-linux (2.6.36-2.8) natty; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config]: fix changed CONFIG_SYSFS_DEPRECATED_V2 enforcement rules
+-  * [Config]: TWL4030_CORE=n for FTBS
+-  * [Config]: CONFIG_ATH6K_LEGACY=n for FTBS
+-  * [Config]: CONFIG_SOLO6X10=n for FTBS
+-  * [Config]: CONFIG_GPIO_PCH=n for armel FTBS
+-  * [Config]: CONFIG_GPIO_VX855=n for armel FTBS
+-  * [Config]: CONFIG_DRM_NOUVEAU=n for armel FTBS
+-  * [Config]: CONFIG_LINE6_USB=n for armel FTBS
+-  * [Config]: CONFIG_SENSORS_AK8975=n for armel FTBS
+-  * [Config]: CONFIG_I2C_I801=n for armel FTBS
+-  * UBUNTU: SAUCE: AppArmor: Fix unpack of network tables.
+-  * AppArmor: compatibility patch for v5 interface
+-  * AppArmor: compatibility patch for v5 network controll
+-  * Dropped (pre-stable): input: Support Clickpad devices in ClickZone mode
+-  * Dropped: UBUNTU: SAUCE: libata: Add ALPM power state accounting to the AHCI driver
+-  * Dropped: UBUNTU: SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
+-  * Dropped: hid: 3m: Convert to MT slots
+-  * Dropped: HID: magicmouse: don't allow hidinput to initialize the device
+-  * Dropped: HID: magicmouse: simplify touch data bit manipulation
+-  * Dropped: HID: magicmouse: simplify touch down logic
+-  * Dropped: HID: magicmouse: enable Magic Trackpad support
+-  * Dropped: UBUNTU: SAUCE: hid: ntrig: remove sysfs nodes
+-  * Dropped: UBUNTU: SAUCE: hid: ntrig: Setup input filtering manually
+-  * Dropped: UBUNTU: SAUCE: hid: ntrig: New ghost-filtering event logic
+-  * Dropped: UBUNTU: SAUCE: hid: ntrig: identify firmware version (wiggled)
+-  * Dropped: UBUNTU: (pre-stable): input: Support Clickpad devices in ClickZone mode
+-  * Dropped: UBUNTU: SAUCE: KMS: cache the EDID information of the LVDS
+-  * Dropped: UBUNTU: SAUCE: fbcon -- fix race between open and removal of framebuffers
+-  * Dropped: UBUNTU: SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
+-  * Dropped: UBUNTU: SAUCE: x86: implement cs-limit nx-emulation for ia32
+-  * Dropped: UBUNTU: SAUCE: x86: more tightly confine cs-limit nx-emulation to ia32 only
+-  * Dropped: UBUNTU: SAUCE: [um] Don't use nx_enabled under UML
+-  * Dropped: UBUNTU: SAUCE: x86: brk away from exec rand area
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased against 2.6.27-rc1
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Fri, 22 Oct 2010 19:35:05 -0600
+-
+-linux (2.6.36-1.7) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebased to v2.6.36 final
+-  * [Config] update configs following rebase to v2.6.36 final
+-  * [Config] update ports configs following rebase to v2.6.36 final
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to v2.6.36 final
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 21 Oct 2010 14:28:57 +0100
+-
+-linux (2.6.36-1.6) natty; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drop broadcom staging driver preview:
+-   * Revert "Staging: Add initial release of brcm80211 - Broadcom 802.11n
+-     wireless LAN driver."
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 20 Oct 2010 10:41:25 +0100
+-
+-linux (2.6.36-1.5) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.36-rc8
+-  * updateconfigs following rebase to v2.6.36-rc8
+-  * updateportsconfigs following rebase to v2.6.36-rc8
+-  * config -- simplify the kernelconfig interface
+-  * config -- add new config mode 'dumpconfigs'
+-
+-  [ Tim Gardner ]
+-
+-  * Simplify the use of CROSS_COMPILER
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drop broadcom staging driver preview:
+-   * Revert "staging: brcm80211: Make compiling of brcm80211.ko and
+-     brcmfmac.ko mutually exclusive."
+-   * Revert "staging: brcm80211: Fix compile issue when BRCM80211_PCI is not
+-     set."
+-   * Revert "Staging: brcm80211: remove driver specific -W options"
+-   * Revert "Staging: brcm80211: clean up makefile cflag lines"
+-   * Revert "staging: brcm80211: add fullmac driver"
+-   * Revert "staging: brcm80211: use string native library"
+-   * Revert "staging: brcm80211: use native ctype library"
+-   * Revert "staging: brcm80211: fix remaining checkpatch errors."
+-   * Revert "staging: brcm80211: fix "ERROR: trailing whitespace.""
+-   * Revert "staging: brcm80211: fix "ERROR: spaces required around that
+-     ...""
+-   * Revert "staging: brcm80211: fix "ERROR: spaces prohibited around that
+-     ':' ...""
+-   * Revert "staging: brcm80211: fix "ERROR: space required before that
+-     ...""
+-   * Revert "staging: brcm80211: fix "ERROR: space required after that ...""
+-   * Revert "staging: brcm80211: fix "ERROR: space required after that close
+-     brace""
+-   * Revert "staging: brcm80211: fix "ERROR: space prohibited before
+-     ...close square bracket""
+-   * Revert "staging: brcm80211: fix "ERROR: space prohibited after that
+-     ...""
+-   * Revert "staging: brcm80211: fix "ERROR: need consistent spacing around
+-     '*'""
+-   * Revert "staging: brcm80211: fix 'ERROR: "(foo*)" should be "(foo *)"'"
+-   * Revert "staging: brcm80211: fix "ERROR: Macros w/ mult. statements ...
+-     do - while loop""
+-   * Revert "staging: brcm80211: fix "ERROR: Macros w/ complex values ...
+-     parenthesis""
+-   * Revert "staging: brcm80211: fix "ERROR: do not initialise statics to 0
+-     or NULL""
+-   * Revert "staging: brcm80211: fix "ERROR: do not initialise globals to 0
+-    or NULL""
+-   * Revert "staging: brcm80211: fix "ERROR: while should follow close brace
+-     '}'""
+-   * Revert "staging: brcm80211: fix "ERROR: that open brace { ... prev
+-     line""
+-   * Revert "staging: brcm80211: fix "ERROR: trailing statements should be
+-     on next line""
+-   * Revert "staging: brcm80211: fix "ERROR: do not use assignment in if
+-     condition""
+-   * Revert "staging: brcm80211: fix "ERROR: return is not a function,
+-     paren...""
+-   * Revert "staging: brcm80211: fix "ERROR: open brace '{' following
+-     function dec...""
+-   * Revert "staging: brcm80211: fix 'ERROR: "foo * bar" should be "foo
+-     *bar"'"
+-   * Revert "staging: brcm80211: Fix URLs for firmware files."
+-   * Revert "staging: brcm80211: use '%pM' format to print MAC address"
+-   * Revert "staging: brcm80211: Add contact info to TODO list."
+-   * Revert "staging: brcm80211: Fix some initialisation failure paths"
+-  * Export dump_{write,seek} to binary loader modules
+-  * rebase to v2.6.36-rc8.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 19 Oct 2010 18:58:11 +0100
+-
+-linux (2.6.36-0.4) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: perf: increase stack footprint to avoid stack-protector warning
+-    (fixes FTBS on powerpc)
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 14 Oct 2010 13:16:16 +0100
+-
+-linux (2.6.36-0.3) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] disable CONFIG_SCSI_QLA_ISCSI to fix FTBS on powerpc
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 14 Oct 2010 03:01:30 +0100
+-
+-linux (2.6.36-0.2) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] updateportsconfigs following rebase to 2.6.36-rc7
+-    (fix FTBS on powerpc)
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 13 Oct 2010 23:25:12 +0100
+-
+-linux (2.6.36-0.1) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * reduce disk usage during buildd builds
+-    - LP: #645653
+-  * [Config] enforcer -- ensure CONFIG_INIT_PASS_ALL_PARAMS is y
+-  * [Config] armel -- drop omap flavour
+-
+-  [ Tim Gardner ]
+-
+-  * Added dropped patch list
+-  * more dropped patches
+-  * [Config] Disable aufs, dmraid-4.5, ndis-wrapper
+-  * [Config] Add support for cross compiling armel
+-  * [Config] CONFIG_SCSI_QLA_ISCSI=n for armel
+-  * [Upstream] drivers/serial/mfd.c: Fix ARM compile error
+-  * [Config]: updateconfigs after adding brcm80211
+-  * staging: brcm80211: Fix Makefile syntax error
+-  * rebased to v2.6.36-rc7
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (upstream) IPS driver: don't toggle CPU turbo on unsupported CPUs
+-  * (upstream) IPS driver: verify BIOS provided limits
+-  * intel_ips: Print MCP limit exceeded values.
+-  * Staging: Add initial release of brcm80211 - Broadcom 802.11n wireless
+-    LAN driver.
+-  * staging: brcm80211: Fix some initialisation failure paths
+-  * staging: brcm80211: Add contact info to TODO list.
+-  * staging: brcm80211: use '%pM' format to print MAC address
+-  * staging: brcm80211: Fix URLs for firmware files.
+-  * staging: brcm80211: fix 'ERROR: "foo * bar" should be "foo *bar"'
+-  * staging: brcm80211: fix "ERROR: open brace '{' following function
+-    dec..."
+-  * staging: brcm80211: fix "ERROR: return is not a function, paren..."
+-  * staging: brcm80211: fix "ERROR: do not use assignment in if condition"
+-  * staging: brcm80211: fix "ERROR: trailing statements should be on next
+-    line"
+-  * staging: brcm80211: fix "ERROR: that open brace { ... prev line"
+-  * staging: brcm80211: fix "ERROR: while should follow close brace '}'"
+-  * staging: brcm80211: fix "ERROR: do not initialise globals to 0 or NULL"
+-  * staging: brcm80211: fix "ERROR: do not initialise statics to 0 or NULL"
+-  * staging: brcm80211: fix "ERROR: Macros w/ complex values ...
+-    parenthesis"
+-  * staging: brcm80211: fix "ERROR: Macros w/ mult. statements ... do -
+-    while loop"
+-  * staging: brcm80211: fix 'ERROR: "(foo*)" should be "(foo *)"'
+-  * staging: brcm80211: fix "ERROR: need consistent spacing around '*'"
+-  * staging: brcm80211: fix "ERROR: space prohibited after that ..."
+-  * staging: brcm80211: fix "ERROR: space prohibited before ...close square
+-    bracket"
+-  * staging: brcm80211: fix "ERROR: space required after that close brace"
+-  * staging: brcm80211: fix "ERROR: space required after that ..."
+-  * staging: brcm80211: fix "ERROR: space required before that ..."
+-  * staging: brcm80211: fix "ERROR: spaces prohibited around that ':' ..."
+-  * staging: brcm80211: fix "ERROR: spaces required around that ..."
+-  * staging: brcm80211: fix "ERROR: trailing whitespace."
+-  * staging: brcm80211: fix remaining checkpatch errors.
+-  * staging: brcm80211: use native ctype library
+-  * staging: brcm80211: use string native library
+-  * staging: brcm80211: add fullmac driver
+-  * Staging: brcm80211: clean up makefile cflag lines
+-  * Staging: brcm80211: remove driver specific -W options
+-  * staging: brcm80211: Fix compile issue when BRCM80211_PCI is not set.
+-  * staging: brcm80211: Make compiling of brcm80211.ko and brcmfmac.ko
+-    mutually exclusive.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 12 Oct 2010 16:00:27 +0100
+-
+-linux (2.6.35-22.33) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: Add support for Intellimouse Mode in ALPS touchpad on
+-    Dell E2 series Laptops"
+-    - LP: #641320
+-
+-  [ Brian Rogers ]
+-
+-  * SAUCE: ir-core: Fix null dereferences in the protocols sysfs interface
+-    - LP: #624701
+-
+-  [ Christopher James Halse Rogers ]
+-
+-  * SAUCE: Nouveau: Add quirk framework to disable acceleration
+-    - LP: #544088, #546393
+-  * SAUCE: Nouveau: Disable acceleration on MacBook Pros
+-    - LP: #546393
+-
+-  [ John Johansen ]
+-
+-  * Revert "SAUCE: AppArmor: allow newer tools to load policy on older
+-    kernels"
+-  * SAUCE: AppArmor: allow newer tools to load policy on older kernels
+-    - LP: #639758
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * SAUCE: Adding vdd_sdi regulator supply to OMAP3EVM
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ALSA: HDA: Enable internal speaker on Dell M101z
+-    - LP: #640254
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 17 Sep 2010 13:21:28 -0700
+-
+-linux (2.6.35-22.32) maverick; urgency=low
+-
+-  [ Arjan van de Ven ]
+-
+-  * SAUCE: libata: Add ALPM power state accounting to the AHCI driver
+-
+-  [ David Henningsson ]
+-
+-  * SAUCE: ALSA: HDA: Enable internal mic on Dell E6410 and Dell E6510
+-    - LP: #605047, #628961
+-
+-  [ John Johansen ]
+-
+-  * [Upstream] AppArmor: Fix splitting an fqname into separate namespace
+-    and profile names
+-    - LP: #615947
+-  * [Upstream] AppArmor: Fix locking from removal of profile namespace
+-    - LP: #615947
+-  * SAUCE: AppArmor: allow newer tools to load policy on older kernels
+-    - LP: #639758
+-  * SAUCE: Improve Amazon EBS performance for EC2
+-    - LP: #634316
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: i915 KMS -- blacklist i855"
+-  * Revert "SAUCE: i915 KMS -- blacklist i845g"
+-  * Revert "SAUCE: i915 KMS -- blacklist i830"
+-  * Revert "SAUCE: i915 KMS -- support disabling KMS for known broken
+-    devices"
+-  * execute module-inclusion within a subshell
+-    - LP: #621175
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) bounce: call flush_dcache_page() after bounce_copy_vec()
+-    - LP: #633227
+-  * (pre-stable) drm/i915: don't enable self-refresh on Ironlake
+-    - LP: #629711
+-  * (pre-stable) mm: Move vma_stack_continue into mm.h
+-  * x86, hwmon: Fix unsafe smp_processor_id() in thermal_throttle_add_dev
+-    - LP: #601073
+-  * PM / Runtime: Make runtime_status attribute not debug-only (v. 2)
+-  * PM / Runtime: Add runtime PM statistics (v3)
+-  * compat: Make compat_alloc_user_space() incorporate the access_ok()
+-    - CVE-2010-3081
+-  * x86-64, compat: Test %rax for the syscall number, not %eax
+-    - CVE-2010-3301
+-  * x86-64, compat: Retruncate rax after ia32 syscall entry tracing
+-    - CVE-2010-3301
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 14 Sep 2010 08:46:49 -0700
+-
+-linux (2.6.35-21.31) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * bodge linux-libc-dev package version due to ti-omap4 error
+-  * linux-libc-dev -- ensure we can only build this on debian.master
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 13 Sep 2010 09:54:31 -0700
+-
+-linux (2.6.35-21.30) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
+-    - LP: #614008
+-
+-  [ Daniel Lezcano ]
+-
+-  * SAUCE: fix compilation warning when CONFIG_SECURITY is not set
+-
+-  [ Henrik Rydberg ]
+-
+-  * SAUCE: Input: wacom - add fuzz parameters to features
+-  * SAUCE: Input: wacom - collect device quirks into single function
+-  * SAUCE: Input: wacom - add support for the Bamboo Touch trackpad
+-  * SAUCE: Input: wacom - add a quirk for low resolution Bamboo devices
+-  * SAUCE: hid: ntrig: Remove unused device ids
+-  * SAUCE: hid: ntrig: remove sysfs nodes
+-  * SAUCE: hid: ntrig: Correct logic for quirks
+-  * SAUCE: hid: ntrig: zero-initialize ntrig struct
+-  * SAUCE: hid: ntrig: Setup input filtering manually
+-  * SAUCE: hid: ntrig: New ghost-filtering event logic
+-
+-  [ Leann Ogasawara ]
+-
+-  * SAUCE: ndiswrapper: Initialize buffer index and check its value
+-    - LP: #613796
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Add support for Intellimouse Mode in ALPS touchpad on Dell E2
+-    series Laptops
+-    - LP: #632884
+-
+-  [ Ping Cheng ]
+-
+-  * SAUCE: Input: wacom - parse the Bamboo device family
+-
+-  [ Rafi Rubin ]
+-
+-  * SAUCE: hid: ntrig: identify firmware version (wiggled)
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_NL80211_TESTMODE=n
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "input: mt: Add support for the Bamboo Touch trackpad"
+-  * e1000e: initial support for 82579 LOMs
+-  * e1000e: correct MAC-PHY interconnect register offset for 82579
+-  * (pre-stable) ALSA: hda - Add a new hp-laptop model for Conexant 5066,
+-    tested on HP G60
+-    - LP: #587388
+-  * DSS2: Don't power off a panel twice
+-    - LP: #588243
+-  * mmc: build fix: mmc_pm_notify is only available with CONFIG_PM=y
+-  * Input: i8042 - reset keyboard controller wehen resuming from S2R
+-    - LP: #86820
+-  * ALSA: hda - Fix beep frequency on IDT 92HD73xx and 92HD71Bxx codecs
+-    - LP: #414795
+-  * agp/intel: Support the extended physical addressing bits on
+-    Sandybridge.
+-    - LP: #632488
+-  * drm/i915,intel_agp: Add support for Sandybridge D0
+-    - LP: #632488
+-  * (pre-stable) intel_agp,i915: Add more sandybridge graphics device ids
+-    - LP: #632488
+-  * mmc: omap: fix for bus width which improves SD card's peformance.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 07 Sep 2010 09:58:52 -0700
+-
+-linux (2.6.35-20.29) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: i915 KMS -- support disabling KMS for known broken devices
+-    - LP: #563277
+-  * SAUCE: i915 KMS -- blacklist i830
+-    - LP: #542208, #563277
+-  * SAUCE: i915 KMS -- blacklist i845g
+-    - LP: #541492, #563277
+-  * SAUCE: i915 KMS -- blacklist i855
+-    - LP: #511001, #541511, #563277
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_SENSORS_PKGTEMP=m
+-    - LP: #601073
+-  * ARM: Temporarily disable module check for armel
+-  * rebase to v2.6.35.4
+-  * [Config] update configs following rebase to v2.6.35.4
+-
+-  [ Ricardo Salveti de Araujo ]
+-
+-  * [Config] Change CONFIG_LEDS_TRIGGER_HEARTBEAT from module to built-in
+-    in Omap
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Added be2net, be2scsi to udebs
+-    - LP: #628776
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86, cpu: Package Level Thermal Control, Power Limit Notification
+-    definitions
+-    - LP: #601073
+-  * x86, hwmon: Package Level Thermal/Power: pkgtemp hwmon driver
+-    - LP: #601073
+-  * x86, hwmon: Package Level Thermal/Power: thermal throttling handler
+-    - LP: #601073
+-  * x86, hwmon: Package Level Thermal/Power: power limit
+-    - LP: #601073
+-  * x86, hwmon: Package Level Thermal/Power: pkgtemp documentation
+-    - LP: #601073
+-  * hid: 3m: Adjust to sequential MT HID protocol
+-  * hid: 3m: Convert to MT slots
+-  * hid: 3m: Correct touchscreen emulation
+-  * hid: 3m: Adjust major / minor axes to scale
+-  * input: bcm5974: Adjust major / minor to scale
+-  * HID: magicmouse: don't allow hidinput to initialize the device
+-  * HID: magicmouse: simplify multitouch feature request
+-  * HID: magicmouse: simplify touch data bit manipulation
+-  * HID: magicmouse: simplify touch down logic
+-  * HID: magicmouse: remove timestamp logic
+-  * HID: magicmouse: enable Magic Trackpad support
+-  * HID: magicmouse: Adjust major / minor axes to scale
+-  * mmc: fix all hangs related to mmc/sd card insert/removal during
+-    suspend/resume
+-    - LP: #477106
+-  * drm/i915: fix VGA plane disable for Ironlake+
+-    - LP: #602281
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 30 Aug 2010 08:38:01 -0700
+-
+-linux (2.6.35-19.28) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * No changes from 2.6.35-19.27.  Some armel udebs were accidentally deleted
+-    from the archive and a no-change rebuild was attempted.  However, the ABI
+-    did not get bumped and resulted in build failures for 2.6.35-19.27.  Fix
+-    up the ABI and re-upload.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sat, 28 Aug 2010 16:42:27 -0700
+-
+-linux (2.6.35-19.27) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * No changes from 2.6.35-19.26.  Some armel udebs were accidentally deleted
+-    from the archive.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 27 Aug 2010 08:58:35 -0700
+-
+-linux (2.6.35-19.26) maverick; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ARM: OMAP: Beagle: revision detection
+-  * ARM: OMAP: Beagle: only Cx boards use pin 23 for write protect
+-  * ARM: OMAP: Beagle: no gpio_wp pin connection on xM
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 26 Aug 2010 09:15:09 -0700
+-
+-linux (2.6.35-19.25) maverick; urgency=low
+-
+-  [ Jarod Wilson ]
+-
+-  * SAUCE: Bring in staging/lirc from 2.6.36
+-    - LP: #609234
+-  * SAUCE: Update ir-core to linuxtv/other which should be merged for
+-    2.6.36.
+-    - LP: #609234
+-  * SAUCE: Fix memleaks in imon and mceusb drivers
+-    - LP: #609234
+-  * SAUCE: Bring in streamzap support from linuxtv/other
+-    - LP: #609234
+-
+-  [ Mario Limonciello ]
+-
+-  * Remove ubuntu/lirc in favor of staging/lirc from 2.6.36
+-    - LP: #609234
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * SAUCE: ARM: adding i2c eeprom driver to read EDID
+-    - LP: #608279
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * intel_idle: disable module support
+-    - LP: #615265
+-  * (pre-stable) ALSA: hda - Ensure codec patch files are checked for the
+-    correct codec ID
+-  * (pre-stable) ALSA: hda - Rename iMic to Int Mic on Lenovo NB0763
+-    - LP: #605101
+-  * (pre-stable) ALSA: HDA: Use model=auto for LG R510
+-    - LP: #495134
+-  * (pre-stable) ALSA: HDA: Add Sony VAIO quirk for ALC269
+-    - LP: #519066
+-  * (pre-stable) ALSA: HDA: Fix front mic on Dell Precision M6500
+-    - LP: #519066
+-  * input: mt: Initialize slots to unused (rev2)
+-  * input: mt: Add support for the Bamboo Touch trackpad
+-  * hid: Add a hid quirk for input sync override
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 Aug 2010 12:42:52 -0700
+-
+-linux (2.6.35-18.24) maverick; urgency=low
+-
+-  [ Colin Watson ]
+-
+-  * Pass DEB_MAINT_PARAMS to hook scripts
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Add CONFIG_INPUT_UINPUT=y to config enforcer
+-    - LP: #584812
+-  * rebase to v2.6.35.3
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) dell-wmi: Add support for eject key on Dell Studio 1555
+-    - LP: #609234
+-  * can: add limit for nframes and clean up signed/unsigned variables
+-    - CVE-2010-2959
+-  * drm: Initialize ioctl struct when no user data is present
+-    - CVE-2010-2803
+-  * ARM: initial stack protector (-fstack-protector) support
+-  * ARM: stack protector: change the canary value per task
+-  * [ARM] implement arch_randomize_brk()
+-  * [ARM] add address randomization to mmap()
+-  * ARM: fix ASLR of PIE executables
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 22 Aug 2010 19:22:04 -0700
+-
+-linux (2.6.35-17.23) maverick; urgency=low
+-
+-  [ Jeremy Kerr ]
+-
+-  * [Config] build-in uinput module
+-    - LP: #584812
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Config] [FTBS] ia64: Temporarily disable CONFIG_CEPH_FS"
+-  * Revert "[Config] [FTBS] ia64: Temporarily disable gpiolib"
+-  * Revert "[Config] [FTBS] sparc: Temporarily disable
+-    CONFIG_MTD_NAND_DENALI"
+-  * Revert "[Config] [FTBS] sparc: Temporarily disable
+-    CONFIG_MFD_JANZ_CMODIO"
+-  * Revert "[Config] [FTBS] sparc: Temporarily disable
+-    CONFIG_INFINIBAND_QIB"
+-  * [Config] Enable INTEL_IPS
+-    - LP: #601057
+-  * Remove ia64 support
+-  * [Config] Update portsconfigs after removing ia64 support
+-  * Remove sparc support
+-  * [Config] Update portsconfigs after removing sparc support
+-
+-  [ Linus Torvalds ]
+-
+-  * (pre-stable) mm: fix page table unmap for stack guard page properly
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * SAUCE: (no-up) ARM: Resetting power_mode to its original value.
+-    - LP: #591941
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * timer: add on-stack deferrable timer interfaces
+-    - LP: #601057
+-  * x86 platform driver: intelligent power sharing driver
+-    - LP: #601057
+-  * IPS driver: add GPU busy and turbo checking
+-    - LP: #601057
+-  * X86: intel_ips, check for kzalloc properly
+-    - LP: #601057
+-  * ips driver: make it less chatty
+-    - LP: #601057
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 17 Aug 2010 09:38:08 -0700
+-
+-linux (2.6.35-16.22) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * debian -- more agressivly clean up after depmod on purge
+-    - LP: #618591
+-
+-  [ Henrik Rydberg ]
+-
+-  * SAUCE: hid: 3m: Simplify touchsreen emulation logic
+-
+-  [ Leann Ogasawara ]
+-
+-  * ubuntu: iscsitarget -- version 1.4.20.2
+-  * ubuntu: rtl8192se -- update to version 0017.0507.2010
+-  * rebase to v2.6.35.2
+-  * [Config] update configs following rebase to v2.6.35.2
+-  * [Config] update ports configs following rebase to v2.6.35.2
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Enable new firewire stack on powerpc
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * SAUCE: (drop after 2.6.35) ARM: Using gpmc function to init nand flash.
+-    - LP: #608266
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 12 Aug 2010 09:58:01 -0700
+-
+-linux (2.6.35-15.21) maverick; urgency=low
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] CONFIG_SND_USB_UA101=m for all architectures
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Input: introduce MT event slots
+-  * Input: document the MT event slot protocol
+-  * (pre-stable) sched: Revert nohz_ratelimit() for now
+-  * (pre-stable) drm/radeon/kms: add missing copy from user
+-    - LP: #606081
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35.1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 09 Aug 2010 09:24:04 -0700
+-
+-linux (2.6.35-14.20) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * update Vcs-Git to point to maverick repo
+-  * debian -- include the debian packaging in the -source package
+-    - LP: #608674
+-  * select debian source format 1.0
+-  * add support for building selected stages of kernel
+-    - LP: #603087
+-  * cleanup conditional dependancy handling
+-    - LP: #603087
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ALSA: hda - Handle missing NID 0x1b on ALC259 codec
+-    - LP: #582199, #586418, #588031
+-  * ALSA: hda - Handle pin NID 0x1a on ALC259/269
+-    - LP: #582199, #586418, #588031
+-  * sched: Revert nohz_ratelimit() for now
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 03 Aug 2010 08:46:47 -0700
+-
+-linux (2.6.35-14.19) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 01 Aug 2010 10:35:56 -0700
+-
+-linux (2.6.35-13.18) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: (no-up) Modularize vesafb -- fix initialisation
+-  * SAUCE: add tracing for user initiated readahead requests
+-  * SAUCE: vt -- maintain bootloader screen mode and content until vt
+-    switch
+-  * SAUCE: vt -- allow grub to request automatic vt_handoff
+-  * SAUCE: fbcon -- fix race between open and removal of framebuffers
+-  * SAUCE: drm -- stop early access to drm devices
+-
+-  [ Bryan Wu ]
+-
+-  * CONFIG: compile in OTG driver and Transceiver driver
+-    - LP: #566645
+-  * remove OTG modules from modules list file
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: -- sync to AppArmor mainline 2010-07-27
+-    - LP: #581525, #599450
+-  * SAUCE: AppArmor: -- sync to AppArmor mainline 2010-07-29
+-  * SAUCE: AppArmor 2.4 compatibility patch
+-  * SAUCE: AppArmor: Allow dfa backward compatibility with broken userspace
+-  * SAUCE: fix pv-ops for legacy Xen
+-  * SAUCE: blkfront: default to sd devices
+-  * [Config] Build in drivers required for Xen pv-ops
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Upstream] i915: Use the correct mask to detect i830 aperture
+-    size."
+-
+-  [ Lee Jones ]
+-
+-  * SAUCE: ARM: OMAP: Add macros for comparing silicon revision
+-    - LP: #608095
+-  * SAUCE: OMAP: DSS2: check for both cpu type and revision, rather than
+-    just revision
+-    - LP: #608095
+-  * SAUCE: OMAP: DSS2: enable hsclk in dsi_pll_init for OMAP36XX
+-    - LP: #608095
+-  * SAUCE: ARM: OMAP: Beagle: support twl gpio differences on xM
+-    - LP: #608095
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * agp/intel: Use the correct mask to detect i830 aperture size.
+-    - LP: #597075
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 30 Jul 2010 15:46:59 -0700
+-
+-linux (2.6.35-12.17) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35-rc6
+-  * [Config] update configs following rebase to v2.6.35-rc6
+-  * [Config] update ports configs following rebase to v2.6.35-rc6
+-  * SAUCE: [FTBS] armel: define KEY_F10 and KEYF11
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 23 Jul 2010 16:16:38 +0200
+-
+-linux (2.6.35-11.16) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Bump ABI for new compiler update 
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 23 Jul 2010 10:24:58 +0200
+-
+-linux (2.6.35-10.15) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: ensure vga16fb loads if no other driver claims the VGA
+-    device"
+-  * [Config] Enable CONFIG_M686=y
+-    - LP: #592495
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * tracing: Add alignment to syscall metadata declarations
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 20 Jul 2010 18:18:49 +0200
+-
+-linux (2.6.35-9.14) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: AUFS -- add BOM and automated update script
+-  * ubuntu: AUFS -- update to b37c575759dc4535ccc03241c584ad5fe69e3b25
+-
+-  [ John Johansen ]
+-
+-  * [Config] Enable DRBD as a module
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: Yama: verify inode is symlink to avoid bind mounts
+-    - LP: #604407
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable CONFIG_DRM_VMWGFX (staging driver)
+-    - LP: #606139
+-  * [Config] ports: Disable CONFIG_DRM_VMWGFX (staging driver)
+-    - LP: #606139
+-  * [Config] Enable CONFIG_DEBUG_STRICT_USER_COPY_CHECKS=y
+-  * [Config] ports: Enable CONFIG_DEBUG_STRICT_USER_COPY_CHECKS=y
+-
+-  [ Lee Jones ]
+-
+-  * Stop ARM boards crashing when CUPS is loaded
+-    - LP: #601226
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * perf probe: Support tracing an entry of array
+-  * perf probe: Support static and global variables
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 16 Jul 2010 14:38:17 -0700
+-
+-linux (2.6.35-8.13) maverick; urgency=low
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: Yama: check PTRACE using thread group leader
+-  * SAUCE: Yama: search for PTRACE exceptions via thread group leader
+-    - LP: #603716
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35-rc5
+-  * [Config] update configs following rebase to v2.6.35-rc5
+-
+-  [ Nicolas Pitre ]
+-
+-  * SAUCE: make ndiswrapper available on X86 only
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Added ums-cypress to udeb
+-    - LP: #576066
+-  * SAUCE: fix build error with CONFIG_BLK_DEV_INITRD=n
+-  * [Config] CONFIG_NDISWRAPPER=m across all configs
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * HID: magicmouse: report last touch up
+-  * rebase to 2.6.35-rc5
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 13 Jul 2010 18:57:59 -0700
+-
+-linux (2.6.35-7.12) maverick; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] i915: Use the correct mask to detect i830 aperture size.
+-    - LP: #597075
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (drop after 2.6.35) drm/radeon/kms: add ioport register access
+-    (squashed)
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Jul 2010 09:53:13 -0600
+-
+-linux (2.6.35-7.11) maverick; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_X86_MRST=n
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (drop after 2.6.35-rc5) writeback: remove writeback_inodes_wbc
+-  * (drop after 2.6.35-rc5) writeback: split writeback_inodes_wb
+-  * (drop after 2.6.35-rc5) writeback: simplify the write back thread queue
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 06 Jul 2010 18:39:08 -0600
+-
+-linux (2.6.35-7.10) maverick; urgency=low
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: security: create task_free security callback
+-  * SAUCE: Yama: add PTRACE exception tracking and interface
+-  * SAUCE: security: unconditionally chain to Yama LSM
+-  * Revert "SAUCE: ptrace: restrict ptrace scope to children"
+-  * Revert "SAUCE: fs: block hardlinks to non-accessible sources"
+-  * Revert "SAUCE: fs: block cross-uid sticky symlinks"
+-  * [Upstream] security: Yama LSM
+-  * [Config] Enable CONFIG_SECURITY_YAMA=y
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] updateconfigs/updateportsconfigs after rebase to 2.6.35-rc4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to 2.6.35-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 01 Jul 2010 08:55:57 -0700
+-
+-linux (2.6.35-6.9) maverick; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] direct_splice_actor() should not use pos in sd
+-    - LP: #588861
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 28 Jun 2010 12:35:49 -0700
+-
+-linux (2.6.35-6.8) maverick; urgency=low
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * ARM: Adding regulator supply for vdds_sdi.
+-    - LP: #597904
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 27 Jun 2010 16:34:43 -0700
+-
+-linux (2.6.35-6.7) maverick; urgency=low
+-
+-  [ Alberto Milone ]
+-
+-  * [Upstream] Add support for the ATIF ACPI method to the radeon driver
+-
+-  [ Chase Douglas ]
+-
+-  * [Upstream] HID: magicmouse: scroll on entire surface, not just middle
+-    of mouse
+-  * [Upstream] HID: magicmouse: disable and add module param for scroll
+-    acceleration
+-  * [Upstream] HID: magicmouse: properly account for scroll movement in
+-    state
+-  * [Upstream] HID: magicmouse: add param for scroll speed
+-  * [Upstream] HID: magicmouse: enable horizontal scrolling
+-
+-  [ Henrik Rydberg ]
+-
+-  * [Upstream] Input: evdev - convert to dynamic event buffer
+-  * [Upstream] Input: evdev - use driver hint to compute size of event
+-    buffer
+-  * [Upstream] Input: bcm5974 - set the average number of events per MT
+-    event packet
+-  * [Upstream] Input: hid-input - use a larger event buffer for MT devices
+-  * [Upstream] Input: evdev - never leave the client buffer empty after
+-    write
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: -- mainline 2010-06-23
+-  * SAUCE: AppArmor 2.4 compatibility patch
+-  * SAUCE: fs: block hardlinks to non-accessible sources AppArmor portion
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_INTR_REMAP=y
+-    - LP: #597091
+-  * [Config] Enable CONFIG_X86_X2APIC
+-    - LP: #597091
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * [Config] ARM: Turning off CONFIG_CPU_IDLE on omap
+-    - LP: #594382
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 24 Jun 2010 12:19:48 -0700
+-
+-linux (2.6.35-5.6) maverick; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * [Config] update omap flavour description
+-
+-  [ Andy Whitcroft ]
+-
+-  * update to ubuntu-debian:508b7aa34b578c0d1e51bfb571f2bfb824dc65ac
+-    - LP: #570500, #576274
+-  * SAUCE: add option to hand off all kernel parameters to init
+-    - LP: #586386
+-  * [Config] enable passing all kernel command line to init
+-    - LP: #586386
+-  * [Config] disable CONFIG_VMI
+-    - LP: #537601
+-  * [Config] enable CONFIG_IPV6_SIT_6RD
+-    - LP: #591869
+-  * [Config] enable CONFIG_VMWARE_BALOON as module
+-    - LP: #592039
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: pm: Config option to disable handling of console during
+-    suspend/resume"
+-    - LP: #594885
+-  * [Config] Remove CONFIG_PM_DISABLE_CONSOLE
+-  * [Config] ports: enable passing all kernel command line to init
+-    - LP: #586386
+-  * [Config] Enable CONFIG_FB_VESA=y for x86
+-  * [Config] Add CONFIG_FRAMEBUFFER_CONSOLE=y to config enforcer
+-  * [Config] Add CONFIG_FB_VESA=y for x86 to config enforcer
+-  * [Config] Enable CONFIG_TASK_DELAY_ACCT=y
+-    - LP: #493156
+-
+-  [ Mathieu Poirier ]
+-
+-  * ARM: Adding MosChip MCS7830 to nic-usb
+-    - LP: #584920
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "[Upstream] docbook: need xmldoclinks for all doc types"
+-  * docbook: need xmldoclinks for all doc types
+-  * perf probe: Add kernel source path option
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 17 Jun 2010 08:05:29 -0700
+-
+-linux (2.6.35-4.5) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Upstream] (evdev) Use driver hint to compute the evdev buffer
+-    size (rev2)"
+-  * Revert "[Upstream] (evdev) Convert to dynamic event buffer (rev4)"
+-  * Revert "[Upstream] (evdev) Use multi-reader buffer to save space
+-    (rev4)"
+-  * Revert "SAUCE: drivers: Remove some duplicate device entries in various
+-    modules"
+-  * [Upstream] USB: option: Remove duplicate AMOI_VENDOR_ID
+-  * [Upstream] Revert "USB: Adding support for HTC Smartphones to ipaq"
+-  * [Upstream] p54usb: Comment out duplicate Medion MD40900 device id
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_NFS_FSCACHE=y
+-    - LP: #440522
+-  * [Config] CONFIG_FSCACHE_STATS=y, CONFIG_FSCACHE_HISTOGRAM=y
+-    - LP: #440522
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 16 Jun 2010 08:43:07 -0700
+-
+-linux (2.6.35-3.4) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * debian -- ensure the version number is clean
+-
+-  [ Henrik Rydberg ]
+-
+-  * [Upstream] Introduce MT event slots (rev 5)
+-  * [Upstream] Document the MT event slot protocol (rev5)
+-  * [Upstream] (evdev) Use multi-reader buffer to save space (rev4)
+-  * [Upstream] (evdev) Convert to dynamic event buffer (rev4)
+-  * [Upstream] (evdev) Use driver hint to compute the evdev buffer size
+-    (rev2)
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: Add MODULE_ALIAS for Dell WMI module"
+-  * Revert "SAUCE: hostap: send events on data interface as well as master
+-    interface"
+-  * Revert "Fix webcam having USB ID 0ac8:303b"
+-  * Revert "SAUCE: toshiba_acpi -- pull in current -dev version of driver"
+-  * rebase to v2.6.35-rc3
+-
+-  [ Maxim Levitsky ]
+-
+-  * [Config] Enable new Smartmedia/xD translation layer
+-    - LP: #202490
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * net: fix deliver_no_wcard regression on loopback device
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.35-rc3
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 10 Jun 2010 16:15:22 -0700
+-
+-linux (2.6.35-2.3) maverick; urgency=low
+-
+-  [ Bryan Wu ]
+-
+-  * CONFIG: enforce -- make sure we disable CONFIG_LOCALVERSION_AUTO
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] armel: Enable CONFIG_BNX2=m
+-  * [Config] ports: Enable CONFIG_BNX2X=m
+-  * SAUCE: armel: define get_dma_ops to fix FTBS
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] net: Print num_rx_queues imbalance warning only when there
+-    are allocated queues
+-    - LP: #591416
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 09 Jun 2010 08:27:41 -0700
+-
+-linux (2.6.35-2.2) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] d-i: make armel configuration versatile flavour specific
+-    - LP: #588805
+-  * [Config] d-i: enable .udebs for omap flavour
+-    - LP: #588805
+-
+-  [ Kees Cook ]
+-
+-  * ptrace: limit scope to attach only (allow read)
+-    - LP: #589656
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35-rc2
+-  * [Config] update configs following rebase to v2.6.35-rc2
+-  * [Config] update port configs following rebase to v2.6.35-rc2
+-
+-  [ Lee Jones ]
+-
+-  * Enable perf to be more helpful when perf_<version> does not exist.
+-    - LP: #570500
+-  * 'fdr editconfig' modification. Easily skip over unwanted menuconfigs.
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Update bnx2 udeb firmware files
+-    - LP: #589304
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.35-rc2
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 07 Jun 2010 09:45:04 -0700
+-
+-linux (2.6.35-1.1) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: AUFS -- update to standalone 2.6.35-rcN as at 20100601
+-    - LP: #587888
+-  * ubuntu: AUFS -- track changes to the arguements to fop fsync()
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35-rc1
+-  * [Config] update configs following rebase to v2.6.35-rc1
+-  * [Config] update port configs following rebase to v2.6.35-rc1
+-  * SAUCE: lirc: rename usb_buffer_alloc() and usb_buffer_free()
+-  * SAUCE: ndiswrapper: rename usb_buffer_alloc() and usb_buffer_free()
+-  * SAUCE: ndiswrapper: convert multicast list to list_head
+-  * [Config] [FTBS] armel: Temporarily disable CONFIG_GPIO_JANZ_TTL
+-  * [Config] [FTBS] ia64: Temporarily disable gpiolib
+-  * [Config] [FTBS] ia64: Temporarily disable CONFIG_CEPH_FS
+-  * [Config] [FTBS] sparc: Temporarily disable CONFIG_INFINIBAND_QIB
+-  * [Config] [FTBS] sparc: Temporarily disable CONFIG_MFD_JANZ_CMODIO
+-  * [Config] [FTBS] armel: Temporarily disable CONFIG_MFD_JANZ_CMODIO
+-  * [Config] [FTBS] armel: Temporarily disable CONFIG_DT3155
+-  * [Config] [FTBS] sparc: Temporarily disable CONFIG_MTD_NAND_DENALI
+-  * [Config] [FTBS] armel: Temporarily disable bnx2
+-  * [Config] [FTBS] armel: Temporarily disable CONFIG_SERIAL_UARTLITE
+-  * SAUCE: [FTBS] armel: Don't include asm/agp.h for ttm
+-  * SAUCE: [FTBS] armel: include linux/dma-mapping.h
+-  * SAUCE: [FTBS] armel: replace omap_set_gpio_debounce with
+-    gpio_set_debounce
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * of/usb: fix build error due to of_node pointer move
+-  * n2_crypto: Fix build after of_device/of_platform_driver changes.
+-  * powerpc/fsl-booke: fix the case where we are not in the first page
+-  * powerpc/fsl-booke: Move the entry setup code into a seperate file
+-  * powerpc/kexec: Add support for FSL-BookE
+-  * greth: Fix build after OF device conversions.
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.35-rc1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 04 Jun 2010 23:01:52 -0700
+-
+-linux (2.6.35-1.0) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Null entry.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 Jun 2010 15:17:41 -0700
+-
+-linux (2.6.34-5.14) maverick; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Added module inclusion support
+-  * [Config] Added virtual flavour module inclusion list and d-i package
+-    definitions
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 Jun 2010 12:58:14 -0700
+-
+-linux (2.6.34-5.13) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: AUFS -- aufs2 20091209"
+-  * Revert "ubuntu: AUFS -- export various core functions
+-    (aufs2-standalone.patch)"
+-  * Revert "ubuntu: AUFS -- export various core functions
+-    (aufs2-base.patch)"
+-  * ubuntu: AUFS -- aufs2 base patch for linux-2.6.34
+-    - LP: #587888
+-  * ubuntu: AUFS -- aufs2 standalone patch for linux-2.6.34
+-    - LP: #587888
+-  * ubuntu: AUFS -- update to standalone 2.6.34 as at 20100601
+-    - LP: #587888
+-  * [Config] AUFS -- enable aufs options
+-    - LP: #587888
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 01 Jun 2010 08:56:43 -0700
+-
+-linux (2.6.34-5.12) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * enforce -- ensure SYSFS compatibility is disabled
+-
+-  [ Chase Douglas ]
+-
+-  * build with libdw-dev for perf probe symbol support
+-  * maverick ftrace configuration changes
+-
+-  [ Kees Cook ]
+-
+-  * Revert "SAUCE: x86: brk away from exec rand area"
+-  * Revert "SAUCE: [um] Don't use nx_enabled under UML"
+-  * Revert "SAUCE: [x86] implement cs-limit nx-emulation for ia32"
+-  * SAUCE: x86: implement cs-limit nx-emulation for ia32
+-    - LP: #369978
+-  * SAUCE: x86: more tightly confine cs-limit nx-emulation to ia32 only
+-  * SAUCE: x86: brk away from exec rand area
+-    - LP: #452175
+-  * SAUCE: ptrace: restrict ptrace scope to children
+-
+-  [ Leann Ogasawara ]
+-
+-  * Add new omap flavour to getabis
+-  * [Config] Enable CONFIG_FRAMEBUFFER_CONSOLE=y for all archs
+-    - LP: #585490
+-  * build/modules: Temorarily add ignore.modules
+-  * ubuntu: iscsitarget -- version 1.4.20.1
+-
+-  [ Loïc Minier ]
+-
+-  * SAUCE: [um] Don't use nx_enabled under UML
+-    - LP: #524849
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 28 May 2010 08:27:17 -0700
+-
+-linux (2.6.34-4.11) maverick; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * SAUCE: omap: remove calls to usb_nop_xceiv_register from board files
+-  * [Config] Add support for OMAP-mainline flavour
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: powerpc: fix compile error when ptrace.h is included from
+-    userspace
+-    - LP: #583733
+-
+-  [ Chase Douglas ]
+-
+-  * Revert "SAUCE: Don't register vga16fb framebuffer if other framebuffers
+-    are present"
+-  * Revert "SAUCE: Disable function tracing after hitting __schedule_bug"
+-  * Revert "SAUCE: drm/i915: don't change DRM configuration when releasing
+-    load detect pipe"
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: fs: block cross-uid sticky symlinks
+-  * SAUCE: fs: block hardlinks to non-accessible sources
+-
+-  [ Koen Kooi ]
+-
+-  * SAUCE: board-omap3-beagle: add DSS2 support
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "staging/go7007 -- disable"
+-  * Revert "[Config] staging/winbond -- disable"
+-  * Revert "Disable 4MB page tables for Atom, work around errata AAE44"
+-  * Revert "SAUCE: sync before umount to reduce time taken by ext4 umount"
+-  * Revert "SAUCE: Enable an e1000e Intel Corporation 82567 Gigabit
+-    controller"
+-  * Revert "SAUCE: Fix MODULE_IMPORT/MODULE_EXPORT"
+-  * Revert "SAUCE: Created MODULE_EXPORT/MODULE_IMPORT macros"
+-  * Revert "SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps"
+-  * Revert "SAUCE: r8169: disable TSO by default for RTL8111/8168B
+-    chipsets."
+-  * Revert "[Upstream] b43: Declare all possible firmware files."
+-  * Revert "add Breaks: against hardy lvm2"
+-  * Revert "SAUCE: Guest OS does not recognize a lun with non zero target
+-    id on Vmware ESX Server"
+-  * Revert "SAUCE: Catch nonsense keycodes and silently ignore"
+-  * [Config] Enable CONFIG_ECRYPT_FS=y for ports
+-  * [Config] Enable CONFIG_USB=y for armel and sparc
+-  * [Config] Enable CONFIG_SCSI=y for ia64 and sparc
+-  * [Config] Enable CONFIG_RFKILL=y for ports
+-  * [Config] Enable CONFIG_ATH9K_DEBUGFS=y
+-  * [Config] Enable CONFIG_IWMC3200TOP_DEBUGFS=y
+-  * [Config] Enable CONFIG_RCU_FAST_NO_HZ=y
+-  * [Config] Enable CONFIG_IWLWIFI_DEVICE_TRACING=y
+-  * [Config] Enable CONFIG_LIBERTAS_MESH=y
+-  * [Config] Enable CONFIG_MMC_RICOH_MMC=y
+-  * [Config] CONFIG_RT2800USB_UNKNOWN=y
+-  * [Config] Enable CONFIG_VGA_SWITCHEROO=y
+-  * [Config] Enable CONFIG_CEPH_FS=m
+-  * [Config] Enable CONFIG_CRYPTO_PCRYPT=m
+-  * [Config] Enable CONFIG_EEEPC_WMI=m
+-  * [Config] Enable CONFIG_RT2800PCI=m
+-  * [Config] Enable CONFIG_SCSI_HPSA=m
+-  * [Config] Enable CONFIG_VHOST_NET=m
+-  * [Config] Disable CONFIG_SND_HDA_INPUT_BEEP_MODE by default
+-    - LP: #582350
+-  * [Config] Disable CONFIG_SOUND_OSS* and CONFIG_SND_*OSS
+-    - LP: #579300
+-  * [Config] Enable CONFIG_PCIEASPM=y
+-    - LP: #333990
+-  * [Config] updateconfigs for OMAP flavour
+-
+-  [ Loïc Minier ]
+-
+-  * Enable perf tools on armel
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: Updated ndiswrapper to 1.56
+-    - LP: #582555
+-  * [Config] Added virtual flavour
+-  * [Config] Remove support for sub-flavours
+-  * [Config] Removed amd64 preempt flavour
+-  * [Config] updateconfigs, updateportsconfigs after flavour munging
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 25 May 2010 09:34:55 -0700
+-
+-linux (2.6.34-3.10) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.34
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 18 May 2010 17:35:35 -0700
+-
+-linux (2.6.34-2.9) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] [FTBS] Disable comedi for armel
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 13 May 2010 23:20:55 +0200
+-
+-linux (2.6.34-2.8) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Drop lpia
+-  * [Config] [FTBS] disable KVM
+-  * [Config] [FTBS] disable ipr for armel
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 13 May 2010 16:07:52 +0200
+-
+-linux (2.6.34-2.7) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] disable CONFIG_SCSI_IPR on powerpc
+-  * [Config] Remove 386 flavour per UDS discussion
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 12 May 2010 18:26:43 +0200
+-
+-linux (2.6.34-1.6) maverick; urgency=low
+-
+-  [ Chase Douglas ]
+-
+-  * enforce CONFIG_TMPFS_POSIX_ACL=y
+-    - LP: #575940
+-  * don't force module dependency checking
+-    - LP: #577029
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: mmap_min_addr check CAP_SYS_RAWIO only for write
+-    - LP: #568844
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: ata: blacklist FUJITSU MHW2160BH PL"
+-  * rebase to v2.6.34-rc7
+-  * [Config] update configs following rebase to v2.6.34-rc7
+-  * [Config] update port configs following rebase to v2.6.34-rc7
+-  * Add btrfs to the udebs
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add atl1c to nic-modules udeb
+-    - LP: #557130
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc7
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 11 May 2010 11:29:08 +0200
+-
+-linux (2.6.34-1.5) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.34-rc6
+-  * [Config] update configs following rebase to v2.6.34-rc6
+-  * [Config] update port configs following rebase to v2.6.34-rc6
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 30 Apr 2010 15:54:05 +0100
+-
+-linux (2.6.34-1.4) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.34-rc5
+-  * [Config] update ports configs following rebase to v2.6.34-rc5
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc5
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 22 Apr 2010 15:36:12 -0700
+-
+-linux (2.6.34-1.3) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.34-rc4
+-  * [Config] update configs following rebase to v2.6.34-rc4
+-  * [Config] update port configs following rebase to v2.6.34-rc4
+-  * ubuntu: dm-raid4-5 -- update to compile with 2.6.34-rc4
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 13 Apr 2010 18:33:44 -0700
+-
+-linux (2.6.34-1.2) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Temorarily disable building linux-doc
+-  * rebase to v2.6.34-rc3
+-  * [Config] update configs following rebase to v2.6.34-rc3
+-  * [Config] update port configs following rebase to v2.6.34-rc3
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc3
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 30 Mar 2010 16:55:44 -0700
+-
+-linux (2.6.34-1.1) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.34-rc2
+-  * ubuntu: dm-raid4-5 -- update to compile with 2.6.34-rc2
+-  * [Config] update port configs following rebase to v2.6.34-rc2
+-  * [Config] update configs following rebase to v2.6.34-rc2
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc2
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 24 Mar 2010 23:00:39 -0700
+-
+-linux (2.6.33-1.1) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * ubuntu: dm-raid4-5 -- update to compile with 2.6.33
+-  * ubuntu: lirc -- drop explicit include of linux/autoconf.h
+-  * ubuntu: lirc -- pass kfifo to kfifo_alloc and move spinlock
+-  * ubuntu: lirc -- rename kfifo_put and kfifo_get
+-  * ubuntu: iscsitarget -- rename daddr inet_sock field
+-  * rebased to v2.6.33
+-  * [Config] update configs following rebase to v2.6.33
+-  * [Config] update ports configs following rebase to v2.6.33
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.33
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 23 Mar 2010 03:55:46 -0700
+-
+-linux (2.6.33-0.0) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Null entry.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 17 Mar 2010 07:48:56 -0700
+-
+-linux (2.6.32-16.25) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * linux-tools -- move to Suggests: with explicit seeding
+-    - LP: #534635
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_HID=m
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) sched: Fix SMT scheduler regression in
+-    find_busiest_queue()
+-  * KVM: introduce kvm_vcpu_on_spin
+-  * KVM: VMX: Add support for Pause-Loop Exiting
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 09 Mar 2010 14:13:51 +0000
+-
+-linux (2.6.32-16.24) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * armel -- perf userspace does not support arm
+-  * ia64 -- libelf-dev/binutils-dev to not provide necessary libraries
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 06 Mar 2010 11:42:12 +0000
+-
+-linux (2.6.32-16.23) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: PM report driver and device suspend/resume times -- move config
+-  * update to standards version 3.8.4.0
+-  * printenv -- expose all of the package selectors
+-  * source package -- cleanup source content control
+-  * doc package -- ensure we do build package content on buildd
+-  * lintian -- correct the address in the debian/copyright
+-  * lintian -- update debhelper package version dependancy
+-  * lintian -- fix ghostscript dependancy
+-  * lintian -- add required misc:Depends
+-  * lintian -- move our debhelper compat level to debian/compat
+-  * perf -- build the kernel carried tools
+-  * perf -- add linux-tools carrying the version switches and manuals
+-  * SAUCE: fix up Kconfig for staging drivers
+-  * [Config] enable NOUVEAU etc following drm backport
+-  * update DRM to mainline v2.6.33
+-  * [Config] Remove AppArmor config options that no longer exist (ports)
+-  * [Config] updateportsconfigs following drm update
+-
+-  [ John Johansen ]
+-
+-  * ubuntu: AppArmor -- update to mainline 2010-03-04
+-  * SAUCE: AppArmor: Reintroduce AppArmor 2.4 compatibility
+-  * SAUCE: AppArmor: replace strim with strstrip for 2.6.32 kernels
+-  * [Config] Remove AppArmor config options that no longer exist
+-
+-  [ Manoj Iyer ]
+-
+-  * ubuntu: rtl8192se -- version 2010-0115,0014
+-    - LP: #530275
+-  * [Config] added CONFIG_RTL8192SE module.
+-    - LP: #530275
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Added vmw_pvscsi to d-i/scsi-modules
+-    - LP: #531017
+-  * [Upstream] netfilter: xt_recent: Add an entry reaper
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "KVM: x86 emulator: Check CPL level during privilege instruction
+-    emulation"
+-  * Revert "KVM: x86 emulator: Fix popf emulation"
+-  * Revert "KVM: x86 emulator: Check IOPL level during io instruction
+-    emulation"
+-  * Revert "KVM: x86 emulator: Add Virtual-8086 mode of emulation"
+-  * Revert "KVM: fix memory access during x86 emulation."
+-  * Add vlan (8021.Q) module package for d-i.
+-  * (pre-stable) drm/i915: blacklist lid status: Sony VGN-BX196VP, Dell
+-    Inspiron 700m
+-    - LP: #515246
+-  * [Upstream] docbook: need xmldoclinks for all doc types
+-  * x86: set_personality_ia32() misses force_personality32
+-  * lib: Introduce generic list_sort function
+-  * drm/nv50: Implement ctxprog/state generation.
+-  * drm/nv50: Remove redundant/incorrect ctxvals initialisation.
+-  * (pre-stable) drm/i915: blacklist lid status: Sony VGN-BX196VP, Dell
+-    Inspiron 700m
+-    - LP: #515246
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Mar 2010 15:40:38 +0000
+-
+-linux (2.6.32-15.22) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Config] added new config option CONFIG_SR_REPORT_TIME_LIMIT"
+-  * Revert "SAUCE: PM report driver and device suspend/resume times."
+-  * [Config] set CONFIG_SR_REPORT_TIME_LIMIT
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: PM report driver and device suspend/resume times.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 02 Mar 2010 01:35:37 +0000
+-
+-linux (2.6.32-15.21) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "(pre-stable) drm/i915: Increase fb alignment to 64k"
+-  * Revert "[Config] lenovo-sl-laptop -- enable"
+-  * Revert "ubuntu: lenovo-sl-laptop -- git tip (b19a08f81f)"
+-  * armel -- cramfs module will no longer be built
+-  * d-i -- make all modules optional
+-  * rename the debug packages to match archive standard
+-    - LP: #527837
+-  * lenovo-sl-laptop is no longer built
+-
+-  [ Colin Ian King ]
+-
+-  * Disable 4MB page tables for Atom, work around errata AAE44
+-    - LP: #523112
+-
+-  [ Colin Watson ]
+-
+-  * ubuntu: dm-raid4-5: Depend on XOR_BLOCKS
+-  * ubuntu: fsam7400: Depend on CHECK_SIGNATURE
+-
+-  [ Jesse Barnes ]
+-
+-  * SAUCE: drm/i915: don't change DRM configuration when releasing load
+-    detect pipe
+-    - LP: #488328
+-
+-  [ Loïc Minier ]
+-
+-  * [Config] armel Update versatile initrd configs
+-    - LP: #524893
+-  * SAUCE: [um] Don't use nx_enabled under UML
+-    - LP: #524849
+-
+-  [ Manoj Iyer ]
+-
+-  * [Config] added new config option CONFIG_SR_REPORT_TIME_LIMIT
+-
+-  [ Mario Limonciello ]
+-
+-  * SAUCE: v3 - Add Dell Business Class Netbook LED driver
+-
+-  [ Rafael J. Wysocki ]
+-
+-  * SAUCE: PM report driver and device suspend/resume times.
+-
+-  [ Surbhi Palande ]
+-
+-  * Revert "[Upstream] e1000e: enhance frame fragment detection"
+-    - CVE-2009-4538
+-  * Revert "[Upstream] e1000: enhance frame fragment detection"
+-    - CVE-2009-4536
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enabled CONFIG_LEDS_DELL_NETBOOKS=m
+-  * SAUCE: (pre-stable) netfilter: xt_recent: fix buffer overflow
+-  * SAUCE: (pre-stable) netfilter: xt_recent: fix false match
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "(pre-stable) eCryptfs: Add getattr function"
+-  * Fix potential crash with sys_move_pages
+-  * futex_lock_pi() key refcnt fix
+-  * futex: Handle user space corruption gracefully
+-  * futex: Handle futex value corruption gracefully
+-  * Fix race in tty_fasync() properly
+-  * hwmon: (w83781d) Request I/O ports individually for probing
+-  * hwmon: (lm78) Request I/O ports individually for probing
+-  * hwmon: (adt7462) Wrong ADT7462_VOLT_COUNT
+-  * ALSA: ctxfi - fix PTP address initialization
+-  * drm/i915: disable hotplug detect before Ironlake CRT detect
+-  * drm/i915: enable self-refresh on 965
+-  * drm/i915: Disable SR when more than one pipe is enabled
+-  * drm/i915: Fix DDC on some systems by clearing BIOS GMBUS setup.
+-  * drm/i915: Add HP nx9020/SamsungSX20S to ACPI LID quirk list
+-  * drm/i915: Fix the incorrect DMI string for Samsung SX20S laptop
+-  * drm/i915: Add MALATA PC-81005 to ACPI LID quirk list
+-  * usb: r8a66597-hcd: Flush the D-cache for the pipe-in transfer buffers.
+-  * i2c-tiny-usb: Fix on big-endian systems
+-  * drm/i915: handle FBC and self-refresh better
+-  * drm/i915: Increase fb alignment to 64k
+-  * drm/i915: Update write_domains on active list after flush.
+-  * regulator: Fix display of null constraints for regulators
+-  * ALSA: hda-intel: Avoid divide by zero crash
+-  * CPUFREQ: Fix use after free of struct powernow_k8_data
+-  * freeze_bdev: don't deactivate successfully frozen MS_RDONLY sb
+-  * cciss: Make cciss_seq_show handle holes in the h->drv[] array
+-  * ioat: fix infinite timeout checking in ioat2_quiesce
+-  * resource: add helpers for fetching rlimits
+-  * fs/exec.c: restrict initial stack space expansion to rlimit
+-  * cifs: fix length calculation for converted unicode readdir names
+-  * NFS: Fix a reference leak in nfs_wb_cancel_page()
+-  * NFS: Try to commit unstable writes in nfs_release_page()
+-  * NFSv4: Don't allow posix locking against servers that don't support it
+-  * NFSv4: Ensure that the NFSv4 locking can recover from stateid errors
+-  * NFS: Fix an Oops when truncating a file
+-  * NFS: Fix a umount race
+-  * NFS: Fix a bug in nfs_fscache_release_page()
+-  * NFS: Fix the mapping of the NFSERR_SERVERFAULT error
+-  * md: fix 'degraded' calculation when starting a reshape.
+-  * V4L/DVB: dvb-core: fix initialization of feeds list in demux filter
+-  * Export the symbol of getboottime and mmonotonic_to_bootbased
+-  * kvmclock: count total_sleep_time when updating guest clock
+-  * KVM: PIT: control word is write-only
+-  * tpm_infineon: fix suspend/resume handler for pnp_driver
+-  * amd64_edac: Do not falsely trigger kerneloops
+-  * netfilter: nf_conntrack: fix memory corruption with multiple namespaces
+-  * netfilter: nf_conntrack: per netns nf_conntrack_cachep
+-  * netfilter: nf_conntrack: restrict runtime expect hashsize modifications
+-  * netfilter: xtables: compat out of scope fix
+-  * netfilter: nf_conntrack: fix hash resizing with namespaces
+-  * drm/i915: remove full registers dump debug
+-  * drm/i915: add i915_lp_ring_sync helper
+-  * drm/i915: Don't wait interruptible for possible plane buffer flush
+-  * dasd: remove strings from s390dbf
+-  * crypto: padlock-sha - Add import/export support
+-  * wmi: Free the allocated acpi objects through wmi_get_event_data
+-  * dell-wmi, hp-wmi, msi-wmi: check wmi_get_event_data() return value
+-  * /dev/mem: introduce size_inside_page()
+-  * devmem: check vmalloc address on kmem read/write
+-  * devmem: fix kmem write bug on memory holes
+-  * SCSI: mptfusion : mptscsih_abort return value should be SUCCESS instead
+-    of value 0.
+-  * sh: Couple kernel and user write page perm bits for CONFIG_X2TLB
+-  * ALSA: hda - use WARN_ON_ONCE() for zero-division detection
+-  * dst: call cond_resched() in dst_gc_task()
+-  * ALSA: hda - Improved MacBook (Pro) 5,1 / 5,2 support
+-  * befs: fix leak
+-  * rtc-fm3130: add missing braces
+-  * Call flush_dcache_page after PIO data transfers in libata-sff.c
+-  * ahci: add Acer G725 to broken suspend list
+-  * pktgen: Fix freezing problem
+-  * x86/amd-iommu: Fix IOMMU-API initialization for iommu=pt
+-  * x86/amd-iommu: Fix deassignment of a device from the pt_domain
+-  * x86: Re-get cfg_new in case reuse/move irq_desc
+-  * Staging: fix rtl8187se compilation errors with mac80211
+-  * ALSA: usb-audio - Avoid Oops after disconnect
+-  * serial: 8250: add serial transmitter fully empty test
+-  * sysfs: sysfs_sd_setattr set iattrs unconditionally
+-  * class: Free the class private data in class_release
+-  * USB: usbfs: only copy the actual data received
+-  * USB: usbfs: properly clean up the as structure on error paths
+-  * rtl8187: Add new device ID
+-  * ACPI: Add NULL pointer check in acpi_bus_start
+-  * ACPI: fix High cpu temperature with 2.6.32
+-  * drm/radeon/kms: use udelay for short delays
+-  * NFS: Too many GETATTR and ACCESS calls after direct I/O
+-  * eCryptfs: Add getattr function
+-  * b43: Fix throughput regression
+-  * ath9k: Fix sequence numbers for PAE frames
+-  * mac80211: Fix probe request filtering in IBSS mode
+-  * iwlwifi: Fix to set correct ht configuration
+-  * dm stripe: avoid divide by zero with invalid stripe count
+-  * dm log: userspace fix overhead_size calcuations
+-  * Linux 2.6.32.9
+-  * sfc: Fix SFE4002 initialisation
+-  * sfc: Fix sign of efx_mcdi_poll_reboot() error in efx_mcdi_poll()
+-  * sfc: SFE4002/SFN4112F: Widen temperature and voltage tolerances
+-  * (pre-stable) HID: handle joysticks with large number of buttons
+-    - LP: #492056
+-  * (pre-stable) HID: extend mask for BUTTON usage page
+-    - LP: #492056
+-  * PM: Measure device suspend and resume times
+-  * e1000: enhance frame fragment detection
+-    - CVE-2009-4536
+-  * e1000e: enhance frame fragment detection
+-    - CVE-2009-4538
+-  * KVM: fix memory access during x86 emulation.
+-    - CVE-2010-0306
+-  * KVM: x86 emulator: Add Virtual-8086 mode of emulation
+-    - CVE-2010-0306
+-  * KVM: x86 emulator: Check IOPL level during io instruction emulation
+-    - CVE-2010-0306
+-  * KVM: x86 emulator: Fix popf emulation
+-    - CVE-2010-0306
+-  * KVM: x86 emulator: Check CPL level during privilege instruction
+-    emulation
+-    - CVE-2010-0306
+-  * Input: wacom - ensure the device is initialized properly upon resume
+-  * Input: wacom - add defines for packet lengths of various devices
+-  * Input: wacom - add support for new LCD tablets
+-    - LP: #516777
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 01 Mar 2010 22:56:28 +0000
+-
+-linux (2.6.32-14.20) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebuild following the GCC update to match compiler for out of tree modules
+-  * Revert "[Config] drbd -- enable"
+-  * Revert "ubuntu: drbd -- version 8.3.1"
+-  * SAUCE: khubd -- switch USB product/manufacturer/serial handling to RCU
+-    - LP: #510937
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 19 Feb 2010 18:47:18 +0000
+-
+-linux (2.6.32-14.19) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ensure we build the source package contents when enabled
+-    - LP: #522308
+-  * [Config] enable CONFIG_X86_MCE_XEON75XX
+-  * SAUCE: AppArmor -- add linux/kref.h for struct kref
+-  * [Config] enable CONFIG_HID_ORTEK
+-  * enable udeb generation for arm versatile flavour
+-    - LP: #522515
+-
+-  [ John Johansen ]
+-
+-  * ubuntu: AppArmor -- update to mainline 2010-02-18
+-    - LP: #439560, #496110, #507069
+-
+-  [ Johnathon Harris ]
+-
+-  * SAUCE: HID: add support for Ortek WKB-2000
+-    - LP: #405390
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * tpm_tis: TPM_STS_DATA_EXPECT workaround
+-    - LP: #490487
+-  * x86, mce: Xeon75xx specific interface to get corrected memory error
+-    information
+-  * x86, mce: Rename cpu_specific_poll to mce_cpu_specific_poll
+-  * x86, mce: Make xeon75xx memory driver dependent on PCI
+-  * drm/edid: Unify detailed block parsing between base and extension
+-    blocks
+-    - LP: #500999
+-  * (pre-stable) eCryptfs: Add getattr function
+-    - LP: #390833
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 18 Feb 2010 19:22:02 +0000
+-
+-linux (2.6.32-13.18) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "enforcer -- make the enforcement configuration common"
+-  * Revert "(pre-stable) Input: ALPS - add interleaved protocol support
+-    (Dell E6x00 series)"
+-  * Revert "(pre-stable) driver-core: fix devtmpfs crash on s390"
+-  * Revert "(pre-stable) Driver-Core: devtmpfs - set root directory mode to
+-    0755"
+-  * Revert "SAUCE: Adds support for COMPAL JHL90 webcam"
+-  * Revert "SAUCE: fix kernel oops in VirtualBox during paravirt patching"
+-  * Revert "SAUCE: make fc transport removal of target configurable"
+-  * enforcer -- make the enforcement configuration common
+-  * getabis -- add preempt flavour to the list
+-  * [Config] enforce DEVTMPFS options
+-  * [Config] armel -- cleanup to-be builtin modules
+-  * [Config] cleanup ports configs
+-  * [Config] enable CRYPTO_GHASH_CLMUL_NI_INTEL
+-    - LP: #485536
+-  * add printdebian target to find branch target
+-  * distclean -- do not remove debian.env
+-  * [Config] generic-pae switch to M586TSC
+-    - LP: #519448
+-  * git-ubuntu-log -- commonise duplicated log handling
+-  * git-ubuntu-log -- tighten up Bug: NNNN matching
+-  * git-ubuntu-log -- sort the bug numbers
+-
+-  [ Chris Wilson ]
+-
+-  * (pre-stable) drm/i915: Increase fb alignment to 64k
+-    - LP: #404064
+-
+-  [ Eric Miao ]
+-
+-  * arm -- enable ubuntu/ directory
+-
+-  [ Huang Ying ]
+-
+-  * SAUCE: crypto: ghash - Add PCLMULQDQ accelerated implementation
+-  * SAUCE: crypto: ghash-intel - Fix building failure on x86_32
+-
+-  [ Loïc Minier ]
+-
+-  * [Config] cleanup preempt configuration
+-  * [Config] versatile: Fix video output
+-    - LP: #517594
+-  * [Config] armel DEFAULT_MMAP_MIN_ADDR=32768
+-  * [Config] Large update to armel/versatile
+-  * [Config] versatile: Add RTC support
+-  * [Config] armel: Enable NEON
+-  * [Config] versatile: Builtin MMC support
+-  * [Config] versatile Builtin SCSI controller
+-  * [Config] armel Disable dma_cache_sync callers
+-  * [Config] armel Disable asm/time.h users
+-  * [Config] armel Disable out of range udelay()
+-  * [Config] armel Disable flush_cache_range() users
+-  * [Config] armel -- Enable ubuntu/ drivers
+-
+-  [ Steve Conklin ]
+-
+-  * SAUCE: drm/i915: Add display hotplug event on Ironlake
+-  * SAUCE: drm/i915: Add ACPI OpRegion support for Ironlake
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "[Upstream]: oprofile/x86: add Xeon 7500 series support"
+-  * Revert "Revert "[Bluetooth] Eliminate checks for impossible conditions
+-    in IRQ handler""
+-  * clockevent: Don't remove broadcast device when cpu is dead
+-  * clockevents: Add missing include to pacify sparse
+-  * ACPI: don't cond_resched if irq is disabled
+-  * be2net: Add support for next generation of BladeEngine device.
+-  * be2net: Add the new PCI IDs to PCI_DEVICE_TABLE.
+-  * mpt2sas: New device SAS2208 support is added
+-  * ar9170: Add support for D-Link DWA 160 A2
+-  * powerpc/fsl: Add PCI device ids for new QoirQ chips
+-  * davinci: dm646x: Add support for 3.x silicon revision
+-  * Input: ALPS - add interleaved protocol support (Dell E6x00 series)
+-  * Driver-Core: devtmpfs - set root directory mode to 0755
+-  * driver-core: fix devtmpfs crash on s390
+-  * vfs: get_sb_single() - do not pass options twice
+-  * ALSA: hda - Add PCI IDs for Nvidia G2xx-series
+-  * V4L/DVB (13569): smsusb: add autodetection support for five additional
+-    Hauppauge USB IDs
+-  * USB: mos7840: add device IDs for B&B electronics devices
+-  * USB: ftdi_sio: add USB device ID's for B&B Electronics line
+-  * V4L/DVB (13168): Add support for Asus Europa Hybrid DVB-T card (SAA7134
+-    SubVendor ID: 0x1043 Device ID: 0x4847)
+-  * iTCO_wdt: Add support for Intel Ibex Peak
+-  * atl1c:use common_task instead of reset_task and link_chg_task
+-  * atl1e:disable NETIF_F_TSO6 for hardware limit
+-  * V4L/DVB (13680a): DocBook/media: copy images after building HTML
+-  * V4L/DVB (13680b): DocBook/media: create links for included sources
+-  * netfilter: xtables: fix conntrack match v1 ipt-save output
+-  * partitions: read whole sector with EFI GPT header
+-  * partitions: use sector size for EFI GPT
+-  * ALSA: ice1724 - Patch for suspend/resume for ESI Juli@
+-  * sched: Fix isolcpus boot option
+-  * sched: Fix missing sched tunable recalculation on cpu add/remove
+-  * nohz: Prevent clocksource wrapping during idle
+-  * nfsd: Fix sort_pacl in fs/nfsd/nf4acl.c to actually sort groups
+-  * timers, init: Limit the number of per cpu calibration bootup messages
+-  * PCI: Always set prefetchable base/limit upper32 registers
+-  * iscsi class: modify handling of replacement timeout
+-  * NFS: Revert default r/wsize behavior
+-  * HID: fixup quirk for NCR devices
+-  * scsi_devinfo: update Hitachi entries (v2)
+-  * scsi_dh: create sysfs file, dh_state for all SCSI disk devices
+-  * scsi_transport_fc: remove invalid BUG_ON
+-  * lpfc: fix hang on SGI ia64 platform
+-  * libfc: fix typo in retry check on received PRLI
+-  * libfc: fix ddp in fc_fcp for 0 xid
+-  * fcoe: remove redundant checking of netdev->netdev_ops
+-  * libfc: Fix wrong scsi return status under FC_DATA_UNDRUN
+-  * libfc: lport: fix minor documentation errors
+-  * libfc: don't WARN_ON in lport_timeout for RESET state
+-  * fcoe: initialize return value in fcoe_destroy
+-  * libfc: Fix frags in frame exceeding SKB_MAX_FRAGS in fc_fcp_send_data
+-  * libfc: fix memory corruption caused by double frees and bad error
+-    handling
+-  * libfc: fix free of fc_rport_priv with timer pending
+-  * libfc: remote port gets stuck in restart state without really
+-    restarting
+-  * fcoe, libfc: fix an libfc issue with queue ramp down in libfc
+-  * fcoe: Fix checking san mac address
+-  * fcoe: Fix getting san mac for VLAN interface
+-  * qlge: Remove explicit setting of PCI Dev CTL reg.
+-  * qlge: Set PCIE max read request size.
+-  * qlge: Don't fail open when port is not initialized.
+-  * qlge: Add handler for DCBX firmware event.
+-  * qlge: Bonding fix for mode 6.
+-  * PCI: AER: fix aer inject result in kernel oops
+-  * DMI: allow omitting ident strings in DMI tables
+-  * Input: i8042 - remove identification strings from DMI tables
+-  * Input: i8042 - add Gigabyte M1022M to the noloop list
+-  * Input: i8042 - add Dritek quirk for Acer Aspire 5610.
+-  * ALSA: hda - select IbexPeak handler for Calpella
+-  * ALSA: hda - Fix quirk for Maxdata obook4-1
+-  * ALSA: hda - Add missing Line-Out and PCM switches as slave
+-  * iTCO_wdt.c - cleanup chipset documentation
+-  * iTCO_wdt: add PCI ID for the Intel EP80579 (Tolapai) SoC
+-  * iTCO_wdt: Add Intel Cougar Point and PCH DeviceIDs
+-  * ahci: disable SNotification capability for ich8
+-  * ata_piix: fix MWDMA handling on PIIX3
+-  * md: fix small irregularity with start_ro module parameter
+-  * V4L/DVB (13826): uvcvideo: Fix controls blacklisting
+-  * cio: fix double free in case of probe failure
+-  * cio: dont panic in non-fatal conditions
+-  * netiucv: displayed TX bytes value much too high
+-  * ipc ns: fix memory leak (idr)
+-  * ALSA: hda - Fix HP T5735 automute
+-  * hwmon: (fschmd) Fix a memleak on multiple opens of /dev/watchdog
+-  * UBI: fix memory leak in update path
+-  * UBI: initialise update marker
+-  * ASoC: fix a memory-leak in wm8903
+-  * mac80211: check that ieee80211_set_power_mgmt only handles STA
+-    interfaces.
+-  * cfg80211: fix channel setting for wext
+-  * KVM: S390: fix potential array overrun in intercept handling
+-  * KVM: only allow one gsi per fd
+-  * KVM: Fix race between APIC TMR and IRR
+-  * KVM: MMU: bail out pagewalk on kvm_read_guest error
+-  * KVM: x86: Fix host_mapping_level()
+-  * KVM: x86: Fix probable memory leak of vcpu->arch.mce_banks
+-  * KVM: x86: Fix leak of free lapic date in kvm_arch_vcpu_init()
+-  * KVM: fix lock imbalance in kvm_*_irq_source_id()
+-  * KVM: only clear irq_source_id if irqchip is present
+-  * IPoIB: Clear ipoib_neigh.dgid in ipoib_neigh_alloc()
+-  * x86: Reenable TSC sync check at boot, even with NONSTOP_TSC
+-  * ACPI: enable C2 and Turbo-mode on Nehalem notebooks on A/C
+-    - LP: #516325
+-  * iwlwifi: Fix throughput stall issue in HT mode for 5000
+-  * fnctl: f_modown should call write_lock_irqsave/restore
+-  * x86, msr/cpuid: Pass the number of minors when unregistering MSR and
+-    CPUID drivers.
+-  * Linux 2.6.32.7
+-  * scsi_lib: Fix bug in completion of bidi commands
+-  * mptsas: Fix issue with chain pools allocation on katmai
+-  * mm: add new 'read_cache_page_gfp()' helper function
+-  * drm/i915: Selectively enable self-reclaim
+-  * firewire: ohci: fix crashes with TSB43AB23 on 64bit systems
+-  * S390: fix single stepped svcs with TRACE_IRQFLAGS=y
+-  * x86: Set hotpluggable nodes in nodes_possible_map
+-  * x86: Remove "x86 CPU features in debugfs" (CONFIG_X86_CPU_DEBUG)
+-  * libata: retry FS IOs even if it has failed with AC_ERR_INVALID
+-  * zcrypt: Do not remove coprocessor for error 8/72
+-  * dasd: fix possible NULL pointer errors
+-  * ACPI: Add a generic API for _OSC -v2
+-  * ACPI: Add platform-wide _OSC support.
+-  * ACPI: fix OSC regression that caused aer and pciehp not to load
+-  * ACPI: Advertise to BIOS in _OSC: _OST on _PPC changes
+-  * UBI: fix volume creation input checking
+-  * e1000/e1000e: don't use small hardware rx buffers
+-  * drm/i915: Reload hangcheck timer too for Ironlake
+-  * Fix a leak in affs_fill_super()
+-  * Fix failure exits in bfs_fill_super()
+-  * fix oops in fs/9p late mount failure
+-  * fix leak in romfs_fill_super()
+-  * Fix remount races with symlink handling in affs
+-  * fix affs parse_options()
+-  * Fix failure exit in ipathfs
+-  * mm: fix migratetype bug which slowed swapping
+-  * FDPIC: Respect PT_GNU_STACK exec protection markings when creating
+-    NOMMU stack
+-  * Split 'flush_old_exec' into two functions
+-  * sparc: TIF_ABI_PENDING bit removal
+-  * x86: get rid of the insane TIF_ABI_PENDING bit
+-  * Input: winbond-cir - remove dmesg spam
+-  * x86: Disable HPET MSI on ATI SB700/SB800
+-  * iwlwifi: set default aggregation frame count limit to 31
+-  * drm/i915: only enable hotplug for detected outputs
+-  * firewire: core: add_descriptor size check
+-  * SECURITY: selinux, fix update_rlimit_cpu parameter
+-  * regulator: Specify REGULATOR_CHANGE_STATUS for WM835x LED constraints
+-  * x86: Add Dell OptiPlex 760 reboot quirk
+-    - LP: #488319
+-  * x86: Add quirk for Intel DG45FC board to avoid low memory corruption
+-  * x86/amd-iommu: Fix possible integer overflow
+-  * clocksource: fix compilation if no GENERIC_TIME
+-  * tcp: update the netstamp_needed counter when cloning sockets
+-  * sky2: Fix oops in sky2_xmit_frame() after TX timeout
+-  * net: restore ip source validation
+-  * af_packet: Don't use skb after dev_queue_xmit()
+-  * ax25: netrom: rose: Fix timer oopses
+-  * KVM: allow userspace to adjust kvmclock offset
+-  * oprofile/x86: add Xeon 7500 series support
+-  * oprofile/x86: fix crash when profiling more than 28 events
+-  * libata: retry link resume if necessary
+-  * mm: percpu-vmap fix RCU list walking
+-  * mm: purge fragmented percpu vmap blocks
+-  * block: fix bio_add_page for non trivial merge_bvec_fn case
+-  * Fix 'flush_old_exec()/setup_new_exec()' split
+-  * random: drop weird m_time/a_time manipulation
+-  * random: Remove unused inode variable
+-  * block: fix bugs in bio-integrity mempool usage
+-  * usb: r8a66597-hdc disable interrupts fix
+-  * connector: Delete buggy notification code.
+-  * be2net: Bug fix to support newer generation of BE ASIC
+-  * be2net: Fix memset() arg ordering.
+-  * mm: flush dcache before writing into page to avoid alias
+-  * mac80211: fix NULL pointer dereference when ftrace is enabled
+-  * imxfb: correct location of callbacks in suspend and resume
+-  * mx3fb: some debug and initialisation fixes
+-  * starfire: clean up properly if firmware loading fails
+-  * kernel/cred.c: use kmem_cache_free
+-  * uartlite: fix crash when using as console
+-  * pktcdvd: removing device does not remove its sysfs dir
+-  * ath9k: fix eeprom INI values override for 2GHz-only cards
+-  * ath9k: fix beacon slot/buffer leak
+-  * powerpc: TIF_ABI_PENDING bit removal
+-  * NET: fix oops at bootime in sysctl code
+-  * Linux 2.6.32.8
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 10 Feb 2010 18:56:52 +0000
+-
+-linux (2.6.32-12.17) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * restore linux-image prefix -- master
+-  * enforce -- we require SELINUX enabled -- master
+-  * enforce -- ensure APPARMOR is our default LSM -- master
+-  * make doc package completely optional -- master
+-  * make source package completely optional -- master
+-  * make linux-libc-dev completly optional -- master
+-  * convert package disable to a deps list -- master
+-  * allow common headers to switch from indep to arch -- master
+-  * convert binary package disable to a deps list -- master
+-  * add configuration option for a full source build tree -- master
+-  * add support for uImage kernels in package control scripts
+-  * getabis -- cleanup and parameterise repository list -- master
+-  * getabis -- move configuration to etc/getabi -- master
+-  * kernelconfig -- move configuration to etc -- master
+-  * rules -- make debian/debian.env master for branch name
+-  * set the current branch name -- master
+-  * pull back common debian.master files into debian -- master
+-  * enforcer -- make the enforcement configuration common
+-  * insert-changes -- correctly link to debian/rules in DROOT
+-
+-  [ Colin Watson ]
+-
+-  * future-proof ddeb handling against buildd changes
+-
+-  [ Eric Miao ]
+-
+-  * SAUCE: Make CONFIG_{OMNIBOOK, AVERATEC_5100P, PACKARDBELL_E5} depend on
+-    X86
+-
+-  [ Loïc Minier ]
+-
+-  * Add modules.builtin.bin to prerm rm list
+-    - LP: #516584
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Implement the amd64 preempt flavour
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * syslog: distinguish between /proc/kmsg and syscalls
+-    - LP: #515623
+-  * sfc: Fix polling for slow MCDI operations
+-  * sfc: Fix conditions for MDIO self-test
+-  * sfc: QT202x: Remove unreliable MMD check at initialisation
+-  * sfc: Add workspace for GMAC bug workaround to MCDI MAC_STATS buffer
+-  * sfc: Use fixed-size buffers for MCDI NVRAM requests
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Feb 2010 07:09:31 +0000
+-
+-linux (2.6.32-12.16) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: acpi battery -- delay first lookup of the battery until
+-    first use"
+-  * SAUCE: acpi battery -- move first lookup asynchronous
+-    - LP: #507211
+-  * [Config] update configs to cleanup generic configs
+-  * [Config] disable CONFIG_X86_CPU_DEBUG for amd64
+-  * [Config] enable USER_NS
+-    - LP: #480739, #509808
+-
+-  [ Heiko Carstens ]
+-
+-  * (pre-stable) driver-core: fix devtmpfs crash on s390
+-    - LP: #512370
+-
+-  [ John Johansen ]
+-
+-  * [Config] for server and virtual flavours make CONFIG_SCSI_SYM53C8XX_2=y
+-    - LP: #494565
+-  * [Config] VIRTIO=y for server/virtual flavours
+-    - LP: #494565
+-
+-  [ Kay Sievers ]
+-
+-  * (pre-stable) Driver-Core: devtmpfs - set root directory mode to 0755
+-    - LP: #512370
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: x86: brk away from exec rand area
+-    - LP: #452175
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Upstream] e1000: enhance frame fragment detection
+-    - CVE-2009-4536
+-  * [Upstream] e1000e: enhance frame fragment detection
+-    - CVE-2009-4538
+-
+-  [ Sebastian Kapfer ]
+-
+-  * (pre-stable) Input: ALPS - add interleaved protocol support (Dell E6x00
+-    series)
+-    - LP: #296610
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * inotify: do not reuse watch descriptors
+-    - LP: #485556
+-  * inotify: only warn once for inotify problems
+-  * revert "drivers/video/s3c-fb.c: fix clock setting for Samsung SoC
+-    Framebuffer"
+-  * memcg: ensure list is empty at rmdir
+-  * drm/i915: remove loop in Ironlake interrupt handler
+-  * block: Fix incorrect reporting of partition alignment
+-  * x86, mce: Thermal monitoring depends on APIC being enabled
+-  * futexes: Remove rw parameter from get_futex_key()
+-  * page allocator: update NR_FREE_PAGES only when necessary
+-  * x86, apic: use physical mode for IBM summit platforms
+-  * edac: i5000_edac critical fix panic out of bounds
+-  * x86: SGI UV: Fix mapping of MMIO registers
+-  * mfd: WM835x GPIO direction register is not locked
+-  * mfd: Correct WM835x ISINK ramp time defines
+-  * ALSA: hda - Fix missing capture mixer for ALC861/660 codecs
+-  * V4L/DVB (13868): gspca - sn9c20x: Fix test of unsigned.
+-  * reiserfs: truncate blocks not used by a write
+-  * HID: add device IDs for new model of Apple Wireless Keyboard
+-  * PCI/cardbus: Add a fixup hook and fix powerpc
+-  * Input: pmouse - move Sentelic probe down the list
+-  * asus-laptop: add Lenovo SL hotkey support
+-  * sched: Fix cpu_clock() in NMIs, on !CONFIG_HAVE_UNSTABLE_SCHED_CLOCK
+-  * sparc64: Fix NMI programming when perf events are active.
+-  * sparc64: Fix Niagara2 perf event handling.
+-  * i2c: Do not use device name after device_unregister
+-  * i2c/pca: Don't use *_interruptible
+-  * serial/8250_pnp: add a new Fujitsu Wacom Tablet PC device
+-  * sched: Fix task priority bug
+-  * vfs: Fix vmtruncate() regression
+-  * Linux 2.6.32.5
+-  * x86, msr/cpuid: Register enough minors for the MSR and CPUID drivers
+-  * V4L/DVB (13900): gspca - sunplus: Fix bridge exchanges.
+-  * Staging: asus_oled: fix oops in 2.6.32.2
+-  * Staging: hv: fix smp problems in the hyperv core code
+-  * tty: fix race in tty_fasync
+-  * ecryptfs: use after free
+-  * ecryptfs: initialize private persistent file before dereferencing
+-    pointer
+-  * nozomi: quick fix for the close/close bug
+-  * serial: 8250_pnp: use wildcard for serial Wacom tablets
+-  * usb: serial: fix memory leak in generic driver
+-  * USB: fix bitmask merge error
+-  * USB: Don't use GFP_KERNEL while we cannot reset a storage device
+-  * USB: EHCI: fix handling of unusual interrupt intervals
+-  * USB: EHCI & UHCI: fix race between root-hub suspend and port resume
+-  * USB: add missing delay during remote wakeup
+-  * USB: add speed values for USB 3.0 and wireless controllers
+-  * ACPI: EC: Accelerate query execution
+-  * ACPI: EC: Add wait for irq storm
+-  * SCSI: enclosure: fix oops while iterating enclosure_status array
+-  * drm/i915: Read the response after issuing DDC bus switch command
+-  * drm/i915: try another possible DDC bus for the SDVO device with
+-    multiple outputs
+-  * block: bdev_stack_limits wrapper
+-  * DM: Fix device mapper topology stacking
+-  * x86/PCI/PAT: return EINVAL for pci mmap WC request for !pat_enabled
+-  * USB: fix usbstorage for 2770:915d delivers no FAT
+-  * vmalloc: remove BUG_ON due to racy counting of VM_LAZY_FREE
+-  * perf timechart: Use tid not pid for COMM change
+-  * perf events: Dont report side-band events on each cpu for
+-    per-task-per-cpu events
+-  * perf: Honour event state for aux stream data
+-  * Linux 2.6.32.6
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 27 Jan 2010 16:40:23 +0000
+-
+-linux (2.6.32-11.15) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "(pre-stable) drm/radeon/kms: fix crtc vblank update for r600"
+-  * Revert "(pre-stable) sched: Fix balance vs hotplug race"
+-  * Revert "[Upstream] acerhdf: Limit modalias matching to supported
+-    boards"
+-  * Revert "[Upstream] mmc: prevent dangling block device from accessing
+-    stale queues"
+-  * Revert "SAUCE: Fix nx_enable reporting"
+-  * Revert "SAUCE: [x86] fix report of cs-limit nx-emulation"
+-  * Revert "SAUCE: [x86] implement cs-limit nx-emulation for ia32"
+-  * SAUCE: i915 -- disable powersave by default
+-    - LP: #492392
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: [x86] implement cs-limit nx-emulation for ia32
+-    - LP: #369978
+-  * SAUCE: [x86] fix report of cs-limit nx-emulation
+-    - LP: #454285
+-  * SAUCE: Fix nx_enable reporting
+-    - LP: #454285
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] b43: Declare all possible firmware files.
+-    - LP: #488636
+-  * [Config] updateconfigs after adding pvscsi
+-    - LP: #497156
+-  * [Config] CONFIG_BT=m
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "x86: Side-step lguest problem by only building cmpxchg8b_emu
+-    for pre-Pentium"
+-  * SCSI: ipr: fix EEH recovery
+-  * SCSI: qla2xxx: dpc thread can execute before scsi host has been added
+-  * SCSI: st: fix mdata->page_order handling
+-  * SCSI: fc class: fix fc_transport_init error handling
+-  * sched: Fix task_hot() test order
+-  * x86, cpuid: Add "volatile" to asm in native_cpuid()
+-  * sched: Select_task_rq_fair() must honour SD_LOAD_BALANCE
+-  * clockevents: Prevent clockevent_devices list corruption on cpu hotplug
+-  * pata_hpt3x2n: fix clock turnaround
+-  * pata_cmd64x: fix overclocking of UDMA0-2 modes
+-  * ASoC: wm8974: fix a wrong bit definition
+-  * sound: sgio2audio/pdaudiocf/usb-audio: initialize PCM buffer
+-  * ALSA: hda - Fix missing capsrc_nids for ALC88x
+-  * acerhdf: limit modalias matching to supported
+-    - LP: #435958
+-  * ACPI: EC: Fix MSI DMI detection
+-  * ACPI: Use the return result of ACPI lid notifier chain correctly
+-  * powerpc: Handle VSX alignment faults correctly in little-endian mode
+-  * ASoC: Do not write to invalid registers on the wm9712.
+-  * drm/radeon: fix build on 64-bit with some compilers.
+-  * USB: emi62: fix crash when trying to load EMI 6|2 firmware
+-  * USB: option: support hi speed for modem Haier CE100
+-  * USB: Fix a bug on appledisplay.c regarding signedness
+-  * USB: musb: gadget_ep0: avoid SetupEnd interrupt
+-  * Bluetooth: Prevent ill-timed autosuspend in USB driver
+-  * USB: rename usb_configure_device
+-  * USB: fix bugs in usb_(de)authorize_device
+-  * drivers/net/usb: Correct code taking the size of a pointer
+-  * x86: SGI UV: Fix writes to led registers on remote uv hubs
+-  * md: Fix unfortunate interaction with evms
+-  * dma: at_hdmac: correct incompatible type for argument 1 of
+-    'spin_lock_bh'
+-  * dma-debug: Do not add notifier when dma debugging is disabled.
+-  * dma-debug: Fix bug causing build warning
+-  * cifs: NULL out tcon, pSesInfo, and srvTcp pointers when chasing DFS
+-    referrals
+-  * x86/amd-iommu: Fix initialization failure panic
+-  * ioat3: fix p-disabled q-continuation
+-  * ioat2,3: put channel hardware in known state at init
+-  * KVM: MMU: remove prefault from invlpg handler
+-  * KVM: LAPIC: make sure IRR bitmap is scanned after vm load
+-  * Libertas: fix buffer overflow in lbs_get_essid()
+-  * iwmc3200wifi: fix array out-of-boundary access
+-  * mac80211: fix propagation of failed hardware reconfigurations
+-  * mac80211: fix WMM AP settings application
+-  * mac80211: Fix IBSS merge
+-  * cfg80211: fix race between deauth and assoc response
+-  * ath5k: fix SWI calibration interrupt storm
+-  * ath9k: wake hardware for interface IBSS/AP/Mesh removal
+-  * ath9k: Fix TX queue draining
+-  * ath9k: fix missed error codes in the tx status check
+-  * ath9k: wake hardware during AMPDU TX actions
+-  * ath9k: fix suspend by waking device prior to stop
+-  * ath9k_hw: Fix possible OOB array indexing in gen_timer_index[] on
+-    64-bit
+-  * ath9k_hw: Fix AR_GPIO_INPUT_EN_VAL_BT_PRIORITY_BB and its shift value
+-    in 0x4054
+-  * iwl3945: disable power save
+-  * iwl3945: fix panic in iwl3945 driver
+-  * iwlwifi: fix EEPROM/OTP reading endian annotations and a bug
+-  * iwlwifi: fix more eeprom endian bugs
+-  * iwlwifi: fix 40MHz operation setting on cards that do not allow it
+-  * mac80211: fix race with suspend and dynamic_ps_disable_work
+-  * NOMMU: Optimise away the {dac_,}mmap_min_addr tests
+-  * 'sysctl_max_map_count' should be non-negative
+-  * kernel/sysctl.c: fix the incomplete part of
+-    sysctl_max_map_count-should-be-non-negative.patch
+-  * V4L/DVB (13596): ov511.c typo: lock => unlock
+-  * x86/ptrace: make genregs[32]_get/set more robust
+-  * memcg: avoid oom-killing innocent task in case of use_hierarchy
+-  * e100: Fix broken cbs accounting due to missing memset.
+-  * ipv6: reassembly: use seperate reassembly queues for conntrack and
+-    local delivery
+-  * netfilter: fix crashes in bridge netfilter caused by fragment jumps
+-  * hwmon: (sht15) Off-by-one error in array index + incorrect constants
+-  * b43: avoid PPC fault during resume
+-  * Keys: KEYCTL_SESSION_TO_PARENT needs TIF_NOTIFY_RESUME architecture
+-    support
+-  * sched: Fix balance vs hotplug race
+-  * drm/radeon/kms: fix crtc vblank update for r600
+-  * drm: disable all the possible outputs/crtcs before entering KMS mode
+-  * S390: dasd: support DIAG access for read-only devices
+-  * xen: fix is_disconnected_device/exists_disconnected_device
+-  * xen: improvement to wait_for_devices()
+-  * xen: wait up to 5 minutes for device connetion
+-  * orinoco: fix GFP_KERNEL in orinoco_set_key with interrupts disabled
+-  * udf: Try harder when looking for VAT inode
+-  * Add unlocked version of inode_add_bytes() function
+-  * quota: decouple fs reserved space from quota reservation
+-  * ext4: Convert to generic reserved quota's space management.
+-  * ext4: fix sleep inside spinlock issue with quota and dealloc (#14739)
+-  * x86, msr: Unify rdmsr_on_cpus/wrmsr_on_cpus
+-  * cpumask: use modern cpumask style in drivers/edac/amd64_edac.c
+-  * amd64_edac: unify MCGCTL ECC switching
+-  * x86, msr: Add support for non-contiguous cpumasks
+-  * x86, msr: msrs_alloc/free for CONFIG_SMP=n
+-  * amd64_edac: fix driver instance freeing
+-  * amd64_edac: make driver loading more robust
+-  * amd64_edac: fix forcing module load/unload
+-  * sched: Sched_rt_periodic_timer vs cpu hotplug
+-  * ext4: Update documentation to correct the inode_readahead_blks option
+-    name
+-  * lguest: fix bug in setting guest GDT entry
+-  * vmscan: do not evict inactive pages when skipping an active list scan
+-  * ksm: fix mlockfreed to munlocked
+-  * rt2x00: Disable powersaving for rt61pci and rt2800pci.
+-  * generic_permission: MAY_OPEN is not write access
+-  * Linux 2.6.32.3
+-  * untangle the do_mremap() mess
+-  * fasync: split 'fasync_helper()' into separate add/remove functions
+-  * ASoC: fix params_rate() macro use in several codecs
+-  * modules: Skip empty sections when exporting section notes
+-  * exofs: simple_write_end does not mark_inode_dirty
+-  * nfsd: make sure data is on disk before calling ->fsync
+-  * sunrpc: fix peername failed on closed listener
+-  * SUNRPC: Fix up an error return value in
+-    gss_import_sec_context_kerberos()
+-  * SUNRPC: Fix the return value in gss_import_sec_context()
+-  * sunrpc: on successful gss error pipe write, don't return error
+-  * drm/i915: Update LVDS connector status when receiving ACPI LID event
+-  * drm/i915: fix order of fence release wrt flushing
+-  * drm/i915: Permit pinning whilst the device is 'suspended'
+-  * drm: remove address mask param for drm_pci_alloc()
+-  * drm/i915: Enable/disable the dithering for LVDS based on VBT setting
+-  * drm/i915: Make the BPC in FDI rx/transcoder be consistent with that in
+-    pipeconf on Ironlake
+-  * drm/i915: Select the correct BPC for LVDS on Ironlake
+-  * drm/i915: fix unused var
+-  * rtc_cmos: convert shutdown to new pnp_driver->shutdown
+-  * drivers/cpuidle/governors/menu.c: fix undefined reference to
+-    `__udivdi3'
+-  * cgroups: fix 2.6.32 regression causing BUG_ON() in cgroup_diput()
+-  * lib/rational.c needs module.h
+-  * dma-debug: allow DMA_BIDIRECTIONAL mappings to be synced with
+-    DMA_FROM_DEVICE and
+-  * kernel/signal.c: fix kernel information leak with print-fatal-signals=1
+-  * mmc_block: add dev_t initialization check
+-  * mmc_block: fix probe error cleanup bug
+-  * mmc_block: fix queue cleanup
+-  * ALSA: hda - Fix ALC861-VD capture source mixer
+-  * ALSA: ac97: Add Dell Dimension 2400 to Headphone/Line Jack Sense
+-    blacklist
+-  * ALSA: atiixp: Specify codec for Foxconn RC4107MA-RS2
+-    - LP: #498863
+-  * ASoC: Fix WM8350 DSP mode B configuration
+-  * netfilter: ebtables: enforce CAP_NET_ADMIN
+-  * netfilter: nf_ct_ftp: fix out of bounds read in update_nl_seq()
+-  * hwmon: (coretemp) Fix TjMax for Atom N450/D410/D510 CPUs
+-  * hwmon: (adt7462) Fix pin 28 monitoring
+-  * quota: Fix dquot_transfer for filesystems different from ext4
+-  * xen: fix hang on suspend.
+-  * iwlwifi: fix iwl_queue_used bug when read_ptr == write_ptr
+-  * ath5k: Fix eeprom checksum check for custom sized eeproms
+-  * cfg80211: fix syntax error on user regulatory hints
+-  * iwl: off by one bug
+-  * mac80211: add missing sanity checks for action frames
+-  * drm/i915: remove render reclock support
+-  * libertas: Remove carrier signaling from the scan code
+-  * kernel/sysctl.c: fix stable merge error in NOMMU mmap_min_addr
+-  * mac80211: fix skb buffering issue (and fixes to that)
+-  * fix braindamage in audit_tree.c untag_chunk()
+-  * fix more leaks in audit_tree.c tag_chunk()
+-  * module: handle ppc64 relocating kcrctabs when CONFIG_RELOCATABLE=y
+-  * ipv6: skb_dst() can be NULL in ipv6_hop_jumbo().
+-  * agp/intel-agp: Clear entire GTT on startup
+-  * Linux 2.6.32.4
+-  * ethtool: Add reset operation
+-  * gro: Name the GRO result enumeration type
+-  * gro: Change all receive functions to return GRO result codes
+-  * sfc: 10Xpress: Initialise pause advertising flags
+-  * sfc: 10Xpress: Report support for pause frames
+-  * sfc: Remove redundant header gmii.h
+-  * sfc: Remove redundant hardware initialisation
+-  * sfc: Rename Falcon-specific board code and types
+-  * sfc: Remove boards.h, moving last remaining declaration to falcon.h
+-  * sfc: Remove versioned bitfield macros
+-  * sfc: Move RX data FIFO thresholds out of struct efx_nic_type
+-  * sfc: Update hardware definitions for Siena
+-  * sfc: Rename register I/O header and functions used by both Falcon and
+-    Siena
+-  * sfc: Eliminate indirect lookups of queue size constants
+-  * sfc: Define DMA address mask explicitly in terms of descriptor field
+-    width
+-  * sfc: Move all TX DMA length limiting into tx.c
+-  * sfc: Change order of device removal to reverse of probe order
+-  * sfc: Remove declarations of nonexistent functions
+-  * sfc: Move efx_xmit_done() declaration into correct stanza
+-  * sfc: Move shared members of struct falcon_nic_data into struct efx_nic
+-  * sfc: Maintain interrupt moderation values in ticks, not microseconds
+-  * sfc: Removed kernel-doc for nonexistent member of efx_phy_operations
+-  * sfc: Remove pointless abstraction of memory BAR number
+-  * sfc: Remove incorrect assertion from efx_pci_remove_main()
+-  * sfc: Remove unnecessary tests of efx->membase
+-  * sfc: Move MTD probe after netdev registration and name allocation
+-  * sfc: Remove unused code for non-autoneg speed/duplex switching
+-  * sfc: Rename 'xfp' file and functions to reflect reality
+-  * sfc: Really allow RX checksum offload to be disabled
+-  * sfc: Feed GRO result into RX allocation policy and interrupt moderation
+-  * sfc: Enable heuristic selection between page and skb RX buffers
+-  * sfc: Remove pointless abstraction of memory BAR number (2)
+-  * sfc: Remove redundant gotos from __efx_rx_packet()
+-  * sfc: Remove ridiculously paranoid assertions
+-  * sfc: Move assertions and buffer cleanup earlier in efx_rx_packet_lro()
+-  * sfc: Record RX queue number on GRO path
+-  * sfc: SFT9001: Reset LED configuration correctly after blinking
+-  * sfc: Use a single blink implementation
+-  * sfc: Rename efx_board::init_leds to init_phy and use for SFN4111T
+-  * sfc: Make board information explicitly Falcon-specific
+-  * sfc: Move definition of struct falcon_nic_data into falcon.h
+-  * sfc: Move struct falcon_board into struct falcon_nic_data
+-  * sfc: Move all I2C stuff into struct falcon_board
+-  * sfc: Gather link state fields in struct efx_nic into new struct
+-    efx_link_state
+-  * sfc: Remove unnecessary casts to struct sk_buff *
+-  * sfc: Remove redundant efx_xmit() function
+-  * sfc: Combine high-level header files
+-  * sfc: Log interrupt and reset type names, not numbers
+-  * sfc: Fix descriptor cache sizes
+-  * sfc: Treat all MAC registers as 128-bit
+-  * sfc: Strengthen EFX_ASSERT_RESET_SERIALISED
+-  * sfc: Comment corrections
+-  * sfc: Remove unused constant
+-  * sfc: Clean up struct falcon_board and struct falcon_board_data
+-  * sfc: Fix bugs in RX queue flushing
+-  * sfc: Remove unused function efx_flush_queues()
+-  * sfc: Only switch Falcon MAC clocks as necessary
+-  * sfc: Hold MAC lock for longer in efx_init_port()
+-  * sfc: Split MAC stats DMA initiation and completion
+-  * sfc: Move Falcon board/PHY/MAC monitoring code to falcon.c
+-  * sfc: Simplify XMAC link polling
+-  * sfc: Change MAC promiscuity and multicast hash at the same time
+-  * sfc: Move inline comment into kernel-doc
+-  * sfc: Do not set net_device::trans_start in self-test
+-  * sfc: Simplify PHY polling
+-  * sfc: QT202x: Reset before reading PHY id
+-  * sfc: Replace MDIO spinlock with mutex
+-  * sfc: Always start Falcon using the XMAC
+-  * sfc: Limit some hardware workarounds to Falcon
+-  * sfc: Remove EFX_WORKAROUND_9141 macro
+-  * sfc: Remove another unused workaround macro
+-  * sfc: Remove some redundant whitespace
+-  * sfc: Decouple NIC revision number from Falcon PCI revision number
+-  * sfc: Move descriptor cache base addresses to struct efx_nic_type
+-  * sfc: Clean up RX event handling
+-  * sfc: Remove redundant writes to INT_ADR_KER
+-  * sfc: Remove duplicate hardware structure definitions
+-  * sfc: Turn pause frame generation on and off at the MAC, not the RX FIFO
+-  * sfc: Move Falcon NIC operations to efx_nic_type
+-  * sfc: Refactor link configuration
+-  * sfc: Generalise link state monitoring
+-  * sfc: Add power-management and wake-on-LAN support
+-  * sfc: Implement ethtool reset operation
+-  * sfc: Add efx_nic_type operation for register self-test
+-  * sfc: Add efx_nic_type operation for NVRAM self-test
+-  * sfc: Add efx_nic_type operation for identity LED control
+-  * sfc: Separate shared NIC code from Falcon-specific and rename
+-    accordingly
+-  * sfc: Fold falcon_probe_nic_variant() into falcon_probe_nic()
+-  * sfc: Extend loopback mode enumeration
+-  * sfc: Remove static PHY data and enumerations
+-  * sfc: Extend MTD driver for use with new NICs
+-  * sfc: Allow for additional checksum offload features
+-  * sfc: Rename falcon.h to nic.h
+-  * sfc: Move shared NIC code from falcon.c to new source file nic.c
+-  * sfc: Add firmware protocol definitions (MCDI)
+-  * sfc: Add support for SFC9000 family (1)
+-  * sfc: Add support for SFC9000 family (2)
+-  * sfc: Implement TSO for TCP/IPv6
+-  * sfc: Update version, copyright dates, authors
+-  * drivers/net/sfc: Correct code taking the size of a pointer
+-  * sfc: Move PHY software state initialisation from init() into probe()
+-  * sfc: Include XGXS in XMAC link status check except in XGMII loopback
+-  * sfc: Fix DMA mapping cleanup in case of an error in TSO
+-  * sfc: QT2025C: Work around PHY bug
+-  * sfc: QT2025C: Switch into self-configure mode when not in loopback
+-  * sfc: QT2025C: Work around PHY firmware initialisation bug
+-  * sfc: QT2025C: Add error message for suspected bad SFP+ cables
+-  * sfc: Disable TX descriptor prefetch watchdog
+-  * [SCSI] vmw_pvscsi: SCSI driver for VMware's virtual HBA.
+-    - LP: #497156
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 19 Jan 2010 16:12:47 +0000
+-
+-linux (2.6.32-10.14) lucid; urgency=low
+-
+-  [ Alex Deucher ]
+-
+-  * SAUCE: drm/radeon/kms: fix LVDS setup on r4xx
+-    - LP: #493795
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "(pre-stable) acpi: Use the ARB_DISABLE for the CPU which model
+-    id is less than 0x0f."
+-  * config-check -- ensure the checks get run at build time
+-  * config-check -- check the processed config during updateconfigs
+-  * config-check -- CONFIG_SECCOMP may not be present
+-  * TUN is now built in ignore
+-  * SAUCE: acpi battery -- delay first lookup of the battery until first
+-    use
+-  * SAUCE: async_populate_rootfs: move rootfs init earlier
+-  * ubuntu: AppArmor -- update to mainline 2010-01-06
+-  * SAUCE: move RLIMIT_CORE pipe dumper marker to 1
+-    - LP: #498525
+-
+-  [ Dave Airlie ]
+-
+-  * (pre-stable) drm/radeon/kms: fix crtc vblank update for r600
+-
+-  [ Leann Ogasawara ]
+-
+-  * Add asix to nic-usb-modules file
+-    - LP: #499785
+-
+-  [ Peter Zijlstra ]
+-
+-  * (pre-stable) sched: Fix balance vs hotplug race
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enable CONFIG_FUNCTION_TRACER
+-    - LP: #497989
+-  * [Config] Drop lpia from getabis
+-  * [Config] Build in TUN/TAP driver
+-    - LP: #499491
+-  * [Config] DH_COMPAT=5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "(pre-stable) drm/i915: Avoid NULL dereference with
+-    component_only tv_modes"
+-  * Revert "(pre-stable) drm/i915: Fix sync to vblank when VGA output is
+-    turned off"
+-  * USB: usb-storage: fix bug in fill_inquiry
+-  * USB: option: add pid for ZTE
+-  * firewire: ohci: handle receive packets with a data length of zero
+-  * rcu: Prepare for synchronization fixes: clean up for non-NO_HZ handling
+-    of ->completed counter
+-  * rcu: Fix synchronization for rcu_process_gp_end() uses of ->completed
+-    counter
+-  * rcu: Fix note_new_gpnum() uses of ->gpnum
+-  * rcu: Remove inline from forward-referenced functions
+-  * perf_event: Fix invalid type in ioctl definition
+-  * perf_event: Initialize data.period in perf_swevent_hrtimer()
+-  * perf: Don't free perf_mmap_data until work has been done
+-  * PM / Runtime: Fix lockdep warning in __pm_runtime_set_status()
+-  * sched: Check for an idle shared cache in select_task_rq_fair()
+-  * sched: Fix affinity logic in select_task_rq_fair()
+-  * sched: Rate-limit newidle
+-  * sched: Fix and clean up rate-limit newidle code
+-  * x86/amd-iommu: attach devices to pre-allocated domains early
+-  * x86/amd-iommu: un__init iommu_setup_msi
+-  * x86, Calgary IOMMU quirk: Find nearest matching Calgary while walking
+-    up the PCI tree
+-  * x86: Fix iommu=nodac parameter handling
+-  * x86: GART: pci-gart_64.c: Use correct length in strncmp
+-  * x86: ASUS P4S800 reboot=bios quirk
+-    - LP: #366682
+-  * x86, apic: Enable lapic nmi watchdog on AMD Family 11h
+-  * ssb: Fix range check in sprom write
+-  * ath5k: allow setting txpower to 0
+-  * ath5k: enable EEPROM checksum check
+-  * hrtimer: Fix /proc/timer_list regression
+-  * ALSA: hrtimer - Fix lock-up
+-  * ALSA: hda - Terradici HDA controllers does not support 64-bit mode
+-  * KVM: x86 emulator: limit instructions to 15 bytes
+-  * KVM: s390: Fix prefix register checking in arch/s390/kvm/sigp.c
+-  * KVM: s390: Make psw available on all exits, not just a subset
+-  * KVM: fix irq_source_id size verification
+-  * KVM: x86: include pvclock MSRs in msrs_to_save
+-  * x86: Prevent GCC 4.4.x (pentium-mmx et al) function prologue wreckage
+-  * x86: Use -maccumulate-outgoing-args for sane mcount prologues
+-  * x86, mce: don't restart timer if disabled
+-  * x86/mce: Set up timer unconditionally
+-  * x86: SGI UV: Fix BAU initialization
+-  * x86: Fix duplicated UV BAU interrupt vector
+-  * x86: Add new Intel CPU cache size descriptors
+-  * x86: Fix typo in Intel CPU cache size descriptor
+-  * pata_hpt{37x|3x2n}: fix timing register masks (take 2)
+-  * s390: clear high-order bits of registers after sam64
+-  * V4L/DVB: Fix test in copy_reg_bits()
+-  * bsdacct: fix uid/gid misreporting
+-  * UBI: flush wl before clearing update marker
+-  * jbd2: don't wipe the journal on a failed journal checksum
+-  * USB: xhci: Add correct email and files to MAINTAINERS entry.
+-  * USB: musb_gadget_ep0: fix unhandled endpoint 0 IRQs, again
+-  * USB: option.c: add support for D-Link DWM-162-U5
+-  * USB: usbtmc: repeat usb_bulk_msg until whole message is transfered
+-  * USB: usb-storage: add BAD_SENSE flag
+-  * USB: Close usb_find_interface race v3
+-  * pxa/em-x270: fix usb hub power up/reset sequence
+-  * hfs: fix a potential buffer overflow
+-  * SUNRPC: IS_ERR/PTR_ERR confusion
+-  * NFS: Fix nfs_migrate_page()
+-  * md/bitmap: protect against bitmap removal while being updated.
+-  * futex: Take mmap_sem for get_user_pages in fault_in_user_writeable
+-  * devpts_get_tty() should validate inode
+-  * debugfs: fix create mutex racy fops and private data
+-  * Driver core: fix race in dev_driver_string
+-  * Serial: Do not read IIR in serial8250_start_tx when UART_BUG_TXEN
+-  * mac80211: Fix bug in computing crc over dynamic IEs in beacon
+-  * mac80211: Fixed bug in mesh portal paths
+-  * mac80211: Revert 'Use correct sign for mesh active path refresh'
+-  * mac80211: fix scan abort sanity checks
+-  * wireless: correctly report signal value for IEEE80211_HW_SIGNAL_UNSPEC
+-  * rtl8187: Fix wrong rfkill switch mask for some models
+-  * x86: Fix bogus warning in apic_noop.apic_write()
+-  * mm: hugetlb: fix hugepage memory leak in mincore()
+-  * mm: hugetlb: fix hugepage memory leak in walk_page_range()
+-  * powerpc/windfarm: Add detection for second cpu pump
+-  * powerpc/therm_adt746x: Record pwm invert bit at module load time]
+-  * powerpc: Fix usage of 64-bit instruction in 32-bit altivec code
+-  * drm/radeon/kms: Add quirk for HIS X1300 board
+-  * drm/radeon/kms: handle vblanks properly with dpms on
+-  * drm/radeon/kms: fix legacy crtc2 dpms
+-  * drm/radeon/kms: fix vram setup on rs600
+-  * drm/radeon/kms: rs6xx/rs740: clamp vram to aperture size
+-  * drm/ttm: Fix build failure due to missing struct page
+-  * drm/i915: Set the error code after failing to insert new offset into mm
+-    ht.
+-  * drm/i915: Add the missing clonemask for display port on Ironlake
+-  * xen/xenbus: make DEVICE_ATTR()s static
+-  * xen: re-register runstate area earlier on resume.
+-  * xen: restore runstate_info even if !have_vcpu_info_placement
+-  * xen: correctly restore pfn_to_mfn_list_list after resume
+-  * xen: register timer interrupt with IRQF_TIMER
+-  * xen: register runstate on secondary CPUs
+-  * xen: don't call dpm_resume_noirq() with interrupts disabled.
+-  * xen: register runstate info for boot CPU early
+-  * xen: call clock resume notifier on all CPUs
+-  * xen: improve error handling in do_suspend.
+-  * xen: don't leak IRQs over suspend/resume.
+-  * xen: use iret for return from 64b kernel to 32b usermode
+-  * xen: explicitly create/destroy stop_machine workqueues outside
+-    suspend/resume region.
+-  * Xen balloon: fix totalram_pages counting.
+-  * xen: try harder to balloon up under memory pressure.
+-  * dm exception store: free tmp_store on persistent flag error
+-  * dm snapshot: only take lock for statustype info not table
+-  * dm crypt: move private iv fields to structs
+-  * dm crypt: restructure essiv error path
+-  * dm: avoid _hash_lock deadlock
+-  * dm snapshot: cope with chunk size larger than origin
+-  * dm crypt: separate essiv allocation from initialisation
+-  * dm crypt: make wipe message also wipe essiv key
+-  * slc90e66: fix UDMA handling
+-  * tcp: Stalling connections: Fix timeout calculation routine
+-  * ip_fragment: also adjust skb->truesize for packets not owned by a
+-    socket
+-  * b44 WOL setup: one-bit-off stack corruption kernel panic fix
+-  * sparc64: Don't specify IRQF_SHARED for LDC interrupts.
+-  * sparc64: Fix overly strict range type matching for PCI devices.
+-  * sparc64: Fix stack debugging IRQ stack regression.
+-  * sparc: Set UTS_MACHINE correctly.
+-  * b43legacy: avoid PPC fault during resume
+-  * tracing: Fix event format export
+-  * ath9k: Fix TX hang poll routine
+-  * ath9k: fix processing of TX PS null data frames
+-  * ath9k: Fix maximum tx fifo settings for single stream devices
+-  * ath9k: fix tx status reporting
+-  * mac80211: Fix dynamic power save for scanning.
+-  * drm/i915: Fix sync to vblank when VGA output is turned off
+-  * memcg: fix memory.memsw.usage_in_bytes for root cgroup
+-  * thinkpad-acpi: fix default brightness_mode for R50e/R51
+-  * thinkpad-acpi: preserve rfkill state across suspend/resume
+-  * ipw2100: fix rebooting hang with driver loaded
+-  * matroxfb: fix problems with display stability
+-  * acerhdf: add new BIOS versions
+-  * asus-laptop: change light sens default values.
+-  * vmalloc: conditionalize build of pcpu_get_vm_areas()
+-  * ACPI: Use the ARB_DISABLE for the CPU which model id is less than 0x0f.
+-  * net: Fix userspace RTM_NEWLINK notifications.
+-  * ext3: Fix data / filesystem corruption when write fails to copy data
+-  * V4L/DVB (13116): gspca - ov519: Webcam 041e:4067 added.
+-  * bcm63xx_enet: fix compilation failure after get_stats_count removal
+-  * x86: Under BIOS control, restore AP's APIC_LVTTHMR to the BSP value
+-  * drm/i915: Avoid NULL dereference with component_only tv_modes
+-  * drm/i915: PineView only has LVDS and CRT ports
+-  * drm/i915: Fix LVDS stability issue on Ironlake
+-  * mm: sigbus instead of abusing oom
+-  * ipvs: zero usvc and udest
+-  * jffs2: Fix long-standing bug with symlink garbage collection.
+-  * intel-iommu: Detect DMAR in hyperspace at probe time.
+-  * intel-iommu: Apply BIOS sanity checks for interrupt remapping too.
+-  * intel-iommu: Check for an RMRR which ends before it starts.
+-  * intel-iommu: Fix oops with intel_iommu=igfx_off
+-  * intel-iommu: ignore page table validation in pass through mode
+-  * netfilter: xtables: document minimal required version
+-  * perf_event: Fix incorrect range check on cpu number
+-  * implement early_io{re,un}map for ia64
+-  * Linux 2.6.32.2
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 07 Jan 2010 15:28:43 +0000
+-
+-linux (2.6.32-9.13) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_B43_PHY_LP
+-    - LP: #493059
+-  * include modules.builtin in the binary debs
+-  * config-check -- add a configuration enforcer
+-  * config-check -- add a unit-test suite to the checker
+-  * [Config] Enable CONFIG_SYN_COOKIES for versatile
+-  * [Config] Enable CONFIG_SECURITY_SMACK for ports
+-  * [Config] Enable CONFIG_SECURITY_FILE_CAPABILITIES for ports
+-  * [Config] Disable CONFIG_COMPAT_BRK for ports
+-  * getabis -- add armel versatile to the list
+-
+-  [ Brad Figg ]
+-
+-  * SAUCE: Increase the default prealloc buffer for HDA audio devices
+-    (non-modem)
+-
+-  [ Manoj Iyer ]
+-
+-  * ubuntu: onmibook -- Added missing BOM file
+-
+-  [ Tim Gardner ]
+-
+-  * ubuntu: fsam7400 -- Cleanup Makefile
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT"
+-  * signal: Fix alternate signal stack check
+-  * SCSI: scsi_lib_dma: fix bug with dma maps on nested scsi objects
+-  * SCSI: osd_protocol.h: Add missing #include
+-  * SCSI: megaraid_sas: fix 64 bit sense pointer truncation
+-  * ext4: fix potential buffer head leak when add_dirent_to_buf() returns
+-    ENOSPC
+-  * ext4: avoid divide by zero when trying to mount a corrupted file system
+-  * ext4: fix the returned block count if EXT4_IOC_MOVE_EXT fails
+-  * ext4: fix lock order problem in ext4_move_extents()
+-  * ext4: fix possible recursive locking warning in EXT4_IOC_MOVE_EXT
+-  * ext4: plug a buffer_head leak in an error path of ext4_iget()
+-  * ext4: make sure directory and symlink blocks are revoked
+-  * ext4: fix i_flags access in ext4_da_writepages_trans_blocks()
+-  * ext4: journal all modifications in ext4_xattr_set_handle
+-  * ext4: don't update the superblock in ext4_statfs()
+-  * ext4: fix uninit block bitmap initialization when s_meta_first_bg is
+-    non-zero
+-  * ext4: fix block validity checks so they work correctly with meta_bg
+-  * ext4: avoid issuing unnecessary barriers
+-  * ext4: fix error handling in ext4_ind_get_blocks()
+-  * ext4: make trim/discard optional (and off by default)
+-  * ext4: make "norecovery" an alias for "noload"
+-  * ext4: Fix double-free of blocks with EXT4_IOC_MOVE_EXT
+-  * ext4: initialize moved_len before calling ext4_move_extents()
+-  * ext4: move_extent_per_page() cleanup
+-  * jbd2: Add ENOMEM checking in and for
+-    jbd2_journal_write_metadata_buffer()
+-  * ext4: Return the PTR_ERR of the correct pointer in
+-    setup_new_group_blocks()
+-  * ext4: Avoid data / filesystem corruption when write fails to copy data
+-  * ext4: wait for log to commit when umounting
+-  * ext4: remove blocks from inode prealloc list on failure
+-  * ext4: ext4_get_reserved_space() must return bytes instead of blocks
+-  * ext4: quota macros cleanup
+-  * ext4: fix incorrect block reservation on quota transfer.
+-  * ext4: Wait for proper transaction commit on fsync
+-  * ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT
+-  * ext4: Fix potential fiemap deadlock (mmap_sem vs. i_data_sem)
+-  * Linux 2.6.32.1
+-  * kbuild: generate modules.builtin
+-  * (pre-stable) drm/i915: Fix sync to vblank when VGA output is turned off
+-    - LP: #494461
+-  * (pre-stable) drm/i915: Avoid NULL dereference with component_only
+-    tv_modes
+-    - LP: #494045
+-
+-  [ Zhao Yakui ]
+-
+-  * (pre-stable) acpi: Use the ARB_DISABLE for the CPU which model id is
+-    less than 0x0f.
+-    - LP: #481765
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 17 Dec 2009 15:41:21 +0000
+-
+-linux (2.6.32-8.12) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: AppArmor -- add linux/err.h for ERR_PTR
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 12 Dec 2009 10:56:16 +0000
+-
+-linux (2.6.32-8.11) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: default ATI Radeon KMS to off until userspace catches
+-    up"
+-  * Revert "SAUCE: AppArmor: Fix oops there is no tracer and doing unsafe
+-    transition."
+-  * Revert "SAUCE: AppArmor: Fix refcounting bug causing leak of creds"
+-  * Revert "SAUCE: AppArmor: Fix cap audit_caching preemption disabling"
+-  * Revert "SAUCE: AppArmor: Fix Oops when in apparmor_bprm_set_creds"
+-  * Revert "SAUCE: AppArmor: Fix oops after profile removal"
+-  * Revert "SAUCE: AppArmor: AppArmor disallows truncate of deleted files."
+-  * Revert "SAUCE: AppArmor: AppArmor fails to audit change_hat correctly"
+-  * Revert "SAUCE: AppArmor: Policy load and replacement can fail to alloc
+-    mem"
+-  * Revert "SAUCE: AppArmor: AppArmor wrongly reports allow perms as
+-    denied"
+-  * Revert "SAUCE: AppArmor: Fix mediation of "deleted" paths"
+-  * Revert "SAUCE: AppArmor: Fix off by 2 error in getprocattr mem
+-    allocation"
+-  * Revert "SAUCE: AppArmor: Set error code after structure
+-    initialization."
+-  * Revert "AppArmor -- fix pstrace_may_access rename"
+-  * Revert "ubuntu: AppArmor security module"
+-  * Revert "SAUCE: Add config option to set a default LSM"
+-  * Revert "ubuntu: fsam7400 -- sw kill switch driver"
+-  * Revert "[Config] fsam7400 -- enable"
+-  * Revert "[Config] AUFS -- enable"
+-  * Revert "ubuntu: AUFS -- aufs2-30 20090727"
+-  * Revert "ubuntu: AUFS -- export various core functions -- fixes"
+-  * Revert "ubuntu: AUFS -- export various core functions"
+-  * Revert "[Config] ubuntu/iscsitarget -- disable"
+-  * Revert "[Config] iscsitarget -- enable"
+-  * Revert "ubuntu: iscsitarget -- SVN revision r214"
+-  * update Vcs-Git to point to the correct repository
+-    - LP: #493589
+-  * update build environment overrides to lucid
+-    - LP: #493589
+-  * [Config] enable CONFIG_DEVTMPFS
+-  * [Config] update all configs following AppArmor 2009-12-08 update
+-  * SAUCE: isapnp_init: make isa PNP scans occur async
+-  * [Config] fsam7400 -- enable
+-  * [Config] omnibook -- enable
+-  * [Config] cleanup CONFIG_AUDIT
+-  * ubuntu: AUFS -- export various core functions (aufs2-base.patch)
+-  * ubuntu: AUFS -- export various core functions (aufs2-standalone.patch)
+-  * ubuntu: AUFS -- aufs2 20091209
+-  * [Config] AUFS -- enable
+-  * [Config] iscsitarget -- enable
+-
+-  [ Arjan van de Ven ]
+-
+-  * SAUCE: KMS: cache the EDID information of the LVDS
+-
+-  [ Colin Watson ]
+-
+-  * bnx2: update d-i firmware filenames
+-    - LP: #494052
+-  * add cdc_ether to nic-usb-modules udeb
+-    - LP: #495060
+-
+-  [ John Johansen ]
+-
+-  * ubuntu: AppArmor -- mainline 2009-10-08
+-
+-  [ Manoj Iyer ]
+-
+-  * ubuntu: fsam7400 -- kill switch for Fujitsu Siemens Amilo M 7400
+-  * ubuntu: omnibook -- support Toshiba (HP) netbooks
+-  * ubuntu: iscsitarget --- version 1.4.19
+-    - LP: #494693
+-
+-  [ Surbhi Palande ]
+-
+-  * SAUCE: Make populate_rootfs asynchronous
+-
+-  [ Tim Gardner ]
+-
+-  * Parallelize flavour builds and packaging
+-  * [Config] Enable CONFIG_KSM
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Config option to set a default LSM
+-  * LSM: Add security_path_chroot().
+-  * LSM: Add security_path_chroot().
+-  * LSM: Move security_path_chmod()/security_path_chown() to after
+-    mutex_lock().
+-  * ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Dec 2009 17:45:19 +0000
+-
+-linux (2.6.32-7.10) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] disable CONFIG_THUMB2_KERNEL to fix arm FTBFS
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sun, 06 Dec 2009 12:56:48 +0000
+-
+-linux (2.6.32-7.9) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: set /proc/acpi/video/*/DOS to 4 by default
+-    - LP: #458982
+-  * SAUCE: ensure vga16fb loads if no other driver claims the VGA device
+-  * [Config] update configs following versatile switch to V7
+-  * rebased to v2.6.32
+-  * [Config] update configs following rebase to v2.6.32
+-  * [Config] update ports configs following rebase to v2.6.32
+-  * SAUCE: default ATI Radeon KMS to off until userspace catches up
+-
+-  [ Arjan van de Ven ]
+-
+-  * SAUCE: vfs: Add a trace point in the mark_inode_dirty function
+-
+-  [ Leann Ogasawara ]
+-
+-  * [SCSI] megaraid_sas: remove sysfs poll_mode_io world writeable
+-    permissions
+-    - CVE-2009-3939
+-
+-  [ Loic Minier ]
+-
+-  * SAUCE: select a v7 CPU for versatile
+-
+-  [ Takashi Iwai ]
+-
+-  * SAUCE: ALSA: hda - Add power on/off counter
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.32
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 04 Dec 2009 10:44:50 +0000
+-
+-linux (2.6.32-6.8) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] disable SSB devices for armel
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 28 Nov 2009 12:16:40 +0000
+-
+-linux (2.6.32-6.7) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: default ATI Radeon KMS to off until userspace catches up"
+-  * Revert "SAUCE: Dell XPS710 reboot quirk"
+-  * Revert "SAUCE: Link acpi-cpufreq.o first"
+-  * Revert "SAUCE: LPIA  Logical reset of USB port on resume"
+-  * Revert "SAUCE: LPIA Reboot fix for Intel Crownbeach development boards"
+-  * Revert "SAUCE: Enable HDMI audio codec on Studio XPS 1340"
+-  * Revert "SAUCE: Dell laptop digital mic does not work, PCI 1028:0271"
+-  * Revert "Add Dell Dimension 9200 reboot quirk"
+-  * Revert "SAUCE: Correctly blacklist Thinkpad r40e in ACPI"
+-  * Revert "SAUCE: tulip: Define ULI PCI ID's"
+-  * Revert "SAUCE: Lower warning level of some PCI messages"
+-  * Revert "mac80211: fix two issues in debugfs"
+-    Drop a number of known redundant commits as identified in the Ubuntu
+-    delta review blueprint.
+-
+-  * reenable armel versatile flavour
+-  * [Config] disable CONFIG_USB_DEVICEFS
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] udeb: Add squashfs to fs-core-modules
+-    - LP: #352615
+-  * [Config] Create a real squashfs udeb
+-    - LP: #352615
+-
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 27 Nov 2009 17:31:16 +0000
+-
+-linux (2.6.32-5.6) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.32-rc8
+-  * update configs following rebase to v2.6.32-rc8
+-  * update ports configs since rebase to v2.6.32-rc8
+-  * [Config] enable cgroup options
+-    - LP: #480739
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.32-rc8
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 23 Nov 2009 11:16:14 +0000
+-
+-linux (2.6.32-4.5) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] SERIO_LIBPS2 and SERIO_I8042 must match
+-  * rebase to v2.6.32-rc7
+-  * resync with Karmic proposed
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: Fix oops after profile removal
+-    - LP: #475619
+-  * SAUCE: AppArmor: Fix Oops when in apparmor_bprm_set_creds
+-    - LP: #437258
+-  * SAUCE: AppArmor: Fix cap audit_caching preemption disabling
+-    - LP: #479102
+-  * SAUCE: AppArmor: Fix refcounting bug causing leak of creds
+-    - LP: #479115
+-  * SAUCE: AppArmor: Fix oops there is no tracer and doing unsafe
+-    transition.
+-    - LP: #480112
+-
+-  [ Ubuntu Changes ]
+-
+-  * resync with Karmic proposed (ddbc670a86a3dee18541a3734149f250ff307adf)
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.32-rc7
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 13 Nov 2009 11:35:13 +0000
+-
+-linux (2.6.32-3.4) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] SERIO_LIBPS2 and SERIO_I8042 must match
+-  * [Upstream] add local prefix to oss local change_bits
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * mtd/maps: gpio-addr-flash: pull in linux/ headers rather than asm/
+-  * mtd/maps: gpio-addr-flash: depend on GPIO arch support
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 11 Nov 2009 14:47:04 +0000
+-
+-linux (2.6.32-3.3) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.32-rc6
+-  * [Config] update configs following rebase to v2.6.32-rc6
+-  * [Config] update ports configs following rebase to v2.6.32-rc6
+-  * resync with Karmic Ubuntu-2.6.31-15.49
+-  * [Config] add module ignores for broken drivers
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: AppArmor wrongly reports allow perms as denied
+-    - LP: #453335
+-  * SAUCE: AppArmor: Policy load and replacement can fail to alloc mem
+-    - LP: #458299
+-  * SAUCE: AppArmor: AppArmor fails to audit change_hat correctly
+-    - LP: #462824
+-  * SAUCE: AppArmor: AppArmor disallows truncate of deleted files.
+-    - LP: #451375
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: Fix nx_enable reporting
+-    - LP: #454285
+-
+-  [ Scott James Remnant ]
+-
+-  * Revert "SAUCE: trace: add trace_event for the open() syscall"
+-  * SAUCE: trace: add trace events for open(), exec() and uselib()
+-    - LP: #462111
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: Fix sub-flavour script to not stop on missing directories
+-    - LP: #453073
+-
+-  [ Ubuntu Changes ]
+-
+-  * resync with Karmic Ubuntu-2.6.31-15.49
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.32-rc6
+-    - LP: #464552
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 10 Nov 2009 15:00:57 +0000
+-
+-linux (2.6.32-2.2) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * install the full changelog with the binary package
+-  * changelog -- explicitly note rebases and clean history
+-  * reinstate armel.mk with no flavours
+-    - LP: #449637
+-  * [Upstream] block: silently error unsupported empty barriers too
+-    - LP: #420423
+-  * [Config] udate configs following karmic resync
+-  * [Config] update ports configs following karmic resync
+-  * [Upstream] lirc -- follow removal of .id element
+-
+-  [ Colin Watson ]
+-
+-  * Use section 'admin' rather than 'base'
+-  * Add more e100 firmware to nic-modules
+-    - LP: #451872
+-  * Add qla1280 firmware to scsi-modules
+-    - LP: #381037
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: Set error code after structure initialization.
+-    - LP: #427948
+-  * SAUCE: AppArmor: Fix off by 2 error in getprocattr mem allocation
+-    - LP: #446595
+-  * SAUCE: AppArmor: Fix mediation of "deleted" paths
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: [x86] fix report of cs-limit nx-emulation
+-    - LP: #454285
+-
+-  [ Leann Ogasawara ]
+-
+-  * SAUCE: (drop after 2.6.31) input: Add support for filtering input
+-    events
+-    - LP: #430809
+-  * SAUCE: (drop after 2.6.31) dell-laptop: Trigger rfkill updates on wifi
+-    toggle switch press
+-    - LP: #430809
+-
+-  [ Luke Yelavich ]
+-
+-  * SAUCE: Add sr_mod to the scsi-modules udeb for powerpc
+-  * [Config] Add sd_mod to scsi-modules udeb for powerpc
+-
+-  [ Mario Limonciello ]
+-
+-  * SAUCE: Update to LIRC 0.8.6
+-    - LP: #432678
+-  * SAUCE: dell-laptop: Store the HW switch status internally rather than
+-    requerying every time
+-    - LP: #430809
+-  * SAUCE: dell-laptop: Blacklist machines not supporting dell-laptop
+-    - LP: #430809
+-
+-  [ Stefan Bader ]
+-
+-  * [Upstream] acerhdf: Limit modalias matching to supported boards
+-    - LP: #435958
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] i915: Fix i2c init message
+-    - LP: #409361
+-  * [Config] Add sym53c8xx.ko to virtual sub-flavour
+-    - LP: #439415
+-  * [Config] Add d101m_ucode.bin to d-i/firmware/nic-modules
+-    - LP: #439456
+-  * [Config] Set default I/O scheduler back to CFQ for desktop flavours
+-    - LP: #381300
+-  * SAUCE: Created MODULE_EXPORT/MODULE_IMPORT macros
+-    - LP: #430694
+-  * SAUCE: Use MODULE_IMPORT macro to tie intel_agp to i915
+-    - LP: #430694
+-  * [Config] CONFIG_GFS2_FS_LOCKING_DLM=y
+-    - LP: #416325
+-  * SAUCE: Fix MODULE_IMPORT/MODULE_EXPORT
+-    - LP: #430694
+-  * SAUCE: Raise the default console 'quiet' level to 2
+-  * [Config] CONFIG_X86_PAT=y
+-  * [Config] Add armel arch to linux-libc-dev arches.
+-    - LP: #449637
+-  * [Config] CONFIG_X86_MCE
+-  * [Upstream] (drop after 2.6.31) Input: synaptics - add another Protege
+-    M300 to rate blacklist
+-    - LP: #433801
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * sgi-gru: Fix kernel stack buffer overrun, CVE-2009-2584
+-  * drm/i915: Fix FDI M/N setting according with correct color depth
+-    - LP: #416792
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 22 Oct 2009 16:53:33 +0100
+-
+-linux (2.6.32-1.1) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.32-rc3
+-  * [Config] update configs following rebase to 2.6.32-rc3
+-  * [Config] update ports configs following rebase to 2.6.32-rc3
+-  * AppArmor -- fix pstrace_may_access rename
+-  * staging/android -- disable
+-  * ubuntu: dm-raid-45 -- update to compile with 2.6.32
+-  * ubuntu: drbd -- disable
+-  * staging/comdi -- disable
+-  * staging/go7007 -- disable
+-  * [Config] staging/winbond -- disable
+-  * [Config] ubuntu/iscsitarget -- disable
+-  * [d-i] cbc and ecb are builtin make them optional in udebs
+-  * rebase to v2.6.32-rc5
+-  * [Config] update configs following rebase to v2.6.32-rc5
+-  * [Config] update ports configs following rebase to v2.6.31-rc5
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add cpio as a build dependency.
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.32-rc3
+-  * rebase to v2.6.32-rc5
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 05 Oct 2009 15:48:58 +0100
+-
+-linux (2.6.31-11.37) karmic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Increase kernel log buffer to 256K for amd64 flavours
+-    - LP: #424810
+-  * [Config] Set HZ=100 for amd64 flavours
+-    - LP: #438234
+-  * [Upstream] e1000e: Emit notice instead of an error when
+-    pci_enable_pcie_error_reporting() fails
+-    - LP: #436370
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * n_tty: honor opost flag for echoes
+-  * n_tty: move echoctl check and clean up logic
+-    - LP: #438310
+-
+-  * Revert "[Upstream] drm/i915: Check that the relocation points to within
+-    the target" - Use upstream cherry-pick.
+-  * drm/i915: Check that the relocation points to within the target
+-    - LP: #429241
+-
+-  * drm/i915: fix tiling on IGDNG
+-  * drm/i915: add B43 chipset support
+-  * agp/intel: Add B43 chipset support
+-    Intel request from kernel team mailing list.
+-
+-  * HID: completely remove apple mightymouse from blacklist
+-    - LP: #428111
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 28 Sep 2009 11:47:29 -0600
+-
+-linux (2.6.31-11.36) karmic; urgency=low
+-
+-  [ Brian Rogers ]
+-
+-  * SAUCE: (drop after 2.6.31) em28xx: ir-kbd-i2c init data needs a
+-    persistent object
+-  * SAUCE: (drop after 2.6.31) saa7134: ir-kbd-i2c init data needs a
+-    persistent object
+-
+-  [ Takashi Iwai ]
+-
+-  * [Upstream] ALSA: hda - Add another entry for Nvidia HDMI device
+-    - LP: #416482
+-
+-  [ Tyler Hicks ]
+-
+-  * SAUCE: (drop after 2.6.31) eCryptfs: Prevent lower dentry from going
+-    negative during unlink
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * sg: fix oops in the error path in sg_build_indirect()
+-  * mpt2sas : Rescan topology from Interrupt context instead of work thread
+-  * mpt2sas: Prevent sending command to FW while Host Reset
+-  * mpt2sas: setting SDEV into RUNNING state from Interrupt context
+-  * mpt2sas: Raid 10 Volume is showing as Raid 1E in dmesg
+-  * SCSI: fix oops during scsi scanning
+-  * SCSI: libsrp: fix memory leak in srp_ring_free()
+-  * cfg80211: fix looping soft lockup in find_ie()
+-  * ath5k: write PCU registers on initial reset
+-  * binfmt_elf: fix PT_INTERP bss handling
+-  * TPM: Fixup boot probe timeout for tpm_tis driver
+-  * md: Fix "strchr" [drivers/md/dm-log-userspace.ko] undefined!
+-  * x86/amd-iommu: fix broken check in amd_iommu_flush_all_devices
+-  * fix undefined reference to user_shm_unlock
+-  * perf_counter: Fix buffer overflow in perf_copy_attr()
+-  * perf_counter: Start counting time enabled when group leader gets
+-    enabled
+-  * powerpc/perf_counters: Reduce stack usage of power_check_constraints
+-  * powerpc: Fix bug where perf_counters breaks oprofile
+-  * powerpc/ps3: Workaround for flash memory I/O error
+-  * block: don't assume device has a request list backing in nr_requests
+-    store
+-  * agp/intel: remove restore in resume
+-  * ALSA: cs46xx - Fix minimum period size
+-  * ASoC: Fix WM835x Out4 capture enumeration
+-  * sound: oxygen: work around MCE when changing volume
+-  * mlx4_core: Allocate and map sufficient ICM memory for EQ context
+-  * perf stat: Change noise calculation to use stddev
+-  * x86: Fix x86_model test in es7000_apic_is_cluster()
+-  * x86/i386: Make sure stack-protector segment base is cache aligned
+-  * PCI: apply nv_msi_ht_cap_quirk on resume too
+-  * x86, pat: Fix cacheflush address in change_page_attr_set_clr()
+-  * ARM: 5691/1: fix cache aliasing issues between kmap() and kmap_atomic()
+-    with highmem
+-  * KVM guest: do not batch pte updates from interrupt context
+-  * KVM: Fix coalesced interrupt reporting in IOAPIC
+-  * KVM: VMX: Check cpl before emulating debug register access
+-  * KVM guest: fix bogus wallclock physical address calculation
+-  * KVM: x86: Disallow hypercalls for guest callers in rings > 0
+-  * KVM: VMX: Fix cr8 exiting control clobbering by EPT
+-  * KVM: x86 emulator: Implement zero-extended immediate decoding
+-  * KVM: MMU: make __kvm_mmu_free_some_pages handle empty list
+-  * KVM: x86 emulator: fix jmp far decoding (opcode 0xea)
+-  * KVM: limit lapic periodic timer frequency
+-  * libata: fix off-by-one error in ata_tf_read_block()
+-  * PCI quirk: update 82576 device ids in SR-IOV quirks list
+-  * PCI: Unhide the SMBus on the Compaq Evo D510 USDT
+-  * powerpc/pseries: Fix to handle slb resize across migration
+-  * Linux 2.6.31.1
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 24 Sep 2009 13:04:28 -0600
+-
+-linux (2.6.31-10.35) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * Disable CONFIG_UEVENT_HELPER_PATH
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] Enable CONFIG_USB_GADGET_DUMMY_HCD
+-  * remove the tlsup driver
+-  * remove lmpcm logitech driver support
+-
+-  [ Bryan Wu ]
+-
+-  * Add 3 missing files to prerm remove file list
+-    - LP: #345623, #415832
+-
+-  [ Chris Wilson ]
+-
+-  * [Upstream] drm/i915: Check that the relocation points to within the
+-    target
+-    - LP: #429241
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Set CONFIG_EXT4_FS=y on ports architectures
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
+-    - LP: #348861
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "[Upstream] ACPI: Add Thinkpad W500, W700, & W700ds to OSI(Linux) white-list"
+-  * Revert "[Upstream] ACPI: Add Thinkpad R400 & Thinkpad R500 to OSI(Linux) white-list"
+-  * Revert "[Upstream] ACPI: Add Thinkpad X300 & Thinkpad X301 to OSI(Linux) white-list"
+-  * Revert "[Upstream] ACPI: Add Thinkpad X200, X200s, X200t to OSI(Linux) white-list"
+-  * Revert "[Upstream] ACPI: Add Thinkpad T400 & Thinkpad T500 to OSI(Linux) white-list"
+-    Upstream suggests that this is not the right approach.
+-
+-  * [Config] Set default I/O scheduler to DEADLINE
+-    CFQ seems to have some load related problems which are often exacerbated by sreadahead.
+-    - LP: #381300
+-
+-  [ ubuntu@tjworld.net ]
+-
+-  * SAUCE: ipw2200: Enable LED by default
+-    - LP: #21367
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ALSA: hda - Add support for new AMD HD audio devices
+-    - LP: #430564
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 16 Sep 2009 15:37:49 +0100
+-
+-linux (2.6.31-10.34) karmic; urgency=low
+-
+-  [ Ted Tso ]
+-
+-  * [Upstream] ext3: Don't update superblock write time when filesystem is
+-    read-only
+-    - LP: #427822
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Sep 2009 16:00:45 -0600
+-
+-linux (2.6.31-10.33) karmic; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Upstream] dvb-usb: fix tuning with Cinergy T2
+-    - LP: #421258
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Unconditionally copy files from sub-flavours lists.
+-    (really, really fix it this time)
+-    - LP: #423426
+-  * [Config] Set CONFIG_CACHEFILES=m for all flavours
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ext4: Don't update superblock write time when filesystem is read-only
+-    - LP: #427822
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Sep 2009 07:50:21 -0600
+-
+-linux (2.6.31-10.32) karmic; urgency=low
+-
+-  [ Eric Miao ]
+-
+-  * [Config] enable module support for memory stick
+-    - LP: #159951
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Unconditionally copy files from sub-flavours lists.
+-    - LP: #423426
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 10 Sep 2009 15:57:55 -0600
+-
+-linux (2.6.31-10.31) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.31 final
+-
+-  [ Colin Watson ]
+-
+-  * [Config] Recommend grub-pc in linux-image
+-    - LP: #385741
+-
+-  [ Ike Panhc ]
+-
+-  * [Upstream] Pull latest update of lenovo-sl-laptop
+-
+-  [ Peter Feuerer ]
+-
+-  * [Upstream] (drop after 2.6.31) acerhdf: fix fan control for AOA150
+-    model
+-    - LP: #426691
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] De-macro some package names.
+-
+-  [ Upstream Changes ]
+-
+-  * rebase to 2.6.31 final.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 10 Sep 2009 09:38:10 +0100
+-
+-linux (2.6.31-10.30) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * [Config] Enable CONFIG_USB_DEVICEFS
+-    - LP: #417748
+-  * [Config] Populate the config-update template a bit more
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.31-rc9
+-  * [Config] update configs following rebase to v2.6.31-rc9
+-  * [Config] update ports configs following rebase to v2.6.31-rc9
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: wireless: hostap, fix oops due to early probing interrupt
+-    - LP: #254837
+-
+-  [ Jerone Young ]
+-
+-  * [Upstream] ACPI: Add Thinkpad T400 & Thinkpad T500 to OSI(Linux)
+-    white-list
+-    - LP: #281732
+-  * [Upstream] ACPI: Add Thinkpad X200, X200s, X200t to OSI(Linux)
+-    white-list
+-    - LP: #281732
+-  * [Upstream] ACPI: Add Thinkpad X300 & Thinkpad X301 to OSI(Linux)
+-    white-list
+-    - LP: #281732
+-  * [Upstream] ACPI: Add Thinkpad R400 & Thinkpad R500 to OSI(Linux)
+-    white-list
+-    - LP: #281732
+-  * [Upstream] ACPI: Add Thinkpad W500, W700, & W700ds to OSI(Linux)
+-    white-list
+-    - LP: #281732
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: Fix profile attachment for regexp based profile names
+-    - LP: #419308
+-  * SAUCE: AppArmor: Return the correct error codes on profile
+-    addition/removal
+-    - LP: #408473
+-  * SAUCE: AppArmor: Fix OOPS in profile listing, and display full list
+-    - LP: #408454
+-  * SAUCE: AppArmor: Fix mapping of pux to new internal permission format
+-    - LP: #419222
+-  * SAUCE: AppArmor: Fix change_profile failure
+-    - LP: #401931
+-  * SAUCE: AppArmor: Tell git to ignore generated include files
+-    - LP: #419505
+-
+-  [ Stefan Bader ]
+-
+-  * [Upstream] acpi: video: Loosen strictness of video bus detection code
+-    - LP: #333386
+-  * SAUCE: Remove ov511 driver from ubuntu subdirectory
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Exclude char-modules from non-x86 udeb creation
+-  * SAUCE: Notify the ACPI call chain of AC events
+-  * [Config] CONFIG_SATA_VIA=m
+-    - LP: #403385
+-  * [Config] Build in all phylib support modules.
+-  * [Config] Don't fail when sub-flavour files are missing
+-    - LP: #423426
+-  * [Config] Set CONFIG_LSM_MMAP_MIN_ADDR=0
+-    - LP: #423513
+-
+-  [ Upstream ]
+-
+-  * Rebased against v2.6.31-rc9
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 07 Sep 2009 11:33:45 +0100
+-
+-linux (2.6.31-9.29) karmic; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Upstream] agp/intel: support for new chip variant of IGDNG mobile
+-    - LP: #419993
+-  * [Config] d-i/modules: Add new char-modules file, initialize with
+-    intel-agp
+-    - LP: #420605
+-
+-  [ Upstream ]
+-
+-  * Rebased against 2.6.31-rc8 plus some inotify regression patches:
+-    up through git://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux-2.6.git
+-    adda766193ea1cf3137484a9521972d080d0b7af.
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Fri, 28 Aug 2009 06:31:30 -0600
+-
+-linux (2.6.31-8.28) karmic; urgency=low
+-
+-  [ Ike Panhc ]
+-
+-  * [Config] Let nic-shared-modules depends on crypto-modules
+-    - LP: #360966
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Upstream] (drop after 2.6.31) drm/i915: increase default latency
+-    constant
+-    - LP: #412492
+-
+-  [ Mario Limonciello ]
+-
+-  * [Upstream]: (drop after 2.6.31) dell-laptop: don't change softblock
+-    status if HW switch is disabled
+-    - LP: #418721
+-  * [Upstream]: (drop after 2.6.31) compal-laptop: Add support for known
+-    Compal made Dell laptops
+-  * [Upstream]: (drop after 2.6.31) compal-laptop: Replace sysfs support
+-    with rfkill support
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add acpiphp to virtual sub-flavour
+-    - LP: #364916
+-  * Drop KSM patch set for now because of instabilities with encrypted swap.
+-    - LP: #418781
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 26 Aug 2009 08:14:26 -0600
+-
+-linux (2.6.31-7.27) karmic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] updateconfigs updateportsconfigs after 2.6.31-rc7 rebase
+-  * SAUCE: (drop after 2.6.31) Added KSM from mmotm-2009-08-20-19-18
+-    Replaces previous ksm patches from 2.6.31-6.25
+-  * [Config] KSM=y
+-
+-  [ Upstream ]
+-
+-  * Rebased against v2.6.31-rc7
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Sat, 22 Aug 2009 20:32:11 -0600
+-
+-linux (2.6.31-6.26) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_AUFS_BR_RAMFS
+-    - LP: #414738
+-  * split out debian directory ready for abstraction
+-  * add printdebian target to find branch target
+-  * abstracted debian -- debian/files is not abstracted
+-  * abstracted debian -- packages must be built in debian/<pkg>
+-  * abstracted debian -- kernel-wedge needs to work in debian/
+-  * abstracted debian -- ensure we install the copyright file
+-  * abstracted-debian -- drop the debian directories from headers
+-  * abstracted-debian -- drop the debian directories from headers part 2
+-  * SAUCE: ubuntu-insert-changes -- follow abstracted debian
+-  * [Upstream] aoe: ensure we initialise the request_queue correctly V2
+-    - LP: #410198
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Ports: Disable CONFIG_CPU_FREQ_DEBUG on powerpc-smp
+-  * [Config] Ports: Re-enable windfarm modules on powerpc64-smp
+-    - LP: #413150
+-  * [Config] Ports: Build all cpu frequency scaling governors into ports
+-    kernels
+-  * [Config] Ports: Build ext2 and ext3 modules into ports kernels
+-  * [Config] Ports: CONFIG_PACKET=y for all ports kernels
+-  * [Config] Ports: Enable PS3 network driver
+-
+-  [ Stefan Bader ]
+-
+-  * abstracted debian -- call $(DEBIAN)/rules using make
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Abstract the debian directory
+-  * SAUCE: Improve error reporting in postinst
+-    - LP: #358564
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Sun, 16 Aug 2009 20:33:28 -0600
+-
+-linux (2.6.31-6.25) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * script to generate Ubuntu changes from changelog
+-  * [Config] standardise ANDROID options
+-  * [Config] standardise CONFIG_ATM as module
+-  * [Config] standardise CONFIG_LIB80211 as module
+-  * [Config] disable CONFIG_PRINT_QUOTA_WARNING
+-  * [Config] set CONFIG_CRAMFS as module
+-  * [Config] enable CONFIG_DAB and modules
+-  * [Config] set CONFIG_MAC80211_HWSIM as module
+-  * [Config] set CONFIG_NET_CLS_FLOW as module
+-  * [Config] set CONFIG_NF_CONNTRACK_SANE as module
+-  * [Config] set CONFIG_NF_CT_PROTO_DCCP as module
+-  * [Config] set CONFIG_RTC_DRV_DS1511 as module
+-  * [Config] set CONFIG_RTC_DRV_R9701 as module
+-  * [Config] set CONFIG_RTC_DRV_S35390A as module
+-  * [Config] set CONFIG_TOIM3232_DONGLE as module
+-  * [Config] standardise CONFIG_USB_MIDI_GADGET as module
+-  * [Config] standardise CONFIG_USB_G_PRINTER as module
+-  * [Config] standardise CONFIG_USB_SERIAL_IR as module
+-  * [Config] set CONFIG_USB_SERIAL_IUU as module
+-  * [Config] standardise CONFIG_USB_STORAGE_CYPRESS_ATACB as module
+-  * [Config] standardise CONFIG_USB_STORAGE_ONETOUCH as module
+-  * cleanup remains of dm-loop
+-  * drop thinkpad ec and smapi support
+-  * drop appleir
+-  * [Config] update configs following rebase to v2.6.31-rc6
+-  * rebase to v2.6.31-rc6
+-
+-  [ Hugh Dickins ]
+-
+-  * SAUCE: ksm patch 1, drop after 2.6.31
+-  * SAUCE: ksm patch 2, drop after 2.6.31
+-  * SAUCE: ksm patch 3, drop after 2.6.31
+-  * SAUCE: ksm patch 4, drop after 2.6.31
+-  * SAUCE: ksm patch 5, drop after 2.6.31
+-  * SAUCE: ksm patch 7, drop after 2.6.31
+-
+-  [ Izik Eidus ]
+-
+-  * SAUCE: ksm patch 0, drop after 2.6.31
+-  * SAUCE: ksm patch 6, drop after 2.6.31
+-  * SAUCE: ksm patch 8, drop after 2.6.31
+-  * SAUCE: ksm patch 9, drop after 2.6.31
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Ports: Re-add PS3 modules to udebs
+-
+-  [ Michael Casadevall ]
+-
+-  * [Config] Update SPARC config and d-i files to reflect what can be built
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Removed armel package support
+-  * [Config] Enabled CONFIG_KSM=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Rebased against v2.6.31-rc6
+-  * ARM: Cleanup: Revert "ARM: Add more cache memory types macros"
+-  * ARM: Cleanup: Revert "Do not use OOB with MLC NAND"
+-  * ARM: Cleanup: Revert "ARM: Make ARM arch aware of ubuntu/ drivers"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Make video capture drivers compile"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Fix isl29003 HWMON driver for i2c
+-    changes"
+-  * ARM: Cleanup: Revert "ARM: IMX51: IPU irq handler deadlock fix"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Babbage 2.5 needs a different system
+-    revision"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Compile-in the IMX51 cpufreq driver
+-    by default"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Enable ZONE_DMA for ARCH_MXC"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Make ARCH_MXC auto-enable
+-    ARCH_MXC_CANONICAL"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Unconditionally disable
+-    CONFIG_GPIOLIB"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Minimal changes for USB to work on
+-    2.6.31"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Fix plat-mxc/timer.c to handle imx51"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Make it compile."
+-  * ARM: Cleanup: Revert "ARM: IMX51: Clean-up the craziness of including
+-    mxc_uart.h _everywhere_"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Move board-mx51* header files to the
+-    correct location"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Changed from snd_card_new to
+-    snd_card_create"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Fix up merge error in Kconfig"
+-  * ARM: Cleanup: Revert "ARM: IMX51: mxc_timer_init prototype"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Removed the mxc_gpio_port structure."
+-  * ARM: Cleanup: Revert "ARM: IMX51: Added external declaration for
+-    mxc_map_io."
+-  * ARM: Cleanup: Revert "ARM: IMX51: Get to bus_id by calling dev_name."
+-  * ARM: Cleanup: Revert "ARM: IMX51: Get to bus_id by calling dev_name."
+-  * ARM: Cleanup: Revert "ARM: IMX51: snd_soc_machine structure replaced
+-    with snd_soc_card."
+-  * ARM: Cleanup: Revert "ARM: IMX51: codec structure was moved to the card
+-    structure"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Hack to add defines for
+-    DMA_MODE_READ/WRITE/MASK"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Add SoC and board support for
+-    Freescale mx51 platform"
+-  * Driver core: add new device to bus's list before probing
+-  * [Upstream] (drop after 2.6.31) ALSA: hda - Reduce click noise at
+-    power-saving
+-    - LP: #381693, #399750, #380892
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 14 Aug 2009 11:32:23 +0100
+-
+-linux (2.6.31-5.24) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * ARM: IMX51: Make video capture drivers compile
+-  * [Config] IMX51: Config updates
+-
+-  [ Andy Whitcroft ]
+-
+-  * remove leftovers of dm-bbr
+-
+-  [ Leann Ogasawara ]
+-
+-  * Add pata_cs5535 to pata-modules
+-    - LP: #318805
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] CONFIG_PPC64=y for powerpc64-smp
+-  * [Config] Set the maximum number of CPUs to 1024 for powerpc64-smp
+-  * [Config] CONFIG_PPC_PS3=y for powerpc64-smp
+-  * [Config] CONFIG_PPC_MAPLE=y on powerpc64-smp
+-  * [Config] CONFIG_PPC_PASEMI=y on powerpc64-smp
+-  * [Config] CONFIG_CPU_FREQ_PMAC64=y on powerpc64-smp
+-  * [Config] Enable all PS3 drivers in powerpc64-smp
+-
+-  [ Mario Limonciello ]
+-
+-  * LIRC -- fix lirc-i2c 2.6.31 compilation
+-
+-  [ Matthew Garrett ]
+-
+-  * [Upstream] dell-laptop: Fix rfkill state queries
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Ignore armel ABI and module changes
+-  * [Config] Update configs after rebase against 2.6.31-rc5
+-
+-  [ Upstream ]
+-
+-  * Rebased to 2.6.31-rc5
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 28 Jul 2009 10:10:09 +0100
+-
+-linux (2.6.31-4.23) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * AUFS -- update to aufs2-30 20090727
+-  * [Config] enable AUFS FUSE support
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] CONFIG_JFS_FS=m on sparc
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] dell-laptop: Fix rfkill state setting.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 27 Jul 2009 11:11:47 +0100
+-
+-linux (2.6.31-4.22) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * ARM: IMX51: Add SoC and board support for Freescale mx51 platform
+-  * ARM: IMX51: Move board-mx51* header files to the correct location
+-  * ARM: IMX51: Clean-up the craziness of including mxc_uart.h _everywhere_
+-  * ARM: IMX51: Make it compile.
+-  * ARM: IMX51: Unconditionally disable CONFIG_GPIOLIB
+-  * ARM: IMX51: Make ARCH_MXC auto-enable ARCH_MXC_CANONICAL
+-  * ARM: IMX51: Enable ZONE_DMA for ARCH_MXC
+-  * ARM: IMX51: Compile-in the IMX51 cpufreq driver by default
+-  * ARM: IMX51: Fix isl29003 HWMON driver for i2c changes
+-  * ARM: USB: musb: Refer to musb_otg_timer_func under correct #ifdef
+-  * ARM: staging: udlfb: Add vmalloc.h include
+-  * UBUNTU [Config]: Bring imx51 config upto date with other flavours
+-
+-  [ Brad Figg ]
+-
+-  * ARM: IMX51: Hack to add defines for DMA_MODE_READ/WRITE/MASK
+-  * ARM: IMX51: codec structure was moved to the card structure
+-  * ARM: IMX51: snd_soc_machine structure replaced with snd_soc_card.
+-  * ARM: IMX51: Get to bus_id by calling dev_name.
+-  * ARM: IMX51: Get to bus_id by calling dev_name.
+-  * ARM: IMX51: Added external declaration for mxc_map_io.
+-  * ARM: IMX51: Removed the mxc_gpio_port structure.
+-  * ARM: IMX51: mxc_timer_init prototype
+-  * ARM: IMX51: Fix up merge error in Kconfig
+-  * ARM: IMX51: Changed from snd_card_new to snd_card_create
+-
+-  [ Dinh Nguyen ]
+-
+-  * ARM: IMX51: Fix plat-mxc/timer.c to handle imx51
+-  * ARM: IMX51: Minimal changes for USB to work on 2.6.31
+-  * ARM: IMX51: Babbage 2.5 needs a different system revision
+-  * ARM: IMX51: IPU irq handler deadlock fix
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enabled CONFIG_CAN=m
+-    - LP: #327243
+-  * [Config] Enabled CONFIG_SERIAL=m
+-    - LP: #397189
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Fri, 24 Jul 2009 06:19:10 -0600
+-
+-linux (2.6.31-4.21) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * dm-raid-4-5: Add missing brackets around test_bit()
+-
+-  [ John Johansen ]
+-
+-  * AppArmor: Fix change_profile failing lpn401931
+-  * AppArmor: Fix determination of forced AUDIT messages.
+-  * AppArmor: Fix oops in auditing of the policy interface offset
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Jul 2009 19:18:30 +0100
+-
+-linux (2.6.31-4.20) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: iscsitarget -- update to SVN revision r214
+-  * SAUCE: iscsitarget -- renable driver
+-  * [Config] consolidate lpia/lpia and i386/generic configs
+-  * [Config] enable CRYPTO modules for all architectures
+-  * [Config] enable cryptoloop
+-  * [Config] enable various filesystems for armel
+-  * [Config] sync i386 generic and generic-pae
+-  * [Config] add the 386 (486 processors and above) flavour
+-  * [Config] re-set DEFAULT_MMAP_MIN_ADDR
+-    - LP: #399914
+-  * add genconfigs/genportsconfigs to extract the built configs
+-  * updateconfigs -- alter concatenation order allow easier updates
+-  * intelfb -- INTELFB now conflicts with DRM_I915
+-  * printchanges -- rebase tree does not have stable tags use changelog
+-  * AppArmor: fix argument size missmatch on 64 bit builds
+-
+-  [ Ike Panhc ]
+-
+-  * Ship bnx2x firmware in nic-modules udeb
+-    - LP: #360966
+-
+-  [ Jeff Mahoney ]
+-
+-  * AppArmor: fix build failure on ia64
+-
+-  [ John Johansen ]
+-
+-  * AppArmour: ensure apparmor enabled parmater is off if AppArmor fails to
+-    initialize.
+-  * AppArmour: fix auditing of domain transitions to include target profile
+-    information
+-  * AppArmor: fix C99 violation
+-  * AppArmor: revert reporting of create to write permission.
+-  * SAUCE: Add config option to set a default LSM
+-  * [Config] enable AppArmor by default
+-  * AppArmor: Fix NULL pointer dereference oops in profile attachment.
+-
+-  [ Keith Packard ]
+-
+-  * SAUCE: drm/i915: Allow frame buffers up to 4096x4096 on 915/945 class
+-    hardware
+-    - LP: #351756
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] add .o files found in arch/powerpc/lib to all powerpc kernel
+-    header packages
+-    - LP: #355344
+-
+-  [ Michael Casadevall ]
+-
+-  * [Config] update SPARC config files to allow success build
+-
+-  [ Scott James Remnant ]
+-
+-  * SAUCE: trace: add trace_event for the open() syscall
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: jfs: Fix early release of acl in jfs_get_acl
+-    - LP: #396780
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] Fix Soltech TA12 volume hotkeys not sending key release
+-    - LP: #397499
+-  * [Upstream] USB Option driver - Add USB ID for Novatel MC727/U727/USB727
+-    refresh
+-    - LP: #365291
+-  * [Config] SSB/B44 are common across all arches/flavours.
+-
+-  [ Upstream ]
+-
+-  * Rebased to 2.6.31-rc4
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Jul 2009 08:41:39 +0100
+-
+-linux (2.6.31-3.19) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Config] Disabled NDISWRAPPER"
+-  * ndiswrapper -- fix i386 compilation failures on cmpxchg8b
+-  * AUFS -- export various core functions
+-  * AUFS -- export various core functions -- fixes
+-  * AUFS -- core filesystem
+-  * AUFS -- track changes in v2.6.31
+-  * [Config] Enable AUFS
+-  * droppped 'iwl3945: do not send scan command if channel count zero' as it
+-    is already upstream but failed to auto-drop on rebase.
+-
+-  [ Eric Paris ]
+-
+-  * SAUCE: fsnotify: use def_bool in kconfig instead of letting the user
+-    choose
+-  * SAUCE: inotify: check filename before dropping repeat events
+-  * SAUCE: fsnotify: fix inotify tail drop check with path entries
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 14 Jul 2009 12:52:55 +0100
+-
+-linux (2.6.31-3.18) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "Add splice-2.6.23.patch from AUFS to export a symbol needed by
+-    AUFS"
+-  * Revert "Add put_filp.patch from AUFS to export a symbol needed by AUFS"
+-  * Revert "Add sec_perm-2.6.24.patch from AUFS - export
+-    security_inode_permission"
+-  * clear out left over AUFS files and modifications
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Enable CONFIG_USB_ISP116X_HCD on sparc
+-  * SAUCE: Explicitly include header files to allow apparmor to build on
+-    powerpc
+-  * [Config] Enable CONFIG_BLK_DEV_IDECD on powerpc
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Dropped ubuntu/misc/wireless/acx
+-  * [Config] Disabled NDISWRAPPER until the compile issues are fixed.
+-
+-  [ Upstream ]
+-
+-  * Rebased to 2.6.31-rc3
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 10 Jul 2009 18:59:33 +0100
+-
+-linux (2.6.31-2.17) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_BLK_DEV_CRYPTOLOOP=m for sparc
+-  * compcache -- remove redundant Kconfig entries part 2
+-  * compcache -- clean up CCFLAGS declarations
+-  * [Config] enable AppArmor
+-  * AppArmor: fix operator precidence issue in as_path_link
+-
+-  [ John Johansen ]
+-
+-  * AppArmor security module
+-  * AppArmor: Correct mapping of file permissions.
+-  * AppArmor: Turn auditing of ptrace on
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] disable CONFIG_DM_RAID45 on powerpc
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 10 Jul 2009 15:02:05 +0100
+-
+-linux (2.6.31-2.16) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * compcache -- remove redundant Kconfig entries
+-    added ignore and ignore.modules for all arches since the compcache update
+-    changes the modules names as well as some compcache ABI values.
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: updated dm-raid45 module version to 2009.04.24 (2.6.30-rc3)
+-  * SAUCE: update compcache version to 0.5.3
+-
+-  [ Tim Gardner ]
+-
+-  * [Config]: Fix sparc FTBS by adding ignore.modules
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 06 Jul 2009 13:35:29 -0600
+-
+-linux (2.6.31-2.15) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: default ATI Radeon KMS to off until userspace catches up
+-  * [Config] Update configs following rebase to 2.6.31-rc2
+-  * [Config] update ports configs following update to 2.6.31-rc2
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] powerpc - Disable CONFIG_RDS
+-
+-  [ Matt Zimmerman ]
+-
+-  * Rename linux-doc-PKGVER to linux-doc and clean up its description
+-    - LP: #382115
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to mainline 2.6.31-rc2
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 04 Jul 2009 17:39:13 +0100
+-
+-linux (2.6.31-1.14) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * update ndiswrapper to 1.55
+-  * remove leftovers of gfs
+-  * [Config] powerpc: enable CONFIG_PPC_DISABLE_WERROR
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] re-enable and build the ide-pmac driver into powerpc kernels
+-  * [Config] Build the ServerWorks Frodo / Apple K2 SATA driver into the
+-    kernel
+-
+-  [ Manoj Iyer ]
+-
+-  * Remove snd-bt-sco ubuntu driver
+-
+-  [ Michael Casadevall ]
+-
+-  * [Config] updates ia64 config and d-i folders to allow succesful build
+-  * [Config] Update powerpc and sparc for 2.6.31
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * intel-iommu: fix Identity Mapping to be arch independent
+-    - LP: #384695
+-  * ACPI: video: prevent NULL deref in acpi_get_pci_dev()
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 30 Jun 2009 17:47:32 +0100
+-
+-linux (2.6.31-1.13) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * REBASE: rebased to mainline 2.6.31-rc1
+-    - "UBUNTU: SAUCE: UHCI USB quirk for resume"
+-      no longer applies, using deprecated interfaces, LPIA only, dropped
+-    - "UBUNTU: SAUCE: Mask off garbage in Dell WMI scan code data"
+-      changes now upstream, dropped
+-  * [Config] Update configs following rebase to 2.6.31-rc1
+-  * [Config] update ports configs following update to 2.6.31-rc1
+-
+-  * [Config] disable broken staging driver CONFIG_STLC45XX
+-  * SAUCE: fix compcache to use updates accessors
+-  * [Config] disable staging driver CONFIG_VT6655
+-  * SAUCE: fix DRDB to use updates accessors
+-  * [Disable] ndiswrapper needs update
+-  * [Disable] LIRC I2C needs update
+-  * [Disable] CONFIG_LENOVO_SL_LAPTOP needs update
+-  * [Config] disable I2C_DESIGNWARE does not compile
+-  * [Config] disable CONFIG_TLSUP for lpia
+-  * [Config] disable CONFIG_FB_UDL for arm
+-  * SAUCE: disable adding scsi headers to linux-libc-dev
+-
+-  [ Mario Limonciello ]
+-
+-  * SAUCE: Add LIRC drivers
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 25 Jun 2009 12:06:22 +0100
+-
+-linux (2.6.30-10.12) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] split out the ports configs into their own family
+-  * [Config] update configs following introduction of ports family
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "Rename linux-doc-PKGVER to linux-doc and clean up its
+-    description". Fixes linux-doc package name conflicts for now.
+-    - LP: #382115
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 22 Jun 2009 09:17:14 -0600
+-
+-linux (2.6.30-10.11) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * [Config] Comment splitconfig.pl and misc cleanup
+-  * [Config] Rename all configs to the new naming scheme
+-  * [Config] Splitconfig rework
+-  * [Config] Rename scripts/misc/oldconfig to kernelconfig
+-  * [Config] Fix build system for new config split
+-  * [Config] Run updateconfigs after the splitconfig rework
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: Default to i915.modeset=0 if CONFIG_DRM_I915_KMS=y"
+-  * [Config] standardise CONFIG_STAGING=y
+-  * [Config] standardise CONFIG_RD_LZMA=y
+-  * [Config] CONFIG_PCI_IOV=y
+-  * [Config] CONFIG_PCI_STUB=m
+-  * [Config] merge kernel configs more agressively
+-
+-  [ Colin Watson ]
+-
+-  * [Config] Run kernel-wedge in $(builddir) rather than at the top level
+-  * [Config] Add support for including firmware in udebs
+-  * [Config] Ship bnx2 firmware in nic-modules udeb
+-    - LP: #384861
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] ports - Import of ports architectures into kernel packaging
+-    infrastructure
+-  * [Config] ports - Do not update ports kernel configurations by default
+-  * [Config] ports - Disable ABI checking for ports architectures
+-  * [Config] ports - Build drivers in ubuntu sub-directory on powerpc
+-  * [Config] ports - Add control.d/vars.* files for ports architectures
+-  * [Config] ports - Add ports architectures for linux-libc-dev
+-  * [Config] ports - Create powerpc specific message-modules and
+-    block-modules udebs
+-  * [Config] ports - Add configuration files for ports architectures
+-
+-  [ Manoj Iyer ]
+-
+-  * [Config] Enable CONFIG_BLK_DEV_AEC62XX=m for amd64 and i386
+-    - LP: #329864
+-
+-  [ Michael Casadevall ]
+-
+-  * [Config] ports - Fix compression of kernels
+-
+-  [ Stefan Bader ]
+-
+-  * [Upstream] mmc: prevent dangling block device from accessing stale
+-    queues
+-    - LP: #383668
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Recommend grub-pc in linux-image
+-    - LP: #385741
+-  * [Config] Implement i386 generic and generic-pae flavours
+-  * [Config] ports - Add control info after integrating ports arches
+-  * [Config] Removed auto-generated files from git
+-  * [Config] Added netxen_nic to nic-modules
+-    - LP: #389603
+-
+-  [ Matt Zimmerman ]
+-
+-  * Rename linux-doc-PKGVER to linux-doc and clean up its description
+-    - LP: #382115
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 15 Jun 2009 14:38:26 -0600
+-
+-linux (2.6.30-9.10) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_SECURITY_TOMOYO=y (amd64, i386, lpia)
+-  * [Config] CONFIG_KEXEC_JUMP=y (amd64, lpia)
+-  * [Config] CONFIG_LENOVO_SL_LAPTOP=m (amd64, lpia)
+-  * [Config] CONFIG_POHMELFS_CRYPTO=y (i386, amd64)
+-  * [Config] CONFIG_SERIAL_MAX3100=m (i386, amd64, lpia)
+-  * [Config] CONFIG_VIDEO_GO7007=m (amd64, i386)
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30 final
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Jun 2009 11:42:53 +0100
+-
+-linux (2.6.30-8.9) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Config update removed the following options:
+-        CONFIG_EDAC_AMD8111=m
+-        CONFIG_EDAC_AMD8131=m
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30-rc8
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 03 Jun 2009 09:21:13 +0100
+-
+-linux (2.6.30-7.8) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Enabled NEW configration options:
+-      Paravirtualization layer for spinlocks (PARAVIRT_SPINLOCKS) [N/y/?] Y
+-      Cisco FNIC Driver (FCOE_FNIC) [N/m/y/?] M
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30-rc7
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 23 May 2009 23:47:24 +0100
+-
+-linux (2.6.30-6.7) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Dropped: UBUNTU: SAUCE: input: Blacklist digitizers from joydev.c (now
+-    upstream)
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30-rc6
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 18 May 2009 18:05:54 +0100
+-
+-linux (2.6.30-5.6) karmic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enable Keyspan USB serial device firmware in kernel module
+-    - LP: #334285
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30-rc5
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 11 May 2009 12:02:16 -0600
+-
+-linux (2.6.30-4.5) karmic; urgency=low
+-
+-  [ Colin Watson ]
+-
+-  * Build-Conflict with findutils (= 4.4.1-1ubuntu1), to avoid
+-    /usr/include/asm/* going missing
+-    - LP: #373214
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Fri, 08 May 2009 11:09:08 +0200
+-
+-linux (2.6.30-3.4) karmic; urgency=low
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: [x86] implement cs-limit nx-emulation for ia32
+-    - LP: #369978
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: input: Blacklist digitizers from joydev.c
+-    - LP: #300143
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Fri, 01 May 2009 14:00:42 -0600
+-
+-linux (2.6.30-2.3) karmic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enabled CC_STACKPROTECTOR=y for all x86en
+-    - LP: #369152
+-  * SAUCE: Default to i915_modeset=0 if CONFIG_DRM_I915_KMS=y
+-  * [Config] CONFIG_DRM_I915_KMS=y
+-  * [Config] Set CONFIG_SECURITY_DEFAULT_MMAP_MIN_ADDR to appropriate ARCH
+-    minimums
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30-rc4
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 30 Apr 2009 09:17:05 -0600
+-
+-linux (2.6.30-1.2) karmic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] armel: disable staging drivers, fixes FTBS
+-  * [Config] armel imx51: Disable CONFIG_MTD_NAND_MXC, fixes FTBS
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * mpt2sas: Change reset_type enum to avoid namespace collision.
+-    Submitted upstream.
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 28 Apr 2009 16:54:41 -0600
+-
+-linux (2.6.30-1.1) karmic; urgency=low
+-
+-  * Initial release after rebasing against v2.6.30-rc3
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 12 Mar 2009 19:16:07 -0600
++ -- Mainline Build <kernel@gloin>  Sat, 03 Feb 2018 12:31:06 -0500
+ 
+-- 
+2.7.4
+
diff --git a/buffalo/ubuntu/0006-configs-based-on-Ubuntu-4.4.0-113.136.patch b/buffalo/ubuntu/0006-configs-based-on-Ubuntu-4.4.0-113.136.patch
new file mode 100644
index 00000000..ce72a25
--- /dev/null
+++ b/buffalo/ubuntu/0006-configs-based-on-Ubuntu-4.4.0-113.136.patch
@@ -0,0 +1,718 @@
+From 3e1a23f5687ca72a20e0b0cc7a3de95b09419f80 Mon Sep 17 00:00:00 2001
+From: Kernel Builder <kernel@gloin.kernel>
+Date: Sat, 3 Feb 2018 12:31:40 -0500
+Subject: [PATCH 6/6] configs (based on Ubuntu-4.4.0-113.136)
+
+---
+ debian.master/config/amd64/config.common.amd64     |   1 -
+ debian.master/config/amd64/config.flavour.generic  |   2 -
+ .../config/amd64/config.flavour.lowlatency         |   2 -
+ debian.master/config/arm64/config.common.arm64     |   8 +-
+ debian.master/config/armhf/config.common.armhf     |   3 -
+ debian.master/config/config.common.ubuntu          | 102 +--------------------
+ debian.master/config/i386/config.common.i386       |   2 -
+ debian.master/config/i386/config.flavour.generic   |   1 -
+ .../config/i386/config.flavour.lowlatency          |   1 -
+ debian.master/config/powerpc/config.common.powerpc |   3 -
+ debian.master/config/ppc64el/config.common.ppc64el |   3 -
+ 11 files changed, 6 insertions(+), 122 deletions(-)
+
+diff --git a/debian.master/config/amd64/config.common.amd64 b/debian.master/config/amd64/config.common.amd64
+index 1377cde..d6b27d2 100644
+--- a/debian.master/config/amd64/config.common.amd64
++++ b/debian.master/config/amd64/config.common.amd64
+@@ -124,7 +124,6 @@ CONFIG_HAVE_SETUP_PER_CPU_AREA=y
+ CONFIG_HFSPLUS_FS=m
+ CONFIG_HFS_FS=m
+ CONFIG_HIBERNATION=y
+-CONFIG_HIO=m
+ CONFIG_HOTPLUG_PCI_PCIE=y
+ CONFIG_HOTPLUG_PCI_SHPC=m
+ CONFIG_HPET=y
+diff --git a/debian.master/config/amd64/config.flavour.generic b/debian.master/config/amd64/config.flavour.generic
+index 4a96322..965113b 100644
+--- a/debian.master/config/amd64/config.flavour.generic
++++ b/debian.master/config/amd64/config.flavour.generic
+@@ -4,7 +4,5 @@
+ CONFIG_HZ=250
+ # CONFIG_HZ_1000 is not set
+ CONFIG_HZ_250=y
+-# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
+-CONFIG_OPENNSL=y
+ # CONFIG_PREEMPT is not set
+ CONFIG_PREEMPT_VOLUNTARY=y
+diff --git a/debian.master/config/amd64/config.flavour.lowlatency b/debian.master/config/amd64/config.flavour.lowlatency
+index 305bd16..0af82e0 100644
+--- a/debian.master/config/amd64/config.flavour.lowlatency
++++ b/debian.master/config/amd64/config.flavour.lowlatency
+@@ -4,7 +4,5 @@
+ CONFIG_HZ=1000
+ CONFIG_HZ_1000=y
+ # CONFIG_HZ_250 is not set
+-CONFIG_IRQ_FORCED_THREADING_DEFAULT=y
+-# CONFIG_OPENNSL is not set
+ CONFIG_PREEMPT=y
+ # CONFIG_PREEMPT_VOLUNTARY is not set
+diff --git a/debian.master/config/arm64/config.common.arm64 b/debian.master/config/arm64/config.common.arm64
+index 06c6881..b57c27a 100644
+--- a/debian.master/config/arm64/config.common.arm64
++++ b/debian.master/config/arm64/config.common.arm64
+@@ -108,7 +108,7 @@ CONFIG_FIRMWARE_IN_KERNEL=y
+ CONFIG_FIXED_PHY=y
+ CONFIG_FMC=m
+ # CONFIG_FONTS is not set
+-CONFIG_FORCE_MAX_ZONEORDER=13
++CONFIG_FORCE_MAX_ZONEORDER=11
+ CONFIG_FRAME_WARN=1024
+ CONFIG_FUSION=y
+ CONFIG_GAMEPORT=m
+@@ -125,7 +125,6 @@ CONFIG_HAVE_ARCH_BITREVERSE=y
+ CONFIG_HAVE_GENERIC_DMA_COHERENT=y
+ CONFIG_HFSPLUS_FS=m
+ CONFIG_HFS_FS=m
+-# CONFIG_HIO is not set
+ CONFIG_HOTPLUG_PCI_PCIE=y
+ CONFIG_HOTPLUG_PCI_SHPC=m
+ # CONFIG_HPET is not set
+@@ -159,7 +158,6 @@ CONFIG_IPMI_HANDLER=m
+ CONFIG_IPX=m
+ # CONFIG_IP_DCCP_CCID3 is not set
+ CONFIG_IRQ_BYPASS_MANAGER=m
+-# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
+ CONFIG_JFS_FS=m
+ CONFIG_JME=m
+ CONFIG_JUMP_LABEL=y
+@@ -261,18 +259,14 @@ CONFIG_NET_VENDOR_VIA=y
+ CONFIG_NET_VENDOR_WIZNET=y
+ CONFIG_NEW_LEDS=y
+ CONFIG_NFC=m
+-CONFIG_NODES_SHIFT=2
+ CONFIG_NOZOMI=m
+ CONFIG_NR_CPUS=128
+ CONFIG_NTB=m
+ # CONFIG_NTFS_RW is not set
+-CONFIG_NUMA=y
+-CONFIG_NUMA_BALANCING_DEFAULT_ENABLED=y
+ CONFIG_NVMEM=m
+ CONFIG_N_GSM=m
+ CONFIG_OF=y
+ CONFIG_OMFS_FS=m
+-# CONFIG_OPENNSL is not set
+ CONFIG_OSF_PARTITION=y
+ # CONFIG_PAGE_EXTENSION is not set
+ CONFIG_PANIC_TIMEOUT=0
+diff --git a/debian.master/config/armhf/config.common.armhf b/debian.master/config/armhf/config.common.armhf
+index ff5a338..0374208 100644
+--- a/debian.master/config/armhf/config.common.armhf
++++ b/debian.master/config/armhf/config.common.armhf
+@@ -122,7 +122,6 @@ CONFIG_HAVE_GENERIC_DMA_COHERENT=y
+ CONFIG_HFSPLUS_FS=m
+ CONFIG_HFS_FS=m
+ CONFIG_HIBERNATION=y
+-# CONFIG_HIO is not set
+ CONFIG_HPFS_FS=m
+ CONFIG_HP_ILO=m
+ CONFIG_HSI=m
+@@ -149,7 +148,6 @@ CONFIG_IPMI_HANDLER=m
+ CONFIG_IPX=m
+ # CONFIG_IP_DCCP_CCID3 is not set
+ CONFIG_IRQ_BYPASS_MANAGER=m
+-# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
+ CONFIG_JFS_FS=m
+ CONFIG_JME=m
+ # CONFIG_JUMP_LABEL is not set
+@@ -262,7 +260,6 @@ CONFIG_NVRAM=m
+ CONFIG_N_GSM=m
+ CONFIG_OF=y
+ CONFIG_OMFS_FS=m
+-# CONFIG_OPENNSL is not set
+ CONFIG_OSF_PARTITION=y
+ CONFIG_PAGE_EXTENSION=y
+ CONFIG_PAGE_OFFSET=0xC0000000
+diff --git a/debian.master/config/config.common.ubuntu b/debian.master/config/config.common.ubuntu
+index 72734ae..fb69a20 100644
+--- a/debian.master/config/config.common.ubuntu
++++ b/debian.master/config/config.common.ubuntu
+@@ -108,9 +108,6 @@ CONFIG_AD5421=m
+ CONFIG_AD5446=m
+ CONFIG_AD5449=m
+ CONFIG_AD5504=m
+-CONFIG_AD5592R=m
+-CONFIG_AD5592R_BASE=m
+-CONFIG_AD5593R=m
+ CONFIG_AD5624R_SPI=m
+ CONFIG_AD5686=m
+ CONFIG_AD5755=m
+@@ -487,7 +484,6 @@ CONFIG_ARM64=y
+ # CONFIG_ARM64_16K_PAGES is not set
+ CONFIG_ARM64_4K_PAGES=y
+ # CONFIG_ARM64_64K_PAGES is not set
+-CONFIG_ARM64_ACPI_PARKING_PROTOCOL=y
+ CONFIG_ARM64_CRYPTO=y
+ CONFIG_ARM64_ERRATUM_819472=y
+ CONFIG_ARM64_ERRATUM_824069=y
+@@ -697,24 +693,6 @@ CONFIG_AUDIT_COMPAT_GENERIC=y
+ CONFIG_AUDIT_GENERIC=y
+ CONFIG_AUDIT_TREE=y
+ CONFIG_AUDIT_WATCH=y
+-CONFIG_AUFS_BDEV_LOOP=y
+-# CONFIG_AUFS_BRANCH_MAX_1023 is not set
+-CONFIG_AUFS_BRANCH_MAX_127=y
+-# CONFIG_AUFS_BRANCH_MAX_32767 is not set
+-# CONFIG_AUFS_BRANCH_MAX_511 is not set
+-# CONFIG_AUFS_BR_FUSE is not set
+-CONFIG_AUFS_BR_HFSPLUS=y
+-# CONFIG_AUFS_BR_RAMFS is not set
+-# CONFIG_AUFS_DEBUG is not set
+-CONFIG_AUFS_EXPORT=y
+-# CONFIG_AUFS_FHSM is not set
+-CONFIG_AUFS_FS=m
+-# CONFIG_AUFS_HNOTIFY is not set
+-CONFIG_AUFS_INO_T_64=y
+-# CONFIG_AUFS_RDU is not set
+-CONFIG_AUFS_SBILIST=y
+-# CONFIG_AUFS_SHWH is not set
+-CONFIG_AUFS_XATTR=y
+ CONFIG_AURORA_NB8800=m
+ CONFIG_AUTO_ZRELADDR=y
+ CONFIG_AX25=m
+@@ -874,7 +852,6 @@ CONFIG_BLK_DEV_LOOP_MIN_COUNT=8
+ CONFIG_BLK_DEV_MD=y
+ CONFIG_BLK_DEV_NBD=m
+ CONFIG_BLK_DEV_NULL_BLK=m
+-CONFIG_BLK_DEV_NVME_SCSI=y
+ CONFIG_BLK_DEV_OSD=m
+ CONFIG_BLK_DEV_PMEM=m
+ CONFIG_BLK_DEV_RAM=m
+@@ -909,9 +886,6 @@ CONFIG_BNX2X=m
+ CONFIG_BNX2X_SRIOV=y
+ CONFIG_BNX2X_VXLAN=y
+ CONFIG_BNXT=m
+-CONFIG_BNXT_BPO=m
+-CONFIG_BNXT_BPO_DCB=y
+-CONFIG_BNXT_BPO_SRIOV=y
+ CONFIG_BNXT_SRIOV=y
+ CONFIG_BOARD_TPCI200=m
+ CONFIG_BONDING=m
+@@ -930,6 +904,7 @@ CONFIG_BOOT_PRINTK_DELAY=y
+ CONFIG_BPF=y
+ CONFIG_BPF_EVENTS=y
+ CONFIG_BPF_JIT=y
++# CONFIG_BPF_JIT_ALWAYS_ON is not set
+ CONFIG_BPF_SYSCALL=y
+ CONFIG_BPQETHER=m
+ CONFIG_BQL=y
+@@ -1096,7 +1071,6 @@ CONFIG_CAN_XILINXCAN=m
+ CONFIG_CAPI_AVM=y
+ CONFIG_CAPI_EICON=y
+ CONFIG_CAPI_TRACE=y
+-CONFIG_CARACALLA_BOARD=y
+ CONFIG_CARDBUS=y
+ CONFIG_CARDMAN_4000=m
+ CONFIG_CARDMAN_4040=m
+@@ -1108,7 +1082,6 @@ CONFIG_CARL9170_WPC=y
+ # CONFIG_CARMINE_DRAM_CUSTOM is not set
+ CONFIG_CASSINI=m
+ CONFIG_CAVIUM_ERRATUM_22375=y
+-CONFIG_CAVIUM_ERRATUM_23144=y
+ CONFIG_CAVIUM_ERRATUM_23154=y
+ CONFIG_CAVIUM_ERRATUM_27456=y
+ # CONFIG_CB710_DEBUG is not set
+@@ -1941,14 +1914,12 @@ CONFIG_DRAGONRISE_FF=y
+ CONFIG_DRM_AMDGPU=m
+ # CONFIG_DRM_AMDGPU_CIK is not set
+ CONFIG_DRM_AMDGPU_USERPTR=y
+-CONFIG_DRM_AMD_POWERPLAY=y
+ CONFIG_DRM_ARMADA=m
+ CONFIG_DRM_AST=m
+ CONFIG_DRM_ATMEL_HLCDC=m
+ # CONFIG_DRM_BOCHS is not set
+ CONFIG_DRM_BRIDGE=y
+ CONFIG_DRM_CIRRUS_QEMU=m
+-CONFIG_DRM_DP_AUX_CHARDEV=y
+ CONFIG_DRM_DW_HDMI=m
+ CONFIG_DRM_DW_HDMI_AHB_AUDIO=m
+ CONFIG_DRM_EXYNOS=m
+@@ -1973,11 +1944,6 @@ CONFIG_DRM_I2C_NXP_TDA998X=m
+ CONFIG_DRM_I2C_SIL164=m
+ CONFIG_DRM_I810=m
+ CONFIG_DRM_I915=m
+-CONFIG_DRM_I915_BPO=m
+-# CONFIG_DRM_I915_BPO_DEBUG is not set
+-# CONFIG_DRM_I915_BPO_PRELIMINARY_HW_SUPPORT is not set
+-CONFIG_DRM_I915_BPO_USERPTR=y
+-# CONFIG_DRM_I915_BPO_WERROR is not set
+ # CONFIG_DRM_I915_PRELIMINARY_HW_SUPPORT is not set
+ CONFIG_DRM_IMX=m
+ CONFIG_DRM_IMX_FB_HELPER=m
+@@ -2250,7 +2216,6 @@ CONFIG_DYNAMIC_FTRACE_WITH_REGS=y
+ CONFIG_E100=m
+ CONFIG_E1000=m
+ CONFIG_E1000E=m
+-CONFIG_E1000E_HWTS=y
+ # CONFIG_E200 is not set
+ CONFIG_E500=y
+ # CONFIG_E5500_CPU is not set
+@@ -2292,7 +2257,6 @@ CONFIG_EDAC_MPC85XX=m
+ CONFIG_EDAC_PASEMI=m
+ CONFIG_EDAC_R82600=m
+ CONFIG_EDAC_SBRIDGE=m
+-CONFIG_EDAC_SKX=m
+ CONFIG_EDAC_SUPPORT=y
+ CONFIG_EDAC_X38=m
+ CONFIG_EDAC_XGENE=m
+@@ -2317,10 +2281,7 @@ CONFIG_EFI_PARTITION=y
+ # CONFIG_EFI_PGT_DUMP is not set
+ CONFIG_EFI_RUNTIME_MAP=y
+ CONFIG_EFI_RUNTIME_WRAPPERS=y
+-CONFIG_EFI_SECURE_BOOT_SIG_ENFORCE=y
+-CONFIG_EFI_SIGNATURE_LIST_PARSER=y
+ CONFIG_EFI_STUB=y
+-CONFIG_EFI_TEST=m
+ CONFIG_EFI_VARS=y
+ CONFIG_EFI_VARS_PSTORE=m
+ # CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE is not set
+@@ -2338,7 +2299,6 @@ CONFIG_EMAC_ROCKCHIP=m
+ CONFIG_EMU_SIZE=0x10000000
+ # CONFIG_ENABLE_MUST_CHECK is not set
+ # CONFIG_ENABLE_WARN_DEPRECATED is not set
+-CONFIG_ENA_ETHERNET=m
+ CONFIG_ENC28J60=m
+ # CONFIG_ENC28J60_WRITEVERIFY is not set
+ CONFIG_ENCRYPTED_KEYS=y
+@@ -2701,6 +2661,7 @@ CONFIG_GENERIC_CMOS_UPDATE=y
+ CONFIG_GENERIC_CPU=y
+ CONFIG_GENERIC_CPU_AUTOPROBE=y
+ # CONFIG_GENERIC_CPU_DEVICES is not set
++CONFIG_GENERIC_CPU_VULNERABILITIES=y
+ CONFIG_GENERIC_EARLY_IOREMAP=y
+ CONFIG_GENERIC_FIND_FIRST_BIT=y
+ CONFIG_GENERIC_HWEIGHT=y
+@@ -2873,6 +2834,7 @@ CONFIG_HAVE_DMA_ATTRS=y
+ CONFIG_HAVE_DMA_CONTIGUOUS=y
+ CONFIG_HAVE_DYNAMIC_FTRACE=y
+ CONFIG_HAVE_DYNAMIC_FTRACE_WITH_REGS=y
++CONFIG_HAVE_EBPF_JIT=y
+ CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS=y
+ CONFIG_HAVE_FENTRY=y
+ CONFIG_HAVE_FTRACE_MCOUNT_RECORD=y
+@@ -2976,7 +2938,6 @@ CONFIG_HIDRAW=y
+ CONFIG_HID_A4TECH=m
+ CONFIG_HID_ACRUX=m
+ CONFIG_HID_ACRUX_FF=y
+-CONFIG_HID_ALPS=m
+ CONFIG_HID_APPLE=m
+ CONFIG_HID_APPLEIR=m
+ CONFIG_HID_AUREAL=m
+@@ -3159,9 +3120,6 @@ CONFIG_HSU_DMA=m
+ CONFIG_HSU_DMA_PCI=m
+ CONFIG_HTC_EGPIO=y
+ CONFIG_HTC_I2CPLD=y
+-CONFIG_HTS221=m
+-CONFIG_HTS221_I2C=m
+-CONFIG_HTS221_SPI=m
+ CONFIG_HTU21=m
+ CONFIG_HT_IRQ=y
+ CONFIG_HUGETLBFS=y
+@@ -3203,7 +3161,6 @@ CONFIG_HW_RANDOM_TPM=m
+ CONFIG_HW_RANDOM_VIA=m
+ CONFIG_HW_RANDOM_VIRTIO=m
+ CONFIG_HW_RANDOM_XGENE=m
+-CONFIG_HW_SCAN_OFFLOAD=y
+ CONFIG_HYPERV=m
+ CONFIG_HYPERVISOR_GUEST=y
+ CONFIG_HYPERV_BALLOON=m
+@@ -3302,7 +3259,6 @@ CONFIG_I2C_SMBUS=m
+ CONFIG_I2C_STUB=m
+ CONFIG_I2C_TAOS_EVM=m
+ CONFIG_I2C_TEGRA=m
+-CONFIG_I2C_THUNDERX=m
+ CONFIG_I2C_TINY_USB=m
+ CONFIG_I2C_UNIPHIER=m
+ CONFIG_I2C_UNIPHIER_F=m
+@@ -3330,7 +3286,6 @@ CONFIG_IBMASR=m
+ CONFIG_IBMEBUS=y
+ CONFIG_IBMVETH=m
+ CONFIG_IBMVIO=y
+-CONFIG_IBMVNIC=m
+ CONFIG_IBM_ASM=m
+ CONFIG_IBM_BSR=m
+ # CONFIG_IBM_EMAC_EMAC4 is not set
+@@ -3408,7 +3363,6 @@ CONFIG_IMA_DEFAULT_TEMPLATE="ima-ng"
+ # CONFIG_IMA_LOAD_X509 is not set
+ CONFIG_IMA_LSM_RULES=y
+ CONFIG_IMA_MEASURE_PCR_IDX=10
+-CONFIG_IMA_MOK_KEYRING=y
+ CONFIG_IMA_NG_TEMPLATE=y
+ # CONFIG_IMA_SIG_TEMPLATE is not set
+ # CONFIG_IMA_TEMPLATE is not set
+@@ -3587,7 +3541,6 @@ CONFIG_INTEGRITY_ASYMMETRIC_KEYS=y
+ CONFIG_INTEGRITY_AUDIT=y
+ CONFIG_INTEGRITY_SIGNATURE=y
+ CONFIG_INTEL_GTT=y
+-CONFIG_INTEL_HID_EVENT=m
+ CONFIG_INTEL_IDLE=y
+ CONFIG_INTEL_IDMA64=m
+ CONFIG_INTEL_IOATDMA=m
+@@ -3612,7 +3565,6 @@ CONFIG_INTEL_OAKTRAIL=m
+ CONFIG_INTEL_PCH_THERMAL=m
+ CONFIG_INTEL_PMC_IPC=m
+ CONFIG_INTEL_POWERCLAMP=m
+-CONFIG_INTEL_PUNIT_IPC=m
+ CONFIG_INTEL_RAPL=m
+ CONFIG_INTEL_RST=m
+ CONFIG_INTEL_SCU_IPC=y
+@@ -3622,7 +3574,6 @@ CONFIG_INTEL_SMARTCONNECT=m
+ CONFIG_INTEL_SOC_DTS_IOSF_CORE=m
+ CONFIG_INTEL_SOC_DTS_THERMAL=m
+ CONFIG_INTEL_SOC_PMIC=y
+-CONFIG_INTEL_TELEMETRY=m
+ CONFIG_INTEL_TH=m
+ # CONFIG_INTEL_TH_DEBUG is not set
+ CONFIG_INTEL_TH_GTH=m
+@@ -3631,7 +3582,6 @@ CONFIG_INTEL_TH_PCI=m
+ CONFIG_INTEL_TH_PTI=m
+ CONFIG_INTEL_TH_STH=m
+ CONFIG_INTEL_TXT=y
+-CONFIG_INTEL_VBTN=m
+ CONFIG_INTERVAL_TREE=y
+ CONFIG_INTERVAL_TREE_TEST=m
+ CONFIG_INV_MPU6050_IIO=m
+@@ -3981,7 +3931,6 @@ CONFIG_JOYSTICK_XPAD_LEDS=y
+ CONFIG_JOYSTICK_ZHENHUA=m
+ CONFIG_JSA1212=m
+ CONFIG_K3_DMA=m
+-CONFIG_KAISER=y
+ CONFIG_KALLSYMS=y
+ CONFIG_KALLSYMS_ALL=y
+ # CONFIG_KASAN is not set
+@@ -3994,7 +3943,6 @@ CONFIG_KEMPLD_WDT=m
+ # CONFIG_KERNEL_LZMA is not set
+ # CONFIG_KERNEL_LZO is not set
+ CONFIG_KERNEL_MODE_NEON=y
+-CONFIG_KERNEL_NOBP=y
+ CONFIG_KERNFS=y
+ CONFIG_KEXEC=y
+ CONFIG_KEXEC_BZIMAGE_VERIFY_SIG=y
+@@ -4368,11 +4316,8 @@ CONFIG_MDIO_BITBANG=m
+ CONFIG_MDIO_BUS_MUX=m
+ CONFIG_MDIO_BUS_MUX_GPIO=m
+ CONFIG_MDIO_BUS_MUX_MMIOREG=m
+-CONFIG_MDIO_CAVIUM=m
+ CONFIG_MDIO_GPIO=m
+ CONFIG_MDIO_OCTEON=m
+-CONFIG_MDIO_THUNDER=m
+-CONFIG_MDIO_XGENE=m
+ CONFIG_MD_AUTODETECT=y
+ CONFIG_MD_CLUSTER=m
+ CONFIG_MD_FAULTY=m
+@@ -4682,7 +4627,6 @@ CONFIG_MODULE_SIG_KEY="certs/signing_key.pem"
+ # CONFIG_MODULE_SIG_SHA256 is not set
+ # CONFIG_MODULE_SIG_SHA384 is not set
+ CONFIG_MODULE_SIG_SHA512=y
+-CONFIG_MODULE_SIG_UEFI=y
+ CONFIG_MODULE_SRCVERSION_ALL=y
+ CONFIG_MODULE_UNLOAD=y
+ CONFIG_MODVERSIONS=y
+@@ -4940,7 +4884,6 @@ CONFIG_NCPFS_STRONG=y
+ CONFIG_ND_BLK=m
+ CONFIG_ND_BTT=m
+ CONFIG_ND_CLAIM=y
+-CONFIG_ND_PFN=m
+ CONFIG_NE2000=m
+ CONFIG_NE2K_PCI=m
+ CONFIG_NEED_MULTIPLE_NODES=y
+@@ -5074,7 +5017,6 @@ CONFIG_NET_CLS_FLOW=m
+ CONFIG_NET_CLS_FLOWER=m
+ CONFIG_NET_CLS_FW=m
+ # CONFIG_NET_CLS_IND is not set
+-CONFIG_NET_CLS_MATCHALL=m
+ CONFIG_NET_CLS_ROUTE4=m
+ CONFIG_NET_CLS_RSVP=m
+ CONFIG_NET_CLS_RSVP6=m
+@@ -5155,7 +5097,6 @@ CONFIG_NET_TEAM_MODE_ROUNDROBIN=m
+ CONFIG_NET_TULIP=y
+ CONFIG_NET_UDP_TUNNEL=m
+ CONFIG_NET_VENDOR_8390=y
+-CONFIG_NET_VENDOR_AMAZON=y
+ CONFIG_NET_VENDOR_APPLE=y
+ CONFIG_NET_VENDOR_AURORA=y
+ CONFIG_NET_VENDOR_CIRRUS=y
+@@ -5406,7 +5347,6 @@ CONFIG_NR_IRQS=512
+ CONFIG_NS83820=m
+ CONFIG_NSC_FIR=m
+ CONFIG_NSC_GPIO=m
+-CONFIG_NTB_AMD=m
+ CONFIG_NTB_INTEL=m
+ CONFIG_NTB_NETDEV=m
+ CONFIG_NTB_PINGPONG=m
+@@ -5415,13 +5355,11 @@ CONFIG_NTB_TRANSPORT=m
+ # CONFIG_NTFS_DEBUG is not set
+ CONFIG_NTFS_FS=m
+ CONFIG_NUMA_BALANCING=y
+-CONFIG_NVDIMM_PFN=y
+ CONFIG_NVEC_PAZ00=m
+ CONFIG_NVEC_POWER=m
+ CONFIG_NVM=y
+ CONFIG_NVMEM_IMX_OCOTP=m
+ CONFIG_NVMEM_VF610_OCOTP=m
+-CONFIG_NVME_VENDOR_EXT_GOOGLE=y
+ # CONFIG_NVM_DEBUG is not set
+ CONFIG_NVM_GENNVM=m
+ CONFIG_NVM_RRPC=m
+@@ -5445,7 +5383,6 @@ CONFIG_OF_IRQ=y
+ CONFIG_OF_MDIO=y
+ CONFIG_OF_MTD=y
+ CONFIG_OF_NET=y
+-CONFIG_OF_NUMA=y
+ CONFIG_OF_OVERLAY=y
+ CONFIG_OF_PCI=y
+ CONFIG_OF_PCI_IRQ=y
+@@ -5502,9 +5439,6 @@ CONFIG_OMAP_SSI_PORT=m
+ CONFIG_OMAP_USB2=m
+ CONFIG_OMAP_WATCHDOG=m
+ CONFIG_OPAL_PRD=m
+-CONFIG_OPENNSL_BCM_KNET=m
+-CONFIG_OPENNSL_KERNEL_BDE=m
+-CONFIG_OPENNSL_USER_BDE=m
+ CONFIG_OPENVSWITCH=m
+ CONFIG_OPENVSWITCH_GENEVE=m
+ CONFIG_OPENVSWITCH_GRE=m
+@@ -5523,7 +5457,6 @@ CONFIG_ORION_WATCHDOG=m
+ CONFIG_OUTER_CACHE=y
+ CONFIG_OUTER_CACHE_SYNC=y
+ CONFIG_OVERLAY_FS=m
+-CONFIG_OVERLAY_FS_V1=y
+ # CONFIG_P1010_RDB is not set
+ # CONFIG_P1022_DS is not set
+ # CONFIG_P1022_RDK is not set
+@@ -5541,6 +5474,7 @@ CONFIG_PACK_STACK=y
+ CONFIG_PADATA=y
+ CONFIG_PAGE_COUNTER=y
+ # CONFIG_PAGE_OWNER is not set
++CONFIG_PAGE_TABLE_ISOLATION=y
+ CONFIG_PANASONIC_LAPTOP=m
+ CONFIG_PANEL=m
+ # CONFIG_PANEL_CHANGE_MESSAGE is not set
+@@ -5683,11 +5617,7 @@ CONFIG_PCI_GOANY=y
+ # CONFIG_PCI_GODIRECT is not set
+ # CONFIG_PCI_GOMMCONFIG is not set
+ CONFIG_PCI_HISI=y
+-CONFIG_PCI_HOST_COMMON=y
+ CONFIG_PCI_HOST_GENERIC=y
+-CONFIG_PCI_HOST_THUNDER_ECAM=y
+-CONFIG_PCI_HOST_THUNDER_PEM=y
+-CONFIG_PCI_HYPERV=m
+ CONFIG_PCI_IMX6=y
+ CONFIG_PCI_IOV=y
+ CONFIG_PCI_LABEL=y
+@@ -5946,7 +5876,6 @@ CONFIG_PPC_BOOK3S=y
+ CONFIG_PPC_CHRP=y
+ # CONFIG_PPC_DCR_MMIO is not set
+ # CONFIG_PPC_DCR_NATIVE is not set
+-# CONFIG_PPC_DEBUG_RFI is not set
+ CONFIG_PPC_E500MC=y
+ # CONFIG_PPC_EARLY_DEBUG is not set
+ # CONFIG_PPC_EMULATED_STATS is not set
+@@ -6069,7 +5998,6 @@ CONFIG_PWM_LPSS=m
+ CONFIG_PWM_LPSS_PCI=m
+ CONFIG_PWM_LPSS_PLATFORM=m
+ CONFIG_PWM_MTK_DISP=m
+-CONFIG_PWM_OMAP_DMTIMER=m
+ CONFIG_PWM_PCA9685=m
+ CONFIG_PWM_RCAR=m
+ CONFIG_PWM_RENESAS_TPU=m
+@@ -6316,6 +6244,7 @@ CONFIG_RENESAS_DMA=y
+ CONFIG_RENESAS_INTC_IRQPIN=y
+ CONFIG_RENESAS_IRQC=y
+ CONFIG_RENESAS_USB_DMAC=m
++CONFIG_RETPOLINE=y
+ CONFIG_RETU_WATCHDOG=m
+ CONFIG_RFD_FTL=m
+ CONFIG_RFKILL_GPIO=m
+@@ -6641,7 +6570,6 @@ CONFIG_SCSI_GENERIC_NCR53C400=y
+ CONFIG_SCSI_IBMVFC=m
+ CONFIG_SCSI_IBMVFC_TRACE=y
+ CONFIG_SCSI_IBMVSCSI=m
+-CONFIG_SCSI_IBMVSCSIS=m
+ CONFIG_SCSI_IMM=m
+ CONFIG_SCSI_IN2000=m
+ CONFIG_SCSI_IPR=m
+@@ -6724,9 +6652,6 @@ CONFIG_SECURITYFS=y
+ CONFIG_SECURITY_APPARMOR=y
+ CONFIG_SECURITY_APPARMOR_BOOTPARAM_VALUE=1
+ CONFIG_SECURITY_APPARMOR_HASH=y
+-CONFIG_SECURITY_APPARMOR_HASH_DEFAULT=y
+-# CONFIG_SECURITY_APPARMOR_STATS is not set
+-CONFIG_SECURITY_APPARMOR_UNCONFINED_INIT=y
+ # CONFIG_SECURITY_DMESG_RESTRICT is not set
+ CONFIG_SECURITY_NETWORK=y
+ CONFIG_SECURITY_NETWORK_XFRM=y
+@@ -7358,7 +7283,6 @@ CONFIG_SND_SOC_IMX_WM8962=m
+ CONFIG_SND_SOC_INTEL_BAYTRAIL=m
+ CONFIG_SND_SOC_INTEL_BROADWELL_MACH=m
+ CONFIG_SND_SOC_INTEL_BYTCR_RT5640_MACH=m
+-CONFIG_SND_SOC_INTEL_BYTCR_RT5660_MACH=m
+ CONFIG_SND_SOC_INTEL_BYT_MAX98090_MACH=m
+ CONFIG_SND_SOC_INTEL_BYT_RT5640_MACH=m
+ CONFIG_SND_SOC_INTEL_CHT_BSW_MAX98090_TI_MACH=m
+@@ -7401,7 +7325,6 @@ CONFIG_SND_SOC_RT286=m
+ CONFIG_SND_SOC_RT5631=m
+ CONFIG_SND_SOC_RT5640=m
+ CONFIG_SND_SOC_RT5645=m
+-CONFIG_SND_SOC_RT5660=m
+ CONFIG_SND_SOC_RT5670=m
+ CONFIG_SND_SOC_RT5677=m
+ CONFIG_SND_SOC_SAMSUNG=m
+@@ -7737,10 +7660,7 @@ CONFIG_SYSFS=y
+ # CONFIG_SYSFS_DEPRECATED is not set
+ CONFIG_SYSFS_SYSCALL=y
+ CONFIG_SYSTEMPORT=m
+-CONFIG_SYSTEM_BLACKLIST_KEYRING=y
+ CONFIG_SYSTEM_DATA_VERIFICATION=y
+-CONFIG_SYSTEM_EXTRA_CERTIFICATE=y
+-CONFIG_SYSTEM_EXTRA_CERTIFICATE_SIZE=4096
+ CONFIG_SYSTEM_TRUSTED_KEYRING=y
+ CONFIG_SYSTEM_TRUSTED_KEYS=""
+ CONFIG_SYSVIPC=y
+@@ -8577,15 +8497,6 @@ CONFIG_VCNL4000=m
+ CONFIG_VDSO=y
+ CONFIG_VDSO32=y
+ CONFIG_VECTORS_BASE=0xffff0000
+-CONFIG_VEN_RSI_91X=m
+-# CONFIG_VEN_RSI_BT_ALONE is not set
+-CONFIG_VEN_RSI_COEX=y
+-CONFIG_VEN_RSI_DEBUGFS=y
+-# CONFIG_VEN_RSI_P2P is not set
+-CONFIG_VEN_RSI_SDIO=m
+-CONFIG_VEN_RSI_USB=m
+-CONFIG_VEN_RSI_WOW=y
+-CONFIG_VERSION_SIGNATURE=""
+ CONFIG_VETH=m
+ CONFIG_VEXPRESS_CONFIG=y
+ CONFIG_VEXPRESS_SYSCFG=y
+@@ -8917,7 +8828,6 @@ CONFIG_WL1251_SPI=m
+ CONFIG_WL12XX=m
+ CONFIG_WL18XX=m
+ CONFIG_WLAN=y
+-CONFIG_WLAN_VENDOR_RSI=y
+ CONFIG_WLCORE=m
+ CONFIG_WLCORE_SDIO=m
+ CONFIG_WLCORE_SPI=m
+@@ -9080,7 +8990,6 @@ CONFIG_XFS_QUOTA=y
+ CONFIG_XFS_RT=y
+ # CONFIG_XFS_WARN is not set
+ CONFIG_XGENE_DMA=m
+-CONFIG_XGENE_SLIMPRO_MBOX=m
+ CONFIG_XILINX_EMACLITE=m
+ CONFIG_XILINX_LL_TEMAC=m
+ CONFIG_XILLYBUS_OF=m
+@@ -9110,7 +9019,6 @@ CONFIG_ZEROPLUS_FF=y
+ CONFIG_ZFCP=m
+ CONFIG_ZISOFS=y
+ CONFIG_ZLIB_INFLATE=y
+-CONFIG_ZONE_DEVICE=y
+ CONFIG_ZONE_DMA=y
+ CONFIG_ZONE_DMA32=y
+ CONFIG_ZPOOL=y
+diff --git a/debian.master/config/i386/config.common.i386 b/debian.master/config/i386/config.common.i386
+index 40538ef..2fa8c87 100644
+--- a/debian.master/config/i386/config.common.i386
++++ b/debian.master/config/i386/config.common.i386
+@@ -122,7 +122,6 @@ CONFIG_HAVE_SETUP_PER_CPU_AREA=y
+ CONFIG_HFSPLUS_FS=m
+ CONFIG_HFS_FS=m
+ CONFIG_HIBERNATION=y
+-CONFIG_HIO=m
+ CONFIG_HOTPLUG_PCI_PCIE=y
+ CONFIG_HOTPLUG_PCI_SHPC=m
+ CONFIG_HPET=y
+@@ -265,7 +264,6 @@ CONFIG_NVRAM=m
+ CONFIG_N_GSM=m
+ # CONFIG_OF is not set
+ CONFIG_OMFS_FS=m
+-# CONFIG_OPENNSL is not set
+ CONFIG_OSF_PARTITION=y
+ CONFIG_OUTPUT_FORMAT="elf32-i386"
+ CONFIG_PAGE_EXTENSION=y
+diff --git a/debian.master/config/i386/config.flavour.generic b/debian.master/config/i386/config.flavour.generic
+index 5c2e4e1..965113b 100644
+--- a/debian.master/config/i386/config.flavour.generic
++++ b/debian.master/config/i386/config.flavour.generic
+@@ -4,6 +4,5 @@
+ CONFIG_HZ=250
+ # CONFIG_HZ_1000 is not set
+ CONFIG_HZ_250=y
+-# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
+ # CONFIG_PREEMPT is not set
+ CONFIG_PREEMPT_VOLUNTARY=y
+diff --git a/debian.master/config/i386/config.flavour.lowlatency b/debian.master/config/i386/config.flavour.lowlatency
+index 6b121e3..0af82e0 100644
+--- a/debian.master/config/i386/config.flavour.lowlatency
++++ b/debian.master/config/i386/config.flavour.lowlatency
+@@ -4,6 +4,5 @@
+ CONFIG_HZ=1000
+ CONFIG_HZ_1000=y
+ # CONFIG_HZ_250 is not set
+-CONFIG_IRQ_FORCED_THREADING_DEFAULT=y
+ CONFIG_PREEMPT=y
+ # CONFIG_PREEMPT_VOLUNTARY is not set
+diff --git a/debian.master/config/powerpc/config.common.powerpc b/debian.master/config/powerpc/config.common.powerpc
+index 41c182d..d26e845 100644
+--- a/debian.master/config/powerpc/config.common.powerpc
++++ b/debian.master/config/powerpc/config.common.powerpc
+@@ -113,7 +113,6 @@ CONFIG_GPIO_TWL6040=m
+ # CONFIG_HAVE_GENERIC_DMA_COHERENT is not set
+ CONFIG_HFSPLUS_FS=m
+ CONFIG_HFS_FS=m
+-# CONFIG_HIO is not set
+ CONFIG_HOTPLUG_PCI_PCIE=y
+ CONFIG_HOTPLUG_PCI_SHPC=m
+ CONFIG_HPFS_FS=m
+@@ -143,7 +142,6 @@ CONFIG_IPX=m
+ # CONFIG_IP_DCCP_CCID3 is not set
+ # CONFIG_IRQ_ALL_CPUS is not set
+ CONFIG_IRQ_BYPASS_MANAGER=m
+-# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
+ # CONFIG_ISA is not set
+ CONFIG_JFS_FS=m
+ CONFIG_JME=m
+@@ -258,7 +256,6 @@ CONFIG_NVRAM=y
+ CONFIG_N_GSM=m
+ CONFIG_OF=y
+ CONFIG_OMFS_FS=m
+-# CONFIG_OPENNSL is not set
+ CONFIG_OSF_PARTITION=y
+ CONFIG_PANIC_TIMEOUT=0
+ CONFIG_PARPORT=m
+diff --git a/debian.master/config/ppc64el/config.common.ppc64el b/debian.master/config/ppc64el/config.common.ppc64el
+index d4a69ea..2347320 100644
+--- a/debian.master/config/ppc64el/config.common.ppc64el
++++ b/debian.master/config/ppc64el/config.common.ppc64el
+@@ -132,7 +132,6 @@ CONFIG_HAVE_SETUP_PER_CPU_AREA=y
+ CONFIG_HFSPLUS_FS=m
+ CONFIG_HFS_FS=m
+ # CONFIG_HIBERNATION is not set
+-# CONFIG_HIO is not set
+ # CONFIG_HOTPLUG_PCI_PCIE is not set
+ # CONFIG_HOTPLUG_PCI_SHPC is not set
+ CONFIG_HPFS_FS=m
+@@ -164,7 +163,6 @@ CONFIG_IPX=m
+ # CONFIG_IP_DCCP_CCID3 is not set
+ CONFIG_IRQ_ALL_CPUS=y
+ CONFIG_IRQ_BYPASS_MANAGER=y
+-# CONFIG_IRQ_FORCED_THREADING_DEFAULT is not set
+ CONFIG_JFS_FS=m
+ CONFIG_JME=m
+ CONFIG_JUMP_LABEL=y
+@@ -284,7 +282,6 @@ CONFIG_NVMEM=m
+ CONFIG_N_GSM=m
+ CONFIG_OF=y
+ CONFIG_OMFS_FS=m
+-# CONFIG_OPENNSL is not set
+ CONFIG_OSF_PARTITION=y
+ # CONFIG_PAGE_EXTENSION is not set
+ CONFIG_PAGE_OFFSET=0xc000000000000000
+-- 
+2.7.4
+
diff --git a/drivers/Kconfig b/drivers/Kconfig
index d2ac339..dee1c09 100644
--- a/drivers/Kconfig
+++ b/drivers/Kconfig
@@ -198,4 +198,6 @@ source "drivers/hwtracing/intel_th/Kconfig"
 
 source "drivers/fpga/Kconfig"
 
+source "drivers/ts6k/Kconfig"
+
 endmenu
diff --git a/drivers/Makefile b/drivers/Makefile
index 098997f..df5f20e 100644
--- a/drivers/Makefile
+++ b/drivers/Makefile
@@ -173,3 +173,4 @@ obj-$(CONFIG_STM)		+= hwtracing/stm/
 obj-$(CONFIG_ANDROID)		+= android/
 obj-$(CONFIG_NVMEM)		+= nvmem/
 obj-$(CONFIG_FPGA)		+= fpga/
+obj-$(CONFIG_TS6000)		+= ts6k/
\ No newline at end of file
diff --git a/drivers/ata/libata-eh.c b/drivers/ata/libata-eh.c
index 75cced2..18427ad 100644
--- a/drivers/ata/libata-eh.c
+++ b/drivers/ata/libata-eh.c
@@ -592,6 +592,9 @@ void ata_scsi_error(struct Scsi_Host *host)
 	struct ata_port *ap = ata_shost_to_port(host);
 	unsigned long flags;
 	LIST_HEAD(eh_work_q);
+#ifdef CONFIG_BUFFALO_PLATFORM
+	extern int buffalo_booting;
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 
 	DPRINTK("ENTER\n");
 
@@ -605,6 +608,12 @@ void ata_scsi_error(struct Scsi_Host *host)
 	   recover nr_timedout == 0 why exactly are we doing error recovery ? */
 	ata_scsi_port_error_handler(host, ap);
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (!buffalo_booting) {
+		/* do nothing */
+	}
+	else
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 	/* finish or retry handled scmd's and clean up */
 	WARN_ON(!list_empty(&eh_work_q));
 
diff --git a/drivers/gpio/gpio-it87.c b/drivers/gpio/gpio-it87.c
index 21f6f7c..bc1e7a9 100644
--- a/drivers/gpio/gpio-it87.c
+++ b/drivers/gpio/gpio-it87.c
@@ -34,6 +34,7 @@
 
 /* Chip Id numbers */
 #define NO_DEV_ID	0xffff
+#define IT8613_ID	0x8613
 #define IT8728_ID	0x8728
 #define IT8732_ID	0x8732
 #define IT8761_ID	0x8761
@@ -307,6 +308,14 @@ static int __init it87_gpio_init(void)
 	it87_gpio->chip = it87_template_chip;
 
 	switch (chip_type) {
+	case IT8613_ID:
+		gpio_ba_reg = 0x62;
+		it87_gpio->io_size = 8;
+		it87_gpio->output_base = 0xc8;
+		it87_gpio->simple_base = 0xc0;
+		it87_gpio->simple_size = 8;
+		it87_gpio->chip.ngpio = 48;
+		break;
 	case IT8728_ID:
 	case IT8732_ID:
 		gpio_ba_reg = 0x62;
diff --git a/drivers/hwmon/compat.h b/drivers/hwmon/compat.h
new file mode 100644
index 00000000..865dcc5
--- /dev/null
+++ b/drivers/hwmon/compat.h
@@ -0,0 +1,68 @@
+/*---------------------------------------------------------------------------
+ * 
+ * compat.h 
+ *     Copyright (c) 2012 Guenter Roeck <linux@roeck-us.net>
+ *
+ *---------------------------------------------------------------------------
+ */
+
+#ifndef COMPAT_H
+#define COMPAT_H
+
+#include <linux/version.h>
+
+#ifndef clamp_val
+#define clamp_val SENSORS_LIMIT
+#endif
+
+#ifndef request_muxed_region
+#if LINUX_VERSION_CODE <= KERNEL_VERSION(2, 6, 28)
+#define request_muxed_region(start,n,name)	__request_region(&ioport_resource, (start), (n), (name))
+#else
+#define IORESOURCE_MUXED	0x00400000
+#define request_muxed_region(start,n,name)	__request_region(&ioport_resource, (start), (n), (name), IORESOURCE_MUXED)
+#endif
+#endif
+
+/* Red Hat EL5 includes backports of these functions, so we can't redefine
+ * our own. */
+#if LINUX_VERSION_CODE <= KERNEL_VERSION(2, 6, 24)
+#if !(defined RHEL_MAJOR && RHEL_MAJOR == 5 && RHEL_MINOR >= 5)
+static inline int strict_strtoul(const char *cp, unsigned int base,
+                                 unsigned long *res)
+{
+	*res = simple_strtoul(cp, NULL, base);
+	return 0;
+}
+
+static inline int strict_strtol(const char *cp, unsigned int base, long *res)
+{
+	*res = simple_strtol(cp, NULL, base);
+	return 0;
+}
+#endif
+#endif
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 39)
+#define kstrtoul strict_strtoul 
+#define kstrtol strict_strtol
+#endif
+
+/*
+ * Some kernel configurations may have CONFIG_HWMON_VID disabled.
+ * We still have the functios declared as external, so we can not use
+ * static inline.
+ */
+#if !defined(CONFIG_HWMON_VID) && !defined(CONFIG_HWMON_VID_MODULE)
+int vid_from_reg(int val, u8 vrm)
+{
+	return 0;
+}
+
+u8 vid_which_vrm(void)
+{
+	return 0;
+}
+#endif
+
+#endif /* COMPAT_H */
diff --git a/drivers/hwmon/it87.c b/drivers/hwmon/it87.c
index 1896e26..44b7b65 100644
--- a/drivers/hwmon/it87.c
+++ b/drivers/hwmon/it87.c
@@ -11,8 +11,17 @@
  *  similar parts.  The other devices are supported by different drivers.
  *
  *  Supports: IT8603E  Super I/O chip w/LPC interface
+ *            IT8606E  Super I/O chip w/LPC interface
+ *            IT8607E  Super I/O chip w/LPC interface
+ *            IT8613E  Super I/O chip w/LPC interface
  *            IT8620E  Super I/O chip w/LPC interface
+ *            IT8622E  Super I/O chip w/LPC interface
  *            IT8623E  Super I/O chip w/LPC interface
+ *            IT8625E  Super I/O chip w/LPC interface
+ *            IT8628E  Super I/O chip w/LPC interface
+ *            IT8655E  Super I/O chip w/LPC interface
+ *            IT8665E  Super I/O chip w/LPC interface
+ *            IT8686E  Super I/O chip w/LPC interface
  *            IT8705F  Super I/O chip w/LPC interface
  *            IT8712F  Super I/O chip w/LPC interface
  *            IT8716F  Super I/O chip w/LPC interface
@@ -22,6 +31,8 @@
  *            IT8726F  Super I/O chip w/LPC interface
  *            IT8728F  Super I/O chip w/LPC interface
  *            IT8732F  Super I/O chip w/LPC interface
+ *            IT8736F  Super I/O chip w/LPC interface
+ *            IT8738E  Super I/O chip w/LPC interface
  *            IT8758E  Super I/O chip w/LPC interface
  *            IT8771E  Super I/O chip w/LPC interface
  *            IT8772E  Super I/O chip w/LPC interface
@@ -30,6 +41,7 @@
  *            IT8783E/F Super I/O chip w/LPC interface
  *            IT8786E  Super I/O chip w/LPC interface
  *            IT8790E  Super I/O chip w/LPC interface
+ *            IT8792E  Super I/O chip w/LPC interface
  *            Sis950   A clone of the IT8705F
  *
  *  Copyright (C) 2001 Chris Gauthron
@@ -44,14 +56,11 @@
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
 #define pr_fmt(fmt) KBUILD_MODNAME ": " fmt
 
+#include <linux/bitops.h>
 #include <linux/module.h>
 #include <linux/init.h>
 #include <linux/slab.h>
@@ -67,22 +76,38 @@
 #include <linux/dmi.h>
 #include <linux/acpi.h>
 #include <linux/io.h>
+#include "compat.h"
+
+#ifndef IT87_DRIVER_VERSION
+#define IT87_DRIVER_VERSION	"<not provided>"
+#endif
 
 #define DRVNAME "it87"
 
 enum chips { it87, it8712, it8716, it8718, it8720, it8721, it8728, it8732,
-	     it8771, it8772, it8781, it8782, it8783, it8786, it8790, it8603,
-	     it8620 };
+	     it8736, it8738,
+	     it8771, it8772, it8781, it8782, it8783, it8786, it8790,
+	     it8792, it8603, it8606, it8607, it8613, it8620, it8622, it8625,
+	     it8628, it8655, it8665, it8686 };
 
 static unsigned short force_id;
-module_param(force_id, ushort, 0);
+module_param(force_id, ushort, 0000);
 MODULE_PARM_DESC(force_id, "Override the detected device ID");
 
-static struct platform_device *pdev;
+static bool ignore_resource_conflict;
+module_param(ignore_resource_conflict, bool, 0000);
+MODULE_PARM_DESC(ignore_resource_conflict, "Ignore ACPI resource conflict");
+
+static bool mmio;
+module_param(mmio, bool, 0000);
+MODULE_PARM_DESC(mmio, "Use MMIO if available");
+
+static struct platform_device *it87_pdev[2];
+
+#define	REG_2E	0x2e	/* The register to read/write */
+#define	REG_4E	0x4e	/* Secondary register to read/write */
 
-#define	REG	0x2e	/* The register to read/write */
 #define	DEV	0x07	/* Register: Logical device select */
-#define	VAL	0x2f	/* The value to read/write */
 #define PME	0x04	/* The device with the fan registers in it */
 
 /* The device with the IT8718F/IT8720F VID value in it */
@@ -91,54 +116,60 @@ static struct platform_device *pdev;
 #define	DEVID	0x20	/* Register: Device ID */
 #define	DEVREV	0x22	/* Register: Device Revision */
 
-static inline int superio_inb(int reg)
+static inline void __superio_enter(int ioreg)
+{
+	outb(0x87, ioreg);
+	outb(0x01, ioreg);
+	outb(0x55, ioreg);
+	outb(ioreg == REG_4E ? 0xaa : 0x55, ioreg);
+}
+
+static inline int superio_inb(int ioreg, int reg)
 {
-	outb(reg, REG);
-	return inb(VAL);
+	int val;
+
+	outb(reg, ioreg);
+	val = inb(ioreg + 1);
+
+	return val;
 }
 
-static inline void superio_outb(int reg, int val)
+static inline void superio_outb(int ioreg, int reg, int val)
 {
-	outb(reg, REG);
-	outb(val, VAL);
+	outb(reg, ioreg);
+	outb(val, ioreg + 1);
 }
 
-static int superio_inw(int reg)
+static int superio_inw(int ioreg, int reg)
 {
-	int val;
-	outb(reg++, REG);
-	val = inb(VAL) << 8;
-	outb(reg, REG);
-	val |= inb(VAL);
-	return val;
+	return (superio_inb(ioreg, reg) << 8) | superio_inb(ioreg, reg + 1);
 }
 
-static inline void superio_select(int ldn)
+static inline void superio_select(int ioreg, int ldn)
 {
-	outb(DEV, REG);
-	outb(ldn, VAL);
+	outb(DEV, ioreg);
+	outb(ldn, ioreg + 1);
 }
 
-static inline int superio_enter(void)
+static inline int superio_enter(int ioreg)
 {
 	/*
-	 * Try to reserve REG and REG + 1 for exclusive access.
+	 * Try to reserve ioreg and ioreg + 1 for exclusive access.
 	 */
-	if (!request_muxed_region(REG, 2, DRVNAME))
+	if (!request_muxed_region(ioreg, 2, DRVNAME))
 		return -EBUSY;
 
-	outb(0x87, REG);
-	outb(0x01, REG);
-	outb(0x55, REG);
-	outb(0x55, REG);
+	__superio_enter(ioreg);
 	return 0;
 }
 
-static inline void superio_exit(void)
+static inline void superio_exit(int ioreg, bool doexit)
 {
-	outb(0x02, REG);
-	outb(0x02, VAL);
-	release_region(REG, 2);
+	if (doexit) {
+		outb(0x02, ioreg);
+		outb(0x02, ioreg + 1);
+	}
+	release_region(ioreg, 2);
 }
 
 /* Logical device 4 registers */
@@ -151,6 +182,9 @@ static inline void superio_exit(void)
 #define IT8726F_DEVID 0x8726
 #define IT8728F_DEVID 0x8728
 #define IT8732F_DEVID 0x8732
+#define IT8736F_DEVID 0x8736
+#define IT8738E_DEVID 0x8738
+#define IT8792E_DEVID 0x8733
 #define IT8771E_DEVID 0x8771
 #define IT8772E_DEVID 0x8772
 #define IT8781F_DEVID 0x8781
@@ -159,18 +193,36 @@ static inline void superio_exit(void)
 #define IT8786E_DEVID 0x8786
 #define IT8790E_DEVID 0x8790
 #define IT8603E_DEVID 0x8603
+#define IT8606E_DEVID 0x8606
+#define IT8607E_DEVID 0x8607
+#define IT8613E_DEVID 0x8613
 #define IT8620E_DEVID 0x8620
+#define IT8622E_DEVID 0x8622
 #define IT8623E_DEVID 0x8623
-#define IT87_ACT_REG  0x30
-#define IT87_BASE_REG 0x60
-
-/* Logical device 7 registers (IT8712F and later) */
+#define IT8625E_DEVID 0x8625
+#define IT8628E_DEVID 0x8628
+#define IT8655E_DEVID 0x8655
+#define IT8665E_DEVID 0x8665
+#define IT8686E_DEVID 0x8686
+
+/* Logical device 4 (Environmental Monitor) registers */
+#define IT87_ACT_REG		0x30
+#define IT87_BASE_REG		0x60
+#define IT87_SPECIAL_CFG_REG	0xf3	/* special configuration register */
+
+/* Global configuration registers (IT8712F and later) */
+#define IT87_EC_HWM_MIO_REG	0x24	/* MMIO configuration register */
 #define IT87_SIO_GPIO1_REG	0x25
 #define IT87_SIO_GPIO2_REG	0x26
 #define IT87_SIO_GPIO3_REG	0x27
+#define IT87_SIO_GPIO4_REG	0x28
 #define IT87_SIO_GPIO5_REG	0x29
+#define IT87_SIO_GPIO9_REG	0xd3
 #define IT87_SIO_PINX1_REG	0x2a	/* Pin selection */
 #define IT87_SIO_PINX2_REG	0x2c	/* Pin selection */
+#define IT87_SIO_PINX4_REG	0x2d	/* Pin selection */
+
+/* Logical device 7 (GPIO) registers (IT8712F and later) */
 #define IT87_SIO_SPI_REG	0xef	/* SPI function pin select */
 #define IT87_SIO_VID_REG	0xfc	/* VID value */
 #define IT87_SIO_BEEP_PIN_REG	0xf6	/* Beep pin mapping */
@@ -204,11 +256,17 @@ static bool fix_pwm_polarity;
 #define IT87_REG_ALARM2        0x02
 #define IT87_REG_ALARM3        0x03
 
+#define IT87_REG_BANK		0x06
+
 /*
  * The IT8718F and IT8720F have the VID value in a different register, in
  * Super-I/O configuration space.
  */
 #define IT87_REG_VID           0x0a
+
+/* Interface Selection register on other chips */
+#define IT87_REG_IFSEL         0x0a
+
 /*
  * The IT8705F and IT8712F earlier than revision 0x08 use register 0x0b
  * for fan divisors. Later IT8712F revisions must use 16-bit tachometer
@@ -217,26 +275,53 @@ static bool fix_pwm_polarity;
 #define IT87_REG_FAN_DIV       0x0b
 #define IT87_REG_FAN_16BIT     0x0c
 
-/* Monitors: 9 voltage (0 to 7, battery), 3 temp (1 to 3), 3 fan (1 to 3) */
+/*
+ * Monitors:
+ * - up to 13 voltage (0 to 7, battery, avcc, 10 to 12)
+ * - up to 6 temp (1 to 6)
+ * - up to 6 fan (1 to 6)
+ */
+
+static const u8 IT87_REG_FAN[] =	{ 0x0d, 0x0e, 0x0f, 0x80, 0x82, 0x4c };
+static const u8 IT87_REG_FAN_MIN[] =	{ 0x10, 0x11, 0x12, 0x84, 0x86, 0x4e };
+static const u8 IT87_REG_FANX[] =	{ 0x18, 0x19, 0x1a, 0x81, 0x83, 0x4d };
+static const u8 IT87_REG_FANX_MIN[] =	{ 0x1b, 0x1c, 0x1d, 0x85, 0x87, 0x4f };
+
+static const u8 IT87_REG_FAN_8665[] =	{ 0x0d, 0x0e, 0x0f, 0x80, 0x82, 0x93 };
+static const u8 IT87_REG_FAN_MIN_8665[] = {
+					0x10, 0x11, 0x12, 0x84, 0x86, 0xb2 };
+static const u8 IT87_REG_FANX_8665[] =	{ 0x18, 0x19, 0x1a, 0x81, 0x83, 0x94 };
+static const u8 IT87_REG_FANX_MIN_8665[] = {
+					0x1b, 0x1c, 0x1d, 0x85, 0x87, 0xb3 };
 
-static const u8 IT87_REG_FAN[]         = { 0x0d, 0x0e, 0x0f, 0x80, 0x82, 0x4c };
-static const u8 IT87_REG_FAN_MIN[]     = { 0x10, 0x11, 0x12, 0x84, 0x86, 0x4e };
-static const u8 IT87_REG_FANX[]        = { 0x18, 0x19, 0x1a, 0x81, 0x83, 0x4d };
-static const u8 IT87_REG_FANX_MIN[]    = { 0x1b, 0x1c, 0x1d, 0x85, 0x87, 0x4f };
-static const u8 IT87_REG_TEMP_OFFSET[] = { 0x56, 0x57, 0x59 };
+static const u8 IT87_REG_TEMP_OFFSET[] = { 0x56, 0x57, 0x59, 0x5a, 0x90, 0x91 };
+
+static const u8 IT87_REG_TEMP_OFFSET_8686[] = {
+					0x56, 0x57, 0x59, 0x90, 0x91, 0x92 };
 
 #define IT87_REG_FAN_MAIN_CTRL 0x13
 #define IT87_REG_FAN_CTL       0x14
-#define IT87_REG_PWM(nr)       (0x15 + (nr))
-#define IT87_REG_PWM_DUTY(nr)  (0x63 + (nr) * 8)
 
-#define IT87_REG_VIN(nr)       (0x20 + (nr))
+static const u8 IT87_REG_PWM[] =	{ 0x15, 0x16, 0x17, 0x7f, 0xa7, 0xaf };
+static const u8 IT87_REG_PWM_8665[] =	{ 0x15, 0x16, 0x17, 0x1e, 0x1f, 0x92 };
+
+static const u8 IT87_REG_PWM_DUTY[] =	{ 0x63, 0x6b, 0x73, 0x7b, 0xa3, 0xab };
+
+static const u8 IT87_REG_VIN[]	= { 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26,
+				    0x27, 0x28, 0x2f, 0x2c, 0x2d, 0x2e };
+
 #define IT87_REG_TEMP(nr)      (0x29 + (nr))
 
 #define IT87_REG_VIN_MAX(nr)   (0x30 + (nr) * 2)
 #define IT87_REG_VIN_MIN(nr)   (0x31 + (nr) * 2)
-#define IT87_REG_TEMP_HIGH(nr) (0x40 + (nr) * 2)
-#define IT87_REG_TEMP_LOW(nr)  (0x41 + (nr) * 2)
+
+static const u8 IT87_REG_TEMP_HIGH[] =	{ 0x40, 0x42, 0x44, 0x46, 0xb4, 0xb6 };
+static const u8 IT87_REG_TEMP_LOW[] =	{ 0x41, 0x43, 0x45, 0x47, 0xb5, 0xb7 };
+
+static const u8 IT87_REG_TEMP_HIGH_8686[] = {
+					0x40, 0x42, 0x44, 0xb4, 0xb6, 0xb8 };
+static const u8 IT87_REG_TEMP_LOW_8686[] = {
+					0x41, 0x43, 0x45, 0xb5, 0xb7, 0xb9 };
 
 #define IT87_REG_VIN_ENABLE    0x50
 #define IT87_REG_TEMP_ENABLE   0x51
@@ -245,161 +330,410 @@ static const u8 IT87_REG_TEMP_OFFSET[] = { 0x56, 0x57, 0x59 };
 
 #define IT87_REG_CHIPID        0x58
 
-#define IT87_REG_AUTO_TEMP(nr, i) (0x60 + (nr) * 8 + (i))
-#define IT87_REG_AUTO_PWM(nr, i)  (0x65 + (nr) * 8 + (i))
+static const u8 IT87_REG_AUTO_BASE[] = { 0x60, 0x68, 0x70, 0x78, 0xa0, 0xa8 };
+
+#define IT87_REG_AUTO_TEMP(nr, i) (IT87_REG_AUTO_BASE[nr] + (i))
+#define IT87_REG_AUTO_PWM(nr, i)  (IT87_REG_AUTO_BASE[nr] + 5 + (i))
+
+#define IT87_REG_TEMP456_ENABLE	0x77
+
+static const u16 IT87_REG_TEMP_SRC1[] =	{ 0x21d, 0x21e, 0x21f };
+#define IT87_REG_TEMP_SRC2	0x23d
+
+#define NUM_VIN			ARRAY_SIZE(IT87_REG_VIN)
+#define NUM_VIN_LIMIT		8
+#define NUM_TEMP		6
+#define NUM_FAN			ARRAY_SIZE(IT87_REG_FAN)
+#define NUM_FAN_DIV		3
+#define NUM_PWM			ARRAY_SIZE(IT87_REG_PWM)
+#define NUM_AUTO_PWM		ARRAY_SIZE(IT87_REG_PWM)
 
 struct it87_devices {
 	const char *name;
-	const char * const suffix;
-	u16 features;
+	const char * const model;
+	u32 features;
+	u8 num_temp_limit;
+	u8 num_temp_offset;
+	u8 num_temp_map;	/* Number of temperature sources for pwm */
 	u8 peci_mask;
 	u8 old_peci_mask;
+	u8 smbus_bitmap;	/* SMBus enable bits in extra config register */
+	u8 ec_special_config;
 };
 
-#define FEAT_12MV_ADC		(1 << 0)
-#define FEAT_NEWER_AUTOPWM	(1 << 1)
-#define FEAT_OLD_AUTOPWM	(1 << 2)
-#define FEAT_16BIT_FANS		(1 << 3)
-#define FEAT_TEMP_OFFSET	(1 << 4)
-#define FEAT_TEMP_PECI		(1 << 5)
-#define FEAT_TEMP_OLD_PECI	(1 << 6)
-#define FEAT_FAN16_CONFIG	(1 << 7)	/* Need to enable 16-bit fans */
-#define FEAT_FIVE_FANS		(1 << 8)	/* Supports five fans */
-#define FEAT_VID		(1 << 9)	/* Set if chip supports VID */
-#define FEAT_IN7_INTERNAL	(1 << 10)	/* Set if in7 is internal */
-#define FEAT_SIX_FANS		(1 << 11)	/* Supports six fans */
-#define FEAT_10_9MV_ADC		(1 << 12)
+#define FEAT_12MV_ADC		BIT(0)
+#define FEAT_NEWER_AUTOPWM	BIT(1)
+#define FEAT_OLD_AUTOPWM	BIT(2)
+#define FEAT_16BIT_FANS		BIT(3)
+#define FEAT_TEMP_PECI		BIT(5)
+#define FEAT_TEMP_OLD_PECI	BIT(6)
+#define FEAT_FAN16_CONFIG	BIT(7)	/* Need to enable 16-bit fans */
+#define FEAT_FIVE_FANS		BIT(8)	/* Supports five fans */
+#define FEAT_VID		BIT(9)	/* Set if chip supports VID */
+#define FEAT_IN7_INTERNAL	BIT(10)	/* Set if in7 is internal */
+#define FEAT_SIX_FANS		BIT(11)	/* Supports six fans */
+#define FEAT_10_9MV_ADC		BIT(12)
+#define FEAT_AVCC3		BIT(13)	/* Chip supports in9/AVCC3 */
+#define FEAT_FIVE_PWM		BIT(14)	/* Chip supports 5 pwm chn */
+#define FEAT_SIX_PWM		BIT(15)	/* Chip supports 6 pwm chn */
+#define FEAT_PWM_FREQ2		BIT(16)	/* Separate pwm freq 2 */
+#define FEAT_SIX_TEMP		BIT(17)	/* Up to 6 temp sensors */
+#define FEAT_VIN3_5V		BIT(18)	/* VIN3 connected to +5V */
+#define FEAT_FOUR_FANS		BIT(19)	/* Supports four fans */
+#define FEAT_FOUR_PWM		BIT(20)	/* Supports four fan controls */
+#define FEAT_BANK_SEL		BIT(21)	/* Chip has multi-bank support */
+#define FEAT_SCALING		BIT(22)	/* Internal voltage scaling */
+#define FEAT_FANCTL_ONOFF	BIT(23)	/* chip has FAN_CTL ON/OFF */
+#define FEAT_11MV_ADC		BIT(24)
+#define FEAT_NEW_TEMPMAP	BIT(25)	/* new temp input selection */
+#define FEAT_MMIO		BIT(26)	/* Chip supports MMIO */
+#define FEAT_FOUR_TEMP		BIT(27)
 
 static const struct it87_devices it87_devices[] = {
 	[it87] = {
 		.name = "it87",
-		.suffix = "F",
-		.features = FEAT_OLD_AUTOPWM,	/* may need to overwrite */
+		.model = "IT87F",
+		.features = FEAT_OLD_AUTOPWM | FEAT_FANCTL_ONOFF,
+						/* may need to overwrite */
+		.num_temp_limit = 3,
+		.num_temp_offset = 0,
+		.num_temp_map = 3,
 	},
 	[it8712] = {
 		.name = "it8712",
-		.suffix = "F",
-		.features = FEAT_OLD_AUTOPWM | FEAT_VID,
+		.model = "IT8712F",
+		.features = FEAT_OLD_AUTOPWM | FEAT_VID | FEAT_FANCTL_ONOFF,
 						/* may need to overwrite */
+		.num_temp_limit = 3,
+		.num_temp_offset = 0,
+		.num_temp_map = 3,
 	},
 	[it8716] = {
 		.name = "it8716",
-		.suffix = "F",
-		.features = FEAT_16BIT_FANS | FEAT_TEMP_OFFSET | FEAT_VID
-		  | FEAT_FAN16_CONFIG | FEAT_FIVE_FANS,
+		.model = "IT8716F",
+		.features = FEAT_16BIT_FANS | FEAT_VID
+		  | FEAT_FAN16_CONFIG | FEAT_FIVE_FANS | FEAT_PWM_FREQ2
+		  | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 	},
 	[it8718] = {
 		.name = "it8718",
-		.suffix = "F",
-		.features = FEAT_16BIT_FANS | FEAT_TEMP_OFFSET | FEAT_VID
-		  | FEAT_TEMP_OLD_PECI | FEAT_FAN16_CONFIG | FEAT_FIVE_FANS,
+		.model = "IT8718F",
+		.features = FEAT_16BIT_FANS | FEAT_VID
+		  | FEAT_TEMP_OLD_PECI | FEAT_FAN16_CONFIG | FEAT_FIVE_FANS
+		  | FEAT_PWM_FREQ2 | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.old_peci_mask = 0x4,
 	},
 	[it8720] = {
 		.name = "it8720",
-		.suffix = "F",
-		.features = FEAT_16BIT_FANS | FEAT_TEMP_OFFSET | FEAT_VID
-		  | FEAT_TEMP_OLD_PECI | FEAT_FAN16_CONFIG | FEAT_FIVE_FANS,
+		.model = "IT8720F",
+		.features = FEAT_16BIT_FANS | FEAT_VID
+		  | FEAT_TEMP_OLD_PECI | FEAT_FAN16_CONFIG | FEAT_FIVE_FANS
+		  | FEAT_PWM_FREQ2 | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.old_peci_mask = 0x4,
 	},
 	[it8721] = {
 		.name = "it8721",
-		.suffix = "F",
+		.model = "IT8721F",
 		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
-		  | FEAT_TEMP_OFFSET | FEAT_TEMP_OLD_PECI | FEAT_TEMP_PECI
-		  | FEAT_FAN16_CONFIG | FEAT_FIVE_FANS | FEAT_IN7_INTERNAL,
+		  | FEAT_TEMP_OLD_PECI | FEAT_TEMP_PECI
+		  | FEAT_FAN16_CONFIG | FEAT_FIVE_FANS | FEAT_IN7_INTERNAL
+		  | FEAT_PWM_FREQ2 | FEAT_SCALING | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.peci_mask = 0x05,
 		.old_peci_mask = 0x02,	/* Actually reports PCH */
 	},
 	[it8728] = {
 		.name = "it8728",
-		.suffix = "F",
+		.model = "IT8728F",
 		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
-		  | FEAT_TEMP_OFFSET | FEAT_TEMP_PECI | FEAT_FIVE_FANS
-		  | FEAT_IN7_INTERNAL,
+		  | FEAT_TEMP_PECI | FEAT_FIVE_FANS
+		  | FEAT_IN7_INTERNAL | FEAT_PWM_FREQ2 | FEAT_SCALING
+		  | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 6,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.peci_mask = 0x07,
 	},
 	[it8732] = {
 		.name = "it8732",
-		.suffix = "F",
+		.model = "IT8732F",
 		.features = FEAT_NEWER_AUTOPWM | FEAT_16BIT_FANS
-		  | FEAT_TEMP_OFFSET | FEAT_TEMP_OLD_PECI | FEAT_TEMP_PECI
-		  | FEAT_10_9MV_ADC | FEAT_IN7_INTERNAL,
+		  | FEAT_TEMP_OLD_PECI | FEAT_TEMP_PECI
+		  | FEAT_10_9MV_ADC | FEAT_IN7_INTERNAL | FEAT_FOUR_FANS
+		  | FEAT_FOUR_PWM | FEAT_FANCTL_ONOFF | FEAT_SCALING,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
+		.peci_mask = 0x07,
+		.old_peci_mask = 0x02,	/* Actually reports PCH */
+	},
+	[it8736] = {
+		.name = "it8736",
+		.model = "IT8736F",
+		.features = FEAT_16BIT_FANS
+		  | FEAT_TEMP_OLD_PECI | FEAT_TEMP_PECI
+		  | FEAT_10_9MV_ADC | FEAT_IN7_INTERNAL | FEAT_FOUR_FANS
+		  | FEAT_FANCTL_ONOFF | FEAT_SCALING,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.peci_mask = 0x07,
 		.old_peci_mask = 0x02,	/* Actually reports PCH */
 	},
+	[it8738] = {
+		.name = "it8738",
+		.model = "IT8738E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_16BIT_FANS
+		  | FEAT_TEMP_OLD_PECI | FEAT_TEMP_PECI
+		  | FEAT_10_9MV_ADC | FEAT_IN7_INTERNAL
+		  | FEAT_FANCTL_ONOFF | FEAT_SCALING
+		  | FEAT_AVCC3,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
+		.peci_mask = 0x07,
+		.old_peci_mask = 0x02,
+	},
 	[it8771] = {
 		.name = "it8771",
-		.suffix = "E",
+		.model = "IT8771E",
 		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
-		  | FEAT_TEMP_OFFSET | FEAT_TEMP_PECI | FEAT_IN7_INTERNAL,
+		  | FEAT_TEMP_PECI | FEAT_IN7_INTERNAL
+		  | FEAT_PWM_FREQ2 | FEAT_SCALING | FEAT_FANCTL_ONOFF,
 				/* PECI: guesswork */
 				/* 12mV ADC (OHM) */
 				/* 16 bit fans (OHM) */
 				/* three fans, always 16 bit (guesswork) */
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.peci_mask = 0x07,
 	},
 	[it8772] = {
 		.name = "it8772",
-		.suffix = "E",
+		.model = "IT8772E",
 		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
-		  | FEAT_TEMP_OFFSET | FEAT_TEMP_PECI | FEAT_IN7_INTERNAL,
+		  | FEAT_TEMP_PECI | FEAT_IN7_INTERNAL
+		  | FEAT_PWM_FREQ2 | FEAT_SCALING | FEAT_FANCTL_ONOFF,
 				/* PECI (coreboot) */
 				/* 12mV ADC (HWSensors4, OHM) */
 				/* 16 bit fans (HWSensors4, OHM) */
 				/* three fans, always 16 bit (datasheet) */
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.peci_mask = 0x07,
 	},
 	[it8781] = {
 		.name = "it8781",
-		.suffix = "F",
-		.features = FEAT_16BIT_FANS | FEAT_TEMP_OFFSET
-		  | FEAT_TEMP_OLD_PECI | FEAT_FAN16_CONFIG,
+		.model = "IT8781F",
+		.features = FEAT_16BIT_FANS
+		  | FEAT_TEMP_OLD_PECI | FEAT_FAN16_CONFIG | FEAT_PWM_FREQ2
+		  | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.old_peci_mask = 0x4,
 	},
 	[it8782] = {
 		.name = "it8782",
-		.suffix = "F",
-		.features = FEAT_16BIT_FANS | FEAT_TEMP_OFFSET
-		  | FEAT_TEMP_OLD_PECI | FEAT_FAN16_CONFIG,
+		.model = "IT8782F",
+		.features = FEAT_16BIT_FANS
+		  | FEAT_TEMP_OLD_PECI | FEAT_FAN16_CONFIG | FEAT_PWM_FREQ2
+		  | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.old_peci_mask = 0x4,
 	},
 	[it8783] = {
 		.name = "it8783",
-		.suffix = "E/F",
-		.features = FEAT_16BIT_FANS | FEAT_TEMP_OFFSET
-		  | FEAT_TEMP_OLD_PECI | FEAT_FAN16_CONFIG,
+		.model = "IT8783E/F",
+		.features = FEAT_16BIT_FANS
+		  | FEAT_TEMP_OLD_PECI | FEAT_FAN16_CONFIG | FEAT_PWM_FREQ2
+		  | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.old_peci_mask = 0x4,
 	},
 	[it8786] = {
 		.name = "it8786",
-		.suffix = "E",
+		.model = "IT8786E",
 		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
-		  | FEAT_TEMP_OFFSET | FEAT_TEMP_PECI | FEAT_IN7_INTERNAL,
+		  | FEAT_TEMP_PECI | FEAT_IN7_INTERNAL
+		  | FEAT_PWM_FREQ2 | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.peci_mask = 0x07,
 	},
 	[it8790] = {
 		.name = "it8790",
-		.suffix = "E",
-		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
-		  | FEAT_TEMP_OFFSET | FEAT_TEMP_PECI | FEAT_IN7_INTERNAL,
+		.model = "IT8790E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_10_9MV_ADC | FEAT_SCALING
+		  | FEAT_16BIT_FANS | FEAT_TEMP_PECI
+		  | FEAT_IN7_INTERNAL | FEAT_PWM_FREQ2 | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
+		.peci_mask = 0x07,
+	},
+	[it8792] = {
+		.name = "it8792",
+		.model = "IT8792E/IT8795E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_10_9MV_ADC | FEAT_SCALING
+		  | FEAT_16BIT_FANS | FEAT_TEMP_PECI
+		  | FEAT_IN7_INTERNAL | FEAT_PWM_FREQ2 | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.peci_mask = 0x07,
 	},
 	[it8603] = {
 		.name = "it8603",
-		.suffix = "E",
+		.model = "IT8603E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
+		  | FEAT_TEMP_PECI | FEAT_IN7_INTERNAL
+		  | FEAT_AVCC3 | FEAT_PWM_FREQ2 | FEAT_SCALING,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 4,
+		.peci_mask = 0x07,
+	},
+	[it8606] = {
+		.name = "it8606",
+		.model = "IT8606E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
+		  | FEAT_TEMP_PECI | FEAT_IN7_INTERNAL
+		  | FEAT_AVCC3 | FEAT_PWM_FREQ2 | FEAT_SCALING,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
+		.peci_mask = 0x07,
+	},
+	[it8607] = {
+		.name = "it8607",
+		.model = "IT8607E",
 		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
-		  | FEAT_TEMP_OFFSET | FEAT_TEMP_PECI | FEAT_IN7_INTERNAL,
+		  | FEAT_TEMP_PECI | FEAT_IN7_INTERNAL | FEAT_NEW_TEMPMAP
+		  | FEAT_AVCC3 | FEAT_PWM_FREQ2 | FEAT_SCALING
+		  | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 6,
+		.peci_mask = 0x07,
+	},
+	[it8613] = {
+		.name = "it8613",
+		.model = "IT8613E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_11MV_ADC | FEAT_16BIT_FANS
+		  | FEAT_TEMP_PECI | FEAT_FIVE_FANS
+		  | FEAT_FIVE_PWM | FEAT_IN7_INTERNAL | FEAT_PWM_FREQ2
+		  | FEAT_AVCC3 | FEAT_SCALING | FEAT_NEW_TEMPMAP,
+		.num_temp_limit = 6,
+		.num_temp_offset = 6,
+		.num_temp_map = 6,
 		.peci_mask = 0x07,
 	},
 	[it8620] = {
 		.name = "it8620",
-		.suffix = "E",
+		.model = "IT8620E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
+		  | FEAT_TEMP_PECI | FEAT_SIX_FANS
+		  | FEAT_IN7_INTERNAL | FEAT_SIX_PWM | FEAT_PWM_FREQ2
+		  | FEAT_SIX_TEMP | FEAT_VIN3_5V | FEAT_SCALING
+		  | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
+		.peci_mask = 0x07,
+	},
+	[it8622] = {
+		.name = "it8622",
+		.model = "IT8622E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
+		  | FEAT_TEMP_PECI | FEAT_FIVE_FANS | FEAT_FOUR_TEMP
+		  | FEAT_FIVE_PWM | FEAT_IN7_INTERNAL | FEAT_PWM_FREQ2
+		  | FEAT_AVCC3 | FEAT_VIN3_5V | FEAT_SCALING,
+		.num_temp_limit = 3,
+		.num_temp_offset = 3,
+		.num_temp_map = 4,
+		.peci_mask = 0x0f,
+		.smbus_bitmap = BIT(1) | BIT(2),
+	},
+	[it8625] = {
+		.name = "it8625",
+		.model = "IT8625E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_16BIT_FANS
+		  | FEAT_AVCC3 | FEAT_NEW_TEMPMAP
+		  | FEAT_11MV_ADC | FEAT_IN7_INTERNAL | FEAT_SIX_FANS
+		  | FEAT_SIX_PWM | FEAT_BANK_SEL | FEAT_SCALING,
+		.num_temp_limit = 6,
+		.num_temp_offset = 6,
+		.num_temp_map = 6,
+		.smbus_bitmap = BIT(1) | BIT(2),
+	},
+	[it8628] = {
+		.name = "it8628",
+		.model = "IT8628E",
 		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
-		  | FEAT_TEMP_OFFSET | FEAT_TEMP_PECI | FEAT_SIX_FANS
-		  | FEAT_IN7_INTERNAL,
+		  | FEAT_TEMP_PECI | FEAT_SIX_FANS
+		  | FEAT_IN7_INTERNAL | FEAT_SIX_PWM | FEAT_PWM_FREQ2
+		  | FEAT_SIX_TEMP | FEAT_SCALING | FEAT_AVCC3
+		  | FEAT_FANCTL_ONOFF,
+		.num_temp_limit = 6,
+		.num_temp_offset = 3,
+		.num_temp_map = 3,
 		.peci_mask = 0x07,
 	},
+	[it8655] = {
+		.name = "it8655",
+		.model = "IT8655E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_16BIT_FANS
+		  | FEAT_AVCC3 | FEAT_NEW_TEMPMAP | FEAT_SCALING
+		  | FEAT_10_9MV_ADC | FEAT_IN7_INTERNAL | FEAT_BANK_SEL
+		  | FEAT_MMIO,
+		.num_temp_limit = 6,
+		.num_temp_offset = 6,
+		.num_temp_map = 6,
+		.smbus_bitmap = BIT(2),
+	},
+	[it8665] = {
+		.name = "it8665",
+		.model = "IT8665E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_16BIT_FANS
+		  | FEAT_AVCC3 | FEAT_NEW_TEMPMAP | FEAT_SCALING
+		  | FEAT_10_9MV_ADC | FEAT_IN7_INTERNAL | FEAT_SIX_FANS
+		  | FEAT_SIX_PWM | FEAT_BANK_SEL | FEAT_MMIO,
+		.num_temp_limit = 6,
+		.num_temp_offset = 6,
+		.num_temp_map = 6,
+		.smbus_bitmap = BIT(2),
+	},
+	[it8686] = {
+		.name = "it8686",
+		.model = "IT8686E",
+		.features = FEAT_NEWER_AUTOPWM | FEAT_12MV_ADC | FEAT_16BIT_FANS
+		  | FEAT_SIX_FANS | FEAT_NEW_TEMPMAP
+		  | FEAT_IN7_INTERNAL | FEAT_SIX_PWM | FEAT_PWM_FREQ2
+		  | FEAT_SIX_TEMP | FEAT_BANK_SEL | FEAT_SCALING | FEAT_AVCC3,
+		.num_temp_limit = 6,
+		.num_temp_offset = 6,
+		.num_temp_map = 7,
+		.smbus_bitmap = BIT(1) | BIT(2),
+	},
 };
 
 #define has_16bit_fans(data)	((data)->features & FEAT_16BIT_FANS)
@@ -407,21 +741,42 @@ static const struct it87_devices it87_devices[] = {
 #define has_10_9mv_adc(data)	((data)->features & FEAT_10_9MV_ADC)
 #define has_newer_autopwm(data)	((data)->features & FEAT_NEWER_AUTOPWM)
 #define has_old_autopwm(data)	((data)->features & FEAT_OLD_AUTOPWM)
-#define has_temp_offset(data)	((data)->features & FEAT_TEMP_OFFSET)
 #define has_temp_peci(data, nr)	(((data)->features & FEAT_TEMP_PECI) && \
-				 ((data)->peci_mask & (1 << nr)))
+				 ((data)->peci_mask & BIT(nr)))
 #define has_temp_old_peci(data, nr) \
 				(((data)->features & FEAT_TEMP_OLD_PECI) && \
-				 ((data)->old_peci_mask & (1 << nr)))
+				 ((data)->old_peci_mask & BIT(nr)))
 #define has_fan16_config(data)	((data)->features & FEAT_FAN16_CONFIG)
 #define has_five_fans(data)	((data)->features & (FEAT_FIVE_FANS | \
 						     FEAT_SIX_FANS))
 #define has_vid(data)		((data)->features & FEAT_VID)
 #define has_in7_internal(data)	((data)->features & FEAT_IN7_INTERNAL)
 #define has_six_fans(data)	((data)->features & FEAT_SIX_FANS)
+#define has_avcc3(data)		((data)->features & FEAT_AVCC3)
+#define has_five_pwm(data)	((data)->features & (FEAT_FIVE_PWM \
+						     | FEAT_SIX_PWM))
+#define has_six_pwm(data)	((data)->features & FEAT_SIX_PWM)
+#define has_pwm_freq2(data)	((data)->features & FEAT_PWM_FREQ2)
+#define has_six_temp(data)	((data)->features & FEAT_SIX_TEMP)
+#define has_vin3_5v(data)	((data)->features & FEAT_VIN3_5V)
+#define has_four_fans(data)	((data)->features & (FEAT_FOUR_FANS | \
+						     FEAT_FIVE_FANS | \
+						     FEAT_SIX_FANS))
+#define has_four_pwm(data)	((data)->features & (FEAT_FOUR_PWM | \
+						     FEAT_FIVE_PWM \
+						     | FEAT_SIX_PWM))
+#define has_bank_sel(data)	((data)->features & FEAT_BANK_SEL)
+#define has_scaling(data)	((data)->features & FEAT_SCALING)
+#define has_fanctl_onoff(data)	((data)->features & FEAT_FANCTL_ONOFF)
+#define has_11mv_adc(data)	((data)->features & FEAT_11MV_ADC)
+#define has_new_tempmap(data)	((data)->features & FEAT_NEW_TEMPMAP)
+#define has_mmio(data)		((data)->features & FEAT_MMIO)
+#define has_four_temp(data)	((data)->features & FEAT_FOUR_TEMP)
 
 struct it87_sio_data {
 	enum chips type;
+	u8 sioaddr;
+	u8 doexit;
 	/* Values read from Super-I/O config space */
 	u8 revision;
 	u8 vid_value;
@@ -433,6 +788,8 @@ struct it87_sio_data {
 	u8 skip_fan;
 	u8 skip_pwm;
 	u8 skip_temp;
+	u8 smbus_bitmap;
+	u8 ec_special_config;
 };
 
 /*
@@ -440,30 +797,57 @@ struct it87_sio_data {
  * The structure is dynamically allocated.
  */
 struct it87_data {
-	struct device *hwmon_dev;
+	const struct attribute_group *groups[7];
 	enum chips type;
-	u16 features;
+	u32 features;
 	u8 peci_mask;
 	u8 old_peci_mask;
 
+	u8 smbus_bitmap;	/* !=0 if SMBus needs to be disabled */
+	u8 saved_bank;		/* saved bank register value */
+	u8 ec_special_config;	/* EC special config register restore value */
+	u8 sioaddr;		/* SIO port address */
+	bool doexit;		/* true if exit from sio config is ok */
+
+	void __iomem *mmio;	/* Remapped MMIO address if available */
+	int (*read)(struct it87_data *, u16);
+	void (*write)(struct it87_data *, u16, u8);
+
+	const u8 *REG_FAN;
+	const u8 *REG_FANX;
+	const u8 *REG_FAN_MIN;
+	const u8 *REG_FANX_MIN;
+
+	const u8 *REG_PWM;
+
+	const u8 *REG_TEMP_OFFSET;
+	const u8 *REG_TEMP_LOW;
+	const u8 *REG_TEMP_HIGH;
+
 	unsigned short addr;
-	const char *name;
 	struct mutex update_lock;
 	char valid;		/* !=0 if following fields are valid */
 	unsigned long last_updated;	/* In jiffies */
 
 	u16 in_scaled;		/* Internal voltage sensors are scaled */
-	u8 in[10][3];		/* [nr][0]=in, [1]=min, [2]=max */
+	u16 in_internal;	/* Bitfield, internal sensors (for labels) */
+	u16 has_in;		/* Bitfield, voltage sensors enabled */
+	u8 in[NUM_VIN][3];		/* [nr][0]=in, [1]=min, [2]=max */
 	u8 has_fan;		/* Bitfield, fans enabled */
-	u16 fan[6][2];		/* Register values, [nr][0]=fan, [1]=min */
+	u16 fan[NUM_FAN][2];	/* Register values, [nr][0]=fan, [1]=min */
 	u8 has_temp;		/* Bitfield, temp sensors enabled */
-	s8 temp[3][4];		/* [nr][0]=temp, [1]=min, [2]=max, [3]=offset */
+	s8 temp[NUM_TEMP][4];	/* [nr][0]=temp, [1]=min, [2]=max, [3]=offset */
+	u8 num_temp_limit;	/* Number of temperature limit registers */
+	u8 num_temp_offset;	/* Number of temperature offset registers */
+	u8 temp_src[4];		/* Up to 4 temperature source registers */
 	u8 sensor;		/* Register value (IT87_REG_TEMP_ENABLE) */
 	u8 extra;		/* Register value (IT87_REG_TEMP_EXTRA) */
-	u8 fan_div[3];		/* Register encoding, shifted right */
+	u8 fan_div[NUM_FAN_DIV];/* Register encoding, shifted right */
+	bool has_vid;		/* True if VID supported */
 	u8 vid;			/* Register encoding, combined */
 	u8 vrm;
 	u32 alarms;		/* Register encoding, combined */
+	bool has_beep;		/* true if beep supported */
 	u8 beeps;		/* Register encoding */
 	u8 fan_main_ctrl;	/* Register value */
 	u8 fan_ctl;		/* Register value */
@@ -478,13 +862,17 @@ struct it87_data {
 	 * is no longer needed, but it is still done to keep the driver
 	 * simple.
 	 */
-	u8 pwm_ctrl[3];		/* Register value */
-	u8 pwm_duty[3];		/* Manual PWM value set by user */
-	u8 pwm_temp_map[3];	/* PWM to temp. chan. mapping (bits 1-0) */
+	u8 has_pwm;		/* Bitfield, pwm control enabled */
+	u8 pwm_ctrl[NUM_PWM];	/* Register value */
+	u8 pwm_duty[NUM_PWM];	/* Manual PWM value set by user */
+	u8 pwm_temp_map[NUM_PWM];/* PWM to temp. chan. mapping (bits 1-0) */
+	u8 pwm_temp_map_mask;	/* 0x03 for old, 0x07 for new temp map */
+	u8 pwm_temp_map_shift;	/* 0 for old, 3 for new temp map */
+	u8 pwm_num_temp_map;	/* from config data, 3..7 depending on chip */
 
 	/* Automatic fan speed control registers */
-	u8 auto_pwm[3][4];	/* [nr][3] is hard-coded */
-	s8 auto_temp[3][5];	/* [nr][0] is point1_temp_hyst */
+	u8 auto_pwm[NUM_AUTO_PWM][4];	/* [nr][3] is hard-coded */
+	s8 auto_temp[NUM_AUTO_PWM][5];	/* [nr][0] is point1_temp_hyst */
 };
 
 static int adc_lsb(const struct it87_data *data, int nr)
@@ -495,9 +883,11 @@ static int adc_lsb(const struct it87_data *data, int nr)
 		lsb = 120;
 	else if (has_10_9mv_adc(data))
 		lsb = 109;
+	else if (has_11mv_adc(data))
+		lsb = 110;
 	else
 		lsb = 160;
-	if (data->in_scaled & (1 << nr))
+	if (data->in_scaled & BIT(nr))
 		lsb <<= 1;
 	return lsb;
 }
@@ -554,15 +944,35 @@ static int pwm_from_reg(const struct it87_data *data, u8 reg)
 		return (reg & 0x7f) << 1;
 }
 
-
 static int DIV_TO_REG(int val)
 {
 	int answer = 0;
+
 	while (answer < 7 && (val >>= 1))
 		answer++;
 	return answer;
 }
-#define DIV_FROM_REG(val) (1 << (val))
+
+#define DIV_FROM_REG(val) BIT(val)
+
+static u8 temp_map_from_reg(const struct it87_data *data, u8 reg)
+{
+	u8 map;
+
+	map  = (reg >> data->pwm_temp_map_shift) & data->pwm_temp_map_mask;
+	if (map >= data->pwm_num_temp_map)	/* map is 0-based */
+		map = 0;
+
+	return map;
+}
+
+static u8 temp_map_to_reg(const struct it87_data *data, int nr, u8 map)
+{
+	u8 ctrl = data->pwm_ctrl[nr];
+
+	return (ctrl & ~(data->pwm_temp_map_mask << data->pwm_temp_map_shift)) |
+	       (map << data->pwm_temp_map_shift);
+}
 
 /*
  * PWM base frequencies. The frequency has to be divided by either 128 or 256,
@@ -585,281 +995,659 @@ static const unsigned int pwm_freq[8] = {
 	750000,
 };
 
-static int it87_probe(struct platform_device *pdev);
-static int it87_remove(struct platform_device *pdev);
-
-static int it87_read_value(struct it87_data *data, u8 reg);
-static void it87_write_value(struct it87_data *data, u8 reg, u8 value);
-static struct it87_data *it87_update_device(struct device *dev);
-static int it87_check_pwm(struct device *dev);
-static void it87_init_device(struct platform_device *pdev);
-
-
-static struct platform_driver it87_driver = {
-	.driver = {
-		.name	= DRVNAME,
-	},
-	.probe	= it87_probe,
-	.remove	= it87_remove,
-};
-
-static ssize_t show_in(struct device *dev, struct device_attribute *attr,
-		       char *buf)
+static int _it87_io_read(struct it87_data *data, u16 reg)
 {
-	struct sensor_device_attribute_2 *sattr = to_sensor_dev_attr_2(attr);
-	int nr = sattr->nr;
-	int index = sattr->index;
-
-	struct it87_data *data = it87_update_device(dev);
-	return sprintf(buf, "%d\n", in_from_reg(data, nr, data->in[nr][index]));
+	outb_p(reg, data->addr + IT87_ADDR_REG_OFFSET);
+	return inb_p(data->addr + IT87_DATA_REG_OFFSET);
 }
 
-static ssize_t set_in(struct device *dev, struct device_attribute *attr,
-		      const char *buf, size_t count)
+static void _it87_io_write(struct it87_data *data, u16 reg, u8 value)
 {
-	struct sensor_device_attribute_2 *sattr = to_sensor_dev_attr_2(attr);
-	int nr = sattr->nr;
-	int index = sattr->index;
-
-	struct it87_data *data = dev_get_drvdata(dev);
-	unsigned long val;
+	outb_p(reg, data->addr + IT87_ADDR_REG_OFFSET);
+	outb_p(value, data->addr + IT87_DATA_REG_OFFSET);
+}
 
-	if (kstrtoul(buf, 10, &val) < 0)
-		return -EINVAL;
+static int smbus_disable(struct it87_data *data)
+{
+	int err;
 
-	mutex_lock(&data->update_lock);
-	data->in[nr][index] = in_to_reg(data, nr, val);
-	it87_write_value(data,
-			 index == 1 ? IT87_REG_VIN_MIN(nr)
-				    : IT87_REG_VIN_MAX(nr),
-			 data->in[nr][index]);
-	mutex_unlock(&data->update_lock);
-	return count;
+	if (data->smbus_bitmap) {
+		err = superio_enter(data->sioaddr);
+		if (err)
+			return err;
+		superio_select(data->sioaddr, PME);
+		superio_outb(data->sioaddr, IT87_SPECIAL_CFG_REG,
+			     data->ec_special_config & ~data->smbus_bitmap);
+		superio_exit(data->sioaddr, data->doexit);
+		if (has_bank_sel(data) && !data->mmio)
+			data->saved_bank = _it87_io_read(data, IT87_REG_BANK);
+	}
+	return 0;
 }
 
-static SENSOR_DEVICE_ATTR_2(in0_input, S_IRUGO, show_in, NULL, 0, 0);
-static SENSOR_DEVICE_ATTR_2(in0_min, S_IRUGO | S_IWUSR, show_in, set_in,
-			    0, 1);
-static SENSOR_DEVICE_ATTR_2(in0_max, S_IRUGO | S_IWUSR, show_in, set_in,
-			    0, 2);
-
-static SENSOR_DEVICE_ATTR_2(in1_input, S_IRUGO, show_in, NULL, 1, 0);
-static SENSOR_DEVICE_ATTR_2(in1_min, S_IRUGO | S_IWUSR, show_in, set_in,
-			    1, 1);
-static SENSOR_DEVICE_ATTR_2(in1_max, S_IRUGO | S_IWUSR, show_in, set_in,
-			    1, 2);
-
-static SENSOR_DEVICE_ATTR_2(in2_input, S_IRUGO, show_in, NULL, 2, 0);
-static SENSOR_DEVICE_ATTR_2(in2_min, S_IRUGO | S_IWUSR, show_in, set_in,
-			    2, 1);
-static SENSOR_DEVICE_ATTR_2(in2_max, S_IRUGO | S_IWUSR, show_in, set_in,
-			    2, 2);
-
-static SENSOR_DEVICE_ATTR_2(in3_input, S_IRUGO, show_in, NULL, 3, 0);
-static SENSOR_DEVICE_ATTR_2(in3_min, S_IRUGO | S_IWUSR, show_in, set_in,
-			    3, 1);
-static SENSOR_DEVICE_ATTR_2(in3_max, S_IRUGO | S_IWUSR, show_in, set_in,
-			    3, 2);
-
-static SENSOR_DEVICE_ATTR_2(in4_input, S_IRUGO, show_in, NULL, 4, 0);
-static SENSOR_DEVICE_ATTR_2(in4_min, S_IRUGO | S_IWUSR, show_in, set_in,
-			    4, 1);
-static SENSOR_DEVICE_ATTR_2(in4_max, S_IRUGO | S_IWUSR, show_in, set_in,
-			    4, 2);
-
-static SENSOR_DEVICE_ATTR_2(in5_input, S_IRUGO, show_in, NULL, 5, 0);
-static SENSOR_DEVICE_ATTR_2(in5_min, S_IRUGO | S_IWUSR, show_in, set_in,
-			    5, 1);
-static SENSOR_DEVICE_ATTR_2(in5_max, S_IRUGO | S_IWUSR, show_in, set_in,
-			    5, 2);
-
-static SENSOR_DEVICE_ATTR_2(in6_input, S_IRUGO, show_in, NULL, 6, 0);
-static SENSOR_DEVICE_ATTR_2(in6_min, S_IRUGO | S_IWUSR, show_in, set_in,
-			    6, 1);
-static SENSOR_DEVICE_ATTR_2(in6_max, S_IRUGO | S_IWUSR, show_in, set_in,
-			    6, 2);
-
-static SENSOR_DEVICE_ATTR_2(in7_input, S_IRUGO, show_in, NULL, 7, 0);
-static SENSOR_DEVICE_ATTR_2(in7_min, S_IRUGO | S_IWUSR, show_in, set_in,
-			    7, 1);
-static SENSOR_DEVICE_ATTR_2(in7_max, S_IRUGO | S_IWUSR, show_in, set_in,
-			    7, 2);
-
-static SENSOR_DEVICE_ATTR_2(in8_input, S_IRUGO, show_in, NULL, 8, 0);
-static SENSOR_DEVICE_ATTR_2(in9_input, S_IRUGO, show_in, NULL, 9, 0);
-
-/* 3 temperatures */
-static ssize_t show_temp(struct device *dev, struct device_attribute *attr,
-			 char *buf)
+static int smbus_enable(struct it87_data *data)
 {
-	struct sensor_device_attribute_2 *sattr = to_sensor_dev_attr_2(attr);
-	int nr = sattr->nr;
-	int index = sattr->index;
-	struct it87_data *data = it87_update_device(dev);
+	int err;
 
-	return sprintf(buf, "%d\n", TEMP_FROM_REG(data->temp[nr][index]));
+	if (data->smbus_bitmap) {
+		if (has_bank_sel(data) && !data->mmio)
+			_it87_io_write(data, IT87_REG_BANK, data->saved_bank);
+		err = superio_enter(data->sioaddr);
+		if (err)
+			return err;
+
+		superio_select(data->sioaddr, PME);
+		superio_outb(data->sioaddr, IT87_SPECIAL_CFG_REG,
+			     data->ec_special_config);
+		superio_exit(data->sioaddr, data->doexit);
+	}
+	return 0;
 }
 
-static ssize_t set_temp(struct device *dev, struct device_attribute *attr,
-			const char *buf, size_t count)
+static u8 it87_io_set_bank(struct it87_data *data, u8 bank)
 {
-	struct sensor_device_attribute_2 *sattr = to_sensor_dev_attr_2(attr);
-	int nr = sattr->nr;
-	int index = sattr->index;
-	struct it87_data *data = dev_get_drvdata(dev);
-	long val;
-	u8 reg, regval;
-
-	if (kstrtol(buf, 10, &val) < 0)
-		return -EINVAL;
+	u8 _bank = bank;
 
-	mutex_lock(&data->update_lock);
+	if (has_bank_sel(data)) {
+		u8 breg = _it87_io_read(data, IT87_REG_BANK);
 
-	switch (index) {
-	default:
-	case 1:
-		reg = IT87_REG_TEMP_LOW(nr);
-		break;
-	case 2:
-		reg = IT87_REG_TEMP_HIGH(nr);
-		break;
-	case 3:
-		regval = it87_read_value(data, IT87_REG_BEEP_ENABLE);
-		if (!(regval & 0x80)) {
-			regval |= 0x80;
-			it87_write_value(data, IT87_REG_BEEP_ENABLE, regval);
+		_bank = breg >> 5;
+		if (bank != _bank) {
+			breg &= 0x1f;
+			breg |= (bank << 5);
+			_it87_io_write(data, IT87_REG_BANK, breg);
 		}
-		data->valid = 0;
-		reg = IT87_REG_TEMP_OFFSET[nr];
-		break;
 	}
-
-	data->temp[nr][index] = TEMP_TO_REG(val);
-	it87_write_value(data, reg, data->temp[nr][index]);
-	mutex_unlock(&data->update_lock);
-	return count;
+	return _bank;
 }
 
-static SENSOR_DEVICE_ATTR_2(temp1_input, S_IRUGO, show_temp, NULL, 0, 0);
-static SENSOR_DEVICE_ATTR_2(temp1_min, S_IRUGO | S_IWUSR, show_temp, set_temp,
-			    0, 1);
-static SENSOR_DEVICE_ATTR_2(temp1_max, S_IRUGO | S_IWUSR, show_temp, set_temp,
-			    0, 2);
-static SENSOR_DEVICE_ATTR_2(temp1_offset, S_IRUGO | S_IWUSR, show_temp,
-			    set_temp, 0, 3);
-static SENSOR_DEVICE_ATTR_2(temp2_input, S_IRUGO, show_temp, NULL, 1, 0);
-static SENSOR_DEVICE_ATTR_2(temp2_min, S_IRUGO | S_IWUSR, show_temp, set_temp,
-			    1, 1);
-static SENSOR_DEVICE_ATTR_2(temp2_max, S_IRUGO | S_IWUSR, show_temp, set_temp,
-			    1, 2);
-static SENSOR_DEVICE_ATTR_2(temp2_offset, S_IRUGO | S_IWUSR, show_temp,
-			    set_temp, 1, 3);
-static SENSOR_DEVICE_ATTR_2(temp3_input, S_IRUGO, show_temp, NULL, 2, 0);
-static SENSOR_DEVICE_ATTR_2(temp3_min, S_IRUGO | S_IWUSR, show_temp, set_temp,
-			    2, 1);
-static SENSOR_DEVICE_ATTR_2(temp3_max, S_IRUGO | S_IWUSR, show_temp, set_temp,
-			    2, 2);
-static SENSOR_DEVICE_ATTR_2(temp3_offset, S_IRUGO | S_IWUSR, show_temp,
-			    set_temp, 2, 3);
+/*
+ * Must be called with data->update_lock held, except during initialization.
+ * Must be called with SMBus accesses disabled.
+ * We ignore the IT87 BUSY flag at this moment - it could lead to deadlocks,
+ * would slow down the IT87 access and should not be necessary.
+ */
+static int it87_io_read(struct it87_data *data, u16 reg)
+{
+	u8 bank;
+	int val;
+
+	bank = it87_io_set_bank(data, reg >> 8);
+	val = _it87_io_read(data, reg & 0xff);
+	it87_io_set_bank(data, bank);
 
-static ssize_t show_temp_type(struct device *dev, struct device_attribute *attr,
-			      char *buf)
+	return val;
+}
+
+/*
+ * Must be called with data->update_lock held, except during initialization.
+ * Must be called with SMBus accesses disabled
+ * We ignore the IT87 BUSY flag at this moment - it could lead to deadlocks,
+ * would slow down the IT87 access and should not be necessary.
+ */
+static void it87_io_write(struct it87_data *data, u16 reg, u8 value)
 {
-	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
-	int nr = sensor_attr->index;
-	struct it87_data *data = it87_update_device(dev);
-	u8 reg = data->sensor;	    /* In case value is updated while used */
-	u8 extra = data->extra;
+	u8 bank;
 
-	if ((has_temp_peci(data, nr) && (reg >> 6 == nr + 1))
-	    || (has_temp_old_peci(data, nr) && (extra & 0x80)))
-		return sprintf(buf, "6\n");  /* Intel PECI */
-	if (reg & (1 << nr))
-		return sprintf(buf, "3\n");  /* thermal diode */
-	if (reg & (8 << nr))
-		return sprintf(buf, "4\n");  /* thermistor */
-	return sprintf(buf, "0\n");      /* disabled */
+	bank = it87_io_set_bank(data, reg >> 8);
+	_it87_io_write(data, reg & 0xff, value);
+	it87_io_set_bank(data, bank);
 }
 
-static ssize_t set_temp_type(struct device *dev, struct device_attribute *attr,
-			     const char *buf, size_t count)
+static int it87_mmio_read(struct it87_data *data, u16 reg)
 {
-	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
-	int nr = sensor_attr->index;
+	return readb(data->mmio + reg);
+}
 
-	struct it87_data *data = dev_get_drvdata(dev);
-	long val;
-	u8 reg, extra;
+static void it87_mmio_write(struct it87_data *data, u16 reg, u8 value)
+{
+	writeb(value, data->mmio + reg);
+}
 
-	if (kstrtol(buf, 10, &val) < 0)
-		return -EINVAL;
+static void it87_update_pwm_ctrl(struct it87_data *data, int nr)
+{
+	u8 ctrl;
 
-	reg = it87_read_value(data, IT87_REG_TEMP_ENABLE);
-	reg &= ~(1 << nr);
-	reg &= ~(8 << nr);
-	if (has_temp_peci(data, nr) && (reg >> 6 == nr + 1 || val == 6))
-		reg &= 0x3f;
-	extra = it87_read_value(data, IT87_REG_TEMP_EXTRA);
-	if (has_temp_old_peci(data, nr) && ((extra & 0x80) || val == 6))
-		extra &= 0x7f;
-	if (val == 2) {	/* backwards compatibility */
-		dev_warn(dev,
-			 "Sensor type 2 is deprecated, please use 4 instead\n");
-		val = 4;
+	ctrl = data->read(data, data->REG_PWM[nr]);
+	data->pwm_ctrl[nr] = ctrl;
+	if (has_newer_autopwm(data)) {
+		data->pwm_temp_map[nr] = temp_map_from_reg(data, ctrl);
+		data->pwm_duty[nr] = data->read(data, IT87_REG_PWM_DUTY[nr]);
+	} else {
+		if (ctrl & 0x80)	/* Automatic mode */
+			data->pwm_temp_map[nr] = temp_map_from_reg(data, ctrl);
+		else				/* Manual mode */
+			data->pwm_duty[nr] = ctrl & 0x7f;
 	}
-	/* 3 = thermal diode; 4 = thermistor; 6 = Intel PECI; 0 = disabled */
-	if (val == 3)
-		reg |= 1 << nr;
-	else if (val == 4)
-		reg |= 8 << nr;
-	else if (has_temp_peci(data, nr) && val == 6)
-		reg |= (nr + 1) << 6;
-	else if (has_temp_old_peci(data, nr) && val == 6)
-		extra |= 0x80;
-	else if (val != 0)
-		return -EINVAL;
 
-	mutex_lock(&data->update_lock);
-	data->sensor = reg;
-	data->extra = extra;
-	it87_write_value(data, IT87_REG_TEMP_ENABLE, data->sensor);
-	if (has_temp_old_peci(data, nr))
-		it87_write_value(data, IT87_REG_TEMP_EXTRA, data->extra);
-	data->valid = 0;	/* Force cache refresh */
-	mutex_unlock(&data->update_lock);
-	return count;
-}
+	if (has_old_autopwm(data)) {
+		int i;
+
+		for (i = 0; i < 5 ; i++)
+			data->auto_temp[nr][i] = data->read(data,
+						IT87_REG_AUTO_TEMP(nr, i));
+		for (i = 0; i < 3 ; i++)
+			data->auto_pwm[nr][i] = data->read(data,
+						IT87_REG_AUTO_PWM(nr, i));
+	} else if (has_newer_autopwm(data)) {
+		int i;
 
-static SENSOR_DEVICE_ATTR(temp1_type, S_IRUGO | S_IWUSR, show_temp_type,
-			  set_temp_type, 0);
-static SENSOR_DEVICE_ATTR(temp2_type, S_IRUGO | S_IWUSR, show_temp_type,
-			  set_temp_type, 1);
-static SENSOR_DEVICE_ATTR(temp3_type, S_IRUGO | S_IWUSR, show_temp_type,
-			  set_temp_type, 2);
+		/*
+		 * 0: temperature hysteresis (base + 5)
+		 * 1: fan off temperature (base + 0)
+		 * 2: fan start temperature (base + 1)
+		 * 3: fan max temperature (base + 2)
+		 */
+		data->auto_temp[nr][0] =
+			data->read(data, IT87_REG_AUTO_TEMP(nr, 5));
 
-/* 3 Fans */
+		for (i = 0; i < 3 ; i++)
+			data->auto_temp[nr][i + 1] =
+				data->read(data, IT87_REG_AUTO_TEMP(nr, i));
+		/*
+		 * 0: start pwm value (base + 3)
+		 * 1: pwm slope (base + 4, 1/8th pwm)
+		 */
+		data->auto_pwm[nr][0] =
+			data->read(data, IT87_REG_AUTO_TEMP(nr, 3));
+		data->auto_pwm[nr][1] =
+			data->read(data, IT87_REG_AUTO_TEMP(nr, 4));
+	}
+}
 
-static int pwm_mode(const struct it87_data *data, int nr)
+static int it87_lock(struct it87_data *data)
 {
-	int ctrl = data->fan_main_ctrl & (1 << nr);
+	int err;
 
-	if (ctrl == 0 && data->type != it8603)		/* Full speed */
-		return 0;
-	if (data->pwm_ctrl[nr] & 0x80)			/* Automatic mode */
-		return 2;
-	else						/* Manual mode */
-		return 1;
+	mutex_lock(&data->update_lock);
+	err = smbus_disable(data);
+	if (err)
+		mutex_unlock(&data->update_lock);
+	return err;
 }
 
-static ssize_t show_fan(struct device *dev, struct device_attribute *attr,
-			char *buf)
+static void it87_unlock(struct it87_data *data)
 {
-	struct sensor_device_attribute_2 *sattr = to_sensor_dev_attr_2(attr);
+	smbus_enable(data);
+	mutex_unlock(&data->update_lock);
+}
+
+static struct it87_data *it87_update_device(struct device *dev)
+{
+	struct it87_data *data = dev_get_drvdata(dev);
+	struct it87_data *ret = data;
+	int err;
+	int i;
+
+	mutex_lock(&data->update_lock);
+
+	if (time_after(jiffies, data->last_updated + HZ + HZ / 2) ||
+	    !data->valid) {
+		err = smbus_disable(data);
+		if (err) {
+			ret = ERR_PTR(err);
+			goto unlock;
+		}
+		if (update_vbat) {
+			/*
+			 * Cleared after each update, so reenable.  Value
+			 * returned by this read will be previous value
+			 */
+			data->write(data, IT87_REG_CONFIG,
+				    data->read(data, IT87_REG_CONFIG) | 0x40);
+		}
+		for (i = 0; i < NUM_VIN; i++) {
+			if (!(data->has_in & BIT(i)))
+				continue;
+
+			data->in[i][0] = data->read(data, IT87_REG_VIN[i]);
+
+			/* VBAT and AVCC don't have limit registers */
+			if (i >= NUM_VIN_LIMIT)
+				continue;
+
+			data->in[i][1] = data->read(data, IT87_REG_VIN_MIN(i));
+			data->in[i][2] = data->read(data, IT87_REG_VIN_MAX(i));
+		}
+
+		for (i = 0; i < NUM_FAN; i++) {
+			/* Skip disabled fans */
+			if (!(data->has_fan & BIT(i)))
+				continue;
+
+			data->fan[i][1] = data->read(data,
+						     data->REG_FAN_MIN[i]);
+			data->fan[i][0] = data->read(data, data->REG_FAN[i]);
+			/* Add high byte if in 16-bit mode */
+			if (has_16bit_fans(data)) {
+				data->fan[i][0] |= data->read(data,
+						data->REG_FANX[i]) << 8;
+				data->fan[i][1] |= data->read(data,
+						data->REG_FANX_MIN[i]) << 8;
+			}
+		}
+		for (i = 0; i < NUM_TEMP; i++) {
+			if (!(data->has_temp & BIT(i)))
+				continue;
+			data->temp[i][0] =
+				data->read(data, IT87_REG_TEMP(i));
+
+			if (i >= data->num_temp_limit)
+				continue;
+
+			if (i < data->num_temp_offset)
+				data->temp[i][3] =
+				  data->read(data, data->REG_TEMP_OFFSET[i]);
+
+			data->temp[i][1] =
+				data->read(data, data->REG_TEMP_LOW[i]);
+			data->temp[i][2] =
+				data->read(data, data->REG_TEMP_HIGH[i]);
+		}
+
+		/* Newer chips don't have clock dividers */
+		if ((data->has_fan & 0x07) && !has_16bit_fans(data)) {
+			i = data->read(data, IT87_REG_FAN_DIV);
+			data->fan_div[0] = i & 0x07;
+			data->fan_div[1] = (i >> 3) & 0x07;
+			data->fan_div[2] = (i & 0x40) ? 3 : 1;
+		}
+
+		data->alarms =
+			data->read(data, IT87_REG_ALARM1) |
+			(data->read(data, IT87_REG_ALARM2) << 8) |
+			(data->read(data, IT87_REG_ALARM3) << 16);
+		data->beeps = data->read(data, IT87_REG_BEEP_ENABLE);
+
+		data->fan_main_ctrl = data->read(data, IT87_REG_FAN_MAIN_CTRL);
+		data->fan_ctl = data->read(data, IT87_REG_FAN_CTL);
+		for (i = 0; i < NUM_PWM; i++) {
+			if (!(data->has_pwm & BIT(i)))
+				continue;
+			it87_update_pwm_ctrl(data, i);
+		}
+
+		data->sensor = data->read(data, IT87_REG_TEMP_ENABLE);
+		data->extra = data->read(data, IT87_REG_TEMP_EXTRA);
+		/*
+		 * The IT8705F does not have VID capability.
+		 * The IT8718F and later don't use IT87_REG_VID for the
+		 * same purpose.
+		 */
+		if (data->type == it8712 || data->type == it8716) {
+			data->vid = data->read(data, IT87_REG_VID);
+			/*
+			 * The older IT8712F revisions had only 5 VID pins,
+			 * but we assume it is always safe to read 6 bits.
+			 */
+			data->vid &= 0x3f;
+		}
+		data->last_updated = jiffies;
+		data->valid = 1;
+		smbus_enable(data);
+	}
+unlock:
+	mutex_unlock(&data->update_lock);
+	return ret;
+}
+
+static ssize_t show_in(struct device *dev, struct device_attribute *attr,
+		       char *buf)
+{
+	struct sensor_device_attribute_2 *sattr = to_sensor_dev_attr_2(attr);
+	struct it87_data *data = it87_update_device(dev);
+	int index = sattr->index;
+	int nr = sattr->nr;
+
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
+	return sprintf(buf, "%d\n", in_from_reg(data, nr, data->in[nr][index]));
+}
+
+static ssize_t set_in(struct device *dev, struct device_attribute *attr,
+		      const char *buf, size_t count)
+{
+	struct sensor_device_attribute_2 *sattr = to_sensor_dev_attr_2(attr);
+	struct it87_data *data = dev_get_drvdata(dev);
+	int index = sattr->index;
+	int nr = sattr->nr;
+	unsigned long val;
+	int err;
+
+	if (kstrtoul(buf, 10, &val) < 0)
+		return -EINVAL;
+
+	err = it87_lock(data);
+	if (err)
+		return err;
+
+	data->in[nr][index] = in_to_reg(data, nr, val);
+	data->write(data, index == 1 ? IT87_REG_VIN_MIN(nr)
+				     : IT87_REG_VIN_MAX(nr),
+		    data->in[nr][index]);
+	it87_unlock(data);
+	return count;
+}
+
+static SENSOR_DEVICE_ATTR_2(in0_input, 0444, show_in, NULL, 0, 0);
+static SENSOR_DEVICE_ATTR_2(in0_min, 0644, show_in, set_in, 0, 1);
+static SENSOR_DEVICE_ATTR_2(in0_max, 0644, show_in, set_in, 0, 2);
+
+static SENSOR_DEVICE_ATTR_2(in1_input, 0444, show_in, NULL, 1, 0);
+static SENSOR_DEVICE_ATTR_2(in1_min, 0644, show_in, set_in, 1, 1);
+static SENSOR_DEVICE_ATTR_2(in1_max, 0644, show_in, set_in, 1, 2);
+
+static SENSOR_DEVICE_ATTR_2(in2_input, 0444, show_in, NULL, 2, 0);
+static SENSOR_DEVICE_ATTR_2(in2_min, 0644, show_in, set_in, 2, 1);
+static SENSOR_DEVICE_ATTR_2(in2_max, 0644, show_in, set_in, 2, 2);
+
+static SENSOR_DEVICE_ATTR_2(in3_input, 0444, show_in, NULL, 3, 0);
+static SENSOR_DEVICE_ATTR_2(in3_min, 0644, show_in, set_in, 3, 1);
+static SENSOR_DEVICE_ATTR_2(in3_max, 0644, show_in, set_in, 3, 2);
+
+static SENSOR_DEVICE_ATTR_2(in4_input, 0444, show_in, NULL, 4, 0);
+static SENSOR_DEVICE_ATTR_2(in4_min, 0644, show_in, set_in, 4, 1);
+static SENSOR_DEVICE_ATTR_2(in4_max, 0644, show_in, set_in, 4, 2);
+
+static SENSOR_DEVICE_ATTR_2(in5_input, 0444, show_in, NULL, 5, 0);
+static SENSOR_DEVICE_ATTR_2(in5_min, 0644, show_in, set_in, 5, 1);
+static SENSOR_DEVICE_ATTR_2(in5_max, 0644, show_in, set_in, 5, 2);
+
+static SENSOR_DEVICE_ATTR_2(in6_input, 0444, show_in, NULL, 6, 0);
+static SENSOR_DEVICE_ATTR_2(in6_min, 0644, show_in, set_in, 6, 1);
+static SENSOR_DEVICE_ATTR_2(in6_max, 0644, show_in, set_in, 6, 2);
+
+static SENSOR_DEVICE_ATTR_2(in7_input, 0444, show_in, NULL, 7, 0);
+static SENSOR_DEVICE_ATTR_2(in7_min, 0644, show_in, set_in, 7, 1);
+static SENSOR_DEVICE_ATTR_2(in7_max, 0644, show_in, set_in, 7, 2);
+
+static SENSOR_DEVICE_ATTR_2(in8_input, 0444, show_in, NULL, 8, 0);
+static SENSOR_DEVICE_ATTR_2(in9_input, 0444, show_in, NULL, 9, 0);
+static SENSOR_DEVICE_ATTR_2(in10_input, 0444, show_in, NULL, 10, 0);
+static SENSOR_DEVICE_ATTR_2(in11_input, 0444, show_in, NULL, 11, 0);
+static SENSOR_DEVICE_ATTR_2(in12_input, 0444, show_in, NULL, 12, 0);
+
+/* Up to 6 temperatures */
+static ssize_t show_temp(struct device *dev, struct device_attribute *attr,
+			 char *buf)
+{
+	struct sensor_device_attribute_2 *sattr = to_sensor_dev_attr_2(attr);
+	int nr = sattr->nr;
+	int index = sattr->index;
+	struct it87_data *data = it87_update_device(dev);
+
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
+	return sprintf(buf, "%d\n", TEMP_FROM_REG(data->temp[nr][index]));
+}
+
+static ssize_t set_temp(struct device *dev, struct device_attribute *attr,
+			const char *buf, size_t count)
+{
+	struct sensor_device_attribute_2 *sattr = to_sensor_dev_attr_2(attr);
+	int nr = sattr->nr;
+	int index = sattr->index;
+	struct it87_data *data = dev_get_drvdata(dev);
+	long val;
+	u8 reg, regval;
+	int err;
+
+	if (kstrtol(buf, 10, &val) < 0)
+		return -EINVAL;
+
+	err = it87_lock(data);
+	if (err)
+		return err;
+
+	switch (index) {
+	default:
+	case 1:
+		reg = data->REG_TEMP_LOW[nr];
+		break;
+	case 2:
+		reg = data->REG_TEMP_HIGH[nr];
+		break;
+	case 3:
+		regval = data->read(data, IT87_REG_BEEP_ENABLE);
+		if (!(regval & 0x80)) {
+			regval |= 0x80;
+			data->write(data, IT87_REG_BEEP_ENABLE, regval);
+		}
+		data->valid = 0;
+		reg = data->REG_TEMP_OFFSET[nr];
+		break;
+	}
+
+	data->temp[nr][index] = TEMP_TO_REG(val);
+	data->write(data, reg, data->temp[nr][index]);
+	it87_unlock(data);
+	return count;
+}
+
+static SENSOR_DEVICE_ATTR_2(temp1_input, 0444, show_temp, NULL, 0, 0);
+static SENSOR_DEVICE_ATTR_2(temp1_min, 0644, show_temp, set_temp, 0, 1);
+static SENSOR_DEVICE_ATTR_2(temp1_max, 0644, show_temp, set_temp, 0, 2);
+static SENSOR_DEVICE_ATTR_2(temp1_offset, 0644, show_temp, set_temp, 0, 3);
+static SENSOR_DEVICE_ATTR_2(temp2_input, 0444, show_temp, NULL, 1, 0);
+static SENSOR_DEVICE_ATTR_2(temp2_min, 0644, show_temp, set_temp, 1, 1);
+static SENSOR_DEVICE_ATTR_2(temp2_max, 0644, show_temp, set_temp, 1, 2);
+static SENSOR_DEVICE_ATTR_2(temp2_offset, 0644, show_temp, set_temp, 1, 3);
+static SENSOR_DEVICE_ATTR_2(temp3_input, 0444, show_temp, NULL, 2, 0);
+static SENSOR_DEVICE_ATTR_2(temp3_min, 0644, show_temp, set_temp, 2, 1);
+static SENSOR_DEVICE_ATTR_2(temp3_max, 0644, show_temp, set_temp, 2, 2);
+static SENSOR_DEVICE_ATTR_2(temp3_offset, 0644, show_temp, set_temp, 2, 3);
+static SENSOR_DEVICE_ATTR_2(temp4_input, 0444, show_temp, NULL, 3, 0);
+static SENSOR_DEVICE_ATTR_2(temp4_min, 0644, show_temp, set_temp, 3, 1);
+static SENSOR_DEVICE_ATTR_2(temp4_max, 0644, show_temp, set_temp, 3, 2);
+static SENSOR_DEVICE_ATTR_2(temp4_offset, 0644, show_temp, set_temp, 3, 3);
+static SENSOR_DEVICE_ATTR_2(temp5_input, 0444, show_temp, NULL, 4, 0);
+static SENSOR_DEVICE_ATTR_2(temp5_min, 0644, show_temp, set_temp, 4, 1);
+static SENSOR_DEVICE_ATTR_2(temp5_max, 0644, show_temp, set_temp, 4, 2);
+static SENSOR_DEVICE_ATTR_2(temp5_offset, 0644, show_temp, set_temp, 4, 3);
+static SENSOR_DEVICE_ATTR_2(temp6_input, 0444, show_temp, NULL, 5, 0);
+static SENSOR_DEVICE_ATTR_2(temp6_min, 0644, show_temp, set_temp, 5, 1);
+static SENSOR_DEVICE_ATTR_2(temp6_max, 0644, show_temp, set_temp, 5, 2);
+static SENSOR_DEVICE_ATTR_2(temp6_offset, 0644, show_temp, set_temp, 5, 3);
+
+static const u8 temp_types_8686[NUM_TEMP][9] = {
+	{ 0, 8, 8, 8, 8, 8, 8, 8, 7 },
+	{ 0, 6, 8, 8, 6, 0, 0, 0, 7 },
+	{ 0, 6, 5, 8, 6, 0, 0, 0, 7 },
+	{ 4, 8, 8, 8, 8, 8, 8, 8, 7 },
+	{ 4, 6, 8, 8, 6, 0, 0, 0, 7 },
+	{ 4, 6, 5, 8, 6, 0, 0, 0, 7 },
+};
+
+static int get_temp_type(struct it87_data *data, int index)
+{
+	u8 reg, extra;
+	int ttype, type = 0;
+
+	if (has_bank_sel(data)) {
+		u8 src1, src2;
+
+		src1 = (data->temp_src[index / 2] >> ((index % 2) * 4)) & 0x0f;
+
+		switch (data->type) {
+		case it8686:
+			if (src1 < 9)
+				type = temp_types_8686[index][src1];
+			break;
+		case it8625:
+			if (index < 3)
+				break;
+		case it8655:
+		case it8665:
+			if (src1 < 3) {
+				index = src1;
+				break;
+			}
+			src2 = data->temp_src[3];
+			switch (src1) {
+			case 3:
+				type = (src2 & BIT(index)) ? 6 : 5;
+				break;
+			case 4 ... 8:
+				type = (src2 & BIT(index)) ? 4 : 6;
+				break;
+			case 9:
+				type = (src2 & BIT(index)) ? 5 : 0;
+				break;
+			default:
+				break;
+			}
+			return type;
+		default:
+			return 0;
+		}
+	}
+	if (type)
+		return type;
+
+	/* Dectect PECI vs. AMDTSI */
+	ttype = 6;
+	if ((has_temp_peci(data, index)) || data->type == it8721 ||
+	    data->type == it8720) {
+		extra = data->read(data, IT87_REG_IFSEL);
+		if ((extra & 0x70) == 0x40)
+			ttype = 5;
+	}
+
+	reg = data->read(data, IT87_REG_TEMP_ENABLE);
+
+	/* Per chip special detection */
+	switch (data->type) {
+	case it8622:
+		if (!(reg & 0xc0) && index == 3)
+			type = ttype;
+		break;
+	default:
+		break;
+	}
+
+	if (type || index >= 3)
+		return type;
+
+	extra = data->read(data, IT87_REG_TEMP_EXTRA);
+
+	if ((has_temp_peci(data, index) && (reg >> 6 == index + 1)) ||
+	    (has_temp_old_peci(data, index) && (extra & 0x80)))
+		type = ttype;		/* Intel PECI or AMDTSI */
+	if (reg & BIT(index))
+		type = 3;		/* thermal diode */
+	else if (reg & BIT(index + 3))
+		type = 4;		/* thermistor */
+
+	return type;
+}
+
+static ssize_t show_temp_type(struct device *dev, struct device_attribute *attr,
+			      char *buf)
+{
+	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
+	struct it87_data *data = it87_update_device(dev);
+	int type;
+
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
+	type = get_temp_type(data, sensor_attr->index);
+	return sprintf(buf, "%d\n", type);
+}
+
+static ssize_t set_temp_type(struct device *dev, struct device_attribute *attr,
+			     const char *buf, size_t count)
+{
+	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
+	int nr = sensor_attr->index;
+
+	struct it87_data *data = dev_get_drvdata(dev);
+	long val;
+	u8 reg, extra;
+	int err;
+
+	if (kstrtol(buf, 10, &val) < 0)
+		return -EINVAL;
+
+	err = it87_lock(data);
+	if (err)
+		return err;
+
+	reg = data->read(data, IT87_REG_TEMP_ENABLE);
+	reg &= ~(1 << nr);
+	reg &= ~(8 << nr);
+	if (has_temp_peci(data, nr) && (reg >> 6 == nr + 1 || val == 6))
+		reg &= 0x3f;
+	extra = data->read(data, IT87_REG_TEMP_EXTRA);
+	if (has_temp_old_peci(data, nr) && ((extra & 0x80) || val == 6))
+		extra &= 0x7f;
+	if (val == 2) {	/* backwards compatibility */
+		dev_warn(dev,
+			 "Sensor type 2 is deprecated, please use 4 instead\n");
+		val = 4;
+	}
+	/* 3 = thermal diode; 4 = thermistor; 6 = Intel PECI; 0 = disabled */
+	if (val == 3)
+		reg |= 1 << nr;
+	else if (val == 4)
+		reg |= 8 << nr;
+	else if (has_temp_peci(data, nr) && val == 6)
+		reg |= (nr + 1) << 6;
+	else if (has_temp_old_peci(data, nr) && val == 6)
+		extra |= 0x80;
+	else if (val != 0) {
+		count = -EINVAL;
+		goto unlock;
+	}
+
+	data->sensor = reg;
+	data->extra = extra;
+	data->write(data, IT87_REG_TEMP_ENABLE, data->sensor);
+	if (has_temp_old_peci(data, nr))
+		data->write(data, IT87_REG_TEMP_EXTRA, data->extra);
+	data->valid = 0;	/* Force cache refresh */
+unlock:
+	it87_unlock(data);
+	return count;
+}
+
+static SENSOR_DEVICE_ATTR(temp1_type, 0644, show_temp_type, set_temp_type, 0);
+static SENSOR_DEVICE_ATTR(temp2_type, 0644, show_temp_type, set_temp_type, 1);
+static SENSOR_DEVICE_ATTR(temp3_type, 0644, show_temp_type, set_temp_type, 2);
+static SENSOR_DEVICE_ATTR(temp4_type, 0644, show_temp_type, set_temp_type, 3);
+static SENSOR_DEVICE_ATTR(temp5_type, 0644, show_temp_type, set_temp_type, 4);
+static SENSOR_DEVICE_ATTR(temp6_type, 0644, show_temp_type, set_temp_type, 5);
+
+/* 6 Fans */
+
+static int pwm_mode(const struct it87_data *data, int nr)
+{
+	if (has_fanctl_onoff(data) && nr < 3 &&
+	    !(data->fan_main_ctrl & BIT(nr)))
+		return 0;				/* Full speed */
+	if (data->pwm_ctrl[nr] & 0x80)
+		return 2;				/* Automatic mode */
+	if ((!has_fanctl_onoff(data) || nr >= 3) &&
+	    data->pwm_duty[nr] == pwm_to_reg(data, 0xff))
+		return 0;			/* Full speed */
+
+	return 1;				/* Manual mode */
+}
+
+static ssize_t show_fan(struct device *dev, struct device_attribute *attr,
+			char *buf)
+{
+	struct sensor_device_attribute_2 *sattr = to_sensor_dev_attr_2(attr);
 	int nr = sattr->nr;
 	int index = sattr->index;
 	int speed;
 	struct it87_data *data = it87_update_device(dev);
 
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
 	speed = has_16bit_fans(data) ?
 		FAN16_FROM_REG(data->fan[nr][index]) :
 		FAN_FROM_REG(data->fan[nr][index],
@@ -868,39 +1656,61 @@ static ssize_t show_fan(struct device *dev, struct device_attribute *attr,
 }
 
 static ssize_t show_fan_div(struct device *dev, struct device_attribute *attr,
-		char *buf)
+			    char *buf)
 {
 	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
+	struct it87_data *data = it87_update_device(dev);
 	int nr = sensor_attr->index;
 
-	struct it87_data *data = it87_update_device(dev);
-	return sprintf(buf, "%d\n", DIV_FROM_REG(data->fan_div[nr]));
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
+	return sprintf(buf, "%lu\n", DIV_FROM_REG(data->fan_div[nr]));
 }
+
 static ssize_t show_pwm_enable(struct device *dev,
-		struct device_attribute *attr, char *buf)
+			       struct device_attribute *attr, char *buf)
 {
 	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
+	struct it87_data *data = it87_update_device(dev);
 	int nr = sensor_attr->index;
 
-	struct it87_data *data = it87_update_device(dev);
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
 	return sprintf(buf, "%d\n", pwm_mode(data, nr));
 }
+
 static ssize_t show_pwm(struct device *dev, struct device_attribute *attr,
-		char *buf)
+			char *buf)
 {
 	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
+	struct it87_data *data = it87_update_device(dev);
 	int nr = sensor_attr->index;
 
-	struct it87_data *data = it87_update_device(dev);
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
 	return sprintf(buf, "%d\n",
 		       pwm_from_reg(data, data->pwm_duty[nr]));
 }
+
 static ssize_t show_pwm_freq(struct device *dev, struct device_attribute *attr,
-		char *buf)
+			     char *buf)
 {
+	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
 	struct it87_data *data = it87_update_device(dev);
-	int index = (data->fan_ctl >> 4) & 0x07;
+	int nr = sensor_attr->index;
 	unsigned int freq;
+	int index;
+
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
+	if (has_pwm_freq2(data) && nr == 1)
+		index = (data->extra >> 4) & 0x07;
+	else
+		index = (data->fan_ctl >> 4) & 0x07;
 
 	freq = pwm_freq[index] / (has_newer_autopwm(data) ? 256 : 128);
 
@@ -916,21 +1726,24 @@ static ssize_t set_fan(struct device *dev, struct device_attribute *attr,
 
 	struct it87_data *data = dev_get_drvdata(dev);
 	long val;
+	int err;
 	u8 reg;
 
 	if (kstrtol(buf, 10, &val) < 0)
 		return -EINVAL;
 
-	mutex_lock(&data->update_lock);
+	err = it87_lock(data);
+	if (err)
+		return err;
 
 	if (has_16bit_fans(data)) {
 		data->fan[nr][index] = FAN16_TO_REG(val);
-		it87_write_value(data, IT87_REG_FAN_MIN[nr],
-				 data->fan[nr][index] & 0xff);
-		it87_write_value(data, IT87_REG_FANX_MIN[nr],
-				 data->fan[nr][index] >> 8);
+		data->write(data, data->REG_FAN_MIN[nr],
+			    data->fan[nr][index] & 0xff);
+		data->write(data, data->REG_FANX_MIN[nr],
+			    data->fan[nr][index] >> 8);
 	} else {
-		reg = it87_read_value(data, IT87_REG_FAN_DIV);
+		reg = data->read(data, IT87_REG_FAN_DIV);
 		switch (nr) {
 		case 0:
 			data->fan_div[nr] = reg & 0x07;
@@ -944,30 +1757,30 @@ static ssize_t set_fan(struct device *dev, struct device_attribute *attr,
 		}
 		data->fan[nr][index] =
 		  FAN_TO_REG(val, DIV_FROM_REG(data->fan_div[nr]));
-		it87_write_value(data, IT87_REG_FAN_MIN[nr],
-				 data->fan[nr][index]);
+		data->write(data, data->REG_FAN_MIN[nr], data->fan[nr][index]);
 	}
-
-	mutex_unlock(&data->update_lock);
+	it87_unlock(data);
 	return count;
 }
 
 static ssize_t set_fan_div(struct device *dev, struct device_attribute *attr,
-		const char *buf, size_t count)
+			   const char *buf, size_t count)
 {
 	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
-	int nr = sensor_attr->index;
-
 	struct it87_data *data = dev_get_drvdata(dev);
+	int nr = sensor_attr->index;
 	unsigned long val;
-	int min;
+	int min, err;
 	u8 old;
 
 	if (kstrtoul(buf, 10, &val) < 0)
 		return -EINVAL;
 
-	mutex_lock(&data->update_lock);
-	old = it87_read_value(data, IT87_REG_FAN_DIV);
+	err = it87_lock(data);
+	if (err)
+		return err;
+
+	old = data->read(data, IT87_REG_FAN_DIV);
 
 	/* Save fan min limit */
 	min = FAN_FROM_REG(data->fan[nr][1], DIV_FROM_REG(data->fan_div[nr]));
@@ -988,13 +1801,12 @@ static ssize_t set_fan_div(struct device *dev, struct device_attribute *attr,
 	val |= (data->fan_div[1] & 0x07) << 3;
 	if (data->fan_div[2] == 3)
 		val |= 0x1 << 6;
-	it87_write_value(data, IT87_REG_FAN_DIV, val);
+	data->write(data, IT87_REG_FAN_DIV, val);
 
 	/* Restore fan min limit */
 	data->fan[nr][1] = FAN_TO_REG(min, DIV_FROM_REG(data->fan_div[nr]));
-	it87_write_value(data, IT87_REG_FAN_MIN[nr], data->fan[nr][1]);
-
-	mutex_unlock(&data->update_lock);
+	data->write(data, data->REG_FAN_MIN[nr], data->fan[nr][1]);
+	it87_unlock(data);
 	return count;
 }
 
@@ -1013,6 +1825,11 @@ static int check_trip_points(struct device *dev, int nr)
 			if (data->auto_pwm[nr][i] > data->auto_pwm[nr][i + 1])
 				err = -EINVAL;
 		}
+	} else if (has_newer_autopwm(data)) {
+		for (i = 1; i < 3; i++) {
+			if (data->auto_temp[nr][i] > data->auto_temp[nr][i + 1])
+				err = -EINVAL;
+		}
 	}
 
 	if (err) {
@@ -1023,14 +1840,14 @@ static int check_trip_points(struct device *dev, int nr)
 	return err;
 }
 
-static ssize_t set_pwm_enable(struct device *dev,
-		struct device_attribute *attr, const char *buf, size_t count)
+static ssize_t set_pwm_enable(struct device *dev, struct device_attribute *attr,
+			      const char *buf, size_t count)
 {
 	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
-	int nr = sensor_attr->index;
-
 	struct it87_data *data = dev_get_drvdata(dev);
+	int nr = sensor_attr->index;
 	long val;
+	int err;
 
 	if (kstrtol(buf, 10, &val) < 0 || val < 0 || val > 2)
 		return -EINVAL;
@@ -1041,66 +1858,96 @@ static ssize_t set_pwm_enable(struct device *dev,
 			return -EINVAL;
 	}
 
-	/* IT8603E does not have on/off mode */
-	if (val == 0 && data->type == it8603)
-		return -EINVAL;
+	err = it87_lock(data);
+	if (err)
+		return err;
 
-	mutex_lock(&data->update_lock);
+	it87_update_pwm_ctrl(data, nr);
 
 	if (val == 0) {
-		int tmp;
-		/* make sure the fan is on when in on/off mode */
-		tmp = it87_read_value(data, IT87_REG_FAN_CTL);
-		it87_write_value(data, IT87_REG_FAN_CTL, tmp | (1 << nr));
-		/* set on/off mode */
-		data->fan_main_ctrl &= ~(1 << nr);
-		it87_write_value(data, IT87_REG_FAN_MAIN_CTRL,
-				 data->fan_main_ctrl);
+		if (nr < 3 && has_fanctl_onoff(data)) {
+			int tmp;
+			/* make sure the fan is on when in on/off mode */
+			tmp = data->read(data, IT87_REG_FAN_CTL);
+			data->write(data, IT87_REG_FAN_CTL, tmp | BIT(nr));
+			/* set on/off mode */
+			data->fan_main_ctrl &= ~BIT(nr);
+			data->write(data, IT87_REG_FAN_MAIN_CTRL,
+				    data->fan_main_ctrl);
+		} else {
+			u8 ctrl;
+
+			/* No on/off mode, set maximum pwm value */
+			data->pwm_duty[nr] = pwm_to_reg(data, 0xff);
+			data->write(data, IT87_REG_PWM_DUTY[nr],
+				    data->pwm_duty[nr]);
+			/* and set manual mode */
+			if (has_newer_autopwm(data)) {
+				ctrl = temp_map_to_reg(data, nr,
+						       data->pwm_temp_map[nr]);
+				ctrl &= 0x7f;
+			} else {
+				ctrl = data->pwm_duty[nr];
+			}
+			data->pwm_ctrl[nr] = ctrl;
+			data->write(data, data->REG_PWM[nr], ctrl);
+		}
 	} else {
-		if (val == 1)				/* Manual mode */
-			data->pwm_ctrl[nr] = has_newer_autopwm(data) ?
-					     data->pwm_temp_map[nr] :
-					     data->pwm_duty[nr];
-		else					/* Automatic mode */
-			data->pwm_ctrl[nr] = 0x80 | data->pwm_temp_map[nr];
-		it87_write_value(data, IT87_REG_PWM(nr), data->pwm_ctrl[nr]);
-
-		if (data->type != it8603) {
+		u8 ctrl;
+
+		if (has_newer_autopwm(data)) {
+			ctrl = temp_map_to_reg(data, nr,
+					       data->pwm_temp_map[nr]);
+			if (val == 1)
+				ctrl &= 0x7f;
+			else
+				ctrl |= 0x80;
+		} else {
+			ctrl = (val == 1 ? data->pwm_duty[nr] : 0x80);
+		}
+		data->pwm_ctrl[nr] = ctrl;
+		data->write(data, data->REG_PWM[nr], ctrl);
+
+		if (has_fanctl_onoff(data) && nr < 3) {
 			/* set SmartGuardian mode */
-			data->fan_main_ctrl |= (1 << nr);
-			it87_write_value(data, IT87_REG_FAN_MAIN_CTRL,
-					 data->fan_main_ctrl);
+			data->fan_main_ctrl |= BIT(nr);
+			data->write(data, IT87_REG_FAN_MAIN_CTRL,
+				    data->fan_main_ctrl);
 		}
 	}
-
-	mutex_unlock(&data->update_lock);
+	it87_unlock(data);
 	return count;
 }
+
 static ssize_t set_pwm(struct device *dev, struct device_attribute *attr,
-		const char *buf, size_t count)
+		       const char *buf, size_t count)
 {
 	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
-	int nr = sensor_attr->index;
-
 	struct it87_data *data = dev_get_drvdata(dev);
+	int nr = sensor_attr->index;
 	long val;
+	int err;
 
 	if (kstrtol(buf, 10, &val) < 0 || val < 0 || val > 255)
 		return -EINVAL;
 
-	mutex_lock(&data->update_lock);
+	err = it87_lock(data);
+	if (err)
+		return err;
+
+	it87_update_pwm_ctrl(data, nr);
 	if (has_newer_autopwm(data)) {
 		/*
 		 * If we are in automatic mode, the PWM duty cycle register
 		 * is read-only so we can't write the value.
 		 */
 		if (data->pwm_ctrl[nr] & 0x80) {
-			mutex_unlock(&data->update_lock);
-			return -EBUSY;
+			count = -EBUSY;
+			goto unlock;
 		}
 		data->pwm_duty[nr] = pwm_to_reg(data, val);
-		it87_write_value(data, IT87_REG_PWM_DUTY(nr),
-				 data->pwm_duty[nr]);
+		data->write(data, IT87_REG_PWM_DUTY[nr],
+			    data->pwm_duty[nr]);
 	} else {
 		data->pwm_duty[nr] = pwm_to_reg(data, val);
 		/*
@@ -1109,18 +1956,23 @@ static ssize_t set_pwm(struct device *dev, struct device_attribute *attr,
 		 */
 		if (!(data->pwm_ctrl[nr] & 0x80)) {
 			data->pwm_ctrl[nr] = data->pwm_duty[nr];
-			it87_write_value(data, IT87_REG_PWM(nr),
-					 data->pwm_ctrl[nr]);
+			data->write(data, data->REG_PWM[nr],
+				    data->pwm_ctrl[nr]);
 		}
 	}
-	mutex_unlock(&data->update_lock);
+unlock:
+	it87_unlock(data);
 	return count;
 }
-static ssize_t set_pwm_freq(struct device *dev,
-		struct device_attribute *attr, const char *buf, size_t count)
+
+static ssize_t set_pwm_freq(struct device *dev, struct device_attribute *attr,
+			    const char *buf, size_t count)
 {
+	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
 	struct it87_data *data = dev_get_drvdata(dev);
+	int nr = sensor_attr->index;
 	unsigned long val;
+	int err;
 	int i;
 
 	if (kstrtoul(buf, 10, &val) < 0)
@@ -1131,85 +1983,79 @@ static ssize_t set_pwm_freq(struct device *dev,
 
 	/* Search for the nearest available frequency */
 	for (i = 0; i < 7; i++) {
-		if (val > (pwm_freq[i] + pwm_freq[i+1]) / 2)
+		if (val > (pwm_freq[i] + pwm_freq[i + 1]) / 2)
 			break;
 	}
 
-	mutex_lock(&data->update_lock);
-	data->fan_ctl = it87_read_value(data, IT87_REG_FAN_CTL) & 0x8f;
-	data->fan_ctl |= i << 4;
-	it87_write_value(data, IT87_REG_FAN_CTL, data->fan_ctl);
-	mutex_unlock(&data->update_lock);
+	err = it87_lock(data);
+	if (err)
+		return err;
 
+	if (nr == 0) {
+		data->fan_ctl = data->read(data, IT87_REG_FAN_CTL) & 0x8f;
+		data->fan_ctl |= i << 4;
+		data->write(data, IT87_REG_FAN_CTL, data->fan_ctl);
+	} else {
+		data->extra = data->read(data, IT87_REG_TEMP_EXTRA) & 0x8f;
+		data->extra |= i << 4;
+		data->write(data, IT87_REG_TEMP_EXTRA, data->extra);
+	}
+	it87_unlock(data);
 	return count;
 }
+
 static ssize_t show_pwm_temp_map(struct device *dev,
-		struct device_attribute *attr, char *buf)
+				 struct device_attribute *attr, char *buf)
 {
 	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
+	struct it87_data *data = it87_update_device(dev);
 	int nr = sensor_attr->index;
 
-	struct it87_data *data = it87_update_device(dev);
-	int map;
+	if (IS_ERR(data))
+		return PTR_ERR(data);
 
-	if (data->pwm_temp_map[nr] < 3)
-		map = 1 << data->pwm_temp_map[nr];
-	else
-		map = 0;			/* Should never happen */
-	return sprintf(buf, "%d\n", map);
+	return sprintf(buf, "%d\n", data->pwm_temp_map[nr] + 1);
 }
+
 static ssize_t set_pwm_temp_map(struct device *dev,
-		struct device_attribute *attr, const char *buf, size_t count)
+				struct device_attribute *attr, const char *buf,
+				size_t count)
 {
 	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
-	int nr = sensor_attr->index;
-
 	struct it87_data *data = dev_get_drvdata(dev);
-	long val;
-	u8 reg;
+	int nr = sensor_attr->index;
+	unsigned long val;
+	int err;
+	u8 map;
 
-	/*
-	 * This check can go away if we ever support automatic fan speed
-	 * control on newer chips.
-	 */
-	if (!has_old_autopwm(data)) {
-		dev_notice(dev, "Mapping change disabled for safety reasons\n");
+	if (kstrtoul(buf, 10, &val) < 0)
 		return -EINVAL;
-	}
 
-	if (kstrtol(buf, 10, &val) < 0)
+	if (!val || val > data->pwm_num_temp_map)
 		return -EINVAL;
 
-	switch (val) {
-	case (1 << 0):
-		reg = 0x00;
-		break;
-	case (1 << 1):
-		reg = 0x01;
-		break;
-	case (1 << 2):
-		reg = 0x02;
-		break;
-	default:
-		return -EINVAL;
-	}
+	map = val - 1;
 
-	mutex_lock(&data->update_lock);
-	data->pwm_temp_map[nr] = reg;
+	err = it87_lock(data);
+	if (err)
+		return err;
+
+	it87_update_pwm_ctrl(data, nr);
+	data->pwm_temp_map[nr] = map;
 	/*
 	 * If we are in automatic mode, write the temp mapping immediately;
 	 * otherwise, just store it for later use.
 	 */
 	if (data->pwm_ctrl[nr] & 0x80) {
-		data->pwm_ctrl[nr] = 0x80 | data->pwm_temp_map[nr];
-		it87_write_value(data, IT87_REG_PWM(nr), data->pwm_ctrl[nr]);
+		data->pwm_ctrl[nr] = temp_map_to_reg(data, nr, map);
+		data->write(data, data->REG_PWM[nr], data->pwm_ctrl[nr]);
 	}
-	mutex_unlock(&data->update_lock);
+	it87_unlock(data);
 	return count;
 }
 
-static ssize_t show_auto_pwm(struct device *dev,
-		struct device_attribute *attr, char *buf)
+static ssize_t show_auto_pwm(struct device *dev, struct device_attribute *attr,
+			     char *buf)
 {
 	struct it87_data *data = it87_update_device(dev);
 	struct sensor_device_attribute_2 *sensor_attr =
@@ -1217,45 +2063,101 @@ static ssize_t show_auto_pwm(struct device *dev,
 	int nr = sensor_attr->nr;
 	int point = sensor_attr->index;
 
-	return sprintf(buf, "%d\n",
-		       pwm_from_reg(data, data->auto_pwm[nr][point]));
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
+	return sprintf(buf, "%d\n",
+		       pwm_from_reg(data, data->auto_pwm[nr][point]));
+}
+
+static ssize_t set_auto_pwm(struct device *dev, struct device_attribute *attr,
+			    const char *buf, size_t count)
+{
+	struct it87_data *data = dev_get_drvdata(dev);
+	struct sensor_device_attribute_2 *sensor_attr =
+			to_sensor_dev_attr_2(attr);
+	int nr = sensor_attr->nr;
+	int point = sensor_attr->index;
+	int regaddr;
+	long val;
+	int err;
+
+	if (kstrtol(buf, 10, &val) < 0 || val < 0 || val > 255)
+		return -EINVAL;
+
+	err = it87_lock(data);
+	if (err)
+		return err;
+
+	data->auto_pwm[nr][point] = pwm_to_reg(data, val);
+	if (has_newer_autopwm(data))
+		regaddr = IT87_REG_AUTO_TEMP(nr, 3);
+	else
+		regaddr = IT87_REG_AUTO_PWM(nr, point);
+	data->write(data, regaddr, data->auto_pwm[nr][point]);
+	it87_unlock(data);
+	return count;
+}
+
+static ssize_t show_auto_pwm_slope(struct device *dev,
+				   struct device_attribute *attr, char *buf)
+{
+	struct it87_data *data = it87_update_device(dev);
+	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
+	int nr = sensor_attr->index;
+
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
+	return sprintf(buf, "%d\n", data->auto_pwm[nr][1] & 0x7f);
 }
 
-static ssize_t set_auto_pwm(struct device *dev,
-		struct device_attribute *attr, const char *buf, size_t count)
+static ssize_t set_auto_pwm_slope(struct device *dev,
+				  struct device_attribute *attr,
+				  const char *buf, size_t count)
 {
 	struct it87_data *data = dev_get_drvdata(dev);
-	struct sensor_device_attribute_2 *sensor_attr =
-			to_sensor_dev_attr_2(attr);
-	int nr = sensor_attr->nr;
-	int point = sensor_attr->index;
-	long val;
+	struct sensor_device_attribute *sensor_attr = to_sensor_dev_attr(attr);
+	int nr = sensor_attr->index;
+	unsigned long val;
+	int err;
 
-	if (kstrtol(buf, 10, &val) < 0 || val < 0 || val > 255)
+	if (kstrtoul(buf, 10, &val) < 0 || val > 127)
 		return -EINVAL;
 
-	mutex_lock(&data->update_lock);
-	data->auto_pwm[nr][point] = pwm_to_reg(data, val);
-	it87_write_value(data, IT87_REG_AUTO_PWM(nr, point),
-			 data->auto_pwm[nr][point]);
-	mutex_unlock(&data->update_lock);
+	err = it87_lock(data);
+	if (err)
+		return err;
+
+	data->auto_pwm[nr][1] = (data->auto_pwm[nr][1] & 0x80) | val;
+	data->write(data, IT87_REG_AUTO_TEMP(nr, 4), data->auto_pwm[nr][1]);
+	it87_unlock(data);
 	return count;
 }
 
-static ssize_t show_auto_temp(struct device *dev,
-		struct device_attribute *attr, char *buf)
+static ssize_t show_auto_temp(struct device *dev, struct device_attribute *attr,
+			      char *buf)
 {
 	struct it87_data *data = it87_update_device(dev);
 	struct sensor_device_attribute_2 *sensor_attr =
 			to_sensor_dev_attr_2(attr);
 	int nr = sensor_attr->nr;
 	int point = sensor_attr->index;
+	int reg;
+
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
+	if (has_old_autopwm(data) || point)
+		reg = data->auto_temp[nr][point];
+	else
+		reg = data->auto_temp[nr][1] - (data->auto_temp[nr][0] & 0x1f);
 
-	return sprintf(buf, "%d\n", TEMP_FROM_REG(data->auto_temp[nr][point]));
+	return sprintf(buf, "%d\n", TEMP_FROM_REG(reg));
 }
 
-static ssize_t set_auto_temp(struct device *dev,
-		struct device_attribute *attr, const char *buf, size_t count)
+static ssize_t set_auto_temp(struct device *dev, struct device_attribute *attr,
+			     const char *buf, size_t count)
 {
 	struct it87_data *data = dev_get_drvdata(dev);
 	struct sensor_device_attribute_2 *sensor_attr =
@@ -1263,243 +2165,340 @@ static ssize_t set_auto_temp(struct device *dev,
 	int nr = sensor_attr->nr;
 	int point = sensor_attr->index;
 	long val;
+	int reg;
+	int err;
 
 	if (kstrtol(buf, 10, &val) < 0 || val < -128000 || val > 127000)
 		return -EINVAL;
 
-	mutex_lock(&data->update_lock);
-	data->auto_temp[nr][point] = TEMP_TO_REG(val);
-	it87_write_value(data, IT87_REG_AUTO_TEMP(nr, point),
-			 data->auto_temp[nr][point]);
-	mutex_unlock(&data->update_lock);
+	err = it87_lock(data);
+	if (err)
+		return err;
+
+	if (has_newer_autopwm(data) && !point) {
+		reg = data->auto_temp[nr][1] - TEMP_TO_REG(val);
+		reg = clamp_val(reg, 0, 0x1f) | (data->auto_temp[nr][0] & 0xe0);
+		data->auto_temp[nr][0] = reg;
+		data->write(data, IT87_REG_AUTO_TEMP(nr, 5), reg);
+	} else {
+		reg = TEMP_TO_REG(val);
+		data->auto_temp[nr][point] = reg;
+		if (has_newer_autopwm(data))
+			point--;
+		data->write(data, IT87_REG_AUTO_TEMP(nr, point), reg);
+	}
+	it87_unlock(data);
 	return count;
 }
 
-static SENSOR_DEVICE_ATTR_2(fan1_input, S_IRUGO, show_fan, NULL, 0, 0);
-static SENSOR_DEVICE_ATTR_2(fan1_min, S_IRUGO | S_IWUSR, show_fan, set_fan,
-			    0, 1);
-static SENSOR_DEVICE_ATTR(fan1_div, S_IRUGO | S_IWUSR, show_fan_div,
-			  set_fan_div, 0);
+static SENSOR_DEVICE_ATTR_2(fan1_input, 0444, show_fan, NULL, 0, 0);
+static SENSOR_DEVICE_ATTR_2(fan1_min, 0644, show_fan, set_fan, 0, 1);
+static SENSOR_DEVICE_ATTR(fan1_div, 0644, show_fan_div, set_fan_div, 0);
 
-static SENSOR_DEVICE_ATTR_2(fan2_input, S_IRUGO, show_fan, NULL, 1, 0);
-static SENSOR_DEVICE_ATTR_2(fan2_min, S_IRUGO | S_IWUSR, show_fan, set_fan,
-			    1, 1);
-static SENSOR_DEVICE_ATTR(fan2_div, S_IRUGO | S_IWUSR, show_fan_div,
-			  set_fan_div, 1);
+static SENSOR_DEVICE_ATTR_2(fan2_input, 0444, show_fan, NULL, 1, 0);
+static SENSOR_DEVICE_ATTR_2(fan2_min, 0644, show_fan, set_fan, 1, 1);
+static SENSOR_DEVICE_ATTR(fan2_div, 0644, show_fan_div, set_fan_div, 1);
 
-static SENSOR_DEVICE_ATTR_2(fan3_input, S_IRUGO, show_fan, NULL, 2, 0);
-static SENSOR_DEVICE_ATTR_2(fan3_min, S_IRUGO | S_IWUSR, show_fan, set_fan,
-			    2, 1);
-static SENSOR_DEVICE_ATTR(fan3_div, S_IRUGO | S_IWUSR, show_fan_div,
-			  set_fan_div, 2);
+static SENSOR_DEVICE_ATTR_2(fan3_input, 0444, show_fan, NULL, 2, 0);
+static SENSOR_DEVICE_ATTR_2(fan3_min, 0644, show_fan, set_fan, 2, 1);
+static SENSOR_DEVICE_ATTR(fan3_div, 0644, show_fan_div, set_fan_div, 2);
 
-static SENSOR_DEVICE_ATTR_2(fan4_input, S_IRUGO, show_fan, NULL, 3, 0);
-static SENSOR_DEVICE_ATTR_2(fan4_min, S_IRUGO | S_IWUSR, show_fan, set_fan,
-			    3, 1);
+static SENSOR_DEVICE_ATTR_2(fan4_input, 0444, show_fan, NULL, 3, 0);
+static SENSOR_DEVICE_ATTR_2(fan4_min, 0644, show_fan, set_fan, 3, 1);
 
-static SENSOR_DEVICE_ATTR_2(fan5_input, S_IRUGO, show_fan, NULL, 4, 0);
-static SENSOR_DEVICE_ATTR_2(fan5_min, S_IRUGO | S_IWUSR, show_fan, set_fan,
-			    4, 1);
+static SENSOR_DEVICE_ATTR_2(fan5_input, 0444, show_fan, NULL, 4, 0);
+static SENSOR_DEVICE_ATTR_2(fan5_min, 0644, show_fan, set_fan, 4, 1);
 
-static SENSOR_DEVICE_ATTR_2(fan6_input, S_IRUGO, show_fan, NULL, 5, 0);
-static SENSOR_DEVICE_ATTR_2(fan6_min, S_IRUGO | S_IWUSR, show_fan, set_fan,
-			    5, 1);
+static SENSOR_DEVICE_ATTR_2(fan6_input, 0444, show_fan, NULL, 5, 0);
+static SENSOR_DEVICE_ATTR_2(fan6_min, 0644, show_fan, set_fan, 5, 1);
 
-static SENSOR_DEVICE_ATTR(pwm1_enable, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR(pwm1_enable, 0644,
 			  show_pwm_enable, set_pwm_enable, 0);
-static SENSOR_DEVICE_ATTR(pwm1, S_IRUGO | S_IWUSR, show_pwm, set_pwm, 0);
-static DEVICE_ATTR(pwm1_freq, S_IRUGO | S_IWUSR, show_pwm_freq, set_pwm_freq);
-static SENSOR_DEVICE_ATTR(pwm1_auto_channels_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR(pwm1, 0644, show_pwm, set_pwm, 0);
+static SENSOR_DEVICE_ATTR(pwm1_freq, 0644, show_pwm_freq, set_pwm_freq, 0);
+static SENSOR_DEVICE_ATTR(pwm1_auto_channels_temp, 0444,
 			  show_pwm_temp_map, set_pwm_temp_map, 0);
-static SENSOR_DEVICE_ATTR_2(pwm1_auto_point1_pwm, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm1_auto_point1_pwm, 0644,
 			    show_auto_pwm, set_auto_pwm, 0, 0);
-static SENSOR_DEVICE_ATTR_2(pwm1_auto_point2_pwm, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm1_auto_point2_pwm, 0644,
 			    show_auto_pwm, set_auto_pwm, 0, 1);
-static SENSOR_DEVICE_ATTR_2(pwm1_auto_point3_pwm, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm1_auto_point3_pwm, 0644,
 			    show_auto_pwm, set_auto_pwm, 0, 2);
-static SENSOR_DEVICE_ATTR_2(pwm1_auto_point4_pwm, S_IRUGO,
+static SENSOR_DEVICE_ATTR_2(pwm1_auto_point4_pwm, 0444,
 			    show_auto_pwm, NULL, 0, 3);
-static SENSOR_DEVICE_ATTR_2(pwm1_auto_point1_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm1_auto_point1_temp, 0644,
 			    show_auto_temp, set_auto_temp, 0, 1);
-static SENSOR_DEVICE_ATTR_2(pwm1_auto_point1_temp_hyst, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm1_auto_point1_temp_hyst, 0644,
 			    show_auto_temp, set_auto_temp, 0, 0);
-static SENSOR_DEVICE_ATTR_2(pwm1_auto_point2_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm1_auto_point2_temp, 0644,
 			    show_auto_temp, set_auto_temp, 0, 2);
-static SENSOR_DEVICE_ATTR_2(pwm1_auto_point3_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm1_auto_point3_temp, 0644,
 			    show_auto_temp, set_auto_temp, 0, 3);
-static SENSOR_DEVICE_ATTR_2(pwm1_auto_point4_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm1_auto_point4_temp, 0644,
 			    show_auto_temp, set_auto_temp, 0, 4);
+static SENSOR_DEVICE_ATTR_2(pwm1_auto_start, 0644,
+			    show_auto_pwm, set_auto_pwm, 0, 0);
+static SENSOR_DEVICE_ATTR(pwm1_auto_slope, 0644,
+			  show_auto_pwm_slope, set_auto_pwm_slope, 0);
 
-static SENSOR_DEVICE_ATTR(pwm2_enable, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR(pwm2_enable, 0644,
 			  show_pwm_enable, set_pwm_enable, 1);
-static SENSOR_DEVICE_ATTR(pwm2, S_IRUGO | S_IWUSR, show_pwm, set_pwm, 1);
-static DEVICE_ATTR(pwm2_freq, S_IRUGO, show_pwm_freq, NULL);
-static SENSOR_DEVICE_ATTR(pwm2_auto_channels_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR(pwm2, 0644, show_pwm, set_pwm, 1);
+static SENSOR_DEVICE_ATTR(pwm2_freq, 0444, show_pwm_freq, set_pwm_freq, 1);
+static SENSOR_DEVICE_ATTR(pwm2_auto_channels_temp, 0444,
 			  show_pwm_temp_map, set_pwm_temp_map, 1);
-static SENSOR_DEVICE_ATTR_2(pwm2_auto_point1_pwm, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm2_auto_point1_pwm, 0644,
 			    show_auto_pwm, set_auto_pwm, 1, 0);
-static SENSOR_DEVICE_ATTR_2(pwm2_auto_point2_pwm, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm2_auto_point2_pwm, 0644,
 			    show_auto_pwm, set_auto_pwm, 1, 1);
-static SENSOR_DEVICE_ATTR_2(pwm2_auto_point3_pwm, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm2_auto_point3_pwm, 0644,
 			    show_auto_pwm, set_auto_pwm, 1, 2);
-static SENSOR_DEVICE_ATTR_2(pwm2_auto_point4_pwm, S_IRUGO,
+static SENSOR_DEVICE_ATTR_2(pwm2_auto_point4_pwm, 0444,
 			    show_auto_pwm, NULL, 1, 3);
-static SENSOR_DEVICE_ATTR_2(pwm2_auto_point1_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm2_auto_point1_temp, 0644,
 			    show_auto_temp, set_auto_temp, 1, 1);
-static SENSOR_DEVICE_ATTR_2(pwm2_auto_point1_temp_hyst, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm2_auto_point1_temp_hyst, 0644,
 			    show_auto_temp, set_auto_temp, 1, 0);
-static SENSOR_DEVICE_ATTR_2(pwm2_auto_point2_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm2_auto_point2_temp, 0644,
 			    show_auto_temp, set_auto_temp, 1, 2);
-static SENSOR_DEVICE_ATTR_2(pwm2_auto_point3_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm2_auto_point3_temp, 0644,
 			    show_auto_temp, set_auto_temp, 1, 3);
-static SENSOR_DEVICE_ATTR_2(pwm2_auto_point4_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm2_auto_point4_temp, 0644,
 			    show_auto_temp, set_auto_temp, 1, 4);
+static SENSOR_DEVICE_ATTR_2(pwm2_auto_start, 0644,
+			    show_auto_pwm, set_auto_pwm, 1, 0);
+static SENSOR_DEVICE_ATTR(pwm2_auto_slope, 0644,
+			  show_auto_pwm_slope, set_auto_pwm_slope, 1);
 
-static SENSOR_DEVICE_ATTR(pwm3_enable, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR(pwm3_enable, 0644,
 			  show_pwm_enable, set_pwm_enable, 2);
-static SENSOR_DEVICE_ATTR(pwm3, S_IRUGO | S_IWUSR, show_pwm, set_pwm, 2);
-static DEVICE_ATTR(pwm3_freq, S_IRUGO, show_pwm_freq, NULL);
-static SENSOR_DEVICE_ATTR(pwm3_auto_channels_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR(pwm3, 0644, show_pwm, set_pwm, 2);
+static SENSOR_DEVICE_ATTR(pwm3_freq, 0444, show_pwm_freq, NULL, 2);
+static SENSOR_DEVICE_ATTR(pwm3_auto_channels_temp, 0444,
 			  show_pwm_temp_map, set_pwm_temp_map, 2);
-static SENSOR_DEVICE_ATTR_2(pwm3_auto_point1_pwm, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm3_auto_point1_pwm, 0644,
 			    show_auto_pwm, set_auto_pwm, 2, 0);
-static SENSOR_DEVICE_ATTR_2(pwm3_auto_point2_pwm, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm3_auto_point2_pwm, 0644,
 			    show_auto_pwm, set_auto_pwm, 2, 1);
-static SENSOR_DEVICE_ATTR_2(pwm3_auto_point3_pwm, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm3_auto_point3_pwm, 0644,
 			    show_auto_pwm, set_auto_pwm, 2, 2);
-static SENSOR_DEVICE_ATTR_2(pwm3_auto_point4_pwm, S_IRUGO,
+static SENSOR_DEVICE_ATTR_2(pwm3_auto_point4_pwm, 0444,
 			    show_auto_pwm, NULL, 2, 3);
-static SENSOR_DEVICE_ATTR_2(pwm3_auto_point1_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm3_auto_point1_temp, 0644,
 			    show_auto_temp, set_auto_temp, 2, 1);
-static SENSOR_DEVICE_ATTR_2(pwm3_auto_point1_temp_hyst, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm3_auto_point1_temp_hyst, 0644,
 			    show_auto_temp, set_auto_temp, 2, 0);
-static SENSOR_DEVICE_ATTR_2(pwm3_auto_point2_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm3_auto_point2_temp, 0644,
 			    show_auto_temp, set_auto_temp, 2, 2);
-static SENSOR_DEVICE_ATTR_2(pwm3_auto_point3_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm3_auto_point3_temp, 0644,
 			    show_auto_temp, set_auto_temp, 2, 3);
-static SENSOR_DEVICE_ATTR_2(pwm3_auto_point4_temp, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR_2(pwm3_auto_point4_temp, 0644,
 			    show_auto_temp, set_auto_temp, 2, 4);
+static SENSOR_DEVICE_ATTR_2(pwm3_auto_start, 0644,
+			    show_auto_pwm, set_auto_pwm, 2, 0);
+static SENSOR_DEVICE_ATTR(pwm3_auto_slope, 0644,
+			  show_auto_pwm_slope, set_auto_pwm_slope, 2);
+
+static SENSOR_DEVICE_ATTR(pwm4_enable, 0644,
+			  show_pwm_enable, set_pwm_enable, 3);
+static SENSOR_DEVICE_ATTR(pwm4, 0644, show_pwm, set_pwm, 3);
+static SENSOR_DEVICE_ATTR(pwm4_freq, 0444, show_pwm_freq, NULL, 3);
+static SENSOR_DEVICE_ATTR(pwm4_auto_channels_temp, 0444,
+			  show_pwm_temp_map, set_pwm_temp_map, 3);
+static SENSOR_DEVICE_ATTR_2(pwm4_auto_point1_temp, 0644,
+			    show_auto_temp, set_auto_temp, 2, 1);
+static SENSOR_DEVICE_ATTR_2(pwm4_auto_point1_temp_hyst, 0644,
+			    show_auto_temp, set_auto_temp, 2, 0);
+static SENSOR_DEVICE_ATTR_2(pwm4_auto_point2_temp, 0644,
+			    show_auto_temp, set_auto_temp, 2, 2);
+static SENSOR_DEVICE_ATTR_2(pwm4_auto_point3_temp, 0644,
+			    show_auto_temp, set_auto_temp, 2, 3);
+static SENSOR_DEVICE_ATTR_2(pwm4_auto_start, 0644,
+			    show_auto_pwm, set_auto_pwm, 3, 0);
+static SENSOR_DEVICE_ATTR(pwm4_auto_slope, 0644,
+			  show_auto_pwm_slope, set_auto_pwm_slope, 3);
+
+static SENSOR_DEVICE_ATTR(pwm5_enable, 0644,
+			  show_pwm_enable, set_pwm_enable, 4);
+static SENSOR_DEVICE_ATTR(pwm5, 0644, show_pwm, set_pwm, 4);
+static SENSOR_DEVICE_ATTR(pwm5_freq, 0444, show_pwm_freq, NULL, 4);
+static SENSOR_DEVICE_ATTR(pwm5_auto_channels_temp, 0444,
+			  show_pwm_temp_map, set_pwm_temp_map, 4);
+static SENSOR_DEVICE_ATTR_2(pwm5_auto_point1_temp, 0644,
+			    show_auto_temp, set_auto_temp, 2, 1);
+static SENSOR_DEVICE_ATTR_2(pwm5_auto_point1_temp_hyst, 0644,
+			    show_auto_temp, set_auto_temp, 2, 0);
+static SENSOR_DEVICE_ATTR_2(pwm5_auto_point2_temp, 0644,
+			    show_auto_temp, set_auto_temp, 2, 2);
+static SENSOR_DEVICE_ATTR_2(pwm5_auto_point3_temp, 0644,
+			    show_auto_temp, set_auto_temp, 2, 3);
+static SENSOR_DEVICE_ATTR_2(pwm5_auto_start, 0644,
+			    show_auto_pwm, set_auto_pwm, 4, 0);
+static SENSOR_DEVICE_ATTR(pwm5_auto_slope, 0644,
+			  show_auto_pwm_slope, set_auto_pwm_slope, 4);
+
+static SENSOR_DEVICE_ATTR(pwm6_enable, 0644,
+			  show_pwm_enable, set_pwm_enable, 5);
+static SENSOR_DEVICE_ATTR(pwm6, 0644, show_pwm, set_pwm, 5);
+static SENSOR_DEVICE_ATTR(pwm6_freq, 0444, show_pwm_freq, NULL, 5);
+static SENSOR_DEVICE_ATTR(pwm6_auto_channels_temp, 0444,
+			  show_pwm_temp_map, set_pwm_temp_map, 5);
+static SENSOR_DEVICE_ATTR_2(pwm6_auto_point1_temp, 0644,
+			    show_auto_temp, set_auto_temp, 2, 1);
+static SENSOR_DEVICE_ATTR_2(pwm6_auto_point1_temp_hyst, 0644,
+			    show_auto_temp, set_auto_temp, 2, 0);
+static SENSOR_DEVICE_ATTR_2(pwm6_auto_point2_temp, 0644,
+			    show_auto_temp, set_auto_temp, 2, 2);
+static SENSOR_DEVICE_ATTR_2(pwm6_auto_point3_temp, 0644,
+			    show_auto_temp, set_auto_temp, 2, 3);
+static SENSOR_DEVICE_ATTR_2(pwm6_auto_start, 0644,
+			    show_auto_pwm, set_auto_pwm, 5, 0);
+static SENSOR_DEVICE_ATTR(pwm6_auto_slope, 0644,
+			  show_auto_pwm_slope, set_auto_pwm_slope, 5);
 
 /* Alarms */
 static ssize_t show_alarms(struct device *dev, struct device_attribute *attr,
-		char *buf)
+			   char *buf)
 {
 	struct it87_data *data = it87_update_device(dev);
+
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
 	return sprintf(buf, "%u\n", data->alarms);
 }
-static DEVICE_ATTR(alarms, S_IRUGO, show_alarms, NULL);
+static DEVICE_ATTR(alarms, 0444, show_alarms, NULL);
 
 static ssize_t show_alarm(struct device *dev, struct device_attribute *attr,
-		char *buf)
+			  char *buf)
 {
-	int bitnr = to_sensor_dev_attr(attr)->index;
 	struct it87_data *data = it87_update_device(dev);
+	int bitnr = to_sensor_dev_attr(attr)->index;
+
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
 	return sprintf(buf, "%u\n", (data->alarms >> bitnr) & 1);
 }
 
-static ssize_t clear_intrusion(struct device *dev, struct device_attribute
-		*attr, const char *buf, size_t count)
+static ssize_t clear_intrusion(struct device *dev,
+			       struct device_attribute *attr, const char *buf,
+			       size_t count)
 {
 	struct it87_data *data = dev_get_drvdata(dev);
+	int err, config;
 	long val;
-	int config;
 
 	if (kstrtol(buf, 10, &val) < 0 || val != 0)
 		return -EINVAL;
 
-	mutex_lock(&data->update_lock);
-	config = it87_read_value(data, IT87_REG_CONFIG);
-	if (config < 0) {
-		count = config;
-	} else {
-		config |= 1 << 5;
-		it87_write_value(data, IT87_REG_CONFIG, config);
-		/* Invalidate cache to force re-read */
-		data->valid = 0;
-	}
-	mutex_unlock(&data->update_lock);
+	err = it87_lock(data);
+	if (err)
+		return err;
 
+	config = data->read(data, IT87_REG_CONFIG);
+	config |= BIT(5);
+	data->write(data, IT87_REG_CONFIG, config);
+	/* Invalidate cache to force re-read */
+	data->valid = 0;
+	it87_unlock(data);
 	return count;
 }
 
-static SENSOR_DEVICE_ATTR(in0_alarm, S_IRUGO, show_alarm, NULL, 8);
-static SENSOR_DEVICE_ATTR(in1_alarm, S_IRUGO, show_alarm, NULL, 9);
-static SENSOR_DEVICE_ATTR(in2_alarm, S_IRUGO, show_alarm, NULL, 10);
-static SENSOR_DEVICE_ATTR(in3_alarm, S_IRUGO, show_alarm, NULL, 11);
-static SENSOR_DEVICE_ATTR(in4_alarm, S_IRUGO, show_alarm, NULL, 12);
-static SENSOR_DEVICE_ATTR(in5_alarm, S_IRUGO, show_alarm, NULL, 13);
-static SENSOR_DEVICE_ATTR(in6_alarm, S_IRUGO, show_alarm, NULL, 14);
-static SENSOR_DEVICE_ATTR(in7_alarm, S_IRUGO, show_alarm, NULL, 15);
-static SENSOR_DEVICE_ATTR(fan1_alarm, S_IRUGO, show_alarm, NULL, 0);
-static SENSOR_DEVICE_ATTR(fan2_alarm, S_IRUGO, show_alarm, NULL, 1);
-static SENSOR_DEVICE_ATTR(fan3_alarm, S_IRUGO, show_alarm, NULL, 2);
-static SENSOR_DEVICE_ATTR(fan4_alarm, S_IRUGO, show_alarm, NULL, 3);
-static SENSOR_DEVICE_ATTR(fan5_alarm, S_IRUGO, show_alarm, NULL, 6);
-static SENSOR_DEVICE_ATTR(fan6_alarm, S_IRUGO, show_alarm, NULL, 7);
-static SENSOR_DEVICE_ATTR(temp1_alarm, S_IRUGO, show_alarm, NULL, 16);
-static SENSOR_DEVICE_ATTR(temp2_alarm, S_IRUGO, show_alarm, NULL, 17);
-static SENSOR_DEVICE_ATTR(temp3_alarm, S_IRUGO, show_alarm, NULL, 18);
-static SENSOR_DEVICE_ATTR(intrusion0_alarm, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR(in0_alarm, 0444, show_alarm, NULL, 8);
+static SENSOR_DEVICE_ATTR(in1_alarm, 0444, show_alarm, NULL, 9);
+static SENSOR_DEVICE_ATTR(in2_alarm, 0444, show_alarm, NULL, 10);
+static SENSOR_DEVICE_ATTR(in3_alarm, 0444, show_alarm, NULL, 11);
+static SENSOR_DEVICE_ATTR(in4_alarm, 0444, show_alarm, NULL, 12);
+static SENSOR_DEVICE_ATTR(in5_alarm, 0444, show_alarm, NULL, 13);
+static SENSOR_DEVICE_ATTR(in6_alarm, 0444, show_alarm, NULL, 14);
+static SENSOR_DEVICE_ATTR(in7_alarm, 0444, show_alarm, NULL, 15);
+static SENSOR_DEVICE_ATTR(fan1_alarm, 0444, show_alarm, NULL, 0);
+static SENSOR_DEVICE_ATTR(fan2_alarm, 0444, show_alarm, NULL, 1);
+static SENSOR_DEVICE_ATTR(fan3_alarm, 0444, show_alarm, NULL, 2);
+static SENSOR_DEVICE_ATTR(fan4_alarm, 0444, show_alarm, NULL, 3);
+static SENSOR_DEVICE_ATTR(fan5_alarm, 0444, show_alarm, NULL, 6);
+static SENSOR_DEVICE_ATTR(fan6_alarm, 0444, show_alarm, NULL, 7);
+static SENSOR_DEVICE_ATTR(temp1_alarm, 0444, show_alarm, NULL, 16);
+static SENSOR_DEVICE_ATTR(temp2_alarm, 0444, show_alarm, NULL, 17);
+static SENSOR_DEVICE_ATTR(temp3_alarm, 0444, show_alarm, NULL, 18);
+static SENSOR_DEVICE_ATTR(temp4_alarm, 0444, show_alarm, NULL, 19);
+static SENSOR_DEVICE_ATTR(temp5_alarm, 0444, show_alarm, NULL, 20);
+static SENSOR_DEVICE_ATTR(temp6_alarm, 0444, show_alarm, NULL, 21);
+static SENSOR_DEVICE_ATTR(intrusion0_alarm, 0644,
 			  show_alarm, clear_intrusion, 4);
 
 static ssize_t show_beep(struct device *dev, struct device_attribute *attr,
-		char *buf)
+			 char *buf)
 {
-	int bitnr = to_sensor_dev_attr(attr)->index;
 	struct it87_data *data = it87_update_device(dev);
+	int bitnr = to_sensor_dev_attr(attr)->index;
+
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
 	return sprintf(buf, "%u\n", (data->beeps >> bitnr) & 1);
 }
+
 static ssize_t set_beep(struct device *dev, struct device_attribute *attr,
-		const char *buf, size_t count)
+			const char *buf, size_t count)
 {
 	int bitnr = to_sensor_dev_attr(attr)->index;
 	struct it87_data *data = dev_get_drvdata(dev);
 	long val;
+	int err;
 
-	if (kstrtol(buf, 10, &val) < 0
-	 || (val != 0 && val != 1))
+	if (kstrtol(buf, 10, &val) < 0 || (val != 0 && val != 1))
 		return -EINVAL;
 
-	mutex_lock(&data->update_lock);
-	data->beeps = it87_read_value(data, IT87_REG_BEEP_ENABLE);
+	err = it87_lock(data);
+	if (err)
+		return err;
+
+	data->beeps = data->read(data, IT87_REG_BEEP_ENABLE);
 	if (val)
-		data->beeps |= (1 << bitnr);
+		data->beeps |= BIT(bitnr);
 	else
-		data->beeps &= ~(1 << bitnr);
-	it87_write_value(data, IT87_REG_BEEP_ENABLE, data->beeps);
-	mutex_unlock(&data->update_lock);
+		data->beeps &= ~BIT(bitnr);
+	data->write(data, IT87_REG_BEEP_ENABLE, data->beeps);
+	it87_unlock(data);
 	return count;
 }
 
-static SENSOR_DEVICE_ATTR(in0_beep, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR(in0_beep, 0644,
 			  show_beep, set_beep, 1);
-static SENSOR_DEVICE_ATTR(in1_beep, S_IRUGO, show_beep, NULL, 1);
-static SENSOR_DEVICE_ATTR(in2_beep, S_IRUGO, show_beep, NULL, 1);
-static SENSOR_DEVICE_ATTR(in3_beep, S_IRUGO, show_beep, NULL, 1);
-static SENSOR_DEVICE_ATTR(in4_beep, S_IRUGO, show_beep, NULL, 1);
-static SENSOR_DEVICE_ATTR(in5_beep, S_IRUGO, show_beep, NULL, 1);
-static SENSOR_DEVICE_ATTR(in6_beep, S_IRUGO, show_beep, NULL, 1);
-static SENSOR_DEVICE_ATTR(in7_beep, S_IRUGO, show_beep, NULL, 1);
+static SENSOR_DEVICE_ATTR(in1_beep, 0444, show_beep, NULL, 1);
+static SENSOR_DEVICE_ATTR(in2_beep, 0444, show_beep, NULL, 1);
+static SENSOR_DEVICE_ATTR(in3_beep, 0444, show_beep, NULL, 1);
+static SENSOR_DEVICE_ATTR(in4_beep, 0444, show_beep, NULL, 1);
+static SENSOR_DEVICE_ATTR(in5_beep, 0444, show_beep, NULL, 1);
+static SENSOR_DEVICE_ATTR(in6_beep, 0444, show_beep, NULL, 1);
+static SENSOR_DEVICE_ATTR(in7_beep, 0444, show_beep, NULL, 1);
 /* fanX_beep writability is set later */
-static SENSOR_DEVICE_ATTR(fan1_beep, S_IRUGO, show_beep, set_beep, 0);
-static SENSOR_DEVICE_ATTR(fan2_beep, S_IRUGO, show_beep, set_beep, 0);
-static SENSOR_DEVICE_ATTR(fan3_beep, S_IRUGO, show_beep, set_beep, 0);
-static SENSOR_DEVICE_ATTR(fan4_beep, S_IRUGO, show_beep, set_beep, 0);
-static SENSOR_DEVICE_ATTR(fan5_beep, S_IRUGO, show_beep, set_beep, 0);
-static SENSOR_DEVICE_ATTR(fan6_beep, S_IRUGO, show_beep, set_beep, 0);
-static SENSOR_DEVICE_ATTR(temp1_beep, S_IRUGO | S_IWUSR,
+static SENSOR_DEVICE_ATTR(fan1_beep, 0444, show_beep, set_beep, 0);
+static SENSOR_DEVICE_ATTR(fan2_beep, 0444, show_beep, set_beep, 0);
+static SENSOR_DEVICE_ATTR(fan3_beep, 0444, show_beep, set_beep, 0);
+static SENSOR_DEVICE_ATTR(fan4_beep, 0444, show_beep, set_beep, 0);
+static SENSOR_DEVICE_ATTR(fan5_beep, 0444, show_beep, set_beep, 0);
+static SENSOR_DEVICE_ATTR(fan6_beep, 0444, show_beep, set_beep, 0);
+static SENSOR_DEVICE_ATTR(temp1_beep, 0644,
 			  show_beep, set_beep, 2);
-static SENSOR_DEVICE_ATTR(temp2_beep, S_IRUGO, show_beep, NULL, 2);
-static SENSOR_DEVICE_ATTR(temp3_beep, S_IRUGO, show_beep, NULL, 2);
+static SENSOR_DEVICE_ATTR(temp2_beep, 0444, show_beep, NULL, 2);
+static SENSOR_DEVICE_ATTR(temp3_beep, 0444, show_beep, NULL, 2);
+static SENSOR_DEVICE_ATTR(temp4_beep, 0444, show_beep, NULL, 2);
+static SENSOR_DEVICE_ATTR(temp5_beep, 0444, show_beep, NULL, 2);
+static SENSOR_DEVICE_ATTR(temp6_beep, 0444, show_beep, NULL, 2);
 
 static ssize_t show_vrm_reg(struct device *dev, struct device_attribute *attr,
-		char *buf)
+			    char *buf)
 {
 	struct it87_data *data = dev_get_drvdata(dev);
+
 	return sprintf(buf, "%u\n", data->vrm);
 }
+
 static ssize_t store_vrm_reg(struct device *dev, struct device_attribute *attr,
-		const char *buf, size_t count)
+			     const char *buf, size_t count)
 {
 	struct it87_data *data = dev_get_drvdata(dev);
 	unsigned long val;
@@ -1511,264 +2510,423 @@ static ssize_t store_vrm_reg(struct device *dev, struct device_attribute *attr,
 
 	return count;
 }
-static DEVICE_ATTR(vrm, S_IRUGO | S_IWUSR, show_vrm_reg, store_vrm_reg);
+static DEVICE_ATTR(vrm, 0644, show_vrm_reg, store_vrm_reg);
 
 static ssize_t show_vid_reg(struct device *dev, struct device_attribute *attr,
-		char *buf)
+			    char *buf)
 {
 	struct it87_data *data = it87_update_device(dev);
-	return sprintf(buf, "%ld\n", (long) vid_from_reg(data->vid, data->vrm));
+
+	if (IS_ERR(data))
+		return PTR_ERR(data);
+
+	return sprintf(buf, "%ld\n", (long)vid_from_reg(data->vid, data->vrm));
 }
-static DEVICE_ATTR(cpu0_vid, S_IRUGO, show_vid_reg, NULL);
+static DEVICE_ATTR(cpu0_vid, 0444, show_vid_reg, NULL);
 
 static ssize_t show_label(struct device *dev, struct device_attribute *attr,
-		char *buf)
+			  char *buf)
 {
 	static const char * const labels[] = {
 		"+5V",
 		"5VSB",
 		"Vbat",
+		"AVCC",
 	};
 	static const char * const labels_it8721[] = {
 		"+3.3V",
 		"3VSB",
 		"Vbat",
+		"+3.3V",
 	};
 	struct it87_data *data = dev_get_drvdata(dev);
 	int nr = to_sensor_dev_attr(attr)->index;
 	const char *label;
 
-	if (has_12mv_adc(data) || has_10_9mv_adc(data))
+	if (has_vin3_5v(data) && nr == 0)
+		label = labels[0];
+	else if (has_12mv_adc(data) || has_10_9mv_adc(data) ||
+		 has_11mv_adc(data))
 		label = labels_it8721[nr];
 	else
 		label = labels[nr];
 
 	return sprintf(buf, "%s\n", label);
 }
-static SENSOR_DEVICE_ATTR(in3_label, S_IRUGO, show_label, NULL, 0);
-static SENSOR_DEVICE_ATTR(in7_label, S_IRUGO, show_label, NULL, 1);
-static SENSOR_DEVICE_ATTR(in8_label, S_IRUGO, show_label, NULL, 2);
-/* special AVCC3 IT8603E in9 */
-static SENSOR_DEVICE_ATTR(in9_label, S_IRUGO, show_label, NULL, 0);
-
-static ssize_t show_name(struct device *dev, struct device_attribute
-			 *devattr, char *buf)
+static SENSOR_DEVICE_ATTR(in3_label, 0444, show_label, NULL, 0);
+static SENSOR_DEVICE_ATTR(in7_label, 0444, show_label, NULL, 1);
+static SENSOR_DEVICE_ATTR(in8_label, 0444, show_label, NULL, 2);
+/* AVCC3 */
+static SENSOR_DEVICE_ATTR(in9_label, 0444, show_label, NULL, 3);
+
+static umode_t it87_in_is_visible(struct kobject *kobj,
+				  struct attribute *attr, int index)
 {
+	struct device *dev = container_of(kobj, struct device, kobj);
 	struct it87_data *data = dev_get_drvdata(dev);
-	return sprintf(buf, "%s\n", data->name);
+	int i = index / 5;	/* voltage index */
+	int a = index % 5;	/* attribute index */
+
+	if (index >= 40) {	/* in8 and higher only have input attributes */
+		i = index - 40 + 8;
+		a = 0;
+	}
+
+	if (!(data->has_in & BIT(i)))
+		return 0;
+
+	if (a == 4 && !data->has_beep)
+		return 0;
+
+	return attr->mode;
 }
-static DEVICE_ATTR(name, S_IRUGO, show_name, NULL);
 
-static struct attribute *it87_attributes_in[10][5] = {
-{
+static struct attribute *it87_attributes_in[] = {
 	&sensor_dev_attr_in0_input.dev_attr.attr,
 	&sensor_dev_attr_in0_min.dev_attr.attr,
 	&sensor_dev_attr_in0_max.dev_attr.attr,
 	&sensor_dev_attr_in0_alarm.dev_attr.attr,
-	NULL
-}, {
+	&sensor_dev_attr_in0_beep.dev_attr.attr,	/* 4 */
+
 	&sensor_dev_attr_in1_input.dev_attr.attr,
 	&sensor_dev_attr_in1_min.dev_attr.attr,
 	&sensor_dev_attr_in1_max.dev_attr.attr,
 	&sensor_dev_attr_in1_alarm.dev_attr.attr,
-	NULL
-}, {
+	&sensor_dev_attr_in1_beep.dev_attr.attr,	/* 9 */
+
 	&sensor_dev_attr_in2_input.dev_attr.attr,
 	&sensor_dev_attr_in2_min.dev_attr.attr,
 	&sensor_dev_attr_in2_max.dev_attr.attr,
 	&sensor_dev_attr_in2_alarm.dev_attr.attr,
-	NULL
-}, {
+	&sensor_dev_attr_in2_beep.dev_attr.attr,	/* 14 */
+
 	&sensor_dev_attr_in3_input.dev_attr.attr,
 	&sensor_dev_attr_in3_min.dev_attr.attr,
 	&sensor_dev_attr_in3_max.dev_attr.attr,
 	&sensor_dev_attr_in3_alarm.dev_attr.attr,
-	NULL
-}, {
+	&sensor_dev_attr_in3_beep.dev_attr.attr,	/* 19 */
+
 	&sensor_dev_attr_in4_input.dev_attr.attr,
 	&sensor_dev_attr_in4_min.dev_attr.attr,
 	&sensor_dev_attr_in4_max.dev_attr.attr,
 	&sensor_dev_attr_in4_alarm.dev_attr.attr,
-	NULL
-}, {
+	&sensor_dev_attr_in4_beep.dev_attr.attr,	/* 24 */
+
 	&sensor_dev_attr_in5_input.dev_attr.attr,
 	&sensor_dev_attr_in5_min.dev_attr.attr,
 	&sensor_dev_attr_in5_max.dev_attr.attr,
 	&sensor_dev_attr_in5_alarm.dev_attr.attr,
-	NULL
-}, {
+	&sensor_dev_attr_in5_beep.dev_attr.attr,	/* 29 */
+
 	&sensor_dev_attr_in6_input.dev_attr.attr,
 	&sensor_dev_attr_in6_min.dev_attr.attr,
 	&sensor_dev_attr_in6_max.dev_attr.attr,
 	&sensor_dev_attr_in6_alarm.dev_attr.attr,
-	NULL
-}, {
+	&sensor_dev_attr_in6_beep.dev_attr.attr,	/* 34 */
+
 	&sensor_dev_attr_in7_input.dev_attr.attr,
 	&sensor_dev_attr_in7_min.dev_attr.attr,
 	&sensor_dev_attr_in7_max.dev_attr.attr,
 	&sensor_dev_attr_in7_alarm.dev_attr.attr,
+	&sensor_dev_attr_in7_beep.dev_attr.attr,	/* 39 */
+
+	&sensor_dev_attr_in8_input.dev_attr.attr,	/* 40 */
+	&sensor_dev_attr_in9_input.dev_attr.attr,	/* 41 */
+	&sensor_dev_attr_in10_input.dev_attr.attr,	/* 42 */
+	&sensor_dev_attr_in11_input.dev_attr.attr,	/* 43 */
+	&sensor_dev_attr_in12_input.dev_attr.attr,	/* 44 */
 	NULL
-}, {
-	&sensor_dev_attr_in8_input.dev_attr.attr,
-	NULL
-}, {
-	&sensor_dev_attr_in9_input.dev_attr.attr,
-	NULL
-} };
-
-static const struct attribute_group it87_group_in[10] = {
-	{ .attrs = it87_attributes_in[0] },
-	{ .attrs = it87_attributes_in[1] },
-	{ .attrs = it87_attributes_in[2] },
-	{ .attrs = it87_attributes_in[3] },
-	{ .attrs = it87_attributes_in[4] },
-	{ .attrs = it87_attributes_in[5] },
-	{ .attrs = it87_attributes_in[6] },
-	{ .attrs = it87_attributes_in[7] },
-	{ .attrs = it87_attributes_in[8] },
-	{ .attrs = it87_attributes_in[9] },
 };
 
-static struct attribute *it87_attributes_temp[3][6] = {
+static const struct attribute_group it87_group_in = {
+	.attrs = it87_attributes_in,
+	.is_visible = it87_in_is_visible,
+};
+
+static umode_t it87_temp_is_visible(struct kobject *kobj,
+				    struct attribute *attr, int index)
 {
+	struct device *dev = container_of(kobj, struct device, kobj);
+	struct it87_data *data = dev_get_drvdata(dev);
+	int i = index / 7;	/* temperature index */
+	int a = index % 7;	/* attribute index */
+
+	if (!(data->has_temp & BIT(i)))
+		return 0;
+
+	if (a && i >= data->num_temp_limit)
+		return 0;
+
+	if (a == 3) {
+		int type = get_temp_type(data, i);
+
+		if (type == 0)
+			return 0;
+		if (has_bank_sel(data))
+			return 0444;
+		return attr->mode;
+	}
+
+	if (a == 5 && i >= data->num_temp_offset)
+		return 0;
+
+	if (a == 6 && !data->has_beep)
+		return 0;
+
+	return attr->mode;
+}
+
+static struct attribute *it87_attributes_temp[] = {
 	&sensor_dev_attr_temp1_input.dev_attr.attr,
 	&sensor_dev_attr_temp1_max.dev_attr.attr,
 	&sensor_dev_attr_temp1_min.dev_attr.attr,
-	&sensor_dev_attr_temp1_type.dev_attr.attr,
+	&sensor_dev_attr_temp1_type.dev_attr.attr,	/* 3 */
 	&sensor_dev_attr_temp1_alarm.dev_attr.attr,
-	NULL
-} , {
-	&sensor_dev_attr_temp2_input.dev_attr.attr,
+	&sensor_dev_attr_temp1_offset.dev_attr.attr,	/* 5 */
+	&sensor_dev_attr_temp1_beep.dev_attr.attr,	/* 6 */
+
+	&sensor_dev_attr_temp2_input.dev_attr.attr,	/* 7 */
 	&sensor_dev_attr_temp2_max.dev_attr.attr,
 	&sensor_dev_attr_temp2_min.dev_attr.attr,
 	&sensor_dev_attr_temp2_type.dev_attr.attr,
 	&sensor_dev_attr_temp2_alarm.dev_attr.attr,
-	NULL
-} , {
-	&sensor_dev_attr_temp3_input.dev_attr.attr,
+	&sensor_dev_attr_temp2_offset.dev_attr.attr,
+	&sensor_dev_attr_temp2_beep.dev_attr.attr,
+
+	&sensor_dev_attr_temp3_input.dev_attr.attr,	/* 14 */
 	&sensor_dev_attr_temp3_max.dev_attr.attr,
 	&sensor_dev_attr_temp3_min.dev_attr.attr,
 	&sensor_dev_attr_temp3_type.dev_attr.attr,
 	&sensor_dev_attr_temp3_alarm.dev_attr.attr,
-	NULL
-} };
+	&sensor_dev_attr_temp3_offset.dev_attr.attr,
+	&sensor_dev_attr_temp3_beep.dev_attr.attr,
 
-static const struct attribute_group it87_group_temp[3] = {
-	{ .attrs = it87_attributes_temp[0] },
-	{ .attrs = it87_attributes_temp[1] },
-	{ .attrs = it87_attributes_temp[2] },
+	&sensor_dev_attr_temp4_input.dev_attr.attr,	/* 21 */
+	&sensor_dev_attr_temp4_max.dev_attr.attr,
+	&sensor_dev_attr_temp4_min.dev_attr.attr,
+	&sensor_dev_attr_temp4_type.dev_attr.attr,
+	&sensor_dev_attr_temp4_alarm.dev_attr.attr,
+	&sensor_dev_attr_temp4_offset.dev_attr.attr,
+	&sensor_dev_attr_temp4_beep.dev_attr.attr,
+
+	&sensor_dev_attr_temp5_input.dev_attr.attr,
+	&sensor_dev_attr_temp5_max.dev_attr.attr,
+	&sensor_dev_attr_temp5_min.dev_attr.attr,
+	&sensor_dev_attr_temp5_type.dev_attr.attr,
+	&sensor_dev_attr_temp5_alarm.dev_attr.attr,
+	&sensor_dev_attr_temp5_offset.dev_attr.attr,
+	&sensor_dev_attr_temp5_beep.dev_attr.attr,
+
+	&sensor_dev_attr_temp6_input.dev_attr.attr,
+	&sensor_dev_attr_temp6_max.dev_attr.attr,
+	&sensor_dev_attr_temp6_min.dev_attr.attr,
+	&sensor_dev_attr_temp6_type.dev_attr.attr,
+	&sensor_dev_attr_temp6_alarm.dev_attr.attr,
+	&sensor_dev_attr_temp6_offset.dev_attr.attr,
+	&sensor_dev_attr_temp6_beep.dev_attr.attr,
+	NULL
 };
 
-static struct attribute *it87_attributes_temp_offset[] = {
-	&sensor_dev_attr_temp1_offset.dev_attr.attr,
-	&sensor_dev_attr_temp2_offset.dev_attr.attr,
-	&sensor_dev_attr_temp3_offset.dev_attr.attr,
+static const struct attribute_group it87_group_temp = {
+	.attrs = it87_attributes_temp,
+	.is_visible = it87_temp_is_visible,
 };
 
+static umode_t it87_is_visible(struct kobject *kobj,
+			       struct attribute *attr, int index)
+{
+	struct device *dev = container_of(kobj, struct device, kobj);
+	struct it87_data *data = dev_get_drvdata(dev);
+
+	if ((index == 2 || index == 3) && !data->has_vid)
+		return 0;
+
+	if (index > 3 && !(data->in_internal & BIT(index - 4)))
+		return 0;
+
+	return attr->mode;
+}
+
 static struct attribute *it87_attributes[] = {
 	&dev_attr_alarms.attr,
 	&sensor_dev_attr_intrusion0_alarm.dev_attr.attr,
-	&dev_attr_name.attr,
+	&dev_attr_vrm.attr,				/* 2 */
+	&dev_attr_cpu0_vid.attr,			/* 3 */
+	&sensor_dev_attr_in3_label.dev_attr.attr,	/* 4 .. 7 */
+	&sensor_dev_attr_in7_label.dev_attr.attr,
+	&sensor_dev_attr_in8_label.dev_attr.attr,
+	&sensor_dev_attr_in9_label.dev_attr.attr,
 	NULL
 };
 
 static const struct attribute_group it87_group = {
 	.attrs = it87_attributes,
+	.is_visible = it87_is_visible,
 };
 
-static struct attribute *it87_attributes_in_beep[] = {
-	&sensor_dev_attr_in0_beep.dev_attr.attr,
-	&sensor_dev_attr_in1_beep.dev_attr.attr,
-	&sensor_dev_attr_in2_beep.dev_attr.attr,
-	&sensor_dev_attr_in3_beep.dev_attr.attr,
-	&sensor_dev_attr_in4_beep.dev_attr.attr,
-	&sensor_dev_attr_in5_beep.dev_attr.attr,
-	&sensor_dev_attr_in6_beep.dev_attr.attr,
-	&sensor_dev_attr_in7_beep.dev_attr.attr,
-	NULL,
-	NULL,
-};
+static umode_t it87_fan_is_visible(struct kobject *kobj,
+				   struct attribute *attr, int index)
+{
+	struct device *dev = container_of(kobj, struct device, kobj);
+	struct it87_data *data = dev_get_drvdata(dev);
+	int i = index / 5;	/* fan index */
+	int a = index % 5;	/* attribute index */
 
-static struct attribute *it87_attributes_temp_beep[] = {
-	&sensor_dev_attr_temp1_beep.dev_attr.attr,
-	&sensor_dev_attr_temp2_beep.dev_attr.attr,
-	&sensor_dev_attr_temp3_beep.dev_attr.attr,
-};
+	if (index >= 15) {	/* fan 4..6 don't have divisor attributes */
+		i = (index - 15) / 4 + 3;
+		a = (index - 15) % 4;
+	}
+
+	if (!(data->has_fan & BIT(i)))
+		return 0;
+
+	if (a == 3) {				/* beep */
+		if (!data->has_beep)
+			return 0;
+		/* first fan beep attribute is writable */
+		if (i == __ffs(data->has_fan))
+			return attr->mode | 0200;
+	}
 
-static struct attribute *it87_attributes_fan[6][3+1] = { {
+	if (a == 4 && has_16bit_fans(data))	/* divisor */
+		return 0;
+
+	return attr->mode;
+}
+
+static struct attribute *it87_attributes_fan[] = {
 	&sensor_dev_attr_fan1_input.dev_attr.attr,
 	&sensor_dev_attr_fan1_min.dev_attr.attr,
 	&sensor_dev_attr_fan1_alarm.dev_attr.attr,
-	NULL
-}, {
+	&sensor_dev_attr_fan1_beep.dev_attr.attr,	/* 3 */
+	&sensor_dev_attr_fan1_div.dev_attr.attr,	/* 4 */
+
 	&sensor_dev_attr_fan2_input.dev_attr.attr,
 	&sensor_dev_attr_fan2_min.dev_attr.attr,
 	&sensor_dev_attr_fan2_alarm.dev_attr.attr,
-	NULL
-}, {
+	&sensor_dev_attr_fan2_beep.dev_attr.attr,
+	&sensor_dev_attr_fan2_div.dev_attr.attr,	/* 9 */
+
 	&sensor_dev_attr_fan3_input.dev_attr.attr,
 	&sensor_dev_attr_fan3_min.dev_attr.attr,
 	&sensor_dev_attr_fan3_alarm.dev_attr.attr,
-	NULL
-}, {
-	&sensor_dev_attr_fan4_input.dev_attr.attr,
+	&sensor_dev_attr_fan3_beep.dev_attr.attr,
+	&sensor_dev_attr_fan3_div.dev_attr.attr,	/* 14 */
+
+	&sensor_dev_attr_fan4_input.dev_attr.attr,	/* 15 */
 	&sensor_dev_attr_fan4_min.dev_attr.attr,
 	&sensor_dev_attr_fan4_alarm.dev_attr.attr,
-	NULL
-}, {
-	&sensor_dev_attr_fan5_input.dev_attr.attr,
+	&sensor_dev_attr_fan4_beep.dev_attr.attr,
+
+	&sensor_dev_attr_fan5_input.dev_attr.attr,	/* 19 */
 	&sensor_dev_attr_fan5_min.dev_attr.attr,
 	&sensor_dev_attr_fan5_alarm.dev_attr.attr,
-	NULL
-}, {
-	&sensor_dev_attr_fan6_input.dev_attr.attr,
+	&sensor_dev_attr_fan5_beep.dev_attr.attr,
+
+	&sensor_dev_attr_fan6_input.dev_attr.attr,	/* 23 */
 	&sensor_dev_attr_fan6_min.dev_attr.attr,
 	&sensor_dev_attr_fan6_alarm.dev_attr.attr,
+	&sensor_dev_attr_fan6_beep.dev_attr.attr,
 	NULL
-} };
-
-static const struct attribute_group it87_group_fan[6] = {
-	{ .attrs = it87_attributes_fan[0] },
-	{ .attrs = it87_attributes_fan[1] },
-	{ .attrs = it87_attributes_fan[2] },
-	{ .attrs = it87_attributes_fan[3] },
-	{ .attrs = it87_attributes_fan[4] },
-	{ .attrs = it87_attributes_fan[5] },
 };
 
-static const struct attribute *it87_attributes_fan_div[] = {
-	&sensor_dev_attr_fan1_div.dev_attr.attr,
-	&sensor_dev_attr_fan2_div.dev_attr.attr,
-	&sensor_dev_attr_fan3_div.dev_attr.attr,
+static const struct attribute_group it87_group_fan = {
+	.attrs = it87_attributes_fan,
+	.is_visible = it87_fan_is_visible,
 };
 
-static struct attribute *it87_attributes_pwm[3][4+1] = { {
+static umode_t it87_pwm_is_visible(struct kobject *kobj,
+				   struct attribute *attr, int index)
+{
+	struct device *dev = container_of(kobj, struct device, kobj);
+	struct it87_data *data = dev_get_drvdata(dev);
+	int i = index / 4;	/* pwm index */
+	int a = index % 4;	/* attribute index */
+
+	if (!(data->has_pwm & BIT(i)))
+		return 0;
+
+	/* pwmX_auto_channels_temp is only writable if auto pwm is supported */
+	if (a == 3 && (has_old_autopwm(data) || has_newer_autopwm(data)))
+		return attr->mode | 0200;
+
+	/* pwm2_freq is writable if there are two pwm frequency selects */
+	if (has_pwm_freq2(data) && i == 1 && a == 2)
+		return attr->mode | 0200;
+
+	return attr->mode;
+}
+
+static struct attribute *it87_attributes_pwm[] = {
 	&sensor_dev_attr_pwm1_enable.dev_attr.attr,
 	&sensor_dev_attr_pwm1.dev_attr.attr,
-	&dev_attr_pwm1_freq.attr,
+	&sensor_dev_attr_pwm1_freq.dev_attr.attr,
 	&sensor_dev_attr_pwm1_auto_channels_temp.dev_attr.attr,
-	NULL
-}, {
+
 	&sensor_dev_attr_pwm2_enable.dev_attr.attr,
 	&sensor_dev_attr_pwm2.dev_attr.attr,
-	&dev_attr_pwm2_freq.attr,
+	&sensor_dev_attr_pwm2_freq.dev_attr.attr,
 	&sensor_dev_attr_pwm2_auto_channels_temp.dev_attr.attr,
-	NULL
-}, {
+
 	&sensor_dev_attr_pwm3_enable.dev_attr.attr,
 	&sensor_dev_attr_pwm3.dev_attr.attr,
-	&dev_attr_pwm3_freq.attr,
+	&sensor_dev_attr_pwm3_freq.dev_attr.attr,
 	&sensor_dev_attr_pwm3_auto_channels_temp.dev_attr.attr,
+
+	&sensor_dev_attr_pwm4_enable.dev_attr.attr,
+	&sensor_dev_attr_pwm4.dev_attr.attr,
+	&sensor_dev_attr_pwm4_freq.dev_attr.attr,
+	&sensor_dev_attr_pwm4_auto_channels_temp.dev_attr.attr,
+
+	&sensor_dev_attr_pwm5_enable.dev_attr.attr,
+	&sensor_dev_attr_pwm5.dev_attr.attr,
+	&sensor_dev_attr_pwm5_freq.dev_attr.attr,
+	&sensor_dev_attr_pwm5_auto_channels_temp.dev_attr.attr,
+
+	&sensor_dev_attr_pwm6_enable.dev_attr.attr,
+	&sensor_dev_attr_pwm6.dev_attr.attr,
+	&sensor_dev_attr_pwm6_freq.dev_attr.attr,
+	&sensor_dev_attr_pwm6_auto_channels_temp.dev_attr.attr,
+
 	NULL
-} };
+};
 
-static const struct attribute_group it87_group_pwm[3] = {
-	{ .attrs = it87_attributes_pwm[0] },
-	{ .attrs = it87_attributes_pwm[1] },
-	{ .attrs = it87_attributes_pwm[2] },
+static const struct attribute_group it87_group_pwm = {
+	.attrs = it87_attributes_pwm,
+	.is_visible = it87_pwm_is_visible,
 };
 
-static struct attribute *it87_attributes_autopwm[3][9+1] = { {
+static umode_t it87_auto_pwm_is_visible(struct kobject *kobj,
+					struct attribute *attr, int index)
+{
+	struct device *dev = container_of(kobj, struct device, kobj);
+	struct it87_data *data = dev_get_drvdata(dev);
+	int i = index / 11;	/* pwm index */
+	int a = index % 11;	/* attribute index */
+
+	if (index >= 33) {	/* pwm 4..6 */
+		i = (index - 33) / 6 + 3;
+		a = (index - 33) % 6 + 4;
+	}
+
+	if (!(data->has_pwm & BIT(i)))
+		return 0;
+
+	if (has_newer_autopwm(data)) {
+		if (a < 4)	/* no auto point pwm */
+			return 0;
+		if (a == 8)	/* no auto_point4 */
+			return 0;
+	}
+	if (has_old_autopwm(data)) {
+		if (a >= 9)	/* no pwm_auto_start, pwm_auto_slope */
+			return 0;
+	}
+
+	return attr->mode;
+}
+
+static struct attribute *it87_attributes_auto_pwm[] = {
 	&sensor_dev_attr_pwm1_auto_point1_pwm.dev_attr.attr,
 	&sensor_dev_attr_pwm1_auto_point2_pwm.dev_attr.attr,
 	&sensor_dev_attr_pwm1_auto_point3_pwm.dev_attr.attr,
@@ -1778,9 +2936,10 @@ static struct attribute *it87_attributes_autopwm[3][9+1] = { {
 	&sensor_dev_attr_pwm1_auto_point2_temp.dev_attr.attr,
 	&sensor_dev_attr_pwm1_auto_point3_temp.dev_attr.attr,
 	&sensor_dev_attr_pwm1_auto_point4_temp.dev_attr.attr,
-	NULL
-}, {
-	&sensor_dev_attr_pwm2_auto_point1_pwm.dev_attr.attr,
+	&sensor_dev_attr_pwm1_auto_start.dev_attr.attr,
+	&sensor_dev_attr_pwm1_auto_slope.dev_attr.attr,
+
+	&sensor_dev_attr_pwm2_auto_point1_pwm.dev_attr.attr,	/* 11 */
 	&sensor_dev_attr_pwm2_auto_point2_pwm.dev_attr.attr,
 	&sensor_dev_attr_pwm2_auto_point3_pwm.dev_attr.attr,
 	&sensor_dev_attr_pwm2_auto_point4_pwm.dev_attr.attr,
@@ -1789,9 +2948,10 @@ static struct attribute *it87_attributes_autopwm[3][9+1] = { {
 	&sensor_dev_attr_pwm2_auto_point2_temp.dev_attr.attr,
 	&sensor_dev_attr_pwm2_auto_point3_temp.dev_attr.attr,
 	&sensor_dev_attr_pwm2_auto_point4_temp.dev_attr.attr,
-	NULL
-}, {
-	&sensor_dev_attr_pwm3_auto_point1_pwm.dev_attr.attr,
+	&sensor_dev_attr_pwm2_auto_start.dev_attr.attr,
+	&sensor_dev_attr_pwm2_auto_slope.dev_attr.attr,
+
+	&sensor_dev_attr_pwm3_auto_point1_pwm.dev_attr.attr,	/* 22 */
 	&sensor_dev_attr_pwm3_auto_point2_pwm.dev_attr.attr,
 	&sensor_dev_attr_pwm3_auto_point3_pwm.dev_attr.attr,
 	&sensor_dev_attr_pwm3_auto_point4_pwm.dev_attr.attr,
@@ -1800,61 +2960,63 @@ static struct attribute *it87_attributes_autopwm[3][9+1] = { {
 	&sensor_dev_attr_pwm3_auto_point2_temp.dev_attr.attr,
 	&sensor_dev_attr_pwm3_auto_point3_temp.dev_attr.attr,
 	&sensor_dev_attr_pwm3_auto_point4_temp.dev_attr.attr,
-	NULL
-} };
-
-static const struct attribute_group it87_group_autopwm[3] = {
-	{ .attrs = it87_attributes_autopwm[0] },
-	{ .attrs = it87_attributes_autopwm[1] },
-	{ .attrs = it87_attributes_autopwm[2] },
-};
-
-static struct attribute *it87_attributes_fan_beep[] = {
-	&sensor_dev_attr_fan1_beep.dev_attr.attr,
-	&sensor_dev_attr_fan2_beep.dev_attr.attr,
-	&sensor_dev_attr_fan3_beep.dev_attr.attr,
-	&sensor_dev_attr_fan4_beep.dev_attr.attr,
-	&sensor_dev_attr_fan5_beep.dev_attr.attr,
-	&sensor_dev_attr_fan6_beep.dev_attr.attr,
-};
-
-static struct attribute *it87_attributes_vid[] = {
-	&dev_attr_vrm.attr,
-	&dev_attr_cpu0_vid.attr,
-	NULL
-};
+	&sensor_dev_attr_pwm3_auto_start.dev_attr.attr,
+	&sensor_dev_attr_pwm3_auto_slope.dev_attr.attr,
+
+	&sensor_dev_attr_pwm4_auto_point1_temp.dev_attr.attr,	/* 33 */
+	&sensor_dev_attr_pwm4_auto_point1_temp_hyst.dev_attr.attr,
+	&sensor_dev_attr_pwm4_auto_point2_temp.dev_attr.attr,
+	&sensor_dev_attr_pwm4_auto_point3_temp.dev_attr.attr,
+	&sensor_dev_attr_pwm4_auto_start.dev_attr.attr,
+	&sensor_dev_attr_pwm4_auto_slope.dev_attr.attr,
+
+	&sensor_dev_attr_pwm5_auto_point1_temp.dev_attr.attr,
+	&sensor_dev_attr_pwm5_auto_point1_temp_hyst.dev_attr.attr,
+	&sensor_dev_attr_pwm5_auto_point2_temp.dev_attr.attr,
+	&sensor_dev_attr_pwm5_auto_point3_temp.dev_attr.attr,
+	&sensor_dev_attr_pwm5_auto_start.dev_attr.attr,
+	&sensor_dev_attr_pwm5_auto_slope.dev_attr.attr,
+
+	&sensor_dev_attr_pwm6_auto_point1_temp.dev_attr.attr,
+	&sensor_dev_attr_pwm6_auto_point1_temp_hyst.dev_attr.attr,
+	&sensor_dev_attr_pwm6_auto_point2_temp.dev_attr.attr,
+	&sensor_dev_attr_pwm6_auto_point3_temp.dev_attr.attr,
+	&sensor_dev_attr_pwm6_auto_start.dev_attr.attr,
+	&sensor_dev_attr_pwm6_auto_slope.dev_attr.attr,
 
-static const struct attribute_group it87_group_vid = {
-	.attrs = it87_attributes_vid,
-};
-
-static struct attribute *it87_attributes_label[] = {
-	&sensor_dev_attr_in3_label.dev_attr.attr,
-	&sensor_dev_attr_in7_label.dev_attr.attr,
-	&sensor_dev_attr_in8_label.dev_attr.attr,
-	&sensor_dev_attr_in9_label.dev_attr.attr,
-	NULL
+	NULL,
 };
 
-static const struct attribute_group it87_group_label = {
-	.attrs = it87_attributes_label,
+static const struct attribute_group it87_group_auto_pwm = {
+	.attrs = it87_attributes_auto_pwm,
+	.is_visible = it87_auto_pwm_is_visible,
 };
 
 /* SuperIO detection - will change isa_address if a chip is found */
-static int __init it87_find(unsigned short *address,
-	struct it87_sio_data *sio_data)
+static int __init it87_find(int sioaddr, unsigned short *address,
+			    phys_addr_t *mmio_address,
+			    struct it87_sio_data *sio_data)
 {
-	int err;
-	u16 chip_type;
-	const char *board_vendor, *board_name;
 	const struct it87_devices *config;
+	phys_addr_t base = 0;
+	bool doexit = true;
+	char mmio_str[32];
+	u16 chip_type;
+	int err;
 
-	err = superio_enter();
+	err = superio_enter(sioaddr);
 	if (err)
 		return err;
 
+	sio_data->sioaddr = sioaddr;
+
 	err = -ENODEV;
-	chip_type = force_id ? force_id : superio_inw(DEVID);
+	chip_type = superio_inw(sioaddr, DEVID);
+	if (chip_type == 0xffff)
+		goto exit;
+
+	if (force_id)
+		chip_type = force_id;
 
 	switch (chip_type) {
 	case IT8705F_DEVID:
@@ -1882,6 +3044,22 @@ static int __init it87_find(unsigned short *address,
 	case IT8732F_DEVID:
 		sio_data->type = it8732;
 		break;
+	case IT8736F_DEVID:
+		sio_data->type = it8736;
+		break;
+	case IT8738E_DEVID:
+		sio_data->type = it8738;
+		break;
+	case IT8792E_DEVID:
+		sio_data->type = it8792;
+		/*
+		 * Disabling configuration mode on IT8792E can result in system
+		 * hang-ups and access failures to the Super-IO chip at the
+		 * second SIO address. Never exit configuration mode on this
+		 * chip to avoid the problem.
+		 */
+		doexit = false;
+		break;
 	case IT8771E_DEVID:
 		sio_data->type = it8771;
 		break;
@@ -1902,14 +3080,42 @@ static int __init it87_find(unsigned short *address,
 		break;
 	case IT8790E_DEVID:
 		sio_data->type = it8790;
+		doexit = false;		/* See IT8792E comment above */
 		break;
 	case IT8603E_DEVID:
 	case IT8623E_DEVID:
 		sio_data->type = it8603;
 		break;
+	case IT8606E_DEVID:
+		sio_data->type = it8606;
+		break;
+	case IT8607E_DEVID:
+		sio_data->type = it8607;
+		break;
+	case IT8613E_DEVID:
+		sio_data->type = it8613;
+		break;
 	case IT8620E_DEVID:
 		sio_data->type = it8620;
 		break;
+	case IT8622E_DEVID:
+		sio_data->type = it8622;
+		break;
+	case IT8625E_DEVID:
+		sio_data->type = it8625;
+		break;
+	case IT8628E_DEVID:
+		sio_data->type = it8628;
+		break;
+	case IT8655E_DEVID:
+		sio_data->type = it8655;
+		break;
+	case IT8665E_DEVID:
+		sio_data->type = it8665;
+		break;
+	case IT8686E_DEVID:
+		sio_data->type = it8686;
+		break;
 	case 0xffff:	/* No device at all */
 		goto exit;
 	default:
@@ -1917,36 +3123,63 @@ static int __init it87_find(unsigned short *address,
 		goto exit;
 	}
 
-	superio_select(PME);
-	if (!(superio_inb(IT87_ACT_REG) & 0x01)) {
+	superio_select(sioaddr, PME);
+	if (!(superio_inb(sioaddr, IT87_ACT_REG) & 0x01)) {
 		pr_info("Device not activated, skipping\n");
 		goto exit;
 	}
 
-	*address = superio_inw(IT87_BASE_REG) & ~(IT87_EXTENT - 1);
+	*address = superio_inw(sioaddr, IT87_BASE_REG) & ~(IT87_EXTENT - 1);
 	if (*address == 0) {
 		pr_info("Base address not set, skipping\n");
 		goto exit;
 	}
 
+	sio_data->doexit = doexit;
+
 	err = 0;
-	sio_data->revision = superio_inb(DEVREV) & 0x0f;
-	pr_info("Found IT%04x%s chip at 0x%x, revision %d\n", chip_type,
-		it87_devices[sio_data->type].suffix,
-		*address, sio_data->revision);
+	sio_data->revision = superio_inb(sioaddr, DEVREV) & 0x0f;
 
 	config = &it87_devices[sio_data->type];
 
+	if (has_mmio(config) && mmio) {
+		u8 reg;
+
+		reg = superio_inb(sioaddr, IT87_EC_HWM_MIO_REG);
+		if (reg & BIT(5)) {
+			base = 0xf0000000 + ((reg & 0x0f) << 24);
+			base += (reg & 0xc0) << 14;
+		}
+	}
+	*mmio_address = base;
+
+	mmio_str[0] = '\0';
+	if (base)
+		snprintf(mmio_str, sizeof(mmio_str), " [MMIO at %pa]", &base);
+
+	pr_info("Found %s chip at 0x%x%s, revision %d\n",
+		it87_devices[sio_data->type].model,
+		*address, mmio_str, sio_data->revision);
+
 	/* in7 (VSB or VCCH5V) is always internal on some chips */
 	if (has_in7_internal(config))
-		sio_data->internal |= (1 << 1);
+		sio_data->internal |= BIT(1);
 
 	/* in8 (Vbat) is always internal */
-	sio_data->internal |= (1 << 2);
+	sio_data->internal |= BIT(2);
+
+	/* in9 (AVCC3), always internal if supported */
+	if (has_avcc3(config))
+		sio_data->internal |= BIT(3); /* in9 is AVCC */
+	else
+		sio_data->skip_in |= BIT(9);
 
-	/* Only the IT8603E has in9 */
-	if (sio_data->type != it8603)
-		sio_data->skip_in |= (1 << 9);
+	if (!has_four_pwm(config))
+		sio_data->skip_pwm |= BIT(3) | BIT(4) | BIT(5);
+	else if (!has_five_pwm(config))
+		sio_data->skip_pwm |= BIT(4) | BIT(5);
+	else if (!has_six_pwm(config))
+		sio_data->skip_pwm |= BIT(5);
 
 	if (!has_vid(config))
 		sio_data->skip_vid = 1;
@@ -1954,45 +3187,46 @@ static int __init it87_find(unsigned short *address,
 	/* Read GPIO config and VID value from LDN 7 (GPIO) */
 	if (sio_data->type == it87) {
 		/* The IT8705F has a different LD number for GPIO */
-		superio_select(5);
-		sio_data->beep_pin = superio_inb(IT87_SIO_BEEP_PIN_REG) & 0x3f;
+		superio_select(sioaddr, 5);
+		sio_data->beep_pin = superio_inb(sioaddr,
+						 IT87_SIO_BEEP_PIN_REG) & 0x3f;
 	} else if (sio_data->type == it8783) {
 		int reg25, reg27, reg2a, reg2c, regef;
 
-		superio_select(GPIO);
+		superio_select(sioaddr, GPIO);
 
-		reg25 = superio_inb(IT87_SIO_GPIO1_REG);
-		reg27 = superio_inb(IT87_SIO_GPIO3_REG);
-		reg2a = superio_inb(IT87_SIO_PINX1_REG);
-		reg2c = superio_inb(IT87_SIO_PINX2_REG);
-		regef = superio_inb(IT87_SIO_SPI_REG);
+		reg25 = superio_inb(sioaddr, IT87_SIO_GPIO1_REG);
+		reg27 = superio_inb(sioaddr, IT87_SIO_GPIO3_REG);
+		reg2a = superio_inb(sioaddr, IT87_SIO_PINX1_REG);
+		reg2c = superio_inb(sioaddr, IT87_SIO_PINX2_REG);
+		regef = superio_inb(sioaddr, IT87_SIO_SPI_REG);
 
 		/* Check if fan3 is there or not */
-		if ((reg27 & (1 << 0)) || !(reg2c & (1 << 2)))
-			sio_data->skip_fan |= (1 << 2);
-		if ((reg25 & (1 << 4))
-		    || (!(reg2a & (1 << 1)) && (regef & (1 << 0))))
-			sio_data->skip_pwm |= (1 << 2);
+		if ((reg27 & BIT(0)) || !(reg2c & BIT(2)))
+			sio_data->skip_fan |= BIT(2);
+		if ((reg25 & BIT(4)) ||
+		    (!(reg2a & BIT(1)) && (regef & BIT(0))))
+			sio_data->skip_pwm |= BIT(2);
 
 		/* Check if fan2 is there or not */
-		if (reg27 & (1 << 7))
-			sio_data->skip_fan |= (1 << 1);
-		if (reg27 & (1 << 3))
-			sio_data->skip_pwm |= (1 << 1);
+		if (reg27 & BIT(7))
+			sio_data->skip_fan |= BIT(1);
+		if (reg27 & BIT(3))
+			sio_data->skip_pwm |= BIT(1);
 
 		/* VIN5 */
-		if ((reg27 & (1 << 0)) || (reg2c & (1 << 2)))
-			sio_data->skip_in |= (1 << 5); /* No VIN5 */
+		if ((reg27 & BIT(0)) || (reg2c & BIT(2)))
+			sio_data->skip_in |= BIT(5); /* No VIN5 */
 
 		/* VIN6 */
-		if (reg27 & (1 << 1))
-			sio_data->skip_in |= (1 << 6); /* No VIN6 */
+		if (reg27 & BIT(1))
+			sio_data->skip_in |= BIT(6); /* No VIN6 */
 
 		/*
 		 * VIN7
 		 * Does not depend on bit 2 of Reg2C, contrary to datasheet.
 		 */
-		if (reg27 & (1 << 2)) {
+		if (reg27 & BIT(2)) {
 			/*
 			 * The data sheet is a bit unclear regarding the
 			 * internal voltage divider for VCCH5V. It says
@@ -2006,81 +3240,335 @@ static int __init it87_find(unsigned short *address,
 			 * not the case, and ask the user to report if the
 			 * resulting voltage is sane.
 			 */
-			if (!(reg2c & (1 << 1))) {
-				reg2c |= (1 << 1);
-				superio_outb(IT87_SIO_PINX2_REG, reg2c);
+			if (!(reg2c & BIT(1))) {
+				reg2c |= BIT(1);
+				superio_outb(sioaddr, IT87_SIO_PINX2_REG,
+					     reg2c);
 				pr_notice("Routing internal VCCH5V to in7.\n");
 			}
 			pr_notice("in7 routed to internal voltage divider, with external pin disabled.\n");
 			pr_notice("Please report if it displays a reasonable voltage.\n");
 		}
 
-		if (reg2c & (1 << 0))
-			sio_data->internal |= (1 << 0);
-		if (reg2c & (1 << 1))
-			sio_data->internal |= (1 << 1);
+		if (reg2c & BIT(0))
+			sio_data->internal |= BIT(0);
+		if (reg2c & BIT(1))
+			sio_data->internal |= BIT(1);
 
-		sio_data->beep_pin = superio_inb(IT87_SIO_BEEP_PIN_REG) & 0x3f;
-	} else if (sio_data->type == it8603) {
+		sio_data->beep_pin = superio_inb(sioaddr,
+						 IT87_SIO_BEEP_PIN_REG) & 0x3f;
+	} else if (sio_data->type == it8603 || sio_data->type == it8606 ||
+		   sio_data->type == it8607) {
 		int reg27, reg29;
 
-		superio_select(GPIO);
+		superio_select(sioaddr, GPIO);
 
-		reg27 = superio_inb(IT87_SIO_GPIO3_REG);
+		reg27 = superio_inb(sioaddr, IT87_SIO_GPIO3_REG);
 
 		/* Check if fan3 is there or not */
-		if (reg27 & (1 << 6))
-			sio_data->skip_pwm |= (1 << 2);
-		if (reg27 & (1 << 7))
-			sio_data->skip_fan |= (1 << 2);
+		if (reg27 & BIT(6))
+			sio_data->skip_pwm |= BIT(2);
+		if (reg27 & BIT(7))
+			sio_data->skip_fan |= BIT(2);
 
 		/* Check if fan2 is there or not */
-		reg29 = superio_inb(IT87_SIO_GPIO5_REG);
-		if (reg29 & (1 << 1))
-			sio_data->skip_pwm |= (1 << 1);
-		if (reg29 & (1 << 2))
-			sio_data->skip_fan |= (1 << 1);
+		reg29 = superio_inb(sioaddr, IT87_SIO_GPIO5_REG);
+		if (reg29 & BIT(1))
+			sio_data->skip_pwm |= BIT(1);
+		if (reg29 & BIT(2))
+			sio_data->skip_fan |= BIT(1);
+
+		switch (sio_data->type) {
+		case it8603:
+			sio_data->skip_in |= BIT(5); /* No VIN5 */
+			sio_data->skip_in |= BIT(6); /* No VIN6 */
+			break;
+		case it8607:
+			sio_data->skip_pwm |= BIT(0);/* No fan1 */
+			sio_data->skip_fan |= BIT(0);
+		default:
+			break;
+		}
 
-		sio_data->skip_in |= (1 << 5); /* No VIN5 */
-		sio_data->skip_in |= (1 << 6); /* No VIN6 */
+		sio_data->beep_pin = superio_inb(sioaddr,
+						 IT87_SIO_BEEP_PIN_REG) & 0x3f;
+	} else if (sio_data->type == it8613) {
+		int reg27, reg29, reg2a;
+
+		superio_select(sioaddr, GPIO);
+
+		/* Check for pwm3, fan3, pwm5, fan5 */
+		reg27 = superio_inb(sioaddr, IT87_SIO_GPIO3_REG);
+		if (reg27 & BIT(1))
+			sio_data->skip_fan |= BIT(4);
+		if (reg27 & BIT(3))
+			sio_data->skip_pwm |= BIT(4);
+		if (reg27 & BIT(6))
+			sio_data->skip_pwm |= BIT(2);
+		if (reg27 & BIT(7))
+			sio_data->skip_fan |= BIT(2);
+
+		/* Check for pwm2, fan2 */
+		reg29 = superio_inb(sioaddr, IT87_SIO_GPIO5_REG);
+		if (reg29 & BIT(1))
+			sio_data->skip_pwm |= BIT(1);
+		if (reg29 & BIT(2))
+			sio_data->skip_fan |= BIT(1);
+
+		/* Check for pwm4, fan4 */
+		reg2a = superio_inb(sioaddr, IT87_SIO_PINX1_REG);
+		if (!(reg2a & BIT(0)) || (reg29 & BIT(7))) {
+			sio_data->skip_fan |= BIT(3);
+			sio_data->skip_pwm |= BIT(3);
+		}
 
-		sio_data->internal |= (1 << 3); /* in9 is AVCC */
+		sio_data->skip_pwm |= BIT(0); /* No pwm1 */
+		sio_data->skip_fan |= BIT(0); /* No fan1 */
+		sio_data->skip_in |= BIT(3);  /* No VIN3 */
+		sio_data->skip_in |= BIT(6);  /* No VIN6 */
 
-		sio_data->beep_pin = superio_inb(IT87_SIO_BEEP_PIN_REG) & 0x3f;
-	} else if (sio_data->type == it8620) {
+		sio_data->beep_pin = superio_inb(sioaddr,
+						 IT87_SIO_BEEP_PIN_REG) & 0x3f;
+	} else if (sio_data->type == it8620 || sio_data->type == it8628 ||
+		   sio_data->type == it8686) {
 		int reg;
 
-		superio_select(GPIO);
+		superio_select(sioaddr, GPIO);
+
+		/* Check for pwm5 */
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO1_REG);
+		if (reg & BIT(6))
+			sio_data->skip_pwm |= BIT(4);
 
 		/* Check for fan4, fan5 */
-		reg = superio_inb(IT87_SIO_GPIO2_REG);
-		if (!(reg & (1 << 5)))
-			sio_data->skip_fan |= (1 << 3);
-		if (!(reg & (1 << 4)))
-			sio_data->skip_fan |= (1 << 4);
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO2_REG);
+		if (!(reg & BIT(5)))
+			sio_data->skip_fan |= BIT(3);
+		if (!(reg & BIT(4)))
+			sio_data->skip_fan |= BIT(4);
 
 		/* Check for pwm3, fan3 */
-		reg = superio_inb(IT87_SIO_GPIO3_REG);
-		if (reg & (1 << 6))
-			sio_data->skip_pwm |= (1 << 2);
-		if (reg & (1 << 7))
-			sio_data->skip_fan |= (1 << 2);
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO3_REG);
+		if (reg & BIT(6))
+			sio_data->skip_pwm |= BIT(2);
+		if (reg & BIT(7))
+			sio_data->skip_fan |= BIT(2);
+
+		/* Check for pwm4 */
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO4_REG);
+		if (reg & BIT(2))
+			sio_data->skip_pwm |= BIT(3);
+
+		/* Check for pwm2, fan2 */
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO5_REG);
+		if (reg & BIT(1))
+			sio_data->skip_pwm |= BIT(1);
+		if (reg & BIT(2))
+			sio_data->skip_fan |= BIT(1);
+		/* Check for pwm6, fan6 */
+		if (!(reg & BIT(7))) {
+			sio_data->skip_pwm |= BIT(5);
+			sio_data->skip_fan |= BIT(5);
+		}
+
+		/* Check if AVCC is on VIN3 */
+		reg = superio_inb(sioaddr, IT87_SIO_PINX2_REG);
+		if (reg & BIT(0)) {
+			/* For it8686, the bit just enables AVCC3 */
+			if (sio_data->type != it8686)
+				sio_data->internal |= BIT(0);
+		} else {
+			sio_data->internal &= ~BIT(3);
+			sio_data->skip_in |= BIT(9);
+		}
+
+		sio_data->beep_pin = superio_inb(sioaddr,
+						 IT87_SIO_BEEP_PIN_REG) & 0x3f;
+	} else if (sio_data->type == it8622) {
+		int reg;
+
+		superio_select(sioaddr, GPIO);
+
+		/* Check for pwm4, fan4 */
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO1_REG);
+		if (reg & BIT(6))
+			sio_data->skip_fan |= BIT(3);
+		if (reg & BIT(5))
+			sio_data->skip_pwm |= BIT(3);
+
+		/* Check for pwm3, fan3, pwm5, fan5 */
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO3_REG);
+		if (reg & BIT(6))
+			sio_data->skip_pwm |= BIT(2);
+		if (reg & BIT(7))
+			sio_data->skip_fan |= BIT(2);
+		if (reg & BIT(3))
+			sio_data->skip_pwm |= BIT(4);
+		if (reg & BIT(1))
+			sio_data->skip_fan |= BIT(4);
+
+		/* Check for pwm2, fan2 */
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO5_REG);
+		if (reg & BIT(1))
+			sio_data->skip_pwm |= BIT(1);
+		if (reg & BIT(2))
+			sio_data->skip_fan |= BIT(1);
+
+		/* Check for AVCC */
+		reg = superio_inb(sioaddr, IT87_SIO_PINX2_REG);
+		if (!(reg & BIT(0)))
+			sio_data->skip_in |= BIT(9);
+
+		sio_data->beep_pin = superio_inb(sioaddr,
+						 IT87_SIO_BEEP_PIN_REG) & 0x3f;
+	} else if (sio_data->type == it8732 || sio_data->type == it8736 ||
+		   sio_data->type == it8738) {
+		int reg;
+
+		superio_select(sioaddr, GPIO);
 
 		/* Check for pwm2, fan2 */
-		reg = superio_inb(IT87_SIO_GPIO5_REG);
-		if (reg & (1 << 1))
-			sio_data->skip_pwm |= (1 << 1);
-		if (reg & (1 << 2))
-			sio_data->skip_fan |= (1 << 1);
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO5_REG);
+		if (reg & BIT(1))
+			sio_data->skip_pwm |= BIT(1);
+		if (reg & BIT(2))
+			sio_data->skip_fan |= BIT(1);
+
+		/* Check for pwm3, fan3, fan4 */
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO3_REG);
+		if (reg & BIT(6))
+			sio_data->skip_pwm |= BIT(2);
+		if (reg & BIT(7))
+			sio_data->skip_fan |= BIT(2);
+		if (reg & BIT(5))
+			sio_data->skip_fan |= BIT(3);
+
+		/* Check if AVCC is on VIN3 */
+		if (sio_data->type != it8738) {
+			reg = superio_inb(sioaddr, IT87_SIO_PINX2_REG);
+			if (reg & BIT(0))
+				sio_data->internal |= BIT(0);
+		}
 
-		sio_data->beep_pin = superio_inb(IT87_SIO_BEEP_PIN_REG) & 0x3f;
+		sio_data->beep_pin = superio_inb(sioaddr,
+						 IT87_SIO_BEEP_PIN_REG) & 0x3f;
+	} else if (sio_data->type == it8655) {
+		int reg;
+
+		superio_select(sioaddr, GPIO);
+
+		/* Check for pwm2 */
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO5_REG);
+		if (reg & BIT(1))
+			sio_data->skip_pwm |= BIT(1);
+
+		/* Check for fan2 */
+		reg = superio_inb(sioaddr, IT87_SIO_PINX4_REG);
+		if (reg & BIT(4))
+			sio_data->skip_fan |= BIT(1);
+
+		/* Check for pwm3, fan3 */
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO3_REG);
+		if (reg & BIT(6))
+			sio_data->skip_pwm |= BIT(2);
+		if (reg & BIT(7))
+			sio_data->skip_fan |= BIT(2);
+
+		sio_data->beep_pin = superio_inb(sioaddr,
+						 IT87_SIO_BEEP_PIN_REG) & 0x3f;
+	} else if (sio_data->type == it8665 || sio_data->type == it8625) {
+		int reg27, reg29, reg2d, regd3;
+
+		superio_select(sioaddr, GPIO);
+
+		reg27 = superio_inb(sioaddr, IT87_SIO_GPIO3_REG);
+		reg29 = superio_inb(sioaddr, IT87_SIO_GPIO5_REG);
+		reg2d = superio_inb(sioaddr, IT87_SIO_PINX4_REG);
+		regd3 = superio_inb(sioaddr, IT87_SIO_GPIO9_REG);
+
+		/* Check for pwm2 */
+		if (reg29 & BIT(1))
+			sio_data->skip_pwm |= BIT(1);
+
+		/* Check for pwm3, fan3 */
+		if (reg27 & BIT(6))
+			sio_data->skip_pwm |= BIT(2);
+		if (reg27 & BIT(7))
+			sio_data->skip_fan |= BIT(2);
+
+		/* Check for fan2, pwm4, fan4, pwm5, fan5 */
+		if (sio_data->type == it8625) {
+			int reg25 = superio_inb(sioaddr, IT87_SIO_GPIO1_REG);
+
+			if (reg29 & BIT(2))
+				sio_data->skip_fan |= BIT(1);
+			if (reg25 & BIT(6))
+				sio_data->skip_fan |= BIT(3);
+			if (reg25 & BIT(5))
+				sio_data->skip_pwm |= BIT(3);
+			if (reg27 & BIT(3))
+				sio_data->skip_pwm |= BIT(4);
+			if (!(reg27 & BIT(1)))
+				sio_data->skip_fan |= BIT(4);
+		} else {
+			int reg26 = superio_inb(sioaddr, IT87_SIO_GPIO2_REG);
+
+			if (reg2d & BIT(4))
+				sio_data->skip_fan |= BIT(1);
+			if (regd3 & BIT(2))
+				sio_data->skip_pwm |= BIT(3);
+			if (regd3 & BIT(3))
+				sio_data->skip_fan |= BIT(3);
+			if (reg26 & BIT(5))
+				sio_data->skip_pwm |= BIT(4);
+			/*
+			 * Table 6-1 in datasheet claims that FAN_TAC5 would
+			 * be enabled with 26h[4]=0. This contradicts with the
+			 * information in section 8.3.9 and with feedback from
+			 * users.
+			 */
+			if (!(reg26 & BIT(4)))
+				sio_data->skip_fan |= BIT(4);
+		}
+
+		/* Check for pwm6, fan6 */
+		if (regd3 & BIT(0))
+			sio_data->skip_pwm |= BIT(5);
+		if (regd3 & BIT(1))
+			sio_data->skip_fan |= BIT(5);
+
+		sio_data->beep_pin = superio_inb(sioaddr,
+						 IT87_SIO_BEEP_PIN_REG) & 0x3f;
 	} else {
 		int reg;
 		bool uart6;
 
-		superio_select(GPIO);
+		superio_select(sioaddr, GPIO);
+
+		/* Check for fan4, fan5 */
+		if (has_five_fans(config)) {
+			reg = superio_inb(sioaddr, IT87_SIO_GPIO2_REG);
+			switch (sio_data->type) {
+			case it8718:
+				if (reg & BIT(5))
+					sio_data->skip_fan |= BIT(3);
+				if (reg & BIT(4))
+					sio_data->skip_fan |= BIT(4);
+				break;
+			case it8720:
+			case it8721:
+			case it8728:
+				if (!(reg & BIT(5)))
+					sio_data->skip_fan |= BIT(3);
+				if (!(reg & BIT(4)))
+					sio_data->skip_fan |= BIT(4);
+				break;
+			default:
+				break;
+			}
+		}
 
-		reg = superio_inb(IT87_SIO_GPIO3_REG);
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO3_REG);
 		if (!sio_data->skip_vid) {
 			/* We need at least 4 VID pins */
 			if (reg & 0x0f) {
@@ -2090,25 +3578,26 @@ static int __init it87_find(unsigned short *address,
 		}
 
 		/* Check if fan3 is there or not */
-		if (reg & (1 << 6))
-			sio_data->skip_pwm |= (1 << 2);
-		if (reg & (1 << 7))
-			sio_data->skip_fan |= (1 << 2);
+		if (reg & BIT(6))
+			sio_data->skip_pwm |= BIT(2);
+		if (reg & BIT(7))
+			sio_data->skip_fan |= BIT(2);
 
 		/* Check if fan2 is there or not */
-		reg = superio_inb(IT87_SIO_GPIO5_REG);
-		if (reg & (1 << 1))
-			sio_data->skip_pwm |= (1 << 1);
-		if (reg & (1 << 2))
-			sio_data->skip_fan |= (1 << 1);
+		reg = superio_inb(sioaddr, IT87_SIO_GPIO5_REG);
+		if (reg & BIT(1))
+			sio_data->skip_pwm |= BIT(1);
+		if (reg & BIT(2))
+			sio_data->skip_fan |= BIT(1);
 
-		if ((sio_data->type == it8718 || sio_data->type == it8720)
-		 && !(sio_data->skip_vid))
-			sio_data->vid_value = superio_inb(IT87_SIO_VID_REG);
+		if ((sio_data->type == it8718 || sio_data->type == it8720) &&
+		    !(sio_data->skip_vid))
+			sio_data->vid_value = superio_inb(sioaddr,
+							  IT87_SIO_VID_REG);
 
-		reg = superio_inb(IT87_SIO_PINX2_REG);
+		reg = superio_inb(sioaddr, IT87_SIO_PINX2_REG);
 
-		uart6 = sio_data->type == it8782 && (reg & (1 << 2));
+		uart6 = sio_data->type == it8782 && (reg & BIT(2));
 
 		/*
 		 * The IT8720F has no VIN7 pin, so VCCH should always be
@@ -2124,15 +3613,15 @@ static int __init it87_find(unsigned short *address,
 		 * If UART6 is enabled, re-route VIN7 to the internal divider
 		 * if that is not already the case.
 		 */
-		if ((sio_data->type == it8720 || uart6) && !(reg & (1 << 1))) {
-			reg |= (1 << 1);
-			superio_outb(IT87_SIO_PINX2_REG, reg);
+		if ((sio_data->type == it8720 || uart6) && !(reg & BIT(1))) {
+			reg |= BIT(1);
+			superio_outb(sioaddr, IT87_SIO_PINX2_REG, reg);
 			pr_notice("Routing internal VCCH to in7\n");
 		}
-		if (reg & (1 << 0))
-			sio_data->internal |= (1 << 0);
-		if (reg & (1 << 1))
-			sio_data->internal |= (1 << 1);
+		if (reg & BIT(0))
+			sio_data->internal |= BIT(0);
+		if (reg & BIT(1))
+			sio_data->internal |= BIT(1);
 
 		/*
 		 * On IT8782F, UART6 pins overlap with VIN5, VIN6, and VIN7.
@@ -2144,395 +3633,101 @@ static int __init it87_find(unsigned short *address,
 		 * temperature source here, skip_temp is preliminary.
 		 */
 		if (uart6) {
-			sio_data->skip_in |= (1 << 5) | (1 << 6);
-			sio_data->skip_temp |= (1 << 2);
+			sio_data->skip_in |= BIT(5) | BIT(6);
+			sio_data->skip_temp |= BIT(2);
 		}
 
-		sio_data->beep_pin = superio_inb(IT87_SIO_BEEP_PIN_REG) & 0x3f;
+		sio_data->beep_pin = superio_inb(sioaddr,
+						 IT87_SIO_BEEP_PIN_REG) & 0x3f;
 	}
 	if (sio_data->beep_pin)
 		pr_info("Beeping is supported\n");
 
-	/* Disable specific features based on DMI strings */
-	board_vendor = dmi_get_system_info(DMI_BOARD_VENDOR);
-	board_name = dmi_get_system_info(DMI_BOARD_NAME);
-	if (board_vendor && board_name) {
-		if (strcmp(board_vendor, "nVIDIA") == 0
-		 && strcmp(board_name, "FN68PT") == 0) {
-			/*
-			 * On the Shuttle SN68PT, FAN_CTL2 is apparently not
-			 * connected to a fan, but to something else. One user
-			 * has reported instant system power-off when changing
-			 * the PWM2 duty cycle, so we disable it.
-			 * I use the board name string as the trigger in case
-			 * the same board is ever used in other systems.
-			 */
-			pr_info("Disabling pwm2 due to hardware constraints\n");
-			sio_data->skip_pwm = (1 << 1);
-		}
-	}
-
-exit:
-	superio_exit();
-	return err;
-}
-
-static void it87_remove_files(struct device *dev)
-{
-	struct it87_data *data = platform_get_drvdata(pdev);
-	struct it87_sio_data *sio_data = dev_get_platdata(dev);
-	int i;
-
-	sysfs_remove_group(&dev->kobj, &it87_group);
-	for (i = 0; i < 10; i++) {
-		if (sio_data->skip_in & (1 << i))
-			continue;
-		sysfs_remove_group(&dev->kobj, &it87_group_in[i]);
-		if (it87_attributes_in_beep[i])
-			sysfs_remove_file(&dev->kobj,
-					  it87_attributes_in_beep[i]);
-	}
-	for (i = 0; i < 3; i++) {
-		if (!(data->has_temp & (1 << i)))
-			continue;
-		sysfs_remove_group(&dev->kobj, &it87_group_temp[i]);
-		if (has_temp_offset(data))
-			sysfs_remove_file(&dev->kobj,
-					  it87_attributes_temp_offset[i]);
-		if (sio_data->beep_pin)
-			sysfs_remove_file(&dev->kobj,
-					  it87_attributes_temp_beep[i]);
-	}
-	for (i = 0; i < 6; i++) {
-		if (!(data->has_fan & (1 << i)))
-			continue;
-		sysfs_remove_group(&dev->kobj, &it87_group_fan[i]);
-		if (sio_data->beep_pin)
-			sysfs_remove_file(&dev->kobj,
-					  it87_attributes_fan_beep[i]);
-		if (i < 3 && !has_16bit_fans(data))
-			sysfs_remove_file(&dev->kobj,
-					  it87_attributes_fan_div[i]);
-	}
-	for (i = 0; i < 3; i++) {
-		if (sio_data->skip_pwm & (1 << i))
-			continue;
-		sysfs_remove_group(&dev->kobj, &it87_group_pwm[i]);
-		if (has_old_autopwm(data))
-			sysfs_remove_group(&dev->kobj,
-					   &it87_group_autopwm[i]);
-	}
-	if (!sio_data->skip_vid)
-		sysfs_remove_group(&dev->kobj, &it87_group_vid);
-	sysfs_remove_group(&dev->kobj, &it87_group_label);
-}
-
-static int it87_probe(struct platform_device *pdev)
-{
-	struct it87_data *data;
-	struct resource *res;
-	struct device *dev = &pdev->dev;
-	struct it87_sio_data *sio_data = dev_get_platdata(dev);
-	int err = 0, i;
-	int enable_pwm_interface;
-	int fan_beep_need_rw;
-
-	res = platform_get_resource(pdev, IORESOURCE_IO, 0);
-	if (!devm_request_region(&pdev->dev, res->start, IT87_EC_EXTENT,
-				 DRVNAME)) {
-		dev_err(dev, "Failed to request region 0x%lx-0x%lx\n",
-			(unsigned long)res->start,
-			(unsigned long)(res->start + IT87_EC_EXTENT - 1));
-		return -EBUSY;
-	}
-
-	data = devm_kzalloc(&pdev->dev, sizeof(struct it87_data), GFP_KERNEL);
-	if (!data)
-		return -ENOMEM;
-
-	data->addr = res->start;
-	data->type = sio_data->type;
-	data->features = it87_devices[sio_data->type].features;
-	data->peci_mask = it87_devices[sio_data->type].peci_mask;
-	data->old_peci_mask = it87_devices[sio_data->type].old_peci_mask;
-	data->name = it87_devices[sio_data->type].name;
-	/*
-	 * IT8705F Datasheet 0.4.1, 3h == Version G.
-	 * IT8712F Datasheet 0.9.1, section 8.3.5 indicates 8h == Version J.
-	 * These are the first revisions with 16-bit tachometer support.
-	 */
-	switch (data->type) {
-	case it87:
-		if (sio_data->revision >= 0x03) {
-			data->features &= ~FEAT_OLD_AUTOPWM;
-			data->features |= FEAT_FAN16_CONFIG | FEAT_16BIT_FANS;
-		}
-		break;
-	case it8712:
-		if (sio_data->revision >= 0x08) {
-			data->features &= ~FEAT_OLD_AUTOPWM;
-			data->features |= FEAT_FAN16_CONFIG | FEAT_16BIT_FANS |
-					  FEAT_FIVE_FANS;
-		}
-		break;
-	default:
-		break;
-	}
-
-	/* Now, we do the remaining detection. */
-	if ((it87_read_value(data, IT87_REG_CONFIG) & 0x80)
-	 || it87_read_value(data, IT87_REG_CHIPID) != 0x90)
-		return -ENODEV;
-
-	platform_set_drvdata(pdev, data);
-
-	mutex_init(&data->update_lock);
-
-	/* Check PWM configuration */
-	enable_pwm_interface = it87_check_pwm(dev);
-
-	/* Starting with IT8721F, we handle scaling of internal voltages */
-	if (has_12mv_adc(data)) {
-		if (sio_data->internal & (1 << 0))
-			data->in_scaled |= (1 << 3);	/* in3 is AVCC */
-		if (sio_data->internal & (1 << 1))
-			data->in_scaled |= (1 << 7);	/* in7 is VSB */
-		if (sio_data->internal & (1 << 2))
-			data->in_scaled |= (1 << 8);	/* in8 is Vbat */
-		if (sio_data->internal & (1 << 3))
-			data->in_scaled |= (1 << 9);	/* in9 is AVCC */
-	} else if (sio_data->type == it8781 || sio_data->type == it8782 ||
-		   sio_data->type == it8783) {
-		if (sio_data->internal & (1 << 0))
-			data->in_scaled |= (1 << 3);	/* in3 is VCC5V */
-		if (sio_data->internal & (1 << 1))
-			data->in_scaled |= (1 << 7);	/* in7 is VCCH5V */
-	}
-
-	data->has_temp = 0x07;
-	if (sio_data->skip_temp & (1 << 2)) {
-		if (sio_data->type == it8782
-		    && !(it87_read_value(data, IT87_REG_TEMP_EXTRA) & 0x80))
-			data->has_temp &= ~(1 << 2);
-	}
-
-	/* Initialize the IT87 chip */
-	it87_init_device(pdev);
-
-	/* Register sysfs hooks */
-	err = sysfs_create_group(&dev->kobj, &it87_group);
-	if (err)
-		return err;
-
-	for (i = 0; i < 10; i++) {
-		if (sio_data->skip_in & (1 << i))
-			continue;
-		err = sysfs_create_group(&dev->kobj, &it87_group_in[i]);
-		if (err)
-			goto error;
-		if (sio_data->beep_pin && it87_attributes_in_beep[i]) {
-			err = sysfs_create_file(&dev->kobj,
-						it87_attributes_in_beep[i]);
-			if (err)
-				goto error;
-		}
-	}
-
-	for (i = 0; i < 3; i++) {
-		if (!(data->has_temp & (1 << i)))
-			continue;
-		err = sysfs_create_group(&dev->kobj, &it87_group_temp[i]);
-		if (err)
-			goto error;
-		if (has_temp_offset(data)) {
-			err = sysfs_create_file(&dev->kobj,
-						it87_attributes_temp_offset[i]);
-			if (err)
-				goto error;
-		}
-		if (sio_data->beep_pin) {
-			err = sysfs_create_file(&dev->kobj,
-						it87_attributes_temp_beep[i]);
-			if (err)
-				goto error;
-		}
-	}
-
-	/* Do not create fan files for disabled fans */
-	fan_beep_need_rw = 1;
-	for (i = 0; i < 6; i++) {
-		if (!(data->has_fan & (1 << i)))
-			continue;
-		err = sysfs_create_group(&dev->kobj, &it87_group_fan[i]);
-		if (err)
-			goto error;
-
-		if (i < 3 && !has_16bit_fans(data)) {
-			err = sysfs_create_file(&dev->kobj,
-						it87_attributes_fan_div[i]);
-			if (err)
-				goto error;
-		}
-
-		if (sio_data->beep_pin) {
-			err = sysfs_create_file(&dev->kobj,
-						it87_attributes_fan_beep[i]);
-			if (err)
-				goto error;
-			if (!fan_beep_need_rw)
-				continue;
-
-			/*
-			 * As we have a single beep enable bit for all fans,
-			 * only the first enabled fan has a writable attribute
-			 * for it.
-			 */
-			if (sysfs_chmod_file(&dev->kobj,
-					     it87_attributes_fan_beep[i],
-					     S_IRUGO | S_IWUSR))
-				dev_dbg(dev, "chmod +w fan%d_beep failed\n",
-					i + 1);
-			fan_beep_need_rw = 0;
-		}
-	}
-
-	if (enable_pwm_interface) {
-		for (i = 0; i < 3; i++) {
-			if (sio_data->skip_pwm & (1 << i))
-				continue;
-			err = sysfs_create_group(&dev->kobj,
-						 &it87_group_pwm[i]);
-			if (err)
-				goto error;
-
-			if (!has_old_autopwm(data))
-				continue;
-			err = sysfs_create_group(&dev->kobj,
-						 &it87_group_autopwm[i]);
-			if (err)
-				goto error;
-		}
-	}
-
-	if (!sio_data->skip_vid) {
-		data->vrm = vid_which_vrm();
-		/* VID reading from Super-I/O config space if available */
-		data->vid = sio_data->vid_value;
-		err = sysfs_create_group(&dev->kobj, &it87_group_vid);
-		if (err)
-			goto error;
-	}
-
-	/* Export labels for internal sensors */
-	for (i = 0; i < 4; i++) {
-		if (!(sio_data->internal & (1 << i)))
-			continue;
-		err = sysfs_create_file(&dev->kobj,
-					it87_attributes_label[i]);
-		if (err)
-			goto error;
-	}
+	if (config->smbus_bitmap && !base) {
+		u8 reg;
 
-	data->hwmon_dev = hwmon_device_register(dev);
-	if (IS_ERR(data->hwmon_dev)) {
-		err = PTR_ERR(data->hwmon_dev);
-		goto error;
+		superio_select(sioaddr, PME);
+		reg = superio_inb(sioaddr, IT87_SPECIAL_CFG_REG);
+		sio_data->ec_special_config = reg;
+		sio_data->smbus_bitmap = reg & config->smbus_bitmap;
 	}
 
-	return 0;
-
-error:
-	it87_remove_files(dev);
+exit:
+	superio_exit(sioaddr, doexit);
 	return err;
 }
 
-static int it87_remove(struct platform_device *pdev)
-{
-	struct it87_data *data = platform_get_drvdata(pdev);
-
-	hwmon_device_unregister(data->hwmon_dev);
-	it87_remove_files(&pdev->dev);
-
-	return 0;
-}
-
-/*
- * Must be called with data->update_lock held, except during initialization.
- * We ignore the IT87 BUSY flag at this moment - it could lead to deadlocks,
- * would slow down the IT87 access and should not be necessary.
- */
-static int it87_read_value(struct it87_data *data, u8 reg)
-{
-	outb_p(reg, data->addr + IT87_ADDR_REG_OFFSET);
-	return inb_p(data->addr + IT87_DATA_REG_OFFSET);
-}
-
-/*
- * Must be called with data->update_lock held, except during initialization.
- * We ignore the IT87 BUSY flag at this moment - it could lead to deadlocks,
- * would slow down the IT87 access and should not be necessary.
- */
-static void it87_write_value(struct it87_data *data, u8 reg, u8 value)
-{
-	outb_p(reg, data->addr + IT87_ADDR_REG_OFFSET);
-	outb_p(value, data->addr + IT87_DATA_REG_OFFSET);
-}
-
-/* Return 1 if and only if the PWM interface is safe to use */
-static int it87_check_pwm(struct device *dev)
-{
-	struct it87_data *data = dev_get_drvdata(dev);
-	/*
-	 * Some BIOSes fail to correctly configure the IT87 fans. All fans off
-	 * and polarity set to active low is sign that this is the case so we
-	 * disable pwm control to protect the user.
-	 */
-	int tmp = it87_read_value(data, IT87_REG_FAN_CTL);
-	if ((tmp & 0x87) == 0) {
-		if (fix_pwm_polarity) {
-			/*
-			 * The user asks us to attempt a chip reconfiguration.
-			 * This means switching to active high polarity and
-			 * inverting all fan speed values.
-			 */
-			int i;
-			u8 pwm[3];
-
-			for (i = 0; i < 3; i++)
-				pwm[i] = it87_read_value(data,
-							 IT87_REG_PWM(i));
-
-			/*
-			 * If any fan is in automatic pwm mode, the polarity
-			 * might be correct, as suspicious as it seems, so we
-			 * better don't change anything (but still disable the
-			 * PWM interface).
-			 */
-			if (!((pwm[0] | pwm[1] | pwm[2]) & 0x80)) {
-				dev_info(dev,
-					 "Reconfiguring PWM to active high polarity\n");
-				it87_write_value(data, IT87_REG_FAN_CTL,
-						 tmp | 0x87);
-				for (i = 0; i < 3; i++)
-					it87_write_value(data,
-							 IT87_REG_PWM(i),
-							 0x7f & ~pwm[i]);
-				return 1;
-			}
-
-			dev_info(dev,
-				 "PWM configuration is too broken to be fixed\n");
-		}
-
-		dev_info(dev,
-			 "Detected broken BIOS defaults, disabling PWM interface\n");
-		return 0;
-	} else if (fix_pwm_polarity) {
-		dev_info(dev,
-			 "PWM configuration looks sane, won't touch\n");
+static void it87_init_regs(struct platform_device *pdev)
+{
+	struct it87_data *data = platform_get_drvdata(pdev);
+
+	/* Initialize chip specific register pointers */
+	switch (data->type) {
+	case it8628:
+	case it8686:
+		data->REG_FAN = IT87_REG_FAN;
+		data->REG_FANX = IT87_REG_FANX;
+		data->REG_FAN_MIN = IT87_REG_FAN_MIN;
+		data->REG_FANX_MIN = IT87_REG_FANX_MIN;
+		data->REG_PWM = IT87_REG_PWM;
+		data->REG_TEMP_OFFSET = IT87_REG_TEMP_OFFSET_8686;
+		data->REG_TEMP_LOW = IT87_REG_TEMP_LOW_8686;
+		data->REG_TEMP_HIGH = IT87_REG_TEMP_HIGH_8686;
+		break;
+	case it8625:
+	case it8655:
+	case it8665:
+		data->REG_FAN = IT87_REG_FAN_8665;
+		data->REG_FANX = IT87_REG_FANX_8665;
+		data->REG_FAN_MIN = IT87_REG_FAN_MIN_8665;
+		data->REG_FANX_MIN = IT87_REG_FANX_MIN_8665;
+		data->REG_PWM = IT87_REG_PWM_8665;
+		data->REG_TEMP_OFFSET = IT87_REG_TEMP_OFFSET;
+		data->REG_TEMP_LOW = IT87_REG_TEMP_LOW;
+		data->REG_TEMP_HIGH = IT87_REG_TEMP_HIGH;
+		break;
+	case it8622:
+		data->REG_FAN = IT87_REG_FAN;
+		data->REG_FANX = IT87_REG_FANX;
+		data->REG_FAN_MIN = IT87_REG_FAN_MIN;
+		data->REG_FANX_MIN = IT87_REG_FANX_MIN;
+		data->REG_PWM = IT87_REG_PWM_8665;
+		data->REG_TEMP_OFFSET = IT87_REG_TEMP_OFFSET;
+		data->REG_TEMP_LOW = IT87_REG_TEMP_LOW;
+		data->REG_TEMP_HIGH = IT87_REG_TEMP_HIGH;
+		break;
+	case it8613:
+		data->REG_FAN = IT87_REG_FAN;
+		data->REG_FANX = IT87_REG_FANX;
+		data->REG_FAN_MIN = IT87_REG_FAN_MIN;
+		data->REG_FANX_MIN = IT87_REG_FANX_MIN;
+		data->REG_PWM = IT87_REG_PWM_8665;
+		data->REG_TEMP_OFFSET = IT87_REG_TEMP_OFFSET;
+		data->REG_TEMP_LOW = IT87_REG_TEMP_LOW;
+		data->REG_TEMP_HIGH = IT87_REG_TEMP_HIGH;
+		break;
+	default:
+		data->REG_FAN = IT87_REG_FAN;
+		data->REG_FANX = IT87_REG_FANX;
+		data->REG_FAN_MIN = IT87_REG_FAN_MIN;
+		data->REG_FANX_MIN = IT87_REG_FANX_MIN;
+		data->REG_PWM = IT87_REG_PWM;
+		data->REG_TEMP_OFFSET = IT87_REG_TEMP_OFFSET;
+		data->REG_TEMP_LOW = IT87_REG_TEMP_LOW;
+		data->REG_TEMP_HIGH = IT87_REG_TEMP_HIGH;
+		break;
 	}
 
-	return 1;
+	if (data->mmio) {
+		data->read = it87_mmio_read;
+		data->write = it87_mmio_write;
+	} else if (has_bank_sel(data)) {
+		data->read = it87_io_read;
+		data->write = it87_io_write;
+	} else {
+		data->read = _it87_io_read;
+		data->write = _it87_io_write;
+	}
 }
 
 /* Called when we have found a new IT87. */
@@ -2543,21 +3738,29 @@ static void it87_init_device(struct platform_device *pdev)
 	int tmp, i;
 	u8 mask;
 
+	if (has_new_tempmap(data)) {
+		data->pwm_temp_map_shift = 3;
+		data->pwm_temp_map_mask = 0x07;
+	} else {
+		data->pwm_temp_map_shift = 0;
+		data->pwm_temp_map_mask = 0x03;
+	}
+
 	/*
 	 * For each PWM channel:
 	 * - If it is in automatic mode, setting to manual mode should set
 	 *   the fan to full speed by default.
 	 * - If it is in manual mode, we need a mapping to temperature
 	 *   channels to use when later setting to automatic mode later.
-	 *   Use a 1:1 mapping by default (we are clueless.)
+	 *   Map to the first sensor by default (we are clueless.)
 	 * In both cases, the value can (and should) be changed by the user
 	 * prior to switching to a different mode.
 	 * Note that this is no longer needed for the IT8721F and later, as
 	 * these have separate registers for the temperature mapping and the
 	 * manual duty cycle.
 	 */
-	for (i = 0; i < 3; i++) {
-		data->pwm_temp_map[i] = i;
+	for (i = 0; i < NUM_AUTO_PWM; i++) {
+		data->pwm_temp_map[i] = 0;
 		data->pwm_duty[i] = 0x7f;	/* Full speed */
 		data->auto_pwm[i][3] = 0x7f;	/* Full speed, hard-coded */
 	}
@@ -2569,15 +3772,15 @@ static void it87_init_device(struct platform_device *pdev)
 	 * means -1 degree C, which surprisingly doesn't trigger an alarm,
 	 * but is still confusing, so change to 127 degrees C.
 	 */
-	for (i = 0; i < 8; i++) {
-		tmp = it87_read_value(data, IT87_REG_VIN_MIN(i));
+	for (i = 0; i < NUM_VIN_LIMIT; i++) {
+		tmp = data->read(data, IT87_REG_VIN_MIN(i));
 		if (tmp == 0xff)
-			it87_write_value(data, IT87_REG_VIN_MIN(i), 0);
+			data->write(data, IT87_REG_VIN_MIN(i), 0);
 	}
-	for (i = 0; i < 3; i++) {
-		tmp = it87_read_value(data, IT87_REG_TEMP_HIGH(i));
+	for (i = 0; i < data->num_temp_limit; i++) {
+		tmp = data->read(data, data->REG_TEMP_HIGH[i]);
 		if (tmp == 0xff)
-			it87_write_value(data, IT87_REG_TEMP_HIGH(i), 127);
+			data->write(data, data->REG_TEMP_HIGH[i], 127);
 	}
 
 	/*
@@ -2588,208 +3791,361 @@ static void it87_init_device(struct platform_device *pdev)
 	 */
 
 	/* Check if voltage monitors are reset manually or by some reason */
-	tmp = it87_read_value(data, IT87_REG_VIN_ENABLE);
+	tmp = data->read(data, IT87_REG_VIN_ENABLE);
 	if ((tmp & 0xff) == 0) {
 		/* Enable all voltage monitors */
-		it87_write_value(data, IT87_REG_VIN_ENABLE, 0xff);
+		data->write(data, IT87_REG_VIN_ENABLE, 0xff);
 	}
 
 	/* Check if tachometers are reset manually or by some reason */
 	mask = 0x70 & ~(sio_data->skip_fan << 4);
-	data->fan_main_ctrl = it87_read_value(data, IT87_REG_FAN_MAIN_CTRL);
+	data->fan_main_ctrl = data->read(data, IT87_REG_FAN_MAIN_CTRL);
 	if ((data->fan_main_ctrl & mask) == 0) {
 		/* Enable all fan tachometers */
 		data->fan_main_ctrl |= mask;
-		it87_write_value(data, IT87_REG_FAN_MAIN_CTRL,
-				 data->fan_main_ctrl);
+		data->write(data, IT87_REG_FAN_MAIN_CTRL, data->fan_main_ctrl);
 	}
 	data->has_fan = (data->fan_main_ctrl >> 4) & 0x07;
 
-	tmp = it87_read_value(data, IT87_REG_FAN_16BIT);
+	tmp = data->read(data, IT87_REG_FAN_16BIT);
 
 	/* Set tachometers to 16-bit mode if needed */
 	if (has_fan16_config(data)) {
 		if (~tmp & 0x07 & data->has_fan) {
 			dev_dbg(&pdev->dev,
 				"Setting fan1-3 to 16-bit mode\n");
-			it87_write_value(data, IT87_REG_FAN_16BIT,
-					 tmp | 0x07);
+			data->write(data, IT87_REG_FAN_16BIT, tmp | 0x07);
 		}
 	}
 
 	/* Check for additional fans */
-	if (has_five_fans(data)) {
-		if (tmp & (1 << 4))
-			data->has_fan |= (1 << 3); /* fan4 enabled */
-		if (tmp & (1 << 5))
-			data->has_fan |= (1 << 4); /* fan5 enabled */
-		if (has_six_fans(data) && (tmp & (1 << 2)))
-			data->has_fan |= (1 << 5); /* fan6 enabled */
+	if (has_four_fans(data) && (tmp & BIT(4)))
+		data->has_fan |= BIT(3); /* fan4 enabled */
+	if (has_five_fans(data) && (tmp & BIT(5)))
+		data->has_fan |= BIT(4); /* fan5 enabled */
+	if (has_six_fans(data)) {
+		switch (data->type) {
+		case it8620:
+		case it8628:
+		case it8686:
+			if (tmp & BIT(2))
+				data->has_fan |= BIT(5); /* fan6 enabled */
+			break;
+		case it8625:
+		case it8665:
+			tmp = data->read(data, IT87_REG_FAN_DIV);
+			if (tmp & BIT(3))
+				data->has_fan |= BIT(5); /* fan6 enabled */
+			break;
+		default:
+			break;
+		}
 	}
 
 	/* Fan input pins may be used for alternative functions */
 	data->has_fan &= ~sio_data->skip_fan;
 
-	/* Start monitoring */
-	it87_write_value(data, IT87_REG_CONFIG,
-			 (it87_read_value(data, IT87_REG_CONFIG) & 0x3e)
-			 | (update_vbat ? 0x41 : 0x01));
-}
-
-static void it87_update_pwm_ctrl(struct it87_data *data, int nr)
-{
-	data->pwm_ctrl[nr] = it87_read_value(data, IT87_REG_PWM(nr));
-	if (has_newer_autopwm(data)) {
-		data->pwm_temp_map[nr] = data->pwm_ctrl[nr] & 0x03;
-		data->pwm_duty[nr] = it87_read_value(data,
-						     IT87_REG_PWM_DUTY(nr));
-	} else {
-		if (data->pwm_ctrl[nr] & 0x80)	/* Automatic mode */
-			data->pwm_temp_map[nr] = data->pwm_ctrl[nr] & 0x03;
-		else				/* Manual mode */
-			data->pwm_duty[nr] = data->pwm_ctrl[nr] & 0x7f;
+	/* Check if pwm6 is enabled */
+	if (has_six_pwm(data)) {
+		switch (data->type) {
+		case it8620:
+		case it8686:
+			tmp = data->read(data, IT87_REG_FAN_DIV);
+			if (!(tmp & BIT(3)))
+				sio_data->skip_pwm |= BIT(5);
+			break;
+		default:
+			break;
+		}
 	}
 
-	if (has_old_autopwm(data)) {
-		int i;
-
-		for (i = 0; i < 5 ; i++)
-			data->auto_temp[nr][i] = it87_read_value(data,
-						IT87_REG_AUTO_TEMP(nr, i));
-		for (i = 0; i < 3 ; i++)
-			data->auto_pwm[nr][i] = it87_read_value(data,
-						IT87_REG_AUTO_PWM(nr, i));
+	if (has_bank_sel(data)) {
+		for (i = 0; i < 3; i++)
+			data->temp_src[i] =
+				data->read(data, IT87_REG_TEMP_SRC1[i]);
+		data->temp_src[3] = data->read(data, IT87_REG_TEMP_SRC2);
 	}
+
+	/* Start monitoring */
+	data->write(data, IT87_REG_CONFIG,
+		    (data->read(data, IT87_REG_CONFIG) & 0x3e) |
+					(update_vbat ? 0x41 : 0x01));
 }
 
-static struct it87_data *it87_update_device(struct device *dev)
+/* Return 1 if and only if the PWM interface is safe to use */
+static int it87_check_pwm(struct device *dev)
 {
 	struct it87_data *data = dev_get_drvdata(dev);
-	int i;
+	/*
+	 * Some BIOSes fail to correctly configure the IT87 fans. All fans off
+	 * and polarity set to active low is sign that this is the case so we
+	 * disable pwm control to protect the user.
+	 */
+	int tmp = data->read(data, IT87_REG_FAN_CTL);
 
-	mutex_lock(&data->update_lock);
+	if ((tmp & 0x87) == 0) {
+		if (fix_pwm_polarity) {
+			/*
+			 * The user asks us to attempt a chip reconfiguration.
+			 * This means switching to active high polarity and
+			 * inverting all fan speed values.
+			 */
+			int i;
+			u8 pwm[3];
+
+			for (i = 0; i < ARRAY_SIZE(pwm); i++)
+				pwm[i] = data->read(data,
+							 data->REG_PWM[i]);
 
-	if (time_after(jiffies, data->last_updated + HZ + HZ / 2)
-	    || !data->valid) {
-		if (update_vbat) {
 			/*
-			 * Cleared after each update, so reenable.  Value
-			 * returned by this read will be previous value
+			 * If any fan is in automatic pwm mode, the polarity
+			 * might be correct, as suspicious as it seems, so we
+			 * better don't change anything (but still disable the
+			 * PWM interface).
 			 */
-			it87_write_value(data, IT87_REG_CONFIG,
-				it87_read_value(data, IT87_REG_CONFIG) | 0x40);
+			if (!((pwm[0] | pwm[1] | pwm[2]) & 0x80)) {
+				dev_info(dev,
+					 "Reconfiguring PWM to active high polarity\n");
+				data->write(data, IT87_REG_FAN_CTL, tmp | 0x87);
+				for (i = 0; i < 3; i++)
+					data->write(data, data->REG_PWM[i],
+						    0x7f & ~pwm[i]);
+				return 1;
+			}
+
+			dev_info(dev,
+				 "PWM configuration is too broken to be fixed\n");
 		}
-		for (i = 0; i <= 7; i++) {
-			data->in[i][0] =
-				it87_read_value(data, IT87_REG_VIN(i));
-			data->in[i][1] =
-				it87_read_value(data, IT87_REG_VIN_MIN(i));
-			data->in[i][2] =
-				it87_read_value(data, IT87_REG_VIN_MAX(i));
+
+		dev_info(dev,
+			 "Detected broken BIOS defaults, disabling PWM interface\n");
+		return 0;
+	} else if (fix_pwm_polarity) {
+		dev_info(dev,
+			 "PWM configuration looks sane, won't touch\n");
+	}
+
+	return 1;
+}
+
+static int it87_probe(struct platform_device *pdev)
+{
+	struct it87_data *data;
+	struct resource *res;
+	struct device *dev = &pdev->dev;
+	struct it87_sio_data *sio_data = dev_get_platdata(dev);
+	int enable_pwm_interface;
+	struct device *hwmon_dev;
+	int err;
+
+	data = devm_kzalloc(dev, sizeof(struct it87_data), GFP_KERNEL);
+	if (!data)
+		return -ENOMEM;
+
+	res = platform_get_resource(pdev, IORESOURCE_IO, 0);
+	if (res) {
+		if (!devm_request_region(dev, res->start, IT87_EC_EXTENT,
+					 DRVNAME)) {
+			dev_err(dev, "Failed to request region %pR\n", res);
+			return -EBUSY;
 		}
-		/* in8 (battery) has no limit registers */
-		data->in[8][0] = it87_read_value(data, IT87_REG_VIN(8));
-		if (data->type == it8603)
-			data->in[9][0] = it87_read_value(data, 0x2f);
+	} else {
+		res = platform_get_resource(pdev, IORESOURCE_MEM, 0);
+		data->mmio = devm_ioremap_resource(dev, res);
+		if (IS_ERR(data->mmio))
+			return PTR_ERR(data->mmio);
+	}
 
-		for (i = 0; i < 6; i++) {
-			/* Skip disabled fans */
-			if (!(data->has_fan & (1 << i)))
-				continue;
+	data->addr = res->start;
+	data->type = sio_data->type;
+	data->sioaddr = sio_data->sioaddr;
+	data->smbus_bitmap = sio_data->smbus_bitmap;
+	data->ec_special_config = sio_data->ec_special_config;
+	data->doexit = sio_data->doexit;
+	data->features = it87_devices[sio_data->type].features;
+	data->num_temp_limit = it87_devices[sio_data->type].num_temp_limit;
+	data->num_temp_offset = it87_devices[sio_data->type].num_temp_offset;
+	data->pwm_num_temp_map = it87_devices[sio_data->type].num_temp_map;
+	data->peci_mask = it87_devices[sio_data->type].peci_mask;
+	data->old_peci_mask = it87_devices[sio_data->type].old_peci_mask;
 
-			data->fan[i][1] =
-				it87_read_value(data, IT87_REG_FAN_MIN[i]);
-			data->fan[i][0] = it87_read_value(data,
-				       IT87_REG_FAN[i]);
-			/* Add high byte if in 16-bit mode */
-			if (has_16bit_fans(data)) {
-				data->fan[i][0] |= it87_read_value(data,
-						IT87_REG_FANX[i]) << 8;
-				data->fan[i][1] |= it87_read_value(data,
-						IT87_REG_FANX_MIN[i]) << 8;
-			}
+	/*
+	 * IT8705F Datasheet 0.4.1, 3h == Version G.
+	 * IT8712F Datasheet 0.9.1, section 8.3.5 indicates 8h == Version J.
+	 * These are the first revisions with 16-bit tachometer support.
+	 */
+	switch (data->type) {
+	case it87:
+		if (sio_data->revision >= 0x03) {
+			data->features &= ~FEAT_OLD_AUTOPWM;
+			data->features |= FEAT_FAN16_CONFIG | FEAT_16BIT_FANS;
 		}
-		for (i = 0; i < 3; i++) {
-			if (!(data->has_temp & (1 << i)))
-				continue;
-			data->temp[i][0] =
-				it87_read_value(data, IT87_REG_TEMP(i));
-			data->temp[i][1] =
-				it87_read_value(data, IT87_REG_TEMP_LOW(i));
-			data->temp[i][2] =
-				it87_read_value(data, IT87_REG_TEMP_HIGH(i));
-			if (has_temp_offset(data))
-				data->temp[i][3] =
-				  it87_read_value(data,
-						  IT87_REG_TEMP_OFFSET[i]);
+		break;
+	case it8712:
+		if (sio_data->revision >= 0x08) {
+			data->features &= ~FEAT_OLD_AUTOPWM;
+			data->features |= FEAT_FAN16_CONFIG | FEAT_16BIT_FANS |
+					  FEAT_FIVE_FANS;
 		}
+		break;
+	default:
+		break;
+	}
 
-		/* Newer chips don't have clock dividers */
-		if ((data->has_fan & 0x07) && !has_16bit_fans(data)) {
-			i = it87_read_value(data, IT87_REG_FAN_DIV);
-			data->fan_div[0] = i & 0x07;
-			data->fan_div[1] = (i >> 3) & 0x07;
-			data->fan_div[2] = (i & 0x40) ? 3 : 1;
-		}
+	platform_set_drvdata(pdev, data);
 
-		data->alarms =
-			it87_read_value(data, IT87_REG_ALARM1) |
-			(it87_read_value(data, IT87_REG_ALARM2) << 8) |
-			(it87_read_value(data, IT87_REG_ALARM3) << 16);
-		data->beeps = it87_read_value(data, IT87_REG_BEEP_ENABLE);
-
-		data->fan_main_ctrl = it87_read_value(data,
-				IT87_REG_FAN_MAIN_CTRL);
-		data->fan_ctl = it87_read_value(data, IT87_REG_FAN_CTL);
-		for (i = 0; i < 3; i++)
-			it87_update_pwm_ctrl(data, i);
+	mutex_init(&data->update_lock);
 
-		data->sensor = it87_read_value(data, IT87_REG_TEMP_ENABLE);
-		data->extra = it87_read_value(data, IT87_REG_TEMP_EXTRA);
-		/*
-		 * The IT8705F does not have VID capability.
-		 * The IT8718F and later don't use IT87_REG_VID for the
-		 * same purpose.
-		 */
-		if (data->type == it8712 || data->type == it8716) {
-			data->vid = it87_read_value(data, IT87_REG_VID);
-			/*
-			 * The older IT8712F revisions had only 5 VID pins,
-			 * but we assume it is always safe to read 6 bits.
-			 */
-			data->vid &= 0x3f;
-		}
-		data->last_updated = jiffies;
-		data->valid = 1;
+	/* Initialize register pointers */
+	it87_init_regs(pdev);
+
+	/*
+	 * We need to disable SMBus before we can read any registers in
+	 * the envmon address space, even if it is for chip identification
+	 * purposes. If the chip has SMBus client support, it likely also has
+	 * multi-page envmon registers, so we have to set the page anyway
+	 * before accessing those registers. Kind of a chicken-and-egg
+	 * problem.
+	 * Fortunately, the chip was already identified through the SIO
+	 * address space, only recent chips are affected, and this is just
+	 * an additional safeguard.
+	 */
+	err = smbus_disable(data);
+	if (err)
+		return err;
+
+	/* Now, we do the remaining detection. */
+	if ((data->read(data, IT87_REG_CONFIG) & 0x80) ||
+	    data->read(data, IT87_REG_CHIPID) != 0x90) {
+		smbus_enable(data);
+		return -ENODEV;
 	}
 
-	mutex_unlock(&data->update_lock);
+	/* Check PWM configuration */
+	enable_pwm_interface = it87_check_pwm(dev);
+
+	/* Starting with IT8721F, we handle scaling of internal voltages */
+	if (has_scaling(data)) {
+		if (sio_data->internal & BIT(0))
+			data->in_scaled |= BIT(3);	/* in3 is AVCC */
+		if (sio_data->internal & BIT(1))
+			data->in_scaled |= BIT(7);	/* in7 is VSB */
+		if (sio_data->internal & BIT(2))
+			data->in_scaled |= BIT(8);	/* in8 is Vbat */
+		if (sio_data->internal & BIT(3))
+			data->in_scaled |= BIT(9);	/* in9 is AVCC */
+	} else if (sio_data->type == it8781 || sio_data->type == it8782 ||
+		   sio_data->type == it8783) {
+		if (sio_data->internal & BIT(0))
+			data->in_scaled |= BIT(3);	/* in3 is VCC5V */
+		if (sio_data->internal & BIT(1))
+			data->in_scaled |= BIT(7);	/* in7 is VCCH5V */
+	}
+
+	data->has_temp = 0x07;
+	if (sio_data->skip_temp & BIT(2)) {
+		if (sio_data->type == it8782 &&
+		    !(data->read(data, IT87_REG_TEMP_EXTRA) & 0x80))
+			data->has_temp &= ~BIT(2);
+	}
+
+	data->in_internal = sio_data->internal;
+	data->has_in = 0x3ff & ~sio_data->skip_in;
+
+	if (has_four_temp(data)) {
+		data->has_temp |= BIT(3);
+	} else if (has_six_temp(data)) {
+		u8 reg = data->read(data, IT87_REG_TEMP456_ENABLE);
+
+		/* Check for additional temperature sensors */
+		if ((reg & 0x03) >= 0x02)
+			data->has_temp |= BIT(3);
+		if (((reg >> 2) & 0x03) >= 0x02)
+			data->has_temp |= BIT(4);
+		if (((reg >> 4) & 0x03) >= 0x02)
+			data->has_temp |= BIT(5);
+
+		/* Check for additional voltage sensors */
+		if ((reg & 0x03) == 0x01)
+			data->has_in |= BIT(10);
+		if (((reg >> 2) & 0x03) == 0x01)
+			data->has_in |= BIT(11);
+		if (((reg >> 4) & 0x03) == 0x01)
+			data->has_in |= BIT(12);
+	}
+
+	data->has_beep = !!sio_data->beep_pin;
+
+	/* Initialize the IT87 chip */
+	it87_init_device(pdev);
 
-	return data;
+	smbus_enable(data);
+
+	if (!sio_data->skip_vid) {
+		data->has_vid = true;
+		data->vrm = vid_which_vrm();
+		/* VID reading from Super-I/O config space if available */
+		data->vid = sio_data->vid_value;
+	}
+
+	/* Prepare for sysfs hooks */
+	data->groups[0] = &it87_group;
+	data->groups[1] = &it87_group_in;
+	data->groups[2] = &it87_group_temp;
+	data->groups[3] = &it87_group_fan;
+
+	if (enable_pwm_interface) {
+		data->has_pwm = BIT(ARRAY_SIZE(IT87_REG_PWM)) - 1;
+		data->has_pwm &= ~sio_data->skip_pwm;
+
+		data->groups[4] = &it87_group_pwm;
+		if (has_old_autopwm(data) || has_newer_autopwm(data))
+			data->groups[5] = &it87_group_auto_pwm;
+	}
+
+	hwmon_dev = devm_hwmon_device_register_with_groups(dev,
+					it87_devices[sio_data->type].name,
+					data, data->groups);
+	return PTR_ERR_OR_ZERO(hwmon_dev);
 }
 
-static int __init it87_device_add(unsigned short address,
+static struct platform_driver it87_driver = {
+	.driver = {
+		.name	= DRVNAME,
+	},
+	.probe	= it87_probe,
+};
+
+static int __init it87_device_add(int index, unsigned short sio_address,
+				  phys_addr_t mmio_address,
 				  const struct it87_sio_data *sio_data)
 {
+	struct platform_device *pdev;
 	struct resource res = {
-		.start	= address + IT87_EC_OFFSET,
-		.end	= address + IT87_EC_OFFSET + IT87_EC_EXTENT - 1,
 		.name	= DRVNAME,
-		.flags	= IORESOURCE_IO,
 	};
 	int err;
 
-	err = acpi_check_resource_conflict(&res);
-	if (err)
-		goto exit;
+	if (mmio_address) {
+		res.start = mmio_address;
+		res.end	= mmio_address + 0x400 - 1;
+		res.flags = IORESOURCE_MEM;
+	} else {
+		res.start = sio_address + IT87_EC_OFFSET;
+		res.end	= sio_address + IT87_EC_OFFSET + IT87_EC_EXTENT - 1;
+		res.flags = IORESOURCE_IO;
+	}
 
-	pdev = platform_device_alloc(DRVNAME, address);
-	if (!pdev) {
-		err = -ENOMEM;
-		pr_err("Device allocation failed\n");
-		goto exit;
+	err = acpi_check_resource_conflict(&res);
+	if (err) {
+		if (!ignore_resource_conflict)
+			return err;
 	}
 
+	pdev = platform_device_alloc(DRVNAME, sio_address);
+	if (!pdev)
+		return -ENOMEM;
+
 	err = platform_device_add_resources(pdev, &res, 1);
 	if (err) {
 		pr_err("Device resource addition failed (%d)\n", err);
@@ -2809,52 +4165,156 @@ static int __init it87_device_add(unsigned short address,
 		goto exit_device_put;
 	}
 
+	it87_pdev[index] = pdev;
 	return 0;
 
 exit_device_put:
 	platform_device_put(pdev);
-exit:
 	return err;
 }
 
+struct it87_dmi_data {
+	bool sio2_force_config;	/* force sio2 into configuration mode	*/
+	u8 skip_pwm;		/* pwm channels to skip for this board	*/
+};
+
+/*
+ * On various Gigabyte AM4 boards (AB350, AX370), the second Super-IO chip
+ * (IT8792E) needs to be in configuration mode before accessing the first
+ * due to a bug in IT8792E which otherwise results in LPC bus access errors.
+ * This needs to be done before accessing the first Super-IO chip since
+ * the second chip may have been accessed prior to loading this driver.
+ *
+ * The problem is also reported to affect IT8795E, which is used on X299 boards
+ * and has the same chip ID as IT8792E (0x8733). It also appears to affect
+ * systems with IT8790E, which is used on some Z97X-Gaming boards as well as
+ * Z87X-OC.
+ * DMI entries for those systems will be added as they become available and
+ * as the problem is confirmed to affect those boards.
+ */
+static struct it87_dmi_data gigabyte_sio2_force = {
+	.sio2_force_config = true,
+};
+
+/*
+ * On the Shuttle SN68PT, FAN_CTL2 is apparently not
+ * connected to a fan, but to something else. One user
+ * has reported instant system power-off when changing
+ * the PWM2 duty cycle, so we disable it.
+ * I use the board name string as the trigger in case
+ * the same board is ever used in other systems.
+ */
+static struct it87_dmi_data nvidia_fn68pt = {
+	.skip_pwm = BIT(1),
+};
+
+static const struct dmi_system_id it87_dmi_table[] __initconst = {
+	{
+		.matches = {
+			DMI_MATCH(DMI_SYS_VENDOR,
+				  "Gigabyte Technology Co., Ltd."),
+			DMI_MATCH(DMI_BOARD_NAME, "AB350"),
+		},
+		.driver_data = &gigabyte_sio2_force,
+	},
+	{
+		.matches = {
+			DMI_MATCH(DMI_SYS_VENDOR,
+				  "Gigabyte Technology Co., Ltd."),
+			DMI_MATCH(DMI_BOARD_NAME, "AX370"),
+		},
+		.driver_data = &gigabyte_sio2_force,
+	},
+	{
+		.matches = {
+			DMI_MATCH(DMI_SYS_VENDOR,
+				  "Gigabyte Technology Co., Ltd."),
+			DMI_MATCH(DMI_BOARD_NAME, "Z97X-Gaming G1"),
+		},
+		.driver_data = &gigabyte_sio2_force,
+	},
+	{
+		.matches = {
+			DMI_MATCH(DMI_BOARD_VENDOR, "nVIDIA"),
+			DMI_MATCH(DMI_BOARD_NAME, "FN68PT"),
+		},
+		.driver_data = &nvidia_fn68pt,
+	},
+	{ }
+};
+
 static int __init sm_it87_init(void)
 {
-	int err;
-	unsigned short isa_address = 0;
+	const struct dmi_system_id *dmi = dmi_first_match(it87_dmi_table);
+	struct it87_dmi_data *dmi_data = NULL;
+	int sioaddr[2] = { REG_2E, REG_4E };
 	struct it87_sio_data sio_data;
+	unsigned short isa_address;
+	phys_addr_t mmio_address;
+	bool found = false;
+	int i, err;
+
+	pr_info("it87 driver version %s\n", IT87_DRIVER_VERSION);
+
+	if (dmi)
+		dmi_data = dmi->driver_data;
 
-	memset(&sio_data, 0, sizeof(struct it87_sio_data));
-	err = it87_find(&isa_address, &sio_data);
-	if (err)
-		return err;
 	err = platform_driver_register(&it87_driver);
 	if (err)
 		return err;
 
-	err = it87_device_add(isa_address, &sio_data);
-	if (err) {
-		platform_driver_unregister(&it87_driver);
-		return err;
+	if (dmi_data && dmi_data->sio2_force_config)
+		__superio_enter(REG_4E);
+
+	for (i = 0; i < ARRAY_SIZE(sioaddr); i++) {
+		memset(&sio_data, 0, sizeof(struct it87_sio_data));
+		isa_address = 0;
+		mmio_address = 0;
+		err = it87_find(sioaddr[i], &isa_address, &mmio_address,
+				&sio_data);
+		if (err || isa_address == 0)
+			continue;
+
+		if (dmi_data)
+			sio_data.skip_pwm |= dmi_data->skip_pwm;
+		err = it87_device_add(i, isa_address, mmio_address, &sio_data);
+		if (err)
+			goto exit_dev_unregister;
+		found = true;
 	}
 
+	if (!found) {
+		err = -ENODEV;
+		goto exit_unregister;
+	}
 	return 0;
+
+exit_dev_unregister:
+	/* NULL check handled by platform_device_unregister */
+	platform_device_unregister(it87_pdev[0]);
+exit_unregister:
+	platform_driver_unregister(&it87_driver);
+	return err;
 }
 
 static void __exit sm_it87_exit(void)
 {
-	platform_device_unregister(pdev);
+	/* NULL check handled by platform_device_unregister */
+	platform_device_unregister(it87_pdev[1]);
+	platform_device_unregister(it87_pdev[0]);
 	platform_driver_unregister(&it87_driver);
 }
 
-
 MODULE_AUTHOR("Chris Gauthron, Jean Delvare <jdelvare@suse.de>");
 MODULE_DESCRIPTION("IT8705F/IT871xF/IT872xF hardware monitoring driver");
-module_param(update_vbat, bool, 0);
+module_param(update_vbat, bool, 0000);
 MODULE_PARM_DESC(update_vbat, "Update vbat if set else return powerup value");
-module_param(fix_pwm_polarity, bool, 0);
+module_param(fix_pwm_polarity, bool, 0000);
 MODULE_PARM_DESC(fix_pwm_polarity,
 		 "Force PWM polarity to active high (DANGEROUS)");
 MODULE_LICENSE("GPL");
+MODULE_VERSION(IT87_DRIVER_VERSION);
 
 module_init(sm_it87_init);
 module_exit(sm_it87_exit);
+
diff --git a/drivers/md/md.c b/drivers/md/md.c
index 0a856cb..9809b06 100644
--- a/drivers/md/md.c
+++ b/drivers/md/md.c
@@ -54,6 +54,9 @@
 #include "md.h"
 #include "bitmap.h"
 #include "md-cluster.h"
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+#include <buffalo/kernevnt.h>
+#endif	/* CONFIG_BUFFALO_USE_KERNEVNT */
 
 #ifndef MODULE
 static void autostart_arrays(int part);
@@ -100,7 +103,17 @@ static void mddev_detach(struct mddev *mddev);
  */
 
 static int sysctl_speed_limit_min = 1000;
+#ifdef CONFIG_BUFFALO_PLATFORM
+static int sysctl_speed_limit_max = 50000;
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+static int sysctl_skip_resync = 0;
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
+#ifdef CONFIG_BUFFALO_USE_MD_KERNEVNT
+static int sysctl_use_kernevnt = 1;
+#endif	/* CONFIG_BUFFALO_USE_MD_KERNEVNT */
+#else	/* CONFIG_BUFFALO_PLATFORM */
 static int sysctl_speed_limit_max = 200000;
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 static inline int speed_min(struct mddev *mddev)
 {
 	return mddev->sync_speed_min ?
@@ -123,6 +136,24 @@ static struct ctl_table raid_table[] = {
 		.mode		= S_IRUGO|S_IWUSR,
 		.proc_handler	= proc_dointvec,
 	},
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+	{
+		.procname	= "skip_resync",
+		.data		= &sysctl_skip_resync,
+		.maxlen		= sizeof(int),
+		.mode		= S_IRUGO|S_IWUSR,
+		.proc_handler	= proc_dointvec,
+	},
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
+#ifdef CONFIG_BUFFALO_USE_MD_KERNEVNT
+	{
+		.procname	= "use_kernevnt",
+		.data		= &sysctl_use_kernevnt,
+		.maxlen		= sizeof(int),
+		.mode		= S_IRUGO|S_IWUSR,
+		.proc_handler	= proc_dointvec,
+	},
+#endif	/* CONFIG_BUFFALO_USE_MD_KERNEVNT */
 	{
 		.procname	= "speed_limit_max",
 		.data		= &sysctl_speed_limit_max,
@@ -3774,6 +3805,55 @@ chunk_size_store(struct mddev *mddev, const char *buf, size_t len)
 static struct md_sysfs_entry md_chunk_size =
 __ATTR(chunk_size, S_IRUGO|S_IWUSR, chunk_size_show, chunk_size_store);
 
+#ifdef CONFIG_BUFFALO_ERRCNT
+static ssize_t
+maxerr_cnt_show(struct mddev *mddev, char *page)
+{
+	return sprintf(page, "%d\n", atomic_read(&mddev->maxerr_cnt));
+}
+
+static ssize_t
+maxerr_cnt_store(struct mddev *mddev, const char *buf, size_t len)
+{
+	char *e;
+	unsigned long n = simple_strtol(buf, &e, 10);
+
+	if (*buf &&
+	    (*e == 0 || *e == '\n') &&
+	    (n == -1 || (signed int)n >= 0)) {
+		atomic_set(&mddev->maxerr_cnt, n);
+		return len;
+	}
+	return -EINVAL;
+}
+static struct md_sysfs_entry md_maxerr_cnt =
+__ATTR(maxerr_cnt, S_IRUGO|S_IWUSR, maxerr_cnt_show, maxerr_cnt_store);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+static ssize_t
+skip_resync_show(struct mddev *mddev, char *page)
+{
+	return sprintf(page, "%d\n", atomic_read(&mddev->skip_resync));
+}
+static ssize_t
+skip_resync_store(struct mddev *mddev, const char *buf, size_t len)
+{
+	char *e;
+	unsigned long n = simple_strtol(buf, &e, 10);
+
+	if (*buf &&
+	    (*e == 0 || *e == '\n') &&
+	    (n == 1 || n == 0)) {
+		atomic_set(&mddev->skip_resync, n);
+		return len;
+	}
+	return -EINVAL;
+}
+static struct md_sysfs_entry md_skip_resync =
+__ATTR(skip_resync, S_IRUGO|S_IWUSR, skip_resync_show, skip_resync_store);
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
+
 static ssize_t
 resync_start_show(struct mddev *mddev, char *page)
 {
@@ -4850,6 +4930,12 @@ __ATTR(array_size, S_IRUGO|S_IWUSR, array_size_show,
 static struct attribute *md_default_attrs[] = {
 	&md_level.attr,
 	&md_layout.attr,
+#ifdef CONFIG_BUFFALO_ERRCNT
+	&md_maxerr_cnt.attr,
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+	&md_skip_resync.attr,
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
 	&md_raid_disks.attr,
 	&md_chunk_size.attr,
 	&md_size.attr,
@@ -5326,6 +5412,12 @@ int md_run(struct mddev *mddev)
 	if (mddev->flags & MD_UPDATE_SB_FLAGS)
 		md_update_sb(mddev, 0);
 
+#ifdef CONFIG_BUFFALO_ERRCNT
+	atomic_set(&mddev->maxerr_cnt, MAXERR_CNT_DEFAULT);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+	atomic_set(&mddev->skip_resync, 0);
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
 	md_new_event(mddev);
 	sysfs_notify_dirent_safe(mddev->sysfs_state);
 	sysfs_notify_dirent_safe(mddev->sysfs_action);
@@ -7179,6 +7271,12 @@ void md_error(struct mddev *mddev, struct md_rdev *rdev)
 	if (!rdev || test_bit(Faulty, &rdev->flags))
 		return;
 
+#ifdef CONFIG_BUFFALO_USE_MD_DEGRADE_KERNEVNT
+	if (sysctl_use_kernevnt)
+		kernevnt_RaidDegraded(mddev->md_minor,
+				      MAJOR(rdev->bdev->bd_dev),
+				      MINOR(rdev->bdev->bd_dev));
+#endif	/* CONFIG_BUFFALO_USE_MD_DEGRADE_KERNEVNT */
 	if (!mddev->pers || !mddev->pers->error_handler)
 		return;
 	mddev->pers->error_handler(mddev,rdev);
@@ -7764,7 +7862,13 @@ void md_do_sync(struct md_thread *thread)
 	char *desc, *action = NULL;
 	struct blk_plug plug;
 	bool cluster_resync_finished = false;
+#ifdef CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT
+	int isRecovery, major=0, minor=0;
+#endif /* CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT */
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	set_user_nice(current, 4);
+#endif /* CONFIG_BUFFALO_PLATFORM */
 	/* just incase thread restarts... */
 	if (test_bit(MD_RECOVERY_DONE, &mddev->recovery))
 		return;
@@ -7782,6 +7886,12 @@ void md_do_sync(struct md_thread *thread)
 			action = "repair";
 		} else
 			desc = "resync";
+#ifdef CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT
+		if (test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+		    test_bit(MD_RECOVERY_REQUESTED, &mddev->recovery) &&
+		    !test_bit(MD_RECOVERY_CHECK, &mddev->recovery))
+			kernevnt_RaidScan(mddev->md_minor, 1);
+#endif	/* CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT */
 	} else if (test_bit(MD_RECOVERY_RESHAPE, &mddev->recovery))
 		desc = "reshape";
 	else
@@ -7893,6 +8003,30 @@ void md_do_sync(struct md_thread *thread)
 			mddev->pers->quiesce(mddev, 0);
 		}
 	}
+#ifdef CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT
+	if (sysctl_use_kernevnt) {
+		if((test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+		    !test_bit(MD_RECOVERY_REQUESTED, &mddev->recovery)) ||
+		   (!test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+		    test_bit(MD_RECOVERY_RECOVER, &mddev->recovery))) {
+			struct md_rdev *rdev_tmp;
+			list_for_each_entry(rdev_tmp, &mddev->disks, same_set){
+				if (rdev_tmp->flags != In_sync) {
+					major = MAJOR(rdev_tmp->bdev->bd_dev);
+					minor = MINOR(rdev_tmp->bdev->bd_dev);
+					break;
+				}
+			}
+			isRecovery = !test_bit(MD_RECOVERY_SYNC,
+					       &mddev->recovery);
+			kernevnt_RaidRecovery(mddev->md_minor, 1,
+					      isRecovery, major, minor);
+		}
+		else if ((test_bit(MD_RECOVERY_RESHAPE, &mddev->recovery))) {
+			kernevnt_RaidReshape(mddev->md_minor, 1);
+		}
+	}
+#endif	/* CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT */
 
 	printk(KERN_INFO "md: %s of RAID array %s\n", desc, mdname(mddev));
 	printk(KERN_INFO "md: minimum _guaranteed_  speed:"
@@ -7938,6 +8072,12 @@ void md_do_sync(struct md_thread *thread)
 	while (j < max_sectors) {
 		sector_t sectors;
 
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+		if (sysctl_skip_resync || atomic_read(&mddev->skip_resync)) {
+			mddev->curr_resync = max_sectors;
+			break;
+		}
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
 		skipped = 0;
 
 		if (!test_bit(MD_RECOVERY_RESHAPE, &mddev->recovery) &&
@@ -8060,6 +8200,20 @@ void md_do_sync(struct md_thread *thread)
 	 */
 	blk_finish_plug(&plug);
 	wait_event(mddev->recovery_wait, !atomic_read(&mddev->recovery_active));
+#ifdef CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT
+	if (sysctl_use_kernevnt) {
+		if((test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+		    !test_bit(MD_RECOVERY_REQUESTED, &mddev->recovery)) ||
+		   (!test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+		    test_bit(MD_RECOVERY_RECOVER, &mddev->recovery)))
+			kernevnt_RaidRecovery(mddev->md_minor, 0,
+					      isRecovery, major, minor);
+                else if((test_bit(MD_RECOVERY_RESHAPE, &mddev->recovery))) {
+			printk("RaidReshape(mddev->md_minor, 0)\n");
+			kernevnt_RaidReshape(mddev->md_minor, 0);
+		}
+	}
+#endif	/* CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT */
 
 	if (!test_bit(MD_RECOVERY_RESHAPE, &mddev->recovery) &&
 	    !test_bit(MD_RECOVERY_INTR, &mddev->recovery) &&
@@ -8126,6 +8280,12 @@ void md_do_sync(struct md_thread *thread)
 	set_bit(MD_RECOVERY_DONE, &mddev->recovery);
 	mddev->curr_resync = 0;
 	spin_unlock(&mddev->lock);
+#ifdef CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT
+	if (test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+	    test_bit(MD_RECOVERY_REQUESTED, &mddev->recovery) &&
+	    !test_bit(MD_RECOVERY_CHECK, &mddev->recovery))
+		kernevnt_RaidScan(mddev->md_minor, 0);
+#endif /* CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT */
 
 	wake_up(&resync_wait);
 	md_wakeup_thread(mddev->thread);
diff --git a/drivers/md/md.h b/drivers/md/md.h
index dfa57b4..50ec4f5 100644
--- a/drivers/md/md.h
+++ b/drivers/md/md.h
@@ -464,6 +464,18 @@ struct mddev {
 	struct work_struct event_work;	/* used by dm to report failure event */
 	void (*sync_super)(struct mddev *mddev, struct md_rdev *rdev);
 	struct md_cluster_info		*cluster_info;
+#ifdef CONFIG_BUFFALO_ERRCNT
+#define MAXERR_CNT_DEFAULT		1000
+	atomic_t			maxerr_cnt; /* If rdev->bdev->bd_disk->
+						     * nr_err reaches to
+						     * maxerr_cnt (excepting
+						     * maxerr_cnt is -1),
+						     * disk will be faulty.
+						     */
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+	atomic_t			skip_resync;
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
 };
 
 static inline int __must_check mddev_lock(struct mddev *mddev)
diff --git a/drivers/md/raid1.c b/drivers/md/raid1.c
index f24a9e1..391ca5b 100644
--- a/drivers/md/raid1.c
+++ b/drivers/md/raid1.c
@@ -321,12 +321,30 @@ static void raid1_end_read_request(struct bio *bio)
 	struct r1bio *r1_bio = bio->bi_private;
 	int mirror;
 	struct r1conf *conf = r1_bio->mddev->private;
+#ifdef CONFIG_BUFFALO_ERRCNT
+	struct md_rdev *rdev;
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 
 	mirror = r1_bio->read_disk;
 	/*
 	 * this branch is our 'one mirror IO has finished' event handler:
 	 */
 	update_head_pos(mirror, r1_bio);
+#ifdef CONFIG_BUFFALO_ERRCNT
+	rcu_read_lock();
+	rdev = rcu_dereference(conf->mirrors[r1_bio->read_disk].rdev);
+	if (rdev != NULL) {
+		int maxerr_cnt = atomic_read(&conf->mddev->maxerr_cnt);
+
+		if (atomic_read(&rdev->bdev->bd_disk->nr_errs) > maxerr_cnt &&
+		    maxerr_cnt != -1)
+			if (conf->raid_disks - r1_bio->mddev->degraded != 1) {
+				rcu_read_unlock();
+				goto do_degrade;
+			}
+	}
+	rcu_read_unlock();
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 
 	if (uptodate)
 		set_bit(R1BIO_Uptodate, &r1_bio->state);
@@ -352,6 +370,9 @@ static void raid1_end_read_request(struct bio *bio)
 		 * oops, read error:
 		 */
 		char b[BDEVNAME_SIZE];
+#ifdef CONFIG_BUFFALO_ERRCNT
+do_degrade:
+#endif /* CONFIG_BUFFALO_ERRCNT */
 		printk_ratelimited(
 			KERN_ERR "md/raid1:%s: %s: "
 			"rescheduling sector %llu\n",
@@ -2021,6 +2042,23 @@ static void sync_request_write(struct mddev *mddev, struct r1bio *r1_bio)
 
 	if (test_bit(MD_RECOVERY_REQUESTED, &mddev->recovery))
 		process_checks(r1_bio);
+#ifdef CONFIG_BUFFALO_ERRCNT
+	rcu_read_lock();
+	for (i = 0; i < mddev->raid_disks; i++) {
+		struct md_rdev *rdev = rcu_dereference(conf->mirrors[i].rdev);
+		int maxerr_cnt = atomic_read(&mddev->maxerr_cnt);
+
+		if (r1_bio->bios[i]->bi_end_io != end_sync_read ||
+		    rdev == NULL)
+			continue;
+
+		if (atomic_read(&rdev->bdev->bd_disk->nr_errs) > maxerr_cnt &&
+		    maxerr_cnt != -1)
+			if (!test_bit(Faulty, &conf->mirrors[i].rdev->flags))
+				md_error(mddev, conf->mirrors[i].rdev);
+	}
+	rcu_read_unlock();
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 
 	/*
 	 * schedule writes
@@ -2310,6 +2348,16 @@ static void handle_read_error(struct r1conf *conf, struct r1bio *r1_bio)
 		freeze_array(conf, 1);
 		fix_read_error(conf, r1_bio->read_disk,
 			       r1_bio->sector, r1_bio->sectors);
+#ifdef CONFIG_BUFFALO_ERRCNT
+		rdev = conf->mirrors[r1_bio->read_disk].rdev;
+		if (rdev != NULL) {
+			int maxerr_cnt =
+				atomic_read(&mddev->maxerr_cnt);
+			if (atomic_read(&rdev->bdev->bd_disk->nr_errs) > maxerr_cnt &&
+			    maxerr_cnt != -1)
+				md_error(mddev, rdev);
+		}
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 		unfreeze_array(conf);
 	} else
 		md_error(mddev, conf->mirrors[r1_bio->read_disk].rdev);
diff --git a/drivers/md/raid5.c b/drivers/md/raid5.c
index 86ab6d1..7aa3210 100644
--- a/drivers/md/raid5.c
+++ b/drivers/md/raid5.c
@@ -2303,6 +2303,9 @@ static void raid5_end_read_request(struct bio * bi)
 	char b[BDEVNAME_SIZE];
 	struct md_rdev *rdev = NULL;
 	sector_t s;
+#ifdef CONFIG_BUFFALO_ERRCNT
+	int error = bi->bi_error;
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 
 	for (i=0 ; i<disks; i++)
 		if (bi == &sh->dev[i].req)
@@ -2329,7 +2332,22 @@ static void raid5_end_read_request(struct bio * bi)
 		s = sh->sector + rdev->new_data_offset;
 	else
 		s = sh->sector + rdev->data_offset;
+#ifdef CONFIG_BUFFALO_ERRCNT
+	if (!(conf->mddev->degraded)) {
+		int maxerr_cnt = atomic_read(&conf->mddev->maxerr_cnt);
+
+		rdev = conf->disks[i].rdev;
+		if (atomic_read(&rdev->bdev->bd_disk->nr_errs) > maxerr_cnt &&
+		    maxerr_cnt != -1)
+			if (!error)
+				error = -EIO;
+	}
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#ifdef CONFIG_BUFFALO_ERRCNT
+	if (!error) {
+#else	/* CONFIG_BUFFALO_ERRCNT */
 	if (!bi->bi_error) {
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 		set_bit(R5_UPTODATE, &sh->dev[i].flags);
 		if (test_bit(R5_ReadError, &sh->dev[i].flags)) {
 			/* Note that this cannot happen on a
@@ -2395,12 +2413,38 @@ static void raid5_end_read_request(struct bio * bi)
 		if (set_bad && test_bit(In_sync, &rdev->flags)
 		    && !test_bit(R5_ReadNoMerge, &sh->dev[i].flags))
 			retry = 1;
+#ifdef CONFIG_BUFFALO_ERRCNT
+		if (retry) {
+			int maxerr_cnt;
+
+			if (test_bit(R5_ReadNoMerge, &sh->dev[i].flags)) {
+				set_bit(R5_ReadError, &sh->dev[i].flags);
+				clear_bit(R5_ReadNoMerge, &sh->dev[i].flags);
+			} else
+				set_bit(R5_ReadNoMerge, &sh->dev[i].flags);
+
+			printk("debug: Read Error dev[%d]: sector %llu(sh->sector=%llu)\n",
+			       i, (unsigned long long)sh->dev[i].sector,
+			       (unsigned long long)sh->sector);
+			/*
+			 * Don't forget the bracket {} put in the outside of
+			 * this macro, if you port this code to another
+			 * version of Linux.
+			 */
+			maxerr_cnt = atomic_read(&conf->mddev->maxerr_cnt);
+			rdev = conf->disks[i].rdev;
+			if (atomic_read(&rdev->bdev->bd_disk->nr_errs) > maxerr_cnt &&
+			    maxerr_cnt != -1)
+				md_error(conf->mddev, conf->disks[i].rdev);
+		}
+#else	/* CONFIG_BUFFALO_ERRCNT */
 		if (retry)
 			if (test_bit(R5_ReadNoMerge, &sh->dev[i].flags)) {
 				set_bit(R5_ReadError, &sh->dev[i].flags);
 				clear_bit(R5_ReadNoMerge, &sh->dev[i].flags);
 			} else
 				set_bit(R5_ReadNoMerge, &sh->dev[i].flags);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 		else {
 			clear_bit(R5_ReadError, &sh->dev[i].flags);
 			clear_bit(R5_ReWrite, &sh->dev[i].flags);
diff --git a/drivers/net/ethernet/Kconfig b/drivers/net/ethernet/Kconfig
index 31c5e47..f43534c 100644
--- a/drivers/net/ethernet/Kconfig
+++ b/drivers/net/ethernet/Kconfig
@@ -178,4 +178,6 @@ source "drivers/net/ethernet/wiznet/Kconfig"
 source "drivers/net/ethernet/xilinx/Kconfig"
 source "drivers/net/ethernet/xircom/Kconfig"
 
+source "drivers/net/ethernet/aquantia/Kconfig"
+
 endif # ETHERNET
diff --git a/drivers/net/ethernet/Makefile b/drivers/net/ethernet/Makefile
index 071f84e..5b6a8f0 100644
--- a/drivers/net/ethernet/Makefile
+++ b/drivers/net/ethernet/Makefile
@@ -87,3 +87,4 @@ obj-$(CONFIG_NET_VENDOR_VIA) += via/
 obj-$(CONFIG_NET_VENDOR_WIZNET) += wiznet/
 obj-$(CONFIG_NET_VENDOR_XILINX) += xilinx/
 obj-$(CONFIG_NET_VENDOR_XIRCOM) += xircom/
+obj-$(CONFIG_AQTION) += aquantia/
diff --git a/drivers/net/ethernet/aquantia/Kconfig b/drivers/net/ethernet/aquantia/Kconfig
new file mode 100644
index 00000000..5edc4ef
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/Kconfig
@@ -0,0 +1,9 @@
+#
+# aQuantia device configuration
+#
+
+config AQTION
+	tristate "aQuantia AQtion(tm) Support"
+	depends on PCI
+	---help---
+	  This enables the support for the aQuantia AQtion(tm) Ethernet card.
diff --git a/drivers/net/ethernet/aquantia/Makefile b/drivers/net/ethernet/aquantia/Makefile
new file mode 100644
index 00000000..f6e9adb
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/Makefile
@@ -0,0 +1,86 @@
+################################################################################
+#
+# aQuantia Ethernet Controller AQtion Linux Driver
+# Copyright(c) 2014-2017 aQuantia Corporation.
+#
+# This program is free software; you can redistribute it and/or modify it
+# under the terms and conditions of the GNU General Public License,
+# version 2, as published by the Free Software Foundation.
+#
+# This program is distributed in the hope it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+# more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with this program. If not, see <http://www.gnu.org/licenses/>.
+#
+# The full GNU General Public License is included in this distribution in
+# the file called "COPYING".
+#
+# Contact Information: <rdc-drv@aquantia.com>
+# aQuantia Corporation, 105 E. Tasman Dr. San Jose, CA 95134, USA
+#
+################################################################################
+
+#
+# Makefile for the AQtion(tm) Ethernet driver
+#
+
+
+TARGET := atlantic
+
+CC = gcc
+
+ifeq "$(CC)" "gcc"
+	ccflags-y := -Wall
+endif
+
+ifeq "$(CC)" "clang-3.5"
+	ccflags-y := -Wno-date-time -W --system-header-prefix=linux/ \
+	-fsanitize=integer,address,undefined,alignment,bool,bounds,null,\
+	enum,integer-divide-by-zero,shift,unreachable,unsigned-integer-overflow
+endif
+
+ifneq ($(KERNELRELEASE),)
+	$(TARGET)-objs:=aq_main.o aq_nic.o aq_pci_func.o aq_nic.o aq_vec.o aq_ring.o \
+	aq_hw_utils.o aq_ethtool.o aq_drvinfo.o hw_atl/hw_atl_a0.o hw_atl/hw_atl_b0.o hw_atl/hw_atl_utils.o\
+	hw_atl/hw_atl_utils_fw2x.o \
+	hw_atl/hw_atl_llh.o
+
+	obj-$(CONFIG_AQTION):=$(TARGET).o
+else
+	ifndef KDIR
+		BUILD_DIR:=/lib/modules/$(shell uname -r)/build
+	else
+		BUILD_DIR:=$(KDIR)
+	endif
+
+	PWD:=$(shell pwd)
+
+all:
+	$(MAKE) -j4 CC=$(CC) -C $(BUILD_DIR) M=$(PWD) modules
+
+dox:	.doxygen
+	@doxygen $<
+
+clean:
+	$(MAKE) -j4 -C $(BUILD_DIR) M=$(PWD) clean
+	@-rm -rdf doc/html 2 > /dev/null
+
+load:
+	insmod ./$(TARGET).ko
+
+unload:
+	rmmod ./$(TARGET).ko
+
+install:
+	@install -D -m 644 ${TARGET}.ko /lib/modules/$(shell uname -r)/aquantia/${TARGET}.ko
+	@depmod -a $(shell uname -r)
+
+uninstall:
+	@rm -f /lib/modules/$(shell uname -r)/aquantia/${TARGET}.ko
+	@depmod -a $(shell uname -r)
+
+endif
+
diff --git a/drivers/net/ethernet/aquantia/README.txt b/drivers/net/ethernet/aquantia/README.txt
new file mode 100644
index 00000000..2f4cdc6
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/README.txt
@@ -0,0 +1,464 @@
+Linux* aQuantia AQtion Driver for the aQuantia Multi-Gigabit PCI Express Family of
+Ethernet Adapters
+=============================================================================
+
+Contents
+========
+
+- Important Note
+- In This Release
+- Identifying Your Adapter
+- Building and Installation
+- Command Line Parameters
+- Additional Configurations
+- Support
+
+IMPORTANT NOTE
+==============
+
+WARNING:  The AQtion driver compiles by default with the LRO (Large Receive
+Offload) feature enabled.  This option offers the lowest CPU utilization for
+receives, but is completely incompatible with *routing/ip forwarding* and
+*bridging*.  If enabling ip forwarding or bridging is a requirement, it is
+necessary to disable LRO using compile time options as noted in the LRO
+section later in this document.  The result of not disabling LRO when combined
+with ip forwarding or bridging can be low throughput or even a kernel panic.
+
+In This Release
+===============
+
+This file describes the aQuantia AQtion Driver for the aQuantia Multi-Gigabit PCI Express Family of
+Ethernet Adapters.  This driver supports the linux kernels >= 3.10, 
+and includes support for x86_64 and ARM Linux system.
+
+This release contains source tarball and (optional) src.rpm package.
+
+Identifying Your Adapter
+========================
+
+The driver in this release is compatible with AQC-100, AQC-107, AQC-108 based ethernet adapters.
+
+
+SFP+ Devices (for AQC-100 based adapters)
+----------------------------------
+
+This release tested with passive Direct Attach Cables (DAC) and SFP+/LC Optical Transceiver.
+
+Building and Installation
+=========================
+
+To manually build this driver:
+------------------------------------------------------------
+1. Make sure you have all the environment to build standalone kernel module.
+   On debian based systems you may do the following:
+
+	sudo apt install linux-headers build-essential
+
+2. Move the base driver tar file to the directory of your choice. For example,
+   use /home/username/aquantia.
+   Untar/unzip archive:
+
+	cd ~/aquantia
+	tar zxf Aquantia-AQtion-x.y.z.tar.gz
+
+3. Change to the driver src directory:
+
+	cd Aquantia-AQtion-x.y.z/
+
+4. Compile the driver module:
+	make
+
+5. Load the module:
+	sudo insmod atlantic.ko
+
+6. Unload the driver
+	sudo rmmod atlantic
+
+7. Install the driver in the system
+	make && make install
+
+driver will be in:
+
+	/lib/modules/`uname -r`/aquantia/atlantic.ko
+
+8. Uninstall the driver:
+	make uninstall
+or run the following commands:
+	sudo rm -f /lib/modules/`uname -r`/aquantia/atlantic.ko
+	depmod -a `uname -r`
+
+Alternatively build and install driver with dkms
+------------------------------------------------------------
+1. Make sure you have all the environment to build standalone kernel module.
+   On debian based systems you may do the following:
+
+	sudo apt-get install linux-headers-`uname -r` build-essential gawk dkms
+
+   On redhat based systems you may do the following:
+
+	sudo yum install kernel-devel-`uname -r` gcc gcc-c++ make gawk dkms
+
+2. Move the base driver tar file to the directory of your choice. For example,
+   use /home/username/aquantia.
+   Untar/unzip archive:
+
+	cd ~/aquantia
+	tar zxf Aquantia-AQtion-x.y.z.tar.gz
+
+3. Change to the driver source directory:
+
+	cd Aquantia-AQtion-x.y.z/
+
+4. Build and install driver:
+
+	sudo ./dkms.sh install
+
+driver will be in:
+
+	/lib/modules/`uname -r`/updates/dkms/atlantic.ko
+
+5. Uninstall the driver:
+
+	sudo ./dkms.sh uninstall
+
+Alternatively you can use Aquantia-AQtion-x.y.z.src.rpm
+------------------------------------------------------------
+1. Move the Aquantia-AQtion-x.y.z.src.rpm file to the directory of your choice. For example,
+   use /home/username/aquantia.
+
+2. Execute the commands:
+    cd /home/username/aquantia
+    sudo rpm -ivh Aquantia-AQtion-x.y.z.x86_64.rpm
+	
+    After this driver will be installed.
+    (You can check this via "rpm -qa | grep Aquantia")
+
+3. Uninstall the driver:
+   Run the following commands:
+   sudo rpm -e Aquantia-AQtion-x.y.z.x86_64
+
+Check that the driver is working
+------------------------------------------------------------
+	
+1. Verify ethernet interface appears:
+	ifconfig
+	or
+	ip addr show
+	
+	If no new interface appears, check dmesg output.
+	If you see "Bad firmware detected" please update firmware on your ethernet card.
+
+2. Assign an IP address to the interface by entering the following, where
+   x is the interface number:
+
+	ifconfig ethX <IP_address> netmask <netmask>
+    or
+	ip addr add <IP_address> dev <DEV>
+
+3. Verify that the interface works. Enter the following, where <IP_address>
+   is the IP address for another machine on the same subnet as the interface
+   that is being tested:
+
+	ping  <IP_address>
+or (for IPv6)
+	ping6 <IPv6_address>
+
+4. Check the correct version of the driver is active (assume interface is eth1):
+
+        ethtool -i eth1
+
+Troubleshooting
+-----------------------
+
+Some distributions do not provide kernel sources ready for thirdparty module build.
+In general, the following could be used to prepare kernel source tree for build:
+
+	sudo su
+	cd /lib/modules/`uname -r`/build
+	make oldconfig
+	make prepare
+	make modules_prepare
+
+Command Line Parameters
+=======================
+The following command line parameters are available on atlantic driver:
+
+aq_itr -Interrupt throttling mode
+----------------------------------------
+Accepted values: 0, 1, 0xFFFF
+Default value: 0xFFFF
+0      - Disable interrupt throttling.
+1      - Enable interrupt throttling and use specified tx and rx rates.
+0xFFFF - Auto throttling mode. Driver will choose the best RX and TX
+         interrupt throtting settings based on link speed.
+
+aq_itr_tx - TX interrupt throttle rate
+----------------------------------------
+Accepted values: 0 - 0x1FF
+Default value: 0
+TX side throttling in microseconds. Adapter will setup maximum interrupt delay
+to this value. Minimum interrupt delay will be a half of this value
+
+aq_itr_rx - RX interrupt throttle rate
+----------------------------------------
+Accepted values: 0 - 0x1FF
+Default value: 0
+RX side throttling in microseconds. Adapter will setup maximum interrupt delay
+to this value. Minimum interrupt delay will be a half of this value
+
+Note: ITR settings could be changed in runtime by ethtool -c means (see below)
+
+aq_rxpageorder
+----------------------------------------
+Default value: 0
+RX page order override. Thats a power of 2 number of RX pages allocated for
+each descriptor. Received descriptor size is still limited by AQ_CFG_RX_FRAME_MAX.
+Increasing pageorder makes page reuse better (actual on iommu enabled systems).
+
+aq_rx_refill_thres
+----------------------------------------
+Default value: 32
+RX refill threshold. RX path will not refill freed descriptors until the
+specified number of free descriptors is observed. Larger values may help
+better page reuse but may lead to packet drops as well.
+
+
+Config file parametes
+=======================
+Some parameters can be changed in the {source_dir}/aq_cfg.h file:
+
+AQ_CFG_VECS_DEF
+------------------------------------------------------------
+Number of queues
+Valid Range: 0 - 8 (up to AQ_CFG_VECS_MAX)
+Default value: 4
+
+AQ_CFG_IS_RSS_DEF
+------------------------------------------------------------
+Enable/disable Receive Side Scaling
+
+This feature allows the adapter to distribute receive processing
+across multiple CPU-cores and to prevent from overloading a single CPU core.
+
+Valid values
+0 - disabled
+1 - enabled
+
+Default value: 1
+
+AQ_CFG_NUM_RSS_QUEUES_DEF
+------------------------------------------------------------
+Number of queues for Receive Side Scaling
+Valid Range: 0 - 4 (up to AQ_CFG_VECS_DEF)
+
+Default value: 4
+
+AQ_CFG_IS_LRO_DEF
+------------------------------------------------------------
+Enable/disable Large Receive Offload
+
+This offload enables the adapter to coalesce multiple TCP segments and indicate
+them as a single coalesced unit to the OS networking subsystem.
+The system consumes less energy but it also introduces more latency in packets processing.
+
+Valid values
+0 - disabled
+1 - enabled
+
+Default value: 1
+
+AQ_CFG_TX_CLEAN_BUDGET
+----------------------------------------
+Maximum descriptors to cleanup on TX at once.
+Default value: 256
+
+After the aq_cfg.h file changed the driver must be rebuilt to take effect.
+
+Additional Configurations
+=========================
+  Viewing Link Messages
+  ---------------------
+  Link messages will not be displayed to the console if the distribution is
+  restricting system messages. In order to see network driver link messages on
+  your console, set dmesg to eight by entering the following:
+
+       dmesg -n 8
+
+  NOTE: This setting is not saved across reboots.
+
+  Jumbo Frames
+  ------------
+  The driver supports Jumbo Frames for all adapters. Jumbo Frames support is
+  enabled by changing the MTU to a value larger than the default of 1500.
+  The maximum value for the MTU is 16000.  Use the ifconfig command to
+  increase the MTU size.  For example:
+
+        ifconfig <ethX> mtu 9000 up
+
+  ethtool
+  -------
+  The driver utilizes the ethtool interface for driver configuration and
+  diagnostics, as well as displaying statistical information. The latest 
+  ethtool version is required for this functionality.
+ 
+  
+  NAPI
+  ----
+  NAPI (Rx polling mode) is supported in the atlantic driver. 
+
+  See ftp://robur.slu.se/pub/Linux/net-development/NAPI/usenix-paper.tgz for 
+  more information on NAPI.
+
+Supported ethtool options
+============================
+ Viewing adapter settings
+ ---------------------
+ ethtool <ethX>
+ 
+ Output example:
+ Settings for enp1s0:
+        Supported ports: [ ]
+        Supported link modes:   100baseT/Full
+                                1000baseT/Full
+                                10000baseT/Full
+        Supported pause frame use: Symmetric
+        Supports auto-negotiation: Yes
+        Advertised link modes:  100baseT/Full
+                                1000baseT/Full
+                                10000baseT/Full
+        Advertised pause frame use: Symmetric
+        Advertised auto-negotiation: Yes
+        Speed: 10000Mb/s
+        Duplex: Full
+        Port: FIBRE
+        PHYAD: 0
+        Transceiver: external
+        Auto-negotiation: on
+        Link detected: yes
+
+ ---
+ Note: AQrate speeds (2.5/5 Gb/s) will be displayed only with linux kernels > 4.10.
+    But you can still use these speeds:
+	ethtool -s eth0 autoneg off speed 2500
+		
+ Viewing adapter information
+ ---------------------
+ ethtool -i <ethX>
+
+ Output example:
+ driver: atlantic
+ version: 1.6.9.0
+ firmware-version: 1.5.49
+ expansion-rom-version:
+ bus-info: 0000:01:00.0
+ supports-statistics: yes
+ supports-test: no
+ supports-eeprom-access: no
+ supports-register-dump: yes
+ supports-priv-flags: no
+
+ Viewing Ethernet adapter statistics:
+ ---------------------
+ ethtool -S <ethX>
+
+ Output example:
+ NIC statistics:
+     InPackets: 13238607
+     InUCast: 13293852
+     InMCast: 52
+     InBCast: 3
+     InErrors: 0
+     OutPackets: 23703019
+     OutUCast: 23704941
+     OutMCast: 67
+     OutBCast: 11
+     InUCastOctects: 213182760
+     OutUCastOctects: 22698443
+     InMCastOctects: 6600
+     OutMCastOctects: 8776
+     InBCastOctects: 192
+     OutBCastOctects: 704
+     InOctects: 2131839552
+     OutOctects: 226938073
+     InPacketsDma: 95532300
+     OutPacketsDma: 59503397
+     InOctetsDma: 1137102462
+     OutOctetsDma: 2394339518
+     InDroppedDma: 0
+     Queue[0] InPackets: 23567131
+     Queue[0] OutPackets: 20070028
+     Queue[0] InJumboPackets: 0
+     Queue[0] InLroPackets: 0
+     Queue[0] InErrors: 0
+     Queue[1] InPackets: 45428967
+     Queue[1] OutPackets: 11306178
+     Queue[1] InJumboPackets: 0
+     Queue[1] InLroPackets: 0
+     Queue[1] InErrors: 0
+     Queue[2] InPackets: 3187011
+     Queue[2] OutPackets: 13080381
+     Queue[2] InJumboPackets: 0
+     Queue[2] InLroPackets: 0
+     Queue[2] InErrors: 0
+     Queue[3] InPackets: 23349136
+     Queue[3] OutPackets: 15046810
+     Queue[3] InJumboPackets: 0
+     Queue[3] InLroPackets: 0
+     Queue[3] InErrors: 0
+
+ Disable GRO when routing/bridging
+ ---------------------------------
+ Due to a known kernel issue, GRO must be turned off when routing/bridging. 
+ Its can be done with command:
+ 
+ ethtool -K <ethX> gro off
+
+ 
+ Disable LRO when routing/bridging
+ ---------------------------------
+ Due to a known kernel issue, LRO must be turned off when routing/bridging. 
+ Its can be done with command:
+ 
+ ethtool -K <ethX> lro off
+
+ Interrupt coalescing support
+ ---------------------------------
+ ITR mode, TX/RX coalescing timings could be viewed with:
+ 
+ ethtool -c <ethX>
+ 
+ and changed with:
+ 
+ ethtool -C <ethX> tx-usecs <usecs> rx-usecs <usecs>
+ 
+ To disable coalescing:
+
+ ethtool -C <ethX> tx-usecs 0 rx-usecs 0 tx-max-frames 1 tx-max-frames 1
+ 
+ Wake on LAN support
+ ---------------------------------
+
+ WOL support by magic packet:
+
+ ethtool -s <ethX> wol g
+ 
+ To disable WOL:
+
+ ethtool -s <ethX> wol d
+
+Support
+=======
+
+If an issue is identified with the released source code on the supported
+kernel with a supported adapter, email the specific information related
+to the issue to support@aquantia.com
+
+License
+=======
+
+aQuantia Corporation Network Driver
+Copyright(c) 2014 - 2018 aQuantia Corporation.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms and conditions of the GNU General Public License,
+version 2, as published by the Free Software Foundation.
diff --git a/drivers/net/ethernet/aquantia/aq_cfg.h b/drivers/net/ethernet/aquantia/aq_cfg.h
new file mode 100644
index 00000000..f7b69c8
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_cfg.h
@@ -0,0 +1,96 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_cfg.h: Definition of configuration parameters and constants. */
+
+#ifndef AQ_CFG_H
+#define AQ_CFG_H
+
+#define AQ_CFG_VECS_DEF   4U
+#define AQ_CFG_TCS_DEF    1U
+
+#define AQ_CFG_TXDS_DEF    4096U
+#define AQ_CFG_RXDS_DEF    2048U
+
+#define AQ_CFG_IS_POLLING_DEF 0U
+
+#define AQ_CFG_FORCE_LEGACY_INT 0U
+
+#define AQ_CFG_INTERRUPT_MODERATION_OFF		0
+#define AQ_CFG_INTERRUPT_MODERATION_ON		1
+#define AQ_CFG_INTERRUPT_MODERATION_AUTO	0xFFFFU
+
+#define AQ_CFG_INTERRUPT_MODERATION_USEC_MAX (0x1FF * 2)
+
+#define AQ_CFG_IRQ_MASK                      0x1FFU
+
+#define AQ_CFG_VECS_MAX   8U
+#define AQ_CFG_TCS_MAX    8U
+
+#define AQ_CFG_TX_FRAME_MAX  (16U * 1024U)
+#define AQ_CFG_RX_FRAME_MAX  (2U * 1024U)
+
+#define AQ_CFG_TX_CLEAN_BUDGET 256U
+
+#define AQ_CFG_RX_HDR_SIZE 256U
+
+/* LRO */
+#define AQ_CFG_IS_LRO_DEF           1U
+
+/* RSS */
+#define AQ_CFG_RSS_INDIRECTION_TABLE_MAX  128U
+#define AQ_CFG_RSS_HASHKEY_SIZE           320U
+
+#define AQ_CFG_IS_RSS_DEF           1U
+#define AQ_CFG_NUM_RSS_QUEUES_DEF   AQ_CFG_VECS_DEF
+#define AQ_CFG_RSS_BASE_CPU_NUM_DEF 0U
+
+#define AQ_CFG_PCI_FUNC_MSIX_IRQS   9U
+#define AQ_CFG_PCI_FUNC_PORTS       2U
+
+#define AQ_CFG_SERVICE_TIMER_INTERVAL    (1 * HZ)
+#define AQ_CFG_POLLING_TIMER_INTERVAL   ((unsigned int)(2 * HZ))
+
+#define AQ_CFG_SKB_FRAGS_MAX   32U
+
+/* Number of descriptors available in one ring to resume this ring queue
+ */
+#define AQ_CFG_RESTART_DESC_THRES   (AQ_CFG_SKB_FRAGS_MAX * 2)
+
+#define AQ_CFG_NAPI_WEIGHT     64U
+
+#define AQ_CFG_MULTICAST_ADDRESS_MAX     32U
+
+/*#define AQ_CFG_MAC_ADDR_PERMANENT {0x30, 0x0E, 0xE3, 0x12, 0x34, 0x56}*/
+
+#define AQ_NIC_FC_OFF    0U
+#define AQ_NIC_FC_TX     1U
+#define AQ_NIC_FC_RX     2U
+#define AQ_NIC_FC_FULL   3U
+#define AQ_NIC_FC_AUTO   4U
+
+#define AQ_CFG_FC_MODE AQ_NIC_FC_FULL
+
+#define AQ_CFG_SPEED_MSK  0xFFFFU	/* 0xFFFFU==auto_neg */
+
+#define AQ_CFG_IS_AUTONEG_DEF       1U
+#define AQ_CFG_MTU_DEF              1514U
+
+#define AQ_CFG_LOCK_TRYS   100U
+
+#define AQ_CFG_DRV_AUTHOR      "aQuantia"
+#define AQ_CFG_DRV_DESC        "aQuantia Corporation(R) Network Driver"
+#define AQ_CFG_DRV_NAME        "atlantic"
+#define AQ_CFG_DRV_VERSION	__stringify(NIC_MAJOR_DRIVER_VERSION)"."\
+				__stringify(NIC_MINOR_DRIVER_VERSION)"."\
+				__stringify(NIC_BUILD_DRIVER_VERSION)"."\
+				__stringify(NIC_REVISION_DRIVER_VERSION) \
+				AQ_CFG_DRV_VERSION_SUFFIX
+
+#endif /* AQ_CFG_H */
diff --git a/drivers/net/ethernet/aquantia/aq_common.h b/drivers/net/ethernet/aquantia/aq_common.h
new file mode 100644
index 00000000..c1886e1
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_common.h
@@ -0,0 +1,66 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_common.h: Basic includes for all files in project. */
+
+#ifndef AQ_COMMON_H
+#define AQ_COMMON_H
+
+#include <linux/etherdevice.h>
+#include <linux/pci.h>
+#include <linux/version.h>
+#include "ver.h"
+#include "aq_cfg.h"
+#include "aq_utils.h"
+#include "aq_compat.h"
+
+#define PCI_VENDOR_ID_AQUANTIA  0x1D6A
+
+#define AQ_DEVICE_ID_0001	0x0001
+#define AQ_DEVICE_ID_D100	0xD100
+#define AQ_DEVICE_ID_D107	0xD107
+#define AQ_DEVICE_ID_D108	0xD108
+#define AQ_DEVICE_ID_D109	0xD109
+
+#define AQ_DEVICE_ID_AQC100	0x00B1
+#define AQ_DEVICE_ID_AQC107	0x07B1
+#define AQ_DEVICE_ID_AQC108	0x08B1
+#define AQ_DEVICE_ID_AQC109	0x09B1
+#define AQ_DEVICE_ID_AQC111	0x11B1
+#define AQ_DEVICE_ID_AQC112	0x12B1
+
+#define AQ_DEVICE_ID_AQC100S	0x80B1
+#define AQ_DEVICE_ID_AQC107S	0x87B1
+#define AQ_DEVICE_ID_AQC108S	0x88B1
+#define AQ_DEVICE_ID_AQC109S	0x89B1
+#define AQ_DEVICE_ID_AQC111S	0x91B1
+#define AQ_DEVICE_ID_AQC112S	0x92B1
+
+#define AQ_DEVICE_ID_AQC111E	0x51B1
+#define AQ_DEVICE_ID_AQC112E	0x52B1
+
+#define HW_ATL_NIC_NAME "aQuantia AQtion 10Gbit Network Adapter"
+
+#define AQ_HWREV_ANY	0
+#define AQ_HWREV_1	1
+#define AQ_HWREV_2	2
+
+#define AQ_NIC_RATE_10G		BIT(0)
+#define AQ_NIC_RATE_5G		BIT(1)
+#define AQ_NIC_RATE_5GSR	BIT(2)
+#define AQ_NIC_RATE_2GS		BIT(3)
+#define AQ_NIC_RATE_1G		BIT(4)
+#define AQ_NIC_RATE_100M	BIT(5)
+
+#define AQ_NIC_RATE_EEE_10G	BIT(6)
+#define AQ_NIC_RATE_EEE_5G	BIT(7)
+#define AQ_NIC_RATE_EEE_2GS	BIT(8)
+#define AQ_NIC_RATE_EEE_1G	BIT(9)
+
+#endif /* AQ_COMMON_H */
diff --git a/drivers/net/ethernet/aquantia/aq_compat.h b/drivers/net/ethernet/aquantia/aq_compat.h
new file mode 100644
index 00000000..ed4c718
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_compat.h
@@ -0,0 +1,116 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_compat.h: Backward compat with previous linux kernel versions */
+
+#ifndef AQ_COMPAT_H
+#define AQ_COMPAT_H
+
+#include <linux/version.h>
+
+#ifndef RHEL_RELEASE_VERSION
+#define RHEL_RELEASE_VERSION(a,b) (((a) << 8) + (b))
+#endif
+
+#ifndef RHEL_RELEASE_CODE
+#define RHEL_RELEASE_CODE 0
+#endif
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4,14,0)
+
+#define from_timer(var, callback_timer, timer_fieldname) \
+	container_of(callback_timer, typeof(*var), timer_fieldname)
+
+static inline void timer_setup(struct timer_list *timer,
+			       void (*callback)(struct timer_list *),
+			       unsigned int flags)
+{
+	setup_timer(timer, (void (*)(unsigned long))callback, (unsigned long)timer);
+}
+
+#endif
+
+#ifndef SPEED_5000
+#define SPEED_5000 5000
+#endif
+
+#ifndef ETH_MIN_MTU
+#define ETH_MIN_MTU	68
+#endif
+
+#ifndef SKB_ALLOC_NAPI
+static inline struct sk_buff *napi_alloc_skb(struct napi_struct *napi, unsigned int length)
+{
+	return netdev_alloc_skb_ip_align(napi->dev, length);
+}
+#endif
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4,7,0)
+/* from commit 1dff8083a024650c75a9c961c38082473ceae8cf */
+#define page_to_virt(x)	__va(PFN_PHYS(page_to_pfn(x)))
+#endif	/* 4.7.0 */
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4,6,0)
+
+#if !(RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,2)))
+/* from commit fe896d1878949ea92ba547587bc3075cc688fb8f */
+static inline void page_ref_inc(struct page *page)
+{
+	atomic_inc(&page->_count);
+}
+
+static inline int page_ref_count(struct page *page)
+{
+	return atomic_read(&page->_count);
+}
+#endif
+
+#endif
+
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,14,0)) && !(RHEL_RELEASE_CODE)
+
+/* from commit 286ab723d4b83d37deb4017008ef1444a95cfb0d */
+static inline void ether_addr_copy(u8 *dst, const u8 *src)
+{
+	memcpy(dst, src, 6);
+}
+#endif /* 3.14.0 */
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3,18,0)
+
+/* introduced in commit 56193d1bce2b2759cb4bdcc00cd05544894a0c90
+ * pull the whole head buffer len for now*/
+#define eth_get_headlen(__data, __max_len) (__max_len)
+
+/* ->xmit_more introduced in commit
+ * 0b725a2ca61bedc33a2a63d0451d528b268cf975 for 3.18-rc1 */
+static inline int skb_xmit_more(struct sk_buff *skb)
+{
+	return 0;
+}
+
+#else /* 3.18.0 */
+static inline int skb_xmit_more(struct sk_buff *skb)
+{
+	return skb->xmit_more;
+}
+
+#endif	/* 3.18.0 */
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,33)
+#define IFF_UNICAST_FLT        0
+#define dev_alloc_pages(__order) alloc_pages_node(NUMA_NO_NODE,                         \
+                                                  GFP_ATOMIC | __GFP_COMP | __GFP_COLD, \
+                                                  __order)
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(3,19,0)
+/* introduced in commit 71dfda58aaaf4bf6b1bc59f9d8afa635fa1337d4 */
+#define dev_alloc_pages(__order) __skb_alloc_pages(GFP_ATOMIC | __GFP_COMP, NULL, __order)
+#endif  /* 3.19.0 */
+
+#endif /* AQ_COMMON_H */
diff --git a/drivers/net/ethernet/aquantia/aq_drvinfo.c b/drivers/net/ethernet/aquantia/aq_drvinfo.c
new file mode 100644
index 00000000..1a07f67
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_drvinfo.c
@@ -0,0 +1,92 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_drvinfo.c: Definition of common code for firmware info in sys.*/
+
+#include <linux/init.h>
+#include <linux/kobject.h>
+#include <linux/module.h>
+#include <linux/stat.h>
+#include <linux/string.h>
+#include <linux/sysfs.h>
+#include <linux/uaccess.h>
+
+#include "aq_drvinfo.h"
+
+
+static ssize_t show_temp(struct device *ndev, struct device_attribute *attr,
+			    char *buf)
+{
+	int err;
+
+	struct aq_nic_s *aq_nic = netdev_priv(to_net_dev(ndev));
+
+	int temp = 0;
+
+	if (!aq_nic->aq_fw_ops->get_temp)
+		return -ENXIO;
+
+	err = aq_nic->aq_fw_ops->get_temp(aq_nic->aq_hw, &temp);
+
+	if (err == 0)
+		return sprintf(buf, "%d.%d\n", temp / 100, temp % 100);
+	return -ENXIO;
+}
+
+
+static ssize_t show_cable_len(struct device *ndev,
+				struct device_attribute *attr, char *buf)
+{
+	int err;
+
+	struct aq_nic_s *aq_nic = netdev_priv(to_net_dev(ndev));
+
+	int cable_len = 0;
+
+	if (!aq_nic->aq_fw_ops->get_cable_len)
+		return -ENXIO;
+
+	err = aq_nic->aq_fw_ops->get_cable_len(aq_nic->aq_hw, &cable_len);
+
+	if (err == 0)
+		return sprintf(buf, "%d\n", cable_len);
+	return -ENXIO;
+}
+
+
+static struct device_attribute aq_dev_attrs[] = {
+	__ATTR(temperature, 0444, show_temp, NULL),
+	__ATTR(cable_length, 0444, show_cable_len, NULL),
+};
+
+int aq_sysfs_init(struct net_device *ndev)
+{
+	int i;
+	int err = 0;
+
+	for (i = 0; i < ARRAY_SIZE(aq_dev_attrs); i++) {
+		err = device_create_file(&ndev->dev, &aq_dev_attrs[i]);
+		if (err < 0) {
+			while (i > 0)
+				device_remove_file(&ndev->dev,
+						&aq_dev_attrs[--i]);
+			break;
+		}
+	}
+	return err;
+}
+
+void aq_sysfs_exit(struct net_device *ndev)
+{
+	int i;
+
+	for (i = 0; i < ARRAY_SIZE(aq_dev_attrs); i++)
+		device_remove_file(&ndev->dev, &aq_dev_attrs[i]);
+}
+
diff --git a/drivers/net/ethernet/aquantia/aq_drvinfo.h b/drivers/net/ethernet/aquantia/aq_drvinfo.h
new file mode 100644
index 00000000..2199ac4
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_drvinfo.h
@@ -0,0 +1,25 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_drvinfo.h: Declaration of common code for firmware info in sys.*/
+
+#ifndef AQ_DRVINFO_H
+#define AQ_DRVINFO_H
+
+#include "aq_nic.h"
+#include "aq_hw.h"
+#include "hw_atl/hw_atl_utils.h"
+
+
+int aq_sysfs_init(struct net_device *ndev);
+void aq_sysfs_exit(struct net_device *ndev);
+
+
+#endif /* AQ_DRVINFO_H */
+
diff --git a/drivers/net/ethernet/aquantia/aq_ethtool.c b/drivers/net/ethernet/aquantia/aq_ethtool.c
new file mode 100644
index 00000000..419dbe6
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_ethtool.c
@@ -0,0 +1,596 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_ethtool.c: Definition of ethertool related functions. */
+
+#include "aq_ethtool.h"
+#include "aq_nic.h"
+#include "aq_vec.h"
+
+static void aq_ethtool_get_regs(struct net_device *ndev,
+				struct ethtool_regs *regs, void *p)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	u32 regs_count = aq_nic_get_regs_count(aq_nic);
+
+	memset(p, 0, regs_count * sizeof(u32));
+	aq_nic_get_regs(aq_nic, regs, p);
+}
+
+static int aq_ethtool_get_regs_len(struct net_device *ndev)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	u32 regs_count = aq_nic_get_regs_count(aq_nic);
+
+	return regs_count * sizeof(u32);
+}
+
+static u32 aq_ethtool_get_link(struct net_device *ndev)
+{
+	return ethtool_op_get_link(ndev);
+}
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 6, 0)
+static int aq_ethtool_get_link_ksettings(struct net_device *ndev,
+					 struct ethtool_link_ksettings *cmd)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+
+	aq_nic_get_link_ksettings(aq_nic, cmd);
+	cmd->base.speed = netif_carrier_ok(ndev) ?
+				aq_nic_get_link_speed(aq_nic) : 0U;
+
+	return 0;
+}
+
+static int
+aq_ethtool_set_link_ksettings(struct net_device *ndev,
+			      const struct ethtool_link_ksettings *cmd)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+
+	return aq_nic_set_link_ksettings(aq_nic, cmd);
+}
+#else
+static int aq_ethtool_get_settings(struct net_device *ndev,
+				   struct ethtool_cmd *cmd)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+
+
+	aq_nic_get_link_settings(aq_nic, cmd);
+	ethtool_cmd_speed_set(cmd, netif_carrier_ok(ndev) ?
+				aq_nic_get_link_speed(aq_nic) : 0U);
+
+	return 0;
+}
+
+static int aq_ethtool_set_settings(struct net_device *ndev,
+				   struct ethtool_cmd *cmd)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	int err = 0U;
+
+	err = aq_nic_set_link_settings(aq_nic, cmd);
+
+	return err;
+}
+#endif
+
+static const char aq_ethtool_stat_names[][ETH_GSTRING_LEN] = {
+	"InPackets",
+	"InUCast",
+	"InMCast",
+	"InBCast",
+	"InErrors",
+	"OutPackets",
+	"OutUCast",
+	"OutMCast",
+	"OutBCast",
+	"InUCastOctets",
+	"OutUCastOctets",
+	"InMCastOctets",
+	"OutMCastOctets",
+	"InBCastOctets",
+	"OutBCastOctets",
+	"InOctets",
+	"OutOctets",
+	"InPacketsDma",
+	"OutPacketsDma",
+	"InOctetsDma",
+	"OutOctetsDma",
+	"InDroppedDma",
+};
+
+static const char aq_ethtool_queue_stat_names[][ETH_GSTRING_LEN] = {
+	"Queue[%d] InPackets",
+	"Queue[%d] OutPackets",
+	"Queue[%d] Restarts",
+	"Queue[%d] InJumboPackets",
+	"Queue[%d] InLroPackets",
+	"Queue[%d] InErrors",
+};
+
+static void aq_ethtool_stats(struct net_device *ndev,
+			     struct ethtool_stats *stats, u64 *data)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+
+	memset(data, 0, (ARRAY_SIZE(aq_ethtool_stat_names) +
+				ARRAY_SIZE(aq_ethtool_queue_stat_names) *
+				cfg->vecs) * sizeof(u64));
+	aq_nic_get_stats(aq_nic, data);
+}
+
+static void aq_ethtool_get_drvinfo(struct net_device *ndev,
+				   struct ethtool_drvinfo *drvinfo)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+	struct pci_dev *pdev = to_pci_dev(ndev->dev.parent);
+	u32 firmware_version = aq_nic_get_fw_version(aq_nic);
+	u32 regs_count = aq_nic_get_regs_count(aq_nic);
+
+	strlcat(drvinfo->driver, AQ_CFG_DRV_NAME, sizeof(drvinfo->driver));
+	strlcat(drvinfo->version, AQ_CFG_DRV_VERSION, sizeof(drvinfo->version));
+
+	snprintf(drvinfo->fw_version, sizeof(drvinfo->fw_version),
+		 "%u.%u.%u", firmware_version >> 24,
+		 (firmware_version >> 16) & 0xFFU, firmware_version & 0xFFFFU);
+
+	strlcpy(drvinfo->bus_info, pdev ? pci_name(pdev) : "",
+		sizeof(drvinfo->bus_info));
+	drvinfo->n_stats = ARRAY_SIZE(aq_ethtool_stat_names) +
+		cfg->vecs * ARRAY_SIZE(aq_ethtool_queue_stat_names);
+	drvinfo->testinfo_len = 0;
+	drvinfo->regdump_len = regs_count;
+	drvinfo->eedump_len = 0;
+}
+
+static void aq_ethtool_get_strings(struct net_device *ndev,
+				   u32 stringset, u8 *data)
+{
+	int i, si;
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+	u8 *p = data;
+
+	if (stringset == ETH_SS_STATS) {
+		memcpy(p, *aq_ethtool_stat_names,
+		       sizeof(aq_ethtool_stat_names));
+		p = p + sizeof(aq_ethtool_stat_names);
+		for (i = 0; i < cfg->vecs; i++) {
+			for (si = 0;
+				si < ARRAY_SIZE(aq_ethtool_queue_stat_names);
+				si++) {
+				snprintf(p, ETH_GSTRING_LEN,
+					 aq_ethtool_queue_stat_names[si], i);
+				p += ETH_GSTRING_LEN;
+			}
+		}
+	}
+}
+
+static int aq_ethtool_get_sset_count(struct net_device *ndev, int stringset)
+{
+	int ret = 0;
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+
+	switch (stringset) {
+	case ETH_SS_STATS:
+		ret = ARRAY_SIZE(aq_ethtool_stat_names) +
+			cfg->vecs * ARRAY_SIZE(aq_ethtool_queue_stat_names);
+		break;
+	default:
+		ret = -EOPNOTSUPP;
+	}
+	return ret;
+}
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+static u32 aq_ethtool_get_rss_indir_size(struct net_device *ndev)
+{
+	return AQ_CFG_RSS_INDIRECTION_TABLE_MAX;
+}
+#endif
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 16, 0)
+static u32 aq_ethtool_get_rss_key_size(struct net_device *ndev)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+
+	return sizeof(cfg->aq_rss.hash_secret_key);
+}
+
+#if defined(ETH_RSS_HASH_TOP)
+static int aq_ethtool_get_rss(struct net_device *ndev, u32 *indir, u8 *key,
+			      u8 *hfunc)
+#else
+static int aq_ethtool_get_rss(struct net_device *ndev, u32 *indir, u8 *key)
+#endif
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+	unsigned int i = 0U;
+
+#if defined(ETH_RSS_HASH_TOP)
+	if (hfunc)
+		*hfunc = ETH_RSS_HASH_TOP; /* Toeplitz */
+#endif
+	if (indir) {
+		for (i = 0; i < AQ_CFG_RSS_INDIRECTION_TABLE_MAX; i++)
+			indir[i] = cfg->aq_rss.indirection_table[i];
+	}
+	if (key)
+		memcpy(key, cfg->aq_rss.hash_secret_key,
+		       sizeof(cfg->aq_rss.hash_secret_key));
+	return 0;
+}
+#endif
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+static int aq_ethtool_get_rxnfc(struct net_device *ndev,
+				struct ethtool_rxnfc *cmd,
+				u32 *rule_locs)
+#else
+static int aq_ethtool_get_rxnfc(struct net_device *ndev,
+				struct ethtool_rxnfc *cmd,
+				void *rule_locs)
+#endif
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+	int err = 0;
+
+	switch (cmd->cmd) {
+	case ETHTOOL_GRXRINGS:
+		cmd->data = cfg->vecs;
+		break;
+
+	default:
+		err = -EOPNOTSUPP;
+		break;
+	}
+
+	return err;
+}
+
+static int aq_ethtool_get_coalesce(struct net_device *ndev,
+				   struct ethtool_coalesce *coal)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+
+	if (cfg->itr == AQ_CFG_INTERRUPT_MODERATION_ON ||
+	    cfg->itr == AQ_CFG_INTERRUPT_MODERATION_AUTO) {
+		coal->rx_coalesce_usecs = cfg->rx_itr;
+		coal->tx_coalesce_usecs = cfg->tx_itr;
+		coal->rx_max_coalesced_frames = 0;
+		coal->tx_max_coalesced_frames = 0;
+	} else {
+		coal->rx_coalesce_usecs = 0;
+		coal->tx_coalesce_usecs = 0;
+		coal->rx_max_coalesced_frames = 1;
+		coal->tx_max_coalesced_frames = 1;
+	}
+	return 0;
+}
+
+static int aq_ethtool_set_coalesce(struct net_device *ndev,
+				   struct ethtool_coalesce *coal)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+
+	/* This is not yet supported
+	 */
+	if (coal->use_adaptive_rx_coalesce || coal->use_adaptive_tx_coalesce)
+		return -EOPNOTSUPP;
+
+	/* Atlantic only supports timing based coalescing
+	 */
+	if (coal->rx_max_coalesced_frames > 1 ||
+	    coal->rx_coalesce_usecs_irq ||
+	    coal->rx_max_coalesced_frames_irq)
+		return -EOPNOTSUPP;
+
+	if (coal->tx_max_coalesced_frames > 1 ||
+	    coal->tx_coalesce_usecs_irq ||
+	    coal->tx_max_coalesced_frames_irq)
+		return -EOPNOTSUPP;
+
+	/* We do not support frame counting. Check this
+	 */
+	if (!(coal->rx_max_coalesced_frames == !coal->rx_coalesce_usecs))
+		return -EOPNOTSUPP;
+	if (!(coal->tx_max_coalesced_frames == !coal->tx_coalesce_usecs))
+		return -EOPNOTSUPP;
+
+	if (coal->rx_coalesce_usecs > AQ_CFG_INTERRUPT_MODERATION_USEC_MAX ||
+	    coal->tx_coalesce_usecs > AQ_CFG_INTERRUPT_MODERATION_USEC_MAX)
+		return -EINVAL;
+
+	cfg->itr = AQ_CFG_INTERRUPT_MODERATION_ON;
+
+	cfg->rx_itr = coal->rx_coalesce_usecs;
+	cfg->tx_itr = coal->tx_coalesce_usecs;
+
+	return aq_nic_update_interrupt_moderation_settings(aq_nic);
+}
+
+
+static void aq_ethtool_get_wol(struct net_device *ndev,
+			       struct ethtool_wolinfo *wol)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+
+	wol->supported = WAKE_MAGIC;
+	wol->wolopts = 0;
+
+	if (cfg->wol)
+		wol->wolopts |= WAKE_MAGIC;
+}
+
+static int aq_ethtool_set_wol(struct net_device *ndev,
+			      struct ethtool_wolinfo *wol)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+	struct pci_dev *pdev = to_pci_dev(ndev->dev.parent);
+	int err = 0;
+
+	if (wol->wolopts & WAKE_MAGIC) {
+		cfg->wol |= AQ_NIC_WOL_ENABLED;
+	} else {
+		cfg->wol &= ~AQ_NIC_WOL_ENABLED;
+	}
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+	err = device_set_wakeup_enable(&pdev->dev, wol->wolopts);
+#else
+	device_set_wakeup_enable(&pdev->dev, wol->wolopts);
+#endif
+
+	return err;
+}
+
+static enum hw_atl_fw2x_rate eee_mask_to_ethtool_mask(u32 speed)
+{
+	u32 rate = 0;
+
+	if (speed & AQ_NIC_RATE_EEE_10G)
+		rate |= SUPPORTED_10000baseT_Full;
+
+	/* This is not supported
+	 * if (speed & AQ_NIC_RATE_EEE_5G)
+	 *	rate |= SUPPORTED_5000baseX_Full;
+	 */
+
+	if (speed & AQ_NIC_RATE_EEE_2GS)
+		rate |= SUPPORTED_2500baseX_Full;
+
+
+	if (speed & AQ_NIC_RATE_EEE_1G)
+		rate |= SUPPORTED_1000baseT_Full;
+
+	return rate;
+}
+
+static int aq_ethtool_get_eee(struct net_device *ndev, struct ethtool_eee *eee)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	int err = 0;
+
+	u32 rate, supported_rates;
+
+	if (!aq_nic->aq_fw_ops->get_eee_rate)
+		return -EOPNOTSUPP;
+
+	err = aq_nic->aq_fw_ops->get_eee_rate(aq_nic->aq_hw, &rate,
+						&supported_rates);
+	if (err < 0)
+		return err;
+
+	eee->supported = eee_mask_to_ethtool_mask(supported_rates);
+
+	if (aq_nic->aq_nic_cfg.eee_enabled)
+		eee->advertised = eee->supported;
+
+	eee->lp_advertised = eee_mask_to_ethtool_mask(rate);
+
+	eee->eee_enabled = !!eee->advertised;
+
+	eee->tx_lpi_enabled = eee->eee_enabled;
+	if (eee->advertised & eee->lp_advertised)
+		eee->eee_active = true;
+
+	return 0;
+}
+
+static int aq_ethtool_set_eee(struct net_device *ndev, struct ethtool_eee *eee)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *cfg = aq_nic_get_cfg(aq_nic);
+	u32 rate, supported_rates;
+	int err = 0;
+
+	if (!aq_nic->aq_fw_ops->get_eee_rate)
+		return -EOPNOTSUPP;
+
+	err = aq_nic->aq_fw_ops->get_eee_rate(aq_nic->aq_hw, &rate,
+							&supported_rates);
+	if (err < 0)
+		return err;
+
+	if (eee->eee_enabled) {
+		rate = supported_rates;
+		cfg->eee_enabled = rate;
+	} else {
+		rate = 0;
+		cfg->eee_enabled = 0;
+	}
+
+	if (aq_nic->aq_fw_ops->set_eee_rate)
+		return aq_nic->aq_fw_ops->set_eee_rate(aq_nic->aq_hw, rate);
+
+	return -EOPNOTSUPP;
+}
+
+static int aq_ethtool_nway_reset(struct net_device *ndev)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+
+	if (unlikely(!aq_nic->aq_fw_ops->renegotiate))
+		return -EOPNOTSUPP;
+
+	if (netif_running(ndev))
+		return aq_nic->aq_fw_ops->renegotiate(aq_nic->aq_hw);
+
+	return 0;
+}
+
+static void aq_ethtool_get_pauseparam(struct net_device *ndev,
+				      struct ethtool_pauseparam *pause)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+
+	pause->autoneg = 0;
+
+	if (aq_nic->aq_hw->aq_nic_cfg->flow_control & AQ_NIC_FC_RX)
+		pause->rx_pause = 1;
+	if (aq_nic->aq_hw->aq_nic_cfg->flow_control & AQ_NIC_FC_TX)
+		pause->tx_pause = 1;
+}
+
+static int aq_ethtool_set_pauseparam(struct net_device *ndev,
+				     struct ethtool_pauseparam *pause)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	int err = 0;
+
+	if (!aq_nic->aq_fw_ops->set_flow_control)
+		return -EOPNOTSUPP;
+
+	if (pause->autoneg == AUTONEG_ENABLE)
+		return -EOPNOTSUPP;
+
+	if (pause->rx_pause)
+		aq_nic->aq_hw->aq_nic_cfg->flow_control |= AQ_NIC_FC_RX;
+	else
+		aq_nic->aq_hw->aq_nic_cfg->flow_control &= ~AQ_NIC_FC_RX;
+
+	if (pause->tx_pause)
+		aq_nic->aq_hw->aq_nic_cfg->flow_control |= AQ_NIC_FC_TX;
+	else
+		aq_nic->aq_hw->aq_nic_cfg->flow_control &= ~AQ_NIC_FC_TX;
+
+
+	err = aq_nic->aq_fw_ops->set_flow_control(aq_nic->aq_hw);
+
+	return err;
+}
+
+static void aq_get_ringparam(struct net_device *ndev,
+                             struct ethtool_ringparam *ring)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *aq_nic_cfg = aq_nic_get_cfg(aq_nic);
+
+	ring->rx_pending = aq_nic_cfg->rxds;
+	ring->tx_pending = aq_nic_cfg->txds;
+
+	ring->rx_max_pending = aq_nic_cfg->aq_hw_caps->rxds_max;
+	ring->tx_max_pending = aq_nic_cfg->aq_hw_caps->txds_max;
+}
+
+static int aq_set_ringparam(struct net_device *ndev,
+                            struct ethtool_ringparam *ring)
+{
+	int err = 0;
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *aq_nic_cfg = aq_nic_get_cfg(aq_nic);
+	const struct aq_hw_caps_s *hw_caps = aq_nic_cfg->aq_hw_caps;
+
+	if ((ring->rx_mini_pending) || (ring->rx_jumbo_pending)) {
+		err = -EOPNOTSUPP;
+		goto err_exit;
+	}
+
+	spin_lock(&aq_nic->aq_spinlock);
+
+	if (netif_running(ndev))
+		dev_close(ndev);
+
+	aq_nic_free_vectors(aq_nic);
+
+	aq_nic_cfg->rxds = max(ring->rx_pending, hw_caps->rxds_min);
+	aq_nic_cfg->rxds = min(aq_nic_cfg->rxds, hw_caps->rxds_max);
+	aq_nic_cfg->rxds = ALIGN(aq_nic_cfg->rxds, AQ_HW_RXD_MULTIPLE);
+
+	aq_nic_cfg->txds = max(ring->tx_pending, hw_caps->txds_min);
+	aq_nic_cfg->txds = min(aq_nic_cfg->txds, hw_caps->txds_max);
+	aq_nic_cfg->txds = ALIGN(aq_nic_cfg->txds, AQ_HW_TXD_MULTIPLE);
+
+	for (aq_nic->aq_vecs = 0; aq_nic->aq_vecs < aq_nic_cfg->vecs;
+	     aq_nic->aq_vecs++) {
+		aq_nic->aq_vec[aq_nic->aq_vecs] =
+		    aq_vec_alloc(aq_nic, aq_nic->aq_vecs, aq_nic_cfg);
+		if (unlikely(!aq_nic->aq_vec[aq_nic->aq_vecs])) {
+			err = -ENOMEM;
+			goto err_unlock;
+		}
+	}
+	if (!netif_running(ndev))
+		err = dev_open(ndev);
+
+err_unlock:
+	spin_unlock(&aq_nic->aq_spinlock);
+err_exit:
+	return err;
+}
+
+const struct ethtool_ops aq_ethtool_ops = {
+	.get_link            = aq_ethtool_get_link,
+	.get_regs_len        = aq_ethtool_get_regs_len,
+	.get_regs            = aq_ethtool_get_regs,
+	.get_drvinfo         = aq_ethtool_get_drvinfo,
+	.get_strings         = aq_ethtool_get_strings,
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+	.get_rxfh_indir_size = aq_ethtool_get_rss_indir_size,
+#endif
+	.get_wol             = aq_ethtool_get_wol,
+	.set_wol             = aq_ethtool_set_wol,
+	.nway_reset          = aq_ethtool_nway_reset,
+	.get_ringparam       = aq_get_ringparam,
+	.set_ringparam       = aq_set_ringparam,
+	.get_eee             = aq_ethtool_get_eee,
+	.set_eee             = aq_ethtool_set_eee,
+	.get_pauseparam      = aq_ethtool_get_pauseparam,
+	.set_pauseparam      = aq_ethtool_set_pauseparam,
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 16, 0)
+	.get_rxfh_key_size   = aq_ethtool_get_rss_key_size,
+	.get_rxfh            = aq_ethtool_get_rss,
+#endif
+	.get_rxnfc           = aq_ethtool_get_rxnfc,
+	.get_sset_count      = aq_ethtool_get_sset_count,
+	.get_ethtool_stats   = aq_ethtool_stats,
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 6, 0)
+	.get_link_ksettings  = aq_ethtool_get_link_ksettings,
+	.set_link_ksettings  = aq_ethtool_set_link_ksettings,
+#else
+	.get_settings        = aq_ethtool_get_settings,
+	.set_settings        = aq_ethtool_set_settings,
+#endif
+	.get_coalesce	     = aq_ethtool_get_coalesce,
+	.set_coalesce	     = aq_ethtool_set_coalesce,
+};
diff --git a/drivers/net/ethernet/aquantia/aq_ethtool.h b/drivers/net/ethernet/aquantia/aq_ethtool.h
new file mode 100644
index 00000000..21c126e
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_ethtool.h
@@ -0,0 +1,19 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_ethtool.h: Declaration of ethertool related functions. */
+
+#ifndef AQ_ETHTOOL_H
+#define AQ_ETHTOOL_H
+
+#include "aq_common.h"
+
+extern const struct ethtool_ops aq_ethtool_ops;
+
+#endif /* AQ_ETHTOOL_H */
diff --git a/drivers/net/ethernet/aquantia/aq_hw.h b/drivers/net/ethernet/aquantia/aq_hw.h
new file mode 100644
index 00000000..83634bb
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_hw.h
@@ -0,0 +1,243 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_hw.h: Declaration of abstract interface for NIC hardware specific
+ * functions.
+ */
+
+#ifndef AQ_HW_H
+#define AQ_HW_H
+
+#include "aq_common.h"
+#include "aq_rss.h"
+#include "hw_atl/hw_atl_utils.h"
+
+/* NIC H/W capabilities */
+struct aq_hw_caps_s {
+	u64 hw_features;
+	u64 link_speed_msk;
+	unsigned int hw_priv_flags;
+	u32 media_type;
+	u32 rxds_max;
+	u32 txds_max;
+	u32 rxds_min;
+	u32 txds_min;
+	u32 txhwb_alignment;
+	u32 irq_mask;
+	u32 vecs;
+	u32 mtu;
+	u32 mac_regs_count;
+	u32 hw_alive_check_addr;
+	u8 msix_irqs;
+	u8 tcs;
+	u8 rxd_alignment;
+	u8 rxd_size;
+	u8 txd_alignment;
+	u8 txd_size;
+	u8 tx_rings;
+	u8 rx_rings;
+	bool flow_control;
+	bool is_64_dma;
+};
+
+struct aq_hw_link_status_s {
+	unsigned int mbps;
+};
+
+struct aq_stats_s {
+	u64 uprc;
+	u64 mprc;
+	u64 bprc;
+	u64 erpt;
+	u64 uptc;
+	u64 mptc;
+	u64 bptc;
+	u64 erpr;
+	u64 mbtc;
+	u64 bbtc;
+	u64 mbrc;
+	u64 bbrc;
+	u64 ubrc;
+	u64 ubtc;
+	u64 dpc;
+	u64 dma_pkt_rc;
+	u64 dma_pkt_tc;
+	u64 dma_oct_rc;
+	u64 dma_oct_tc;
+};
+
+#define AQ_HW_IRQ_INVALID 0U
+#define AQ_HW_IRQ_LEGACY  1U
+#define AQ_HW_IRQ_MSI     2U
+#define AQ_HW_IRQ_MSIX    3U
+
+#define AQ_HW_POWER_STATE_D0   0U
+#define AQ_HW_POWER_STATE_D3   3U
+
+#define AQ_HW_FLAG_STARTED     0x00000004U
+#define AQ_HW_FLAG_STOPPING    0x00000008U
+#define AQ_HW_FLAG_RESETTING   0x00000010U
+#define AQ_HW_FLAG_CLOSING     0x00000020U
+#define AQ_HW_LINK_DOWN        0x04000000U
+#define AQ_HW_FLAG_ERR_UNPLUG  0x40000000U
+#define AQ_HW_FLAG_ERR_HW      0x80000000U
+
+#define AQ_HW_FLAG_ERRORS      (AQ_HW_FLAG_ERR_HW | AQ_HW_FLAG_ERR_UNPLUG)
+
+#define AQ_NIC_FLAGS_IS_NOT_READY (AQ_NIC_FLAG_STOPPING | \
+			AQ_NIC_FLAG_RESETTING | AQ_NIC_FLAG_CLOSING | \
+			AQ_NIC_FLAG_ERR_UNPLUG | AQ_NIC_FLAG_ERR_HW)
+
+#define AQ_NIC_FLAGS_IS_NOT_TX_READY (AQ_NIC_FLAGS_IS_NOT_READY | \
+					AQ_NIC_LINK_DOWN)
+
+#define AQ_HW_MEDIA_TYPE_TP    1U
+#define AQ_HW_MEDIA_TYPE_FIBRE 2U
+
+#define AQ_HW_TXD_MULTIPLE 8U
+#define AQ_HW_RXD_MULTIPLE 8U
+
+struct aq_hw_s {
+	atomic_t flags;
+	u8 rbl_enabled:1;
+	struct aq_nic_cfg_s *aq_nic_cfg;
+	const struct aq_fw_ops *aq_fw_ops;
+	void __iomem *mmio;
+	struct aq_hw_link_status_s aq_link_status;
+	struct hw_aq_atl_utils_mbox mbox;
+	struct hw_atl_stats_s last_stats;
+	struct aq_stats_s curr_stats;
+
+	u64 speed;
+	u32 itr_tx;
+	u32 itr_rx;
+	unsigned int chip_features;
+	u32 fw_ver_actual;
+	atomic_t dpc;
+	u32 mbox_addr;
+	u32 rpc_addr;
+	u32 rpc_tid;
+	struct hw_aq_atl_utils_fw_rpc rpc;
+};
+
+struct aq_ring_s;
+struct aq_ring_param_s;
+struct sk_buff;
+
+struct aq_hw_ops {
+
+	int (*hw_ring_tx_xmit)(struct aq_hw_s *self, struct aq_ring_s *aq_ring,
+			       unsigned int frags);
+
+	int (*hw_ring_rx_receive)(struct aq_hw_s *self,
+				  struct aq_ring_s *aq_ring);
+
+	int (*hw_ring_rx_fill)(struct aq_hw_s *self, struct aq_ring_s *aq_ring,
+			       unsigned int sw_tail_old);
+
+	int (*hw_ring_tx_head_update)(struct aq_hw_s *self,
+				      struct aq_ring_s *aq_ring);
+
+	int (*hw_set_mac_address)(struct aq_hw_s *self, u8 *mac_addr);
+
+	int (*hw_reset)(struct aq_hw_s *self);
+
+	int (*hw_init)(struct aq_hw_s *self, u8 *mac_addr);
+
+	int (*hw_start)(struct aq_hw_s *self);
+
+	int (*hw_stop)(struct aq_hw_s *self);
+
+	int (*hw_ring_tx_init)(struct aq_hw_s *self, struct aq_ring_s *aq_ring,
+			       struct aq_ring_param_s *aq_ring_param);
+
+	int (*hw_ring_tx_start)(struct aq_hw_s *self,
+				struct aq_ring_s *aq_ring);
+
+	int (*hw_ring_tx_stop)(struct aq_hw_s *self,
+			       struct aq_ring_s *aq_ring);
+
+	int (*hw_ring_rx_init)(struct aq_hw_s *self,
+			       struct aq_ring_s *aq_ring,
+			       struct aq_ring_param_s *aq_ring_param);
+
+	int (*hw_ring_rx_start)(struct aq_hw_s *self,
+				struct aq_ring_s *aq_ring);
+
+	int (*hw_ring_rx_stop)(struct aq_hw_s *self,
+			       struct aq_ring_s *aq_ring);
+
+	int (*hw_irq_enable)(struct aq_hw_s *self, u64 mask);
+
+	int (*hw_irq_disable)(struct aq_hw_s *self, u64 mask);
+
+	int (*hw_irq_read)(struct aq_hw_s *self, u64 *mask);
+
+	int (*hw_packet_filter_set)(struct aq_hw_s *self,
+				    unsigned int packet_filter);
+
+	int (*hw_multicast_list_set)(struct aq_hw_s *self,
+				     u8 ar_mac[AQ_CFG_MULTICAST_ADDRESS_MAX]
+				     [ETH_ALEN],
+				     u32 count);
+
+	int (*hw_interrupt_moderation_set)(struct aq_hw_s *self);
+
+	int (*hw_rss_set)(struct aq_hw_s *self,
+			  struct aq_rss_parameters *rss_params);
+
+	int (*hw_rss_hash_set)(struct aq_hw_s *self,
+			       struct aq_rss_parameters *rss_params);
+
+	int (*hw_get_regs)(struct aq_hw_s *self,
+			   const struct aq_hw_caps_s *aq_hw_caps,
+			   u32 *regs_buff);
+
+	struct aq_stats_s *(*hw_get_hw_stats)(struct aq_hw_s *self);
+
+	int (*hw_get_fw_version)(struct aq_hw_s *self, u32 *fw_version);
+
+};
+
+struct aq_fw_ops {
+	int (*init)(struct aq_hw_s *self);
+
+	int (*deinit)(struct aq_hw_s *self);
+
+	int (*reset)(struct aq_hw_s *self);
+
+	int (*renegotiate)(struct aq_hw_s *self);
+
+	int (*get_mac_permanent)(struct aq_hw_s *self, u8 *mac);
+
+	int (*set_link_speed)(struct aq_hw_s *self, u32 speed);
+
+	int (*set_state)(struct aq_hw_s *self,
+			enum hal_atl_utils_fw_state_e state);
+
+	int (*update_link_status)(struct aq_hw_s *self);
+
+	int (*update_stats)(struct aq_hw_s *self);
+
+	int (*set_power)(struct aq_hw_s *self, unsigned int power_state,
+			u8 *mac);
+
+	int (*get_temp)(struct aq_hw_s *self, int *temp);
+
+	int (*get_cable_len)(struct aq_hw_s *self, int *cable_len);
+
+	int (*set_eee_rate)(struct aq_hw_s *self, u32 speed);
+
+	int (*get_eee_rate)(struct aq_hw_s *self, u32 *rate,
+			u32 *supported_rates);
+
+	int (*set_flow_control)(struct aq_hw_s *self);
+};
+
+#endif /* AQ_HW_H */
diff --git a/drivers/net/ethernet/aquantia/aq_hw_utils.c b/drivers/net/ethernet/aquantia/aq_hw_utils.c
new file mode 100644
index 00000000..d526c4f
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_hw_utils.c
@@ -0,0 +1,71 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_hw_utils.c: Definitions of helper functions used across
+ * hardware layer.
+ */
+
+#include "aq_hw_utils.h"
+#include "aq_hw.h"
+#include "aq_nic.h"
+
+void aq_hw_write_reg_bit(struct aq_hw_s *aq_hw, u32 addr, u32 msk,
+			 u32 shift, u32 val)
+{
+	if (msk ^ ~0) {
+		u32 reg_old, reg_new;
+
+		reg_old = aq_hw_read_reg(aq_hw, addr);
+		reg_new = (reg_old & (~msk)) | (val << shift);
+
+		if (reg_old != reg_new)
+			aq_hw_write_reg(aq_hw, addr, reg_new);
+	} else {
+		aq_hw_write_reg(aq_hw, addr, val);
+	}
+}
+
+u32 aq_hw_read_reg_bit(struct aq_hw_s *aq_hw, u32 addr, u32 msk, u32 shift)
+{
+	return ((aq_hw_read_reg(aq_hw, addr) & msk) >> shift);
+}
+
+u32 aq_hw_read_reg(struct aq_hw_s *hw, u32 reg)
+{
+	u32 value = readl(hw->mmio + reg);
+
+	if ((~0U) == value &&
+	    (~0U) == readl(hw->mmio +
+			   hw->aq_nic_cfg->aq_hw_caps->hw_alive_check_addr))
+		aq_utils_obj_set(&hw->flags, AQ_HW_FLAG_ERR_UNPLUG);
+
+	return value;
+}
+
+void aq_hw_write_reg(struct aq_hw_s *hw, u32 reg, u32 value)
+{
+	writel(value, hw->mmio + reg);
+}
+
+int aq_hw_err_from_flags(struct aq_hw_s *hw)
+{
+	int err = 0;
+
+	if (aq_utils_obj_test(&hw->flags, AQ_HW_FLAG_ERR_UNPLUG)) {
+		err = -ENXIO;
+		goto err_exit;
+	}
+	if (aq_utils_obj_test(&hw->flags, AQ_HW_FLAG_ERR_HW)) {
+		err = -EIO;
+		goto err_exit;
+	}
+
+err_exit:
+	return err;
+}
diff --git a/drivers/net/ethernet/aquantia/aq_hw_utils.h b/drivers/net/ethernet/aquantia/aq_hw_utils.h
new file mode 100644
index 00000000..dc88a12
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_hw_utils.h
@@ -0,0 +1,50 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_hw_utils.h: Declaration of helper functions used across hardware
+ * layer.
+ */
+
+#ifndef AQ_HW_UTILS_H
+#define AQ_HW_UTILS_H
+
+#include "aq_common.h"
+
+#ifndef HIDWORD
+#define LODWORD(_qw)    ((u32)(_qw))
+#define HIDWORD(_qw)    ((u32)(((_qw) >> 32) & 0xffffffff))
+#endif
+
+#define AQ_HW_SLEEP(_US_) mdelay(_US_)
+
+#define AQ_HW_WAIT_FOR(_B_, _US_, _N_) \
+do { \
+	unsigned int AQ_HW_WAIT_FOR_i; \
+	for (AQ_HW_WAIT_FOR_i = _N_; (!(_B_)) && (AQ_HW_WAIT_FOR_i);\
+	--AQ_HW_WAIT_FOR_i) {\
+		udelay(_US_); \
+	} \
+	if (!AQ_HW_WAIT_FOR_i) {\
+		err = -ETIME; \
+	} \
+} while (0)
+
+#define aq_pr_err(...) pr_err(AQ_CFG_DRV_NAME ": " __VA_ARGS__)
+#define aq_pr_trace(...) pr_info(AQ_CFG_DRV_NAME ": " __VA_ARGS__)
+
+struct aq_hw_s;
+
+void aq_hw_write_reg_bit(struct aq_hw_s *aq_hw, u32 addr, u32 msk,
+			 u32 shift, u32 val);
+u32 aq_hw_read_reg_bit(struct aq_hw_s *aq_hw, u32 addr, u32 msk, u32 shift);
+u32 aq_hw_read_reg(struct aq_hw_s *hw, u32 reg);
+void aq_hw_write_reg(struct aq_hw_s *hw, u32 reg, u32 value);
+int aq_hw_err_from_flags(struct aq_hw_s *hw);
+
+#endif /* AQ_HW_UTILS_H */
diff --git a/drivers/net/ethernet/aquantia/aq_main.c b/drivers/net/ethernet/aquantia/aq_main.c
new file mode 100644
index 00000000..8ad57e0
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_main.c
@@ -0,0 +1,190 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_main.c: Main file for aQuantia Linux driver. */
+
+#include "aq_main.h"
+#include "aq_nic.h"
+#include "aq_pci_func.h"
+#include "aq_ethtool.h"
+#include "aq_drvinfo.h"
+
+#include <linux/netdevice.h>
+#include <linux/module.h>
+#include <linux/init.h>
+#include <linux/kobject.h>
+#include <linux/stat.h>
+#include <linux/string.h>
+#include <linux/sysfs.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+#include <uapi/linux/stat.h>
+#endif
+
+MODULE_LICENSE("GPL v2");
+MODULE_VERSION(AQ_CFG_DRV_VERSION);
+MODULE_AUTHOR(AQ_CFG_DRV_AUTHOR);
+MODULE_DESCRIPTION(AQ_CFG_DRV_DESC);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+int aq_phy_deferred_linkdown = 1;
+module_param_named(deferred_linkdown, aq_phy_deferred_linkdown, int, 0600);
+MODULE_PARM_DESC(deferred_linkdown, "Max linkdown count for lanact event");
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+
+static const struct net_device_ops aq_ndev_ops;
+
+struct net_device *aq_ndev_alloc(void)
+{
+	struct net_device *ndev = NULL;
+	struct aq_nic_s *aq_nic = NULL;
+
+	ndev = alloc_etherdev_mq(sizeof(struct aq_nic_s), AQ_CFG_VECS_MAX);
+	if (!ndev)
+		return NULL;
+
+	aq_nic = netdev_priv(ndev);
+	aq_nic->ndev = ndev;
+	ndev->netdev_ops = &aq_ndev_ops;
+	ndev->ethtool_ops = &aq_ethtool_ops;
+
+	return ndev;
+}
+
+static int aq_ndev_open(struct net_device *ndev)
+{
+	int err = 0;
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+
+	aq_sysfs_init(ndev);
+
+	err = aq_nic_init(aq_nic);
+	if (err < 0)
+		goto err_exit;
+	err = aq_nic_start(aq_nic);
+	if (err < 0)
+		goto err_exit;
+
+err_exit:
+	if (err < 0)
+		aq_nic_deinit(aq_nic);
+	return err;
+}
+
+static int aq_ndev_close(struct net_device *ndev)
+{
+	int err = 0;
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+
+	aq_sysfs_exit(ndev);
+
+
+	err = aq_nic_stop(aq_nic);
+	if (err < 0)
+		goto err_exit;
+	aq_nic_deinit(aq_nic);
+
+err_exit:
+	return err;
+}
+
+static int aq_ndev_start_xmit(struct sk_buff *skb, struct net_device *ndev)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+
+	return aq_nic_xmit(aq_nic, skb);
+}
+
+static int aq_ndev_change_mtu(struct net_device *ndev, int new_mtu)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	int err = aq_nic_set_mtu(aq_nic, new_mtu + ETH_HLEN);
+
+	if (err < 0)
+		goto err_exit;
+	ndev->mtu = new_mtu;
+
+err_exit:
+	return err;
+}
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+static int aq_ndev_set_features(struct net_device *ndev,
+				netdev_features_t features)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	struct aq_nic_cfg_s *aq_cfg = aq_nic_get_cfg(aq_nic);
+	bool is_lro = false;
+
+	if (aq_cfg->hw_features & NETIF_F_LRO) {
+		is_lro = features & NETIF_F_LRO;
+
+		if (aq_cfg->is_lro != is_lro) {
+			aq_cfg->is_lro = is_lro;
+
+			if (netif_running(ndev)) {
+				aq_ndev_close(ndev);
+				aq_ndev_open(ndev);
+			}
+		}
+	}
+
+	return 0;
+}
+#endif
+
+static int aq_ndev_set_mac_address(struct net_device *ndev, void *addr)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	int err = 0;
+
+	err = eth_mac_addr(ndev, addr);
+	if (err < 0)
+		goto err_exit;
+	err = aq_nic_set_mac(aq_nic, ndev);
+	if (err < 0)
+		goto err_exit;
+
+err_exit:
+	return err;
+}
+
+static void aq_ndev_set_multicast_settings(struct net_device *ndev)
+{
+	struct aq_nic_s *aq_nic = netdev_priv(ndev);
+	int err = 0;
+
+	err = aq_nic_set_packet_filter(aq_nic, ndev->flags);
+	if (err < 0)
+		return;
+
+	if (netdev_mc_count(ndev)) {
+		err = aq_nic_set_multicast_list(aq_nic, ndev);
+		if (err < 0)
+			return;
+	}
+}
+
+static const struct net_device_ops aq_ndev_ops = {
+	.ndo_open = aq_ndev_open,
+	.ndo_stop = aq_ndev_close,
+	.ndo_start_xmit = aq_ndev_start_xmit,
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 2, 0)
+	.ndo_set_multicast_list = aq_ndev_set_multicast_settings,
+#else
+	.ndo_set_rx_mode = aq_ndev_set_multicast_settings,
+#endif
+#if (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,5))
+	.extended.ndo_change_mtu = aq_ndev_change_mtu,
+#else
+	.ndo_change_mtu = aq_ndev_change_mtu,
+#endif
+	.ndo_set_mac_address = aq_ndev_set_mac_address,
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+	.ndo_set_features = aq_ndev_set_features
+#endif
+};
diff --git a/drivers/net/ethernet/aquantia/aq_main.h b/drivers/net/ethernet/aquantia/aq_main.h
new file mode 100644
index 00000000..ce92152
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_main.h
@@ -0,0 +1,19 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_main.h: Main file for aQuantia Linux driver. */
+
+#ifndef AQ_MAIN_H
+#define AQ_MAIN_H
+
+#include "aq_common.h"
+
+struct net_device *aq_ndev_alloc(void);
+
+#endif /* AQ_MAIN_H */
diff --git a/drivers/net/ethernet/aquantia/aq_nic.c b/drivers/net/ethernet/aquantia/aq_nic.c
new file mode 100644
index 00000000..088db46
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_nic.c
@@ -0,0 +1,1162 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_nic.c: Definition of common code for NIC. */
+
+#include "aq_nic.h"
+#include "aq_ring.h"
+#include "aq_vec.h"
+#include "aq_hw.h"
+#include "aq_pci_func.h"
+
+#include <linux/moduleparam.h>
+#include <linux/netdevice.h>
+#include <linux/etherdevice.h>
+#include <linux/timer.h>
+#include <linux/cpu.h>
+#include <linux/ip.h>
+#include <linux/tcp.h>
+#include <net/ip.h>
+#include <net/tcp.h>
+#include <net/ipv6.h>
+
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+#include "buffalo/kernevnt.h"
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+
+static unsigned int aq_itr = AQ_CFG_INTERRUPT_MODERATION_AUTO;
+module_param_named(aq_itr, aq_itr, uint, 0644);
+MODULE_PARM_DESC(aq_itr, "Interrupt throttling mode");
+
+static unsigned int aq_itr_tx;
+module_param_named(aq_itr_tx, aq_itr_tx, uint, 0644);
+MODULE_PARM_DESC(aq_itr_tx, "TX interrupt throttle rate");
+
+static unsigned int aq_itr_rx;
+module_param_named(aq_itr_rx, aq_itr_rx, uint, 0644);
+MODULE_PARM_DESC(aq_itr_rx, "RX interrupt throttle rate");
+
+static unsigned int aq_rxpageorder = 0;
+module_param_named(aq_rxpageorder, aq_rxpageorder, uint, 0644);
+MODULE_PARM_DESC(aq_rxpageorder, "RX page order override");
+
+unsigned aq_rx_refill_thres = 32;
+module_param_named(aq_rx_refill_thres, aq_rx_refill_thres, uint, 0644);
+MODULE_PARM_DESC(aq_rx_refill_thres, "RX refill threshold");
+
+static void aq_nic_update_ndev_stats(struct aq_nic_s *self);
+
+static void aq_nic_rss_init(struct aq_nic_s *self, unsigned int num_rss_queues)
+{
+	struct aq_nic_cfg_s *cfg = &self->aq_nic_cfg;
+	struct aq_rss_parameters *rss_params = &cfg->aq_rss;
+	int i = 0;
+
+	static u8 rss_key[40] = {
+		0x1e, 0xad, 0x71, 0x87, 0x65, 0xfc, 0x26, 0x7d,
+		0x0d, 0x45, 0x67, 0x74, 0xcd, 0x06, 0x1a, 0x18,
+		0xb6, 0xc1, 0xf0, 0xc7, 0xbb, 0x18, 0xbe, 0xf8,
+		0x19, 0x13, 0x4b, 0xa9, 0xd0, 0x3e, 0xfe, 0x70,
+		0x25, 0x03, 0xab, 0x50, 0x6a, 0x8b, 0x82, 0x0c
+	};
+
+	rss_params->hash_secret_key_size = sizeof(rss_key);
+	memcpy(rss_params->hash_secret_key, rss_key, sizeof(rss_key));
+	rss_params->indirection_table_size = AQ_CFG_RSS_INDIRECTION_TABLE_MAX;
+
+	for (i = rss_params->indirection_table_size; i--;)
+		rss_params->indirection_table[i] = i & (num_rss_queues - 1);
+}
+
+/* Checks hw_caps and 'corrects' aq_nic_cfg in runtime */
+void aq_nic_cfg_start(struct aq_nic_s *self)
+{
+	struct aq_nic_cfg_s *cfg = &self->aq_nic_cfg;
+
+	cfg->tcs = AQ_CFG_TCS_DEF;
+
+	cfg->is_polling = AQ_CFG_IS_POLLING_DEF;
+
+	cfg->itr = aq_itr;
+	cfg->tx_itr = aq_itr_tx;
+	cfg->rx_itr = aq_itr_rx;
+
+	cfg->rxpageorder = aq_rxpageorder;
+	cfg->is_rss = AQ_CFG_IS_RSS_DEF;
+	cfg->num_rss_queues = AQ_CFG_NUM_RSS_QUEUES_DEF;
+	cfg->aq_rss.base_cpu_number = AQ_CFG_RSS_BASE_CPU_NUM_DEF;
+	cfg->flow_control = AQ_CFG_FC_MODE;
+
+	cfg->mtu = AQ_CFG_MTU_DEF;
+	cfg->link_speed_msk = AQ_CFG_SPEED_MSK;
+	cfg->is_autoneg = AQ_CFG_IS_AUTONEG_DEF;
+
+	cfg->is_lro = AQ_CFG_IS_LRO_DEF;
+
+	cfg->vlan_id = 0U;
+
+	aq_nic_rss_init(self, cfg->num_rss_queues);
+
+	/*descriptors */
+	cfg->rxds = min(cfg->aq_hw_caps->rxds_max, AQ_CFG_RXDS_DEF);
+	cfg->txds = min(cfg->aq_hw_caps->txds_max, AQ_CFG_TXDS_DEF);
+
+	/*rss rings */
+	cfg->vecs = min(cfg->aq_hw_caps->vecs, AQ_CFG_VECS_DEF);
+	cfg->vecs = min(cfg->vecs, num_online_cpus());
+	cfg->vecs = min(cfg->vecs, self->irqvecs);
+	/* cfg->vecs should be power of 2 for RSS */
+	if (cfg->vecs >= 8U)
+		cfg->vecs = 8U;
+	else if (cfg->vecs >= 4U)
+		cfg->vecs = 4U;
+	else if (cfg->vecs >= 2U)
+		cfg->vecs = 2U;
+	else
+		cfg->vecs = 1U;
+
+	cfg->num_rss_queues = min(cfg->vecs, AQ_CFG_NUM_RSS_QUEUES_DEF);
+
+	cfg->irq_type = aq_pci_func_get_irq_type(self);
+
+	if ((cfg->irq_type == AQ_HW_IRQ_LEGACY) ||
+	    (cfg->aq_hw_caps->vecs == 1U) ||
+	    (cfg->vecs == 1U)) {
+		cfg->is_rss = 0U;
+		cfg->vecs = 1U;
+	}
+
+	cfg->link_speed_msk &= cfg->aq_hw_caps->link_speed_msk;
+	cfg->hw_features = cfg->aq_hw_caps->hw_features;
+}
+
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+extern int aq_phy_deferred_linkdown;
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+static int aq_nic_update_link_status(struct aq_nic_s *self)
+{
+	int err = self->aq_fw_ops->update_link_status(self->aq_hw);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	int new_state = 0;
+	unsigned int max_linkdown = max(aq_phy_deferred_linkdown, 1);
+	struct timespec ts;
+	unsigned long now;
+
+	ktime_get_ts(&ts);
+	now = (unsigned long)ts.tv_sec;
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+
+	if (err)
+		return err;
+
+	if (self->link_status.mbps != self->aq_hw->aq_link_status.mbps) {
+		pr_info("%s: link change old %d new %d\n",
+			AQ_CFG_DRV_NAME, self->link_status.mbps,
+			self->aq_hw->aq_link_status.mbps);
+		aq_nic_update_interrupt_moderation_settings(self);
+	}
+
+	self->link_status = self->aq_hw->aq_link_status;
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+        /* prepare for called just after initialization */
+	if (self->state_cache.down_tv == ~0UL || max_linkdown <= 1) {
+		self->state_cache.down_tv = now - max_linkdown;
+	} else if (netif_carrier_ok(self->ndev)) {
+		self->state_cache.down_tv = now;
+	}
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+
+	if (!netif_carrier_ok(self->ndev) && self->link_status.mbps) {
+		aq_utils_obj_set(&self->flags,
+				 AQ_NIC_FLAG_STARTED);
+		aq_utils_obj_clear(&self->flags,
+				   AQ_NIC_LINK_DOWN);
+		netif_carrier_on(self->ndev);
+		netif_tx_wake_all_queues(self->ndev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+		/* issue event when link-down count was expired */
+		new_state += (self->state_cache.link != 1);
+		new_state += (self->state_cache.speed != self->link_status.mbps);
+		self->state_cache.link = 1;
+		self->state_cache.down_tv = 0;
+		self->state_cache.speed = self->link_status.mbps;
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+	}
+	if (netif_carrier_ok(self->ndev) && !self->link_status.mbps) {
+		netif_carrier_off(self->ndev);
+		netif_tx_disable(self->ndev);
+		aq_utils_obj_set(&self->flags, AQ_NIC_LINK_DOWN);
+	}
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	if (!self->link_status.mbps) {
+		/* issue event only when link-down count was overflow */
+		if (now >= (self->state_cache.down_tv + max_linkdown)) {
+			new_state += (self->state_cache.link != 0);
+			self->state_cache.link = 0;
+		}
+	}
+	if (new_state) {
+		kernevnt_LanAct_params(self->ndev->name, self->link_status.mbps, 1);
+	}
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+	return 0;
+}
+
+static void aq_nic_service_timer_cb(struct timer_list *t)
+{
+	struct aq_nic_s *self = from_timer(self, t, service_timer);
+	int ctimer = AQ_CFG_SERVICE_TIMER_INTERVAL;
+	int err = 0;
+
+	spin_lock(&self->aq_spinlock);
+
+	if (aq_utils_obj_test(&self->flags, AQ_NIC_FLAGS_IS_NOT_READY))
+		goto err_exit;
+
+	err = aq_nic_update_link_status(self);
+	if (err)
+		goto err_exit;
+
+	if (self->aq_fw_ops->update_stats)
+		self->aq_fw_ops->update_stats(self->aq_hw);
+
+	aq_nic_update_ndev_stats(self);
+
+	/* If no link - use faster timer rate to detect link up asap */
+	if (!netif_carrier_ok(self->ndev))
+		ctimer = max(ctimer / 2, 1);
+
+err_exit:
+	spin_unlock(&self->aq_spinlock);
+	mod_timer(&self->service_timer, jiffies + ctimer);
+}
+
+static void aq_nic_polling_timer_cb(struct timer_list *t)
+{
+	struct aq_nic_s *self = from_timer(self, t, polling_timer);
+	struct aq_vec_s *aq_vec = NULL;
+	unsigned int i = 0U;
+
+	for (i = 0U, aq_vec = self->aq_vec[0];
+		self->aq_vecs > i; ++i, aq_vec = self->aq_vec[i])
+		aq_vec_isr(i, (void *)aq_vec);
+
+	mod_timer(&self->polling_timer, jiffies +
+		AQ_CFG_POLLING_TIMER_INTERVAL);
+}
+
+int aq_nic_ndev_register(struct aq_nic_s *self)
+{
+	int err = 0;
+
+	if (!self->ndev) {
+		err = -EINVAL;
+		goto err_exit;
+	}
+
+	err = hw_atl_utils_initfw(self->aq_hw, &self->aq_fw_ops);
+	if (err)
+		goto err_exit;
+
+	err = self->aq_fw_ops->get_mac_permanent(self->aq_hw,
+			    self->ndev->dev_addr);
+	if (err)
+		goto err_exit;
+
+#if defined(AQ_CFG_MAC_ADDR_PERMANENT)
+	{
+		static u8 mac_addr_permanent[] = AQ_CFG_MAC_ADDR_PERMANENT;
+
+		ether_addr_copy(self->ndev->dev_addr, mac_addr_permanent);
+	}
+#endif
+
+	for (self->aq_vecs = 0; self->aq_vecs < aq_nic_get_cfg(self)->vecs;
+	     self->aq_vecs++) {
+		self->aq_vec[self->aq_vecs] =
+		    aq_vec_alloc(self, self->aq_vecs, aq_nic_get_cfg(self));
+		if (!self->aq_vec[self->aq_vecs]) {
+			err = -ENOMEM;
+			goto err_exit;
+		}
+	}
+
+	netif_carrier_off(self->ndev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	kernevnt_LanAct_params(self->ndev->name, 0, 1);
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+
+	netif_tx_disable(self->ndev);
+
+	err = register_netdev(self->ndev);
+	if (err)
+		goto err_exit;
+
+err_exit:
+	return err;
+}
+
+void aq_nic_ndev_init(struct aq_nic_s *self)
+{
+	const struct aq_hw_caps_s *aq_hw_caps = self->aq_nic_cfg.aq_hw_caps;
+	struct aq_nic_cfg_s *aq_nic_cfg = &self->aq_nic_cfg;
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+	self->ndev->hw_features |= aq_hw_caps->hw_features;
+#endif
+	self->ndev->features = aq_hw_caps->hw_features;
+	self->ndev->vlan_features |= NETIF_F_HW_CSUM | NETIF_F_RXCSUM | NETIF_F_RXHASH | NETIF_F_SG | NETIF_F_LRO;
+	self->ndev->priv_flags = aq_hw_caps->hw_priv_flags;
+	self->ndev->priv_flags |= IFF_LIVE_ADDR_CHANGE;
+
+	self->ndev->mtu = aq_nic_cfg->mtu - ETH_HLEN;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 10, 0)
+	self->ndev->max_mtu = aq_hw_caps->mtu - ETH_FCS_LEN - ETH_HLEN;
+#elif (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,5))
+	self->ndev->extended->min_mtu = ETH_MIN_MTU;
+	self->ndev->extended->max_mtu = aq_hw_caps->mtu - ETH_FCS_LEN - ETH_HLEN;
+#endif
+}
+
+void aq_nic_set_tx_ring(struct aq_nic_s *self, unsigned int idx,
+			struct aq_ring_s *ring)
+{
+	self->aq_ring_tx[idx] = ring;
+}
+
+struct net_device *aq_nic_get_ndev(struct aq_nic_s *self)
+{
+	return self->ndev;
+}
+
+int aq_nic_init(struct aq_nic_s *self)
+{
+	struct aq_vec_s *aq_vec = NULL;
+	int err = 0;
+	unsigned int i = 0U;
+
+	self->power_state = AQ_HW_POWER_STATE_D0;
+	err = self->aq_hw_ops->hw_reset(self->aq_hw);
+	if (err < 0)
+		goto err_exit;
+
+	err = self->aq_hw_ops->hw_init(self->aq_hw,
+				       aq_nic_get_ndev(self)->dev_addr);
+	if (err < 0)
+		goto err_exit;
+
+	for (i = 0U, aq_vec = self->aq_vec[0];
+		self->aq_vecs > i; ++i, aq_vec = self->aq_vec[i])
+		aq_vec_init(aq_vec, self->aq_hw_ops, self->aq_hw);
+
+	spin_lock_init(&self->aq_spinlock);
+
+	netif_carrier_off(self->ndev);
+
+err_exit:
+	return err;
+}
+
+int aq_nic_start(struct aq_nic_s *self)
+{
+	struct aq_vec_s *aq_vec = NULL;
+	int err = 0;
+	unsigned int i = 0U;
+
+	err = self->aq_hw_ops->hw_multicast_list_set(self->aq_hw,
+						    self->mc_list.ar,
+						    self->mc_list.count);
+	if (err < 0)
+		goto err_exit;
+
+	err = self->aq_hw_ops->hw_packet_filter_set(self->aq_hw,
+						   self->packet_filter);
+	if (err < 0)
+		goto err_exit;
+
+	for (i = 0U, aq_vec = self->aq_vec[0];
+		self->aq_vecs > i; ++i, aq_vec = self->aq_vec[i]) {
+		err = aq_vec_start(aq_vec);
+		if (err < 0)
+			goto err_exit;
+	}
+
+	err = self->aq_hw_ops->hw_start(self->aq_hw);
+	if (err < 0)
+		goto err_exit;
+
+	err = aq_nic_update_interrupt_moderation_settings(self);
+	if (err)
+		goto err_exit;
+	timer_setup(&self->service_timer, aq_nic_service_timer_cb, 0);
+	mod_timer(&self->service_timer, jiffies +
+			AQ_CFG_SERVICE_TIMER_INTERVAL);
+
+	if (self->aq_nic_cfg.is_polling) {
+		timer_setup(&self->polling_timer, aq_nic_polling_timer_cb, 0);
+		mod_timer(&self->polling_timer, jiffies +
+			  AQ_CFG_POLLING_TIMER_INTERVAL);
+	} else {
+		for (i = 0U, aq_vec = self->aq_vec[0];
+			self->aq_vecs > i; ++i, aq_vec = self->aq_vec[i]) {
+			err = aq_pci_func_alloc_irq(self, i,
+						    self->ndev->name, aq_vec,
+						    aq_vec_get_affinity_mask(aq_vec));
+			if (err < 0)
+				goto err_exit;
+		}
+
+		err = self->aq_hw_ops->hw_irq_enable(self->aq_hw,
+				    AQ_CFG_IRQ_MASK);
+		if (err < 0)
+			goto err_exit;
+	}
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+	err = netif_set_real_num_tx_queues(self->ndev, self->aq_vecs);
+	if (err < 0)
+		goto err_exit;
+
+	err = netif_set_real_num_rx_queues(self->ndev, self->aq_vecs);
+	if (err < 0)
+		goto err_exit;
+#endif
+	netif_tx_start_all_queues(self->ndev);
+
+err_exit:
+	return err;
+}
+
+static unsigned int aq_nic_map_skb(struct aq_nic_s *self,
+				   struct sk_buff *skb,
+				   struct aq_ring_s *ring)
+{
+	unsigned int ret = 0U;
+	unsigned int nr_frags = skb_shinfo(skb)->nr_frags;
+	unsigned int frag_count = 0U;
+	unsigned int dx = ring->sw_tail;
+	struct aq_ring_buff_s *first = NULL;
+	struct aq_ring_buff_s *dx_buff = &ring->buff_ring[dx];
+
+	if (unlikely(skb_is_gso(skb))) {
+		dx_buff->flags = 0U;
+		dx_buff->len_pkt = skb->len;
+		dx_buff->len_l2 = ETH_HLEN;
+		dx_buff->len_l3 = ip_hdrlen(skb);
+		dx_buff->len_l4 = tcp_hdrlen(skb);
+		dx_buff->mss = skb_shinfo(skb)->gso_size;
+		dx_buff->is_txc = 1U;
+		dx_buff->eop_index = 0xffffU;
+
+		dx_buff->is_ipv6 =
+			(ip_hdr(skb)->version == 6) ? 1U : 0U;
+
+		dx = aq_ring_next_dx(ring, dx);
+		dx_buff = &ring->buff_ring[dx];
+		++ret;
+	}
+
+	dx_buff->flags = 0U;
+	dx_buff->len = skb_headlen(skb);
+	dx_buff->pa = dma_map_single(aq_nic_get_dev(self),
+				     skb->data,
+				     dx_buff->len,
+				     DMA_TO_DEVICE);
+
+	if (unlikely(dma_mapping_error(aq_nic_get_dev(self), dx_buff->pa)))
+		goto exit;
+
+	first = dx_buff;
+	dx_buff->len_pkt = skb->len;
+	dx_buff->is_sop = 1U;
+	dx_buff->is_mapped = 1U;
+	++ret;
+
+	if (skb->ip_summed == CHECKSUM_PARTIAL) {
+		dx_buff->is_ip_cso = (htons(ETH_P_IP) == skb->protocol) ?
+			1U : 0U;
+
+		if (ip_hdr(skb)->version == 4) {
+			dx_buff->is_tcp_cso =
+				(ip_hdr(skb)->protocol == IPPROTO_TCP) ?
+					1U : 0U;
+			dx_buff->is_udp_cso =
+				(ip_hdr(skb)->protocol == IPPROTO_UDP) ?
+					1U : 0U;
+		} else if (ip_hdr(skb)->version == 6) {
+			dx_buff->is_tcp_cso =
+				(ipv6_hdr(skb)->nexthdr == NEXTHDR_TCP) ?
+					1U : 0U;
+			dx_buff->is_udp_cso =
+				(ipv6_hdr(skb)->nexthdr == NEXTHDR_UDP) ?
+					1U : 0U;
+		}
+	}
+
+	for (; nr_frags--; ++frag_count) {
+		unsigned int frag_len = 0U;
+		unsigned int buff_offset = 0U;
+		unsigned int buff_size = 0U;
+		dma_addr_t frag_pa;
+		skb_frag_t *frag = &skb_shinfo(skb)->frags[frag_count];
+
+		frag_len = skb_frag_size(frag);
+
+		while (frag_len) {
+			if (frag_len > AQ_CFG_TX_FRAME_MAX)
+				buff_size = AQ_CFG_TX_FRAME_MAX;
+			else
+				buff_size = frag_len;
+
+			frag_pa = skb_frag_dma_map(aq_nic_get_dev(self),
+						   frag,
+						   buff_offset,
+						   buff_size,
+						   DMA_TO_DEVICE);
+
+			if (unlikely(dma_mapping_error(aq_nic_get_dev(self),
+						       frag_pa)))
+				goto mapping_error;
+
+			dx = aq_ring_next_dx(ring, dx);
+			dx_buff = &ring->buff_ring[dx];
+
+			dx_buff->flags = 0U;
+			dx_buff->len = buff_size;
+			dx_buff->pa = frag_pa;
+			dx_buff->is_mapped = 1U;
+			dx_buff->eop_index = 0xffffU;
+
+			frag_len -= buff_size;
+			buff_offset += buff_size;
+
+			++ret;
+		}
+	}
+
+	first->eop_index = dx;
+	dx_buff->is_eop = 1U;
+	dx_buff->skb = skb;
+	goto exit;
+
+mapping_error:
+	for (dx = ring->sw_tail;
+	     ret > 0;
+	     --ret, dx = aq_ring_next_dx(ring, dx)) {
+		dx_buff = &ring->buff_ring[dx];
+
+		if (!dx_buff->is_txc && dx_buff->pa) {
+			if (unlikely(dx_buff->is_sop)) {
+				dma_unmap_single(aq_nic_get_dev(self),
+						 dx_buff->pa,
+						 dx_buff->len,
+						 DMA_TO_DEVICE);
+			} else {
+				dma_unmap_page(aq_nic_get_dev(self),
+					       dx_buff->pa,
+					       dx_buff->len,
+					       DMA_TO_DEVICE);
+			}
+		}
+	}
+
+exit:
+	return ret;
+}
+
+int aq_nic_xmit(struct aq_nic_s *self, struct sk_buff *skb)
+{
+	struct aq_ring_s *ring = NULL;
+	unsigned int frags = 0U;
+	unsigned int vec = skb->queue_mapping % self->aq_nic_cfg.vecs;
+	unsigned int tc = 0U;
+	int err = NETDEV_TX_OK;
+
+	frags = skb_shinfo(skb)->nr_frags + 1;
+
+	ring = self->aq_ring_tx[AQ_NIC_TCVEC2RING(self, tc, vec)];
+
+	if (frags > AQ_CFG_SKB_FRAGS_MAX) {
+		dev_kfree_skb_any(skb);
+		goto err_exit;
+	}
+
+	aq_ring_update_queue_state(ring);
+
+	/* Above status update may stop the queue. Check this. */
+	if (__netif_subqueue_stopped(self->ndev, ring->idx)) {
+		err = NETDEV_TX_BUSY;
+		goto err_exit;
+	}
+
+	frags = aq_nic_map_skb(self, skb, ring);
+
+	if (likely(frags)) {
+		err = self->aq_hw_ops->hw_ring_tx_xmit(self->aq_hw,
+						       ring, frags);
+		if (err >= 0) {
+			++ring->stats.tx.packets;
+			ring->stats.tx.bytes += skb->len;
+		}
+	} else {
+		err = NETDEV_TX_BUSY;
+	}
+
+err_exit:
+	return err;
+}
+
+int aq_nic_update_interrupt_moderation_settings(struct aq_nic_s *self)
+{
+	return self->aq_hw_ops->hw_interrupt_moderation_set(self->aq_hw);
+}
+
+int aq_nic_set_packet_filter(struct aq_nic_s *self, unsigned int flags)
+{
+	int err = 0;
+
+	err = self->aq_hw_ops->hw_packet_filter_set(self->aq_hw, flags);
+	if (err < 0)
+		goto err_exit;
+
+	self->packet_filter = flags;
+
+err_exit:
+	return err;
+}
+
+int aq_nic_set_multicast_list(struct aq_nic_s *self, struct net_device *ndev)
+{
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+	struct netdev_hw_addr *ha = NULL;
+#else
+	struct dev_addr_list *ha = NULL;
+#endif
+	unsigned int i = 0U;
+
+	self->mc_list.count = 0U;
+	netdev_for_each_mc_addr(ha, ndev) {
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+		ether_addr_copy(self->mc_list.ar[i++], ha->addr);
+#else
+		ether_addr_copy(self->mc_list.ar[i++], ha->da_addr);
+#endif
+		++self->mc_list.count;
+
+		if (i >= AQ_CFG_MULTICAST_ADDRESS_MAX)
+			break;
+	}
+
+	if (i >= AQ_CFG_MULTICAST_ADDRESS_MAX) {
+		/* Number of filters is too big: atlantic does not support this.
+		 * Force all multi filter to support this.
+		 * With this we disable all UC filters and setup "all pass"
+		 * multicast mask
+		 */
+		self->packet_filter |= IFF_ALLMULTI;
+		self->aq_nic_cfg.mc_list_count = 0;
+		return self->aq_hw_ops->hw_packet_filter_set(self->aq_hw,
+							     self->packet_filter);
+	} else {
+		return self->aq_hw_ops->hw_multicast_list_set(self->aq_hw,
+						    self->mc_list.ar,
+						    self->mc_list.count);
+	}
+}
+
+int aq_nic_set_mtu(struct aq_nic_s *self, int new_mtu)
+{
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 10, 0)
+	if (new_mtu < ETH_MIN_MTU+ETH_HLEN ||
+	    new_mtu > self->aq_nic_cfg.aq_hw_caps->mtu - ETH_FCS_LEN)
+		return -EINVAL;
+#endif
+	self->aq_nic_cfg.mtu = new_mtu;
+
+	return 0;
+}
+
+int aq_nic_set_mac(struct aq_nic_s *self, struct net_device *ndev)
+{
+	return self->aq_hw_ops->hw_set_mac_address(self->aq_hw, ndev->dev_addr);
+}
+
+unsigned int aq_nic_get_link_speed(struct aq_nic_s *self)
+{
+	return self->link_status.mbps;
+}
+
+int aq_nic_get_regs(struct aq_nic_s *self, struct ethtool_regs *regs, void *p)
+{
+	u32 *regs_buff = p;
+	int err = 0;
+
+	regs->version = 1;
+
+	err = self->aq_hw_ops->hw_get_regs(self->aq_hw,
+					   self->aq_nic_cfg.aq_hw_caps,
+					   regs_buff);
+	if (err < 0)
+		goto err_exit;
+
+err_exit:
+	return err;
+}
+
+int aq_nic_get_regs_count(struct aq_nic_s *self)
+{
+	return self->aq_nic_cfg.aq_hw_caps->mac_regs_count;
+}
+
+void aq_nic_get_stats(struct aq_nic_s *self, u64 *data)
+{
+	unsigned int i = 0U;
+	unsigned int count = 0U;
+	struct aq_vec_s *aq_vec = NULL;
+	struct aq_stats_s *stats = self->aq_hw_ops->hw_get_hw_stats(self->aq_hw);
+
+	if (!stats)
+		goto err_exit;
+
+	data[i] = stats->uprc + stats->mprc + stats->bprc;
+	data[++i] = stats->uprc;
+	data[++i] = stats->mprc;
+	data[++i] = stats->bprc;
+	data[++i] = stats->erpt;
+	data[++i] = stats->uptc + stats->mptc + stats->bptc;
+	data[++i] = stats->uptc;
+	data[++i] = stats->mptc;
+	data[++i] = stats->bptc;
+	data[++i] = stats->ubrc;
+	data[++i] = stats->ubtc;
+	data[++i] = stats->mbrc;
+	data[++i] = stats->mbtc;
+	data[++i] = stats->bbrc;
+	data[++i] = stats->bbtc;
+	data[++i] = stats->ubrc + stats->mbrc + stats->bbrc;
+	data[++i] = stats->ubtc + stats->mbtc + stats->bbtc;
+	data[++i] = stats->dma_pkt_rc;
+	data[++i] = stats->dma_pkt_tc;
+	data[++i] = stats->dma_oct_rc;
+	data[++i] = stats->dma_oct_tc;
+	data[++i] = stats->dpc;
+
+	i++;
+
+	data += i;
+
+	for (i = 0U, aq_vec = self->aq_vec[0];
+		aq_vec && self->aq_vecs > i; ++i, aq_vec = self->aq_vec[i]) {
+		data += count;
+		aq_vec_get_sw_stats(aq_vec, data, &count);
+	}
+
+err_exit:;
+}
+
+static void aq_nic_update_ndev_stats(struct aq_nic_s *self)
+{
+	struct net_device *ndev = self->ndev;
+	struct aq_stats_s *stats = self->aq_hw_ops->hw_get_hw_stats(self->aq_hw);
+
+	ndev->stats.rx_packets = stats->uprc + stats->mprc + stats->bprc;
+	ndev->stats.rx_bytes = stats->ubrc + stats->mbrc + stats->bbrc;
+	ndev->stats.rx_errors = stats->erpr;
+	ndev->stats.tx_packets = stats->uptc + stats->mptc + stats->bptc;
+	ndev->stats.tx_bytes = stats->ubtc + stats->mbtc + stats->bbtc;
+	ndev->stats.tx_errors = stats->erpt;
+	ndev->stats.multicast = stats->mprc;
+}
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 6, 0)
+void aq_nic_get_link_ksettings(struct aq_nic_s *self,
+			       struct ethtool_link_ksettings *cmd)
+{
+	if (self->aq_nic_cfg.aq_hw_caps->media_type == AQ_HW_MEDIA_TYPE_FIBRE)
+		cmd->base.port = PORT_FIBRE;
+	else
+		cmd->base.port = PORT_TP;
+	/* This driver supports only 10G capable adapters, so DUPLEX_FULL */
+	cmd->base.duplex = DUPLEX_FULL;
+	cmd->base.autoneg = self->aq_nic_cfg.is_autoneg;
+
+	ethtool_link_ksettings_zero_link_mode(cmd, supported);
+
+	if (self->aq_nic_cfg.aq_hw_caps->link_speed_msk & AQ_NIC_RATE_10G)
+		ethtool_link_ksettings_add_link_mode(cmd, supported,
+						     10000baseT_Full);
+
+#if LINUX_VERSION_CODE > KERNEL_VERSION(4, 10, 0)
+	if (self->aq_nic_cfg.aq_hw_caps->link_speed_msk & AQ_NIC_RATE_5G)
+		ethtool_link_ksettings_add_link_mode(cmd, supported,
+						     5000baseT_Full);
+
+	if (self->aq_nic_cfg.aq_hw_caps->link_speed_msk & AQ_NIC_RATE_2GS)
+		ethtool_link_ksettings_add_link_mode(cmd, supported,
+						     2500baseT_Full);
+#endif
+	if (self->aq_nic_cfg.aq_hw_caps->link_speed_msk & AQ_NIC_RATE_1G)
+		ethtool_link_ksettings_add_link_mode(cmd, supported,
+						     1000baseT_Full);
+
+	if (self->aq_nic_cfg.aq_hw_caps->link_speed_msk & AQ_NIC_RATE_100M)
+		ethtool_link_ksettings_add_link_mode(cmd, supported,
+						     100baseT_Full);
+
+	if (self->aq_nic_cfg.aq_hw_caps->flow_control)
+		ethtool_link_ksettings_add_link_mode(cmd, supported,
+						     Pause);
+
+	ethtool_link_ksettings_add_link_mode(cmd, supported, Autoneg);
+
+	if (self->aq_nic_cfg.aq_hw_caps->media_type == AQ_HW_MEDIA_TYPE_FIBRE)
+		ethtool_link_ksettings_add_link_mode(cmd, supported, FIBRE);
+	else
+		ethtool_link_ksettings_add_link_mode(cmd, supported, TP);
+
+	ethtool_link_ksettings_zero_link_mode(cmd, advertising);
+
+	if (self->aq_nic_cfg.is_autoneg)
+		ethtool_link_ksettings_add_link_mode(cmd, advertising, Autoneg);
+
+	if (self->aq_nic_cfg.link_speed_msk  & AQ_NIC_RATE_10G)
+		ethtool_link_ksettings_add_link_mode(cmd, advertising,
+						     10000baseT_Full);
+#if LINUX_VERSION_CODE > KERNEL_VERSION(4, 10, 0)
+	if (self->aq_nic_cfg.link_speed_msk  & AQ_NIC_RATE_5G)
+		ethtool_link_ksettings_add_link_mode(cmd, advertising,
+						     5000baseT_Full);
+
+	if (self->aq_nic_cfg.link_speed_msk  & AQ_NIC_RATE_2GS)
+		ethtool_link_ksettings_add_link_mode(cmd, advertising,
+						     2500baseT_Full);
+#endif
+	if (self->aq_nic_cfg.link_speed_msk  & AQ_NIC_RATE_1G)
+		ethtool_link_ksettings_add_link_mode(cmd, advertising,
+						     1000baseT_Full);
+
+	if (self->aq_nic_cfg.link_speed_msk  & AQ_NIC_RATE_100M)
+		ethtool_link_ksettings_add_link_mode(cmd, advertising,
+						     100baseT_Full);
+
+	if (self->aq_nic_cfg.flow_control & AQ_NIC_FC_RX)
+		ethtool_link_ksettings_add_link_mode(cmd, advertising,
+						     Pause);
+
+	if (self->aq_nic_cfg.flow_control & AQ_NIC_FC_TX)
+		ethtool_link_ksettings_add_link_mode(cmd, advertising,
+						     Asym_Pause);
+
+	if (self->aq_nic_cfg.aq_hw_caps->media_type == AQ_HW_MEDIA_TYPE_FIBRE)
+		ethtool_link_ksettings_add_link_mode(cmd, advertising, FIBRE);
+	else
+		ethtool_link_ksettings_add_link_mode(cmd, advertising, TP);
+}
+
+int aq_nic_set_link_ksettings(struct aq_nic_s *self,
+			      const struct ethtool_link_ksettings *cmd)
+{
+	u32 speed = 0U;
+	u32 rate = 0U;
+	int err = 0;
+
+	if (cmd->base.autoneg == AUTONEG_ENABLE) {
+		rate = self->aq_nic_cfg.aq_hw_caps->link_speed_msk;
+		self->aq_nic_cfg.is_autoneg = true;
+	} else {
+		speed = cmd->base.speed;
+
+		switch (speed) {
+		case SPEED_100:
+			rate = AQ_NIC_RATE_100M;
+			break;
+
+		case SPEED_1000:
+			rate = AQ_NIC_RATE_1G;
+			break;
+
+		case SPEED_2500:
+			rate = AQ_NIC_RATE_2GS;
+			break;
+
+		case SPEED_5000:
+			rate = AQ_NIC_RATE_5G;
+			break;
+
+		case SPEED_10000:
+			rate = AQ_NIC_RATE_10G;
+			break;
+
+		default:
+			err = -1;
+			goto err_exit;
+		break;
+		}
+		if (!(self->aq_nic_cfg.aq_hw_caps->link_speed_msk & rate)) {
+			err = -1;
+			goto err_exit;
+		}
+
+		self->aq_nic_cfg.is_autoneg = false;
+	}
+
+	err = self->aq_fw_ops->set_link_speed(self->aq_hw, rate);
+	if (err < 0)
+		goto err_exit;
+
+	self->aq_nic_cfg.link_speed_msk = rate;
+
+err_exit:
+	return err;
+}
+#else
+void aq_nic_get_link_settings(struct aq_nic_s *self, struct ethtool_cmd *cmd)
+{
+	const struct aq_hw_caps_s *hw_caps = self->aq_nic_cfg.aq_hw_caps;
+
+	if (hw_caps->media_type == AQ_HW_MEDIA_TYPE_FIBRE)
+		cmd->port = PORT_FIBRE;
+	else
+		cmd->port = PORT_TP;
+	cmd->transceiver = XCVR_EXTERNAL;
+	/* This driver supports only 10G capable adapters, so DUPLEX_FULL */
+	cmd->duplex = DUPLEX_FULL;
+	cmd->autoneg = self->aq_nic_cfg.is_autoneg;
+
+
+	cmd->supported |= (hw_caps->link_speed_msk & AQ_NIC_RATE_10G) ?
+				ADVERTISED_10000baseT_Full : 0U;
+	cmd->supported |= (hw_caps->link_speed_msk & AQ_NIC_RATE_1G) ?
+				ADVERTISED_1000baseT_Full : 0U;
+	cmd->supported |= (hw_caps->link_speed_msk & AQ_NIC_RATE_100M) ?
+				ADVERTISED_100baseT_Full : 0U;
+	cmd->supported |= hw_caps->flow_control ? SUPPORTED_Pause : 0;
+	cmd->supported |= SUPPORTED_Autoneg;
+
+	if (hw_caps->media_type == AQ_HW_MEDIA_TYPE_FIBRE)
+		cmd->supported |= SUPPORTED_FIBRE;
+	else
+		cmd->supported |= SUPPORTED_TP;
+
+	cmd->advertising = (self->aq_nic_cfg.is_autoneg) ?
+							ADVERTISED_Autoneg : 0U;
+	cmd->advertising |=
+			(self->aq_nic_cfg.link_speed_msk & AQ_NIC_RATE_10G) ?
+			ADVERTISED_10000baseT_Full : 0U;
+	cmd->advertising |=
+			(self->aq_nic_cfg.link_speed_msk & AQ_NIC_RATE_1G) ?
+			ADVERTISED_1000baseT_Full : 0U;
+
+	cmd->advertising |=
+			(self->aq_nic_cfg.link_speed_msk & AQ_NIC_RATE_100M) ?
+			ADVERTISED_100baseT_Full : 0U;
+	cmd->advertising |= (self->aq_nic_cfg.flow_control) ?
+				ADVERTISED_Pause : 0U;
+
+	if (hw_caps->media_type == AQ_HW_MEDIA_TYPE_FIBRE)
+		cmd->advertising |= ADVERTISED_FIBRE;
+	else
+		cmd->advertising |= ADVERTISED_TP;
+}
+
+int aq_nic_set_link_settings(struct aq_nic_s *self, struct ethtool_cmd *cmd)
+{
+	u32 speed = 0U;
+	u32 rate = 0U;
+	int err = 0;
+
+	if (cmd->autoneg == AUTONEG_ENABLE) {
+		rate = self->aq_nic_cfg.aq_hw_caps->link_speed_msk;
+		self->aq_nic_cfg.is_autoneg = true;
+	} else {
+		speed = ethtool_cmd_speed(cmd);
+
+		switch (speed) {
+		case SPEED_100:
+			rate = AQ_NIC_RATE_100M;
+			break;
+
+		case SPEED_1000:
+			rate = AQ_NIC_RATE_1G;
+			break;
+
+		case SPEED_2500:
+			rate = AQ_NIC_RATE_2GS;
+			break;
+
+		case SPEED_5000:
+			rate = AQ_NIC_RATE_5G;
+			break;
+
+		case SPEED_10000:
+			rate = AQ_NIC_RATE_10G;
+			break;
+
+		default:
+			err = -1;
+			goto err_exit;
+		break;
+		}
+
+		if (!(self->aq_nic_cfg.aq_hw_caps->link_speed_msk & rate)) {
+			err = -1;
+			goto err_exit;
+		}
+
+		self->aq_nic_cfg.is_autoneg = false;
+	}
+
+	err = self->aq_fw_ops->set_link_speed(self->aq_hw, rate);
+	if (err < 0)
+		goto err_exit;
+
+	self->aq_nic_cfg.link_speed_msk = rate;
+
+err_exit:
+	return err;
+}
+
+#endif
+
+struct aq_nic_cfg_s *aq_nic_get_cfg(struct aq_nic_s *self)
+{
+	return &self->aq_nic_cfg;
+}
+
+u32 aq_nic_get_fw_version(struct aq_nic_s *self)
+{
+	u32 fw_version = 0U;
+
+	self->aq_hw_ops->hw_get_fw_version(self->aq_hw, &fw_version);
+
+	return fw_version;
+}
+
+int aq_nic_stop(struct aq_nic_s *self)
+{
+	struct aq_vec_s *aq_vec = NULL;
+	unsigned int i = 0U;
+
+	netif_tx_disable(self->ndev);
+	netif_carrier_off(self->ndev);
+
+	del_timer_sync(&self->service_timer);
+
+	self->aq_hw_ops->hw_irq_disable(self->aq_hw, AQ_CFG_IRQ_MASK);
+
+	if (self->aq_nic_cfg.is_polling)
+		del_timer_sync(&self->polling_timer);
+	else
+		aq_pci_func_free_irqs(self);
+
+	for (i = 0U, aq_vec = self->aq_vec[0];
+		self->aq_vecs > i; ++i, aq_vec = self->aq_vec[i])
+		aq_vec_stop(aq_vec);
+
+	return self->aq_hw_ops->hw_stop(self->aq_hw);
+}
+
+void aq_nic_deinit(struct aq_nic_s *self)
+{
+	struct aq_vec_s *aq_vec = NULL;
+	unsigned int i = 0U;
+
+	if (!self)
+		goto err_exit;
+
+	for (i = 0U, aq_vec = self->aq_vec[0];
+		self->aq_vecs > i; ++i, aq_vec = self->aq_vec[i])
+		aq_vec_deinit(aq_vec);
+
+	(void)self->aq_fw_ops->deinit(self->aq_hw);
+
+	if (self->power_state != AQ_HW_POWER_STATE_D0 ||
+	    self->aq_hw->aq_nic_cfg->wol) {
+		(void)self->aq_fw_ops->set_power(self->aq_hw,
+			self->power_state, self->ndev->dev_addr);
+	}
+
+err_exit:;
+}
+
+void aq_nic_free_vectors(struct aq_nic_s *self)
+{
+	unsigned int i = 0U;
+
+	if (!self)
+		goto err_exit;
+
+	for (i = ARRAY_SIZE(self->aq_vec); i--;) {
+		if (self->aq_vec[i]) {
+			aq_vec_free(self->aq_vec[i]);
+			self->aq_vec[i] = NULL;
+		}
+	}
+
+err_exit:;
+}
+
+int aq_nic_change_pm_state(struct aq_nic_s *self, pm_message_t *pm_msg)
+{
+	int err = 0;
+
+	if (!netif_running(self->ndev)) {
+		err = 0;
+		goto out;
+	}
+	rtnl_lock();
+	if (pm_msg->event & PM_EVENT_SLEEP || pm_msg->event & PM_EVENT_FREEZE) {
+		self->power_state = AQ_HW_POWER_STATE_D3;
+		netif_device_detach(self->ndev);
+		netif_tx_stop_all_queues(self->ndev);
+
+		err = aq_nic_stop(self);
+		if (err < 0)
+			goto err_exit;
+
+		aq_nic_deinit(self);
+	} else {
+		err = aq_nic_init(self);
+		if (err < 0)
+			goto err_exit;
+
+		err = aq_nic_start(self);
+		if (err < 0)
+			goto err_exit;
+
+		netif_device_attach(self->ndev);
+		netif_tx_start_all_queues(self->ndev);
+	}
+
+err_exit:
+	rtnl_unlock();
+out:
+	return err;
+}
+
+void aq_nic_shutdown(struct aq_nic_s *self)
+{
+	int err = 0;
+
+	if (!self->ndev)
+		return;
+
+	rtnl_lock();
+
+	netif_device_detach(self->ndev);
+
+	if (netif_running(self->ndev)) {
+		err = aq_nic_stop(self);
+		if (err < 0)
+			goto err_exit;
+	}
+	aq_nic_deinit(self);
+
+err_exit:
+	rtnl_unlock();
+}
diff --git a/drivers/net/ethernet/aquantia/aq_nic.h b/drivers/net/ethernet/aquantia/aq_nic.h
new file mode 100644
index 00000000..0e19d12
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_nic.h
@@ -0,0 +1,152 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_nic.h: Declaration of common code for NIC. */
+
+#ifndef AQ_NIC_H
+#define AQ_NIC_H
+
+#include "aq_common.h"
+#include "aq_rss.h"
+#include "aq_hw.h"
+
+struct aq_ring_s;
+struct aq_hw_ops;
+struct aq_fw_s;
+struct aq_vec_s;
+
+struct aq_nic_cfg_s {
+	const struct aq_hw_caps_s *aq_hw_caps;
+	u64 hw_features;
+	u32 rxds;		/* rx ring size, descriptors # */
+	u32 txds;		/* tx ring size, descriptors # */
+	u32 vecs;		/* vecs==allocated irqs */
+	u32 irq_type;
+	u32 itr;
+	u16 rx_itr;
+	u16 tx_itr;
+	u32 rxpageorder;
+	u32 num_rss_queues;
+	u32 mtu;
+	u32 flow_control;
+	u32 link_speed_msk;
+	u32 vlan_id;
+	u32 wol;
+	u16 is_mc_list_enabled;
+	u16 mc_list_count;
+	bool is_autoneg;
+	bool is_polling;
+	bool is_rss;
+	bool is_lro;
+	u8  tcs;
+	struct aq_rss_parameters aq_rss;
+	u32 eee_enabled;
+};
+
+#define AQ_NIC_FLAG_STARTED     0x00000004U
+#define AQ_NIC_FLAG_STOPPING    0x00000008U
+#define AQ_NIC_FLAG_RESETTING   0x00000010U
+#define AQ_NIC_FLAG_CLOSING     0x00000020U
+#define AQ_NIC_LINK_DOWN        0x04000000U
+#define AQ_NIC_FLAG_ERR_UNPLUG  0x40000000U
+#define AQ_NIC_FLAG_ERR_HW      0x80000000U
+
+
+#define AQ_NIC_WOL_ENABLED           BIT(0)
+
+
+#define AQ_NIC_TCVEC2RING(_NIC_, _TC_, _VEC_) \
+	((_TC_) * AQ_CFG_TCS_MAX + (_VEC_))
+
+
+struct aq_nic_s {
+	atomic_t flags;
+	struct aq_vec_s *aq_vec[AQ_CFG_VECS_MAX];
+	struct aq_ring_s *aq_ring_tx[AQ_CFG_VECS_MAX * AQ_CFG_TCS_MAX];
+	struct aq_hw_s *aq_hw;
+	struct net_device *ndev;
+	unsigned int aq_vecs;
+	unsigned int packet_filter;
+	unsigned int power_state;
+	u8 port;
+	const struct aq_hw_ops *aq_hw_ops;
+	const struct aq_fw_ops *aq_fw_ops;
+	struct aq_nic_cfg_s aq_nic_cfg;
+	struct timer_list service_timer;
+	struct timer_list polling_timer;
+	struct aq_hw_link_status_s link_status;
+	struct {
+		u32 count;
+		u8 ar[AQ_CFG_MULTICAST_ADDRESS_MAX][ETH_ALEN];
+	} mc_list;
+
+	struct pci_dev *pdev;
+	unsigned int msix_entry_mask;
+	u32 irqvecs;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 7, 0)
+	unsigned int irq_type;
+	struct msix_entry msix_entry[AQ_CFG_PCI_FUNC_MSIX_IRQS];
+#endif
+	spinlock_t aq_spinlock;
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	struct {
+		int speed;
+		unsigned int link;
+		unsigned long down_tv;
+	} state_cache;
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+};
+
+static inline struct device *aq_nic_get_dev(struct aq_nic_s *self)
+{
+	return self->ndev->dev.parent;
+}
+
+extern unsigned aq_rx_refill_thres;
+
+void aq_nic_ndev_init(struct aq_nic_s *self);
+struct aq_nic_s *aq_nic_alloc_hot(struct net_device *ndev);
+void aq_nic_set_tx_ring(struct aq_nic_s *self, unsigned int idx,
+			struct aq_ring_s *ring);
+struct net_device *aq_nic_get_ndev(struct aq_nic_s *self);
+int aq_nic_init(struct aq_nic_s *self);
+void aq_nic_cfg_start(struct aq_nic_s *self);
+int aq_nic_ndev_register(struct aq_nic_s *self);
+void aq_nic_ndev_free(struct aq_nic_s *self);
+int aq_nic_start(struct aq_nic_s *self);
+int aq_nic_xmit(struct aq_nic_s *self, struct sk_buff *skb);
+int aq_nic_get_regs(struct aq_nic_s *self, struct ethtool_regs *regs, void *p);
+int aq_nic_get_regs_count(struct aq_nic_s *self);
+void aq_nic_get_stats(struct aq_nic_s *self, u64 *data);
+int aq_nic_stop(struct aq_nic_s *self);
+void aq_nic_deinit(struct aq_nic_s *self);
+void aq_nic_free_hot_resources(struct aq_nic_s *self);
+void aq_nic_free_vectors(struct aq_nic_s *self);
+int aq_nic_set_mtu(struct aq_nic_s *self, int new_mtu);
+int aq_nic_set_mac(struct aq_nic_s *self, struct net_device *ndev);
+int aq_nic_set_packet_filter(struct aq_nic_s *self, unsigned int flags);
+int aq_nic_set_multicast_list(struct aq_nic_s *self, struct net_device *ndev);
+unsigned int aq_nic_get_link_speed(struct aq_nic_s *self);
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 6, 0)
+void aq_nic_get_link_ksettings(struct aq_nic_s *self,
+			       struct ethtool_link_ksettings *cmd);
+int aq_nic_set_link_ksettings(struct aq_nic_s *self,
+			      const struct ethtool_link_ksettings *cmd);
+#else
+void aq_nic_get_link_settings(struct aq_nic_s *self, struct ethtool_cmd *cmd);
+int aq_nic_set_link_settings(struct aq_nic_s *self, struct ethtool_cmd *cmd);
+#endif
+struct aq_nic_cfg_s *aq_nic_get_cfg(struct aq_nic_s *self);
+u32 aq_nic_get_fw_version(struct aq_nic_s *self);
+int aq_nic_change_pm_state(struct aq_nic_s *self, pm_message_t *pm_msg);
+int aq_nic_update_interrupt_moderation_settings(struct aq_nic_s *self);
+void aq_nic_shutdown(struct aq_nic_s *self);
+
+#endif /* AQ_NIC_H */
diff --git a/drivers/net/ethernet/aquantia/aq_pci_func.c b/drivers/net/ethernet/aquantia/aq_pci_func.c
new file mode 100644
index 00000000..a454dbd
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_pci_func.c
@@ -0,0 +1,445 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_pci_func.c: Definition of PCI functions. */
+
+#include <linux/interrupt.h>
+#include <linux/module.h>
+
+#include "aq_main.h"
+#include "aq_nic.h"
+#include "aq_vec.h"
+#include "aq_hw.h"
+#include "aq_pci_func.h"
+#include "hw_atl/hw_atl_a0.h"
+#include "hw_atl/hw_atl_b0.h"
+
+static const struct pci_device_id aq_pci_tbl[] = {
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_0001), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_D100), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_D107), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_D108), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_D109), },
+
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC100), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC107), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC108), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC109), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC111), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC112), },
+
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC100S), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC107S), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC108S), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC109S), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC111S), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC112S), },
+
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC111E), },
+	{ PCI_VDEVICE(AQUANTIA, AQ_DEVICE_ID_AQC112E), },
+
+	{}
+};
+
+static const struct aq_board_revision_s hw_atl_boards[] = {
+	{ AQ_DEVICE_ID_0001,	AQ_HWREV_1,	&hw_atl_ops_a0, &hw_atl_a0_caps_aqc107, },
+	{ AQ_DEVICE_ID_D100,	AQ_HWREV_1,	&hw_atl_ops_a0, &hw_atl_a0_caps_aqc100, },
+	{ AQ_DEVICE_ID_D107,	AQ_HWREV_1,	&hw_atl_ops_a0, &hw_atl_a0_caps_aqc107, },
+	{ AQ_DEVICE_ID_D108,	AQ_HWREV_1,	&hw_atl_ops_a0, &hw_atl_a0_caps_aqc108, },
+	{ AQ_DEVICE_ID_D109,	AQ_HWREV_1,	&hw_atl_ops_a0, &hw_atl_a0_caps_aqc109, },
+
+	{ AQ_DEVICE_ID_0001,	AQ_HWREV_2,	&hw_atl_ops_b0, &hw_atl_b0_caps_aqc107, },
+	{ AQ_DEVICE_ID_D100,	AQ_HWREV_2,	&hw_atl_ops_b0, &hw_atl_b0_caps_aqc100, },
+	{ AQ_DEVICE_ID_D107,	AQ_HWREV_2,	&hw_atl_ops_b0, &hw_atl_b0_caps_aqc107, },
+	{ AQ_DEVICE_ID_D108,	AQ_HWREV_2,	&hw_atl_ops_b0, &hw_atl_b0_caps_aqc108, },
+	{ AQ_DEVICE_ID_D109,	AQ_HWREV_2,	&hw_atl_ops_b0, &hw_atl_b0_caps_aqc109, },
+
+	{ AQ_DEVICE_ID_AQC100,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc107, },
+	{ AQ_DEVICE_ID_AQC107,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc107, },
+	{ AQ_DEVICE_ID_AQC108,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc108, },
+	{ AQ_DEVICE_ID_AQC109,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc109, },
+	{ AQ_DEVICE_ID_AQC111,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc111, },
+	{ AQ_DEVICE_ID_AQC112,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc112, },
+
+	{ AQ_DEVICE_ID_AQC100S,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc100s, },
+	{ AQ_DEVICE_ID_AQC107S,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc107s, },
+	{ AQ_DEVICE_ID_AQC108S,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc108s, },
+	{ AQ_DEVICE_ID_AQC109S,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc109s, },
+	{ AQ_DEVICE_ID_AQC111S,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc111s, },
+	{ AQ_DEVICE_ID_AQC112S,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc112s, },
+
+	{ AQ_DEVICE_ID_AQC111E,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc111e, },
+	{ AQ_DEVICE_ID_AQC112E,	AQ_HWREV_ANY,	&hw_atl_ops_b1, &hw_atl_b0_caps_aqc112e, },
+};
+
+MODULE_DEVICE_TABLE(pci, aq_pci_tbl);
+
+static int aq_pci_probe_get_hw_by_id(struct pci_dev *pdev,
+				     const struct aq_hw_ops **ops,
+				     const struct aq_hw_caps_s **caps)
+{
+	int i = 0;
+
+	if (pdev->vendor != PCI_VENDOR_ID_AQUANTIA)
+		return -EINVAL;
+
+	for (i = 0; i < ARRAY_SIZE(hw_atl_boards); i++) {
+		if (hw_atl_boards[i].devid == pdev->device &&
+		    (hw_atl_boards[i].revision == AQ_HWREV_ANY ||
+		     hw_atl_boards[i].revision == pdev->revision)) {
+			*ops = hw_atl_boards[i].ops;
+			*caps = hw_atl_boards[i].caps;
+			break;
+		}
+	}
+
+	if (i == ARRAY_SIZE(hw_atl_boards))
+		return -EINVAL;
+
+	return 0;
+}
+
+int aq_pci_func_init(struct pci_dev *pdev)
+{
+	int err = 0;
+
+	err = pci_set_dma_mask(pdev, DMA_BIT_MASK(64));
+	if (!err) {
+		err = pci_set_consistent_dma_mask(pdev, DMA_BIT_MASK(64));
+
+	}
+	if (err) {
+		err = pci_set_dma_mask(pdev, DMA_BIT_MASK(32));
+		if (!err)
+			err = pci_set_consistent_dma_mask(pdev,
+							  DMA_BIT_MASK(32));
+	}
+	if (err != 0) {
+		err = -ENOSR;
+		goto err_exit;
+	}
+
+	err = pci_request_regions(pdev, AQ_CFG_DRV_NAME "_mmio");
+	if (err < 0)
+		goto err_exit;
+
+	pci_set_master(pdev);
+
+	return 0;
+
+err_exit:
+	return err;
+}
+
+int aq_pci_func_alloc_irq(struct aq_nic_s *self, unsigned int i,
+			  char *name, void *aq_vec, cpumask_t *affinity_mask)
+{
+	struct pci_dev *pdev = self->pdev;
+	int err = 0;
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 8, 0)
+	if (pdev->msix_enabled)
+		err = request_irq(self->msix_entry[i].vector, aq_vec_isr, 0,
+				  name, aq_vec);
+	else if (pdev->msi_enabled)
+		err = request_irq(pdev->irq, aq_vec_isr, 0,
+				  name, aq_vec);
+	else
+		err = request_irq(pdev->irq, aq_vec_isr_legacy,
+				  IRQF_SHARED, name, aq_vec);
+
+	if (err >= 0) {
+		self->msix_entry_mask |= (1 << i);
+		self->aq_vec[i] = aq_vec;
+
+		if (pdev->msix_enabled)
+			irq_set_affinity_hint(self->msix_entry[i].vector,
+					      affinity_mask);
+	}
+#else
+	if (pdev->msix_enabled || pdev->msi_enabled)
+		err = request_irq(pci_irq_vector(pdev, i), aq_vec_isr, 0,
+				  name, aq_vec);
+	else
+		err = request_irq(pci_irq_vector(pdev, i), aq_vec_isr_legacy,
+				  IRQF_SHARED, name, aq_vec);
+
+	if (err >= 0) {
+		self->msix_entry_mask |= (1 << i);
+		self->aq_vec[i] = aq_vec;
+
+		if (pdev->msix_enabled)
+			irq_set_affinity_hint(pci_irq_vector(pdev, i),
+					      affinity_mask);
+	}
+#endif
+	return err;
+}
+
+void aq_pci_func_free_irqs(struct aq_nic_s *self)
+{
+	struct pci_dev *pdev = self->pdev;
+	unsigned int i = 0U;
+
+	for (i = 32U; i--;) {
+		if (!((1U << i) & self->msix_entry_mask))
+			continue;
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 8, 0)
+		switch (aq_pci_func_get_irq_type(self)) {
+		case AQ_HW_IRQ_MSIX:
+			irq_set_affinity_hint(self->msix_entry[i].vector, NULL);
+			free_irq(self->msix_entry[i].vector, self->aq_vec[i]);
+			break;
+
+		case AQ_HW_IRQ_MSI:
+			free_irq(pdev->irq, self->aq_vec[i]);
+			break;
+
+		case AQ_HW_IRQ_LEGACY:
+			free_irq(pdev->irq, self->aq_vec[i]);
+			break;
+
+		default:
+			break;
+		}
+
+#else
+		if (pdev->msix_enabled)
+			irq_set_affinity_hint(pci_irq_vector(pdev, i), NULL);
+		free_irq(pci_irq_vector(pdev, i), self->aq_vec[i]);
+#endif
+		self->msix_entry_mask &= ~(1U << i);
+	}
+}
+
+unsigned int aq_pci_func_get_irq_type(struct aq_nic_s *self)
+{
+	if (self->pdev->msix_enabled)
+		return AQ_HW_IRQ_MSIX;
+	if (self->pdev->msi_enabled)
+		return AQ_HW_IRQ_MSIX;
+	return AQ_HW_IRQ_LEGACY;
+}
+
+static void aq_pci_free_irq_vectors(struct aq_nic_s *self)
+{
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 7, 0)
+
+	switch (aq_pci_func_get_irq_type(self)) {
+	case AQ_HW_IRQ_MSI:
+		pci_disable_msi(self->pdev);
+		break;
+
+	case AQ_HW_IRQ_MSIX:
+		pci_disable_msix(self->pdev);
+		break;
+
+	case AQ_HW_IRQ_LEGACY:
+		break;
+
+	default:
+		break;
+	}
+
+#else
+	pci_free_irq_vectors(self->pdev);
+
+#endif
+}
+
+static int aq_pci_probe(struct pci_dev *pdev,
+			const struct pci_device_id *pci_id)
+{
+	struct aq_nic_s *self = NULL;
+	int err = 0;
+	struct net_device *ndev;
+	resource_size_t mmio_pa;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 8, 0)
+	unsigned int i = 0U;
+#endif
+	u32 bar;
+	u32 numvecs;
+
+	err = pci_enable_device(pdev);
+	if (err)
+		return err;
+
+	err = aq_pci_func_init(pdev);
+	if (err)
+		goto err_pci_func;
+
+	ndev = aq_ndev_alloc();
+	if (!ndev) {
+		err = -ENOMEM;
+		goto err_ndev;
+	}
+
+	self = netdev_priv(ndev);
+	self->pdev = pdev;
+	SET_NETDEV_DEV(ndev, &pdev->dev);
+	pci_set_drvdata(pdev, self);
+
+	err = aq_pci_probe_get_hw_by_id(pdev, &self->aq_hw_ops,
+					&aq_nic_get_cfg(self)->aq_hw_caps);
+	if (err)
+		goto err_ioremap;
+
+	self->aq_hw = kzalloc(sizeof(*self->aq_hw), GFP_KERNEL);
+	if (!self->aq_hw) {
+		err = -ENOMEM;
+		goto err_ioremap;
+	}
+	self->aq_hw->aq_nic_cfg = aq_nic_get_cfg(self);
+
+	for (bar = 0; bar < 4; ++bar) {
+		if (IORESOURCE_MEM & pci_resource_flags(pdev, bar)) {
+			resource_size_t reg_sz;
+
+			mmio_pa = pci_resource_start(pdev, bar);
+			if (mmio_pa == 0U) {
+				err = -EIO;
+				goto err_free_aq_hw;
+			}
+
+			reg_sz = pci_resource_len(pdev, bar);
+			if ((reg_sz <= 24 /*ATL_REGS_SIZE*/)) {
+				err = -EIO;
+				goto err_free_aq_hw;
+			}
+
+			self->aq_hw->mmio = ioremap_nocache(mmio_pa, reg_sz);
+			if (!self->aq_hw->mmio) {
+				err = -EIO;
+				goto err_free_aq_hw;
+			}
+			break;
+		}
+	}
+
+	if (bar == 4) {
+		err = -EIO;
+		goto err_free_aq_hw;
+	}
+
+	numvecs = min((u8)AQ_CFG_VECS_DEF,
+		      aq_nic_get_cfg(self)->aq_hw_caps->msix_irqs);
+	numvecs = min(numvecs, num_online_cpus());
+	/*enable interrupts */
+#if !AQ_CFG_FORCE_LEGACY_INT
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 7, 0)
+	for (i = 0; i < numvecs; i++)
+		self->msix_entry[i].entry = i;
+
+	err = pci_enable_msix(self->pdev, self->msix_entry, numvecs);
+
+	if (err < 0) {
+		err = pci_enable_msi(self->pdev);
+
+		if (err < 0)
+			goto err_hwinit;
+	}
+#else
+	numvecs = pci_alloc_irq_vectors(self->pdev, 1, numvecs,
+					PCI_IRQ_MSIX | PCI_IRQ_MSI |
+					PCI_IRQ_LEGACY);
+
+	if (numvecs < 0) {
+		err = numvecs;
+		goto err_hwinit;
+	}
+#endif
+#endif
+	self->irqvecs = numvecs;
+
+	/* net device init */
+	aq_nic_cfg_start(self);
+
+	aq_nic_ndev_init(self);
+
+	err = aq_nic_ndev_register(self);
+	if (err < 0)
+		goto err_register;
+
+	return 0;
+
+err_register:
+	aq_nic_free_vectors(self);
+	aq_pci_free_irq_vectors(self);
+err_hwinit:
+	iounmap(self->aq_hw->mmio);
+err_free_aq_hw:
+	kfree(self->aq_hw);
+err_ioremap:
+	free_netdev(ndev);
+err_ndev:
+	pci_release_regions(pdev);
+err_pci_func:
+	pci_disable_device(pdev);
+	return err;
+}
+
+static void aq_pci_remove(struct pci_dev *pdev)
+{
+	struct aq_nic_s *self = pci_get_drvdata(pdev);
+
+	if (self->ndev) {
+		if (self->ndev->reg_state == NETREG_REGISTERED)
+			unregister_netdev(self->ndev);
+		aq_nic_free_vectors(self);
+		aq_pci_free_irq_vectors(self);
+		iounmap(self->aq_hw->mmio);
+		kfree(self->aq_hw);
+		pci_release_regions(pdev);
+		free_netdev(self->ndev);
+	}
+
+	pci_disable_device(pdev);
+}
+
+static void aq_pci_shutdown(struct pci_dev *pdev)
+{
+	struct aq_nic_s *self = pci_get_drvdata(pdev);
+
+	aq_nic_shutdown(self);
+
+	pci_disable_device(pdev);
+
+	if (system_state == SYSTEM_POWER_OFF) {
+		pci_wake_from_d3(pdev, !!self->aq_nic_cfg.wol);
+		pci_set_power_state(pdev, PCI_D3hot);
+	}
+}
+
+static int aq_pci_suspend(struct pci_dev *pdev, pm_message_t pm_msg)
+{
+	struct aq_nic_s *self = pci_get_drvdata(pdev);
+
+	return aq_nic_change_pm_state(self, &pm_msg);
+}
+
+static int aq_pci_resume(struct pci_dev *pdev)
+{
+	struct aq_nic_s *self = pci_get_drvdata(pdev);
+	pm_message_t pm_msg = PMSG_RESTORE;
+
+	return aq_nic_change_pm_state(self, &pm_msg);
+}
+
+static struct pci_driver aq_pci_ops = {
+	.name = AQ_CFG_DRV_NAME,
+	.id_table = aq_pci_tbl,
+	.probe = aq_pci_probe,
+	.remove = aq_pci_remove,
+	.suspend = aq_pci_suspend,
+	.resume = aq_pci_resume,
+	.shutdown = aq_pci_shutdown,
+};
+
+module_pci_driver(aq_pci_ops);
diff --git a/drivers/net/ethernet/aquantia/aq_pci_func.h b/drivers/net/ethernet/aquantia/aq_pci_func.h
new file mode 100644
index 00000000..aeee67b
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_pci_func.h
@@ -0,0 +1,32 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_pci_func.h: Declaration of PCI functions. */
+
+#ifndef AQ_PCI_FUNC_H
+#define AQ_PCI_FUNC_H
+
+#include "aq_common.h"
+#include "aq_nic.h"
+
+struct aq_board_revision_s {
+	unsigned short devid;
+	unsigned short revision;
+	const struct aq_hw_ops *ops;
+	const struct aq_hw_caps_s *caps;
+};
+
+int aq_pci_func_init(struct pci_dev *pdev);
+int aq_pci_func_alloc_irq(struct aq_nic_s *self, unsigned int i,
+			  char *name, void *aq_vec,
+			  cpumask_t *affinity_mask);
+void aq_pci_func_free_irqs(struct aq_nic_s *self);
+unsigned int aq_pci_func_get_irq_type(struct aq_nic_s *self);
+
+#endif /* AQ_PCI_FUNC_H */
diff --git a/drivers/net/ethernet/aquantia/aq_ring.c b/drivers/net/ethernet/aquantia/aq_ring.c
new file mode 100644
index 00000000..4edacf9
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_ring.c
@@ -0,0 +1,452 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_ring.c: Definition of functions for Rx/Tx rings. */
+
+#include "aq_ring.h"
+#include "aq_nic.h"
+#include "aq_hw.h"
+#include "aq_hw_utils.h"
+
+#include <linux/netdevice.h>
+#include <linux/etherdevice.h>
+
+static inline void aq_free_rxpage(struct aq_rxpage *rxpage, struct device *dev)
+{
+	unsigned len = PAGE_SIZE << rxpage->order;
+
+	dma_unmap_page(dev, rxpage->daddr, len, DMA_FROM_DEVICE);
+
+	/* Drop the ref for being in the ring. */
+	__free_pages(rxpage->page, rxpage->order);
+	rxpage->page = NULL;
+}
+
+static int aq_get_rxpage(struct aq_rxpage *rxpage, unsigned order,
+	struct device *dev)
+{
+	struct page *page;
+	dma_addr_t daddr;
+	int ret = -ENOMEM;
+
+	page = dev_alloc_pages(order);
+	if (unlikely(!page))
+		goto err_exit;
+
+	daddr = dma_map_page(dev, page, 0, PAGE_SIZE << order, DMA_FROM_DEVICE);
+
+	if (unlikely(dma_mapping_error(dev, daddr)))
+		goto free_page;
+
+	rxpage->page = page;
+	rxpage->daddr = daddr;
+	rxpage->order = order;
+	rxpage->pg_off = 0;
+
+	return 0;
+
+free_page:
+	__free_pages(page, order);
+err_exit:
+
+	return ret;
+}
+
+static int aq_get_rxpages(struct aq_ring_s *self, struct aq_ring_buff_s *rxbuf, int order)
+{
+	int ret;
+
+	if (rxbuf->rxdata.page) {
+		/* One means ring is the only user and can reuse */
+		if (page_ref_count(rxbuf->rxdata.page) > 1) {
+			/* Try reuse buffer */
+			rxbuf->rxdata.pg_off += AQ_CFG_RX_FRAME_MAX;
+			if (rxbuf->rxdata.pg_off + AQ_CFG_RX_FRAME_MAX <=
+				(PAGE_SIZE << order)) {
+				self->stats.rx.pg_flips++;
+			} else {
+				/* Buffer exhausted. We have other users and
+				 * should release this page and realloc
+				 */
+				aq_free_rxpage(&rxbuf->rxdata,
+					       aq_nic_get_dev(self->aq_nic));
+				self->stats.rx.pg_losts++;
+			}
+		} else
+			self->stats.rx.pg_reuses++;
+	}
+
+	if (!rxbuf->rxdata.page) {
+		ret = aq_get_rxpage(&rxbuf->rxdata, order,
+				  aq_nic_get_dev(self->aq_nic));
+		return ret;
+	}
+
+	return 0;
+}
+
+static struct aq_ring_s *aq_ring_alloc(struct aq_ring_s *self,
+				       struct aq_nic_s *aq_nic)
+{
+	int err = 0;
+
+	self->buff_ring =
+		kcalloc(self->size, sizeof(struct aq_ring_buff_s), GFP_KERNEL);
+
+	if (!self->buff_ring) {
+		err = -ENOMEM;
+		goto err_exit;
+	}
+	self->dx_ring = dma_alloc_coherent(aq_nic_get_dev(aq_nic),
+						self->size * self->dx_size,
+						&self->dx_ring_pa, GFP_KERNEL);
+	if (!self->dx_ring) {
+		err = -ENOMEM;
+		goto err_exit;
+	}
+
+err_exit:
+	if (err < 0) {
+		aq_ring_free(self);
+		self = NULL;
+	}
+	return self;
+}
+
+struct aq_ring_s *aq_ring_tx_alloc(struct aq_ring_s *self,
+				   struct aq_nic_s *aq_nic,
+				   unsigned int idx,
+				   struct aq_nic_cfg_s *aq_nic_cfg)
+{
+	int err = 0;
+
+	self->aq_nic = aq_nic;
+	self->idx = idx;
+	self->size = aq_nic_cfg->txds;
+	self->dx_size = aq_nic_cfg->aq_hw_caps->txd_size;
+
+	self = aq_ring_alloc(self, aq_nic);
+	if (!self) {
+		err = -ENOMEM;
+		goto err_exit;
+	}
+
+err_exit:
+	if (err < 0) {
+		aq_ring_free(self);
+		self = NULL;
+	}
+	return self;
+}
+
+struct aq_ring_s *aq_ring_rx_alloc(struct aq_ring_s *self,
+				   struct aq_nic_s *aq_nic,
+				   unsigned int idx,
+				   struct aq_nic_cfg_s *aq_nic_cfg)
+{
+	int err = 0;
+
+	self->aq_nic = aq_nic;
+	self->idx = idx;
+	self->size = aq_nic_cfg->rxds;
+	self->dx_size = aq_nic_cfg->aq_hw_caps->rxd_size;
+	self->page_order = fls(AQ_CFG_RX_FRAME_MAX / PAGE_SIZE +
+			(AQ_CFG_RX_FRAME_MAX % PAGE_SIZE ? 1 : 0)) - 1;
+	if (aq_nic_cfg->rxpageorder > self->page_order)
+		self->page_order = aq_nic_cfg->rxpageorder;
+
+	self = aq_ring_alloc(self, aq_nic);
+	if (!self) {
+		err = -ENOMEM;
+		goto err_exit;
+	}
+
+err_exit:
+	if (err < 0) {
+		aq_ring_free(self);
+		self = NULL;
+	}
+	return self;
+}
+
+int aq_ring_init(struct aq_ring_s *self)
+{
+	self->hw_head = 0;
+	self->sw_head = 0;
+	self->sw_tail = 0;
+	return 0;
+}
+
+static inline bool aq_ring_dx_in_range(unsigned int h, unsigned int i,
+				       unsigned int t)
+{
+	return (h < t) ? ((h < i) && (i < t)) : ((h < i) || (i < t));
+}
+
+void aq_ring_update_queue_state(struct aq_ring_s *ring)
+{
+	if (aq_ring_avail_dx(ring) <= AQ_CFG_SKB_FRAGS_MAX)
+		aq_ring_queue_stop(ring);
+	else if (aq_ring_avail_dx(ring) > AQ_CFG_RESTART_DESC_THRES)
+		aq_ring_queue_wake(ring);
+}
+
+void aq_ring_queue_wake(struct aq_ring_s *ring)
+{
+	struct net_device *ndev = aq_nic_get_ndev(ring->aq_nic);
+
+	if (__netif_subqueue_stopped(ndev, ring->idx)) {
+		netif_wake_subqueue(ndev, ring->idx);
+		ring->stats.tx.queue_restarts++;
+	}
+}
+
+void aq_ring_queue_stop(struct aq_ring_s *ring)
+{
+	struct net_device *ndev = aq_nic_get_ndev(ring->aq_nic);
+
+	if (!__netif_subqueue_stopped(ndev, ring->idx))
+		netif_stop_subqueue(ndev, ring->idx);
+}
+
+bool aq_ring_tx_clean(struct aq_ring_s *self)
+{
+	struct device *dev = aq_nic_get_dev(self->aq_nic);
+	unsigned int budget = AQ_CFG_TX_CLEAN_BUDGET;
+
+	for (; self->sw_head != self->hw_head && budget--;
+		self->sw_head = aq_ring_next_dx(self, self->sw_head)) {
+		struct aq_ring_buff_s *buff = &self->buff_ring[self->sw_head];
+
+		if (likely(buff->is_mapped)) {
+			if (unlikely(buff->is_sop)) {
+				if (!buff->is_eop &&
+				    buff->eop_index != 0xffffU &&
+				    (!aq_ring_dx_in_range(self->sw_head,
+						buff->eop_index,
+						self->hw_head)))
+					break;
+
+				dma_unmap_single(dev, buff->pa, buff->len,
+						 DMA_TO_DEVICE);
+			} else {
+				dma_unmap_page(dev, buff->pa, buff->len,
+					       DMA_TO_DEVICE);
+			}
+		}
+
+		if (unlikely(buff->is_eop))
+			dev_kfree_skb_any(buff->skb);
+
+		buff->pa = 0U;
+		buff->eop_index = 0xffffU;
+	}
+
+	return !!budget;
+}
+
+#define AQ_SKB_ALIGN SKB_DATA_ALIGN(sizeof(struct skb_shared_info))
+int aq_ring_rx_clean(struct aq_ring_s *self,
+		     struct napi_struct *napi,
+		     int *work_done,
+		     int budget)
+{
+	struct net_device *ndev = aq_nic_get_ndev(self->aq_nic);
+	bool is_rsc_completed = true;
+	int err = 0;
+
+	for (; (self->sw_head != self->hw_head) && budget;
+		self->sw_head = aq_ring_next_dx(self, self->sw_head),
+		--budget, ++(*work_done)) {
+		struct aq_ring_buff_s *buff = &self->buff_ring[self->sw_head];
+		struct aq_ring_buff_s *buff_ = NULL;
+		struct sk_buff *skb = NULL;
+		unsigned int next_ = 0U;
+		unsigned int i = 0U;
+		u16 hdr_len;
+
+		if (buff->is_error) {
+			continue;
+		}
+
+		if (buff->is_cleaned)
+			continue;
+
+		rmb();
+
+		if (!buff->is_eop) {
+			for (next_ = buff->next,
+			     buff_ = &self->buff_ring[next_]; true;
+			     next_ = buff_->next,
+			     buff_ = &self->buff_ring[next_]) {
+				is_rsc_completed =
+					aq_ring_dx_in_range(self->sw_head,
+							    next_,
+							    self->hw_head);
+
+				if (unlikely(!is_rsc_completed)) {
+					is_rsc_completed = false;
+					break;
+				}
+
+				if (buff_->is_eop)
+					break;
+			}
+
+			if (!is_rsc_completed) {
+				err = 0;
+				goto err_exit;
+			}
+		}
+
+		dma_sync_single_range_for_cpu(aq_nic_get_dev(self->aq_nic),
+					      buff->rxdata.daddr,
+					      buff->rxdata.pg_off,
+					      buff->len, DMA_FROM_DEVICE);
+
+		skb = napi_alloc_skb(napi, AQ_CFG_RX_HDR_SIZE);
+		if (unlikely(!skb)) {
+			err = -ENOMEM;
+			goto err_exit;
+		}
+
+		hdr_len = min_t(u16, buff->len, AQ_CFG_RX_HDR_SIZE);
+		skb_put(skb, hdr_len);
+		memcpy(skb->data, aq_buf_vaddr(&buff->rxdata), hdr_len);
+
+		if (buff->len - hdr_len > 0) {
+			skb_add_rx_frag(skb, 0, buff->rxdata.page,
+					buff->rxdata.pg_off + hdr_len,
+					buff->len - hdr_len,
+					AQ_CFG_RX_FRAME_MAX);
+			page_ref_inc(buff->rxdata.page);
+		}
+
+		if (!buff->is_eop) {
+			for (i = 1U, next_ = buff->next,
+			     buff_ = &self->buff_ring[next_]; true;
+			     next_ = buff_->next,
+			     buff_ = &self->buff_ring[next_], ++i) {
+				dma_sync_single_range_for_cpu(
+						aq_nic_get_dev(self->aq_nic),
+						buff_->rxdata.daddr,
+						buff_->rxdata.pg_off,
+						buff_->len, DMA_FROM_DEVICE);
+				skb_add_rx_frag(skb, i,
+						buff_->rxdata.page,
+						buff_->rxdata.pg_off,
+						buff_->len,
+						AQ_CFG_RX_FRAME_MAX);
+				page_ref_inc(buff_->rxdata.page);
+				buff_->is_cleaned = 1;
+
+				if (buff_->is_eop)
+					break;
+			}
+		}
+
+		skb->protocol = eth_type_trans(skb, ndev);
+
+		if (unlikely(buff->is_cso_err)) {
+			++self->stats.rx.errors;
+			skb->ip_summed = CHECKSUM_NONE;
+		} else {
+			if (buff->is_ip_cso) {
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 18, 0)
+				__skb_incr_checksum_unnecessary(skb);
+				if (buff->is_udp_cso || buff->is_tcp_cso)
+					__skb_incr_checksum_unnecessary(skb);
+#else
+				skb->ip_summed = CHECKSUM_UNNECESSARY;
+#endif
+			} else {
+				skb->ip_summed = CHECKSUM_NONE;
+			}
+		}
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 14, 0) || (RHEL_RELEASE_CODE > 0)
+		skb_set_hash(skb, buff->rss_hash,
+			     buff->is_hash_l4 ? PKT_HASH_TYPE_L4 :
+			     PKT_HASH_TYPE_NONE);
+#else
+		skb->rxhash = buff->rss_hash;
+#endif
+
+		skb_record_rx_queue(skb, self->idx);
+
+		++self->stats.rx.packets;
+		self->stats.rx.bytes += skb->len;
+
+		napi_gro_receive(napi, skb);
+
+	}
+
+err_exit:
+	return err;
+}
+
+int aq_ring_rx_fill(struct aq_ring_s *self)
+{
+	unsigned int page_order = self->page_order;
+	struct aq_ring_buff_s *buff = NULL;
+	int err = 0;
+	int i = 0;
+
+	if (aq_ring_avail_dx(self) < min_t(unsigned, aq_rx_refill_thres, self->size/2))
+		return err;
+
+	for (i = aq_ring_avail_dx(self); i--;
+		self->sw_tail = aq_ring_next_dx(self, self->sw_tail)) {
+		buff = &self->buff_ring[self->sw_tail];
+
+		buff->flags = 0U;
+		buff->len = AQ_CFG_RX_FRAME_MAX;
+
+		err = aq_get_rxpages(self, buff, page_order);
+		if (err)
+			goto err_exit;
+
+		buff->pa = aq_buf_daddr(&buff->rxdata);
+		buff = NULL;
+	}
+
+err_exit:
+	return err;
+}
+
+void aq_ring_rx_deinit(struct aq_ring_s *self)
+{
+	if (!self)
+		goto err_exit;
+
+	for (; self->sw_head != self->sw_tail;
+		self->sw_head = aq_ring_next_dx(self, self->sw_head)) {
+		struct aq_ring_buff_s *buff = &self->buff_ring[self->sw_head];
+
+		aq_free_rxpage(&buff->rxdata, aq_nic_get_dev(self->aq_nic));
+
+	}
+
+err_exit:;
+}
+
+void aq_ring_free(struct aq_ring_s *self)
+{
+	if (!self)
+		goto err_exit;
+
+	kfree(self->buff_ring);
+
+	if (self->dx_ring)
+		dma_free_coherent(aq_nic_get_dev(self->aq_nic),
+				  self->size * self->dx_size, self->dx_ring,
+				  self->dx_ring_pa);
+
+err_exit:;
+}
diff --git a/drivers/net/ethernet/aquantia/aq_ring.h b/drivers/net/ethernet/aquantia/aq_ring.h
new file mode 100644
index 00000000..1b5bd65
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_ring.h
@@ -0,0 +1,177 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_ring.h: Declaration of functions for Rx/Tx rings. */
+
+#ifndef AQ_RING_H
+#define AQ_RING_H
+
+#include "aq_common.h"
+
+struct page;
+struct aq_nic_cfg_s;
+
+struct aq_rxpage {
+	struct page *page;
+	dma_addr_t daddr;
+	unsigned order;
+	unsigned pg_off;
+};
+
+/*           TxC       SOP        DX         EOP
+ *         +----------+----------+----------+-----------
+ *   8bytes|len l3,l4 | pa       | pa       | pa
+ *         +----------+----------+----------+-----------
+ * 4/8bytes|len pkt   |len pkt   |          | skb
+ *         +----------+----------+----------+-----------
+ * 4/8bytes|is_txc    |len,flags |len       |len,is_eop
+ *         +----------+----------+----------+-----------
+ *
+ *  This aq_ring_buff_s doesn't have endianness dependency.
+ *  It is __packed for cache line optimizations.
+ */
+struct __packed aq_ring_buff_s {
+	union {
+		/* RX/TX */
+		dma_addr_t pa;
+		/* RX */
+		struct {
+			u32 rss_hash;
+			u16 next;
+			u8 is_hash_l4;
+			u8 rsvd1;
+			struct aq_rxpage rxdata;
+		};
+		/* EOP */
+		struct {
+			dma_addr_t pa_eop;
+			struct sk_buff *skb;
+		};
+		/* TxC */
+		struct {
+			u32 mss;
+			u8 len_l2;
+			u8 len_l3;
+			u8 len_l4;
+			u8 is_ipv6:1;
+			u8 rsvd2:7;
+			u32 len_pkt;
+		};
+	};
+	union {
+		struct {
+			u16 len;
+			u32 is_ip_cso:1;
+			u32 is_udp_cso:1;
+			u32 is_tcp_cso:1;
+			u32 is_cso_err:1;
+			u32 is_sop:1;
+			u32 is_eop:1;
+			u32 is_txc:1;
+			u32 is_mapped:1;
+			u32 is_cleaned:1;
+			u32 is_error:1;
+			u32 rsvd3:6;
+			u16 eop_index;
+			u16 rsvd4;
+		};
+		u64 flags;
+	};
+};
+
+struct aq_ring_stats_rx_s {
+	u64 errors;
+	u64 packets;
+	u64 bytes;
+	u64 lro_packets;
+	u64 jumbo_packets;
+	u64 pg_losts;
+	u64 pg_flips;
+	u64 pg_reuses;
+};
+
+struct aq_ring_stats_tx_s {
+	u64 errors;
+	u64 packets;
+	u64 bytes;
+	u64 queue_restarts;
+};
+
+union aq_ring_stats_s {
+	struct aq_ring_stats_rx_s rx;
+	struct aq_ring_stats_tx_s tx;
+};
+
+struct aq_ring_s {
+	struct aq_ring_buff_s *buff_ring;
+	u8 *dx_ring;		/* descriptors ring, dma shared mem */
+	struct aq_nic_s *aq_nic;
+	unsigned int idx;	/* for HW layer registers operations */
+	unsigned int hw_head;
+	unsigned int sw_head;
+	unsigned int sw_tail;
+	unsigned int size;	/* descriptors number */
+	unsigned int dx_size;	/* TX or RX descriptor size,  */
+				/* stored here for fater math */
+	unsigned int page_order;
+	union aq_ring_stats_s stats;
+	dma_addr_t dx_ring_pa;
+};
+
+struct aq_ring_param_s {
+	unsigned int vec_idx;
+	unsigned int cpu;
+	cpumask_t affinity_mask;
+};
+
+static inline void *aq_buf_vaddr(struct aq_rxpage *rxpage)
+{
+	return page_to_virt(rxpage->page) + rxpage->pg_off;
+}
+
+static inline dma_addr_t aq_buf_daddr(struct aq_rxpage *rxpage)
+{
+	return rxpage->daddr + rxpage->pg_off;
+}
+
+static inline unsigned int aq_ring_next_dx(struct aq_ring_s *self,
+					   unsigned int dx)
+{
+	return (++dx >= self->size) ? 0U : dx;
+}
+
+static inline unsigned int aq_ring_avail_dx(struct aq_ring_s *self)
+{
+	return (((self->sw_tail >= self->sw_head)) ?
+		(self->size - 1) - self->sw_tail + self->sw_head :
+		self->sw_head - self->sw_tail - 1);
+}
+
+struct aq_ring_s *aq_ring_tx_alloc(struct aq_ring_s *self,
+				   struct aq_nic_s *aq_nic,
+				   unsigned int idx,
+				   struct aq_nic_cfg_s *aq_nic_cfg);
+struct aq_ring_s *aq_ring_rx_alloc(struct aq_ring_s *self,
+				   struct aq_nic_s *aq_nic,
+				   unsigned int idx,
+				   struct aq_nic_cfg_s *aq_nic_cfg);
+int aq_ring_init(struct aq_ring_s *self);
+void aq_ring_rx_deinit(struct aq_ring_s *self);
+void aq_ring_free(struct aq_ring_s *self);
+void aq_ring_update_queue_state(struct aq_ring_s *ring);
+void aq_ring_queue_wake(struct aq_ring_s *ring);
+void aq_ring_queue_stop(struct aq_ring_s *ring);
+bool aq_ring_tx_clean(struct aq_ring_s *self);
+int aq_ring_rx_clean(struct aq_ring_s *self,
+		     struct napi_struct *napi,
+		     int *work_done,
+		     int budget);
+int aq_ring_rx_fill(struct aq_ring_s *self);
+
+#endif /* AQ_RING_H */
diff --git a/drivers/net/ethernet/aquantia/aq_rss.h b/drivers/net/ethernet/aquantia/aq_rss.h
new file mode 100644
index 00000000..1db6eb2
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_rss.h
@@ -0,0 +1,26 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_rss.h: Receive Side Scaling definitions. */
+
+#ifndef AQ_RSS_H
+#define AQ_RSS_H
+
+#include "aq_common.h"
+#include "aq_cfg.h"
+
+struct aq_rss_parameters {
+	u16 base_cpu_number;
+	u16 indirection_table_size;
+	u16 hash_secret_key_size;
+	u32 hash_secret_key[AQ_CFG_RSS_HASHKEY_SIZE / sizeof(u32)];
+	u8 indirection_table[AQ_CFG_RSS_INDIRECTION_TABLE_MAX];
+};
+
+#endif /* AQ_RSS_H */
diff --git a/drivers/net/ethernet/aquantia/aq_utils.h b/drivers/net/ethernet/aquantia/aq_utils.h
new file mode 100644
index 00000000..786ea81
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_utils.h
@@ -0,0 +1,42 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_utils.h: Useful macro and structures used in all layers of driver. */
+
+#ifndef AQ_UTILS_H
+#define AQ_UTILS_H
+
+#include "aq_common.h"
+
+static inline void aq_utils_obj_set(atomic_t *flags, u32 mask)
+{
+	unsigned long flags_old, flags_new;
+
+	do {
+		flags_old = atomic_read(flags);
+		flags_new = flags_old | (mask);
+	} while (atomic_cmpxchg(flags, flags_old, flags_new) != flags_old);
+}
+
+static inline void aq_utils_obj_clear(atomic_t *flags, u32 mask)
+{
+	unsigned long flags_old, flags_new;
+
+	do {
+		flags_old = atomic_read(flags);
+		flags_new = flags_old & ~(mask);
+	} while (atomic_cmpxchg(flags, flags_old, flags_new) != flags_old);
+}
+
+static inline bool aq_utils_obj_test(atomic_t *flags, u32 mask)
+{
+	return atomic_read(flags) & mask;
+}
+
+#endif /* AQ_UTILS_H */
diff --git a/drivers/net/ethernet/aquantia/aq_vec.c b/drivers/net/ethernet/aquantia/aq_vec.c
new file mode 100644
index 00000000..916d486
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_vec.c
@@ -0,0 +1,394 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_vec.c: Definition of common structure for vector of Rx and Tx rings.
+ * Definition of functions for Rx and Tx rings. Friendly module for aq_nic.
+ */
+
+#include "aq_vec.h"
+#include "aq_nic.h"
+#include "aq_ring.h"
+#include "aq_hw.h"
+
+#include <linux/netdevice.h>
+
+struct aq_vec_s {
+	const struct aq_hw_ops *aq_hw_ops;
+	struct aq_hw_s *aq_hw;
+	struct aq_nic_s *aq_nic;
+	unsigned int tx_rings;
+	unsigned int rx_rings;
+	struct aq_ring_param_s aq_ring_param;
+	struct napi_struct napi;
+	struct aq_ring_s ring[AQ_CFG_TCS_MAX][2];
+};
+
+#define AQ_VEC_TX_ID 0
+#define AQ_VEC_RX_ID 1
+
+static int aq_vec_poll(struct napi_struct *napi, int budget)
+{
+	struct aq_vec_s *self = container_of(napi, struct aq_vec_s, napi);
+	unsigned int sw_tail_old = 0U;
+	struct aq_ring_s *ring = NULL;
+	bool was_tx_cleaned = true;
+	unsigned int i = 0U;
+	int work_done = 0;
+	int err = 0;
+
+	if (!self) {
+		err = -EINVAL;
+	} else {
+		for (i = 0U, ring = self->ring[0];
+			self->tx_rings > i; ++i, ring = self->ring[i]) {
+			if (self->aq_hw_ops->hw_ring_tx_head_update) {
+				err = self->aq_hw_ops->hw_ring_tx_head_update(
+							self->aq_hw,
+							&ring[AQ_VEC_TX_ID]);
+				if (err < 0)
+					goto err_exit;
+			}
+
+			if (ring[AQ_VEC_TX_ID].sw_head !=
+			    ring[AQ_VEC_TX_ID].hw_head) {
+				was_tx_cleaned = aq_ring_tx_clean(&ring[AQ_VEC_TX_ID]);
+				aq_ring_update_queue_state(&ring[AQ_VEC_TX_ID]);
+			}
+
+			err = self->aq_hw_ops->hw_ring_rx_receive(self->aq_hw,
+					    &ring[AQ_VEC_RX_ID]);
+			if (err < 0)
+				goto err_exit;
+
+			if (ring[AQ_VEC_RX_ID].sw_head !=
+				ring[AQ_VEC_RX_ID].hw_head) {
+				err = aq_ring_rx_clean(&ring[AQ_VEC_RX_ID],
+						       napi,
+						       &work_done,
+						       budget - work_done);
+				if (err < 0)
+					goto err_exit;
+
+				sw_tail_old = ring[AQ_VEC_RX_ID].sw_tail;
+
+				err = aq_ring_rx_fill(&ring[AQ_VEC_RX_ID]);
+				if (err < 0)
+					goto err_exit;
+
+				err = self->aq_hw_ops->hw_ring_rx_fill(
+					self->aq_hw,
+					&ring[AQ_VEC_RX_ID], sw_tail_old);
+				if (err < 0)
+					goto err_exit;
+			}
+		}
+
+		if (!was_tx_cleaned)
+			work_done = budget;
+
+		if (work_done < budget) {
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 19, 0)
+			napi_complete_done(napi, work_done);
+#else
+			napi_complete(napi);
+#endif
+			self->aq_hw_ops->hw_irq_enable(self->aq_hw,
+					1U << self->aq_ring_param.vec_idx);
+		}
+	}
+err_exit:
+	return work_done;
+}
+
+struct aq_vec_s *aq_vec_alloc(struct aq_nic_s *aq_nic, unsigned int idx,
+			      struct aq_nic_cfg_s *aq_nic_cfg)
+{
+	struct aq_vec_s *self = NULL;
+	struct aq_ring_s *ring = NULL;
+	unsigned int i = 0U;
+	int err = 0;
+
+	self = kzalloc(sizeof(*self), GFP_KERNEL);
+	if (!self) {
+		err = -ENOMEM;
+		goto err_exit;
+	}
+
+	self->aq_nic = aq_nic;
+	self->aq_ring_param.vec_idx = idx;
+	self->aq_ring_param.cpu =
+		idx + aq_nic_cfg->aq_rss.base_cpu_number;
+
+	cpumask_set_cpu(self->aq_ring_param.cpu,
+			&self->aq_ring_param.affinity_mask);
+
+	self->tx_rings = 0;
+	self->rx_rings = 0;
+
+	netif_napi_add(aq_nic_get_ndev(aq_nic), &self->napi,
+		       aq_vec_poll, AQ_CFG_NAPI_WEIGHT);
+
+	for (i = 0; i < aq_nic_cfg->tcs; ++i) {
+		unsigned int idx_ring = AQ_NIC_TCVEC2RING(self->nic,
+						self->tx_rings,
+						self->aq_ring_param.vec_idx);
+
+		ring = aq_ring_tx_alloc(&self->ring[i][AQ_VEC_TX_ID], aq_nic,
+					idx_ring, aq_nic_cfg);
+		if (!ring) {
+			err = -ENOMEM;
+			goto err_exit;
+		}
+
+		++self->tx_rings;
+
+		aq_nic_set_tx_ring(aq_nic, idx_ring, ring);
+
+		ring = aq_ring_rx_alloc(&self->ring[i][AQ_VEC_RX_ID], aq_nic,
+					idx_ring, aq_nic_cfg);
+		if (!ring) {
+			err = -ENOMEM;
+			goto err_exit;
+		}
+
+		++self->rx_rings;
+	}
+
+err_exit:
+	if (err < 0) {
+		aq_vec_free(self);
+		self = NULL;
+	}
+	return self;
+}
+
+int aq_vec_init(struct aq_vec_s *self, const struct aq_hw_ops *aq_hw_ops,
+		struct aq_hw_s *aq_hw)
+{
+	struct aq_ring_s *ring = NULL;
+	unsigned int i = 0U;
+	int err = 0;
+
+	self->aq_hw_ops = aq_hw_ops;
+	self->aq_hw = aq_hw;
+
+	for (i = 0U, ring = self->ring[0];
+		self->tx_rings > i; ++i, ring = self->ring[i]) {
+		err = aq_ring_init(&ring[AQ_VEC_TX_ID]);
+		if (err < 0)
+			goto err_exit;
+
+		err = self->aq_hw_ops->hw_ring_tx_init(self->aq_hw,
+						       &ring[AQ_VEC_TX_ID],
+						       &self->aq_ring_param);
+		if (err < 0)
+			goto err_exit;
+
+		err = aq_ring_init(&ring[AQ_VEC_RX_ID]);
+		if (err < 0)
+			goto err_exit;
+
+		err = self->aq_hw_ops->hw_ring_rx_init(self->aq_hw,
+						       &ring[AQ_VEC_RX_ID],
+						       &self->aq_ring_param);
+		if (err < 0)
+			goto err_exit;
+
+		err = aq_ring_rx_fill(&ring[AQ_VEC_RX_ID]);
+		if (err < 0)
+			goto err_exit;
+
+		err = self->aq_hw_ops->hw_ring_rx_fill(self->aq_hw,
+						       &ring[AQ_VEC_RX_ID], 0U);
+		if (err < 0)
+			goto err_exit;
+	}
+
+err_exit:
+	return err;
+}
+
+int aq_vec_start(struct aq_vec_s *self)
+{
+	struct aq_ring_s *ring = NULL;
+	unsigned int i = 0U;
+	int err = 0;
+
+	for (i = 0U, ring = self->ring[0];
+		self->tx_rings > i; ++i, ring = self->ring[i]) {
+		err = self->aq_hw_ops->hw_ring_tx_start(self->aq_hw,
+							&ring[AQ_VEC_TX_ID]);
+		if (err < 0)
+			goto err_exit;
+
+		err = self->aq_hw_ops->hw_ring_rx_start(self->aq_hw,
+							&ring[AQ_VEC_RX_ID]);
+		if (err < 0)
+			goto err_exit;
+	}
+
+	napi_enable(&self->napi);
+
+err_exit:
+	return err;
+}
+
+void aq_vec_stop(struct aq_vec_s *self)
+{
+	struct aq_ring_s *ring = NULL;
+	unsigned int i = 0U;
+
+	for (i = 0U, ring = self->ring[0];
+		self->tx_rings > i; ++i, ring = self->ring[i]) {
+		self->aq_hw_ops->hw_ring_tx_stop(self->aq_hw,
+						 &ring[AQ_VEC_TX_ID]);
+
+		self->aq_hw_ops->hw_ring_rx_stop(self->aq_hw,
+						 &ring[AQ_VEC_RX_ID]);
+	}
+
+	napi_disable(&self->napi);
+}
+
+void aq_vec_deinit(struct aq_vec_s *self)
+{
+	struct aq_ring_s *ring = NULL;
+	unsigned int i = 0U;
+
+	if (!self)
+		goto err_exit;
+
+	for (i = 0U, ring = self->ring[0];
+		self->tx_rings > i; ++i, ring = self->ring[i]) {
+		aq_ring_tx_clean(&ring[AQ_VEC_TX_ID]);
+		aq_ring_rx_deinit(&ring[AQ_VEC_RX_ID]);
+	}
+err_exit:;
+}
+
+void aq_vec_free(struct aq_vec_s *self)
+{
+	struct aq_ring_s *ring = NULL;
+	unsigned int i = 0U;
+
+	if (!self)
+		goto err_exit;
+
+	for (i = 0U, ring = self->ring[0];
+		self->tx_rings > i; ++i, ring = self->ring[i]) {
+		aq_ring_free(&ring[AQ_VEC_TX_ID]);
+		aq_ring_free(&ring[AQ_VEC_RX_ID]);
+	}
+
+	netif_napi_del(&self->napi);
+
+	kfree(self);
+
+err_exit:;
+}
+
+irqreturn_t aq_vec_isr(int irq, void *private)
+{
+	struct aq_vec_s *self = private;
+	int err = 0;
+
+	if (!self) {
+		err = -EINVAL;
+		goto err_exit;
+	}
+	napi_schedule(&self->napi);
+
+err_exit:
+	return err >= 0 ? IRQ_HANDLED : IRQ_NONE;
+}
+
+irqreturn_t aq_vec_isr_legacy(int irq, void *private)
+{
+	struct aq_vec_s *self = private;
+	u64 irq_mask = 0U;
+	irqreturn_t err = 0;
+
+	if (!self) {
+		err = -EINVAL;
+		goto err_exit;
+	}
+	err = self->aq_hw_ops->hw_irq_read(self->aq_hw, &irq_mask);
+	if (err < 0)
+		goto err_exit;
+
+	if (irq_mask) {
+		self->aq_hw_ops->hw_irq_disable(self->aq_hw,
+			      1U << self->aq_ring_param.vec_idx);
+		napi_schedule(&self->napi);
+	} else {
+		self->aq_hw_ops->hw_irq_enable(self->aq_hw, 1U);
+		err = IRQ_NONE;
+	}
+
+err_exit:
+	return err >= 0 ? IRQ_HANDLED : IRQ_NONE;
+}
+
+cpumask_t *aq_vec_get_affinity_mask(struct aq_vec_s *self)
+{
+	return &self->aq_ring_param.affinity_mask;
+}
+
+void aq_vec_add_stats(struct aq_vec_s *self,
+		      struct aq_ring_stats_rx_s *stats_rx,
+		      struct aq_ring_stats_tx_s *stats_tx)
+{
+	struct aq_ring_s *ring = NULL;
+	unsigned int r = 0U;
+
+	for (r = 0U, ring = self->ring[0];
+		self->tx_rings > r; ++r, ring = self->ring[r]) {
+		struct aq_ring_stats_tx_s *tx = &ring[AQ_VEC_TX_ID].stats.tx;
+		struct aq_ring_stats_rx_s *rx = &ring[AQ_VEC_RX_ID].stats.rx;
+
+		stats_rx->packets += rx->packets;
+		stats_rx->bytes += rx->bytes;
+		stats_rx->errors += rx->errors;
+		stats_rx->jumbo_packets += rx->jumbo_packets;
+		stats_rx->lro_packets += rx->lro_packets;
+		stats_rx->pg_losts += rx->pg_losts;
+		stats_rx->pg_flips += rx->pg_flips;
+		stats_rx->pg_reuses += rx->pg_reuses;
+
+		stats_tx->packets += tx->packets;
+		stats_tx->bytes += tx->bytes;
+		stats_tx->errors += tx->errors;
+		stats_tx->queue_restarts += tx->queue_restarts;
+	}
+}
+
+int aq_vec_get_sw_stats(struct aq_vec_s *self, u64 *data, unsigned int *p_count)
+{
+	unsigned int count = 0U;
+	struct aq_ring_stats_rx_s stats_rx;
+	struct aq_ring_stats_tx_s stats_tx;
+
+	memset(&stats_rx, 0U, sizeof(struct aq_ring_stats_rx_s));
+	memset(&stats_tx, 0U, sizeof(struct aq_ring_stats_tx_s));
+	aq_vec_add_stats(self, &stats_rx, &stats_tx);
+
+	/* This data should mimic aq_ethtool_queue_stat_names structure
+	 */
+	data[count] += stats_rx.packets;
+	data[++count] += stats_tx.packets;
+	data[++count] += stats_tx.queue_restarts;
+	data[++count] += stats_rx.jumbo_packets;
+	data[++count] += stats_rx.lro_packets;
+	data[++count] += stats_rx.errors;
+
+	if (p_count)
+		*p_count = ++count;
+
+	return 0;
+}
diff --git a/drivers/net/ethernet/aquantia/aq_vec.h b/drivers/net/ethernet/aquantia/aq_vec.h
new file mode 100644
index 00000000..8bdf60b
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/aq_vec.h
@@ -0,0 +1,44 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File aq_vec.h: Definition of common structures for vector of Rx and Tx rings.
+ * Declaration of functions for Rx and Tx rings.
+ */
+
+#ifndef AQ_VEC_H
+#define AQ_VEC_H
+
+#include "aq_common.h"
+#include <linux/irqreturn.h>
+
+struct aq_hw_s;
+struct aq_hw_ops;
+struct aq_nic_s;
+struct aq_nic_cfg_s;
+struct aq_ring_stats_rx_s;
+struct aq_ring_stats_tx_s;
+
+irqreturn_t aq_vec_isr(int irq, void *private);
+irqreturn_t aq_vec_isr_legacy(int irq, void *private);
+struct aq_vec_s *aq_vec_alloc(struct aq_nic_s *aq_nic, unsigned int idx,
+			      struct aq_nic_cfg_s *aq_nic_cfg);
+int aq_vec_init(struct aq_vec_s *self, const struct aq_hw_ops *aq_hw_ops,
+		struct aq_hw_s *aq_hw);
+void aq_vec_deinit(struct aq_vec_s *self);
+void aq_vec_free(struct aq_vec_s *self);
+int aq_vec_start(struct aq_vec_s *self);
+void aq_vec_stop(struct aq_vec_s *self);
+cpumask_t *aq_vec_get_affinity_mask(struct aq_vec_s *self);
+int aq_vec_get_sw_stats(struct aq_vec_s *self, u64 *data,
+			unsigned int *p_count);
+void aq_vec_add_stats(struct aq_vec_s *self,
+		      struct aq_ring_stats_rx_s *stats_rx,
+		      struct aq_ring_stats_tx_s *stats_tx);
+
+#endif /* AQ_VEC_H */
diff --git a/drivers/net/ethernet/aquantia/build-deb.sh b/drivers/net/ethernet/aquantia/build-deb.sh
new file mode 100755
index 00000000..9ddc676
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/build-deb.sh
@@ -0,0 +1,64 @@
+#!/bin/sh
+set -x
+version=`git describe --tags --abbrev=4  | sed 's/\(.*\)-.*/\1/' | sed 's/-/./' | sed 's/v//'`
+
+if [ -e $version ]; then
+        version=`date +%s`
+fi
+
+DRV_ROOT=$PWD
+DEB_ROOT=$PWD/../build
+DEB_DEBIAN=$DEB_ROOT/DEBIAN
+DEB_CONTROL=$DEB_DEBIAN/control
+SRC=/var/build_aq_drv/${version}/Linux
+DEB_SRC=$DEB_ROOT/$SRC
+DEB_OUT=$DRV_ROOT
+TARGET=atlantic
+
+rm -rf $DEB_ROOT
+
+mkdir -p $DEB_DEBIAN || exit 1
+mkdir -p $DEB_SRC || exit 1
+
+cp -r $DRV_ROOT/* $DEB_SRC
+
+echo "Package: Atlantic
+Maintainer: Anatoly Vildemanov <avildem@aquantia.com>
+Build-Depends: debhelper (>= 8.0.0)
+Version: $version
+Section: utils
+Architecture: all
+Description: This package contains aQuantia AQtion Ethernet Linux driver" > $DEB_CONTROL || exit 1
+
+echo "#!/bin/bash
+KERNEL=/lib/modules/\$(uname -r)/aquantia/$TARGET.ko
+mv \$KERNEL \$KERNEL.bac || true
+depmod -a \$(uname -r)
+rmmod $TARGET.ko || true
+" > $DEB_DEBIAN/preinst || exit 1
+
+echo "#!/bin/bash
+cd $SRC
+AQ_KERNEL=/lib/modules/\$(uname -r)/aquantia/
+KERNEL=\$AQ_KERNEL/$TARGET.ko
+make all
+chmod 644 $TARGET.ko
+mkdir -p \$AQ_KERNEL
+cp $TARGET.ko \$AQ_KERNEL
+depmod -a \$(uname -r)
+insmod $TARGET.ko
+" > $DEB_DEBIAN/postinst || exit 1
+
+echo "#!/bin/bash
+rmmod $TARGET.ko || true
+KERNEL=/lib/modules/\$(uname -r)/aquantia/$TARGET.ko
+rm -rf $KERNEL
+depmod -a \$(uname -r)
+
+" > $DEB_DEBIAN/postrm || exit 1
+
+chmod 755 $DEB_DEBIAN/preinst $DEB_DEBIAN/postinst $DEB_DEBIAN/postrm
+
+deb_name='atlantic_'$version'.deb'
+
+fakeroot dpkg-deb --build  $DEB_ROOT $deb_name
\ No newline at end of file
diff --git a/drivers/net/ethernet/aquantia/dkms.sh b/drivers/net/ethernet/aquantia/dkms.sh
new file mode 100755
index 00000000..a4ebba4
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/dkms.sh
@@ -0,0 +1,146 @@
+#!/bin/sh
+
+# error code
+ERR_OK=0
+ERR_SCRIPT=1
+ERR_DRIVER_NOT_ADD=200
+ERR_DRIVER_ALREADY_ADD=$(expr ${ERR_DRIVER_NOT_ADD} + 1)
+
+get_version_driver ()
+{
+	local FILENAME="ver.h"
+
+	local MAJOR=`   awk -n '/NIC_MAJOR_DRIVER_VERSION/    {print $3}' ${FILENAME}`
+	local MINOR=`   awk -n '/NIC_MINOR_DRIVER_VERSION/    {print $3}' ${FILENAME}`
+	local BUILD=`   awk -n '/NIC_BUILD_DRIVER_VERSION/    {print $3}' ${FILENAME}`
+	local REVISION=`awk -n '/NIC_REVISION_DRIVER_VERSION/ {print $3}' ${FILENAME}`
+
+	echo "${MAJOR}.${MINOR}.${BUILD}.${REVISION}"
+}
+
+remove_driver ()
+{
+	case ${@} in
+		${ERR_DRIVER_ALREADY_ADD} ) ;;
+		${ERR_DRIVER_NOT_ADD}     ) rm -rf ${MODULE_SRC} ;;
+		*                         ) dkms remove ${MODULE_NAME}/${MODULE_VERSION} --all || exit ${ERR_SCRIPT}
+		                            rm -rf ${MODULE_SRC} ;;
+	esac
+
+	exit ${@}
+}
+
+install_driver ()
+{
+	mkdir -p ${MODULE_SRC}
+	cp -r * ${MODULE_SRC}
+
+cat <<EOF >/usr/src/${PACKAGE_NAME}/dkms.conf
+	PACKAGE_NAME="${MODULE_NAME}"
+	BUILT_MODULE_NAME[0]="${MODULE_NAME}"
+	PACKAGE_VERSION="${MODULE_VERSION}"
+	DEST_MODULE_LOCATION[0]="/kernel/drivers/net/ethernet/aquantia"
+	AUTOINSTALL="yes"
+EOF
+
+	dkms add ${MODULE_NAME}/${MODULE_VERSION}
+	local ERR=${?}
+	if [ ${ERR} != 0 ] ; then
+		if [ "${ERR}" = "3" ] ; then
+			remove_driver ${ERR_DRIVER_ALREADY_ADD} > /dev/null
+		else
+			remove_driver ${ERR_DRIVER_NOT_ADD}     > /dev/null
+		fi
+	fi
+
+	dkms build   ${MODULE_NAME}/${MODULE_VERSION} || remove_driver ${?} > /dev/null
+	dkms install ${MODULE_NAME}/${MODULE_VERSION} || remove_driver ${?} > /dev/null
+}
+
+uninstall_driver ()
+{
+	remove_driver ${ERR_OK}
+}
+
+get_uninstalled_packages ()
+{
+	local UNINSTALLED=""
+
+	for PACKAGE in ${PACKAGES}
+	do
+		${CMD} ${PACKAGE} > /dev/null
+		if [ "${?}" != "0" ] ; then
+			UNINSTALLED="${UNINSTALLED} ${PACKAGE}"
+		fi
+	done
+
+	echo "${UNINSTALLED}"
+}
+
+get_distro_os ()
+{
+	local OS=`uname`
+	if [ "${OS}" = "Linux" ] ; then
+		if [ -f /etc/redhat-release ] ; then
+			DISTRO_NAME='redhat'
+		elif [ -f /etc/debian_version ] ; then
+			DISTRO_NAME='debian'
+		elif [ -f /etc/SuSE-release ] ; then
+			DISTRO_NAME='suse'
+		elif [ -f /etc/mandrake-release ] ; then
+			DISTRO_NAME='mandrake'
+		fi
+	else
+		DISTRO_NAME="undefined"
+	fi
+
+	echo ${DISTRO_NAME}
+}
+
+main ()
+{
+	YUM="yum"
+	APT_GET="apt-get"
+	DKMS="dkms"
+	GAWK="gawk"
+	CMD=""
+	DISTRO=$(get_distro_os)
+	if [ "${DISTRO}" = "debian" ] ; then
+		PACKET_MNG="${APT_GET}"
+		LINUX_HEADERS="linux-headers-`uname -r`"
+		TOOLS="build-essential"
+		CMD="dpkg-query -l"
+	elif [ "${DISTRO}" = "redhat" ] ; then
+		PACKET_MNG="${YUM}"
+		LINUX_HEADERS="kernel-devel-`uname -r`"
+		TOOLS="gcc gcc-c++ make"
+		CMD="${YUM} list installed"
+	else
+		echo "Sorry, your operating system ${DISTRO} is not supported."
+		exit ${ERR_SCRIPT}
+	fi
+
+	# necessary packages
+	PACKAGES="${LINUX_HEADERS} ${DKMS} ${GAWK} ${TOOLS}"
+	UNINSTALLED_PACKAGES=$(get_uninstalled_packages)
+
+	if [ ! -z "${UNINSTALLED_PACKAGES}" ] ; then
+		echo "Please install the necessary packages${UNINSTALLED_PACKAGES}."
+		echo "Example: sudo ${PACKET_MNG} install${UNINSTALLED_PACKAGES}."
+		exit ${ERR_SCRIPT}
+	fi
+
+	MODULE_NAME="atlantic"
+	MODULE_VERSION=$(get_version_driver)
+	PACKAGE_NAME="${MODULE_NAME}-${MODULE_VERSION}"
+	MODULE_SRC="/usr/src/${PACKAGE_NAME}"
+
+	case ${1} in
+		install   ) install_driver ;;
+		uninstall ) uninstall_driver ;;
+		*         ) echo "Sorry, invalid parameters, please enter: ${0} install or ${0} uninstall."
+		            exit ${ERR_SCRIPT} ;;
+	esac
+}
+
+main ${1}
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_a0.c b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_a0.c
new file mode 100644
index 00000000..b893b4f
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_a0.c
@@ -0,0 +1,900 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_a0.c: Definition of Atlantic hardware specific functions. */
+
+#include "../aq_hw.h"
+#include "../aq_hw_utils.h"
+#include "../aq_ring.h"
+#include "../aq_nic.h"
+#include "hw_atl_a0.h"
+#include "hw_atl_utils.h"
+#include "hw_atl_llh.h"
+#include "hw_atl_a0_internal.h"
+
+#define DEFAULT_A0_BOARD_BASIC_CAPABILITIES \
+	.is_64_dma = true,		  \
+	.msix_irqs = 4U,		  \
+	.irq_mask = ~0U,		  \
+	.vecs = HW_ATL_A0_RSS_MAX,	  \
+	.tcs = HW_ATL_A0_TC_MAX,	  \
+	.rxd_alignment = 1U,		  \
+	.rxd_size = HW_ATL_A0_RXD_SIZE,   \
+	.rxds_max = HW_ATL_A0_MAX_RXD,    \
+	.rxds_min = HW_ATL_A0_MIN_RXD,    \
+	.txd_alignment = 1U,		  \
+	.txd_size = HW_ATL_A0_TXD_SIZE,   \
+	.txds_max = HW_ATL_A0_MAX_TXD,    \
+	.txds_min = HW_ATL_A0_MIN_RXD,    \
+	.txhwb_alignment = 4096U,	  \
+	.tx_rings = HW_ATL_A0_TX_RINGS,   \
+	.rx_rings = HW_ATL_A0_RX_RINGS,   \
+	.hw_features = NETIF_F_HW_CSUM |  \
+			NETIF_F_RXHASH |  \
+			NETIF_F_RXCSUM |  \
+			NETIF_F_SG |	  \
+			NETIF_F_TSO,	  \
+	.hw_priv_flags = IFF_UNICAST_FLT, \
+	.flow_control = true,		  \
+	.mtu = HW_ATL_A0_MTU_JUMBO,       \
+	.mac_regs_count = 88,		  \
+	.hw_alive_check_addr = 0x10U
+
+const struct aq_hw_caps_s hw_atl_a0_caps_aqc100 = {
+	DEFAULT_A0_BOARD_BASIC_CAPABILITIES,
+	.media_type = AQ_HW_MEDIA_TYPE_FIBRE,
+	.link_speed_msk = AQ_NIC_RATE_5G|
+			  AQ_NIC_RATE_2GS|
+			  AQ_NIC_RATE_1G|
+			  AQ_NIC_RATE_100M,
+};
+
+const struct aq_hw_caps_s hw_atl_a0_caps_aqc107 = {
+	DEFAULT_A0_BOARD_BASIC_CAPABILITIES,
+	.media_type = AQ_HW_MEDIA_TYPE_TP,
+	.link_speed_msk = AQ_NIC_RATE_10G|
+			  AQ_NIC_RATE_5G|
+			  AQ_NIC_RATE_2GS|
+			  AQ_NIC_RATE_1G|
+			  AQ_NIC_RATE_100M,
+};
+
+const struct aq_hw_caps_s hw_atl_a0_caps_aqc108 = {
+	DEFAULT_A0_BOARD_BASIC_CAPABILITIES,
+	.media_type = AQ_HW_MEDIA_TYPE_TP,
+	.link_speed_msk = AQ_NIC_RATE_5G|
+			  AQ_NIC_RATE_2GS|
+			  AQ_NIC_RATE_1G|
+			  AQ_NIC_RATE_100M,
+};
+
+const struct aq_hw_caps_s hw_atl_a0_caps_aqc109 = {
+	DEFAULT_A0_BOARD_BASIC_CAPABILITIES,
+	.media_type = AQ_HW_MEDIA_TYPE_TP,
+	.link_speed_msk = AQ_NIC_RATE_2GS|
+			  AQ_NIC_RATE_1G|
+			  AQ_NIC_RATE_100M,
+};
+
+static int hw_atl_a0_hw_reset(struct aq_hw_s *self)
+{
+	int err = 0;
+
+	hw_atl_glb_glb_reg_res_dis_set(self, 1U);
+	hw_atl_pci_pci_reg_res_dis_set(self, 0U);
+	hw_atl_rx_rx_reg_res_dis_set(self, 0U);
+	hw_atl_tx_tx_reg_res_dis_set(self, 0U);
+
+	HW_ATL_FLUSH();
+	hw_atl_glb_soft_res_set(self, 1);
+
+	/* check 10 times by 1ms */
+	AQ_HW_WAIT_FOR(hw_atl_glb_soft_res_get(self) == 0, 1000U, 10U);
+	if (err < 0)
+		goto err_exit;
+
+	hw_atl_itr_irq_reg_res_dis_set(self, 0U);
+	hw_atl_itr_res_irq_set(self, 1U);
+
+	/* check 10 times by 1ms */
+	AQ_HW_WAIT_FOR(hw_atl_itr_res_irq_get(self) == 0, 1000U, 10U);
+	if (err < 0)
+		goto err_exit;
+
+	self->aq_fw_ops->set_state(self, MPI_RESET);
+
+	err = aq_hw_err_from_flags(self);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_a0_hw_qos_set(struct aq_hw_s *self)
+{
+	u32 tc = 0U;
+	u32 buff_size = 0U;
+	unsigned int i_priority = 0U;
+	bool is_rx_flow_control = false;
+
+	/* TPS Descriptor rate init */
+	hw_atl_tps_tx_pkt_shed_desc_rate_curr_time_res_set(self, 0x0U);
+	hw_atl_tps_tx_pkt_shed_desc_rate_lim_set(self, 0xA);
+
+	/* TPS VM init */
+	hw_atl_tps_tx_pkt_shed_desc_vm_arb_mode_set(self, 0U);
+
+	/* TPS TC credits init */
+	hw_atl_tps_tx_pkt_shed_desc_tc_arb_mode_set(self, 0U);
+	hw_atl_tps_tx_pkt_shed_data_arb_mode_set(self, 0U);
+
+	hw_atl_tps_tx_pkt_shed_tc_data_max_credit_set(self, 0xFFF, 0U);
+	hw_atl_tps_tx_pkt_shed_tc_data_weight_set(self, 0x64, 0U);
+	hw_atl_tps_tx_pkt_shed_desc_tc_max_credit_set(self, 0x50, 0U);
+	hw_atl_tps_tx_pkt_shed_desc_tc_weight_set(self, 0x1E, 0U);
+
+	/* Tx buf size */
+	buff_size = HW_ATL_A0_TXBUF_MAX;
+
+	hw_atl_tpb_tx_pkt_buff_size_per_tc_set(self, buff_size, tc);
+	hw_atl_tpb_tx_buff_hi_threshold_per_tc_set(self,
+						   (buff_size *
+						   (1024 / 32U) * 66U) /
+						   100U, tc);
+	hw_atl_tpb_tx_buff_lo_threshold_per_tc_set(self,
+						   (buff_size *
+						   (1024 / 32U) * 50U) /
+						   100U, tc);
+
+	/* QoS Rx buf size per TC */
+	tc = 0;
+	is_rx_flow_control = (AQ_NIC_FC_RX & self->aq_nic_cfg->flow_control);
+	buff_size = HW_ATL_A0_RXBUF_MAX;
+
+	hw_atl_rpb_rx_pkt_buff_size_per_tc_set(self, buff_size, tc);
+	hw_atl_rpb_rx_buff_hi_threshold_per_tc_set(self,
+						   (buff_size *
+						   (1024U / 32U) * 66U) /
+						   100U, tc);
+	hw_atl_rpb_rx_buff_lo_threshold_per_tc_set(self,
+						   (buff_size *
+						   (1024U / 32U) * 50U) /
+						   100U, tc);
+	hw_atl_rpb_rx_xoff_en_per_tc_set(self, is_rx_flow_control ? 1U : 0U, tc);
+
+	/* QoS 802.1p priority -> TC mapping */
+	for (i_priority = 8U; i_priority--;)
+		hw_atl_rpf_rpb_user_priority_tc_map_set(self, i_priority, 0U);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_rss_hash_set(struct aq_hw_s *self,
+				     struct aq_rss_parameters *rss_params)
+{
+	struct aq_nic_cfg_s *cfg = self->aq_nic_cfg;
+	int err = 0;
+	unsigned int i = 0U;
+	unsigned int addr = 0U;
+
+	for (i = 10, addr = 0U; i--; ++addr) {
+		u32 key_data = cfg->is_rss ?
+			__swab32(rss_params->hash_secret_key[i]) : 0U;
+		hw_atl_rpf_rss_key_wr_data_set(self, key_data);
+		hw_atl_rpf_rss_key_addr_set(self, addr);
+		hw_atl_rpf_rss_key_wr_en_set(self, 1U);
+		AQ_HW_WAIT_FOR(hw_atl_rpf_rss_key_wr_en_get(self) == 0,
+			       1000U, 10U);
+		if (err < 0)
+			goto err_exit;
+	}
+
+	err = aq_hw_err_from_flags(self);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_a0_hw_rss_set(struct aq_hw_s *self,
+				struct aq_rss_parameters *rss_params)
+{
+	u8 *indirection_table =	rss_params->indirection_table;
+	u32 i = 0U;
+	u32 num_rss_queues = max(1U, self->aq_nic_cfg->num_rss_queues);
+	int err = 0;
+	u16 bitary[(HW_ATL_A0_RSS_REDIRECTION_MAX *
+					HW_ATL_A0_RSS_REDIRECTION_BITS / 16U)];
+
+	memset(bitary, 0, sizeof(bitary));
+
+	for (i = HW_ATL_A0_RSS_REDIRECTION_MAX; i--; ) {
+		(*(u32 *)(bitary + ((i * 3U) / 16U))) |=
+			((indirection_table[i] % num_rss_queues) <<
+			((i * 3U) & 0xFU));
+	}
+
+	for (i = ARRAY_SIZE(bitary); i--;) {
+		hw_atl_rpf_rss_redir_tbl_wr_data_set(self, bitary[i]);
+		hw_atl_rpf_rss_redir_tbl_addr_set(self, i);
+		hw_atl_rpf_rss_redir_wr_en_set(self, 1U);
+		AQ_HW_WAIT_FOR(hw_atl_rpf_rss_redir_wr_en_get(self) == 0,
+			       1000U, 10U);
+		if (err < 0)
+			goto err_exit;
+	}
+
+	err = aq_hw_err_from_flags(self);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_a0_hw_offload_set(struct aq_hw_s *self,
+				    struct aq_nic_cfg_s *aq_nic_cfg)
+{
+	/* TX checksums offloads*/
+	hw_atl_tpo_ipv4header_crc_offload_en_set(self, 1);
+	hw_atl_tpo_tcp_udp_crc_offload_en_set(self, 1);
+
+	/* RX checksums offloads*/
+	hw_atl_rpo_ipv4header_crc_offload_en_set(self, 1);
+	hw_atl_rpo_tcp_udp_crc_offload_en_set(self, 1);
+
+	/* LSO offloads*/
+	hw_atl_tdm_large_send_offload_en_set(self, 0xFFFFFFFFU);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_init_tx_path(struct aq_hw_s *self)
+{
+	hw_atl_thm_lso_tcp_flag_of_first_pkt_set(self, 0x0FF6U);
+	hw_atl_thm_lso_tcp_flag_of_middle_pkt_set(self, 0x0FF6U);
+	hw_atl_thm_lso_tcp_flag_of_last_pkt_set(self, 0x0F7FU);
+
+	/* Tx interrupts */
+	hw_atl_tdm_tx_desc_wr_wb_irq_en_set(self, 1U);
+
+	/* misc */
+	aq_hw_write_reg(self, 0x00007040U, IS_CHIP_FEATURE(TPO2) ?
+			0x00010000U : 0x00000000U);
+	hw_atl_tdm_tx_dca_en_set(self, 0U);
+	hw_atl_tdm_tx_dca_mode_set(self, 0U);
+
+	hw_atl_tpb_tx_path_scp_ins_en_set(self, 1U);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_init_rx_path(struct aq_hw_s *self)
+{
+	struct aq_nic_cfg_s *cfg = self->aq_nic_cfg;
+	int i;
+
+	/* Rx TC/RSS number config */
+	hw_atl_rpb_rpf_rx_traf_class_mode_set(self, 1U);
+
+	/* Rx flow control */
+	hw_atl_rpb_rx_flow_ctl_mode_set(self, 1U);
+
+	/* RSS Ring selection */
+	hw_atl_reg_rx_flr_rss_control1set(self, cfg->is_rss ?
+					0xB3333333U : 0x00000000U);
+
+	/* Multicast filters */
+	for (i = HW_ATL_A0_MAC_MAX; i--;) {
+		hw_atl_rpfl2_uc_flr_en_set(self, (i == 0U) ? 1U : 0U, i);
+		hw_atl_rpfl2unicast_flr_act_set(self, 1U, i);
+	}
+
+	hw_atl_reg_rx_flr_mcst_flr_msk_set(self, 0x00000000U);
+	hw_atl_reg_rx_flr_mcst_flr_set(self, 0x00010FFFU, 0U);
+
+	/* Vlan filters */
+	hw_atl_rpf_vlan_outer_etht_set(self, 0x88A8U);
+	hw_atl_rpf_vlan_inner_etht_set(self, 0x8100U);
+	hw_atl_rpf_vlan_prom_mode_en_set(self, 1);
+
+	/* Rx Interrupts */
+	hw_atl_rdm_rx_desc_wr_wb_irq_en_set(self, 1U);
+
+	/* misc */
+	hw_atl_rpfl2broadcast_flr_act_set(self, 1U);
+	hw_atl_rpfl2broadcast_count_threshold_set(self, 0xFFFFU & (~0U / 256U));
+
+	hw_atl_rdm_rx_dca_en_set(self, 0U);
+	hw_atl_rdm_rx_dca_mode_set(self, 0U);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_mac_addr_set(struct aq_hw_s *self, u8 *mac_addr)
+{
+	int err = 0;
+	unsigned int h = 0U;
+	unsigned int l = 0U;
+
+	if (!mac_addr) {
+		err = -EINVAL;
+		goto err_exit;
+	}
+	h = (mac_addr[0] << 8) | (mac_addr[1]);
+	l = (mac_addr[2] << 24) | (mac_addr[3] << 16) |
+		(mac_addr[4] << 8) | mac_addr[5];
+
+	hw_atl_rpfl2_uc_flr_en_set(self, 0U, HW_ATL_A0_MAC);
+	hw_atl_rpfl2unicast_dest_addresslsw_set(self, l, HW_ATL_A0_MAC);
+	hw_atl_rpfl2unicast_dest_addressmsw_set(self, h, HW_ATL_A0_MAC);
+	hw_atl_rpfl2_uc_flr_en_set(self, 1U, HW_ATL_A0_MAC);
+
+	err = aq_hw_err_from_flags(self);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_a0_hw_init(struct aq_hw_s *self, u8 *mac_addr)
+{
+	static u32 aq_hw_atl_igcr_table_[4][2] = {
+		{ 0x20000000U, 0x20000000U }, /* AQ_IRQ_INVALID */
+		{ 0x20000080U, 0x20000080U }, /* AQ_IRQ_LEGACY */
+		{ 0x20000021U, 0x20000025U }, /* AQ_IRQ_MSI */
+		{ 0x20000022U, 0x20000026U }  /* AQ_IRQ_MSIX */
+	};
+
+	int err = 0;
+
+	struct aq_nic_cfg_s *aq_nic_cfg = self->aq_nic_cfg;
+
+	hw_atl_a0_hw_init_tx_path(self);
+	hw_atl_a0_hw_init_rx_path(self);
+
+	hw_atl_a0_hw_mac_addr_set(self, mac_addr);
+
+	self->aq_fw_ops->set_link_speed(self, aq_nic_cfg->link_speed_msk);
+	self->aq_fw_ops->set_state(self, MPI_INIT);
+
+	hw_atl_reg_tx_dma_debug_ctl_set(self, 0x800000b8U);
+	hw_atl_reg_tx_dma_debug_ctl_set(self, 0x000000b8U);
+
+	hw_atl_a0_hw_qos_set(self);
+	hw_atl_a0_hw_rss_set(self, &aq_nic_cfg->aq_rss);
+	hw_atl_a0_hw_rss_hash_set(self, &aq_nic_cfg->aq_rss);
+
+	/* Reset link status and read out initial hardware counters */
+	self->aq_link_status.mbps = 0;
+	self->aq_fw_ops->update_stats(self);
+
+	err = aq_hw_err_from_flags(self);
+	if (err < 0)
+		goto err_exit;
+
+	/* Interrupts */
+	hw_atl_reg_irq_glb_ctl_set(self,
+				   aq_hw_atl_igcr_table_[aq_nic_cfg->irq_type]
+					[(aq_nic_cfg->vecs > 1U) ? 1 : 0]);
+
+	hw_atl_itr_irq_auto_masklsw_set(self, aq_nic_cfg->aq_hw_caps->irq_mask);
+
+	/* Interrupts */
+	hw_atl_reg_gen_irq_map_set(self,
+				   ((HW_ATL_A0_ERR_INT << 0x18) | (1U << 0x1F)) |
+				   ((HW_ATL_A0_ERR_INT << 0x10) | (1U << 0x17)) |
+				   ((HW_ATL_A0_ERR_INT << 8) | (1U << 0xF)) |
+				   ((HW_ATL_A0_ERR_INT) | (1U << 0x7)), 0U);
+
+	hw_atl_a0_hw_offload_set(self, aq_nic_cfg);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_a0_hw_ring_tx_start(struct aq_hw_s *self,
+				      struct aq_ring_s *ring)
+{
+	hw_atl_tdm_tx_desc_en_set(self, 1, ring->idx);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_ring_rx_start(struct aq_hw_s *self,
+				      struct aq_ring_s *ring)
+{
+	hw_atl_rdm_rx_desc_en_set(self, 1, ring->idx);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_start(struct aq_hw_s *self)
+{
+	hw_atl_tpb_tx_buff_en_set(self, 1);
+	hw_atl_rpb_rx_buff_en_set(self, 1);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_tx_ring_tail_update(struct aq_hw_s *self,
+					    struct aq_ring_s *ring)
+{
+	hw_atl_reg_tx_dma_desc_tail_ptr_set(self, ring->sw_tail, ring->idx);
+	return 0;
+}
+
+static int hw_atl_a0_hw_ring_tx_xmit(struct aq_hw_s *self,
+				     struct aq_ring_s *ring,
+				     unsigned int frags)
+{
+	struct aq_ring_buff_s *buff = NULL;
+	struct hw_atl_txd_s *txd = NULL;
+	unsigned int buff_pa_len = 0U;
+	unsigned int pkt_len = 0U;
+	unsigned int frag_count = 0U;
+	bool is_gso = false;
+
+	buff = &ring->buff_ring[ring->sw_tail];
+	pkt_len = (buff->is_eop && buff->is_sop) ? buff->len : buff->len_pkt;
+
+	for (frag_count = 0; frag_count < frags; frag_count++) {
+		txd = (struct hw_atl_txd_s *)&ring->dx_ring[ring->sw_tail *
+						HW_ATL_A0_TXD_SIZE];
+		txd->ctl = 0;
+		txd->ctl2 = 0;
+		txd->buf_addr = 0;
+
+		buff = &ring->buff_ring[ring->sw_tail];
+
+		if (buff->is_txc) {
+			txd->ctl |= (buff->len_l3 << 31) |
+				(buff->len_l2 << 24) |
+				HW_ATL_A0_TXD_CTL_CMD_TCP |
+				HW_ATL_A0_TXD_CTL_DESC_TYPE_TXC;
+			txd->ctl2 |= (buff->mss << 16) |
+				(buff->len_l4 << 8) |
+				(buff->len_l3 >> 1);
+
+			pkt_len -= (buff->len_l4 +
+				    buff->len_l3 +
+				    buff->len_l2);
+			is_gso = true;
+		} else {
+			buff_pa_len = buff->len;
+
+			txd->buf_addr = buff->pa;
+			txd->ctl |= (HW_ATL_A0_TXD_CTL_BLEN &
+						((u32)buff_pa_len << 4));
+			txd->ctl |= HW_ATL_A0_TXD_CTL_DESC_TYPE_TXD;
+			/* PAY_LEN */
+			txd->ctl2 |= HW_ATL_A0_TXD_CTL2_LEN & (pkt_len << 14);
+
+			if (is_gso) {
+				txd->ctl |= HW_ATL_A0_TXD_CTL_CMD_LSO;
+				txd->ctl2 |= HW_ATL_A0_TXD_CTL2_CTX_EN;
+			}
+
+			/* Tx checksum offloads */
+			if (buff->is_ip_cso)
+				txd->ctl |= HW_ATL_A0_TXD_CTL_CMD_IPCSO;
+
+			if (buff->is_udp_cso || buff->is_tcp_cso)
+				txd->ctl |= HW_ATL_A0_TXD_CTL_CMD_TUCSO;
+
+			if (unlikely(buff->is_eop)) {
+				txd->ctl |= HW_ATL_A0_TXD_CTL_EOP;
+				txd->ctl |= HW_ATL_A0_TXD_CTL_CMD_WB;
+			}
+		}
+
+		ring->sw_tail = aq_ring_next_dx(ring, ring->sw_tail);
+	}
+
+	hw_atl_a0_hw_tx_ring_tail_update(self, ring);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_ring_rx_init(struct aq_hw_s *self,
+				     struct aq_ring_s *aq_ring,
+				     struct aq_ring_param_s *aq_ring_param)
+{
+	u32 dma_desc_addr_lsw = (u32)aq_ring->dx_ring_pa;
+	u32 dma_desc_addr_msw = (u32)(((u64)aq_ring->dx_ring_pa) >> 32);
+
+	hw_atl_rdm_rx_desc_en_set(self, false, aq_ring->idx);
+
+	hw_atl_rdm_rx_desc_head_splitting_set(self, 0U, aq_ring->idx);
+
+	hw_atl_reg_rx_dma_desc_base_addresslswset(self, dma_desc_addr_lsw,
+						  aq_ring->idx);
+
+	hw_atl_reg_rx_dma_desc_base_addressmswset(self,
+						  dma_desc_addr_msw,
+						  aq_ring->idx);
+
+	hw_atl_rdm_rx_desc_len_set(self, aq_ring->size / 8U, aq_ring->idx);
+
+	hw_atl_rdm_rx_desc_data_buff_size_set(self,
+					      AQ_CFG_RX_FRAME_MAX / 1024U,
+				       aq_ring->idx);
+
+	hw_atl_rdm_rx_desc_head_buff_size_set(self, 0U, aq_ring->idx);
+	hw_atl_rdm_rx_desc_head_splitting_set(self, 0U, aq_ring->idx);
+	hw_atl_rpo_rx_desc_vlan_stripping_set(self, 0U, aq_ring->idx);
+
+	/* Rx ring set mode */
+
+	/* Mapping interrupt vector */
+	hw_atl_itr_irq_map_rx_set(self, aq_ring_param->vec_idx, aq_ring->idx);
+	hw_atl_itr_irq_map_en_rx_set(self, true, aq_ring->idx);
+
+	hw_atl_rdm_cpu_id_set(self, aq_ring_param->cpu, aq_ring->idx);
+	hw_atl_rdm_rx_desc_dca_en_set(self, 0U, aq_ring->idx);
+	hw_atl_rdm_rx_head_dca_en_set(self, 0U, aq_ring->idx);
+	hw_atl_rdm_rx_pld_dca_en_set(self, 0U, aq_ring->idx);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_ring_tx_init(struct aq_hw_s *self,
+				     struct aq_ring_s *aq_ring,
+				     struct aq_ring_param_s *aq_ring_param)
+{
+	u32 dma_desc_lsw_addr = (u32)aq_ring->dx_ring_pa;
+	u32 dma_desc_msw_addr = (u32)(((u64)aq_ring->dx_ring_pa) >> 32);
+
+	hw_atl_reg_tx_dma_desc_base_addresslswset(self, dma_desc_lsw_addr,
+						  aq_ring->idx);
+
+	hw_atl_reg_tx_dma_desc_base_addressmswset(self, dma_desc_msw_addr,
+						  aq_ring->idx);
+
+	hw_atl_tdm_tx_desc_len_set(self, aq_ring->size / 8U, aq_ring->idx);
+
+	hw_atl_a0_hw_tx_ring_tail_update(self, aq_ring);
+
+	/* Set Tx threshold */
+	hw_atl_tdm_tx_desc_wr_wb_threshold_set(self, 0U, aq_ring->idx);
+
+	/* Mapping interrupt vector */
+	hw_atl_itr_irq_map_tx_set(self, aq_ring_param->vec_idx, aq_ring->idx);
+	hw_atl_itr_irq_map_en_tx_set(self, true, aq_ring->idx);
+
+	hw_atl_tdm_cpu_id_set(self, aq_ring_param->cpu, aq_ring->idx);
+	hw_atl_tdm_tx_desc_dca_en_set(self, 0U, aq_ring->idx);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_ring_rx_fill(struct aq_hw_s *self,
+				     struct aq_ring_s *ring,
+				     unsigned int sw_tail_old)
+{
+	for (; sw_tail_old != ring->sw_tail;
+		sw_tail_old = aq_ring_next_dx(ring, sw_tail_old)) {
+		struct hw_atl_rxd_s *rxd =
+			(struct hw_atl_rxd_s *)&ring->dx_ring[sw_tail_old *
+							HW_ATL_A0_RXD_SIZE];
+
+		struct aq_ring_buff_s *buff = &ring->buff_ring[sw_tail_old];
+
+		rxd->buf_addr = buff->pa;
+		rxd->hdr_addr = 0U;
+	}
+
+	hw_atl_reg_rx_dma_desc_tail_ptr_set(self, sw_tail_old, ring->idx);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_ring_tx_head_update(struct aq_hw_s *self,
+					    struct aq_ring_s *ring)
+{
+	int err = 0;
+	unsigned int hw_head = hw_atl_tdm_tx_desc_head_ptr_get(self, ring->idx);
+
+	if (aq_utils_obj_test(&self->flags, AQ_HW_FLAG_ERR_UNPLUG)) {
+		err = -ENXIO;
+		goto err_exit;
+	}
+	ring->hw_head = hw_head;
+	err = aq_hw_err_from_flags(self);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_a0_hw_ring_rx_receive(struct aq_hw_s *self,
+					struct aq_ring_s *ring)
+{
+	for (; ring->hw_head != ring->sw_tail;
+		ring->hw_head = aq_ring_next_dx(ring, ring->hw_head)) {
+		struct aq_ring_buff_s *buff = NULL;
+		struct hw_atl_rxd_wb_s *rxd_wb = (struct hw_atl_rxd_wb_s *)
+			&ring->dx_ring[ring->hw_head * HW_ATL_A0_RXD_SIZE];
+
+		unsigned int is_err = 1U;
+		unsigned int is_rx_check_sum_enabled = 0U;
+		unsigned int pkt_type = 0U;
+
+		if (!(rxd_wb->status & 0x5U)) { /* RxD is not done */
+			if ((1U << 4) &
+			hw_atl_reg_rx_dma_desc_status_get(self, ring->idx)) {
+				hw_atl_rdm_rx_desc_en_set(self, false, ring->idx);
+				hw_atl_rdm_rx_desc_res_set(self, true, ring->idx);
+				hw_atl_rdm_rx_desc_res_set(self, false, ring->idx);
+				hw_atl_rdm_rx_desc_en_set(self, true, ring->idx);
+			}
+
+			if (ring->hw_head ||
+			    (hw_atl_rdm_rx_desc_head_ptr_get(self,
+							     ring->idx) < 2U)) {
+				break;
+			} else if (!(rxd_wb->status & 0x1U)) {
+				struct hw_atl_rxd_wb_s *rxd_wb1 =
+					(struct hw_atl_rxd_wb_s *)
+					(&ring->dx_ring[(1U) *
+						HW_ATL_A0_RXD_SIZE]);
+
+				if ((rxd_wb1->status & 0x1U)) {
+					rxd_wb->pkt_len = 1514U;
+					rxd_wb->status = 3U;
+				} else {
+					break;
+				}
+			}
+		}
+
+		buff = &ring->buff_ring[ring->hw_head];
+
+		if (0x3U != (rxd_wb->status & 0x3U))
+			rxd_wb->status |= 4;
+
+		is_err = (0x0000001CU & rxd_wb->status);
+		is_rx_check_sum_enabled = (rxd_wb->type) & (0x3U << 19);
+		pkt_type = 0xFFU & (rxd_wb->type >> 4);
+
+		if (is_rx_check_sum_enabled) {
+			if (0x0U == (pkt_type & 0x3U))
+				buff->is_ip_cso = (is_err & 0x08U) ? 0 : 1;
+
+			if (0x4U == (pkt_type & 0x1CU))
+				buff->is_udp_cso = (is_err & 0x10U) ? 0 : 1;
+			else if (0x0U == (pkt_type & 0x1CU))
+				buff->is_tcp_cso = (is_err & 0x10U) ? 0 : 1;
+
+			/* Checksum offload workaround for small packets */
+			if (rxd_wb->pkt_len <= 60) {
+				buff->is_ip_cso = 0U;
+				buff->is_cso_err = 0U;
+			}
+		}
+
+		is_err &= ~0x18U;
+		is_err &= ~0x04U;
+
+		if (is_err || rxd_wb->type & 0x1000U) {
+			/* status error or DMA error */
+			buff->is_error = 1U;
+		} else {
+			if (self->aq_nic_cfg->is_rss) {
+				/* last 4 byte */
+				u16 rss_type = rxd_wb->type & 0xFU;
+
+				if (rss_type && rss_type < 0x8U) {
+					buff->is_hash_l4 = (rss_type == 0x4 ||
+							rss_type == 0x5);
+					buff->rss_hash = rxd_wb->rss_hash;
+				}
+			}
+
+			if (HW_ATL_A0_RXD_WB_STAT2_EOP & rxd_wb->status) {
+				buff->len = rxd_wb->pkt_len %
+					AQ_CFG_RX_FRAME_MAX;
+				buff->len = buff->len ?
+					buff->len : AQ_CFG_RX_FRAME_MAX;
+				buff->next = 0U;
+				buff->is_eop = 1U;
+			} else {
+				/* jumbo */
+				buff->next = aq_ring_next_dx(ring,
+							     ring->hw_head);
+				++ring->stats.rx.jumbo_packets;
+			}
+		}
+	}
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_irq_enable(struct aq_hw_s *self, u64 mask)
+{
+	hw_atl_itr_irq_msk_setlsw_set(self, LODWORD(mask) |
+			       (1U << HW_ATL_A0_ERR_INT));
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_irq_disable(struct aq_hw_s *self, u64 mask)
+{
+	hw_atl_itr_irq_msk_clearlsw_set(self, LODWORD(mask));
+	hw_atl_itr_irq_status_clearlsw_set(self, LODWORD(mask));
+
+	if ((1U << 16) & hw_atl_reg_gen_irq_status_get(self))
+		atomic_inc(&self->dpc);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_irq_read(struct aq_hw_s *self, u64 *mask)
+{
+	*mask = hw_atl_itr_irq_statuslsw_get(self);
+	return aq_hw_err_from_flags(self);
+}
+
+#define IS_FILTER_ENABLED(_F_) ((packet_filter & (_F_)) ? 1U : 0U)
+
+static int hw_atl_a0_hw_packet_filter_set(struct aq_hw_s *self,
+					  unsigned int packet_filter)
+{
+	unsigned int i = 0U;
+
+	hw_atl_rpfl2promiscuous_mode_en_set(self,
+					    IS_FILTER_ENABLED(IFF_PROMISC));
+	hw_atl_rpfl2multicast_flr_en_set(self,
+					 IS_FILTER_ENABLED(IFF_MULTICAST), 0);
+	hw_atl_rpfl2broadcast_en_set(self, IS_FILTER_ENABLED(IFF_BROADCAST));
+
+	self->aq_nic_cfg->is_mc_list_enabled =
+			IS_FILTER_ENABLED(IFF_MULTICAST);
+
+	for (i = HW_ATL_A0_MAC_MIN; i < HW_ATL_A0_MAC_MAX; ++i)
+		hw_atl_rpfl2_uc_flr_en_set(self,
+					   (self->aq_nic_cfg->is_mc_list_enabled &&
+					   (i <= self->aq_nic_cfg->mc_list_count)) ?
+					    1U : 0U, i);
+
+	return aq_hw_err_from_flags(self);
+}
+
+#undef IS_FILTER_ENABLED
+
+static int hw_atl_a0_hw_multicast_list_set(struct aq_hw_s *self,
+					   u8 ar_mac
+					   [AQ_CFG_MULTICAST_ADDRESS_MAX]
+					   [ETH_ALEN],
+					   u32 count)
+{
+	int err = 0;
+
+	if (count > (HW_ATL_A0_MAC_MAX - HW_ATL_A0_MAC_MIN)) {
+		err = EBADRQC;
+		goto err_exit;
+	}
+	for (self->aq_nic_cfg->mc_list_count = 0U;
+			self->aq_nic_cfg->mc_list_count < count;
+			++self->aq_nic_cfg->mc_list_count) {
+		u32 i = self->aq_nic_cfg->mc_list_count;
+		u32 h = (ar_mac[i][0] << 8) | (ar_mac[i][1]);
+		u32 l = (ar_mac[i][2] << 24) | (ar_mac[i][3] << 16) |
+					(ar_mac[i][4] << 8) | ar_mac[i][5];
+
+		hw_atl_rpfl2_uc_flr_en_set(self, 0U, HW_ATL_A0_MAC_MIN + i);
+
+		hw_atl_rpfl2unicast_dest_addresslsw_set(self,
+							l,
+							HW_ATL_A0_MAC_MIN + i);
+
+		hw_atl_rpfl2unicast_dest_addressmsw_set(self,
+							h,
+							HW_ATL_A0_MAC_MIN + i);
+
+		hw_atl_rpfl2_uc_flr_en_set(self,
+					   (self->aq_nic_cfg->is_mc_list_enabled),
+					   HW_ATL_A0_MAC_MIN + i);
+	}
+
+	err = aq_hw_err_from_flags(self);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_a0_hw_interrupt_moderation_set(struct aq_hw_s *self)
+{
+	unsigned int i = 0U;
+	u32 itr_rx;
+
+	if (self->aq_nic_cfg->itr) {
+		if (self->aq_nic_cfg->itr != AQ_CFG_INTERRUPT_MODERATION_AUTO) {
+			u32 itr_ = (self->aq_nic_cfg->itr >> 1);
+
+			itr_ = min(AQ_CFG_IRQ_MASK, itr_);
+
+			itr_rx = 0x80000000U | (itr_ << 0x10);
+		} else  {
+			u32 n = 0xFFFFU & aq_hw_read_reg(self, 0x00002A00U);
+
+			if (n < self->aq_link_status.mbps) {
+				itr_rx = 0U;
+			} else {
+				static unsigned int hw_timers_tbl_[] = {
+					0x01CU, /* 10Gbit */
+					0x039U, /* 5Gbit */
+					0x039U, /* 5Gbit 5GS */
+					0x073U, /* 2.5Gbit */
+					0x120U, /* 1Gbit */
+					0x1FFU, /* 100Mbit */
+				};
+
+				unsigned int speed_index =
+					hw_atl_utils_mbps_2_speed_index(
+						self->aq_link_status.mbps);
+
+				itr_rx = 0x80000000U |
+					(hw_timers_tbl_[speed_index] << 0x10U);
+			}
+
+			aq_hw_write_reg(self, 0x00002A00U, 0x40000000U);
+			aq_hw_write_reg(self, 0x00002A00U, 0x8D000000U);
+		}
+	} else {
+		itr_rx = 0U;
+	}
+
+	for (i = HW_ATL_A0_RINGS_MAX; i--;)
+		hw_atl_reg_irq_thr_set(self, itr_rx, i);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_stop(struct aq_hw_s *self)
+{
+	hw_atl_a0_hw_irq_disable(self, HW_ATL_A0_INT_MASK);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_ring_tx_stop(struct aq_hw_s *self,
+				     struct aq_ring_s *ring)
+{
+	hw_atl_tdm_tx_desc_en_set(self, 0U, ring->idx);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_a0_hw_ring_rx_stop(struct aq_hw_s *self,
+				     struct aq_ring_s *ring)
+{
+	hw_atl_rdm_rx_desc_en_set(self, 0U, ring->idx);
+	return aq_hw_err_from_flags(self);
+}
+
+const struct aq_hw_ops hw_atl_ops_a0 = {
+	.hw_set_mac_address   = hw_atl_a0_hw_mac_addr_set,
+	.hw_init              = hw_atl_a0_hw_init,
+	.hw_reset             = hw_atl_a0_hw_reset,
+	.hw_start             = hw_atl_a0_hw_start,
+	.hw_ring_tx_start     = hw_atl_a0_hw_ring_tx_start,
+	.hw_ring_tx_stop      = hw_atl_a0_hw_ring_tx_stop,
+	.hw_ring_rx_start     = hw_atl_a0_hw_ring_rx_start,
+	.hw_ring_rx_stop      = hw_atl_a0_hw_ring_rx_stop,
+	.hw_stop              = hw_atl_a0_hw_stop,
+
+	.hw_ring_tx_xmit         = hw_atl_a0_hw_ring_tx_xmit,
+	.hw_ring_tx_head_update  = hw_atl_a0_hw_ring_tx_head_update,
+
+	.hw_ring_rx_receive      = hw_atl_a0_hw_ring_rx_receive,
+	.hw_ring_rx_fill         = hw_atl_a0_hw_ring_rx_fill,
+
+	.hw_irq_enable           = hw_atl_a0_hw_irq_enable,
+	.hw_irq_disable          = hw_atl_a0_hw_irq_disable,
+	.hw_irq_read             = hw_atl_a0_hw_irq_read,
+
+	.hw_ring_rx_init             = hw_atl_a0_hw_ring_rx_init,
+	.hw_ring_tx_init             = hw_atl_a0_hw_ring_tx_init,
+	.hw_packet_filter_set        = hw_atl_a0_hw_packet_filter_set,
+	.hw_multicast_list_set       = hw_atl_a0_hw_multicast_list_set,
+	.hw_interrupt_moderation_set = hw_atl_a0_hw_interrupt_moderation_set,
+	.hw_rss_set                  = hw_atl_a0_hw_rss_set,
+	.hw_rss_hash_set             = hw_atl_a0_hw_rss_hash_set,
+	.hw_get_regs                 = hw_atl_utils_hw_get_regs,
+	.hw_get_hw_stats             = hw_atl_utils_get_hw_stats,
+	.hw_get_fw_version           = hw_atl_utils_get_fw_version,
+};
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_a0.h b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_a0.h
new file mode 100644
index 00000000..25fe954
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_a0.h
@@ -0,0 +1,26 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_a0.h: Declaration of abstract interface for Atlantic hardware
+ * specific functions.
+ */
+
+#ifndef HW_ATL_A0_H
+#define HW_ATL_A0_H
+
+#include "../aq_common.h"
+
+extern const struct aq_hw_caps_s hw_atl_a0_caps_aqc100;
+extern const struct aq_hw_caps_s hw_atl_a0_caps_aqc107;
+extern const struct aq_hw_caps_s hw_atl_a0_caps_aqc108;
+extern const struct aq_hw_caps_s hw_atl_a0_caps_aqc109;
+
+extern const struct aq_hw_ops hw_atl_ops_a0;
+
+#endif /* HW_ATL_A0_H */
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_a0_internal.h b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_a0_internal.h
new file mode 100644
index 00000000..a021dc4
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_a0_internal.h
@@ -0,0 +1,93 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_a0_internal.h: Definition of Atlantic A0 chip specific
+ * constants.
+ */
+
+#ifndef HW_ATL_A0_INTERNAL_H
+#define HW_ATL_A0_INTERNAL_H
+
+#include "../aq_common.h"
+
+#define HW_ATL_A0_MTU_JUMBO 9014U
+
+#define HW_ATL_A0_TX_RINGS 4U
+#define HW_ATL_A0_RX_RINGS 4U
+
+#define HW_ATL_A0_RINGS_MAX 32U
+#define HW_ATL_A0_TXD_SIZE  16U
+#define HW_ATL_A0_RXD_SIZE  16U
+
+#define HW_ATL_A0_MAC      0U
+#define HW_ATL_A0_MAC_MIN  1U
+#define HW_ATL_A0_MAC_MAX  33U
+
+/* interrupts */
+#define HW_ATL_A0_ERR_INT 8U
+#define HW_ATL_A0_INT_MASK  0xFFFFFFFFU
+
+#define HW_ATL_A0_TXD_CTL2_LEN        0xFFFFC000U
+#define HW_ATL_A0_TXD_CTL2_CTX_EN     0x00002000U
+#define HW_ATL_A0_TXD_CTL2_CTX_IDX    0x00001000U
+
+#define HW_ATL_A0_TXD_CTL_DESC_TYPE_TXD   0x00000001U
+#define HW_ATL_A0_TXD_CTL_DESC_TYPE_TXC   0x00000002U
+#define HW_ATL_A0_TXD_CTL_BLEN        0x000FFFF0U
+#define HW_ATL_A0_TXD_CTL_DD          0x00100000U
+#define HW_ATL_A0_TXD_CTL_EOP         0x00200000U
+
+#define HW_ATL_A0_TXD_CTL_CMD_X       0x3FC00000U
+
+#define HW_ATL_A0_TXD_CTL_CMD_VLAN    BIT(22)
+#define HW_ATL_A0_TXD_CTL_CMD_FCS     BIT(23)
+#define HW_ATL_A0_TXD_CTL_CMD_IPCSO   BIT(24)
+#define HW_ATL_A0_TXD_CTL_CMD_TUCSO   BIT(25)
+#define HW_ATL_A0_TXD_CTL_CMD_LSO     BIT(26)
+#define HW_ATL_A0_TXD_CTL_CMD_WB      BIT(27)
+#define HW_ATL_A0_TXD_CTL_CMD_VXLAN   BIT(28)
+
+#define HW_ATL_A0_TXD_CTL_CMD_IPV6    BIT(21)
+#define HW_ATL_A0_TXD_CTL_CMD_TCP     BIT(22)
+
+#define HW_ATL_A0_MPI_CONTROL_ADR     0x0368U
+#define HW_ATL_A0_MPI_STATE_ADR       0x036CU
+
+#define HW_ATL_A0_MPI_SPEED_MSK       0xFFFFU
+#define HW_ATL_A0_MPI_SPEED_SHIFT     16U
+
+#define HW_ATL_A0_TXBUF_MAX 160U
+#define HW_ATL_A0_RXBUF_MAX 320U
+
+#define HW_ATL_A0_RSS_REDIRECTION_MAX 64U
+#define HW_ATL_A0_RSS_REDIRECTION_BITS 3U
+
+#define HW_ATL_A0_TC_MAX 1U
+#define HW_ATL_A0_RSS_MAX 8U
+
+#define HW_ATL_A0_FW_SEMA_RAM           0x2U
+
+#define HW_ATL_A0_RXD_DD    0x1U
+#define HW_ATL_A0_RXD_NCEA0 0x1U
+
+#define HW_ATL_A0_RXD_WB_STAT2_EOP     0x0002U
+
+#define HW_ATL_A0_UCP_0X370_REG  0x370U
+
+#define HW_ATL_A0_FW_VER_EXPECTED 0x01050006U
+
+#define HW_ATL_A0_MIN_RXD \
+	(ALIGN(AQ_CFG_SKB_FRAGS_MAX + 1U, AQ_HW_RXD_MULTIPLE))
+#define HW_ATL_A0_MIN_TXD \
+	(ALIGN(AQ_CFG_SKB_FRAGS_MAX + 1U, AQ_HW_TXD_MULTIPLE))
+
+#define HW_ATL_A0_MAX_RXD 8184U
+#define HW_ATL_A0_MAX_TXD 8184U
+
+#endif /* HW_ATL_A0_INTERNAL_H */
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_b0.c b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_b0.c
new file mode 100644
index 00000000..5c5534b
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_b0.c
@@ -0,0 +1,974 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_b0.c: Definition of Atlantic hardware specific functions. */
+
+#include "../aq_hw.h"
+#include "../aq_hw_utils.h"
+#include "../aq_ring.h"
+#include "../aq_nic.h"
+#include "hw_atl_b0.h"
+#include "hw_atl_utils.h"
+#include "hw_atl_llh.h"
+#include "hw_atl_b0_internal.h"
+#include "hw_atl_llh_internal.h"
+
+#define DEFAULT_B0_BOARD_BASIC_CAPABILITIES \
+	.is_64_dma = true,		  \
+	.msix_irqs = 4U,		  \
+	.irq_mask = ~0U,		  \
+	.vecs = HW_ATL_B0_RSS_MAX,	  \
+	.tcs = HW_ATL_B0_TC_MAX,	  \
+	.rxd_alignment = 1U,		  \
+	.rxd_size = HW_ATL_B0_RXD_SIZE,   \
+	.rxds_max = HW_ATL_B0_MAX_RXD,    \
+	.rxds_min = HW_ATL_B0_MIN_RXD,    \
+	.txd_alignment = 1U,		  \
+	.txd_size = HW_ATL_B0_TXD_SIZE,   \
+	.txds_max = HW_ATL_B0_MAX_TXD,    \
+	.txds_min = HW_ATL_B0_MIN_TXD,    \
+	.txhwb_alignment = 4096U,	  \
+	.tx_rings = HW_ATL_B0_TX_RINGS,   \
+	.rx_rings = HW_ATL_B0_RX_RINGS,   \
+	.hw_features = NETIF_F_HW_CSUM |  \
+			NETIF_F_RXCSUM |  \
+			NETIF_F_RXHASH |  \
+			NETIF_F_SG |      \
+			NETIF_F_TSO |     \
+			NETIF_F_LRO,      \
+	.hw_priv_flags = IFF_UNICAST_FLT, \
+	.flow_control = true,		  \
+	.mtu = HW_ATL_B0_MTU_JUMBO,	  \
+	.mac_regs_count = 88,		  \
+	.hw_alive_check_addr = 0x10U
+
+const struct aq_hw_caps_s hw_atl_b0_caps_aqc100 = {
+	DEFAULT_B0_BOARD_BASIC_CAPABILITIES,
+	.media_type = AQ_HW_MEDIA_TYPE_FIBRE,
+	.link_speed_msk = AQ_NIC_RATE_10G|
+			  AQ_NIC_RATE_5G|
+			  AQ_NIC_RATE_2GS|
+			  AQ_NIC_RATE_1G|
+			  AQ_NIC_RATE_100M,
+};
+
+const struct aq_hw_caps_s hw_atl_b0_caps_aqc107 = {
+	DEFAULT_B0_BOARD_BASIC_CAPABILITIES,
+	.media_type = AQ_HW_MEDIA_TYPE_TP,
+	.link_speed_msk = AQ_NIC_RATE_10G|
+			  AQ_NIC_RATE_5G|
+			  AQ_NIC_RATE_2GS|
+			  AQ_NIC_RATE_1G|
+			  AQ_NIC_RATE_100M,
+};
+
+const struct aq_hw_caps_s hw_atl_b0_caps_aqc108 = {
+	DEFAULT_B0_BOARD_BASIC_CAPABILITIES,
+	.media_type = AQ_HW_MEDIA_TYPE_TP,
+	.link_speed_msk = AQ_NIC_RATE_5G|
+			  AQ_NIC_RATE_2GS|
+			  AQ_NIC_RATE_1G|
+			  AQ_NIC_RATE_100M,
+};
+
+const struct aq_hw_caps_s hw_atl_b0_caps_aqc109 = {
+	DEFAULT_B0_BOARD_BASIC_CAPABILITIES,
+	.media_type = AQ_HW_MEDIA_TYPE_TP,
+	.link_speed_msk = AQ_NIC_RATE_2GS |
+			  AQ_NIC_RATE_1G  |
+			  AQ_NIC_RATE_100M,
+};
+
+static int hw_atl_b0_hw_reset(struct aq_hw_s *self)
+{
+	int err = 0;
+
+	err = hw_atl_utils_soft_reset(self);
+	if (err)
+		return err;
+
+	self->aq_fw_ops->set_state(self, MPI_RESET);
+
+	err = aq_hw_err_from_flags(self);
+
+	return err;
+}
+
+static int hw_atl_b0_hw_qos_set(struct aq_hw_s *self)
+{
+	u32 tc = 0U;
+	u32 buff_size = 0U;
+	unsigned int i_priority = 0U;
+	bool is_rx_flow_control = false;
+
+	/* TPS Descriptor rate init */
+	hw_atl_tps_tx_pkt_shed_desc_rate_curr_time_res_set(self, 0x0U);
+	hw_atl_tps_tx_pkt_shed_desc_rate_lim_set(self, 0xA);
+
+	/* TPS VM init */
+	hw_atl_tps_tx_pkt_shed_desc_vm_arb_mode_set(self, 0U);
+
+	/* TPS TC credits init */
+	hw_atl_tps_tx_pkt_shed_desc_tc_arb_mode_set(self, 0U);
+	hw_atl_tps_tx_pkt_shed_data_arb_mode_set(self, 0U);
+
+	hw_atl_tps_tx_pkt_shed_tc_data_max_credit_set(self, 0xFFF, 0U);
+	hw_atl_tps_tx_pkt_shed_tc_data_weight_set(self, 0x64, 0U);
+	hw_atl_tps_tx_pkt_shed_desc_tc_max_credit_set(self, 0x50, 0U);
+	hw_atl_tps_tx_pkt_shed_desc_tc_weight_set(self, 0x1E, 0U);
+
+	/* Tx buf size */
+	buff_size = HW_ATL_B0_TXBUF_MAX;
+
+	hw_atl_tpb_tx_pkt_buff_size_per_tc_set(self, buff_size, tc);
+	hw_atl_tpb_tx_buff_hi_threshold_per_tc_set(self,
+						   (buff_size *
+						   (1024 / 32U) * 66U) /
+						   100U, tc);
+	hw_atl_tpb_tx_buff_lo_threshold_per_tc_set(self,
+						   (buff_size *
+						   (1024 / 32U) * 50U) /
+						   100U, tc);
+
+	/* QoS Rx buf size per TC */
+	tc = 0;
+	is_rx_flow_control = (AQ_NIC_FC_RX & self->aq_nic_cfg->flow_control);
+	buff_size = HW_ATL_B0_RXBUF_MAX;
+
+	hw_atl_rpb_rx_pkt_buff_size_per_tc_set(self, buff_size, tc);
+	hw_atl_rpb_rx_buff_hi_threshold_per_tc_set(self,
+						   (buff_size *
+						   (1024U / 32U) * 66U) /
+						   100U, tc);
+	hw_atl_rpb_rx_buff_lo_threshold_per_tc_set(self,
+						   (buff_size *
+						   (1024U / 32U) * 50U) /
+						   100U, tc);
+	hw_atl_rpb_rx_xoff_en_per_tc_set(self, is_rx_flow_control ? 1U : 0U, tc);
+
+	/* QoS 802.1p priority -> TC mapping */
+	for (i_priority = 8U; i_priority--;)
+		hw_atl_rpf_rpb_user_priority_tc_map_set(self, i_priority, 0U);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_rss_hash_set(struct aq_hw_s *self,
+				     struct aq_rss_parameters *rss_params)
+{
+	struct aq_nic_cfg_s *cfg = self->aq_nic_cfg;
+	int err = 0;
+	unsigned int i = 0U;
+	unsigned int addr = 0U;
+
+	for (i = 10, addr = 0U; i--; ++addr) {
+		u32 key_data = cfg->is_rss ?
+			__swab32(rss_params->hash_secret_key[i]) : 0U;
+		hw_atl_rpf_rss_key_wr_data_set(self, key_data);
+		hw_atl_rpf_rss_key_addr_set(self, addr);
+		hw_atl_rpf_rss_key_wr_en_set(self, 1U);
+		AQ_HW_WAIT_FOR(hw_atl_rpf_rss_key_wr_en_get(self) == 0,
+			       1000U, 10U);
+		if (err < 0)
+			goto err_exit;
+	}
+
+	err = aq_hw_err_from_flags(self);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_b0_hw_rss_set(struct aq_hw_s *self,
+				struct aq_rss_parameters *rss_params)
+{
+	u8 *indirection_table =	rss_params->indirection_table;
+	u32 i = 0U;
+	u32 num_rss_queues = max(1U, self->aq_nic_cfg->num_rss_queues);
+	int err = 0;
+	u16 bitary[(HW_ATL_B0_RSS_REDIRECTION_MAX *
+					HW_ATL_B0_RSS_REDIRECTION_BITS / 16U)];
+
+	memset(bitary, 0, sizeof(bitary));
+
+	for (i = HW_ATL_B0_RSS_REDIRECTION_MAX; i--;) {
+		(*(u32 *)(bitary + ((i * 3U) / 16U))) |=
+			((indirection_table[i] % num_rss_queues) <<
+			((i * 3U) & 0xFU));
+	}
+
+	for (i = ARRAY_SIZE(bitary); i--;) {
+		hw_atl_rpf_rss_redir_tbl_wr_data_set(self, bitary[i]);
+		hw_atl_rpf_rss_redir_tbl_addr_set(self, i);
+		hw_atl_rpf_rss_redir_wr_en_set(self, 1U);
+		AQ_HW_WAIT_FOR(hw_atl_rpf_rss_redir_wr_en_get(self) == 0,
+			       1000U, 10U);
+		if (err < 0)
+			goto err_exit;
+	}
+
+	err = aq_hw_err_from_flags(self);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_b0_hw_offload_set(struct aq_hw_s *self,
+				    struct aq_nic_cfg_s *aq_nic_cfg)
+{
+	unsigned int i;
+
+	/* TX checksums offloads*/
+	hw_atl_tpo_ipv4header_crc_offload_en_set(self, 1);
+	hw_atl_tpo_tcp_udp_crc_offload_en_set(self, 1);
+
+	/* RX checksums offloads*/
+	hw_atl_rpo_ipv4header_crc_offload_en_set(self, 1);
+	hw_atl_rpo_tcp_udp_crc_offload_en_set(self, 1);
+
+	/* LSO offloads*/
+	hw_atl_tdm_large_send_offload_en_set(self, 0xFFFFFFFFU);
+
+/* LRO offloads */
+	{
+		unsigned int val = (8U < HW_ATL_B0_LRO_RXD_MAX) ? 0x3U :
+			((4U < HW_ATL_B0_LRO_RXD_MAX) ? 0x2U :
+			((2U < HW_ATL_B0_LRO_RXD_MAX) ? 0x1U : 0x0));
+
+		for (i = 0; i < HW_ATL_B0_RINGS_MAX; i++)
+			hw_atl_rpo_lro_max_num_of_descriptors_set(self, val, i);
+
+		hw_atl_rpo_lro_time_base_divider_set(self, 0x61AU);
+		hw_atl_rpo_lro_inactive_interval_set(self, 0);
+		hw_atl_rpo_lro_max_coalescing_interval_set(self, 2);
+
+		hw_atl_rpo_lro_qsessions_lim_set(self, 1U);
+
+		hw_atl_rpo_lro_total_desc_lim_set(self, 2U);
+
+		hw_atl_rpo_lro_patch_optimization_en_set(self, 0U);
+
+		hw_atl_rpo_lro_min_pay_of_first_pkt_set(self, 10U);
+
+		hw_atl_rpo_lro_pkt_lim_set(self, 1U);
+
+		hw_atl_rpo_lro_en_set(self,
+				      aq_nic_cfg->is_lro ? 0xFFFFFFFFU : 0U);
+	}
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_init_tx_path(struct aq_hw_s *self)
+{
+	hw_atl_thm_lso_tcp_flag_of_first_pkt_set(self, 0x0FF6U);
+	hw_atl_thm_lso_tcp_flag_of_middle_pkt_set(self, 0x0FF6U);
+	hw_atl_thm_lso_tcp_flag_of_last_pkt_set(self, 0x0F7FU);
+
+	/* Tx interrupts */
+	hw_atl_tdm_tx_desc_wr_wb_irq_en_set(self, 1U);
+
+	/* misc */
+	aq_hw_write_reg(self, 0x00007040U, IS_CHIP_FEATURE(TPO2) ?
+			0x00010000U : 0x00000000U);
+	hw_atl_tdm_tx_dca_en_set(self, 0U);
+	hw_atl_tdm_tx_dca_mode_set(self, 0U);
+
+	hw_atl_tpb_tx_path_scp_ins_en_set(self, 1U);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_init_rx_path(struct aq_hw_s *self)
+{
+	struct aq_nic_cfg_s *cfg = self->aq_nic_cfg;
+	unsigned int control_reg_val = 0U;
+	int i;
+
+	/* Rx TC/RSS number config */
+	hw_atl_rpb_rpf_rx_traf_class_mode_set(self, 1U);
+
+	/* Rx flow control */
+	hw_atl_rpb_rx_flow_ctl_mode_set(self, 1U);
+
+	/* RSS Ring selection */
+	hw_atl_reg_rx_flr_rss_control1set(self, cfg->is_rss ?
+					0xB3333333U : 0x00000000U);
+
+	/* Multicast filters */
+	for (i = HW_ATL_B0_MAC_MAX; i--;) {
+		hw_atl_rpfl2_uc_flr_en_set(self, (i == 0U) ? 1U : 0U, i);
+		hw_atl_rpfl2unicast_flr_act_set(self, 1U, i);
+	}
+
+	hw_atl_reg_rx_flr_mcst_flr_msk_set(self, 0x00000000U);
+	hw_atl_reg_rx_flr_mcst_flr_set(self, 0x00010FFFU, 0U);
+
+	/* Vlan filters */
+	hw_atl_rpf_vlan_outer_etht_set(self, 0x88A8U);
+	hw_atl_rpf_vlan_inner_etht_set(self, 0x8100U);
+
+	if (cfg->vlan_id) {
+		hw_atl_rpf_vlan_flr_act_set(self, 1U, 0U);
+		hw_atl_rpf_vlan_id_flr_set(self, 0U, 0U);
+		hw_atl_rpf_vlan_flr_en_set(self, 0U, 0U);
+
+		hw_atl_rpf_vlan_accept_untagged_packets_set(self, 1U);
+		hw_atl_rpf_vlan_untagged_act_set(self, 1U);
+
+		hw_atl_rpf_vlan_flr_act_set(self, 1U, 1U);
+		hw_atl_rpf_vlan_id_flr_set(self, cfg->vlan_id, 0U);
+		hw_atl_rpf_vlan_flr_en_set(self, 1U, 1U);
+	} else {
+		hw_atl_rpf_vlan_prom_mode_en_set(self, 1);
+	}
+
+	/* Rx Interrupts */
+	hw_atl_rdm_rx_desc_wr_wb_irq_en_set(self, 1U);
+
+	/* misc */
+	control_reg_val = IS_CHIP_FEATURE(RPF2) ? 0x000F0000U : 0x00000000U;
+
+	/* RSS hash type set for IP/TCP */
+	control_reg_val |= 0x1EU;
+
+	aq_hw_write_reg(self, 0x00005040U, control_reg_val);	
+
+	hw_atl_rpfl2broadcast_flr_act_set(self, 1U);
+	hw_atl_rpfl2broadcast_count_threshold_set(self, 0xFFFFU & (~0U / 256U));
+
+	hw_atl_rdm_rx_dca_en_set(self, 0U);
+	hw_atl_rdm_rx_dca_mode_set(self, 0U);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_mac_addr_set(struct aq_hw_s *self, u8 *mac_addr)
+{
+	int err = 0;
+	unsigned int h = 0U;
+	unsigned int l = 0U;
+
+	if (!mac_addr) {
+		err = -EINVAL;
+		goto err_exit;
+	}
+	h = (mac_addr[0] << 8) | (mac_addr[1]);
+	l = (mac_addr[2] << 24) | (mac_addr[3] << 16) |
+		(mac_addr[4] << 8) | mac_addr[5];
+
+	hw_atl_rpfl2_uc_flr_en_set(self, 0U, HW_ATL_B0_MAC);
+	hw_atl_rpfl2unicast_dest_addresslsw_set(self, l, HW_ATL_B0_MAC);
+	hw_atl_rpfl2unicast_dest_addressmsw_set(self, h, HW_ATL_B0_MAC);
+	hw_atl_rpfl2_uc_flr_en_set(self, 1U, HW_ATL_B0_MAC);
+
+	err = aq_hw_err_from_flags(self);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_b0_hw_init(struct aq_hw_s *self, u8 *mac_addr)
+{
+	static u32 aq_hw_atl_igcr_table_[4][2] = {
+		{ 0x20000000U, 0x20000000U }, /* AQ_IRQ_INVALID */
+		{ 0x20000080U, 0x20000080U }, /* AQ_IRQ_LEGACY */
+		{ 0x20000021U, 0x20000025U }, /* AQ_IRQ_MSI */
+		{ 0x20000022U, 0x20000026U }  /* AQ_IRQ_MSIX */
+	};
+
+	int err = 0;
+	u32 val;
+
+	struct aq_nic_cfg_s *aq_nic_cfg = self->aq_nic_cfg;
+
+	hw_atl_b0_hw_init_tx_path(self);
+	hw_atl_b0_hw_init_rx_path(self);
+
+	hw_atl_b0_hw_mac_addr_set(self, mac_addr);
+
+	self->aq_fw_ops->set_link_speed(self, aq_nic_cfg->link_speed_msk);
+	self->aq_fw_ops->set_state(self, MPI_INIT);
+
+	hw_atl_b0_hw_qos_set(self);
+	hw_atl_b0_hw_rss_set(self, &aq_nic_cfg->aq_rss);
+	hw_atl_b0_hw_rss_hash_set(self, &aq_nic_cfg->aq_rss);
+
+	/* Force limit MRRS on RDM/TDM to 2K */
+	val = aq_hw_read_reg(self, HW_ATL_PCI_REG_CONTROL6_ADR);
+	aq_hw_write_reg(self, HW_ATL_PCI_REG_CONTROL6_ADR,
+			(val & ~0x707) | 0x404);
+
+	/* TX DMA total request limit. B0 hardware is not capable to
+	 * handle more than (8K-MRRS) incoming DMA data.
+	 * Value 24 in 256byte units
+	 */
+	aq_hw_write_reg(self, HW_ATL_TX_DMA_TOTAL_REQ_LIMIT_ADR, 24);
+
+	/* Reset link status and read out initial hardware counters */
+	self->aq_link_status.mbps = 0;
+	self->aq_fw_ops->update_stats(self);
+
+	err = aq_hw_err_from_flags(self);
+	if (err < 0)
+		goto err_exit;
+
+	/* Interrupts */
+	hw_atl_reg_irq_glb_ctl_set(self,
+				   aq_hw_atl_igcr_table_[aq_nic_cfg->irq_type]
+						 [(aq_nic_cfg->vecs > 1U) ?
+						 1 : 0]);
+
+	hw_atl_itr_irq_auto_masklsw_set(self, aq_nic_cfg->aq_hw_caps->irq_mask);
+
+	/* Interrupts */
+	hw_atl_reg_gen_irq_map_set(self,
+				   ((HW_ATL_B0_ERR_INT << 0x18) | (1U << 0x1F)) |
+			    ((HW_ATL_B0_ERR_INT << 0x10) | (1U << 0x17)), 0U);
+
+	hw_atl_b0_hw_offload_set(self, aq_nic_cfg);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_b0_hw_ring_tx_start(struct aq_hw_s *self,
+				      struct aq_ring_s *ring)
+{
+	hw_atl_tdm_tx_desc_en_set(self, 1, ring->idx);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_ring_rx_start(struct aq_hw_s *self,
+				      struct aq_ring_s *ring)
+{
+	hw_atl_rdm_rx_desc_en_set(self, 1, ring->idx);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_start(struct aq_hw_s *self)
+{
+	hw_atl_tpb_tx_buff_en_set(self, 1);
+	hw_atl_rpb_rx_buff_en_set(self, 1);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_tx_ring_tail_update(struct aq_hw_s *self,
+					    struct aq_ring_s *ring)
+{
+	hw_atl_reg_tx_dma_desc_tail_ptr_set(self, ring->sw_tail, ring->idx);
+	return 0;
+}
+
+static int hw_atl_b0_hw_ring_tx_xmit(struct aq_hw_s *self,
+				     struct aq_ring_s *ring,
+				     unsigned int frags)
+{
+	struct aq_ring_buff_s *buff = NULL;
+	struct hw_atl_txd_s *txd = NULL;
+	unsigned int buff_pa_len = 0U;
+	unsigned int pkt_len = 0U;
+	unsigned int frag_count = 0U;
+	bool is_gso = false;
+
+	buff = &ring->buff_ring[ring->sw_tail];
+	pkt_len = (buff->is_eop && buff->is_sop) ? buff->len : buff->len_pkt;
+
+	for (frag_count = 0; frag_count < frags; frag_count++) {
+		txd = (struct hw_atl_txd_s *)&ring->dx_ring[ring->sw_tail *
+						HW_ATL_B0_TXD_SIZE];
+		txd->ctl = 0;
+		txd->ctl2 = 0;
+		txd->buf_addr = 0;
+
+		buff = &ring->buff_ring[ring->sw_tail];
+
+		if (buff->is_txc) {
+			txd->ctl |= (buff->len_l3 << 31) |
+				(buff->len_l2 << 24) |
+				HW_ATL_B0_TXD_CTL_CMD_TCP |
+				HW_ATL_B0_TXD_CTL_DESC_TYPE_TXC;
+			txd->ctl2 |= (buff->mss << 16) |
+				(buff->len_l4 << 8) |
+				(buff->len_l3 >> 1);
+
+			pkt_len -= (buff->len_l4 +
+				    buff->len_l3 +
+				    buff->len_l2);
+			is_gso = true;
+
+			if (buff->is_ipv6)
+				txd->ctl |= HW_ATL_B0_TXD_CTL_CMD_IPV6;
+		} else {
+			buff_pa_len = buff->len;
+
+			txd->buf_addr = buff->pa;
+			txd->ctl |= (HW_ATL_B0_TXD_CTL_BLEN &
+						((u32)buff_pa_len << 4));
+			txd->ctl |= HW_ATL_B0_TXD_CTL_DESC_TYPE_TXD;
+			/* PAY_LEN */
+			txd->ctl2 |= HW_ATL_B0_TXD_CTL2_LEN & (pkt_len << 14);
+
+			if (is_gso) {
+				txd->ctl |= HW_ATL_B0_TXD_CTL_CMD_LSO;
+				txd->ctl2 |= HW_ATL_B0_TXD_CTL2_CTX_EN;
+			}
+
+			/* Tx checksum offloads */
+			if (buff->is_ip_cso)
+				txd->ctl |= HW_ATL_B0_TXD_CTL_CMD_IPCSO;
+
+			if (buff->is_udp_cso || buff->is_tcp_cso)
+				txd->ctl |= HW_ATL_B0_TXD_CTL_CMD_TUCSO;
+
+			if (unlikely(buff->is_eop)) {
+				txd->ctl |= HW_ATL_B0_TXD_CTL_EOP;
+				txd->ctl |= HW_ATL_B0_TXD_CTL_CMD_WB;
+				is_gso = false;
+			}
+		}
+
+		ring->sw_tail = aq_ring_next_dx(ring, ring->sw_tail);
+	}
+
+	wmb();
+
+	hw_atl_b0_hw_tx_ring_tail_update(self, ring);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_ring_rx_init(struct aq_hw_s *self,
+				     struct aq_ring_s *aq_ring,
+				     struct aq_ring_param_s *aq_ring_param)
+{
+	u32 dma_desc_addr_lsw = (u32)aq_ring->dx_ring_pa;
+	u32 dma_desc_addr_msw = (u32)(((u64)aq_ring->dx_ring_pa) >> 32);
+
+	hw_atl_rdm_rx_desc_en_set(self, false, aq_ring->idx);
+
+	hw_atl_rdm_rx_desc_head_splitting_set(self, 0U, aq_ring->idx);
+
+	hw_atl_reg_rx_dma_desc_base_addresslswset(self, dma_desc_addr_lsw,
+						  aq_ring->idx);
+
+	hw_atl_reg_rx_dma_desc_base_addressmswset(self,
+						  dma_desc_addr_msw, aq_ring->idx);
+
+	hw_atl_rdm_rx_desc_len_set(self, aq_ring->size / 8U, aq_ring->idx);
+
+	hw_atl_rdm_rx_desc_data_buff_size_set(self,
+					      AQ_CFG_RX_FRAME_MAX / 1024U,
+				       aq_ring->idx);
+
+	hw_atl_rdm_rx_desc_head_buff_size_set(self, 0U, aq_ring->idx);
+	hw_atl_rdm_rx_desc_head_splitting_set(self, 0U, aq_ring->idx);
+	hw_atl_rpo_rx_desc_vlan_stripping_set(self, 0U, aq_ring->idx);
+
+	/* Rx ring set mode */
+
+	/* Mapping interrupt vector */
+	hw_atl_itr_irq_map_rx_set(self, aq_ring_param->vec_idx, aq_ring->idx);
+	hw_atl_itr_irq_map_en_rx_set(self, true, aq_ring->idx);
+
+	hw_atl_rdm_cpu_id_set(self, aq_ring_param->cpu, aq_ring->idx);
+	hw_atl_rdm_rx_desc_dca_en_set(self, 0U, aq_ring->idx);
+	hw_atl_rdm_rx_head_dca_en_set(self, 0U, aq_ring->idx);
+	hw_atl_rdm_rx_pld_dca_en_set(self, 0U, aq_ring->idx);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_ring_tx_init(struct aq_hw_s *self,
+				     struct aq_ring_s *aq_ring,
+				     struct aq_ring_param_s *aq_ring_param)
+{
+	u32 dma_desc_lsw_addr = (u32)aq_ring->dx_ring_pa;
+	u32 dma_desc_msw_addr = (u32)(((u64)aq_ring->dx_ring_pa) >> 32);
+
+	hw_atl_reg_tx_dma_desc_base_addresslswset(self, dma_desc_lsw_addr,
+						  aq_ring->idx);
+
+	hw_atl_reg_tx_dma_desc_base_addressmswset(self, dma_desc_msw_addr,
+						  aq_ring->idx);
+
+	hw_atl_tdm_tx_desc_len_set(self, aq_ring->size / 8U, aq_ring->idx);
+
+	hw_atl_b0_hw_tx_ring_tail_update(self, aq_ring);
+
+	/* Set Tx threshold */
+	hw_atl_tdm_tx_desc_wr_wb_threshold_set(self, 0U, aq_ring->idx);
+
+	/* Mapping interrupt vector */
+	hw_atl_itr_irq_map_tx_set(self, aq_ring_param->vec_idx, aq_ring->idx);
+	hw_atl_itr_irq_map_en_tx_set(self, true, aq_ring->idx);
+
+	hw_atl_tdm_cpu_id_set(self, aq_ring_param->cpu, aq_ring->idx);
+	hw_atl_tdm_tx_desc_dca_en_set(self, 0U, aq_ring->idx);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_ring_rx_fill(struct aq_hw_s *self,
+				     struct aq_ring_s *ring,
+				     unsigned int sw_tail_old)
+{
+	for (; sw_tail_old != ring->sw_tail;
+		sw_tail_old = aq_ring_next_dx(ring, sw_tail_old)) {
+		struct hw_atl_rxd_s *rxd =
+			(struct hw_atl_rxd_s *)&ring->dx_ring[sw_tail_old *
+							HW_ATL_B0_RXD_SIZE];
+
+		struct aq_ring_buff_s *buff = &ring->buff_ring[sw_tail_old];
+
+		rxd->buf_addr = buff->pa;
+		rxd->hdr_addr = 0U;
+	}
+
+	wmb();
+
+	hw_atl_reg_rx_dma_desc_tail_ptr_set(self, sw_tail_old, ring->idx);
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_ring_tx_head_update(struct aq_hw_s *self,
+					    struct aq_ring_s *ring)
+{
+	int err = 0;
+	unsigned int hw_head_ = hw_atl_tdm_tx_desc_head_ptr_get(self, ring->idx);
+
+	if (aq_utils_obj_test(&self->flags, AQ_HW_FLAG_ERR_UNPLUG)) {
+		err = -ENXIO;
+		goto err_exit;
+	}
+	ring->hw_head = hw_head_;
+	err = aq_hw_err_from_flags(self);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_b0_hw_ring_rx_receive(struct aq_hw_s *self,
+					struct aq_ring_s *ring)
+{
+	for (; ring->hw_head != ring->sw_tail;
+		ring->hw_head = aq_ring_next_dx(ring, ring->hw_head)) {
+		struct aq_ring_buff_s *buff = NULL;
+		struct hw_atl_rxd_wb_s *rxd_wb = (struct hw_atl_rxd_wb_s *)
+			&ring->dx_ring[ring->hw_head * HW_ATL_B0_RXD_SIZE];
+
+		unsigned int is_err = 1U;
+		unsigned int is_rx_check_sum_enabled = 0U;
+		unsigned int pkt_type = 0U;
+
+		if (!(rxd_wb->status & 0x1U)) { /* RxD is not done */
+			break;
+		}
+
+		buff = &ring->buff_ring[ring->hw_head];
+
+		is_err = (0x0000003CU & rxd_wb->status);
+
+		is_rx_check_sum_enabled = (rxd_wb->type) & (0x3U << 19);
+		is_err &= ~0x20U; /* exclude validity bit */
+
+		pkt_type = 0xFFU & (rxd_wb->type >> 4);
+
+		if (is_rx_check_sum_enabled) {
+			if (0x0U == (pkt_type & 0x3U))
+				buff->is_ip_cso = (is_err & 0x08U) ? 0U : 1U;
+
+			if (0x4U == (pkt_type & 0x1CU))
+				buff->is_udp_cso = buff->is_cso_err ? 0U : 1U;
+			else if (0x0U == (pkt_type & 0x1CU))
+				buff->is_tcp_cso = buff->is_cso_err ? 0U : 1U;
+
+			/* Checksum offload workaround for small packets */
+			if (rxd_wb->pkt_len <= 60) {
+				buff->is_ip_cso = 0U;
+				buff->is_cso_err = 0U;
+			}
+		}
+
+		is_err &= ~0x18U;
+
+		if (is_err || rxd_wb->type & 0x1000U) {
+			/* status error or DMA error */
+			buff->is_error = 1U;
+		} else {
+			if (self->aq_nic_cfg->is_rss) {
+				/* last 4 byte */
+				u16 rss_type = rxd_wb->type & 0xFU;
+
+				if (rss_type && rss_type < 0x8U) {
+					buff->is_hash_l4 = (rss_type == 0x4 ||
+					rss_type == 0x5);
+					buff->rss_hash = rxd_wb->rss_hash;
+				}
+			}
+
+			if (HW_ATL_B0_RXD_WB_STAT2_EOP & rxd_wb->status) {
+				buff->len = rxd_wb->pkt_len %
+					AQ_CFG_RX_FRAME_MAX;
+				buff->len = buff->len ?
+					buff->len : AQ_CFG_RX_FRAME_MAX;
+				buff->next = 0U;
+				buff->is_eop = 1U;
+			} else {
+				buff->len = rxd_wb->pkt_len > AQ_CFG_RX_FRAME_MAX ?
+					AQ_CFG_RX_FRAME_MAX : rxd_wb->pkt_len;
+
+				if (HW_ATL_B0_RXD_WB_STAT2_RSCCNT &
+					rxd_wb->status) {
+					/* LRO */
+					buff->next = rxd_wb->next_desc_ptr;
+					++ring->stats.rx.lro_packets;
+				} else {
+					/* jumbo */
+					buff->next =
+						aq_ring_next_dx(ring,
+								ring->hw_head);
+					++ring->stats.rx.jumbo_packets;
+				}
+			}
+		}
+	}
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_irq_enable(struct aq_hw_s *self, u64 mask)
+{
+	hw_atl_itr_irq_msk_setlsw_set(self, LODWORD(mask));
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_irq_disable(struct aq_hw_s *self, u64 mask)
+{
+	hw_atl_itr_irq_msk_clearlsw_set(self, LODWORD(mask));
+	hw_atl_itr_irq_status_clearlsw_set(self, LODWORD(mask));
+
+	atomic_inc(&self->dpc);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_irq_read(struct aq_hw_s *self, u64 *mask)
+{
+	*mask = hw_atl_itr_irq_statuslsw_get(self);
+	return aq_hw_err_from_flags(self);
+}
+
+#define IS_FILTER_ENABLED(_F_) ((packet_filter & (_F_)) ? 1U : 0U)
+
+static int hw_atl_b0_hw_packet_filter_set(struct aq_hw_s *self,
+					  unsigned int packet_filter)
+{
+	unsigned int i = 0U;
+
+	hw_atl_rpfl2promiscuous_mode_en_set(self, IS_FILTER_ENABLED(IFF_PROMISC));
+	hw_atl_rpfl2multicast_flr_en_set(self,
+					 IS_FILTER_ENABLED(IFF_MULTICAST), 0);
+
+	hw_atl_rpfl2_accept_all_mc_packets_set(self,
+					       IS_FILTER_ENABLED(IFF_ALLMULTI));
+
+	hw_atl_rpfl2broadcast_en_set(self, IS_FILTER_ENABLED(IFF_BROADCAST));
+
+	self->aq_nic_cfg->is_mc_list_enabled = IS_FILTER_ENABLED(IFF_MULTICAST);
+
+	for (i = HW_ATL_B0_MAC_MIN; i < HW_ATL_B0_MAC_MAX; ++i)
+		hw_atl_rpfl2_uc_flr_en_set(self,
+					   (self->aq_nic_cfg->is_mc_list_enabled &&
+				    (i <= self->aq_nic_cfg->mc_list_count)) ?
+				    1U : 0U, i);
+
+	return aq_hw_err_from_flags(self);
+}
+
+#undef IS_FILTER_ENABLED
+
+static int hw_atl_b0_hw_multicast_list_set(struct aq_hw_s *self,
+					   u8 ar_mac
+					   [AQ_CFG_MULTICAST_ADDRESS_MAX]
+					   [ETH_ALEN],
+					   u32 count)
+{
+	int err = 0;
+
+	if (count > (HW_ATL_B0_MAC_MAX - HW_ATL_B0_MAC_MIN)) {
+		err = -EBADRQC;
+		goto err_exit;
+	}
+	for (self->aq_nic_cfg->mc_list_count = 0U;
+			self->aq_nic_cfg->mc_list_count < count;
+			++self->aq_nic_cfg->mc_list_count) {
+		u32 i = self->aq_nic_cfg->mc_list_count;
+		u32 h = (ar_mac[i][0] << 8) | (ar_mac[i][1]);
+		u32 l = (ar_mac[i][2] << 24) | (ar_mac[i][3] << 16) |
+					(ar_mac[i][4] << 8) | ar_mac[i][5];
+
+		hw_atl_rpfl2_uc_flr_en_set(self, 0U, HW_ATL_B0_MAC_MIN + i);
+
+		hw_atl_rpfl2unicast_dest_addresslsw_set(self,
+							l, HW_ATL_B0_MAC_MIN + i);
+
+		hw_atl_rpfl2unicast_dest_addressmsw_set(self,
+							h, HW_ATL_B0_MAC_MIN + i);
+
+		hw_atl_rpfl2_uc_flr_en_set(self,
+					   (self->aq_nic_cfg->is_mc_list_enabled),
+				    HW_ATL_B0_MAC_MIN + i);
+	}
+
+	err = aq_hw_err_from_flags(self);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_b0_hw_interrupt_moderation_set(struct aq_hw_s *self)
+{
+	unsigned int i = 0U;
+	u32 itr_tx = 2U;
+	u32 itr_rx = 2U;
+
+	switch (self->aq_nic_cfg->itr) {
+	case  AQ_CFG_INTERRUPT_MODERATION_ON:
+	case  AQ_CFG_INTERRUPT_MODERATION_AUTO:
+		hw_atl_tdm_tx_desc_wr_wb_irq_en_set(self, 0U);
+		hw_atl_tdm_tdm_intr_moder_en_set(self, 1U);
+		hw_atl_rdm_rx_desc_wr_wb_irq_en_set(self, 0U);
+		hw_atl_rdm_rdm_intr_moder_en_set(self, 1U);
+
+		if (self->aq_nic_cfg->itr == AQ_CFG_INTERRUPT_MODERATION_ON) {
+			/* HW timers are in 2us units */
+			int tx_max_timer = self->aq_nic_cfg->tx_itr / 2;
+			int tx_min_timer = tx_max_timer / 2;
+
+			int rx_max_timer = self->aq_nic_cfg->rx_itr / 2;
+			int rx_min_timer = rx_max_timer / 2;
+
+			tx_max_timer = min(HW_ATL_INTR_MODER_MAX, tx_max_timer);
+			tx_min_timer = min(HW_ATL_INTR_MODER_MIN, tx_min_timer);
+			rx_max_timer = min(HW_ATL_INTR_MODER_MAX, rx_max_timer);
+			rx_min_timer = min(HW_ATL_INTR_MODER_MIN, rx_min_timer);
+
+			itr_tx |= tx_min_timer << 0x8U;
+			itr_tx |= tx_max_timer << 0x10U;
+			itr_rx |= rx_min_timer << 0x8U;
+			itr_rx |= rx_max_timer << 0x10U;
+		} else {
+			static unsigned int hw_atl_b0_timers_table_tx_[][2] = {
+				{0xfU, 0xffU}, /* 10Gbit */
+				{0xfU, 0x1ffU}, /* 5Gbit */
+				{0xfU, 0x1ffU}, /* 5Gbit 5GS */
+				{0xfU, 0x1ffU}, /* 2.5Gbit */
+				{0xfU, 0x1ffU}, /* 1Gbit */
+				{0xfU, 0x1ffU}, /* 100Mbit */
+			};
+
+			static unsigned int hw_atl_b0_timers_table_rx_[][2] = {
+				{0x6U, 0x38U},/* 10Gbit */
+				{0xCU, 0x70U},/* 5Gbit */
+				{0xCU, 0x70U},/* 5Gbit 5GS */
+				{0x18U, 0xE0U},/* 2.5Gbit */
+				{0x30U, 0x80U},/* 1Gbit */
+				{0x4U, 0x50U},/* 100Mbit */
+			};
+
+			unsigned int speed_index =
+					hw_atl_utils_mbps_2_speed_index(
+						self->aq_link_status.mbps);
+
+			/* Update user visible ITR settings */
+			self->aq_nic_cfg->tx_itr = hw_atl_b0_timers_table_tx_
+							[speed_index][1] * 2;
+			self->aq_nic_cfg->rx_itr = hw_atl_b0_timers_table_rx_
+							[speed_index][1] * 2;
+
+			itr_tx |= hw_atl_b0_timers_table_tx_
+						[speed_index][0] << 0x8U;
+			itr_tx |= hw_atl_b0_timers_table_tx_
+						[speed_index][1] << 0x10U;
+
+			itr_rx |= hw_atl_b0_timers_table_rx_
+						[speed_index][0] << 0x8U;
+			itr_rx |= hw_atl_b0_timers_table_rx_
+						[speed_index][1] << 0x10U;
+		}
+		break;
+	case AQ_CFG_INTERRUPT_MODERATION_OFF:
+		hw_atl_tdm_tx_desc_wr_wb_irq_en_set(self, 1U);
+		hw_atl_tdm_tdm_intr_moder_en_set(self, 0U);
+		hw_atl_rdm_rx_desc_wr_wb_irq_en_set(self, 1U);
+		hw_atl_rdm_rdm_intr_moder_en_set(self, 0U);
+		itr_tx = 0U;
+		itr_rx = 0U;
+		break;
+	}
+
+	for (i = HW_ATL_B0_RINGS_MAX; i--;) {
+		hw_atl_reg_tx_intr_moder_ctrl_set(self, itr_tx, i);
+		hw_atl_reg_rx_intr_moder_ctrl_set(self, itr_rx, i);
+	}
+
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_stop(struct aq_hw_s *self)
+{
+	hw_atl_b0_hw_irq_disable(self, HW_ATL_B0_INT_MASK);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_ring_tx_stop(struct aq_hw_s *self,
+				     struct aq_ring_s *ring)
+{
+	hw_atl_tdm_tx_desc_en_set(self, 0U, ring->idx);
+	return aq_hw_err_from_flags(self);
+}
+
+static int hw_atl_b0_hw_ring_rx_stop(struct aq_hw_s *self,
+				     struct aq_ring_s *ring)
+{
+	hw_atl_rdm_rx_desc_en_set(self, 0U, ring->idx);
+	return aq_hw_err_from_flags(self);
+}
+
+const struct aq_hw_ops hw_atl_ops_b0 = {
+	.hw_set_mac_address   = hw_atl_b0_hw_mac_addr_set,
+	.hw_init              = hw_atl_b0_hw_init,
+	.hw_reset             = hw_atl_b0_hw_reset,
+	.hw_start             = hw_atl_b0_hw_start,
+	.hw_ring_tx_start     = hw_atl_b0_hw_ring_tx_start,
+	.hw_ring_tx_stop      = hw_atl_b0_hw_ring_tx_stop,
+	.hw_ring_rx_start     = hw_atl_b0_hw_ring_rx_start,
+	.hw_ring_rx_stop      = hw_atl_b0_hw_ring_rx_stop,
+	.hw_stop              = hw_atl_b0_hw_stop,
+
+	.hw_ring_tx_xmit         = hw_atl_b0_hw_ring_tx_xmit,
+	.hw_ring_tx_head_update  = hw_atl_b0_hw_ring_tx_head_update,
+
+	.hw_ring_rx_receive      = hw_atl_b0_hw_ring_rx_receive,
+	.hw_ring_rx_fill         = hw_atl_b0_hw_ring_rx_fill,
+
+	.hw_irq_enable           = hw_atl_b0_hw_irq_enable,
+	.hw_irq_disable          = hw_atl_b0_hw_irq_disable,
+	.hw_irq_read             = hw_atl_b0_hw_irq_read,
+
+	.hw_ring_rx_init             = hw_atl_b0_hw_ring_rx_init,
+	.hw_ring_tx_init             = hw_atl_b0_hw_ring_tx_init,
+	.hw_packet_filter_set        = hw_atl_b0_hw_packet_filter_set,
+	.hw_multicast_list_set       = hw_atl_b0_hw_multicast_list_set,
+	.hw_interrupt_moderation_set = hw_atl_b0_hw_interrupt_moderation_set,
+	.hw_rss_set                  = hw_atl_b0_hw_rss_set,
+	.hw_rss_hash_set             = hw_atl_b0_hw_rss_hash_set,
+	.hw_get_regs                 = hw_atl_utils_hw_get_regs,
+	.hw_get_hw_stats             = hw_atl_utils_get_hw_stats,
+	.hw_get_fw_version           = hw_atl_utils_get_fw_version,
+};
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_b0.h b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_b0.h
new file mode 100644
index 00000000..2cc8dac
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_b0.h
@@ -0,0 +1,42 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_b0.h: Declaration of abstract interface for Atlantic hardware
+ * specific functions.
+ */
+
+#ifndef HW_ATL_B0_H
+#define HW_ATL_B0_H
+
+#include "../aq_common.h"
+
+extern const struct aq_hw_caps_s hw_atl_b0_caps_aqc100;
+extern const struct aq_hw_caps_s hw_atl_b0_caps_aqc107;
+extern const struct aq_hw_caps_s hw_atl_b0_caps_aqc108;
+extern const struct aq_hw_caps_s hw_atl_b0_caps_aqc109;
+
+#define hw_atl_b0_caps_aqc111 hw_atl_b0_caps_aqc108
+#define hw_atl_b0_caps_aqc112 hw_atl_b0_caps_aqc109
+
+#define hw_atl_b0_caps_aqc100s hw_atl_b0_caps_aqc100
+#define hw_atl_b0_caps_aqc107s hw_atl_b0_caps_aqc107
+#define hw_atl_b0_caps_aqc108s hw_atl_b0_caps_aqc108
+#define hw_atl_b0_caps_aqc109s hw_atl_b0_caps_aqc109
+
+#define hw_atl_b0_caps_aqc111s hw_atl_b0_caps_aqc108
+#define hw_atl_b0_caps_aqc112s hw_atl_b0_caps_aqc109
+
+#define hw_atl_b0_caps_aqc111e hw_atl_b0_caps_aqc108
+#define hw_atl_b0_caps_aqc112e hw_atl_b0_caps_aqc109
+
+extern const struct aq_hw_ops hw_atl_ops_b0;
+
+#define hw_atl_ops_b1 hw_atl_ops_b0
+
+#endif /* HW_ATL_B0_H */
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_b0_internal.h b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_b0_internal.h
new file mode 100644
index 00000000..495675e
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_b0_internal.h
@@ -0,0 +1,147 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_b0_internal.h: Definition of Atlantic B0 chip specific
+ * constants.
+ */
+
+#ifndef HW_ATL_B0_INTERNAL_H
+#define HW_ATL_B0_INTERNAL_H
+
+#include "../aq_common.h"
+
+#define HW_ATL_B0_MTU_JUMBO  16352U
+#define HW_ATL_B0_MTU        1514U
+
+#define HW_ATL_B0_TX_RINGS 4U
+#define HW_ATL_B0_RX_RINGS 4U
+
+#define HW_ATL_B0_RINGS_MAX 32U
+#define HW_ATL_B0_TXD_SIZE       (16U)
+#define HW_ATL_B0_RXD_SIZE       (16U)
+
+#define HW_ATL_B0_MAC      0U
+#define HW_ATL_B0_MAC_MIN  1U
+#define HW_ATL_B0_MAC_MAX  33U
+
+/* UCAST/MCAST filters */
+#define HW_ATL_B0_UCAST_FILTERS_MAX 38
+#define HW_ATL_B0_MCAST_FILTERS_MAX 8
+
+/* interrupts */
+#define HW_ATL_B0_ERR_INT 8U
+#define HW_ATL_B0_INT_MASK  (0xFFFFFFFFU)
+
+#define HW_ATL_B0_TXD_CTL2_LEN        (0xFFFFC000)
+#define HW_ATL_B0_TXD_CTL2_CTX_EN     (0x00002000)
+#define HW_ATL_B0_TXD_CTL2_CTX_IDX    (0x00001000)
+
+#define HW_ATL_B0_TXD_CTL_DESC_TYPE_TXD   (0x00000001)
+#define HW_ATL_B0_TXD_CTL_DESC_TYPE_TXC   (0x00000002)
+#define HW_ATL_B0_TXD_CTL_BLEN        (0x000FFFF0)
+#define HW_ATL_B0_TXD_CTL_DD          (0x00100000)
+#define HW_ATL_B0_TXD_CTL_EOP         (0x00200000)
+
+#define HW_ATL_B0_TXD_CTL_CMD_X       (0x3FC00000)
+
+#define HW_ATL_B0_TXD_CTL_CMD_VLAN    BIT(22)
+#define HW_ATL_B0_TXD_CTL_CMD_FCS     BIT(23)
+#define HW_ATL_B0_TXD_CTL_CMD_IPCSO   BIT(24)
+#define HW_ATL_B0_TXD_CTL_CMD_TUCSO   BIT(25)
+#define HW_ATL_B0_TXD_CTL_CMD_LSO     BIT(26)
+#define HW_ATL_B0_TXD_CTL_CMD_WB      BIT(27)
+#define HW_ATL_B0_TXD_CTL_CMD_VXLAN   BIT(28)
+
+#define HW_ATL_B0_TXD_CTL_CMD_IPV6    BIT(21)
+#define HW_ATL_B0_TXD_CTL_CMD_TCP     BIT(22)
+
+#define HW_ATL_B0_MPI_CONTROL_ADR       0x0368U
+#define HW_ATL_B0_MPI_STATE_ADR         0x036CU
+
+#define HW_ATL_B0_MPI_SPEED_MSK         0xFFFFU
+#define HW_ATL_B0_MPI_SPEED_SHIFT       16U
+
+#define HW_ATL_B0_TXBUF_MAX  160U
+#define HW_ATL_B0_RXBUF_MAX  320U
+
+#define HW_ATL_B0_RSS_REDIRECTION_MAX 64U
+#define HW_ATL_B0_RSS_REDIRECTION_BITS 3U
+#define HW_ATL_B0_RSS_HASHKEY_BITS 320U
+
+#define HW_ATL_B0_TCRSS_4_8  1
+#define HW_ATL_B0_TC_MAX 1U
+#define HW_ATL_B0_RSS_MAX 8U
+
+#define HW_ATL_B0_LRO_RXD_MAX 2U
+#define HW_ATL_B0_RS_SLIP_ENABLED  0U
+
+/* (256k -1(max pay_len) - 54(header)) */
+#define HAL_ATL_B0_LSO_MAX_SEGMENT_SIZE 262089U
+
+/* (256k -1(max pay_len) - 74(header)) */
+#define HAL_ATL_B0_LSO_IPV6_MAX_SEGMENT_SIZE 262069U
+
+#define HW_ATL_B0_CHIP_REVISION_B0      0xA0U
+#define HW_ATL_B0_CHIP_REVISION_UNKNOWN 0xFFU
+
+#define HW_ATL_B0_FW_SEMA_RAM           0x2U
+
+#define HW_ATL_B0_TXC_LEN_TUNLEN    (0x0000FF00)
+#define HW_ATL_B0_TXC_LEN_OUTLEN    (0xFFFF0000)
+
+#define HW_ATL_B0_TXC_CTL_DESC_TYPE (0x00000007)
+#define HW_ATL_B0_TXC_CTL_CTX_ID    (0x00000008)
+#define HW_ATL_B0_TXC_CTL_VLAN      (0x000FFFF0)
+#define HW_ATL_B0_TXC_CTL_CMD       (0x00F00000)
+#define HW_ATL_B0_TXC_CTL_L2LEN     (0x7F000000)
+
+#define HW_ATL_B0_TXC_CTL_L3LEN     (0x80000000)	/* L3LEN lsb */
+#define HW_ATL_B0_TXC_LEN2_L3LEN    (0x000000FF)	/* L3LE upper bits */
+#define HW_ATL_B0_TXC_LEN2_L4LEN    (0x0000FF00)
+#define HW_ATL_B0_TXC_LEN2_MSSLEN   (0xFFFF0000)
+
+#define HW_ATL_B0_RXD_DD    (0x1)
+#define HW_ATL_B0_RXD_NCEA0 (0x1)
+
+#define HW_ATL_B0_RXD_WB_STAT_RSSTYPE (0x0000000F)
+#define HW_ATL_B0_RXD_WB_STAT_PKTTYPE (0x00000FF0)
+#define HW_ATL_B0_RXD_WB_STAT_RXCTRL  (0x00180000)
+#define HW_ATL_B0_RXD_WB_STAT_SPLHDR  (0x00200000)
+#define HW_ATL_B0_RXD_WB_STAT_HDRLEN  (0xFFC00000)
+
+#define HW_ATL_B0_RXD_WB_STAT2_DD      (0x0001)
+#define HW_ATL_B0_RXD_WB_STAT2_EOP     (0x0002)
+#define HW_ATL_B0_RXD_WB_STAT2_RXSTAT  (0x003C)
+#define HW_ATL_B0_RXD_WB_STAT2_MACERR  (0x0004)
+#define HW_ATL_B0_RXD_WB_STAT2_IP4ERR  (0x0008)
+#define HW_ATL_B0_RXD_WB_STAT2_TCPUPDERR  (0x0010)
+#define HW_ATL_B0_RXD_WB_STAT2_RXESTAT (0x0FC0)
+#define HW_ATL_B0_RXD_WB_STAT2_RSCCNT  (0xF000)
+
+#define L2_FILTER_ACTION_DISCARD (0x0)
+#define L2_FILTER_ACTION_HOST    (0x1)
+
+#define HW_ATL_B0_UCP_0X370_REG  (0x370)
+
+#define HW_ATL_B0_FLUSH() AQ_HW_READ_REG(self, 0x10)
+
+#define HW_ATL_INTR_MODER_MAX  0x1FF
+#define HW_ATL_INTR_MODER_MIN  0xFF
+
+#define HW_ATL_B0_MIN_RXD \
+	(ALIGN(AQ_CFG_SKB_FRAGS_MAX + 1U, AQ_HW_RXD_MULTIPLE))
+#define HW_ATL_B0_MIN_TXD \
+	(ALIGN(AQ_CFG_SKB_FRAGS_MAX + 1U, AQ_HW_TXD_MULTIPLE))
+
+#define HW_ATL_B0_MAX_RXD 8184U
+#define HW_ATL_B0_MAX_TXD 8184U
+
+/* HW layer capabilities */
+
+#endif /* HW_ATL_B0_INTERNAL_H */
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_llh.c b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_llh.c
new file mode 100644
index 00000000..292c489
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_llh.c
@@ -0,0 +1,1472 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_llh.c: Definitions of bitfield and register access functions for
+ * Atlantic registers.
+ */
+
+#include "hw_atl_llh.h"
+#include "hw_atl_llh_internal.h"
+#include "../aq_hw_utils.h"
+
+/* global */
+void hw_atl_reg_glb_cpu_sem_set(struct aq_hw_s *aq_hw, u32 glb_cpu_sem,
+				u32 semaphore)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_GLB_CPU_SEM_ADR(semaphore), glb_cpu_sem);
+}
+
+u32 hw_atl_reg_glb_cpu_sem_get(struct aq_hw_s *aq_hw, u32 semaphore)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_GLB_CPU_SEM_ADR(semaphore));
+}
+
+void hw_atl_glb_glb_reg_res_dis_set(struct aq_hw_s *aq_hw, u32 glb_reg_res_dis)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_GLB_REG_RES_DIS_ADR,
+			    HW_ATL_GLB_REG_RES_DIS_MSK,
+			    HW_ATL_GLB_REG_RES_DIS_SHIFT,
+			    glb_reg_res_dis);
+}
+
+void hw_atl_glb_soft_res_set(struct aq_hw_s *aq_hw, u32 soft_res)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_GLB_SOFT_RES_ADR,
+			    HW_ATL_GLB_SOFT_RES_MSK,
+			    HW_ATL_GLB_SOFT_RES_SHIFT, soft_res);
+}
+
+u32 hw_atl_glb_soft_res_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg_bit(aq_hw, HW_ATL_GLB_SOFT_RES_ADR,
+				  HW_ATL_GLB_SOFT_RES_MSK,
+				  HW_ATL_GLB_SOFT_RES_SHIFT);
+}
+
+u32 hw_atl_reg_rx_dma_stat_counter7get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_RX_DMA_STAT_COUNTER7_ADR);
+}
+
+u32 hw_atl_reg_glb_mif_id_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_GLB_MIF_ID_ADR);
+}
+
+/* stats */
+u32 hw_atl_rpb_rx_dma_drop_pkt_cnt_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_RPB_RX_DMA_DROP_PKT_CNT_ADR);
+}
+
+u32 hw_atl_stats_rx_dma_good_octet_counterlsw_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_STATS_RX_DMA_GOOD_OCTET_COUNTERLSW);
+}
+
+u32 hw_atl_stats_rx_dma_good_pkt_counterlsw_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_STATS_RX_DMA_GOOD_PKT_COUNTERLSW);
+}
+
+u32 hw_atl_stats_tx_dma_good_octet_counterlsw_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_STATS_TX_DMA_GOOD_OCTET_COUNTERLSW);
+}
+
+u32 hw_atl_stats_tx_dma_good_pkt_counterlsw_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_STATS_TX_DMA_GOOD_PKT_COUNTERLSW);
+}
+
+u32 hw_atl_stats_rx_dma_good_octet_countermsw_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_STATS_RX_DMA_GOOD_OCTET_COUNTERMSW);
+}
+
+u32 hw_atl_stats_rx_dma_good_pkt_countermsw_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_STATS_RX_DMA_GOOD_PKT_COUNTERMSW);
+}
+
+u32 hw_atl_stats_tx_dma_good_octet_countermsw_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_STATS_TX_DMA_GOOD_OCTET_COUNTERMSW);
+}
+
+u32 hw_atl_stats_tx_dma_good_pkt_countermsw_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_STATS_TX_DMA_GOOD_PKT_COUNTERMSW);
+}
+
+/* interrupt */
+void hw_atl_itr_irq_auto_masklsw_set(struct aq_hw_s *aq_hw,
+				     u32 irq_auto_masklsw)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_ITR_IAMRLSW_ADR, irq_auto_masklsw);
+}
+
+void hw_atl_itr_irq_map_en_rx_set(struct aq_hw_s *aq_hw, u32 irq_map_en_rx,
+				  u32 rx)
+{
+/* register address for bitfield imr_rx{r}_en */
+	static u32 itr_imr_rxren_adr[32] = {
+			0x00002100U, 0x00002100U, 0x00002104U, 0x00002104U,
+			0x00002108U, 0x00002108U, 0x0000210CU, 0x0000210CU,
+			0x00002110U, 0x00002110U, 0x00002114U, 0x00002114U,
+			0x00002118U, 0x00002118U, 0x0000211CU, 0x0000211CU,
+			0x00002120U, 0x00002120U, 0x00002124U, 0x00002124U,
+			0x00002128U, 0x00002128U, 0x0000212CU, 0x0000212CU,
+			0x00002130U, 0x00002130U, 0x00002134U, 0x00002134U,
+			0x00002138U, 0x00002138U, 0x0000213CU, 0x0000213CU
+		};
+
+/* bitmask for bitfield imr_rx{r}_en */
+	static u32 itr_imr_rxren_msk[32] = {
+			0x00008000U, 0x00000080U, 0x00008000U, 0x00000080U,
+			0x00008000U, 0x00000080U, 0x00008000U, 0x00000080U,
+			0x00008000U, 0x00000080U, 0x00008000U, 0x00000080U,
+			0x00008000U, 0x00000080U, 0x00008000U, 0x00000080U,
+			0x00008000U, 0x00000080U, 0x00008000U, 0x00000080U,
+			0x00008000U, 0x00000080U, 0x00008000U, 0x00000080U,
+			0x00008000U, 0x00000080U, 0x00008000U, 0x00000080U,
+			0x00008000U, 0x00000080U, 0x00008000U, 0x00000080U
+		};
+
+/* lower bit position of bitfield imr_rx{r}_en */
+	static u32 itr_imr_rxren_shift[32] = {
+			15U, 7U, 15U, 7U, 15U, 7U, 15U, 7U,
+			15U, 7U, 15U, 7U, 15U, 7U, 15U, 7U,
+			15U, 7U, 15U, 7U, 15U, 7U, 15U, 7U,
+			15U, 7U, 15U, 7U, 15U, 7U, 15U, 7U
+		};
+
+	aq_hw_write_reg_bit(aq_hw, itr_imr_rxren_adr[rx],
+			    itr_imr_rxren_msk[rx],
+			    itr_imr_rxren_shift[rx],
+			    irq_map_en_rx);
+}
+
+void hw_atl_itr_irq_map_en_tx_set(struct aq_hw_s *aq_hw, u32 irq_map_en_tx,
+				  u32 tx)
+{
+/* register address for bitfield imr_tx{t}_en */
+	static u32 itr_imr_txten_adr[32] = {
+			0x00002100U, 0x00002100U, 0x00002104U, 0x00002104U,
+			0x00002108U, 0x00002108U, 0x0000210CU, 0x0000210CU,
+			0x00002110U, 0x00002110U, 0x00002114U, 0x00002114U,
+			0x00002118U, 0x00002118U, 0x0000211CU, 0x0000211CU,
+			0x00002120U, 0x00002120U, 0x00002124U, 0x00002124U,
+			0x00002128U, 0x00002128U, 0x0000212CU, 0x0000212CU,
+			0x00002130U, 0x00002130U, 0x00002134U, 0x00002134U,
+			0x00002138U, 0x00002138U, 0x0000213CU, 0x0000213CU
+		};
+
+/* bitmask for bitfield imr_tx{t}_en */
+	static u32 itr_imr_txten_msk[32] = {
+			0x80000000U, 0x00800000U, 0x80000000U, 0x00800000U,
+			0x80000000U, 0x00800000U, 0x80000000U, 0x00800000U,
+			0x80000000U, 0x00800000U, 0x80000000U, 0x00800000U,
+			0x80000000U, 0x00800000U, 0x80000000U, 0x00800000U,
+			0x80000000U, 0x00800000U, 0x80000000U, 0x00800000U,
+			0x80000000U, 0x00800000U, 0x80000000U, 0x00800000U,
+			0x80000000U, 0x00800000U, 0x80000000U, 0x00800000U,
+			0x80000000U, 0x00800000U, 0x80000000U, 0x00800000U
+		};
+
+/* lower bit position of bitfield imr_tx{t}_en */
+	static u32 itr_imr_txten_shift[32] = {
+			31U, 23U, 31U, 23U, 31U, 23U, 31U, 23U,
+			31U, 23U, 31U, 23U, 31U, 23U, 31U, 23U,
+			31U, 23U, 31U, 23U, 31U, 23U, 31U, 23U,
+			31U, 23U, 31U, 23U, 31U, 23U, 31U, 23U
+		};
+
+	aq_hw_write_reg_bit(aq_hw, itr_imr_txten_adr[tx],
+			    itr_imr_txten_msk[tx],
+			    itr_imr_txten_shift[tx],
+			    irq_map_en_tx);
+}
+
+void hw_atl_itr_irq_map_rx_set(struct aq_hw_s *aq_hw, u32 irq_map_rx, u32 rx)
+{
+/* register address for bitfield imr_rx{r}[4:0] */
+	static u32 itr_imr_rxr_adr[32] = {
+			0x00002100U, 0x00002100U, 0x00002104U, 0x00002104U,
+			0x00002108U, 0x00002108U, 0x0000210CU, 0x0000210CU,
+			0x00002110U, 0x00002110U, 0x00002114U, 0x00002114U,
+			0x00002118U, 0x00002118U, 0x0000211CU, 0x0000211CU,
+			0x00002120U, 0x00002120U, 0x00002124U, 0x00002124U,
+			0x00002128U, 0x00002128U, 0x0000212CU, 0x0000212CU,
+			0x00002130U, 0x00002130U, 0x00002134U, 0x00002134U,
+			0x00002138U, 0x00002138U, 0x0000213CU, 0x0000213CU
+		};
+
+/* bitmask for bitfield imr_rx{r}[4:0] */
+	static u32 itr_imr_rxr_msk[32] = {
+			0x00001f00U, 0x0000001FU, 0x00001F00U, 0x0000001FU,
+			0x00001f00U, 0x0000001FU, 0x00001F00U, 0x0000001FU,
+			0x00001f00U, 0x0000001FU, 0x00001F00U, 0x0000001FU,
+			0x00001f00U, 0x0000001FU, 0x00001F00U, 0x0000001FU,
+			0x00001f00U, 0x0000001FU, 0x00001F00U, 0x0000001FU,
+			0x00001f00U, 0x0000001FU, 0x00001F00U, 0x0000001FU,
+			0x00001f00U, 0x0000001FU, 0x00001F00U, 0x0000001FU,
+			0x00001f00U, 0x0000001FU, 0x00001F00U, 0x0000001FU
+		};
+
+/* lower bit position of bitfield imr_rx{r}[4:0] */
+	static u32 itr_imr_rxr_shift[32] = {
+			8U, 0U, 8U, 0U, 8U, 0U, 8U, 0U,
+			8U, 0U, 8U, 0U, 8U, 0U, 8U, 0U,
+			8U, 0U, 8U, 0U, 8U, 0U, 8U, 0U,
+			8U, 0U, 8U, 0U, 8U, 0U, 8U, 0U
+		};
+
+	aq_hw_write_reg_bit(aq_hw, itr_imr_rxr_adr[rx],
+			    itr_imr_rxr_msk[rx],
+			    itr_imr_rxr_shift[rx],
+			    irq_map_rx);
+}
+
+void hw_atl_itr_irq_map_tx_set(struct aq_hw_s *aq_hw, u32 irq_map_tx, u32 tx)
+{
+/* register address for bitfield imr_tx{t}[4:0] */
+	static u32 itr_imr_txt_adr[32] = {
+			0x00002100U, 0x00002100U, 0x00002104U, 0x00002104U,
+			0x00002108U, 0x00002108U, 0x0000210CU, 0x0000210CU,
+			0x00002110U, 0x00002110U, 0x00002114U, 0x00002114U,
+			0x00002118U, 0x00002118U, 0x0000211CU, 0x0000211CU,
+			0x00002120U, 0x00002120U, 0x00002124U, 0x00002124U,
+			0x00002128U, 0x00002128U, 0x0000212CU, 0x0000212CU,
+			0x00002130U, 0x00002130U, 0x00002134U, 0x00002134U,
+			0x00002138U, 0x00002138U, 0x0000213CU, 0x0000213CU
+		};
+
+/* bitmask for bitfield imr_tx{t}[4:0] */
+	static u32 itr_imr_txt_msk[32] = {
+			0x1f000000U, 0x001F0000U, 0x1F000000U, 0x001F0000U,
+			0x1f000000U, 0x001F0000U, 0x1F000000U, 0x001F0000U,
+			0x1f000000U, 0x001F0000U, 0x1F000000U, 0x001F0000U,
+			0x1f000000U, 0x001F0000U, 0x1F000000U, 0x001F0000U,
+			0x1f000000U, 0x001F0000U, 0x1F000000U, 0x001F0000U,
+			0x1f000000U, 0x001F0000U, 0x1F000000U, 0x001F0000U,
+			0x1f000000U, 0x001F0000U, 0x1F000000U, 0x001F0000U,
+			0x1f000000U, 0x001F0000U, 0x1F000000U, 0x001F0000U
+		};
+
+/* lower bit position of bitfield imr_tx{t}[4:0] */
+	static u32 itr_imr_txt_shift[32] = {
+			24U, 16U, 24U, 16U, 24U, 16U, 24U, 16U,
+			24U, 16U, 24U, 16U, 24U, 16U, 24U, 16U,
+			24U, 16U, 24U, 16U, 24U, 16U, 24U, 16U,
+			24U, 16U, 24U, 16U, 24U, 16U, 24U, 16U
+		};
+
+	aq_hw_write_reg_bit(aq_hw, itr_imr_txt_adr[tx],
+			    itr_imr_txt_msk[tx],
+			    itr_imr_txt_shift[tx],
+			    irq_map_tx);
+}
+
+void hw_atl_itr_irq_msk_clearlsw_set(struct aq_hw_s *aq_hw,
+				     u32 irq_msk_clearlsw)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_ITR_IMCRLSW_ADR, irq_msk_clearlsw);
+}
+
+void hw_atl_itr_irq_msk_setlsw_set(struct aq_hw_s *aq_hw, u32 irq_msk_setlsw)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_ITR_IMSRLSW_ADR, irq_msk_setlsw);
+}
+
+void hw_atl_itr_irq_reg_res_dis_set(struct aq_hw_s *aq_hw, u32 irq_reg_res_dis)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_ITR_REG_RES_DSBL_ADR,
+			    HW_ATL_ITR_REG_RES_DSBL_MSK,
+			    HW_ATL_ITR_REG_RES_DSBL_SHIFT, irq_reg_res_dis);
+}
+
+void hw_atl_itr_irq_status_clearlsw_set(struct aq_hw_s *aq_hw,
+					u32 irq_status_clearlsw)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_ITR_ISCRLSW_ADR, irq_status_clearlsw);
+}
+
+u32 hw_atl_itr_irq_statuslsw_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_ITR_ISRLSW_ADR);
+}
+
+u32 hw_atl_itr_res_irq_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg_bit(aq_hw, HW_ATL_ITR_RES_ADR, HW_ATL_ITR_RES_MSK,
+				  HW_ATL_ITR_RES_SHIFT);
+}
+
+void hw_atl_itr_res_irq_set(struct aq_hw_s *aq_hw, u32 res_irq)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_ITR_RES_ADR, HW_ATL_ITR_RES_MSK,
+			    HW_ATL_ITR_RES_SHIFT, res_irq);
+}
+
+/* rdm */
+void hw_atl_rdm_cpu_id_set(struct aq_hw_s *aq_hw, u32 cpuid, u32 dca)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DCADCPUID_ADR(dca),
+			    HW_ATL_RDM_DCADCPUID_MSK,
+			    HW_ATL_RDM_DCADCPUID_SHIFT, cpuid);
+}
+
+void hw_atl_rdm_rx_dca_en_set(struct aq_hw_s *aq_hw, u32 rx_dca_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DCA_EN_ADR, HW_ATL_RDM_DCA_EN_MSK,
+			    HW_ATL_RDM_DCA_EN_SHIFT, rx_dca_en);
+}
+
+void hw_atl_rdm_rx_dca_mode_set(struct aq_hw_s *aq_hw, u32 rx_dca_mode)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DCA_MODE_ADR,
+			    HW_ATL_RDM_DCA_MODE_MSK,
+			    HW_ATL_RDM_DCA_MODE_SHIFT, rx_dca_mode);
+}
+
+void hw_atl_rdm_rx_desc_data_buff_size_set(struct aq_hw_s *aq_hw,
+					   u32 rx_desc_data_buff_size,
+					   u32 descriptor)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DESCDDATA_SIZE_ADR(descriptor),
+			    HW_ATL_RDM_DESCDDATA_SIZE_MSK,
+			    HW_ATL_RDM_DESCDDATA_SIZE_SHIFT,
+			    rx_desc_data_buff_size);
+}
+
+void hw_atl_rdm_rx_desc_dca_en_set(struct aq_hw_s *aq_hw, u32 rx_desc_dca_en,
+				   u32 dca)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DCADDESC_EN_ADR(dca),
+			    HW_ATL_RDM_DCADDESC_EN_MSK,
+			    HW_ATL_RDM_DCADDESC_EN_SHIFT,
+			    rx_desc_dca_en);
+}
+
+void hw_atl_rdm_rx_desc_en_set(struct aq_hw_s *aq_hw, u32 rx_desc_en,
+			       u32 descriptor)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DESCDEN_ADR(descriptor),
+			    HW_ATL_RDM_DESCDEN_MSK,
+			    HW_ATL_RDM_DESCDEN_SHIFT,
+			    rx_desc_en);
+}
+
+void hw_atl_rdm_rx_desc_head_buff_size_set(struct aq_hw_s *aq_hw,
+					   u32 rx_desc_head_buff_size,
+					   u32 descriptor)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DESCDHDR_SIZE_ADR(descriptor),
+			    HW_ATL_RDM_DESCDHDR_SIZE_MSK,
+			    HW_ATL_RDM_DESCDHDR_SIZE_SHIFT,
+			    rx_desc_head_buff_size);
+}
+
+void hw_atl_rdm_rx_desc_head_splitting_set(struct aq_hw_s *aq_hw,
+					   u32 rx_desc_head_splitting,
+					   u32 descriptor)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DESCDHDR_SPLIT_ADR(descriptor),
+			    HW_ATL_RDM_DESCDHDR_SPLIT_MSK,
+			    HW_ATL_RDM_DESCDHDR_SPLIT_SHIFT,
+			    rx_desc_head_splitting);
+}
+
+u32 hw_atl_rdm_rx_desc_head_ptr_get(struct aq_hw_s *aq_hw, u32 descriptor)
+{
+	return aq_hw_read_reg_bit(aq_hw, HW_ATL_RDM_DESCDHD_ADR(descriptor),
+				  HW_ATL_RDM_DESCDHD_MSK,
+				  HW_ATL_RDM_DESCDHD_SHIFT);
+}
+
+void hw_atl_rdm_rx_desc_len_set(struct aq_hw_s *aq_hw, u32 rx_desc_len,
+				u32 descriptor)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DESCDLEN_ADR(descriptor),
+			    HW_ATL_RDM_DESCDLEN_MSK, HW_ATL_RDM_DESCDLEN_SHIFT,
+			    rx_desc_len);
+}
+
+void hw_atl_rdm_rx_desc_res_set(struct aq_hw_s *aq_hw, u32 rx_desc_res,
+				u32 descriptor)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DESCDRESET_ADR(descriptor),
+			    HW_ATL_RDM_DESCDRESET_MSK,
+			    HW_ATL_RDM_DESCDRESET_SHIFT,
+			    rx_desc_res);
+}
+
+void hw_atl_rdm_rx_desc_wr_wb_irq_en_set(struct aq_hw_s *aq_hw,
+					 u32 rx_desc_wr_wb_irq_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_INT_DESC_WRB_EN_ADR,
+			    HW_ATL_RDM_INT_DESC_WRB_EN_MSK,
+			    HW_ATL_RDM_INT_DESC_WRB_EN_SHIFT,
+			    rx_desc_wr_wb_irq_en);
+}
+
+void hw_atl_rdm_rx_head_dca_en_set(struct aq_hw_s *aq_hw, u32 rx_head_dca_en,
+				   u32 dca)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DCADHDR_EN_ADR(dca),
+			    HW_ATL_RDM_DCADHDR_EN_MSK,
+			    HW_ATL_RDM_DCADHDR_EN_SHIFT,
+			    rx_head_dca_en);
+}
+
+void hw_atl_rdm_rx_pld_dca_en_set(struct aq_hw_s *aq_hw, u32 rx_pld_dca_en,
+				  u32 dca)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_DCADPAY_EN_ADR(dca),
+			    HW_ATL_RDM_DCADPAY_EN_MSK,
+			    HW_ATL_RDM_DCADPAY_EN_SHIFT,
+			    rx_pld_dca_en);
+}
+
+void hw_atl_rdm_rdm_intr_moder_en_set(struct aq_hw_s *aq_hw,
+				      u32 rdm_intr_moder_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RDM_INT_RIM_EN_ADR,
+			    HW_ATL_RDM_INT_RIM_EN_MSK,
+			    HW_ATL_RDM_INT_RIM_EN_SHIFT,
+			    rdm_intr_moder_en);
+}
+
+/* reg */
+void hw_atl_reg_gen_irq_map_set(struct aq_hw_s *aq_hw, u32 gen_intr_map,
+				u32 regidx)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_GEN_INTR_MAP_ADR(regidx), gen_intr_map);
+}
+
+u32 hw_atl_reg_gen_irq_status_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_GEN_INTR_STAT_ADR);
+}
+
+void hw_atl_reg_irq_glb_ctl_set(struct aq_hw_s *aq_hw, u32 intr_glb_ctl)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_INTR_GLB_CTL_ADR, intr_glb_ctl);
+}
+
+void hw_atl_reg_irq_thr_set(struct aq_hw_s *aq_hw, u32 intr_thr, u32 throttle)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_INTR_THR_ADR(throttle), intr_thr);
+}
+
+void hw_atl_reg_rx_dma_desc_base_addresslswset(struct aq_hw_s *aq_hw,
+					       u32 rx_dma_desc_base_addrlsw,
+					       u32 descriptor)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RX_DMA_DESC_BASE_ADDRLSW_ADR(descriptor),
+			rx_dma_desc_base_addrlsw);
+}
+
+void hw_atl_reg_rx_dma_desc_base_addressmswset(struct aq_hw_s *aq_hw,
+					       u32 rx_dma_desc_base_addrmsw,
+					       u32 descriptor)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RX_DMA_DESC_BASE_ADDRMSW_ADR(descriptor),
+			rx_dma_desc_base_addrmsw);
+}
+
+u32 hw_atl_reg_rx_dma_desc_status_get(struct aq_hw_s *aq_hw, u32 descriptor)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_RX_DMA_DESC_STAT_ADR(descriptor));
+}
+
+void hw_atl_reg_rx_dma_desc_tail_ptr_set(struct aq_hw_s *aq_hw,
+					 u32 rx_dma_desc_tail_ptr,
+					 u32 descriptor)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RX_DMA_DESC_TAIL_PTR_ADR(descriptor),
+			rx_dma_desc_tail_ptr);
+}
+
+void hw_atl_reg_rx_flr_mcst_flr_msk_set(struct aq_hw_s *aq_hw,
+					u32 rx_flr_mcst_flr_msk)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RX_FLR_MCST_FLR_MSK_ADR,
+			rx_flr_mcst_flr_msk);
+}
+
+void hw_atl_reg_rx_flr_mcst_flr_set(struct aq_hw_s *aq_hw, u32 rx_flr_mcst_flr,
+				    u32 filter)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RX_FLR_MCST_FLR_ADR(filter),
+			rx_flr_mcst_flr);
+}
+
+void hw_atl_reg_rx_flr_rss_control1set(struct aq_hw_s *aq_hw,
+				       u32 rx_flr_rss_control1)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RX_FLR_RSS_CONTROL1_ADR,
+			rx_flr_rss_control1);
+}
+
+void hw_atl_reg_rx_flr_control2_set(struct aq_hw_s *aq_hw,
+				    u32 rx_filter_control2)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RX_FLR_CONTROL2_ADR, rx_filter_control2);
+}
+
+void hw_atl_reg_rx_intr_moder_ctrl_set(struct aq_hw_s *aq_hw,
+				       u32 rx_intr_moderation_ctl,
+				       u32 queue)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RX_INTR_MODERATION_CTL_ADR(queue),
+			rx_intr_moderation_ctl);
+}
+
+void hw_atl_reg_tx_dma_debug_ctl_set(struct aq_hw_s *aq_hw,
+				     u32 tx_dma_debug_ctl)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_TX_DMA_DEBUG_CTL_ADR, tx_dma_debug_ctl);
+}
+
+void hw_atl_reg_tx_dma_desc_base_addresslswset(struct aq_hw_s *aq_hw,
+					       u32 tx_dma_desc_base_addrlsw,
+					       u32 descriptor)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_TX_DMA_DESC_BASE_ADDRLSW_ADR(descriptor),
+			tx_dma_desc_base_addrlsw);
+}
+
+void hw_atl_reg_tx_dma_desc_base_addressmswset(struct aq_hw_s *aq_hw,
+					       u32 tx_dma_desc_base_addrmsw,
+					       u32 descriptor)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_TX_DMA_DESC_BASE_ADDRMSW_ADR(descriptor),
+			tx_dma_desc_base_addrmsw);
+}
+
+void hw_atl_reg_tx_dma_desc_tail_ptr_set(struct aq_hw_s *aq_hw,
+					 u32 tx_dma_desc_tail_ptr,
+					 u32 descriptor)
+{
+	wmb();
+
+	aq_hw_write_reg(aq_hw, HW_ATL_TX_DMA_DESC_TAIL_PTR_ADR(descriptor),
+			tx_dma_desc_tail_ptr);
+}
+
+void hw_atl_reg_tx_intr_moder_ctrl_set(struct aq_hw_s *aq_hw,
+				       u32 tx_intr_moderation_ctl,
+				       u32 queue)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_TX_INTR_MODERATION_CTL_ADR(queue),
+			tx_intr_moderation_ctl);
+}
+
+/* RPB: rx packet buffer */
+void hw_atl_rpb_dma_sys_lbk_set(struct aq_hw_s *aq_hw, u32 dma_sys_lbk)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPB_DMA_SYS_LBK_ADR,
+			    HW_ATL_RPB_DMA_SYS_LBK_MSK,
+			    HW_ATL_RPB_DMA_SYS_LBK_SHIFT, dma_sys_lbk);
+}
+
+void hw_atl_rpb_rpf_rx_traf_class_mode_set(struct aq_hw_s *aq_hw,
+					   u32 rx_traf_class_mode)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPB_RPF_RX_TC_MODE_ADR,
+			    HW_ATL_RPB_RPF_RX_TC_MODE_MSK,
+			    HW_ATL_RPB_RPF_RX_TC_MODE_SHIFT,
+			    rx_traf_class_mode);
+}
+
+void hw_atl_rpb_rx_buff_en_set(struct aq_hw_s *aq_hw, u32 rx_buff_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPB_RX_BUF_EN_ADR,
+			    HW_ATL_RPB_RX_BUF_EN_MSK,
+			    HW_ATL_RPB_RX_BUF_EN_SHIFT, rx_buff_en);
+}
+
+void hw_atl_rpb_rx_buff_hi_threshold_per_tc_set(struct aq_hw_s *aq_hw,
+						u32 rx_buff_hi_threshold_per_tc,
+						u32 buffer)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPB_RXBHI_THRESH_ADR(buffer),
+			    HW_ATL_RPB_RXBHI_THRESH_MSK,
+			    HW_ATL_RPB_RXBHI_THRESH_SHIFT,
+			    rx_buff_hi_threshold_per_tc);
+}
+
+void hw_atl_rpb_rx_buff_lo_threshold_per_tc_set(struct aq_hw_s *aq_hw,
+						u32 rx_buff_lo_threshold_per_tc,
+						u32 buffer)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPB_RXBLO_THRESH_ADR(buffer),
+			    HW_ATL_RPB_RXBLO_THRESH_MSK,
+			    HW_ATL_RPB_RXBLO_THRESH_SHIFT,
+			    rx_buff_lo_threshold_per_tc);
+}
+
+void hw_atl_rpb_rx_flow_ctl_mode_set(struct aq_hw_s *aq_hw, u32 rx_flow_ctl_mode)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPB_RX_FC_MODE_ADR,
+			    HW_ATL_RPB_RX_FC_MODE_MSK,
+			    HW_ATL_RPB_RX_FC_MODE_SHIFT, rx_flow_ctl_mode);
+}
+
+void hw_atl_rpb_rx_pkt_buff_size_per_tc_set(struct aq_hw_s *aq_hw,
+					    u32 rx_pkt_buff_size_per_tc, u32 buffer)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPB_RXBBUF_SIZE_ADR(buffer),
+			    HW_ATL_RPB_RXBBUF_SIZE_MSK,
+			    HW_ATL_RPB_RXBBUF_SIZE_SHIFT,
+			    rx_pkt_buff_size_per_tc);
+}
+
+void hw_atl_rpb_rx_xoff_en_per_tc_set(struct aq_hw_s *aq_hw, u32 rx_xoff_en_per_tc,
+				      u32 buffer)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPB_RXBXOFF_EN_ADR(buffer),
+			    HW_ATL_RPB_RXBXOFF_EN_MSK,
+			    HW_ATL_RPB_RXBXOFF_EN_SHIFT,
+			    rx_xoff_en_per_tc);
+}
+
+/* rpf */
+
+void hw_atl_rpfl2broadcast_count_threshold_set(struct aq_hw_s *aq_hw,
+					       u32 l2broadcast_count_threshold)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPFL2BC_THRESH_ADR,
+			    HW_ATL_RPFL2BC_THRESH_MSK,
+			    HW_ATL_RPFL2BC_THRESH_SHIFT,
+			    l2broadcast_count_threshold);
+}
+
+void hw_atl_rpfl2broadcast_en_set(struct aq_hw_s *aq_hw, u32 l2broadcast_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPFL2BC_EN_ADR, HW_ATL_RPFL2BC_EN_MSK,
+			    HW_ATL_RPFL2BC_EN_SHIFT, l2broadcast_en);
+}
+
+void hw_atl_rpfl2broadcast_flr_act_set(struct aq_hw_s *aq_hw,
+				       u32 l2broadcast_flr_act)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPFL2BC_ACT_ADR,
+			    HW_ATL_RPFL2BC_ACT_MSK,
+			    HW_ATL_RPFL2BC_ACT_SHIFT, l2broadcast_flr_act);
+}
+
+void hw_atl_rpfl2multicast_flr_en_set(struct aq_hw_s *aq_hw,
+				      u32 l2multicast_flr_en,
+				      u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPFL2MC_ENF_ADR(filter),
+			    HW_ATL_RPFL2MC_ENF_MSK,
+			    HW_ATL_RPFL2MC_ENF_SHIFT, l2multicast_flr_en);
+}
+
+void hw_atl_rpfl2promiscuous_mode_en_set(struct aq_hw_s *aq_hw,
+					 u32 l2promiscuous_mode_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPFL2PROMIS_MODE_ADR,
+			    HW_ATL_RPFL2PROMIS_MODE_MSK,
+			    HW_ATL_RPFL2PROMIS_MODE_SHIFT,
+			    l2promiscuous_mode_en);
+}
+
+void hw_atl_rpfl2unicast_flr_act_set(struct aq_hw_s *aq_hw,
+				     u32 l2unicast_flr_act,
+				     u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPFL2UC_ACTF_ADR(filter),
+			    HW_ATL_RPFL2UC_ACTF_MSK, HW_ATL_RPFL2UC_ACTF_SHIFT,
+			    l2unicast_flr_act);
+}
+
+void hw_atl_rpfl2_uc_flr_en_set(struct aq_hw_s *aq_hw, u32 l2unicast_flr_en,
+				u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPFL2UC_ENF_ADR(filter),
+			    HW_ATL_RPFL2UC_ENF_MSK,
+			    HW_ATL_RPFL2UC_ENF_SHIFT, l2unicast_flr_en);
+}
+
+void hw_atl_rpfl2unicast_dest_addresslsw_set(struct aq_hw_s *aq_hw,
+					     u32 l2unicast_dest_addresslsw,
+					     u32 filter)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RPFL2UC_DAFLSW_ADR(filter),
+			l2unicast_dest_addresslsw);
+}
+
+void hw_atl_rpfl2unicast_dest_addressmsw_set(struct aq_hw_s *aq_hw,
+					     u32 l2unicast_dest_addressmsw,
+					     u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPFL2UC_DAFMSW_ADR(filter),
+			    HW_ATL_RPFL2UC_DAFMSW_MSK,
+			    HW_ATL_RPFL2UC_DAFMSW_SHIFT,
+			    l2unicast_dest_addressmsw);
+}
+
+void hw_atl_rpfl2_accept_all_mc_packets_set(struct aq_hw_s *aq_hw,
+					    u32 l2_accept_all_mc_packets)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPFL2MC_ACCEPT_ALL_ADR,
+			    HW_ATL_RPFL2MC_ACCEPT_ALL_MSK,
+			    HW_ATL_RPFL2MC_ACCEPT_ALL_SHIFT,
+			    l2_accept_all_mc_packets);
+}
+
+void hw_atl_rpf_rpb_user_priority_tc_map_set(struct aq_hw_s *aq_hw,
+					     u32 user_priority_tc_map, u32 tc)
+{
+/* register address for bitfield rx_tc_up{t}[2:0] */
+	static u32 rpf_rpb_rx_tc_upt_adr[8] = {
+			0x000054c4U, 0x000054C4U, 0x000054C4U, 0x000054C4U,
+			0x000054c4U, 0x000054C4U, 0x000054C4U, 0x000054C4U
+		};
+
+/* bitmask for bitfield rx_tc_up{t}[2:0] */
+	static u32 rpf_rpb_rx_tc_upt_msk[8] = {
+			0x00000007U, 0x00000070U, 0x00000700U, 0x00007000U,
+			0x00070000U, 0x00700000U, 0x07000000U, 0x70000000U
+		};
+
+/* lower bit position of bitfield rx_tc_up{t}[2:0] */
+	static u32 rpf_rpb_rx_tc_upt_shft[8] = {
+			0U, 4U, 8U, 12U, 16U, 20U, 24U, 28U
+		};
+
+	aq_hw_write_reg_bit(aq_hw, rpf_rpb_rx_tc_upt_adr[tc],
+			    rpf_rpb_rx_tc_upt_msk[tc],
+			    rpf_rpb_rx_tc_upt_shft[tc],
+			    user_priority_tc_map);
+}
+
+void hw_atl_rpf_rss_key_addr_set(struct aq_hw_s *aq_hw, u32 rss_key_addr)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_RSS_KEY_ADDR_ADR,
+			    HW_ATL_RPF_RSS_KEY_ADDR_MSK,
+			    HW_ATL_RPF_RSS_KEY_ADDR_SHIFT,
+			    rss_key_addr);
+}
+
+void hw_atl_rpf_rss_key_wr_data_set(struct aq_hw_s *aq_hw, u32 rss_key_wr_data)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RPF_RSS_KEY_WR_DATA_ADR,
+			rss_key_wr_data);
+}
+
+u32 hw_atl_rpf_rss_key_wr_en_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg_bit(aq_hw, HW_ATL_RPF_RSS_KEY_WR_ENI_ADR,
+				  HW_ATL_RPF_RSS_KEY_WR_ENI_MSK,
+				  HW_ATL_RPF_RSS_KEY_WR_ENI_SHIFT);
+}
+
+void hw_atl_rpf_rss_key_wr_en_set(struct aq_hw_s *aq_hw, u32 rss_key_wr_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_RSS_KEY_WR_ENI_ADR,
+			    HW_ATL_RPF_RSS_KEY_WR_ENI_MSK,
+			    HW_ATL_RPF_RSS_KEY_WR_ENI_SHIFT,
+			    rss_key_wr_en);
+}
+
+void hw_atl_rpf_rss_redir_tbl_addr_set(struct aq_hw_s *aq_hw,
+				       u32 rss_redir_tbl_addr)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_RSS_REDIR_ADDR_ADR,
+			    HW_ATL_RPF_RSS_REDIR_ADDR_MSK,
+			    HW_ATL_RPF_RSS_REDIR_ADDR_SHIFT,
+			    rss_redir_tbl_addr);
+}
+
+void hw_atl_rpf_rss_redir_tbl_wr_data_set(struct aq_hw_s *aq_hw,
+					  u32 rss_redir_tbl_wr_data)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_RSS_REDIR_WR_DATA_ADR,
+			    HW_ATL_RPF_RSS_REDIR_WR_DATA_MSK,
+			    HW_ATL_RPF_RSS_REDIR_WR_DATA_SHIFT,
+			    rss_redir_tbl_wr_data);
+}
+
+u32 hw_atl_rpf_rss_redir_wr_en_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg_bit(aq_hw, HW_ATL_RPF_RSS_REDIR_WR_ENI_ADR,
+				  HW_ATL_RPF_RSS_REDIR_WR_ENI_MSK,
+				  HW_ATL_RPF_RSS_REDIR_WR_ENI_SHIFT);
+}
+
+void hw_atl_rpf_rss_redir_wr_en_set(struct aq_hw_s *aq_hw, u32 rss_redir_wr_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_RSS_REDIR_WR_ENI_ADR,
+			    HW_ATL_RPF_RSS_REDIR_WR_ENI_MSK,
+			    HW_ATL_RPF_RSS_REDIR_WR_ENI_SHIFT, rss_redir_wr_en);
+}
+
+void hw_atl_rpf_tpo_to_rpf_sys_lbk_set(struct aq_hw_s *aq_hw,
+				       u32 tpo_to_rpf_sys_lbk)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_TPO_RPF_SYS_LBK_ADR,
+			    HW_ATL_RPF_TPO_RPF_SYS_LBK_MSK,
+			    HW_ATL_RPF_TPO_RPF_SYS_LBK_SHIFT,
+			    tpo_to_rpf_sys_lbk);
+}
+
+void hw_atl_rpf_vlan_inner_etht_set(struct aq_hw_s *aq_hw, u32 vlan_inner_etht)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_VL_INNER_TPID_ADR,
+			    HW_ATL_RPF_VL_INNER_TPID_MSK,
+			    HW_ATL_RPF_VL_INNER_TPID_SHIFT,
+			    vlan_inner_etht);
+}
+
+void hw_atl_rpf_vlan_outer_etht_set(struct aq_hw_s *aq_hw, u32 vlan_outer_etht)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_VL_OUTER_TPID_ADR,
+			    HW_ATL_RPF_VL_OUTER_TPID_MSK,
+			    HW_ATL_RPF_VL_OUTER_TPID_SHIFT,
+			    vlan_outer_etht);
+}
+
+void hw_atl_rpf_vlan_prom_mode_en_set(struct aq_hw_s *aq_hw,
+				      u32 vlan_prom_mode_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_VL_PROMIS_MODE_ADR,
+			    HW_ATL_RPF_VL_PROMIS_MODE_MSK,
+			    HW_ATL_RPF_VL_PROMIS_MODE_SHIFT,
+			    vlan_prom_mode_en);
+}
+
+void hw_atl_rpf_vlan_accept_untagged_packets_set(struct aq_hw_s *aq_hw,
+						 u32 vlan_acc_untagged_packets)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_VL_ACCEPT_UNTAGGED_MODE_ADR,
+			    HW_ATL_RPF_VL_ACCEPT_UNTAGGED_MODE_MSK,
+			    HW_ATL_RPF_VL_ACCEPT_UNTAGGED_MODE_SHIFT,
+			    vlan_acc_untagged_packets);
+}
+
+void hw_atl_rpf_vlan_untagged_act_set(struct aq_hw_s *aq_hw,
+				      u32 vlan_untagged_act)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_VL_UNTAGGED_ACT_ADR,
+			    HW_ATL_RPF_VL_UNTAGGED_ACT_MSK,
+			    HW_ATL_RPF_VL_UNTAGGED_ACT_SHIFT,
+			    vlan_untagged_act);
+}
+
+void hw_atl_rpf_vlan_flr_en_set(struct aq_hw_s *aq_hw, u32 vlan_flr_en,
+				u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_VL_EN_F_ADR(filter),
+			    HW_ATL_RPF_VL_EN_F_MSK,
+			    HW_ATL_RPF_VL_EN_F_SHIFT,
+			    vlan_flr_en);
+}
+
+void hw_atl_rpf_vlan_flr_act_set(struct aq_hw_s *aq_hw, u32 vlan_flr_act,
+				 u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_VL_ACT_F_ADR(filter),
+			    HW_ATL_RPF_VL_ACT_F_MSK,
+			    HW_ATL_RPF_VL_ACT_F_SHIFT,
+			    vlan_flr_act);
+}
+
+void hw_atl_rpf_vlan_id_flr_set(struct aq_hw_s *aq_hw, u32 vlan_id_flr,
+				u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_VL_ID_F_ADR(filter),
+			    HW_ATL_RPF_VL_ID_F_MSK,
+			    HW_ATL_RPF_VL_ID_F_SHIFT,
+			    vlan_id_flr);
+}
+
+void hw_atl_rpf_etht_flr_en_set(struct aq_hw_s *aq_hw, u32 etht_flr_en,
+				u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_ET_ENF_ADR(filter),
+			    HW_ATL_RPF_ET_ENF_MSK,
+			    HW_ATL_RPF_ET_ENF_SHIFT, etht_flr_en);
+}
+
+void hw_atl_rpf_etht_user_priority_en_set(struct aq_hw_s *aq_hw,
+					  u32 etht_user_priority_en, u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_ET_UPFEN_ADR(filter),
+			    HW_ATL_RPF_ET_UPFEN_MSK, HW_ATL_RPF_ET_UPFEN_SHIFT,
+			    etht_user_priority_en);
+}
+
+void hw_atl_rpf_etht_rx_queue_en_set(struct aq_hw_s *aq_hw,
+				     u32 etht_rx_queue_en,
+				     u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_ET_RXQFEN_ADR(filter),
+			    HW_ATL_RPF_ET_RXQFEN_MSK,
+			    HW_ATL_RPF_ET_RXQFEN_SHIFT,
+			    etht_rx_queue_en);
+}
+
+void hw_atl_rpf_etht_user_priority_set(struct aq_hw_s *aq_hw,
+				       u32 etht_user_priority,
+				       u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_ET_UPF_ADR(filter),
+			    HW_ATL_RPF_ET_UPF_MSK,
+			    HW_ATL_RPF_ET_UPF_SHIFT, etht_user_priority);
+}
+
+void hw_atl_rpf_etht_rx_queue_set(struct aq_hw_s *aq_hw, u32 etht_rx_queue,
+				  u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_ET_RXQF_ADR(filter),
+			    HW_ATL_RPF_ET_RXQF_MSK,
+			    HW_ATL_RPF_ET_RXQF_SHIFT, etht_rx_queue);
+}
+
+void hw_atl_rpf_etht_mgt_queue_set(struct aq_hw_s *aq_hw, u32 etht_mgt_queue,
+				   u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_ET_MNG_RXQF_ADR(filter),
+			    HW_ATL_RPF_ET_MNG_RXQF_MSK,
+			    HW_ATL_RPF_ET_MNG_RXQF_SHIFT,
+			    etht_mgt_queue);
+}
+
+void hw_atl_rpf_etht_flr_act_set(struct aq_hw_s *aq_hw, u32 etht_flr_act,
+				 u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_ET_ACTF_ADR(filter),
+			    HW_ATL_RPF_ET_ACTF_MSK,
+			    HW_ATL_RPF_ET_ACTF_SHIFT, etht_flr_act);
+}
+
+void hw_atl_rpf_etht_flr_set(struct aq_hw_s *aq_hw, u32 etht_flr, u32 filter)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPF_ET_VALF_ADR(filter),
+			    HW_ATL_RPF_ET_VALF_MSK,
+			    HW_ATL_RPF_ET_VALF_SHIFT, etht_flr);
+}
+
+/* RPO: rx packet offload */
+void hw_atl_rpo_ipv4header_crc_offload_en_set(struct aq_hw_s *aq_hw,
+					      u32 ipv4header_crc_offload_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPO_IPV4CHK_EN_ADR,
+			    HW_ATL_RPO_IPV4CHK_EN_MSK,
+			    HW_ATL_RPO_IPV4CHK_EN_SHIFT,
+			    ipv4header_crc_offload_en);
+}
+
+void hw_atl_rpo_rx_desc_vlan_stripping_set(struct aq_hw_s *aq_hw,
+					   u32 rx_desc_vlan_stripping,
+					   u32 descriptor)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPO_DESCDVL_STRIP_ADR(descriptor),
+			    HW_ATL_RPO_DESCDVL_STRIP_MSK,
+			    HW_ATL_RPO_DESCDVL_STRIP_SHIFT,
+			    rx_desc_vlan_stripping);
+}
+
+void hw_atl_rpo_tcp_udp_crc_offload_en_set(struct aq_hw_s *aq_hw,
+					   u32 tcp_udp_crc_offload_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPOL4CHK_EN_ADR,
+			    HW_ATL_RPOL4CHK_EN_MSK,
+			    HW_ATL_RPOL4CHK_EN_SHIFT, tcp_udp_crc_offload_en);
+}
+
+void hw_atl_rpo_lro_en_set(struct aq_hw_s *aq_hw, u32 lro_en)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RPO_LRO_EN_ADR, lro_en);
+}
+
+void hw_atl_rpo_lro_patch_optimization_en_set(struct aq_hw_s *aq_hw,
+					      u32 lro_patch_optimization_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPO_LRO_PTOPT_EN_ADR,
+			    HW_ATL_RPO_LRO_PTOPT_EN_MSK,
+			    HW_ATL_RPO_LRO_PTOPT_EN_SHIFT,
+			    lro_patch_optimization_en);
+}
+
+void hw_atl_rpo_lro_qsessions_lim_set(struct aq_hw_s *aq_hw,
+				      u32 lro_qsessions_lim)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPO_LRO_QSES_LMT_ADR,
+			    HW_ATL_RPO_LRO_QSES_LMT_MSK,
+			    HW_ATL_RPO_LRO_QSES_LMT_SHIFT,
+			    lro_qsessions_lim);
+}
+
+void hw_atl_rpo_lro_total_desc_lim_set(struct aq_hw_s *aq_hw,
+				       u32 lro_total_desc_lim)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPO_LRO_TOT_DSC_LMT_ADR,
+			    HW_ATL_RPO_LRO_TOT_DSC_LMT_MSK,
+			    HW_ATL_RPO_LRO_TOT_DSC_LMT_SHIFT,
+			    lro_total_desc_lim);
+}
+
+void hw_atl_rpo_lro_min_pay_of_first_pkt_set(struct aq_hw_s *aq_hw,
+					     u32 lro_min_pld_of_first_pkt)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPO_LRO_PKT_MIN_ADR,
+			    HW_ATL_RPO_LRO_PKT_MIN_MSK,
+			    HW_ATL_RPO_LRO_PKT_MIN_SHIFT,
+			    lro_min_pld_of_first_pkt);
+}
+
+void hw_atl_rpo_lro_pkt_lim_set(struct aq_hw_s *aq_hw, u32 lro_pkt_lim)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_RPO_LRO_RSC_MAX_ADR, lro_pkt_lim);
+}
+
+void hw_atl_rpo_lro_max_num_of_descriptors_set(struct aq_hw_s *aq_hw,
+					       u32 lro_max_number_of_descriptors,
+					       u32 lro)
+{
+/* Register address for bitfield lro{L}_des_max[1:0] */
+	static u32 rpo_lro_ldes_max_adr[32] = {
+			0x000055A0U, 0x000055A0U, 0x000055A0U, 0x000055A0U,
+			0x000055A0U, 0x000055A0U, 0x000055A0U, 0x000055A0U,
+			0x000055A4U, 0x000055A4U, 0x000055A4U, 0x000055A4U,
+			0x000055A4U, 0x000055A4U, 0x000055A4U, 0x000055A4U,
+			0x000055A8U, 0x000055A8U, 0x000055A8U, 0x000055A8U,
+			0x000055A8U, 0x000055A8U, 0x000055A8U, 0x000055A8U,
+			0x000055ACU, 0x000055ACU, 0x000055ACU, 0x000055ACU,
+			0x000055ACU, 0x000055ACU, 0x000055ACU, 0x000055ACU
+		};
+
+/* Bitmask for bitfield lro{L}_des_max[1:0] */
+	static u32 rpo_lro_ldes_max_msk[32] = {
+			0x00000003U, 0x00000030U, 0x00000300U, 0x00003000U,
+			0x00030000U, 0x00300000U, 0x03000000U, 0x30000000U,
+			0x00000003U, 0x00000030U, 0x00000300U, 0x00003000U,
+			0x00030000U, 0x00300000U, 0x03000000U, 0x30000000U,
+			0x00000003U, 0x00000030U, 0x00000300U, 0x00003000U,
+			0x00030000U, 0x00300000U, 0x03000000U, 0x30000000U,
+			0x00000003U, 0x00000030U, 0x00000300U, 0x00003000U,
+			0x00030000U, 0x00300000U, 0x03000000U, 0x30000000U
+		};
+
+/* Lower bit position of bitfield lro{L}_des_max[1:0] */
+	static u32 rpo_lro_ldes_max_shift[32] = {
+			0U, 4U, 8U, 12U, 16U, 20U, 24U, 28U,
+			0U, 4U, 8U, 12U, 16U, 20U, 24U, 28U,
+			0U, 4U, 8U, 12U, 16U, 20U, 24U, 28U,
+			0U, 4U, 8U, 12U, 16U, 20U, 24U, 28U
+		};
+
+	aq_hw_write_reg_bit(aq_hw, rpo_lro_ldes_max_adr[lro],
+			    rpo_lro_ldes_max_msk[lro],
+			    rpo_lro_ldes_max_shift[lro],
+			    lro_max_number_of_descriptors);
+}
+
+void hw_atl_rpo_lro_time_base_divider_set(struct aq_hw_s *aq_hw,
+					  u32 lro_time_base_divider)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPO_LRO_TB_DIV_ADR,
+			    HW_ATL_RPO_LRO_TB_DIV_MSK,
+			    HW_ATL_RPO_LRO_TB_DIV_SHIFT,
+			    lro_time_base_divider);
+}
+
+void hw_atl_rpo_lro_inactive_interval_set(struct aq_hw_s *aq_hw,
+					  u32 lro_inactive_interval)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPO_LRO_INA_IVAL_ADR,
+			    HW_ATL_RPO_LRO_INA_IVAL_MSK,
+			    HW_ATL_RPO_LRO_INA_IVAL_SHIFT,
+			    lro_inactive_interval);
+}
+
+void hw_atl_rpo_lro_max_coalescing_interval_set(struct aq_hw_s *aq_hw,
+						u32 lro_max_coal_interval)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RPO_LRO_MAX_IVAL_ADR,
+			    HW_ATL_RPO_LRO_MAX_IVAL_MSK,
+			    HW_ATL_RPO_LRO_MAX_IVAL_SHIFT,
+			    lro_max_coal_interval);
+}
+
+/* rx */
+void hw_atl_rx_rx_reg_res_dis_set(struct aq_hw_s *aq_hw, u32 rx_reg_res_dis)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_RX_REG_RES_DSBL_ADR,
+			    HW_ATL_RX_REG_RES_DSBL_MSK,
+			    HW_ATL_RX_REG_RES_DSBL_SHIFT,
+			    rx_reg_res_dis);
+}
+
+/* tdm */
+void hw_atl_tdm_cpu_id_set(struct aq_hw_s *aq_hw, u32 cpuid, u32 dca)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TDM_DCADCPUID_ADR(dca),
+			    HW_ATL_TDM_DCADCPUID_MSK,
+			    HW_ATL_TDM_DCADCPUID_SHIFT, cpuid);
+}
+
+void hw_atl_tdm_large_send_offload_en_set(struct aq_hw_s *aq_hw,
+					  u32 large_send_offload_en)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_TDM_LSO_EN_ADR, large_send_offload_en);
+}
+
+void hw_atl_tdm_tx_dca_en_set(struct aq_hw_s *aq_hw, u32 tx_dca_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TDM_DCA_EN_ADR, HW_ATL_TDM_DCA_EN_MSK,
+			    HW_ATL_TDM_DCA_EN_SHIFT, tx_dca_en);
+}
+
+void hw_atl_tdm_tx_dca_mode_set(struct aq_hw_s *aq_hw, u32 tx_dca_mode)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TDM_DCA_MODE_ADR,
+			    HW_ATL_TDM_DCA_MODE_MSK,
+			    HW_ATL_TDM_DCA_MODE_SHIFT, tx_dca_mode);
+}
+
+void hw_atl_tdm_tx_desc_dca_en_set(struct aq_hw_s *aq_hw, u32 tx_desc_dca_en,
+				   u32 dca)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TDM_DCADDESC_EN_ADR(dca),
+			    HW_ATL_TDM_DCADDESC_EN_MSK,
+			    HW_ATL_TDM_DCADDESC_EN_SHIFT,
+			    tx_desc_dca_en);
+}
+
+void hw_atl_tdm_tx_desc_en_set(struct aq_hw_s *aq_hw, u32 tx_desc_en,
+			       u32 descriptor)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TDM_DESCDEN_ADR(descriptor),
+			    HW_ATL_TDM_DESCDEN_MSK,
+			    HW_ATL_TDM_DESCDEN_SHIFT,
+			    tx_desc_en);
+}
+
+u32 hw_atl_tdm_tx_desc_head_ptr_get(struct aq_hw_s *aq_hw, u32 descriptor)
+{
+	return aq_hw_read_reg_bit(aq_hw, HW_ATL_TDM_DESCDHD_ADR(descriptor),
+				  HW_ATL_TDM_DESCDHD_MSK,
+				  HW_ATL_TDM_DESCDHD_SHIFT);
+}
+
+void hw_atl_tdm_tx_desc_len_set(struct aq_hw_s *aq_hw, u32 tx_desc_len,
+				u32 descriptor)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TDM_DESCDLEN_ADR(descriptor),
+			    HW_ATL_TDM_DESCDLEN_MSK,
+			    HW_ATL_TDM_DESCDLEN_SHIFT,
+			    tx_desc_len);
+}
+
+void hw_atl_tdm_tx_desc_wr_wb_irq_en_set(struct aq_hw_s *aq_hw,
+					 u32 tx_desc_wr_wb_irq_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TDM_INT_DESC_WRB_EN_ADR,
+			    HW_ATL_TDM_INT_DESC_WRB_EN_MSK,
+			    HW_ATL_TDM_INT_DESC_WRB_EN_SHIFT,
+			    tx_desc_wr_wb_irq_en);
+}
+
+void hw_atl_tdm_tx_desc_wr_wb_threshold_set(struct aq_hw_s *aq_hw,
+					    u32 tx_desc_wr_wb_threshold,
+					    u32 descriptor)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TDM_DESCDWRB_THRESH_ADR(descriptor),
+			    HW_ATL_TDM_DESCDWRB_THRESH_MSK,
+			    HW_ATL_TDM_DESCDWRB_THRESH_SHIFT,
+			    tx_desc_wr_wb_threshold);
+}
+
+void hw_atl_tdm_tdm_intr_moder_en_set(struct aq_hw_s *aq_hw,
+				      u32 tdm_irq_moderation_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TDM_INT_MOD_EN_ADR,
+			    HW_ATL_TDM_INT_MOD_EN_MSK,
+			    HW_ATL_TDM_INT_MOD_EN_SHIFT,
+			    tdm_irq_moderation_en);
+}
+
+/* thm */
+void hw_atl_thm_lso_tcp_flag_of_first_pkt_set(struct aq_hw_s *aq_hw,
+					      u32 lso_tcp_flag_of_first_pkt)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_THM_LSO_TCP_FLAG_FIRST_ADR,
+			    HW_ATL_THM_LSO_TCP_FLAG_FIRST_MSK,
+			    HW_ATL_THM_LSO_TCP_FLAG_FIRST_SHIFT,
+			    lso_tcp_flag_of_first_pkt);
+}
+
+void hw_atl_thm_lso_tcp_flag_of_last_pkt_set(struct aq_hw_s *aq_hw,
+					     u32 lso_tcp_flag_of_last_pkt)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_THM_LSO_TCP_FLAG_LAST_ADR,
+			    HW_ATL_THM_LSO_TCP_FLAG_LAST_MSK,
+			    HW_ATL_THM_LSO_TCP_FLAG_LAST_SHIFT,
+			    lso_tcp_flag_of_last_pkt);
+}
+
+void hw_atl_thm_lso_tcp_flag_of_middle_pkt_set(struct aq_hw_s *aq_hw,
+					       u32 lso_tcp_flag_of_middle_pkt)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_THM_LSO_TCP_FLAG_MID_ADR,
+			    HW_ATL_THM_LSO_TCP_FLAG_MID_MSK,
+			    HW_ATL_THM_LSO_TCP_FLAG_MID_SHIFT,
+			    lso_tcp_flag_of_middle_pkt);
+}
+
+/* TPB: tx packet buffer */
+void hw_atl_tpb_tx_buff_en_set(struct aq_hw_s *aq_hw, u32 tx_buff_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPB_TX_BUF_EN_ADR,
+			    HW_ATL_TPB_TX_BUF_EN_MSK,
+			    HW_ATL_TPB_TX_BUF_EN_SHIFT, tx_buff_en);
+}
+
+void hw_atl_tpb_tx_buff_hi_threshold_per_tc_set(struct aq_hw_s *aq_hw,
+						u32 tx_buff_hi_threshold_per_tc,
+					 u32 buffer)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPB_TXBHI_THRESH_ADR(buffer),
+			    HW_ATL_TPB_TXBHI_THRESH_MSK,
+			    HW_ATL_TPB_TXBHI_THRESH_SHIFT,
+			    tx_buff_hi_threshold_per_tc);
+}
+
+void hw_atl_tpb_tx_buff_lo_threshold_per_tc_set(struct aq_hw_s *aq_hw,
+						u32 tx_buff_lo_threshold_per_tc,
+					 u32 buffer)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPB_TXBLO_THRESH_ADR(buffer),
+			    HW_ATL_TPB_TXBLO_THRESH_MSK,
+			    HW_ATL_TPB_TXBLO_THRESH_SHIFT,
+			    tx_buff_lo_threshold_per_tc);
+}
+
+void hw_atl_tpb_tx_dma_sys_lbk_en_set(struct aq_hw_s *aq_hw, u32 tx_dma_sys_lbk_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPB_DMA_SYS_LBK_ADR,
+			    HW_ATL_TPB_DMA_SYS_LBK_MSK,
+			    HW_ATL_TPB_DMA_SYS_LBK_SHIFT,
+			    tx_dma_sys_lbk_en);
+}
+
+void hw_atl_tpb_tx_pkt_buff_size_per_tc_set(struct aq_hw_s *aq_hw,
+					    u32 tx_pkt_buff_size_per_tc, u32 buffer)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPB_TXBBUF_SIZE_ADR(buffer),
+			    HW_ATL_TPB_TXBBUF_SIZE_MSK,
+			    HW_ATL_TPB_TXBBUF_SIZE_SHIFT,
+			    tx_pkt_buff_size_per_tc);
+}
+
+void hw_atl_tpb_tx_path_scp_ins_en_set(struct aq_hw_s *aq_hw, u32 tx_path_scp_ins_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPB_TX_SCP_INS_EN_ADR,
+			    HW_ATL_TPB_TX_SCP_INS_EN_MSK,
+			    HW_ATL_TPB_TX_SCP_INS_EN_SHIFT,
+			    tx_path_scp_ins_en);
+}
+
+/* TPO: tx packet offload */
+void hw_atl_tpo_ipv4header_crc_offload_en_set(struct aq_hw_s *aq_hw,
+					      u32 ipv4header_crc_offload_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPO_IPV4CHK_EN_ADR,
+			    HW_ATL_TPO_IPV4CHK_EN_MSK,
+			    HW_ATL_TPO_IPV4CHK_EN_SHIFT,
+			    ipv4header_crc_offload_en);
+}
+
+void hw_atl_tpo_tcp_udp_crc_offload_en_set(struct aq_hw_s *aq_hw,
+					   u32 tcp_udp_crc_offload_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPOL4CHK_EN_ADR,
+			    HW_ATL_TPOL4CHK_EN_MSK,
+			    HW_ATL_TPOL4CHK_EN_SHIFT,
+			    tcp_udp_crc_offload_en);
+}
+
+void hw_atl_tpo_tx_pkt_sys_lbk_en_set(struct aq_hw_s *aq_hw,
+				      u32 tx_pkt_sys_lbk_en)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPO_PKT_SYS_LBK_ADR,
+			    HW_ATL_TPO_PKT_SYS_LBK_MSK,
+			    HW_ATL_TPO_PKT_SYS_LBK_SHIFT,
+			    tx_pkt_sys_lbk_en);
+}
+
+/* TPS: tx packet scheduler */
+void hw_atl_tps_tx_pkt_shed_data_arb_mode_set(struct aq_hw_s *aq_hw,
+					      u32 tx_pkt_shed_data_arb_mode)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPS_DATA_TC_ARB_MODE_ADR,
+			    HW_ATL_TPS_DATA_TC_ARB_MODE_MSK,
+			    HW_ATL_TPS_DATA_TC_ARB_MODE_SHIFT,
+			    tx_pkt_shed_data_arb_mode);
+}
+
+void hw_atl_tps_tx_pkt_shed_desc_rate_curr_time_res_set(struct aq_hw_s *aq_hw,
+							u32 curr_time_res)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPS_DESC_RATE_TA_RST_ADR,
+			    HW_ATL_TPS_DESC_RATE_TA_RST_MSK,
+			    HW_ATL_TPS_DESC_RATE_TA_RST_SHIFT,
+			    curr_time_res);
+}
+
+void hw_atl_tps_tx_pkt_shed_desc_rate_lim_set(struct aq_hw_s *aq_hw,
+					      u32 tx_pkt_shed_desc_rate_lim)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPS_DESC_RATE_LIM_ADR,
+			    HW_ATL_TPS_DESC_RATE_LIM_MSK,
+			    HW_ATL_TPS_DESC_RATE_LIM_SHIFT,
+			    tx_pkt_shed_desc_rate_lim);
+}
+
+void hw_atl_tps_tx_pkt_shed_desc_tc_arb_mode_set(struct aq_hw_s *aq_hw,
+						 u32 arb_mode)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPS_DESC_TC_ARB_MODE_ADR,
+			    HW_ATL_TPS_DESC_TC_ARB_MODE_MSK,
+			    HW_ATL_TPS_DESC_TC_ARB_MODE_SHIFT,
+			    arb_mode);
+}
+
+void hw_atl_tps_tx_pkt_shed_desc_tc_max_credit_set(struct aq_hw_s *aq_hw,
+						   u32 max_credit,
+						   u32 tc)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPS_DESC_TCTCREDIT_MAX_ADR(tc),
+			    HW_ATL_TPS_DESC_TCTCREDIT_MAX_MSK,
+			    HW_ATL_TPS_DESC_TCTCREDIT_MAX_SHIFT,
+			    max_credit);
+}
+
+void hw_atl_tps_tx_pkt_shed_desc_tc_weight_set(struct aq_hw_s *aq_hw,
+					       u32 tx_pkt_shed_desc_tc_weight,
+					       u32 tc)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPS_DESC_TCTWEIGHT_ADR(tc),
+			    HW_ATL_TPS_DESC_TCTWEIGHT_MSK,
+			    HW_ATL_TPS_DESC_TCTWEIGHT_SHIFT,
+			    tx_pkt_shed_desc_tc_weight);
+}
+
+void hw_atl_tps_tx_pkt_shed_desc_vm_arb_mode_set(struct aq_hw_s *aq_hw,
+						 u32 arb_mode)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPS_DESC_VM_ARB_MODE_ADR,
+			    HW_ATL_TPS_DESC_VM_ARB_MODE_MSK,
+			    HW_ATL_TPS_DESC_VM_ARB_MODE_SHIFT,
+			    arb_mode);
+}
+
+void hw_atl_tps_tx_pkt_shed_tc_data_max_credit_set(struct aq_hw_s *aq_hw,
+						   u32 max_credit,
+						   u32 tc)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPS_DATA_TCTCREDIT_MAX_ADR(tc),
+			    HW_ATL_TPS_DATA_TCTCREDIT_MAX_MSK,
+			    HW_ATL_TPS_DATA_TCTCREDIT_MAX_SHIFT,
+			    max_credit);
+}
+
+void hw_atl_tps_tx_pkt_shed_tc_data_weight_set(struct aq_hw_s *aq_hw,
+					       u32 tx_pkt_shed_tc_data_weight,
+					       u32 tc)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TPS_DATA_TCTWEIGHT_ADR(tc),
+			    HW_ATL_TPS_DATA_TCTWEIGHT_MSK,
+			    HW_ATL_TPS_DATA_TCTWEIGHT_SHIFT,
+			    tx_pkt_shed_tc_data_weight);
+}
+
+/* tx */
+void hw_atl_tx_tx_reg_res_dis_set(struct aq_hw_s *aq_hw, u32 tx_reg_res_dis)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_TX_REG_RES_DSBL_ADR,
+			    HW_ATL_TX_REG_RES_DSBL_MSK,
+			    HW_ATL_TX_REG_RES_DSBL_SHIFT, tx_reg_res_dis);
+}
+
+/* msm */
+u32 hw_atl_msm_reg_access_status_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg_bit(aq_hw, HW_ATL_MSM_REG_ACCESS_BUSY_ADR,
+				  HW_ATL_MSM_REG_ACCESS_BUSY_MSK,
+				  HW_ATL_MSM_REG_ACCESS_BUSY_SHIFT);
+}
+
+void hw_atl_msm_reg_addr_for_indirect_addr_set(struct aq_hw_s *aq_hw,
+					       u32 reg_addr_for_indirect_addr)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_MSM_REG_ADDR_ADR,
+			    HW_ATL_MSM_REG_ADDR_MSK,
+			    HW_ATL_MSM_REG_ADDR_SHIFT,
+			    reg_addr_for_indirect_addr);
+}
+
+void hw_atl_msm_reg_rd_strobe_set(struct aq_hw_s *aq_hw, u32 reg_rd_strobe)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_MSM_REG_RD_STROBE_ADR,
+			    HW_ATL_MSM_REG_RD_STROBE_MSK,
+			    HW_ATL_MSM_REG_RD_STROBE_SHIFT,
+			    reg_rd_strobe);
+}
+
+u32 hw_atl_msm_reg_rd_data_get(struct aq_hw_s *aq_hw)
+{
+	return aq_hw_read_reg(aq_hw, HW_ATL_MSM_REG_RD_DATA_ADR);
+}
+
+void hw_atl_msm_reg_wr_data_set(struct aq_hw_s *aq_hw, u32 reg_wr_data)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_MSM_REG_WR_DATA_ADR, reg_wr_data);
+}
+
+void hw_atl_msm_reg_wr_strobe_set(struct aq_hw_s *aq_hw, u32 reg_wr_strobe)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_MSM_REG_WR_STROBE_ADR,
+			    HW_ATL_MSM_REG_WR_STROBE_MSK,
+			    HW_ATL_MSM_REG_WR_STROBE_SHIFT,
+			    reg_wr_strobe);
+}
+
+/* pci */
+void hw_atl_pci_pci_reg_res_dis_set(struct aq_hw_s *aq_hw, u32 pci_reg_res_dis)
+{
+	aq_hw_write_reg_bit(aq_hw, HW_ATL_PCI_REG_RES_DSBL_ADR,
+			    HW_ATL_PCI_REG_RES_DSBL_MSK,
+			    HW_ATL_PCI_REG_RES_DSBL_SHIFT,
+			    pci_reg_res_dis);
+}
+
+void hw_atl_reg_glb_cpu_scratch_scp_set(struct aq_hw_s *aq_hw,
+					u32 glb_cpu_scratch_scp,
+					u32 scratch_scp)
+{
+	aq_hw_write_reg(aq_hw, HW_ATL_GLB_CPU_SCRATCH_SCP_ADR(scratch_scp),
+			glb_cpu_scratch_scp);
+}
+
+void mcp_up_force_intr_set(struct aq_hw_s *aq_hw, u32 up_force_intr)
+{
+
+	aq_hw_write_reg_bit(aq_hw, mcp_up_force_interrupt_adr,
+			mcp_up_force_interrupt_msk,
+			mcp_up_force_interrupt_shift, up_force_intr);
+}
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_llh.h b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_llh.h
new file mode 100644
index 00000000..d2da1a6
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_llh.h
@@ -0,0 +1,705 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_llh.h: Declarations of bitfield and register access functions for
+ * Atlantic registers.
+ */
+
+#ifndef HW_ATL_LLH_H
+#define HW_ATL_LLH_H
+
+#include <linux/types.h>
+
+struct aq_hw_s;
+
+/* global */
+
+/* set global microprocessor semaphore */
+void hw_atl_reg_glb_cpu_sem_set(struct aq_hw_s *aq_hw,	u32 glb_cpu_sem,
+				u32 semaphore);
+
+/* get global microprocessor semaphore */
+u32 hw_atl_reg_glb_cpu_sem_get(struct aq_hw_s *aq_hw, u32 semaphore);
+
+/* set global register reset disable */
+void hw_atl_glb_glb_reg_res_dis_set(struct aq_hw_s *aq_hw, u32 glb_reg_res_dis);
+
+/* set soft reset */
+void hw_atl_glb_soft_res_set(struct aq_hw_s *aq_hw, u32 soft_res);
+
+/* get soft reset */
+u32 hw_atl_glb_soft_res_get(struct aq_hw_s *aq_hw);
+
+/* stats */
+
+u32 hw_atl_rpb_rx_dma_drop_pkt_cnt_get(struct aq_hw_s *aq_hw);
+
+/* get rx dma good octet counter lsw */
+u32 hw_atl_stats_rx_dma_good_octet_counterlsw_get(struct aq_hw_s *aq_hw);
+
+/* get rx dma good packet counter lsw */
+u32 hw_atl_stats_rx_dma_good_pkt_counterlsw_get(struct aq_hw_s *aq_hw);
+
+/* get tx dma good octet counter lsw */
+u32 hw_atl_stats_tx_dma_good_octet_counterlsw_get(struct aq_hw_s *aq_hw);
+
+/* get tx dma good packet counter lsw */
+u32 hw_atl_stats_tx_dma_good_pkt_counterlsw_get(struct aq_hw_s *aq_hw);
+
+/* get rx dma good octet counter msw */
+u32 hw_atl_stats_rx_dma_good_octet_countermsw_get(struct aq_hw_s *aq_hw);
+
+/* get rx dma good packet counter msw */
+u32 hw_atl_stats_rx_dma_good_pkt_countermsw_get(struct aq_hw_s *aq_hw);
+
+/* get tx dma good octet counter msw */
+u32 hw_atl_stats_tx_dma_good_octet_countermsw_get(struct aq_hw_s *aq_hw);
+
+/* get tx dma good packet counter msw */
+u32 hw_atl_stats_tx_dma_good_pkt_countermsw_get(struct aq_hw_s *aq_hw);
+
+/* get msm rx errors counter register */
+u32 hw_atl_reg_mac_msm_rx_errs_cnt_get(struct aq_hw_s *aq_hw);
+
+/* get msm rx unicast frames counter register */
+u32 hw_atl_reg_mac_msm_rx_ucst_frm_cnt_get(struct aq_hw_s *aq_hw);
+
+/* get msm rx multicast frames counter register */
+u32 hw_atl_reg_mac_msm_rx_mcst_frm_cnt_get(struct aq_hw_s *aq_hw);
+
+/* get msm rx broadcast frames counter register */
+u32 hw_atl_reg_mac_msm_rx_bcst_frm_cnt_get(struct aq_hw_s *aq_hw);
+
+/* get msm rx broadcast octets counter register 1 */
+u32 hw_atl_reg_mac_msm_rx_bcst_octets_counter1get(struct aq_hw_s *aq_hw);
+
+/* get msm rx unicast octets counter register 0 */
+u32 hw_atl_reg_mac_msm_rx_ucst_octets_counter0get(struct aq_hw_s *aq_hw);
+
+/* get rx dma statistics counter 7 */
+u32 hw_atl_reg_rx_dma_stat_counter7get(struct aq_hw_s *aq_hw);
+
+/* get msm tx errors counter register */
+u32 hw_atl_reg_mac_msm_tx_errs_cnt_get(struct aq_hw_s *aq_hw);
+
+/* get msm tx unicast frames counter register */
+u32 hw_atl_reg_mac_msm_tx_ucst_frm_cnt_get(struct aq_hw_s *aq_hw);
+
+/* get msm tx multicast frames counter register */
+u32 hw_atl_reg_mac_msm_tx_mcst_frm_cnt_get(struct aq_hw_s *aq_hw);
+
+/* get msm tx broadcast frames counter register */
+u32 hw_atl_reg_mac_msm_tx_bcst_frm_cnt_get(struct aq_hw_s *aq_hw);
+
+/* get msm tx multicast octets counter register 1 */
+u32 hw_atl_reg_mac_msm_tx_mcst_octets_counter1get(struct aq_hw_s *aq_hw);
+
+/* get msm tx broadcast octets counter register 1 */
+u32 hw_atl_reg_mac_msm_tx_bcst_octets_counter1get(struct aq_hw_s *aq_hw);
+
+/* get msm tx unicast octets counter register 0 */
+u32 hw_atl_reg_mac_msm_tx_ucst_octets_counter0get(struct aq_hw_s *aq_hw);
+
+/* get global mif identification */
+u32 hw_atl_reg_glb_mif_id_get(struct aq_hw_s *aq_hw);
+
+/* interrupt */
+
+/* set interrupt auto mask lsw */
+void hw_atl_itr_irq_auto_masklsw_set(struct aq_hw_s *aq_hw,
+				     u32 irq_auto_masklsw);
+
+/* set interrupt mapping enable rx */
+void hw_atl_itr_irq_map_en_rx_set(struct aq_hw_s *aq_hw, u32 irq_map_en_rx,
+				  u32 rx);
+
+/* set interrupt mapping enable tx */
+void hw_atl_itr_irq_map_en_tx_set(struct aq_hw_s *aq_hw, u32 irq_map_en_tx,
+				  u32 tx);
+
+/* set interrupt mapping rx */
+void hw_atl_itr_irq_map_rx_set(struct aq_hw_s *aq_hw, u32 irq_map_rx, u32 rx);
+
+/* set interrupt mapping tx */
+void hw_atl_itr_irq_map_tx_set(struct aq_hw_s *aq_hw, u32 irq_map_tx, u32 tx);
+
+/* set interrupt mask clear lsw */
+void hw_atl_itr_irq_msk_clearlsw_set(struct aq_hw_s *aq_hw,
+				     u32 irq_msk_clearlsw);
+
+/* set interrupt mask set lsw */
+void hw_atl_itr_irq_msk_setlsw_set(struct aq_hw_s *aq_hw, u32 irq_msk_setlsw);
+
+/* set interrupt register reset disable */
+void hw_atl_itr_irq_reg_res_dis_set(struct aq_hw_s *aq_hw, u32 irq_reg_res_dis);
+
+/* set interrupt status clear lsw */
+void hw_atl_itr_irq_status_clearlsw_set(struct aq_hw_s *aq_hw,
+					u32 irq_status_clearlsw);
+
+/* get interrupt status lsw */
+u32 hw_atl_itr_irq_statuslsw_get(struct aq_hw_s *aq_hw);
+
+/* get reset interrupt */
+u32 hw_atl_itr_res_irq_get(struct aq_hw_s *aq_hw);
+
+/* set reset interrupt */
+void hw_atl_itr_res_irq_set(struct aq_hw_s *aq_hw, u32 res_irq);
+
+/* rdm */
+
+/* set cpu id */
+void hw_atl_rdm_cpu_id_set(struct aq_hw_s *aq_hw, u32 cpuid, u32 dca);
+
+/* set rx dca enable */
+void hw_atl_rdm_rx_dca_en_set(struct aq_hw_s *aq_hw, u32 rx_dca_en);
+
+/* set rx dca mode */
+void hw_atl_rdm_rx_dca_mode_set(struct aq_hw_s *aq_hw, u32 rx_dca_mode);
+
+/* set rx descriptor data buffer size */
+void hw_atl_rdm_rx_desc_data_buff_size_set(struct aq_hw_s *aq_hw,
+					   u32 rx_desc_data_buff_size,
+				    u32 descriptor);
+
+/* set rx descriptor dca enable */
+void hw_atl_rdm_rx_desc_dca_en_set(struct aq_hw_s *aq_hw, u32 rx_desc_dca_en,
+				   u32 dca);
+
+/* set rx descriptor enable */
+void hw_atl_rdm_rx_desc_en_set(struct aq_hw_s *aq_hw, u32 rx_desc_en,
+			       u32 descriptor);
+
+/* set rx descriptor header splitting */
+void hw_atl_rdm_rx_desc_head_splitting_set(struct aq_hw_s *aq_hw,
+					   u32 rx_desc_head_splitting,
+				    u32 descriptor);
+
+/* get rx descriptor head pointer */
+u32 hw_atl_rdm_rx_desc_head_ptr_get(struct aq_hw_s *aq_hw, u32 descriptor);
+
+/* set rx descriptor length */
+void hw_atl_rdm_rx_desc_len_set(struct aq_hw_s *aq_hw, u32 rx_desc_len,
+				u32 descriptor);
+
+/* set rx descriptor write-back interrupt enable */
+void hw_atl_rdm_rx_desc_wr_wb_irq_en_set(struct aq_hw_s *aq_hw,
+					 u32 rx_desc_wr_wb_irq_en);
+
+/* set rx header dca enable */
+void hw_atl_rdm_rx_head_dca_en_set(struct aq_hw_s *aq_hw, u32 rx_head_dca_en,
+				   u32 dca);
+
+/* set rx payload dca enable */
+void hw_atl_rdm_rx_pld_dca_en_set(struct aq_hw_s *aq_hw, u32 rx_pld_dca_en,
+				  u32 dca);
+
+/* set rx descriptor header buffer size */
+void hw_atl_rdm_rx_desc_head_buff_size_set(struct aq_hw_s *aq_hw,
+					   u32 rx_desc_head_buff_size,
+					   u32 descriptor);
+
+/* set rx descriptor reset */
+void hw_atl_rdm_rx_desc_res_set(struct aq_hw_s *aq_hw, u32 rx_desc_res,
+				u32 descriptor);
+
+/* Set RDM Interrupt Moderation Enable */
+void hw_atl_rdm_rdm_intr_moder_en_set(struct aq_hw_s *aq_hw,
+				      u32 rdm_intr_moder_en);
+
+/* reg */
+
+/* set general interrupt mapping register */
+void hw_atl_reg_gen_irq_map_set(struct aq_hw_s *aq_hw, u32 gen_intr_map,
+				u32 regidx);
+
+/* get general interrupt status register */
+u32 hw_atl_reg_gen_irq_status_get(struct aq_hw_s *aq_hw);
+
+/* set interrupt global control register */
+void hw_atl_reg_irq_glb_ctl_set(struct aq_hw_s *aq_hw, u32 intr_glb_ctl);
+
+/* set interrupt throttle register */
+void hw_atl_reg_irq_thr_set(struct aq_hw_s *aq_hw, u32 intr_thr, u32 throttle);
+
+/* set rx dma descriptor base address lsw */
+void hw_atl_reg_rx_dma_desc_base_addresslswset(struct aq_hw_s *aq_hw,
+					       u32 rx_dma_desc_base_addrlsw,
+					u32 descriptor);
+
+/* set rx dma descriptor base address msw */
+void hw_atl_reg_rx_dma_desc_base_addressmswset(struct aq_hw_s *aq_hw,
+					       u32 rx_dma_desc_base_addrmsw,
+					u32 descriptor);
+
+/* get rx dma descriptor status register */
+u32 hw_atl_reg_rx_dma_desc_status_get(struct aq_hw_s *aq_hw, u32 descriptor);
+
+/* set rx dma descriptor tail pointer register */
+void hw_atl_reg_rx_dma_desc_tail_ptr_set(struct aq_hw_s *aq_hw,
+					 u32 rx_dma_desc_tail_ptr,
+				  u32 descriptor);
+
+/* set rx filter multicast filter mask register */
+void hw_atl_reg_rx_flr_mcst_flr_msk_set(struct aq_hw_s *aq_hw,
+					u32 rx_flr_mcst_flr_msk);
+
+/* set rx filter multicast filter register */
+void hw_atl_reg_rx_flr_mcst_flr_set(struct aq_hw_s *aq_hw, u32 rx_flr_mcst_flr,
+				    u32 filter);
+
+/* set rx filter rss control register 1 */
+void hw_atl_reg_rx_flr_rss_control1set(struct aq_hw_s *aq_hw,
+				       u32 rx_flr_rss_control1);
+
+/* Set RX Filter Control Register 2 */
+void hw_atl_reg_rx_flr_control2_set(struct aq_hw_s *aq_hw, u32 rx_flr_control2);
+
+/* Set RX Interrupt Moderation Control Register */
+void hw_atl_reg_rx_intr_moder_ctrl_set(struct aq_hw_s *aq_hw,
+				       u32 rx_intr_moderation_ctl,
+				u32 queue);
+
+/* set tx dma debug control */
+void hw_atl_reg_tx_dma_debug_ctl_set(struct aq_hw_s *aq_hw,
+				     u32 tx_dma_debug_ctl);
+
+/* set tx dma descriptor base address lsw */
+void hw_atl_reg_tx_dma_desc_base_addresslswset(struct aq_hw_s *aq_hw,
+					       u32 tx_dma_desc_base_addrlsw,
+					u32 descriptor);
+
+/* set tx dma descriptor base address msw */
+void hw_atl_reg_tx_dma_desc_base_addressmswset(struct aq_hw_s *aq_hw,
+					       u32 tx_dma_desc_base_addrmsw,
+					u32 descriptor);
+
+/* set tx dma descriptor tail pointer register */
+void hw_atl_reg_tx_dma_desc_tail_ptr_set(struct aq_hw_s *aq_hw,
+					 u32 tx_dma_desc_tail_ptr,
+					 u32 descriptor);
+
+/* Set TX Interrupt Moderation Control Register */
+void hw_atl_reg_tx_intr_moder_ctrl_set(struct aq_hw_s *aq_hw,
+				       u32 tx_intr_moderation_ctl,
+				       u32 queue);
+
+/* set global microprocessor scratch pad */
+void hw_atl_reg_glb_cpu_scratch_scp_set(struct aq_hw_s *aq_hw,
+					u32 glb_cpu_scratch_scp,
+					u32 scratch_scp);
+
+/* rpb */
+
+/* set dma system loopback */
+void hw_atl_rpb_dma_sys_lbk_set(struct aq_hw_s *aq_hw, u32 dma_sys_lbk);
+
+/* set rx traffic class mode */
+void hw_atl_rpb_rpf_rx_traf_class_mode_set(struct aq_hw_s *aq_hw,
+					   u32 rx_traf_class_mode);
+
+/* set rx buffer enable */
+void hw_atl_rpb_rx_buff_en_set(struct aq_hw_s *aq_hw, u32 rx_buff_en);
+
+/* set rx buffer high threshold (per tc) */
+void hw_atl_rpb_rx_buff_hi_threshold_per_tc_set(struct aq_hw_s *aq_hw,
+						u32 rx_buff_hi_threshold_per_tc,
+						u32 buffer);
+
+/* set rx buffer low threshold (per tc) */
+void hw_atl_rpb_rx_buff_lo_threshold_per_tc_set(struct aq_hw_s *aq_hw,
+						u32 rx_buff_lo_threshold_per_tc,
+					 u32 buffer);
+
+/* set rx flow control mode */
+void hw_atl_rpb_rx_flow_ctl_mode_set(struct aq_hw_s *aq_hw, u32 rx_flow_ctl_mode);
+
+/* set rx packet buffer size (per tc) */
+void hw_atl_rpb_rx_pkt_buff_size_per_tc_set(struct aq_hw_s *aq_hw,
+					    u32 rx_pkt_buff_size_per_tc,
+					    u32 buffer);
+
+/* set rx xoff enable (per tc) */
+void hw_atl_rpb_rx_xoff_en_per_tc_set(struct aq_hw_s *aq_hw, u32 rx_xoff_en_per_tc,
+				      u32 buffer);
+
+/* rpf */
+
+/* set l2 broadcast count threshold */
+void hw_atl_rpfl2broadcast_count_threshold_set(struct aq_hw_s *aq_hw,
+					       u32 l2broadcast_count_threshold);
+
+/* set l2 broadcast enable */
+void hw_atl_rpfl2broadcast_en_set(struct aq_hw_s *aq_hw, u32 l2broadcast_en);
+
+/* set l2 broadcast filter action */
+void hw_atl_rpfl2broadcast_flr_act_set(struct aq_hw_s *aq_hw,
+				       u32 l2broadcast_flr_act);
+
+/* set l2 multicast filter enable */
+void hw_atl_rpfl2multicast_flr_en_set(struct aq_hw_s *aq_hw,
+				      u32 l2multicast_flr_en,
+				      u32 filter);
+
+/* set l2 promiscuous mode enable */
+void hw_atl_rpfl2promiscuous_mode_en_set(struct aq_hw_s *aq_hw,
+					 u32 l2promiscuous_mode_en);
+
+/* set l2 unicast filter action */
+void hw_atl_rpfl2unicast_flr_act_set(struct aq_hw_s *aq_hw,
+				     u32 l2unicast_flr_act,
+				     u32 filter);
+
+/* set l2 unicast filter enable */
+void hw_atl_rpfl2_uc_flr_en_set(struct aq_hw_s *aq_hw, u32 l2unicast_flr_en,
+				u32 filter);
+
+/* set l2 unicast destination address lsw */
+void hw_atl_rpfl2unicast_dest_addresslsw_set(struct aq_hw_s *aq_hw,
+					     u32 l2unicast_dest_addresslsw,
+				      u32 filter);
+
+/* set l2 unicast destination address msw */
+void hw_atl_rpfl2unicast_dest_addressmsw_set(struct aq_hw_s *aq_hw,
+					     u32 l2unicast_dest_addressmsw,
+				      u32 filter);
+
+/* Set L2 Accept all Multicast packets */
+void hw_atl_rpfl2_accept_all_mc_packets_set(struct aq_hw_s *aq_hw,
+					    u32 l2_accept_all_mc_packets);
+
+/* set user-priority tc mapping */
+void hw_atl_rpf_rpb_user_priority_tc_map_set(struct aq_hw_s *aq_hw,
+					     u32 user_priority_tc_map, u32 tc);
+
+/* set rss key address */
+void hw_atl_rpf_rss_key_addr_set(struct aq_hw_s *aq_hw, u32 rss_key_addr);
+
+/* set rss key write data */
+void hw_atl_rpf_rss_key_wr_data_set(struct aq_hw_s *aq_hw, u32 rss_key_wr_data);
+
+/* get rss key write enable */
+u32 hw_atl_rpf_rss_key_wr_en_get(struct aq_hw_s *aq_hw);
+
+/* set rss key write enable */
+void hw_atl_rpf_rss_key_wr_en_set(struct aq_hw_s *aq_hw, u32 rss_key_wr_en);
+
+/* set rss redirection table address */
+void hw_atl_rpf_rss_redir_tbl_addr_set(struct aq_hw_s *aq_hw,
+				       u32 rss_redir_tbl_addr);
+
+/* set rss redirection table write data */
+void hw_atl_rpf_rss_redir_tbl_wr_data_set(struct aq_hw_s *aq_hw,
+					  u32 rss_redir_tbl_wr_data);
+
+/* get rss redirection write enable */
+u32 hw_atl_rpf_rss_redir_wr_en_get(struct aq_hw_s *aq_hw);
+
+/* set rss redirection write enable */
+void hw_atl_rpf_rss_redir_wr_en_set(struct aq_hw_s *aq_hw, u32 rss_redir_wr_en);
+
+/* set tpo to rpf system loopback */
+void hw_atl_rpf_tpo_to_rpf_sys_lbk_set(struct aq_hw_s *aq_hw,
+				       u32 tpo_to_rpf_sys_lbk);
+
+/* set vlan inner ethertype */
+void hw_atl_rpf_vlan_inner_etht_set(struct aq_hw_s *aq_hw, u32 vlan_inner_etht);
+
+/* set vlan outer ethertype */
+void hw_atl_rpf_vlan_outer_etht_set(struct aq_hw_s *aq_hw, u32 vlan_outer_etht);
+
+/* set vlan promiscuous mode enable */
+void hw_atl_rpf_vlan_prom_mode_en_set(struct aq_hw_s *aq_hw,
+				      u32 vlan_prom_mode_en);
+
+/* Set VLAN untagged action */
+void hw_atl_rpf_vlan_untagged_act_set(struct aq_hw_s *aq_hw,
+				      u32 vlan_untagged_act);
+
+/* Set VLAN accept untagged packets */
+void hw_atl_rpf_vlan_accept_untagged_packets_set(struct aq_hw_s *aq_hw,
+						 u32 vlan_acc_untagged_packets);
+
+/* Set VLAN filter enable */
+void hw_atl_rpf_vlan_flr_en_set(struct aq_hw_s *aq_hw, u32 vlan_flr_en,
+				u32 filter);
+
+/* Set VLAN Filter Action */
+void hw_atl_rpf_vlan_flr_act_set(struct aq_hw_s *aq_hw, u32 vlan_filter_act,
+				 u32 filter);
+
+/* Set VLAN ID Filter */
+void hw_atl_rpf_vlan_id_flr_set(struct aq_hw_s *aq_hw, u32 vlan_id_flr,
+				u32 filter);
+
+/* set ethertype filter enable */
+void hw_atl_rpf_etht_flr_en_set(struct aq_hw_s *aq_hw, u32 etht_flr_en,
+				u32 filter);
+
+/* set  ethertype user-priority enable */
+void hw_atl_rpf_etht_user_priority_en_set(struct aq_hw_s *aq_hw,
+					  u32 etht_user_priority_en,
+					  u32 filter);
+
+/* set  ethertype rx queue enable */
+void hw_atl_rpf_etht_rx_queue_en_set(struct aq_hw_s *aq_hw,
+				     u32 etht_rx_queue_en,
+				     u32 filter);
+
+/* set ethertype rx queue */
+void hw_atl_rpf_etht_rx_queue_set(struct aq_hw_s *aq_hw, u32 etht_rx_queue,
+				  u32 filter);
+
+/* set ethertype user-priority */
+void hw_atl_rpf_etht_user_priority_set(struct aq_hw_s *aq_hw,
+				       u32 etht_user_priority,
+				       u32 filter);
+
+/* set ethertype management queue */
+void hw_atl_rpf_etht_mgt_queue_set(struct aq_hw_s *aq_hw, u32 etht_mgt_queue,
+				   u32 filter);
+
+/* set ethertype filter action */
+void hw_atl_rpf_etht_flr_act_set(struct aq_hw_s *aq_hw, u32 etht_flr_act,
+				 u32 filter);
+
+/* set ethertype filter */
+void hw_atl_rpf_etht_flr_set(struct aq_hw_s *aq_hw, u32 etht_flr, u32 filter);
+
+/* rpo */
+
+/* set ipv4 header checksum offload enable */
+void hw_atl_rpo_ipv4header_crc_offload_en_set(struct aq_hw_s *aq_hw,
+					      u32 ipv4header_crc_offload_en);
+
+/* set rx descriptor vlan stripping */
+void hw_atl_rpo_rx_desc_vlan_stripping_set(struct aq_hw_s *aq_hw,
+					   u32 rx_desc_vlan_stripping,
+					   u32 descriptor);
+
+/* set tcp/udp checksum offload enable */
+void hw_atl_rpo_tcp_udp_crc_offload_en_set(struct aq_hw_s *aq_hw,
+					   u32 tcp_udp_crc_offload_en);
+
+/* Set LRO Patch Optimization Enable. */
+void hw_atl_rpo_lro_patch_optimization_en_set(struct aq_hw_s *aq_hw,
+					      u32 lro_patch_optimization_en);
+
+/* Set Large Receive Offload Enable */
+void hw_atl_rpo_lro_en_set(struct aq_hw_s *aq_hw, u32 lro_en);
+
+/* Set LRO Q Sessions Limit */
+void hw_atl_rpo_lro_qsessions_lim_set(struct aq_hw_s *aq_hw,
+				      u32 lro_qsessions_lim);
+
+/* Set LRO Total Descriptor Limit */
+void hw_atl_rpo_lro_total_desc_lim_set(struct aq_hw_s *aq_hw,
+				       u32 lro_total_desc_lim);
+
+/* Set LRO Min Payload of First Packet */
+void hw_atl_rpo_lro_min_pay_of_first_pkt_set(struct aq_hw_s *aq_hw,
+					     u32 lro_min_pld_of_first_pkt);
+
+/* Set LRO Packet Limit */
+void hw_atl_rpo_lro_pkt_lim_set(struct aq_hw_s *aq_hw, u32 lro_packet_lim);
+
+/* Set LRO Max Number of Descriptors */
+void hw_atl_rpo_lro_max_num_of_descriptors_set(struct aq_hw_s *aq_hw,
+					       u32 lro_max_desc_num, u32 lro);
+
+/* Set LRO Time Base Divider */
+void hw_atl_rpo_lro_time_base_divider_set(struct aq_hw_s *aq_hw,
+					  u32 lro_time_base_divider);
+
+/*Set LRO Inactive Interval */
+void hw_atl_rpo_lro_inactive_interval_set(struct aq_hw_s *aq_hw,
+					  u32 lro_inactive_interval);
+
+/*Set LRO Max Coalescing Interval */
+void hw_atl_rpo_lro_max_coalescing_interval_set(struct aq_hw_s *aq_hw,
+						u32 lro_max_coal_interval);
+
+/* rx */
+
+/* set rx register reset disable */
+void hw_atl_rx_rx_reg_res_dis_set(struct aq_hw_s *aq_hw, u32 rx_reg_res_dis);
+
+/* tdm */
+
+/* set cpu id */
+void hw_atl_tdm_cpu_id_set(struct aq_hw_s *aq_hw, u32 cpuid, u32 dca);
+
+/* set large send offload enable */
+void hw_atl_tdm_large_send_offload_en_set(struct aq_hw_s *aq_hw,
+					  u32 large_send_offload_en);
+
+/* set tx descriptor enable */
+void hw_atl_tdm_tx_desc_en_set(struct aq_hw_s *aq_hw, u32 tx_desc_en,
+			       u32 descriptor);
+
+/* set tx dca enable */
+void hw_atl_tdm_tx_dca_en_set(struct aq_hw_s *aq_hw, u32 tx_dca_en);
+
+/* set tx dca mode */
+void hw_atl_tdm_tx_dca_mode_set(struct aq_hw_s *aq_hw, u32 tx_dca_mode);
+
+/* set tx descriptor dca enable */
+void hw_atl_tdm_tx_desc_dca_en_set(struct aq_hw_s *aq_hw, u32 tx_desc_dca_en,
+				   u32 dca);
+
+/* get tx descriptor head pointer */
+u32 hw_atl_tdm_tx_desc_head_ptr_get(struct aq_hw_s *aq_hw, u32 descriptor);
+
+/* set tx descriptor length */
+void hw_atl_tdm_tx_desc_len_set(struct aq_hw_s *aq_hw, u32 tx_desc_len,
+				u32 descriptor);
+
+/* set tx descriptor write-back interrupt enable */
+void hw_atl_tdm_tx_desc_wr_wb_irq_en_set(struct aq_hw_s *aq_hw,
+					 u32 tx_desc_wr_wb_irq_en);
+
+/* set tx descriptor write-back threshold */
+void hw_atl_tdm_tx_desc_wr_wb_threshold_set(struct aq_hw_s *aq_hw,
+					    u32 tx_desc_wr_wb_threshold,
+				     u32 descriptor);
+
+/* Set TDM Interrupt Moderation Enable */
+void hw_atl_tdm_tdm_intr_moder_en_set(struct aq_hw_s *aq_hw,
+				      u32 tdm_irq_moderation_en);
+/* thm */
+
+/* set lso tcp flag of first packet */
+void hw_atl_thm_lso_tcp_flag_of_first_pkt_set(struct aq_hw_s *aq_hw,
+					      u32 lso_tcp_flag_of_first_pkt);
+
+/* set lso tcp flag of last packet */
+void hw_atl_thm_lso_tcp_flag_of_last_pkt_set(struct aq_hw_s *aq_hw,
+					     u32 lso_tcp_flag_of_last_pkt);
+
+/* set lso tcp flag of middle packet */
+void hw_atl_thm_lso_tcp_flag_of_middle_pkt_set(struct aq_hw_s *aq_hw,
+					       u32 lso_tcp_flag_of_middle_pkt);
+
+/* tpb */
+
+/* set tx buffer enable */
+void hw_atl_tpb_tx_buff_en_set(struct aq_hw_s *aq_hw, u32 tx_buff_en);
+
+/* set tx buffer high threshold (per tc) */
+void hw_atl_tpb_tx_buff_hi_threshold_per_tc_set(struct aq_hw_s *aq_hw,
+						u32 tx_buff_hi_threshold_per_tc,
+					 u32 buffer);
+
+/* set tx buffer low threshold (per tc) */
+void hw_atl_tpb_tx_buff_lo_threshold_per_tc_set(struct aq_hw_s *aq_hw,
+						u32 tx_buff_lo_threshold_per_tc,
+					 u32 buffer);
+
+/* set tx dma system loopback enable */
+void hw_atl_tpb_tx_dma_sys_lbk_en_set(struct aq_hw_s *aq_hw, u32 tx_dma_sys_lbk_en);
+
+/* set tx packet buffer size (per tc) */
+void hw_atl_tpb_tx_pkt_buff_size_per_tc_set(struct aq_hw_s *aq_hw,
+					    u32 tx_pkt_buff_size_per_tc, u32 buffer);
+
+/* set tx path pad insert enable */
+void hw_atl_tpb_tx_path_scp_ins_en_set(struct aq_hw_s *aq_hw, u32 tx_path_scp_ins_en);
+
+/* tpo */
+
+/* set ipv4 header checksum offload enable */
+void hw_atl_tpo_ipv4header_crc_offload_en_set(struct aq_hw_s *aq_hw,
+					      u32 ipv4header_crc_offload_en);
+
+/* set tcp/udp checksum offload enable */
+void hw_atl_tpo_tcp_udp_crc_offload_en_set(struct aq_hw_s *aq_hw,
+					   u32 tcp_udp_crc_offload_en);
+
+/* set tx pkt system loopback enable */
+void hw_atl_tpo_tx_pkt_sys_lbk_en_set(struct aq_hw_s *aq_hw,
+				      u32 tx_pkt_sys_lbk_en);
+
+/* tps */
+
+/* set tx packet scheduler data arbitration mode */
+void hw_atl_tps_tx_pkt_shed_data_arb_mode_set(struct aq_hw_s *aq_hw,
+					      u32 tx_pkt_shed_data_arb_mode);
+
+/* set tx packet scheduler descriptor rate current time reset */
+void hw_atl_tps_tx_pkt_shed_desc_rate_curr_time_res_set(struct aq_hw_s *aq_hw,
+							u32 curr_time_res);
+
+/* set tx packet scheduler descriptor rate limit */
+void hw_atl_tps_tx_pkt_shed_desc_rate_lim_set(struct aq_hw_s *aq_hw,
+					      u32 tx_pkt_shed_desc_rate_lim);
+
+/* set tx packet scheduler descriptor tc arbitration mode */
+void hw_atl_tps_tx_pkt_shed_desc_tc_arb_mode_set(struct aq_hw_s *aq_hw,
+						 u32 arb_mode);
+
+/* set tx packet scheduler descriptor tc max credit */
+void hw_atl_tps_tx_pkt_shed_desc_tc_max_credit_set(struct aq_hw_s *aq_hw,
+						   u32 max_credit,
+					    u32 tc);
+
+/* set tx packet scheduler descriptor tc weight */
+void hw_atl_tps_tx_pkt_shed_desc_tc_weight_set(struct aq_hw_s *aq_hw,
+					       u32 tx_pkt_shed_desc_tc_weight,
+					u32 tc);
+
+/* set tx packet scheduler descriptor vm arbitration mode */
+void hw_atl_tps_tx_pkt_shed_desc_vm_arb_mode_set(struct aq_hw_s *aq_hw,
+						 u32 arb_mode);
+
+/* set tx packet scheduler tc data max credit */
+void hw_atl_tps_tx_pkt_shed_tc_data_max_credit_set(struct aq_hw_s *aq_hw,
+						   u32 max_credit,
+					    u32 tc);
+
+/* set tx packet scheduler tc data weight */
+void hw_atl_tps_tx_pkt_shed_tc_data_weight_set(struct aq_hw_s *aq_hw,
+					       u32 tx_pkt_shed_tc_data_weight,
+					u32 tc);
+
+/* tx */
+
+/* set tx register reset disable */
+void hw_atl_tx_tx_reg_res_dis_set(struct aq_hw_s *aq_hw, u32 tx_reg_res_dis);
+
+/* msm */
+
+/* get register access status */
+u32 hw_atl_msm_reg_access_status_get(struct aq_hw_s *aq_hw);
+
+/* set  register address for indirect address */
+void hw_atl_msm_reg_addr_for_indirect_addr_set(struct aq_hw_s *aq_hw,
+					       u32 reg_addr_for_indirect_addr);
+
+/* set register read strobe */
+void hw_atl_msm_reg_rd_strobe_set(struct aq_hw_s *aq_hw, u32 reg_rd_strobe);
+
+/* get  register read data */
+u32 hw_atl_msm_reg_rd_data_get(struct aq_hw_s *aq_hw);
+
+/* set  register write data */
+void hw_atl_msm_reg_wr_data_set(struct aq_hw_s *aq_hw, u32 reg_wr_data);
+
+/* set register write strobe */
+void hw_atl_msm_reg_wr_strobe_set(struct aq_hw_s *aq_hw, u32 reg_wr_strobe);
+
+/* pci */
+
+/* set pci register reset disable */
+void hw_atl_pci_pci_reg_res_dis_set(struct aq_hw_s *aq_hw, u32 pci_reg_res_dis);
+
+/* set uP Force Interrupt */
+void mcp_up_force_intr_set(struct aq_hw_s *aq_hw, u32 up_force_intr);
+
+
+#endif /* HW_ATL_LLH_H */
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_llh_internal.h b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_llh_internal.h
new file mode 100644
index 00000000..3448e10
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_llh_internal.h
@@ -0,0 +1,2403 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_llh_internal.h: Preprocessor definitions
+ * for Atlantic registers.
+ */
+
+#ifndef HW_ATL_LLH_INTERNAL_H
+#define HW_ATL_LLH_INTERNAL_H
+
+/* global microprocessor semaphore  definitions
+ * base address: 0x000003a0
+ * parameter: semaphore {s} | stride size 0x4 | range [0, 15]
+ */
+#define HW_ATL_GLB_CPU_SEM_ADR(semaphore)  (0x000003a0u + (semaphore) * 0x4)
+/* register address for bitfield rx dma good octet counter lsw [1f:0] */
+#define HW_ATL_STATS_RX_DMA_GOOD_OCTET_COUNTERLSW 0x00006808
+/* register address for bitfield rx dma good packet counter lsw [1f:0] */
+#define HW_ATL_STATS_RX_DMA_GOOD_PKT_COUNTERLSW 0x00006800
+/* register address for bitfield tx dma good octet counter lsw [1f:0] */
+#define HW_ATL_STATS_TX_DMA_GOOD_OCTET_COUNTERLSW 0x00008808
+/* register address for bitfield tx dma good packet counter lsw [1f:0] */
+#define HW_ATL_STATS_TX_DMA_GOOD_PKT_COUNTERLSW 0x00008800
+
+/* register address for bitfield rx dma good octet counter msw [3f:20] */
+#define HW_ATL_STATS_RX_DMA_GOOD_OCTET_COUNTERMSW 0x0000680c
+/* register address for bitfield rx dma good packet counter msw [3f:20] */
+#define HW_ATL_STATS_RX_DMA_GOOD_PKT_COUNTERMSW 0x00006804
+/* register address for bitfield tx dma good octet counter msw [3f:20] */
+#define HW_ATL_STATS_TX_DMA_GOOD_OCTET_COUNTERMSW 0x0000880c
+/* register address for bitfield tx dma good packet counter msw [3f:20] */
+#define HW_ATL_STATS_TX_DMA_GOOD_PKT_COUNTERMSW 0x00008804
+
+/* preprocessor definitions for msm rx errors counter register */
+#define HW_ATL_MAC_MSM_RX_ERRS_CNT_ADR 0x00000120u
+
+/* preprocessor definitions for msm rx unicast frames counter register */
+#define HW_ATL_MAC_MSM_RX_UCST_FRM_CNT_ADR 0x000000e0u
+
+/* preprocessor definitions for msm rx multicast frames counter register */
+#define HW_ATL_MAC_MSM_RX_MCST_FRM_CNT_ADR 0x000000e8u
+
+/* preprocessor definitions for msm rx broadcast frames counter register */
+#define HW_ATL_MAC_MSM_RX_BCST_FRM_CNT_ADR 0x000000f0u
+
+/* preprocessor definitions for msm rx broadcast octets counter register 1 */
+#define HW_ATL_MAC_MSM_RX_BCST_OCTETS_COUNTER1_ADR 0x000001b0u
+
+/* preprocessor definitions for msm rx broadcast octets counter register 2 */
+#define HW_ATL_MAC_MSM_RX_BCST_OCTETS_COUNTER2_ADR 0x000001b4u
+
+/* preprocessor definitions for msm rx unicast octets counter register 0 */
+#define HW_ATL_MAC_MSM_RX_UCST_OCTETS_COUNTER0_ADR 0x000001b8u
+
+/* preprocessor definitions for rx dma statistics counter 7 */
+#define HW_ATL_RX_DMA_STAT_COUNTER7_ADR 0x00006818u
+
+/* preprocessor definitions for msm tx unicast frames counter register */
+#define HW_ATL_MAC_MSM_TX_UCST_FRM_CNT_ADR 0x00000108u
+
+/* preprocessor definitions for msm tx multicast frames counter register */
+#define HW_ATL_MAC_MSM_TX_MCST_FRM_CNT_ADR 0x00000110u
+
+/* preprocessor definitions for global mif identification */
+#define HW_ATL_GLB_MIF_ID_ADR 0x0000001cu
+
+/* register address for bitfield iamr_lsw[1f:0] */
+#define HW_ATL_ITR_IAMRLSW_ADR 0x00002090
+/* register address for bitfield rx dma drop packet counter [1f:0] */
+#define HW_ATL_RPB_RX_DMA_DROP_PKT_CNT_ADR 0x00006818
+
+/* register address for bitfield imcr_lsw[1f:0] */
+#define HW_ATL_ITR_IMCRLSW_ADR 0x00002070
+/* register address for bitfield imsr_lsw[1f:0] */
+#define HW_ATL_ITR_IMSRLSW_ADR 0x00002060
+/* register address for bitfield itr_reg_res_dsbl */
+#define HW_ATL_ITR_REG_RES_DSBL_ADR 0x00002300
+/* bitmask for bitfield itr_reg_res_dsbl */
+#define HW_ATL_ITR_REG_RES_DSBL_MSK 0x20000000
+/* lower bit position of bitfield itr_reg_res_dsbl */
+#define HW_ATL_ITR_REG_RES_DSBL_SHIFT 29
+/* register address for bitfield iscr_lsw[1f:0] */
+#define HW_ATL_ITR_ISCRLSW_ADR 0x00002050
+/* register address for bitfield isr_lsw[1f:0] */
+#define HW_ATL_ITR_ISRLSW_ADR 0x00002000
+/* register address for bitfield itr_reset */
+#define HW_ATL_ITR_RES_ADR 0x00002300
+/* bitmask for bitfield itr_reset */
+#define HW_ATL_ITR_RES_MSK 0x80000000
+/* lower bit position of bitfield itr_reset */
+#define HW_ATL_ITR_RES_SHIFT 31
+/* register address for bitfield dca{d}_cpuid[7:0] */
+#define HW_ATL_RDM_DCADCPUID_ADR(dca) (0x00006100 + (dca) * 0x4)
+/* bitmask for bitfield dca{d}_cpuid[7:0] */
+#define HW_ATL_RDM_DCADCPUID_MSK 0x000000ff
+/* lower bit position of bitfield dca{d}_cpuid[7:0] */
+#define HW_ATL_RDM_DCADCPUID_SHIFT 0
+/* register address for bitfield dca_en */
+#define HW_ATL_RDM_DCA_EN_ADR 0x00006180
+
+/* rx dca_en bitfield definitions
+ * preprocessor definitions for the bitfield "dca_en".
+ * port="pif_rdm_dca_en_i"
+ */
+
+/* register address for bitfield dca_en */
+#define HW_ATL_RDM_DCA_EN_ADR 0x00006180
+/* bitmask for bitfield dca_en */
+#define HW_ATL_RDM_DCA_EN_MSK 0x80000000
+/* inverted bitmask for bitfield dca_en */
+#define HW_ATL_RDM_DCA_EN_MSKN 0x7fffffff
+/* lower bit position of bitfield dca_en */
+#define HW_ATL_RDM_DCA_EN_SHIFT 31
+/* width of bitfield dca_en */
+#define HW_ATL_RDM_DCA_EN_WIDTH 1
+/* default value of bitfield dca_en */
+#define HW_ATL_RDM_DCA_EN_DEFAULT 0x1
+
+/* rx dca_mode[3:0] bitfield definitions
+ * preprocessor definitions for the bitfield "dca_mode[3:0]".
+ * port="pif_rdm_dca_mode_i[3:0]"
+ */
+
+/* register address for bitfield dca_mode[3:0] */
+#define HW_ATL_RDM_DCA_MODE_ADR 0x00006180
+/* bitmask for bitfield dca_mode[3:0] */
+#define HW_ATL_RDM_DCA_MODE_MSK 0x0000000f
+/* inverted bitmask for bitfield dca_mode[3:0] */
+#define HW_ATL_RDM_DCA_MODE_MSKN 0xfffffff0
+/* lower bit position of bitfield dca_mode[3:0] */
+#define HW_ATL_RDM_DCA_MODE_SHIFT 0
+/* width of bitfield dca_mode[3:0] */
+#define HW_ATL_RDM_DCA_MODE_WIDTH 4
+/* default value of bitfield dca_mode[3:0] */
+#define HW_ATL_RDM_DCA_MODE_DEFAULT 0x0
+
+/* rx desc{d}_data_size[4:0] bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_data_size[4:0]".
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ * port="pif_rdm_desc0_data_size_i[4:0]"
+ */
+
+/* register address for bitfield desc{d}_data_size[4:0] */
+#define HW_ATL_RDM_DESCDDATA_SIZE_ADR(descriptor) \
+	(0x00005b18 + (descriptor) * 0x20)
+/* bitmask for bitfield desc{d}_data_size[4:0] */
+#define HW_ATL_RDM_DESCDDATA_SIZE_MSK 0x0000001f
+/* inverted bitmask for bitfield desc{d}_data_size[4:0] */
+#define HW_ATL_RDM_DESCDDATA_SIZE_MSKN 0xffffffe0
+/* lower bit position of bitfield desc{d}_data_size[4:0] */
+#define HW_ATL_RDM_DESCDDATA_SIZE_SHIFT 0
+/* width of bitfield desc{d}_data_size[4:0] */
+#define HW_ATL_RDM_DESCDDATA_SIZE_WIDTH 5
+/* default value of bitfield desc{d}_data_size[4:0] */
+#define HW_ATL_RDM_DESCDDATA_SIZE_DEFAULT 0x0
+
+/* rx dca{d}_desc_en bitfield definitions
+ * preprocessor definitions for the bitfield "dca{d}_desc_en".
+ * parameter: dca {d} | stride size 0x4 | range [0, 31]
+ * port="pif_rdm_dca_desc_en_i[0]"
+ */
+
+/* register address for bitfield dca{d}_desc_en */
+#define HW_ATL_RDM_DCADDESC_EN_ADR(dca) (0x00006100 + (dca) * 0x4)
+/* bitmask for bitfield dca{d}_desc_en */
+#define HW_ATL_RDM_DCADDESC_EN_MSK 0x80000000
+/* inverted bitmask for bitfield dca{d}_desc_en */
+#define HW_ATL_RDM_DCADDESC_EN_MSKN 0x7fffffff
+/* lower bit position of bitfield dca{d}_desc_en */
+#define HW_ATL_RDM_DCADDESC_EN_SHIFT 31
+/* width of bitfield dca{d}_desc_en */
+#define HW_ATL_RDM_DCADDESC_EN_WIDTH 1
+/* default value of bitfield dca{d}_desc_en */
+#define HW_ATL_RDM_DCADDESC_EN_DEFAULT 0x0
+
+/* rx desc{d}_en bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_en".
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ * port="pif_rdm_desc_en_i[0]"
+ */
+
+/* register address for bitfield desc{d}_en */
+#define HW_ATL_RDM_DESCDEN_ADR(descriptor) (0x00005b08 + (descriptor) * 0x20)
+/* bitmask for bitfield desc{d}_en */
+#define HW_ATL_RDM_DESCDEN_MSK 0x80000000
+/* inverted bitmask for bitfield desc{d}_en */
+#define HW_ATL_RDM_DESCDEN_MSKN 0x7fffffff
+/* lower bit position of bitfield desc{d}_en */
+#define HW_ATL_RDM_DESCDEN_SHIFT 31
+/* width of bitfield desc{d}_en */
+#define HW_ATL_RDM_DESCDEN_WIDTH 1
+/* default value of bitfield desc{d}_en */
+#define HW_ATL_RDM_DESCDEN_DEFAULT 0x0
+
+/* rx desc{d}_hdr_size[4:0] bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_hdr_size[4:0]".
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ * port="pif_rdm_desc0_hdr_size_i[4:0]"
+ */
+
+/* register address for bitfield desc{d}_hdr_size[4:0] */
+#define HW_ATL_RDM_DESCDHDR_SIZE_ADR(descriptor) \
+	(0x00005b18 + (descriptor) * 0x20)
+/* bitmask for bitfield desc{d}_hdr_size[4:0] */
+#define HW_ATL_RDM_DESCDHDR_SIZE_MSK 0x00001f00
+/* inverted bitmask for bitfield desc{d}_hdr_size[4:0] */
+#define HW_ATL_RDM_DESCDHDR_SIZE_MSKN 0xffffe0ff
+/* lower bit position of bitfield desc{d}_hdr_size[4:0] */
+#define HW_ATL_RDM_DESCDHDR_SIZE_SHIFT 8
+/* width of bitfield desc{d}_hdr_size[4:0] */
+#define HW_ATL_RDM_DESCDHDR_SIZE_WIDTH 5
+/* default value of bitfield desc{d}_hdr_size[4:0] */
+#define HW_ATL_RDM_DESCDHDR_SIZE_DEFAULT 0x0
+
+/* rx desc{d}_hdr_split bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_hdr_split".
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ * port="pif_rdm_desc_hdr_split_i[0]"
+ */
+
+/* register address for bitfield desc{d}_hdr_split */
+#define HW_ATL_RDM_DESCDHDR_SPLIT_ADR(descriptor) \
+	(0x00005b08 + (descriptor) * 0x20)
+/* bitmask for bitfield desc{d}_hdr_split */
+#define HW_ATL_RDM_DESCDHDR_SPLIT_MSK 0x10000000
+/* inverted bitmask for bitfield desc{d}_hdr_split */
+#define HW_ATL_RDM_DESCDHDR_SPLIT_MSKN 0xefffffff
+/* lower bit position of bitfield desc{d}_hdr_split */
+#define HW_ATL_RDM_DESCDHDR_SPLIT_SHIFT 28
+/* width of bitfield desc{d}_hdr_split */
+#define HW_ATL_RDM_DESCDHDR_SPLIT_WIDTH 1
+/* default value of bitfield desc{d}_hdr_split */
+#define HW_ATL_RDM_DESCDHDR_SPLIT_DEFAULT 0x0
+
+/* rx desc{d}_hd[c:0] bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_hd[c:0]".
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ * port="rdm_pif_desc0_hd_o[12:0]"
+ */
+
+/* register address for bitfield desc{d}_hd[c:0] */
+#define HW_ATL_RDM_DESCDHD_ADR(descriptor) (0x00005b0c + (descriptor) * 0x20)
+/* bitmask for bitfield desc{d}_hd[c:0] */
+#define HW_ATL_RDM_DESCDHD_MSK 0x00001fff
+/* inverted bitmask for bitfield desc{d}_hd[c:0] */
+#define HW_ATL_RDM_DESCDHD_MSKN 0xffffe000
+/* lower bit position of bitfield desc{d}_hd[c:0] */
+#define HW_ATL_RDM_DESCDHD_SHIFT 0
+/* width of bitfield desc{d}_hd[c:0] */
+#define HW_ATL_RDM_DESCDHD_WIDTH 13
+
+/* rx desc{d}_len[9:0] bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_len[9:0]".
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ * port="pif_rdm_desc0_len_i[9:0]"
+ */
+
+/* register address for bitfield desc{d}_len[9:0] */
+#define HW_ATL_RDM_DESCDLEN_ADR(descriptor) (0x00005b08 + (descriptor) * 0x20)
+/* bitmask for bitfield desc{d}_len[9:0] */
+#define HW_ATL_RDM_DESCDLEN_MSK 0x00001ff8
+/* inverted bitmask for bitfield desc{d}_len[9:0] */
+#define HW_ATL_RDM_DESCDLEN_MSKN 0xffffe007
+/* lower bit position of bitfield desc{d}_len[9:0] */
+#define HW_ATL_RDM_DESCDLEN_SHIFT 3
+/* width of bitfield desc{d}_len[9:0] */
+#define HW_ATL_RDM_DESCDLEN_WIDTH 10
+/* default value of bitfield desc{d}_len[9:0] */
+#define HW_ATL_RDM_DESCDLEN_DEFAULT 0x0
+
+/* rx desc{d}_reset bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_reset".
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ * port="pif_rdm_q_pf_res_i[0]"
+ */
+
+/* register address for bitfield desc{d}_reset */
+#define HW_ATL_RDM_DESCDRESET_ADR(descriptor) (0x00005b08 + (descriptor) * 0x20)
+/* bitmask for bitfield desc{d}_reset */
+#define HW_ATL_RDM_DESCDRESET_MSK 0x02000000
+/* inverted bitmask for bitfield desc{d}_reset */
+#define HW_ATL_RDM_DESCDRESET_MSKN 0xfdffffff
+/* lower bit position of bitfield desc{d}_reset */
+#define HW_ATL_RDM_DESCDRESET_SHIFT 25
+/* width of bitfield desc{d}_reset */
+#define HW_ATL_RDM_DESCDRESET_WIDTH 1
+/* default value of bitfield desc{d}_reset */
+#define HW_ATL_RDM_DESCDRESET_DEFAULT 0x0
+
+/* rx int_desc_wrb_en bitfield definitions
+ * preprocessor definitions for the bitfield "int_desc_wrb_en".
+ * port="pif_rdm_int_desc_wrb_en_i"
+ */
+
+/* register address for bitfield int_desc_wrb_en */
+#define HW_ATL_RDM_INT_DESC_WRB_EN_ADR 0x00005a30
+/* bitmask for bitfield int_desc_wrb_en */
+#define HW_ATL_RDM_INT_DESC_WRB_EN_MSK 0x00000004
+/* inverted bitmask for bitfield int_desc_wrb_en */
+#define HW_ATL_RDM_INT_DESC_WRB_EN_MSKN 0xfffffffb
+/* lower bit position of bitfield int_desc_wrb_en */
+#define HW_ATL_RDM_INT_DESC_WRB_EN_SHIFT 2
+/* width of bitfield int_desc_wrb_en */
+#define HW_ATL_RDM_INT_DESC_WRB_EN_WIDTH 1
+/* default value of bitfield int_desc_wrb_en */
+#define HW_ATL_RDM_INT_DESC_WRB_EN_DEFAULT 0x0
+
+/* rx dca{d}_hdr_en bitfield definitions
+ * preprocessor definitions for the bitfield "dca{d}_hdr_en".
+ * parameter: dca {d} | stride size 0x4 | range [0, 31]
+ * port="pif_rdm_dca_hdr_en_i[0]"
+ */
+
+/* register address for bitfield dca{d}_hdr_en */
+#define HW_ATL_RDM_DCADHDR_EN_ADR(dca) (0x00006100 + (dca) * 0x4)
+/* bitmask for bitfield dca{d}_hdr_en */
+#define HW_ATL_RDM_DCADHDR_EN_MSK 0x40000000
+/* inverted bitmask for bitfield dca{d}_hdr_en */
+#define HW_ATL_RDM_DCADHDR_EN_MSKN 0xbfffffff
+/* lower bit position of bitfield dca{d}_hdr_en */
+#define HW_ATL_RDM_DCADHDR_EN_SHIFT 30
+/* width of bitfield dca{d}_hdr_en */
+#define HW_ATL_RDM_DCADHDR_EN_WIDTH 1
+/* default value of bitfield dca{d}_hdr_en */
+#define HW_ATL_RDM_DCADHDR_EN_DEFAULT 0x0
+
+/* rx dca{d}_pay_en bitfield definitions
+ * preprocessor definitions for the bitfield "dca{d}_pay_en".
+ * parameter: dca {d} | stride size 0x4 | range [0, 31]
+ * port="pif_rdm_dca_pay_en_i[0]"
+ */
+
+/* register address for bitfield dca{d}_pay_en */
+#define HW_ATL_RDM_DCADPAY_EN_ADR(dca) (0x00006100 + (dca) * 0x4)
+/* bitmask for bitfield dca{d}_pay_en */
+#define HW_ATL_RDM_DCADPAY_EN_MSK 0x20000000
+/* inverted bitmask for bitfield dca{d}_pay_en */
+#define HW_ATL_RDM_DCADPAY_EN_MSKN 0xdfffffff
+/* lower bit position of bitfield dca{d}_pay_en */
+#define HW_ATL_RDM_DCADPAY_EN_SHIFT 29
+/* width of bitfield dca{d}_pay_en */
+#define HW_ATL_RDM_DCADPAY_EN_WIDTH 1
+/* default value of bitfield dca{d}_pay_en */
+#define HW_ATL_RDM_DCADPAY_EN_DEFAULT 0x0
+
+/* RX rdm_int_rim_en Bitfield Definitions
+ * Preprocessor definitions for the bitfield "rdm_int_rim_en".
+ * PORT="pif_rdm_int_rim_en_i"
+ */
+
+/* Register address for bitfield rdm_int_rim_en */
+#define HW_ATL_RDM_INT_RIM_EN_ADR 0x00005A30
+/* Bitmask for bitfield rdm_int_rim_en */
+#define HW_ATL_RDM_INT_RIM_EN_MSK 0x00000008
+/* Inverted bitmask for bitfield rdm_int_rim_en */
+#define HW_ATL_RDM_INT_RIM_EN_MSKN 0xFFFFFFF7
+/* Lower bit position of bitfield rdm_int_rim_en */
+#define HW_ATL_RDM_INT_RIM_EN_SHIFT 3
+/* Width of bitfield rdm_int_rim_en */
+#define HW_ATL_RDM_INT_RIM_EN_WIDTH 1
+/* Default value of bitfield rdm_int_rim_en */
+#define HW_ATL_RDM_INT_RIM_EN_DEFAULT 0x0
+
+/* general interrupt mapping register definitions
+ * preprocessor definitions for general interrupt mapping register
+ * base address: 0x00002180
+ * parameter: regidx {f} | stride size 0x4 | range [0, 3]
+ */
+#define HW_ATL_GEN_INTR_MAP_ADR(regidx) (0x00002180u + (regidx) * 0x4)
+
+/* general interrupt status register definitions
+ * preprocessor definitions for general interrupt status register
+ * address: 0x000021A0
+ */
+
+#define HW_ATL_GEN_INTR_STAT_ADR 0x000021A4U
+
+/* interrupt global control register  definitions
+ * preprocessor definitions for interrupt global control register
+ * address: 0x00002300
+ */
+#define HW_ATL_INTR_GLB_CTL_ADR 0x00002300u
+
+/* interrupt throttle register definitions
+ * preprocessor definitions for interrupt throttle register
+ * base address: 0x00002800
+ * parameter: throttle {t} | stride size 0x4 | range [0, 31]
+ */
+#define HW_ATL_INTR_THR_ADR(throttle) (0x00002800u + (throttle) * 0x4)
+
+/* rx dma descriptor base address lsw definitions
+ * preprocessor definitions for rx dma descriptor base address lsw
+ * base address: 0x00005b00
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ */
+#define HW_ATL_RX_DMA_DESC_BASE_ADDRLSW_ADR(descriptor) \
+(0x00005b00u + (descriptor) * 0x20)
+
+/* rx dma descriptor base address msw definitions
+ * preprocessor definitions for rx dma descriptor base address msw
+ * base address: 0x00005b04
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ */
+#define HW_ATL_RX_DMA_DESC_BASE_ADDRMSW_ADR(descriptor) \
+(0x00005b04u + (descriptor) * 0x20)
+
+/* rx dma descriptor status register definitions
+ * preprocessor definitions for rx dma descriptor status register
+ * base address: 0x00005b14
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ */
+#define HW_ATL_RX_DMA_DESC_STAT_ADR(descriptor) \
+	(0x00005b14u + (descriptor) * 0x20)
+
+/* rx dma descriptor tail pointer register definitions
+ * preprocessor definitions for rx dma descriptor tail pointer register
+ * base address: 0x00005b10
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ */
+#define HW_ATL_RX_DMA_DESC_TAIL_PTR_ADR(descriptor) \
+	(0x00005b10u + (descriptor) * 0x20)
+
+/* rx interrupt moderation control register definitions
+ * Preprocessor definitions for RX Interrupt Moderation Control Register
+ * Base Address: 0x00005A40
+ * Parameter: RIM {R} | stride size 0x4 | range [0, 31]
+ */
+#define HW_ATL_RX_INTR_MODERATION_CTL_ADR(rim) (0x00005A40u + (rim) * 0x4)
+
+/* rx filter multicast filter mask register definitions
+ * preprocessor definitions for rx filter multicast filter mask register
+ * address: 0x00005270
+ */
+#define HW_ATL_RX_FLR_MCST_FLR_MSK_ADR 0x00005270u
+
+/* rx filter multicast filter register definitions
+ * preprocessor definitions for rx filter multicast filter register
+ * base address: 0x00005250
+ * parameter: filter {f} | stride size 0x4 | range [0, 7]
+ */
+#define HW_ATL_RX_FLR_MCST_FLR_ADR(filter) (0x00005250u + (filter) * 0x4)
+
+/* RX Filter RSS Control Register 1 Definitions
+ * Preprocessor definitions for RX Filter RSS Control Register 1
+ * Address: 0x000054C0
+ */
+#define HW_ATL_RX_FLR_RSS_CONTROL1_ADR 0x000054C0u
+
+/* RX Filter Control Register 2 Definitions
+ * Preprocessor definitions for RX Filter Control Register 2
+ * Address: 0x00005104
+ */
+#define HW_ATL_RX_FLR_CONTROL2_ADR 0x00005104u
+
+/* tx tx dma debug control [1f:0] bitfield definitions
+ * preprocessor definitions for the bitfield "tx dma debug control [1f:0]".
+ * port="pif_tdm_debug_cntl_i[31:0]"
+ */
+
+/* register address for bitfield tx dma debug control [1f:0] */
+#define HW_ATL_TDM_TX_DMA_DEBUG_CTL_ADR 0x00008920
+/* bitmask for bitfield tx dma debug control [1f:0] */
+#define HW_ATL_TDM_TX_DMA_DEBUG_CTL_MSK 0xffffffff
+/* inverted bitmask for bitfield tx dma debug control [1f:0] */
+#define HW_ATL_TDM_TX_DMA_DEBUG_CTL_MSKN 0x00000000
+/* lower bit position of bitfield tx dma debug control [1f:0] */
+#define HW_ATL_TDM_TX_DMA_DEBUG_CTL_SHIFT 0
+/* width of bitfield tx dma debug control [1f:0] */
+#define HW_ATL_TDM_TX_DMA_DEBUG_CTL_WIDTH 32
+/* default value of bitfield tx dma debug control [1f:0] */
+#define HW_ATL_TDM_TX_DMA_DEBUG_CTL_DEFAULT 0x0
+
+/* tx dma descriptor base address lsw definitions
+ * preprocessor definitions for tx dma descriptor base address lsw
+ * base address: 0x00007c00
+ * parameter: descriptor {d} | stride size 0x40 | range [0, 31]
+ */
+#define HW_ATL_TX_DMA_DESC_BASE_ADDRLSW_ADR(descriptor) \
+	(0x00007c00u + (descriptor) * 0x40)
+
+/* tx dma descriptor tail pointer register definitions
+ * preprocessor definitions for tx dma descriptor tail pointer register
+ * base address: 0x00007c10
+ *  parameter: descriptor {d} | stride size 0x40 | range [0, 31]
+ */
+#define HW_ATL_TX_DMA_DESC_TAIL_PTR_ADR(descriptor) \
+	(0x00007c10u + (descriptor) * 0x40)
+
+/* rx dma_sys_loopback bitfield definitions
+ * preprocessor definitions for the bitfield "dma_sys_loopback".
+ * port="pif_rpb_dma_sys_lbk_i"
+ */
+
+/* register address for bitfield dma_sys_loopback */
+#define HW_ATL_RPB_DMA_SYS_LBK_ADR 0x00005000
+/* bitmask for bitfield dma_sys_loopback */
+#define HW_ATL_RPB_DMA_SYS_LBK_MSK 0x00000040
+/* inverted bitmask for bitfield dma_sys_loopback */
+#define HW_ATL_RPB_DMA_SYS_LBK_MSKN 0xffffffbf
+/* lower bit position of bitfield dma_sys_loopback */
+#define HW_ATL_RPB_DMA_SYS_LBK_SHIFT 6
+/* width of bitfield dma_sys_loopback */
+#define HW_ATL_RPB_DMA_SYS_LBK_WIDTH 1
+/* default value of bitfield dma_sys_loopback */
+#define HW_ATL_RPB_DMA_SYS_LBK_DEFAULT 0x0
+
+/* rx rx_tc_mode bitfield definitions
+ * preprocessor definitions for the bitfield "rx_tc_mode".
+ * port="pif_rpb_rx_tc_mode_i,pif_rpf_rx_tc_mode_i"
+ */
+
+/* register address for bitfield rx_tc_mode */
+#define HW_ATL_RPB_RPF_RX_TC_MODE_ADR 0x00005700
+/* bitmask for bitfield rx_tc_mode */
+#define HW_ATL_RPB_RPF_RX_TC_MODE_MSK 0x00000100
+/* inverted bitmask for bitfield rx_tc_mode */
+#define HW_ATL_RPB_RPF_RX_TC_MODE_MSKN 0xfffffeff
+/* lower bit position of bitfield rx_tc_mode */
+#define HW_ATL_RPB_RPF_RX_TC_MODE_SHIFT 8
+/* width of bitfield rx_tc_mode */
+#define HW_ATL_RPB_RPF_RX_TC_MODE_WIDTH 1
+/* default value of bitfield rx_tc_mode */
+#define HW_ATL_RPB_RPF_RX_TC_MODE_DEFAULT 0x0
+
+/* rx rx_buf_en bitfield definitions
+ * preprocessor definitions for the bitfield "rx_buf_en".
+ * port="pif_rpb_rx_buf_en_i"
+ */
+
+/* register address for bitfield rx_buf_en */
+#define HW_ATL_RPB_RX_BUF_EN_ADR 0x00005700
+/* bitmask for bitfield rx_buf_en */
+#define HW_ATL_RPB_RX_BUF_EN_MSK 0x00000001
+/* inverted bitmask for bitfield rx_buf_en */
+#define HW_ATL_RPB_RX_BUF_EN_MSKN 0xfffffffe
+/* lower bit position of bitfield rx_buf_en */
+#define HW_ATL_RPB_RX_BUF_EN_SHIFT 0
+/* width of bitfield rx_buf_en */
+#define HW_ATL_RPB_RX_BUF_EN_WIDTH 1
+/* default value of bitfield rx_buf_en */
+#define HW_ATL_RPB_RX_BUF_EN_DEFAULT 0x0
+
+/* rx rx{b}_hi_thresh[d:0] bitfield definitions
+ * preprocessor definitions for the bitfield "rx{b}_hi_thresh[d:0]".
+ * parameter: buffer {b} | stride size 0x10 | range [0, 7]
+ * port="pif_rpb_rx0_hi_thresh_i[13:0]"
+ */
+
+/* register address for bitfield rx{b}_hi_thresh[d:0] */
+#define HW_ATL_RPB_RXBHI_THRESH_ADR(buffer) (0x00005714 + (buffer) * 0x10)
+/* bitmask for bitfield rx{b}_hi_thresh[d:0] */
+#define HW_ATL_RPB_RXBHI_THRESH_MSK 0x3fff0000
+/* inverted bitmask for bitfield rx{b}_hi_thresh[d:0] */
+#define HW_ATL_RPB_RXBHI_THRESH_MSKN 0xc000ffff
+/* lower bit position of bitfield rx{b}_hi_thresh[d:0] */
+#define HW_ATL_RPB_RXBHI_THRESH_SHIFT 16
+/* width of bitfield rx{b}_hi_thresh[d:0] */
+#define HW_ATL_RPB_RXBHI_THRESH_WIDTH 14
+/* default value of bitfield rx{b}_hi_thresh[d:0] */
+#define HW_ATL_RPB_RXBHI_THRESH_DEFAULT 0x0
+
+/* rx rx{b}_lo_thresh[d:0] bitfield definitions
+ * preprocessor definitions for the bitfield "rx{b}_lo_thresh[d:0]".
+ * parameter: buffer {b} | stride size 0x10 | range [0, 7]
+ * port="pif_rpb_rx0_lo_thresh_i[13:0]"
+ */
+
+/* register address for bitfield rx{b}_lo_thresh[d:0] */
+#define HW_ATL_RPB_RXBLO_THRESH_ADR(buffer) (0x00005714 + (buffer) * 0x10)
+/* bitmask for bitfield rx{b}_lo_thresh[d:0] */
+#define HW_ATL_RPB_RXBLO_THRESH_MSK 0x00003fff
+/* inverted bitmask for bitfield rx{b}_lo_thresh[d:0] */
+#define HW_ATL_RPB_RXBLO_THRESH_MSKN 0xffffc000
+/* lower bit position of bitfield rx{b}_lo_thresh[d:0] */
+#define HW_ATL_RPB_RXBLO_THRESH_SHIFT 0
+/* width of bitfield rx{b}_lo_thresh[d:0] */
+#define HW_ATL_RPB_RXBLO_THRESH_WIDTH 14
+/* default value of bitfield rx{b}_lo_thresh[d:0] */
+#define HW_ATL_RPB_RXBLO_THRESH_DEFAULT 0x0
+
+/* rx rx_fc_mode[1:0] bitfield definitions
+ * preprocessor definitions for the bitfield "rx_fc_mode[1:0]".
+ * port="pif_rpb_rx_fc_mode_i[1:0]"
+ */
+
+/* register address for bitfield rx_fc_mode[1:0] */
+#define HW_ATL_RPB_RX_FC_MODE_ADR 0x00005700
+/* bitmask for bitfield rx_fc_mode[1:0] */
+#define HW_ATL_RPB_RX_FC_MODE_MSK 0x00000030
+/* inverted bitmask for bitfield rx_fc_mode[1:0] */
+#define HW_ATL_RPB_RX_FC_MODE_MSKN 0xffffffcf
+/* lower bit position of bitfield rx_fc_mode[1:0] */
+#define HW_ATL_RPB_RX_FC_MODE_SHIFT 4
+/* width of bitfield rx_fc_mode[1:0] */
+#define HW_ATL_RPB_RX_FC_MODE_WIDTH 2
+/* default value of bitfield rx_fc_mode[1:0] */
+#define HW_ATL_RPB_RX_FC_MODE_DEFAULT 0x0
+
+/* rx rx{b}_buf_size[8:0] bitfield definitions
+ * preprocessor definitions for the bitfield "rx{b}_buf_size[8:0]".
+ * parameter: buffer {b} | stride size 0x10 | range [0, 7]
+ * port="pif_rpb_rx0_buf_size_i[8:0]"
+ */
+
+/* register address for bitfield rx{b}_buf_size[8:0] */
+#define HW_ATL_RPB_RXBBUF_SIZE_ADR(buffer) (0x00005710 + (buffer) * 0x10)
+/* bitmask for bitfield rx{b}_buf_size[8:0] */
+#define HW_ATL_RPB_RXBBUF_SIZE_MSK 0x000001ff
+/* inverted bitmask for bitfield rx{b}_buf_size[8:0] */
+#define HW_ATL_RPB_RXBBUF_SIZE_MSKN 0xfffffe00
+/* lower bit position of bitfield rx{b}_buf_size[8:0] */
+#define HW_ATL_RPB_RXBBUF_SIZE_SHIFT 0
+/* width of bitfield rx{b}_buf_size[8:0] */
+#define HW_ATL_RPB_RXBBUF_SIZE_WIDTH 9
+/* default value of bitfield rx{b}_buf_size[8:0] */
+#define HW_ATL_RPB_RXBBUF_SIZE_DEFAULT 0x0
+
+/* rx rx{b}_xoff_en bitfield definitions
+ * preprocessor definitions for the bitfield "rx{b}_xoff_en".
+ * parameter: buffer {b} | stride size 0x10 | range [0, 7]
+ * port="pif_rpb_rx_xoff_en_i[0]"
+ */
+
+/* register address for bitfield rx{b}_xoff_en */
+#define HW_ATL_RPB_RXBXOFF_EN_ADR(buffer) (0x00005714 + (buffer) * 0x10)
+/* bitmask for bitfield rx{b}_xoff_en */
+#define HW_ATL_RPB_RXBXOFF_EN_MSK 0x80000000
+/* inverted bitmask for bitfield rx{b}_xoff_en */
+#define HW_ATL_RPB_RXBXOFF_EN_MSKN 0x7fffffff
+/* lower bit position of bitfield rx{b}_xoff_en */
+#define HW_ATL_RPB_RXBXOFF_EN_SHIFT 31
+/* width of bitfield rx{b}_xoff_en */
+#define HW_ATL_RPB_RXBXOFF_EN_WIDTH 1
+/* default value of bitfield rx{b}_xoff_en */
+#define HW_ATL_RPB_RXBXOFF_EN_DEFAULT 0x0
+
+/* rx l2_bc_thresh[f:0] bitfield definitions
+ * preprocessor definitions for the bitfield "l2_bc_thresh[f:0]".
+ * port="pif_rpf_l2_bc_thresh_i[15:0]"
+ */
+
+/* register address for bitfield l2_bc_thresh[f:0] */
+#define HW_ATL_RPFL2BC_THRESH_ADR 0x00005100
+/* bitmask for bitfield l2_bc_thresh[f:0] */
+#define HW_ATL_RPFL2BC_THRESH_MSK 0xffff0000
+/* inverted bitmask for bitfield l2_bc_thresh[f:0] */
+#define HW_ATL_RPFL2BC_THRESH_MSKN 0x0000ffff
+/* lower bit position of bitfield l2_bc_thresh[f:0] */
+#define HW_ATL_RPFL2BC_THRESH_SHIFT 16
+/* width of bitfield l2_bc_thresh[f:0] */
+#define HW_ATL_RPFL2BC_THRESH_WIDTH 16
+/* default value of bitfield l2_bc_thresh[f:0] */
+#define HW_ATL_RPFL2BC_THRESH_DEFAULT 0x0
+
+/* rx l2_bc_en bitfield definitions
+ * preprocessor definitions for the bitfield "l2_bc_en".
+ * port="pif_rpf_l2_bc_en_i"
+ */
+
+/* register address for bitfield l2_bc_en */
+#define HW_ATL_RPFL2BC_EN_ADR 0x00005100
+/* bitmask for bitfield l2_bc_en */
+#define HW_ATL_RPFL2BC_EN_MSK 0x00000001
+/* inverted bitmask for bitfield l2_bc_en */
+#define HW_ATL_RPFL2BC_EN_MSKN 0xfffffffe
+/* lower bit position of bitfield l2_bc_en */
+#define HW_ATL_RPFL2BC_EN_SHIFT 0
+/* width of bitfield l2_bc_en */
+#define HW_ATL_RPFL2BC_EN_WIDTH 1
+/* default value of bitfield l2_bc_en */
+#define HW_ATL_RPFL2BC_EN_DEFAULT 0x0
+
+/* rx l2_bc_act[2:0] bitfield definitions
+ * preprocessor definitions for the bitfield "l2_bc_act[2:0]".
+ * port="pif_rpf_l2_bc_act_i[2:0]"
+ */
+
+/* register address for bitfield l2_bc_act[2:0] */
+#define HW_ATL_RPFL2BC_ACT_ADR 0x00005100
+/* bitmask for bitfield l2_bc_act[2:0] */
+#define HW_ATL_RPFL2BC_ACT_MSK 0x00007000
+/* inverted bitmask for bitfield l2_bc_act[2:0] */
+#define HW_ATL_RPFL2BC_ACT_MSKN 0xffff8fff
+/* lower bit position of bitfield l2_bc_act[2:0] */
+#define HW_ATL_RPFL2BC_ACT_SHIFT 12
+/* width of bitfield l2_bc_act[2:0] */
+#define HW_ATL_RPFL2BC_ACT_WIDTH 3
+/* default value of bitfield l2_bc_act[2:0] */
+#define HW_ATL_RPFL2BC_ACT_DEFAULT 0x0
+
+/* rx l2_mc_en{f} bitfield definitions
+ * preprocessor definitions for the bitfield "l2_mc_en{f}".
+ * parameter: filter {f} | stride size 0x4 | range [0, 7]
+ * port="pif_rpf_l2_mc_en_i[0]"
+ */
+
+/* register address for bitfield l2_mc_en{f} */
+#define HW_ATL_RPFL2MC_ENF_ADR(filter) (0x00005250 + (filter) * 0x4)
+/* bitmask for bitfield l2_mc_en{f} */
+#define HW_ATL_RPFL2MC_ENF_MSK 0x80000000
+/* inverted bitmask for bitfield l2_mc_en{f} */
+#define HW_ATL_RPFL2MC_ENF_MSKN 0x7fffffff
+/* lower bit position of bitfield l2_mc_en{f} */
+#define HW_ATL_RPFL2MC_ENF_SHIFT 31
+/* width of bitfield l2_mc_en{f} */
+#define HW_ATL_RPFL2MC_ENF_WIDTH 1
+/* default value of bitfield l2_mc_en{f} */
+#define HW_ATL_RPFL2MC_ENF_DEFAULT 0x0
+
+/* rx l2_promis_mode bitfield definitions
+ * preprocessor definitions for the bitfield "l2_promis_mode".
+ * port="pif_rpf_l2_promis_mode_i"
+ */
+
+/* register address for bitfield l2_promis_mode */
+#define HW_ATL_RPFL2PROMIS_MODE_ADR 0x00005100
+/* bitmask for bitfield l2_promis_mode */
+#define HW_ATL_RPFL2PROMIS_MODE_MSK 0x00000008
+/* inverted bitmask for bitfield l2_promis_mode */
+#define HW_ATL_RPFL2PROMIS_MODE_MSKN 0xfffffff7
+/* lower bit position of bitfield l2_promis_mode */
+#define HW_ATL_RPFL2PROMIS_MODE_SHIFT 3
+/* width of bitfield l2_promis_mode */
+#define HW_ATL_RPFL2PROMIS_MODE_WIDTH 1
+/* default value of bitfield l2_promis_mode */
+#define HW_ATL_RPFL2PROMIS_MODE_DEFAULT 0x0
+
+/* rx l2_uc_act{f}[2:0] bitfield definitions
+ * preprocessor definitions for the bitfield "l2_uc_act{f}[2:0]".
+ * parameter: filter {f} | stride size 0x8 | range [0, 37]
+ * port="pif_rpf_l2_uc_act0_i[2:0]"
+ */
+
+/* register address for bitfield l2_uc_act{f}[2:0] */
+#define HW_ATL_RPFL2UC_ACTF_ADR(filter) (0x00005114 + (filter) * 0x8)
+/* bitmask for bitfield l2_uc_act{f}[2:0] */
+#define HW_ATL_RPFL2UC_ACTF_MSK 0x00070000
+/* inverted bitmask for bitfield l2_uc_act{f}[2:0] */
+#define HW_ATL_RPFL2UC_ACTF_MSKN 0xfff8ffff
+/* lower bit position of bitfield l2_uc_act{f}[2:0] */
+#define HW_ATL_RPFL2UC_ACTF_SHIFT 16
+/* width of bitfield l2_uc_act{f}[2:0] */
+#define HW_ATL_RPFL2UC_ACTF_WIDTH 3
+/* default value of bitfield l2_uc_act{f}[2:0] */
+#define HW_ATL_RPFL2UC_ACTF_DEFAULT 0x0
+
+/* rx l2_uc_en{f} bitfield definitions
+ * preprocessor definitions for the bitfield "l2_uc_en{f}".
+ * parameter: filter {f} | stride size 0x8 | range [0, 37]
+ * port="pif_rpf_l2_uc_en_i[0]"
+ */
+
+/* register address for bitfield l2_uc_en{f} */
+#define HW_ATL_RPFL2UC_ENF_ADR(filter) (0x00005114 + (filter) * 0x8)
+/* bitmask for bitfield l2_uc_en{f} */
+#define HW_ATL_RPFL2UC_ENF_MSK 0x80000000
+/* inverted bitmask for bitfield l2_uc_en{f} */
+#define HW_ATL_RPFL2UC_ENF_MSKN 0x7fffffff
+/* lower bit position of bitfield l2_uc_en{f} */
+#define HW_ATL_RPFL2UC_ENF_SHIFT 31
+/* width of bitfield l2_uc_en{f} */
+#define HW_ATL_RPFL2UC_ENF_WIDTH 1
+/* default value of bitfield l2_uc_en{f} */
+#define HW_ATL_RPFL2UC_ENF_DEFAULT 0x0
+
+/* register address for bitfield l2_uc_da{f}_lsw[1f:0] */
+#define HW_ATL_RPFL2UC_DAFLSW_ADR(filter) (0x00005110 + (filter) * 0x8)
+/* register address for bitfield l2_uc_da{f}_msw[f:0] */
+#define HW_ATL_RPFL2UC_DAFMSW_ADR(filter) (0x00005114 + (filter) * 0x8)
+/* bitmask for bitfield l2_uc_da{f}_msw[f:0] */
+#define HW_ATL_RPFL2UC_DAFMSW_MSK 0x0000ffff
+/* lower bit position of bitfield l2_uc_da{f}_msw[f:0] */
+#define HW_ATL_RPFL2UC_DAFMSW_SHIFT 0
+
+/* rx l2_mc_accept_all bitfield definitions
+ * Preprocessor definitions for the bitfield "l2_mc_accept_all".
+ * PORT="pif_rpf_l2_mc_all_accept_i"
+ */
+
+/* Register address for bitfield l2_mc_accept_all */
+#define HW_ATL_RPFL2MC_ACCEPT_ALL_ADR 0x00005270
+/* Bitmask for bitfield l2_mc_accept_all */
+#define HW_ATL_RPFL2MC_ACCEPT_ALL_MSK 0x00004000
+/* Inverted bitmask for bitfield l2_mc_accept_all */
+#define HW_ATL_RPFL2MC_ACCEPT_ALL_MSKN 0xFFFFBFFF
+/* Lower bit position of bitfield l2_mc_accept_all */
+#define HW_ATL_RPFL2MC_ACCEPT_ALL_SHIFT 14
+/* Width of bitfield l2_mc_accept_all */
+#define HW_ATL_RPFL2MC_ACCEPT_ALL_WIDTH 1
+/* Default value of bitfield l2_mc_accept_all */
+#define HW_ATL_RPFL2MC_ACCEPT_ALL_DEFAULT 0x0
+
+/* width of bitfield rx_tc_up{t}[2:0] */
+#define HW_ATL_RPF_RPB_RX_TC_UPT_WIDTH 3
+/* default value of bitfield rx_tc_up{t}[2:0] */
+#define HW_ATL_RPF_RPB_RX_TC_UPT_DEFAULT 0x0
+
+/* rx rss_key_addr[4:0] bitfield definitions
+ * preprocessor definitions for the bitfield "rss_key_addr[4:0]".
+ * port="pif_rpf_rss_key_addr_i[4:0]"
+ */
+
+/* register address for bitfield rss_key_addr[4:0] */
+#define HW_ATL_RPF_RSS_KEY_ADDR_ADR 0x000054d0
+/* bitmask for bitfield rss_key_addr[4:0] */
+#define HW_ATL_RPF_RSS_KEY_ADDR_MSK 0x0000001f
+/* inverted bitmask for bitfield rss_key_addr[4:0] */
+#define HW_ATL_RPF_RSS_KEY_ADDR_MSKN 0xffffffe0
+/* lower bit position of bitfield rss_key_addr[4:0] */
+#define HW_ATL_RPF_RSS_KEY_ADDR_SHIFT 0
+/* width of bitfield rss_key_addr[4:0] */
+#define HW_ATL_RPF_RSS_KEY_ADDR_WIDTH 5
+/* default value of bitfield rss_key_addr[4:0] */
+#define HW_ATL_RPF_RSS_KEY_ADDR_DEFAULT 0x0
+
+/* rx rss_key_wr_data[1f:0] bitfield definitions
+ * preprocessor definitions for the bitfield "rss_key_wr_data[1f:0]".
+ * port="pif_rpf_rss_key_wr_data_i[31:0]"
+ */
+
+/* register address for bitfield rss_key_wr_data[1f:0] */
+#define HW_ATL_RPF_RSS_KEY_WR_DATA_ADR 0x000054d4
+/* bitmask for bitfield rss_key_wr_data[1f:0] */
+#define HW_ATL_RPF_RSS_KEY_WR_DATA_MSK 0xffffffff
+/* inverted bitmask for bitfield rss_key_wr_data[1f:0] */
+#define HW_ATL_RPF_RSS_KEY_WR_DATA_MSKN 0x00000000
+/* lower bit position of bitfield rss_key_wr_data[1f:0] */
+#define HW_ATL_RPF_RSS_KEY_WR_DATA_SHIFT 0
+/* width of bitfield rss_key_wr_data[1f:0] */
+#define HW_ATL_RPF_RSS_KEY_WR_DATA_WIDTH 32
+/* default value of bitfield rss_key_wr_data[1f:0] */
+#define HW_ATL_RPF_RSS_KEY_WR_DATA_DEFAULT 0x0
+
+/* rx rss_key_wr_en_i bitfield definitions
+ * preprocessor definitions for the bitfield "rss_key_wr_en_i".
+ * port="pif_rpf_rss_key_wr_en_i"
+ */
+
+/* register address for bitfield rss_key_wr_en_i */
+#define HW_ATL_RPF_RSS_KEY_WR_ENI_ADR 0x000054d0
+/* bitmask for bitfield rss_key_wr_en_i */
+#define HW_ATL_RPF_RSS_KEY_WR_ENI_MSK 0x00000020
+/* inverted bitmask for bitfield rss_key_wr_en_i */
+#define HW_ATL_RPF_RSS_KEY_WR_ENI_MSKN 0xffffffdf
+/* lower bit position of bitfield rss_key_wr_en_i */
+#define HW_ATL_RPF_RSS_KEY_WR_ENI_SHIFT 5
+/* width of bitfield rss_key_wr_en_i */
+#define HW_ATL_RPF_RSS_KEY_WR_ENI_WIDTH 1
+/* default value of bitfield rss_key_wr_en_i */
+#define HW_ATL_RPF_RSS_KEY_WR_ENI_DEFAULT 0x0
+
+/* rx rss_redir_addr[3:0] bitfield definitions
+ * preprocessor definitions for the bitfield "rss_redir_addr[3:0]".
+ * port="pif_rpf_rss_redir_addr_i[3:0]"
+ */
+
+/* register address for bitfield rss_redir_addr[3:0] */
+#define HW_ATL_RPF_RSS_REDIR_ADDR_ADR 0x000054e0
+/* bitmask for bitfield rss_redir_addr[3:0] */
+#define HW_ATL_RPF_RSS_REDIR_ADDR_MSK 0x0000000f
+/* inverted bitmask for bitfield rss_redir_addr[3:0] */
+#define HW_ATL_RPF_RSS_REDIR_ADDR_MSKN 0xfffffff0
+/* lower bit position of bitfield rss_redir_addr[3:0] */
+#define HW_ATL_RPF_RSS_REDIR_ADDR_SHIFT 0
+/* width of bitfield rss_redir_addr[3:0] */
+#define HW_ATL_RPF_RSS_REDIR_ADDR_WIDTH 4
+/* default value of bitfield rss_redir_addr[3:0] */
+#define HW_ATL_RPF_RSS_REDIR_ADDR_DEFAULT 0x0
+
+/* rx rss_redir_wr_data[f:0] bitfield definitions
+ * preprocessor definitions for the bitfield "rss_redir_wr_data[f:0]".
+ * port="pif_rpf_rss_redir_wr_data_i[15:0]"
+ */
+
+/* register address for bitfield rss_redir_wr_data[f:0] */
+#define HW_ATL_RPF_RSS_REDIR_WR_DATA_ADR 0x000054e4
+/* bitmask for bitfield rss_redir_wr_data[f:0] */
+#define HW_ATL_RPF_RSS_REDIR_WR_DATA_MSK 0x0000ffff
+/* inverted bitmask for bitfield rss_redir_wr_data[f:0] */
+#define HW_ATL_RPF_RSS_REDIR_WR_DATA_MSKN 0xffff0000
+/* lower bit position of bitfield rss_redir_wr_data[f:0] */
+#define HW_ATL_RPF_RSS_REDIR_WR_DATA_SHIFT 0
+/* width of bitfield rss_redir_wr_data[f:0] */
+#define HW_ATL_RPF_RSS_REDIR_WR_DATA_WIDTH 16
+/* default value of bitfield rss_redir_wr_data[f:0] */
+#define HW_ATL_RPF_RSS_REDIR_WR_DATA_DEFAULT 0x0
+
+/* rx rss_redir_wr_en_i bitfield definitions
+ * preprocessor definitions for the bitfield "rss_redir_wr_en_i".
+ * port="pif_rpf_rss_redir_wr_en_i"
+ */
+
+/* register address for bitfield rss_redir_wr_en_i */
+#define HW_ATL_RPF_RSS_REDIR_WR_ENI_ADR 0x000054e0
+/* bitmask for bitfield rss_redir_wr_en_i */
+#define HW_ATL_RPF_RSS_REDIR_WR_ENI_MSK 0x00000010
+/* inverted bitmask for bitfield rss_redir_wr_en_i */
+#define HW_ATL_RPF_RSS_REDIR_WR_ENI_MSKN 0xffffffef
+/* lower bit position of bitfield rss_redir_wr_en_i */
+#define HW_ATL_RPF_RSS_REDIR_WR_ENI_SHIFT 4
+/* width of bitfield rss_redir_wr_en_i */
+#define HW_ATL_RPF_RSS_REDIR_WR_ENI_WIDTH 1
+/* default value of bitfield rss_redir_wr_en_i */
+#define HW_ATL_RPF_RSS_REDIR_WR_ENI_DEFAULT 0x0
+
+/* rx tpo_rpf_sys_loopback bitfield definitions
+ * preprocessor definitions for the bitfield "tpo_rpf_sys_loopback".
+ * port="pif_rpf_tpo_pkt_sys_lbk_i"
+ */
+
+/* register address for bitfield tpo_rpf_sys_loopback */
+#define HW_ATL_RPF_TPO_RPF_SYS_LBK_ADR 0x00005000
+/* bitmask for bitfield tpo_rpf_sys_loopback */
+#define HW_ATL_RPF_TPO_RPF_SYS_LBK_MSK 0x00000100
+/* inverted bitmask for bitfield tpo_rpf_sys_loopback */
+#define HW_ATL_RPF_TPO_RPF_SYS_LBK_MSKN 0xfffffeff
+/* lower bit position of bitfield tpo_rpf_sys_loopback */
+#define HW_ATL_RPF_TPO_RPF_SYS_LBK_SHIFT 8
+/* width of bitfield tpo_rpf_sys_loopback */
+#define HW_ATL_RPF_TPO_RPF_SYS_LBK_WIDTH 1
+/* default value of bitfield tpo_rpf_sys_loopback */
+#define HW_ATL_RPF_TPO_RPF_SYS_LBK_DEFAULT 0x0
+
+/* rx vl_inner_tpid[f:0] bitfield definitions
+ * preprocessor definitions for the bitfield "vl_inner_tpid[f:0]".
+ * port="pif_rpf_vl_inner_tpid_i[15:0]"
+ */
+
+/* register address for bitfield vl_inner_tpid[f:0] */
+#define HW_ATL_RPF_VL_INNER_TPID_ADR 0x00005284
+/* bitmask for bitfield vl_inner_tpid[f:0] */
+#define HW_ATL_RPF_VL_INNER_TPID_MSK 0x0000ffff
+/* inverted bitmask for bitfield vl_inner_tpid[f:0] */
+#define HW_ATL_RPF_VL_INNER_TPID_MSKN 0xffff0000
+/* lower bit position of bitfield vl_inner_tpid[f:0] */
+#define HW_ATL_RPF_VL_INNER_TPID_SHIFT 0
+/* width of bitfield vl_inner_tpid[f:0] */
+#define HW_ATL_RPF_VL_INNER_TPID_WIDTH 16
+/* default value of bitfield vl_inner_tpid[f:0] */
+#define HW_ATL_RPF_VL_INNER_TPID_DEFAULT 0x8100
+
+/* rx vl_outer_tpid[f:0] bitfield definitions
+ * preprocessor definitions for the bitfield "vl_outer_tpid[f:0]".
+ * port="pif_rpf_vl_outer_tpid_i[15:0]"
+ */
+
+/* register address for bitfield vl_outer_tpid[f:0] */
+#define HW_ATL_RPF_VL_OUTER_TPID_ADR 0x00005284
+/* bitmask for bitfield vl_outer_tpid[f:0] */
+#define HW_ATL_RPF_VL_OUTER_TPID_MSK 0xffff0000
+/* inverted bitmask for bitfield vl_outer_tpid[f:0] */
+#define HW_ATL_RPF_VL_OUTER_TPID_MSKN 0x0000ffff
+/* lower bit position of bitfield vl_outer_tpid[f:0] */
+#define HW_ATL_RPF_VL_OUTER_TPID_SHIFT 16
+/* width of bitfield vl_outer_tpid[f:0] */
+#define HW_ATL_RPF_VL_OUTER_TPID_WIDTH 16
+/* default value of bitfield vl_outer_tpid[f:0] */
+#define HW_ATL_RPF_VL_OUTER_TPID_DEFAULT 0x88a8
+
+/* rx vl_promis_mode bitfield definitions
+ * preprocessor definitions for the bitfield "vl_promis_mode".
+ * port="pif_rpf_vl_promis_mode_i"
+ */
+
+/* register address for bitfield vl_promis_mode */
+#define HW_ATL_RPF_VL_PROMIS_MODE_ADR 0x00005280
+/* bitmask for bitfield vl_promis_mode */
+#define HW_ATL_RPF_VL_PROMIS_MODE_MSK 0x00000002
+/* inverted bitmask for bitfield vl_promis_mode */
+#define HW_ATL_RPF_VL_PROMIS_MODE_MSKN 0xfffffffd
+/* lower bit position of bitfield vl_promis_mode */
+#define HW_ATL_RPF_VL_PROMIS_MODE_SHIFT 1
+/* width of bitfield vl_promis_mode */
+#define HW_ATL_RPF_VL_PROMIS_MODE_WIDTH 1
+/* default value of bitfield vl_promis_mode */
+#define HW_ATL_RPF_VL_PROMIS_MODE_DEFAULT 0x0
+
+/* RX vl_accept_untagged_mode Bitfield Definitions
+ * Preprocessor definitions for the bitfield "vl_accept_untagged_mode".
+ * PORT="pif_rpf_vl_accept_untagged_i"
+ */
+
+/* Register address for bitfield vl_accept_untagged_mode */
+#define HW_ATL_RPF_VL_ACCEPT_UNTAGGED_MODE_ADR 0x00005280
+/* Bitmask for bitfield vl_accept_untagged_mode */
+#define HW_ATL_RPF_VL_ACCEPT_UNTAGGED_MODE_MSK 0x00000004
+/* Inverted bitmask for bitfield vl_accept_untagged_mode */
+#define HW_ATL_RPF_VL_ACCEPT_UNTAGGED_MODE_MSKN 0xFFFFFFFB
+/* Lower bit position of bitfield vl_accept_untagged_mode */
+#define HW_ATL_RPF_VL_ACCEPT_UNTAGGED_MODE_SHIFT 2
+/* Width of bitfield vl_accept_untagged_mode */
+#define HW_ATL_RPF_VL_ACCEPT_UNTAGGED_MODE_WIDTH 1
+/* Default value of bitfield vl_accept_untagged_mode */
+#define HW_ATL_RPF_VL_ACCEPT_UNTAGGED_MODE_DEFAULT 0x0
+
+/* rX vl_untagged_act[2:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "vl_untagged_act[2:0]".
+ * PORT="pif_rpf_vl_untagged_act_i[2:0]"
+ */
+
+/* Register address for bitfield vl_untagged_act[2:0] */
+#define HW_ATL_RPF_VL_UNTAGGED_ACT_ADR 0x00005280
+/* Bitmask for bitfield vl_untagged_act[2:0] */
+#define HW_ATL_RPF_VL_UNTAGGED_ACT_MSK 0x00000038
+/* Inverted bitmask for bitfield vl_untagged_act[2:0] */
+#define HW_ATL_RPF_VL_UNTAGGED_ACT_MSKN 0xFFFFFFC7
+/* Lower bit position of bitfield vl_untagged_act[2:0] */
+#define HW_ATL_RPF_VL_UNTAGGED_ACT_SHIFT 3
+/* Width of bitfield vl_untagged_act[2:0] */
+#define HW_ATL_RPF_VL_UNTAGGED_ACT_WIDTH 3
+/* Default value of bitfield vl_untagged_act[2:0] */
+#define HW_ATL_RPF_VL_UNTAGGED_ACT_DEFAULT 0x0
+
+/* RX vl_en{F} Bitfield Definitions
+ * Preprocessor definitions for the bitfield "vl_en{F}".
+ * Parameter: filter {F} | stride size 0x4 | range [0, 15]
+ * PORT="pif_rpf_vl_en_i[0]"
+ */
+
+/* Register address for bitfield vl_en{F} */
+#define HW_ATL_RPF_VL_EN_F_ADR(filter) (0x00005290 + (filter) * 0x4)
+/* Bitmask for bitfield vl_en{F} */
+#define HW_ATL_RPF_VL_EN_F_MSK 0x80000000
+/* Inverted bitmask for bitfield vl_en{F} */
+#define HW_ATL_RPF_VL_EN_F_MSKN 0x7FFFFFFF
+/* Lower bit position of bitfield vl_en{F} */
+#define HW_ATL_RPF_VL_EN_F_SHIFT 31
+/* Width of bitfield vl_en{F} */
+#define HW_ATL_RPF_VL_EN_F_WIDTH 1
+/* Default value of bitfield vl_en{F} */
+#define HW_ATL_RPF_VL_EN_F_DEFAULT 0x0
+
+/* RX vl_act{F}[2:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "vl_act{F}[2:0]".
+ * Parameter: filter {F} | stride size 0x4 | range [0, 15]
+ * PORT="pif_rpf_vl_act0_i[2:0]"
+ */
+
+/* Register address for bitfield vl_act{F}[2:0] */
+#define HW_ATL_RPF_VL_ACT_F_ADR(filter) (0x00005290 + (filter) * 0x4)
+/* Bitmask for bitfield vl_act{F}[2:0] */
+#define HW_ATL_RPF_VL_ACT_F_MSK 0x00070000
+/* Inverted bitmask for bitfield vl_act{F}[2:0] */
+#define HW_ATL_RPF_VL_ACT_F_MSKN 0xFFF8FFFF
+/* Lower bit position of bitfield vl_act{F}[2:0] */
+#define HW_ATL_RPF_VL_ACT_F_SHIFT 16
+/* Width of bitfield vl_act{F}[2:0] */
+#define HW_ATL_RPF_VL_ACT_F_WIDTH 3
+/* Default value of bitfield vl_act{F}[2:0] */
+#define HW_ATL_RPF_VL_ACT_F_DEFAULT 0x0
+
+/* RX vl_id{F}[B:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "vl_id{F}[B:0]".
+ * Parameter: filter {F} | stride size 0x4 | range [0, 15]
+ * PORT="pif_rpf_vl_id0_i[11:0]"
+ */
+
+/* Register address for bitfield vl_id{F}[B:0] */
+#define HW_ATL_RPF_VL_ID_F_ADR(filter) (0x00005290 + (filter) * 0x4)
+/* Bitmask for bitfield vl_id{F}[B:0] */
+#define HW_ATL_RPF_VL_ID_F_MSK 0x00000FFF
+/* Inverted bitmask for bitfield vl_id{F}[B:0] */
+#define HW_ATL_RPF_VL_ID_F_MSKN 0xFFFFF000
+/* Lower bit position of bitfield vl_id{F}[B:0] */
+#define HW_ATL_RPF_VL_ID_F_SHIFT 0
+/* Width of bitfield vl_id{F}[B:0] */
+#define HW_ATL_RPF_VL_ID_F_WIDTH 12
+/* Default value of bitfield vl_id{F}[B:0] */
+#define HW_ATL_RPF_VL_ID_F_DEFAULT 0x0
+
+/* RX et_en{F} Bitfield Definitions
+ * Preprocessor definitions for the bitfield "et_en{F}".
+ * Parameter: filter {F} | stride size 0x4 | range [0, 15]
+ * PORT="pif_rpf_et_en_i[0]"
+ */
+
+/* Register address for bitfield et_en{F} */
+#define HW_ATL_RPF_ET_EN_F_ADR(filter) (0x00005300 + (filter) * 0x4)
+/* Bitmask for bitfield et_en{F} */
+#define HW_ATL_RPF_ET_EN_F_MSK 0x80000000
+/* Inverted bitmask for bitfield et_en{F} */
+#define HW_ATL_RPF_ET_EN_F_MSKN 0x7FFFFFFF
+/* Lower bit position of bitfield et_en{F} */
+#define HW_ATL_RPF_ET_EN_F_SHIFT 31
+/* Width of bitfield et_en{F} */
+#define HW_ATL_RPF_ET_EN_F_WIDTH 1
+/* Default value of bitfield et_en{F} */
+#define HW_ATL_RPF_ET_EN_F_DEFAULT 0x0
+
+/* rx et_en{f} bitfield definitions
+ * preprocessor definitions for the bitfield "et_en{f}".
+ * parameter: filter {f} | stride size 0x4 | range [0, 15]
+ * port="pif_rpf_et_en_i[0]"
+ */
+
+/* register address for bitfield et_en{f} */
+#define HW_ATL_RPF_ET_ENF_ADR(filter) (0x00005300 + (filter) * 0x4)
+/* bitmask for bitfield et_en{f} */
+#define HW_ATL_RPF_ET_ENF_MSK 0x80000000
+/* inverted bitmask for bitfield et_en{f} */
+#define HW_ATL_RPF_ET_ENF_MSKN 0x7fffffff
+/* lower bit position of bitfield et_en{f} */
+#define HW_ATL_RPF_ET_ENF_SHIFT 31
+/* width of bitfield et_en{f} */
+#define HW_ATL_RPF_ET_ENF_WIDTH 1
+/* default value of bitfield et_en{f} */
+#define HW_ATL_RPF_ET_ENF_DEFAULT 0x0
+
+/* rx et_up{f}_en bitfield definitions
+ * preprocessor definitions for the bitfield "et_up{f}_en".
+ * parameter: filter {f} | stride size 0x4 | range [0, 15]
+ * port="pif_rpf_et_up_en_i[0]"
+ */
+
+/* register address for bitfield et_up{f}_en */
+#define HW_ATL_RPF_ET_UPFEN_ADR(filter) (0x00005300 + (filter) * 0x4)
+/* bitmask for bitfield et_up{f}_en */
+#define HW_ATL_RPF_ET_UPFEN_MSK 0x40000000
+/* inverted bitmask for bitfield et_up{f}_en */
+#define HW_ATL_RPF_ET_UPFEN_MSKN 0xbfffffff
+/* lower bit position of bitfield et_up{f}_en */
+#define HW_ATL_RPF_ET_UPFEN_SHIFT 30
+/* width of bitfield et_up{f}_en */
+#define HW_ATL_RPF_ET_UPFEN_WIDTH 1
+/* default value of bitfield et_up{f}_en */
+#define HW_ATL_RPF_ET_UPFEN_DEFAULT 0x0
+
+/* rx et_rxq{f}_en bitfield definitions
+ * preprocessor definitions for the bitfield "et_rxq{f}_en".
+ * parameter: filter {f} | stride size 0x4 | range [0, 15]
+ * port="pif_rpf_et_rxq_en_i[0]"
+ */
+
+/* register address for bitfield et_rxq{f}_en */
+#define HW_ATL_RPF_ET_RXQFEN_ADR(filter) (0x00005300 + (filter) * 0x4)
+/* bitmask for bitfield et_rxq{f}_en */
+#define HW_ATL_RPF_ET_RXQFEN_MSK 0x20000000
+/* inverted bitmask for bitfield et_rxq{f}_en */
+#define HW_ATL_RPF_ET_RXQFEN_MSKN 0xdfffffff
+/* lower bit position of bitfield et_rxq{f}_en */
+#define HW_ATL_RPF_ET_RXQFEN_SHIFT 29
+/* width of bitfield et_rxq{f}_en */
+#define HW_ATL_RPF_ET_RXQFEN_WIDTH 1
+/* default value of bitfield et_rxq{f}_en */
+#define HW_ATL_RPF_ET_RXQFEN_DEFAULT 0x0
+
+/* rx et_up{f}[2:0] bitfield definitions
+ * preprocessor definitions for the bitfield "et_up{f}[2:0]".
+ * parameter: filter {f} | stride size 0x4 | range [0, 15]
+ * port="pif_rpf_et_up0_i[2:0]"
+ */
+
+/* register address for bitfield et_up{f}[2:0] */
+#define HW_ATL_RPF_ET_UPF_ADR(filter) (0x00005300 + (filter) * 0x4)
+/* bitmask for bitfield et_up{f}[2:0] */
+#define HW_ATL_RPF_ET_UPF_MSK 0x1c000000
+/* inverted bitmask for bitfield et_up{f}[2:0] */
+#define HW_ATL_RPF_ET_UPF_MSKN 0xe3ffffff
+/* lower bit position of bitfield et_up{f}[2:0] */
+#define HW_ATL_RPF_ET_UPF_SHIFT 26
+/* width of bitfield et_up{f}[2:0] */
+#define HW_ATL_RPF_ET_UPF_WIDTH 3
+/* default value of bitfield et_up{f}[2:0] */
+#define HW_ATL_RPF_ET_UPF_DEFAULT 0x0
+
+/* rx et_rxq{f}[4:0] bitfield definitions
+ * preprocessor definitions for the bitfield "et_rxq{f}[4:0]".
+ * parameter: filter {f} | stride size 0x4 | range [0, 15]
+ * port="pif_rpf_et_rxq0_i[4:0]"
+ */
+
+/* register address for bitfield et_rxq{f}[4:0] */
+#define HW_ATL_RPF_ET_RXQF_ADR(filter) (0x00005300 + (filter) * 0x4)
+/* bitmask for bitfield et_rxq{f}[4:0] */
+#define HW_ATL_RPF_ET_RXQF_MSK 0x01f00000
+/* inverted bitmask for bitfield et_rxq{f}[4:0] */
+#define HW_ATL_RPF_ET_RXQF_MSKN 0xfe0fffff
+/* lower bit position of bitfield et_rxq{f}[4:0] */
+#define HW_ATL_RPF_ET_RXQF_SHIFT 20
+/* width of bitfield et_rxq{f}[4:0] */
+#define HW_ATL_RPF_ET_RXQF_WIDTH 5
+/* default value of bitfield et_rxq{f}[4:0] */
+#define HW_ATL_RPF_ET_RXQF_DEFAULT 0x0
+
+/* rx et_mng_rxq{f} bitfield definitions
+ * preprocessor definitions for the bitfield "et_mng_rxq{f}".
+ * parameter: filter {f} | stride size 0x4 | range [0, 15]
+ * port="pif_rpf_et_mng_rxq_i[0]"
+ */
+
+/* register address for bitfield et_mng_rxq{f} */
+#define HW_ATL_RPF_ET_MNG_RXQF_ADR(filter) (0x00005300 + (filter) * 0x4)
+/* bitmask for bitfield et_mng_rxq{f} */
+#define HW_ATL_RPF_ET_MNG_RXQF_MSK 0x00080000
+/* inverted bitmask for bitfield et_mng_rxq{f} */
+#define HW_ATL_RPF_ET_MNG_RXQF_MSKN 0xfff7ffff
+/* lower bit position of bitfield et_mng_rxq{f} */
+#define HW_ATL_RPF_ET_MNG_RXQF_SHIFT 19
+/* width of bitfield et_mng_rxq{f} */
+#define HW_ATL_RPF_ET_MNG_RXQF_WIDTH 1
+/* default value of bitfield et_mng_rxq{f} */
+#define HW_ATL_RPF_ET_MNG_RXQF_DEFAULT 0x0
+
+/* rx et_act{f}[2:0] bitfield definitions
+ * preprocessor definitions for the bitfield "et_act{f}[2:0]".
+ * parameter: filter {f} | stride size 0x4 | range [0, 15]
+ * port="pif_rpf_et_act0_i[2:0]"
+ */
+
+/* register address for bitfield et_act{f}[2:0] */
+#define HW_ATL_RPF_ET_ACTF_ADR(filter) (0x00005300 + (filter) * 0x4)
+/* bitmask for bitfield et_act{f}[2:0] */
+#define HW_ATL_RPF_ET_ACTF_MSK 0x00070000
+/* inverted bitmask for bitfield et_act{f}[2:0] */
+#define HW_ATL_RPF_ET_ACTF_MSKN 0xfff8ffff
+/* lower bit position of bitfield et_act{f}[2:0] */
+#define HW_ATL_RPF_ET_ACTF_SHIFT 16
+/* width of bitfield et_act{f}[2:0] */
+#define HW_ATL_RPF_ET_ACTF_WIDTH 3
+/* default value of bitfield et_act{f}[2:0] */
+#define HW_ATL_RPF_ET_ACTF_DEFAULT 0x0
+
+/* rx et_val{f}[f:0] bitfield definitions
+ * preprocessor definitions for the bitfield "et_val{f}[f:0]".
+ * parameter: filter {f} | stride size 0x4 | range [0, 15]
+ * port="pif_rpf_et_val0_i[15:0]"
+ */
+
+/* register address for bitfield et_val{f}[f:0] */
+#define HW_ATL_RPF_ET_VALF_ADR(filter) (0x00005300 + (filter) * 0x4)
+/* bitmask for bitfield et_val{f}[f:0] */
+#define HW_ATL_RPF_ET_VALF_MSK 0x0000ffff
+/* inverted bitmask for bitfield et_val{f}[f:0] */
+#define HW_ATL_RPF_ET_VALF_MSKN 0xffff0000
+/* lower bit position of bitfield et_val{f}[f:0] */
+#define HW_ATL_RPF_ET_VALF_SHIFT 0
+/* width of bitfield et_val{f}[f:0] */
+#define HW_ATL_RPF_ET_VALF_WIDTH 16
+/* default value of bitfield et_val{f}[f:0] */
+#define HW_ATL_RPF_ET_VALF_DEFAULT 0x0
+
+/* rx ipv4_chk_en bitfield definitions
+ * preprocessor definitions for the bitfield "ipv4_chk_en".
+ * port="pif_rpo_ipv4_chk_en_i"
+ */
+
+/* register address for bitfield ipv4_chk_en */
+#define HW_ATL_RPO_IPV4CHK_EN_ADR 0x00005580
+/* bitmask for bitfield ipv4_chk_en */
+#define HW_ATL_RPO_IPV4CHK_EN_MSK 0x00000002
+/* inverted bitmask for bitfield ipv4_chk_en */
+#define HW_ATL_RPO_IPV4CHK_EN_MSKN 0xfffffffd
+/* lower bit position of bitfield ipv4_chk_en */
+#define HW_ATL_RPO_IPV4CHK_EN_SHIFT 1
+/* width of bitfield ipv4_chk_en */
+#define HW_ATL_RPO_IPV4CHK_EN_WIDTH 1
+/* default value of bitfield ipv4_chk_en */
+#define HW_ATL_RPO_IPV4CHK_EN_DEFAULT 0x0
+
+/* rx desc{d}_vl_strip bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_vl_strip".
+ * parameter: descriptor {d} | stride size 0x20 | range [0, 31]
+ * port="pif_rpo_desc_vl_strip_i[0]"
+ */
+
+/* register address for bitfield desc{d}_vl_strip */
+#define HW_ATL_RPO_DESCDVL_STRIP_ADR(descriptor) \
+	(0x00005b08 + (descriptor) * 0x20)
+/* bitmask for bitfield desc{d}_vl_strip */
+#define HW_ATL_RPO_DESCDVL_STRIP_MSK 0x20000000
+/* inverted bitmask for bitfield desc{d}_vl_strip */
+#define HW_ATL_RPO_DESCDVL_STRIP_MSKN 0xdfffffff
+/* lower bit position of bitfield desc{d}_vl_strip */
+#define HW_ATL_RPO_DESCDVL_STRIP_SHIFT 29
+/* width of bitfield desc{d}_vl_strip */
+#define HW_ATL_RPO_DESCDVL_STRIP_WIDTH 1
+/* default value of bitfield desc{d}_vl_strip */
+#define HW_ATL_RPO_DESCDVL_STRIP_DEFAULT 0x0
+
+/* rx l4_chk_en bitfield definitions
+ * preprocessor definitions for the bitfield "l4_chk_en".
+ * port="pif_rpo_l4_chk_en_i"
+ */
+
+/* register address for bitfield l4_chk_en */
+#define HW_ATL_RPOL4CHK_EN_ADR 0x00005580
+/* bitmask for bitfield l4_chk_en */
+#define HW_ATL_RPOL4CHK_EN_MSK 0x00000001
+/* inverted bitmask for bitfield l4_chk_en */
+#define HW_ATL_RPOL4CHK_EN_MSKN 0xfffffffe
+/* lower bit position of bitfield l4_chk_en */
+#define HW_ATL_RPOL4CHK_EN_SHIFT 0
+/* width of bitfield l4_chk_en */
+#define HW_ATL_RPOL4CHK_EN_WIDTH 1
+/* default value of bitfield l4_chk_en */
+#define HW_ATL_RPOL4CHK_EN_DEFAULT 0x0
+
+/* rx reg_res_dsbl bitfield definitions
+ * preprocessor definitions for the bitfield "reg_res_dsbl".
+ * port="pif_rx_reg_res_dsbl_i"
+ */
+
+/* register address for bitfield reg_res_dsbl */
+#define HW_ATL_RX_REG_RES_DSBL_ADR 0x00005000
+/* bitmask for bitfield reg_res_dsbl */
+#define HW_ATL_RX_REG_RES_DSBL_MSK 0x20000000
+/* inverted bitmask for bitfield reg_res_dsbl */
+#define HW_ATL_RX_REG_RES_DSBL_MSKN 0xdfffffff
+/* lower bit position of bitfield reg_res_dsbl */
+#define HW_ATL_RX_REG_RES_DSBL_SHIFT 29
+/* width of bitfield reg_res_dsbl */
+#define HW_ATL_RX_REG_RES_DSBL_WIDTH 1
+/* default value of bitfield reg_res_dsbl */
+#define HW_ATL_RX_REG_RES_DSBL_DEFAULT 0x1
+
+/* tx dca{d}_cpuid[7:0] bitfield definitions
+ * preprocessor definitions for the bitfield "dca{d}_cpuid[7:0]".
+ * parameter: dca {d} | stride size 0x4 | range [0, 31]
+ * port="pif_tdm_dca0_cpuid_i[7:0]"
+ */
+
+/* register address for bitfield dca{d}_cpuid[7:0] */
+#define HW_ATL_TDM_DCADCPUID_ADR(dca) (0x00008400 + (dca) * 0x4)
+/* bitmask for bitfield dca{d}_cpuid[7:0] */
+#define HW_ATL_TDM_DCADCPUID_MSK 0x000000ff
+/* inverted bitmask for bitfield dca{d}_cpuid[7:0] */
+#define HW_ATL_TDM_DCADCPUID_MSKN 0xffffff00
+/* lower bit position of bitfield dca{d}_cpuid[7:0] */
+#define HW_ATL_TDM_DCADCPUID_SHIFT 0
+/* width of bitfield dca{d}_cpuid[7:0] */
+#define HW_ATL_TDM_DCADCPUID_WIDTH 8
+/* default value of bitfield dca{d}_cpuid[7:0] */
+#define HW_ATL_TDM_DCADCPUID_DEFAULT 0x0
+
+/* tx lso_en[1f:0] bitfield definitions
+ * preprocessor definitions for the bitfield "lso_en[1f:0]".
+ * port="pif_tdm_lso_en_i[31:0]"
+ */
+
+/* register address for bitfield lso_en[1f:0] */
+#define HW_ATL_TDM_LSO_EN_ADR 0x00007810
+/* bitmask for bitfield lso_en[1f:0] */
+#define HW_ATL_TDM_LSO_EN_MSK 0xffffffff
+/* inverted bitmask for bitfield lso_en[1f:0] */
+#define HW_ATL_TDM_LSO_EN_MSKN 0x00000000
+/* lower bit position of bitfield lso_en[1f:0] */
+#define HW_ATL_TDM_LSO_EN_SHIFT 0
+/* width of bitfield lso_en[1f:0] */
+#define HW_ATL_TDM_LSO_EN_WIDTH 32
+/* default value of bitfield lso_en[1f:0] */
+#define HW_ATL_TDM_LSO_EN_DEFAULT 0x0
+
+/* tx dca_en bitfield definitions
+ * preprocessor definitions for the bitfield "dca_en".
+ * port="pif_tdm_dca_en_i"
+ */
+
+/* register address for bitfield dca_en */
+#define HW_ATL_TDM_DCA_EN_ADR 0x00008480
+/* bitmask for bitfield dca_en */
+#define HW_ATL_TDM_DCA_EN_MSK 0x80000000
+/* inverted bitmask for bitfield dca_en */
+#define HW_ATL_TDM_DCA_EN_MSKN 0x7fffffff
+/* lower bit position of bitfield dca_en */
+#define HW_ATL_TDM_DCA_EN_SHIFT 31
+/* width of bitfield dca_en */
+#define HW_ATL_TDM_DCA_EN_WIDTH 1
+/* default value of bitfield dca_en */
+#define HW_ATL_TDM_DCA_EN_DEFAULT 0x1
+
+/* tx dca_mode[3:0] bitfield definitions
+ * preprocessor definitions for the bitfield "dca_mode[3:0]".
+ * port="pif_tdm_dca_mode_i[3:0]"
+ */
+
+/* register address for bitfield dca_mode[3:0] */
+#define HW_ATL_TDM_DCA_MODE_ADR 0x00008480
+/* bitmask for bitfield dca_mode[3:0] */
+#define HW_ATL_TDM_DCA_MODE_MSK 0x0000000f
+/* inverted bitmask for bitfield dca_mode[3:0] */
+#define HW_ATL_TDM_DCA_MODE_MSKN 0xfffffff0
+/* lower bit position of bitfield dca_mode[3:0] */
+#define HW_ATL_TDM_DCA_MODE_SHIFT 0
+/* width of bitfield dca_mode[3:0] */
+#define HW_ATL_TDM_DCA_MODE_WIDTH 4
+/* default value of bitfield dca_mode[3:0] */
+#define HW_ATL_TDM_DCA_MODE_DEFAULT 0x0
+
+/* tx dca{d}_desc_en bitfield definitions
+ * preprocessor definitions for the bitfield "dca{d}_desc_en".
+ * parameter: dca {d} | stride size 0x4 | range [0, 31]
+ * port="pif_tdm_dca_desc_en_i[0]"
+ */
+
+/* register address for bitfield dca{d}_desc_en */
+#define HW_ATL_TDM_DCADDESC_EN_ADR(dca) (0x00008400 + (dca) * 0x4)
+/* bitmask for bitfield dca{d}_desc_en */
+#define HW_ATL_TDM_DCADDESC_EN_MSK 0x80000000
+/* inverted bitmask for bitfield dca{d}_desc_en */
+#define HW_ATL_TDM_DCADDESC_EN_MSKN 0x7fffffff
+/* lower bit position of bitfield dca{d}_desc_en */
+#define HW_ATL_TDM_DCADDESC_EN_SHIFT 31
+/* width of bitfield dca{d}_desc_en */
+#define HW_ATL_TDM_DCADDESC_EN_WIDTH 1
+/* default value of bitfield dca{d}_desc_en */
+#define HW_ATL_TDM_DCADDESC_EN_DEFAULT 0x0
+
+/* tx desc{d}_en bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_en".
+ * parameter: descriptor {d} | stride size 0x40 | range [0, 31]
+ * port="pif_tdm_desc_en_i[0]"
+ */
+
+/* register address for bitfield desc{d}_en */
+#define HW_ATL_TDM_DESCDEN_ADR(descriptor) (0x00007c08 + (descriptor) * 0x40)
+/* bitmask for bitfield desc{d}_en */
+#define HW_ATL_TDM_DESCDEN_MSK 0x80000000
+/* inverted bitmask for bitfield desc{d}_en */
+#define HW_ATL_TDM_DESCDEN_MSKN 0x7fffffff
+/* lower bit position of bitfield desc{d}_en */
+#define HW_ATL_TDM_DESCDEN_SHIFT 31
+/* width of bitfield desc{d}_en */
+#define HW_ATL_TDM_DESCDEN_WIDTH 1
+/* default value of bitfield desc{d}_en */
+#define HW_ATL_TDM_DESCDEN_DEFAULT 0x0
+
+/* tx desc{d}_hd[c:0] bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_hd[c:0]".
+ * parameter: descriptor {d} | stride size 0x40 | range [0, 31]
+ * port="tdm_pif_desc0_hd_o[12:0]"
+ */
+
+/* register address for bitfield desc{d}_hd[c:0] */
+#define HW_ATL_TDM_DESCDHD_ADR(descriptor) (0x00007c0c + (descriptor) * 0x40)
+/* bitmask for bitfield desc{d}_hd[c:0] */
+#define HW_ATL_TDM_DESCDHD_MSK 0x00001fff
+/* inverted bitmask for bitfield desc{d}_hd[c:0] */
+#define HW_ATL_TDM_DESCDHD_MSKN 0xffffe000
+/* lower bit position of bitfield desc{d}_hd[c:0] */
+#define HW_ATL_TDM_DESCDHD_SHIFT 0
+/* width of bitfield desc{d}_hd[c:0] */
+#define HW_ATL_TDM_DESCDHD_WIDTH 13
+
+/* tx desc{d}_len[9:0] bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_len[9:0]".
+ * parameter: descriptor {d} | stride size 0x40 | range [0, 31]
+ * port="pif_tdm_desc0_len_i[9:0]"
+ */
+
+/* register address for bitfield desc{d}_len[9:0] */
+#define HW_ATL_TDM_DESCDLEN_ADR(descriptor) (0x00007c08 + (descriptor) * 0x40)
+/* bitmask for bitfield desc{d}_len[9:0] */
+#define HW_ATL_TDM_DESCDLEN_MSK 0x00001ff8
+/* inverted bitmask for bitfield desc{d}_len[9:0] */
+#define HW_ATL_TDM_DESCDLEN_MSKN 0xffffe007
+/* lower bit position of bitfield desc{d}_len[9:0] */
+#define HW_ATL_TDM_DESCDLEN_SHIFT 3
+/* width of bitfield desc{d}_len[9:0] */
+#define HW_ATL_TDM_DESCDLEN_WIDTH 10
+/* default value of bitfield desc{d}_len[9:0] */
+#define HW_ATL_TDM_DESCDLEN_DEFAULT 0x0
+
+/* tx int_desc_wrb_en bitfield definitions
+ * preprocessor definitions for the bitfield "int_desc_wrb_en".
+ * port="pif_tdm_int_desc_wrb_en_i"
+ */
+
+/* register address for bitfield int_desc_wrb_en */
+#define HW_ATL_TDM_INT_DESC_WRB_EN_ADR 0x00007b40
+/* bitmask for bitfield int_desc_wrb_en */
+#define HW_ATL_TDM_INT_DESC_WRB_EN_MSK 0x00000002
+/* inverted bitmask for bitfield int_desc_wrb_en */
+#define HW_ATL_TDM_INT_DESC_WRB_EN_MSKN 0xfffffffd
+/* lower bit position of bitfield int_desc_wrb_en */
+#define HW_ATL_TDM_INT_DESC_WRB_EN_SHIFT 1
+/* width of bitfield int_desc_wrb_en */
+#define HW_ATL_TDM_INT_DESC_WRB_EN_WIDTH 1
+/* default value of bitfield int_desc_wrb_en */
+#define HW_ATL_TDM_INT_DESC_WRB_EN_DEFAULT 0x0
+
+/* tx desc{d}_wrb_thresh[6:0] bitfield definitions
+ * preprocessor definitions for the bitfield "desc{d}_wrb_thresh[6:0]".
+ * parameter: descriptor {d} | stride size 0x40 | range [0, 31]
+ * port="pif_tdm_desc0_wrb_thresh_i[6:0]"
+ */
+
+/* register address for bitfield desc{d}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESCDWRB_THRESH_ADR(descriptor) \
+	(0x00007c18 + (descriptor) * 0x40)
+/* bitmask for bitfield desc{d}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESCDWRB_THRESH_MSK 0x00007f00
+/* inverted bitmask for bitfield desc{d}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESCDWRB_THRESH_MSKN 0xffff80ff
+/* lower bit position of bitfield desc{d}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESCDWRB_THRESH_SHIFT 8
+/* width of bitfield desc{d}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESCDWRB_THRESH_WIDTH 7
+/* default value of bitfield desc{d}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESCDWRB_THRESH_DEFAULT 0x0
+
+/* tx lso_tcp_flag_first[b:0] bitfield definitions
+ * preprocessor definitions for the bitfield "lso_tcp_flag_first[b:0]".
+ * port="pif_thm_lso_tcp_flag_first_i[11:0]"
+ */
+
+/* register address for bitfield lso_tcp_flag_first[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_FIRST_ADR 0x00007820
+/* bitmask for bitfield lso_tcp_flag_first[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_FIRST_MSK 0x00000fff
+/* inverted bitmask for bitfield lso_tcp_flag_first[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_FIRST_MSKN 0xfffff000
+/* lower bit position of bitfield lso_tcp_flag_first[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_FIRST_SHIFT 0
+/* width of bitfield lso_tcp_flag_first[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_FIRST_WIDTH 12
+/* default value of bitfield lso_tcp_flag_first[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_FIRST_DEFAULT 0x0
+
+/* tx lso_tcp_flag_last[b:0] bitfield definitions
+ * preprocessor definitions for the bitfield "lso_tcp_flag_last[b:0]".
+ * port="pif_thm_lso_tcp_flag_last_i[11:0]"
+ */
+
+/* register address for bitfield lso_tcp_flag_last[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_LAST_ADR 0x00007824
+/* bitmask for bitfield lso_tcp_flag_last[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_LAST_MSK 0x00000fff
+/* inverted bitmask for bitfield lso_tcp_flag_last[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_LAST_MSKN 0xfffff000
+/* lower bit position of bitfield lso_tcp_flag_last[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_LAST_SHIFT 0
+/* width of bitfield lso_tcp_flag_last[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_LAST_WIDTH 12
+/* default value of bitfield lso_tcp_flag_last[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_LAST_DEFAULT 0x0
+
+/* tx lso_tcp_flag_mid[b:0] bitfield definitions
+ * preprocessor definitions for the bitfield "lso_tcp_flag_mid[b:0]".
+ * port="pif_thm_lso_tcp_flag_mid_i[11:0]"
+ */
+
+/* Register address for bitfield lro_rsc_max[1F:0] */
+#define HW_ATL_RPO_LRO_RSC_MAX_ADR 0x00005598
+/* Bitmask for bitfield lro_rsc_max[1F:0] */
+#define HW_ATL_RPO_LRO_RSC_MAX_MSK 0xFFFFFFFF
+/* Inverted bitmask for bitfield lro_rsc_max[1F:0] */
+#define HW_ATL_RPO_LRO_RSC_MAX_MSKN 0x00000000
+/* Lower bit position of bitfield lro_rsc_max[1F:0] */
+#define HW_ATL_RPO_LRO_RSC_MAX_SHIFT 0
+/* Width of bitfield lro_rsc_max[1F:0] */
+#define HW_ATL_RPO_LRO_RSC_MAX_WIDTH 32
+/* Default value of bitfield lro_rsc_max[1F:0] */
+#define HW_ATL_RPO_LRO_RSC_MAX_DEFAULT 0x0
+
+/* RX lro_en[1F:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "lro_en[1F:0]".
+ * PORT="pif_rpo_lro_en_i[31:0]"
+ */
+
+/* Register address for bitfield lro_en[1F:0] */
+#define HW_ATL_RPO_LRO_EN_ADR 0x00005590
+/* Bitmask for bitfield lro_en[1F:0] */
+#define HW_ATL_RPO_LRO_EN_MSK 0xFFFFFFFF
+/* Inverted bitmask for bitfield lro_en[1F:0] */
+#define HW_ATL_RPO_LRO_EN_MSKN 0x00000000
+/* Lower bit position of bitfield lro_en[1F:0] */
+#define HW_ATL_RPO_LRO_EN_SHIFT 0
+/* Width of bitfield lro_en[1F:0] */
+#define HW_ATL_RPO_LRO_EN_WIDTH 32
+/* Default value of bitfield lro_en[1F:0] */
+#define HW_ATL_RPO_LRO_EN_DEFAULT 0x0
+
+/* RX lro_ptopt_en Bitfield Definitions
+ * Preprocessor definitions for the bitfield "lro_ptopt_en".
+ * PORT="pif_rpo_lro_ptopt_en_i"
+ */
+
+/* Register address for bitfield lro_ptopt_en */
+#define HW_ATL_RPO_LRO_PTOPT_EN_ADR 0x00005594
+/* Bitmask for bitfield lro_ptopt_en */
+#define HW_ATL_RPO_LRO_PTOPT_EN_MSK 0x00008000
+/* Inverted bitmask for bitfield lro_ptopt_en */
+#define HW_ATL_RPO_LRO_PTOPT_EN_MSKN 0xFFFF7FFF
+/* Lower bit position of bitfield lro_ptopt_en */
+#define HW_ATL_RPO_LRO_PTOPT_EN_SHIFT 15
+/* Width of bitfield lro_ptopt_en */
+#define HW_ATL_RPO_LRO_PTOPT_EN_WIDTH 1
+/* Default value of bitfield lro_ptopt_en */
+#define HW_ATL_RPO_LRO_PTOPT_EN_DEFALT 0x1
+
+/* RX lro_q_ses_lmt Bitfield Definitions
+ * Preprocessor definitions for the bitfield "lro_q_ses_lmt".
+ * PORT="pif_rpo_lro_q_ses_lmt_i[1:0]"
+ */
+
+/* Register address for bitfield lro_q_ses_lmt */
+#define HW_ATL_RPO_LRO_QSES_LMT_ADR 0x00005594
+/* Bitmask for bitfield lro_q_ses_lmt */
+#define HW_ATL_RPO_LRO_QSES_LMT_MSK 0x00003000
+/* Inverted bitmask for bitfield lro_q_ses_lmt */
+#define HW_ATL_RPO_LRO_QSES_LMT_MSKN 0xFFFFCFFF
+/* Lower bit position of bitfield lro_q_ses_lmt */
+#define HW_ATL_RPO_LRO_QSES_LMT_SHIFT 12
+/* Width of bitfield lro_q_ses_lmt */
+#define HW_ATL_RPO_LRO_QSES_LMT_WIDTH 2
+/* Default value of bitfield lro_q_ses_lmt */
+#define HW_ATL_RPO_LRO_QSES_LMT_DEFAULT 0x1
+
+/* RX lro_tot_dsc_lmt[1:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "lro_tot_dsc_lmt[1:0]".
+ * PORT="pif_rpo_lro_tot_dsc_lmt_i[1:0]"
+ */
+
+/* Register address for bitfield lro_tot_dsc_lmt[1:0] */
+#define HW_ATL_RPO_LRO_TOT_DSC_LMT_ADR 0x00005594
+/* Bitmask for bitfield lro_tot_dsc_lmt[1:0] */
+#define HW_ATL_RPO_LRO_TOT_DSC_LMT_MSK 0x00000060
+/* Inverted bitmask for bitfield lro_tot_dsc_lmt[1:0] */
+#define HW_ATL_RPO_LRO_TOT_DSC_LMT_MSKN 0xFFFFFF9F
+/* Lower bit position of bitfield lro_tot_dsc_lmt[1:0] */
+#define HW_ATL_RPO_LRO_TOT_DSC_LMT_SHIFT 5
+/* Width of bitfield lro_tot_dsc_lmt[1:0] */
+#define HW_ATL_RPO_LRO_TOT_DSC_LMT_WIDTH 2
+/* Default value of bitfield lro_tot_dsc_lmt[1:0] */
+#define HW_ATL_RPO_LRO_TOT_DSC_LMT_DEFALT 0x1
+
+/* RX lro_pkt_min[4:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "lro_pkt_min[4:0]".
+ * PORT="pif_rpo_lro_pkt_min_i[4:0]"
+ */
+
+/* Register address for bitfield lro_pkt_min[4:0] */
+#define HW_ATL_RPO_LRO_PKT_MIN_ADR 0x00005594
+/* Bitmask for bitfield lro_pkt_min[4:0] */
+#define HW_ATL_RPO_LRO_PKT_MIN_MSK 0x0000001F
+/* Inverted bitmask for bitfield lro_pkt_min[4:0] */
+#define HW_ATL_RPO_LRO_PKT_MIN_MSKN 0xFFFFFFE0
+/* Lower bit position of bitfield lro_pkt_min[4:0] */
+#define HW_ATL_RPO_LRO_PKT_MIN_SHIFT 0
+/* Width of bitfield lro_pkt_min[4:0] */
+#define HW_ATL_RPO_LRO_PKT_MIN_WIDTH 5
+/* Default value of bitfield lro_pkt_min[4:0] */
+#define HW_ATL_RPO_LRO_PKT_MIN_DEFAULT 0x8
+
+/* Width of bitfield lro{L}_des_max[1:0] */
+#define HW_ATL_RPO_LRO_LDES_MAX_WIDTH 2
+/* Default value of bitfield lro{L}_des_max[1:0] */
+#define HW_ATL_RPO_LRO_LDES_MAX_DEFAULT 0x0
+
+/* RX lro_tb_div[11:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "lro_tb_div[11:0]".
+ * PORT="pif_rpo_lro_tb_div_i[11:0]"
+ */
+
+/* Register address for bitfield lro_tb_div[11:0] */
+#define HW_ATL_RPO_LRO_TB_DIV_ADR 0x00005620
+/* Bitmask for bitfield lro_tb_div[11:0] */
+#define HW_ATL_RPO_LRO_TB_DIV_MSK 0xFFF00000
+/* Inverted bitmask for bitfield lro_tb_div[11:0] */
+#define HW_ATL_RPO_LRO_TB_DIV_MSKN 0x000FFFFF
+/* Lower bit position of bitfield lro_tb_div[11:0] */
+#define HW_ATL_RPO_LRO_TB_DIV_SHIFT 20
+/* Width of bitfield lro_tb_div[11:0] */
+#define HW_ATL_RPO_LRO_TB_DIV_WIDTH 12
+/* Default value of bitfield lro_tb_div[11:0] */
+#define HW_ATL_RPO_LRO_TB_DIV_DEFAULT 0xC35
+
+/* RX lro_ina_ival[9:0] Bitfield Definitions
+ *   Preprocessor definitions for the bitfield "lro_ina_ival[9:0]".
+ *   PORT="pif_rpo_lro_ina_ival_i[9:0]"
+ */
+
+/* Register address for bitfield lro_ina_ival[9:0] */
+#define HW_ATL_RPO_LRO_INA_IVAL_ADR 0x00005620
+/* Bitmask for bitfield lro_ina_ival[9:0] */
+#define HW_ATL_RPO_LRO_INA_IVAL_MSK 0x000FFC00
+/* Inverted bitmask for bitfield lro_ina_ival[9:0] */
+#define HW_ATL_RPO_LRO_INA_IVAL_MSKN 0xFFF003FF
+/* Lower bit position of bitfield lro_ina_ival[9:0] */
+#define HW_ATL_RPO_LRO_INA_IVAL_SHIFT 10
+/* Width of bitfield lro_ina_ival[9:0] */
+#define HW_ATL_RPO_LRO_INA_IVAL_WIDTH 10
+/* Default value of bitfield lro_ina_ival[9:0] */
+#define HW_ATL_RPO_LRO_INA_IVAL_DEFAULT 0xA
+
+/* RX lro_max_ival[9:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "lro_max_ival[9:0]".
+ * PORT="pif_rpo_lro_max_ival_i[9:0]"
+ */
+
+/* Register address for bitfield lro_max_ival[9:0] */
+#define HW_ATL_RPO_LRO_MAX_IVAL_ADR 0x00005620
+/* Bitmask for bitfield lro_max_ival[9:0] */
+#define HW_ATL_RPO_LRO_MAX_IVAL_MSK 0x000003FF
+/* Inverted bitmask for bitfield lro_max_ival[9:0] */
+#define HW_ATL_RPO_LRO_MAX_IVAL_MSKN 0xFFFFFC00
+/* Lower bit position of bitfield lro_max_ival[9:0] */
+#define HW_ATL_RPO_LRO_MAX_IVAL_SHIFT 0
+/* Width of bitfield lro_max_ival[9:0] */
+#define HW_ATL_RPO_LRO_MAX_IVAL_WIDTH 10
+/* Default value of bitfield lro_max_ival[9:0] */
+#define HW_ATL_RPO_LRO_MAX_IVAL_DEFAULT 0x19
+
+/* TX dca{D}_cpuid[7:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "dca{D}_cpuid[7:0]".
+ * Parameter: DCA {D} | stride size 0x4 | range [0, 31]
+ * PORT="pif_tdm_dca0_cpuid_i[7:0]"
+ */
+
+/* Register address for bitfield dca{D}_cpuid[7:0] */
+#define HW_ATL_TDM_DCA_DCPUID_ADR(dca) (0x00008400 + (dca) * 0x4)
+/* Bitmask for bitfield dca{D}_cpuid[7:0] */
+#define HW_ATL_TDM_DCA_DCPUID_MSK 0x000000FF
+/* Inverted bitmask for bitfield dca{D}_cpuid[7:0] */
+#define HW_ATL_TDM_DCA_DCPUID_MSKN 0xFFFFFF00
+/* Lower bit position of bitfield dca{D}_cpuid[7:0] */
+#define HW_ATL_TDM_DCA_DCPUID_SHIFT 0
+/* Width of bitfield dca{D}_cpuid[7:0] */
+#define HW_ATL_TDM_DCA_DCPUID_WIDTH 8
+/* Default value of bitfield dca{D}_cpuid[7:0] */
+#define HW_ATL_TDM_DCA_DCPUID_DEFAULT 0x0
+
+/* TX dca{D}_desc_en Bitfield Definitions
+ * Preprocessor definitions for the bitfield "dca{D}_desc_en".
+ * Parameter: DCA {D} | stride size 0x4 | range [0, 31]
+ * PORT="pif_tdm_dca_desc_en_i[0]"
+ */
+
+/* Register address for bitfield dca{D}_desc_en */
+#define HW_ATL_TDM_DCA_DDESC_EN_ADR(dca) (0x00008400 + (dca) * 0x4)
+/* Bitmask for bitfield dca{D}_desc_en */
+#define HW_ATL_TDM_DCA_DDESC_EN_MSK 0x80000000
+/* Inverted bitmask for bitfield dca{D}_desc_en */
+#define HW_ATL_TDM_DCA_DDESC_EN_MSKN 0x7FFFFFFF
+/* Lower bit position of bitfield dca{D}_desc_en */
+#define HW_ATL_TDM_DCA_DDESC_EN_SHIFT 31
+/* Width of bitfield dca{D}_desc_en */
+#define HW_ATL_TDM_DCA_DDESC_EN_WIDTH 1
+/* Default value of bitfield dca{D}_desc_en */
+#define HW_ATL_TDM_DCA_DDESC_EN_DEFAULT 0x0
+
+/* TX desc{D}_en Bitfield Definitions
+ * Preprocessor definitions for the bitfield "desc{D}_en".
+ * Parameter: descriptor {D} | stride size 0x40 | range [0, 31]
+ * PORT="pif_tdm_desc_en_i[0]"
+ */
+
+/* Register address for bitfield desc{D}_en */
+#define HW_ATL_TDM_DESC_DEN_ADR(descriptor) (0x00007C08 + (descriptor) * 0x40)
+/* Bitmask for bitfield desc{D}_en */
+#define HW_ATL_TDM_DESC_DEN_MSK 0x80000000
+/* Inverted bitmask for bitfield desc{D}_en */
+#define HW_ATL_TDM_DESC_DEN_MSKN 0x7FFFFFFF
+/* Lower bit position of bitfield desc{D}_en */
+#define HW_ATL_TDM_DESC_DEN_SHIFT 31
+/* Width of bitfield desc{D}_en */
+#define HW_ATL_TDM_DESC_DEN_WIDTH 1
+/* Default value of bitfield desc{D}_en */
+#define HW_ATL_TDM_DESC_DEN_DEFAULT 0x0
+
+/* TX desc{D}_hd[C:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "desc{D}_hd[C:0]".
+ * Parameter: descriptor {D} | stride size 0x40 | range [0, 31]
+ * PORT="tdm_pif_desc0_hd_o[12:0]"
+ */
+
+/* Register address for bitfield desc{D}_hd[C:0] */
+#define HW_ATL_TDM_DESC_DHD_ADR(descriptor) (0x00007C0C + (descriptor) * 0x40)
+/* Bitmask for bitfield desc{D}_hd[C:0] */
+#define HW_ATL_TDM_DESC_DHD_MSK 0x00001FFF
+/* Inverted bitmask for bitfield desc{D}_hd[C:0] */
+#define HW_ATL_TDM_DESC_DHD_MSKN 0xFFFFE000
+/* Lower bit position of bitfield desc{D}_hd[C:0] */
+#define HW_ATL_TDM_DESC_DHD_SHIFT 0
+/* Width of bitfield desc{D}_hd[C:0] */
+#define HW_ATL_TDM_DESC_DHD_WIDTH 13
+
+/* TX desc{D}_len[9:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "desc{D}_len[9:0]".
+ * Parameter: descriptor {D} | stride size 0x40 | range [0, 31]
+ * PORT="pif_tdm_desc0_len_i[9:0]"
+ */
+
+/* Register address for bitfield desc{D}_len[9:0] */
+#define HW_ATL_TDM_DESC_DLEN_ADR(descriptor) (0x00007C08 + (descriptor) * 0x40)
+/* Bitmask for bitfield desc{D}_len[9:0] */
+#define HW_ATL_TDM_DESC_DLEN_MSK 0x00001FF8
+/* Inverted bitmask for bitfield desc{D}_len[9:0] */
+#define HW_ATL_TDM_DESC_DLEN_MSKN 0xFFFFE007
+/* Lower bit position of bitfield desc{D}_len[9:0] */
+#define HW_ATL_TDM_DESC_DLEN_SHIFT 3
+/* Width of bitfield desc{D}_len[9:0] */
+#define HW_ATL_TDM_DESC_DLEN_WIDTH 10
+/* Default value of bitfield desc{D}_len[9:0] */
+#define HW_ATL_TDM_DESC_DLEN_DEFAULT 0x0
+
+/* TX desc{D}_wrb_thresh[6:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "desc{D}_wrb_thresh[6:0]".
+ * Parameter: descriptor {D} | stride size 0x40 | range [0, 31]
+ * PORT="pif_tdm_desc0_wrb_thresh_i[6:0]"
+ */
+
+/* Register address for bitfield desc{D}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESC_DWRB_THRESH_ADR(descriptor) \
+	(0x00007C18 + (descriptor) * 0x40)
+/* Bitmask for bitfield desc{D}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESC_DWRB_THRESH_MSK 0x00007F00
+/* Inverted bitmask for bitfield desc{D}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESC_DWRB_THRESH_MSKN 0xFFFF80FF
+/* Lower bit position of bitfield desc{D}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESC_DWRB_THRESH_SHIFT 8
+/* Width of bitfield desc{D}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESC_DWRB_THRESH_WIDTH 7
+/* Default value of bitfield desc{D}_wrb_thresh[6:0] */
+#define HW_ATL_TDM_DESC_DWRB_THRESH_DEFAULT 0x0
+
+/* TX tdm_int_mod_en Bitfield Definitions
+ * Preprocessor definitions for the bitfield "tdm_int_mod_en".
+ * PORT="pif_tdm_int_mod_en_i"
+ */
+
+/* Register address for bitfield tdm_int_mod_en */
+#define HW_ATL_TDM_INT_MOD_EN_ADR 0x00007B40
+/* Bitmask for bitfield tdm_int_mod_en */
+#define HW_ATL_TDM_INT_MOD_EN_MSK 0x00000010
+/* Inverted bitmask for bitfield tdm_int_mod_en */
+#define HW_ATL_TDM_INT_MOD_EN_MSKN 0xFFFFFFEF
+/* Lower bit position of bitfield tdm_int_mod_en */
+#define HW_ATL_TDM_INT_MOD_EN_SHIFT 4
+/* Width of bitfield tdm_int_mod_en */
+#define HW_ATL_TDM_INT_MOD_EN_WIDTH 1
+/* Default value of bitfield tdm_int_mod_en */
+#define HW_ATL_TDM_INT_MOD_EN_DEFAULT 0x0
+
+/* TX lso_tcp_flag_mid[B:0] Bitfield Definitions
+ * Preprocessor definitions for the bitfield "lso_tcp_flag_mid[B:0]".
+ * PORT="pif_thm_lso_tcp_flag_mid_i[11:0]"
+ */
+/* register address for bitfield lso_tcp_flag_mid[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_MID_ADR 0x00007820
+/* bitmask for bitfield lso_tcp_flag_mid[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_MID_MSK 0x0fff0000
+/* inverted bitmask for bitfield lso_tcp_flag_mid[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_MID_MSKN 0xf000ffff
+/* lower bit position of bitfield lso_tcp_flag_mid[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_MID_SHIFT 16
+/* width of bitfield lso_tcp_flag_mid[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_MID_WIDTH 12
+/* default value of bitfield lso_tcp_flag_mid[b:0] */
+#define HW_ATL_THM_LSO_TCP_FLAG_MID_DEFAULT 0x0
+
+/* tx tx_buf_en bitfield definitions
+ * preprocessor definitions for the bitfield "tx_buf_en".
+ * port="pif_tpb_tx_buf_en_i"
+ */
+
+/* register address for bitfield tx_buf_en */
+#define HW_ATL_TPB_TX_BUF_EN_ADR 0x00007900
+/* bitmask for bitfield tx_buf_en */
+#define HW_ATL_TPB_TX_BUF_EN_MSK 0x00000001
+/* inverted bitmask for bitfield tx_buf_en */
+#define HW_ATL_TPB_TX_BUF_EN_MSKN 0xfffffffe
+/* lower bit position of bitfield tx_buf_en */
+#define HW_ATL_TPB_TX_BUF_EN_SHIFT 0
+/* width of bitfield tx_buf_en */
+#define HW_ATL_TPB_TX_BUF_EN_WIDTH 1
+/* default value of bitfield tx_buf_en */
+#define HW_ATL_TPB_TX_BUF_EN_DEFAULT 0x0
+
+/* tx tx{b}_hi_thresh[c:0] bitfield definitions
+ * preprocessor definitions for the bitfield "tx{b}_hi_thresh[c:0]".
+ * parameter: buffer {b} | stride size 0x10 | range [0, 7]
+ * port="pif_tpb_tx0_hi_thresh_i[12:0]"
+ */
+
+/* register address for bitfield tx{b}_hi_thresh[c:0] */
+#define HW_ATL_TPB_TXBHI_THRESH_ADR(buffer) (0x00007914 + (buffer) * 0x10)
+/* bitmask for bitfield tx{b}_hi_thresh[c:0] */
+#define HW_ATL_TPB_TXBHI_THRESH_MSK 0x1fff0000
+/* inverted bitmask for bitfield tx{b}_hi_thresh[c:0] */
+#define HW_ATL_TPB_TXBHI_THRESH_MSKN 0xe000ffff
+/* lower bit position of bitfield tx{b}_hi_thresh[c:0] */
+#define HW_ATL_TPB_TXBHI_THRESH_SHIFT 16
+/* width of bitfield tx{b}_hi_thresh[c:0] */
+#define HW_ATL_TPB_TXBHI_THRESH_WIDTH 13
+/* default value of bitfield tx{b}_hi_thresh[c:0] */
+#define HW_ATL_TPB_TXBHI_THRESH_DEFAULT 0x0
+
+/* tx tx{b}_lo_thresh[c:0] bitfield definitions
+ * preprocessor definitions for the bitfield "tx{b}_lo_thresh[c:0]".
+ * parameter: buffer {b} | stride size 0x10 | range [0, 7]
+ * port="pif_tpb_tx0_lo_thresh_i[12:0]"
+ */
+
+/* register address for bitfield tx{b}_lo_thresh[c:0] */
+#define HW_ATL_TPB_TXBLO_THRESH_ADR(buffer) (0x00007914 + (buffer) * 0x10)
+/* bitmask for bitfield tx{b}_lo_thresh[c:0] */
+#define HW_ATL_TPB_TXBLO_THRESH_MSK 0x00001fff
+/* inverted bitmask for bitfield tx{b}_lo_thresh[c:0] */
+#define HW_ATL_TPB_TXBLO_THRESH_MSKN 0xffffe000
+/* lower bit position of bitfield tx{b}_lo_thresh[c:0] */
+#define HW_ATL_TPB_TXBLO_THRESH_SHIFT 0
+/* width of bitfield tx{b}_lo_thresh[c:0] */
+#define HW_ATL_TPB_TXBLO_THRESH_WIDTH 13
+/* default value of bitfield tx{b}_lo_thresh[c:0] */
+#define HW_ATL_TPB_TXBLO_THRESH_DEFAULT 0x0
+
+/* tx dma_sys_loopback bitfield definitions
+ * preprocessor definitions for the bitfield "dma_sys_loopback".
+ * port="pif_tpb_dma_sys_lbk_i"
+ */
+
+/* register address for bitfield dma_sys_loopback */
+#define HW_ATL_TPB_DMA_SYS_LBK_ADR 0x00007000
+/* bitmask for bitfield dma_sys_loopback */
+#define HW_ATL_TPB_DMA_SYS_LBK_MSK 0x00000040
+/* inverted bitmask for bitfield dma_sys_loopback */
+#define HW_ATL_TPB_DMA_SYS_LBK_MSKN 0xffffffbf
+/* lower bit position of bitfield dma_sys_loopback */
+#define HW_ATL_TPB_DMA_SYS_LBK_SHIFT 6
+/* width of bitfield dma_sys_loopback */
+#define HW_ATL_TPB_DMA_SYS_LBK_WIDTH 1
+/* default value of bitfield dma_sys_loopback */
+#define HW_ATL_TPB_DMA_SYS_LBK_DEFAULT 0x0
+
+/* tx tx{b}_buf_size[7:0] bitfield definitions
+ * preprocessor definitions for the bitfield "tx{b}_buf_size[7:0]".
+ * parameter: buffer {b} | stride size 0x10 | range [0, 7]
+ * port="pif_tpb_tx0_buf_size_i[7:0]"
+ */
+
+/* register address for bitfield tx{b}_buf_size[7:0] */
+#define HW_ATL_TPB_TXBBUF_SIZE_ADR(buffer) (0x00007910 + (buffer) * 0x10)
+/* bitmask for bitfield tx{b}_buf_size[7:0] */
+#define HW_ATL_TPB_TXBBUF_SIZE_MSK 0x000000ff
+/* inverted bitmask for bitfield tx{b}_buf_size[7:0] */
+#define HW_ATL_TPB_TXBBUF_SIZE_MSKN 0xffffff00
+/* lower bit position of bitfield tx{b}_buf_size[7:0] */
+#define HW_ATL_TPB_TXBBUF_SIZE_SHIFT 0
+/* width of bitfield tx{b}_buf_size[7:0] */
+#define HW_ATL_TPB_TXBBUF_SIZE_WIDTH 8
+/* default value of bitfield tx{b}_buf_size[7:0] */
+#define HW_ATL_TPB_TXBBUF_SIZE_DEFAULT 0x0
+
+/* tx tx_scp_ins_en bitfield definitions
+ * preprocessor definitions for the bitfield "tx_scp_ins_en".
+ * port="pif_tpb_scp_ins_en_i"
+ */
+
+/* register address for bitfield tx_scp_ins_en */
+#define HW_ATL_TPB_TX_SCP_INS_EN_ADR 0x00007900
+/* bitmask for bitfield tx_scp_ins_en */
+#define HW_ATL_TPB_TX_SCP_INS_EN_MSK 0x00000004
+/* inverted bitmask for bitfield tx_scp_ins_en */
+#define HW_ATL_TPB_TX_SCP_INS_EN_MSKN 0xfffffffb
+/* lower bit position of bitfield tx_scp_ins_en */
+#define HW_ATL_TPB_TX_SCP_INS_EN_SHIFT 2
+/* width of bitfield tx_scp_ins_en */
+#define HW_ATL_TPB_TX_SCP_INS_EN_WIDTH 1
+/* default value of bitfield tx_scp_ins_en */
+#define HW_ATL_TPB_TX_SCP_INS_EN_DEFAULT 0x0
+
+/* tx ipv4_chk_en bitfield definitions
+ * preprocessor definitions for the bitfield "ipv4_chk_en".
+ * port="pif_tpo_ipv4_chk_en_i"
+ */
+
+/* register address for bitfield ipv4_chk_en */
+#define HW_ATL_TPO_IPV4CHK_EN_ADR 0x00007800
+/* bitmask for bitfield ipv4_chk_en */
+#define HW_ATL_TPO_IPV4CHK_EN_MSK 0x00000002
+/* inverted bitmask for bitfield ipv4_chk_en */
+#define HW_ATL_TPO_IPV4CHK_EN_MSKN 0xfffffffd
+/* lower bit position of bitfield ipv4_chk_en */
+#define HW_ATL_TPO_IPV4CHK_EN_SHIFT 1
+/* width of bitfield ipv4_chk_en */
+#define HW_ATL_TPO_IPV4CHK_EN_WIDTH 1
+/* default value of bitfield ipv4_chk_en */
+#define HW_ATL_TPO_IPV4CHK_EN_DEFAULT 0x0
+
+/* tx l4_chk_en bitfield definitions
+ * preprocessor definitions for the bitfield "l4_chk_en".
+ * port="pif_tpo_l4_chk_en_i"
+ */
+
+/* register address for bitfield l4_chk_en */
+#define HW_ATL_TPOL4CHK_EN_ADR 0x00007800
+/* bitmask for bitfield l4_chk_en */
+#define HW_ATL_TPOL4CHK_EN_MSK 0x00000001
+/* inverted bitmask for bitfield l4_chk_en */
+#define HW_ATL_TPOL4CHK_EN_MSKN 0xfffffffe
+/* lower bit position of bitfield l4_chk_en */
+#define HW_ATL_TPOL4CHK_EN_SHIFT 0
+/* width of bitfield l4_chk_en */
+#define HW_ATL_TPOL4CHK_EN_WIDTH 1
+/* default value of bitfield l4_chk_en */
+#define HW_ATL_TPOL4CHK_EN_DEFAULT 0x0
+
+/* tx pkt_sys_loopback bitfield definitions
+ * preprocessor definitions for the bitfield "pkt_sys_loopback".
+ * port="pif_tpo_pkt_sys_lbk_i"
+ */
+
+/* register address for bitfield pkt_sys_loopback */
+#define HW_ATL_TPO_PKT_SYS_LBK_ADR 0x00007000
+/* bitmask for bitfield pkt_sys_loopback */
+#define HW_ATL_TPO_PKT_SYS_LBK_MSK 0x00000080
+/* inverted bitmask for bitfield pkt_sys_loopback */
+#define HW_ATL_TPO_PKT_SYS_LBK_MSKN 0xffffff7f
+/* lower bit position of bitfield pkt_sys_loopback */
+#define HW_ATL_TPO_PKT_SYS_LBK_SHIFT 7
+/* width of bitfield pkt_sys_loopback */
+#define HW_ATL_TPO_PKT_SYS_LBK_WIDTH 1
+/* default value of bitfield pkt_sys_loopback */
+#define HW_ATL_TPO_PKT_SYS_LBK_DEFAULT 0x0
+
+/* tx data_tc_arb_mode bitfield definitions
+ * preprocessor definitions for the bitfield "data_tc_arb_mode".
+ * port="pif_tps_data_tc_arb_mode_i"
+ */
+
+/* register address for bitfield data_tc_arb_mode */
+#define HW_ATL_TPS_DATA_TC_ARB_MODE_ADR 0x00007100
+/* bitmask for bitfield data_tc_arb_mode */
+#define HW_ATL_TPS_DATA_TC_ARB_MODE_MSK 0x00000001
+/* inverted bitmask for bitfield data_tc_arb_mode */
+#define HW_ATL_TPS_DATA_TC_ARB_MODE_MSKN 0xfffffffe
+/* lower bit position of bitfield data_tc_arb_mode */
+#define HW_ATL_TPS_DATA_TC_ARB_MODE_SHIFT 0
+/* width of bitfield data_tc_arb_mode */
+#define HW_ATL_TPS_DATA_TC_ARB_MODE_WIDTH 1
+/* default value of bitfield data_tc_arb_mode */
+#define HW_ATL_TPS_DATA_TC_ARB_MODE_DEFAULT 0x0
+
+/* tx desc_rate_ta_rst bitfield definitions
+ * preprocessor definitions for the bitfield "desc_rate_ta_rst".
+ * port="pif_tps_desc_rate_ta_rst_i"
+ */
+
+/* register address for bitfield desc_rate_ta_rst */
+#define HW_ATL_TPS_DESC_RATE_TA_RST_ADR 0x00007310
+/* bitmask for bitfield desc_rate_ta_rst */
+#define HW_ATL_TPS_DESC_RATE_TA_RST_MSK 0x80000000
+/* inverted bitmask for bitfield desc_rate_ta_rst */
+#define HW_ATL_TPS_DESC_RATE_TA_RST_MSKN 0x7fffffff
+/* lower bit position of bitfield desc_rate_ta_rst */
+#define HW_ATL_TPS_DESC_RATE_TA_RST_SHIFT 31
+/* width of bitfield desc_rate_ta_rst */
+#define HW_ATL_TPS_DESC_RATE_TA_RST_WIDTH 1
+/* default value of bitfield desc_rate_ta_rst */
+#define HW_ATL_TPS_DESC_RATE_TA_RST_DEFAULT 0x0
+
+/* tx desc_rate_limit[a:0] bitfield definitions
+ * preprocessor definitions for the bitfield "desc_rate_limit[a:0]".
+ * port="pif_tps_desc_rate_lim_i[10:0]"
+ */
+
+/* register address for bitfield desc_rate_limit[a:0] */
+#define HW_ATL_TPS_DESC_RATE_LIM_ADR 0x00007310
+/* bitmask for bitfield desc_rate_limit[a:0] */
+#define HW_ATL_TPS_DESC_RATE_LIM_MSK 0x000007ff
+/* inverted bitmask for bitfield desc_rate_limit[a:0] */
+#define HW_ATL_TPS_DESC_RATE_LIM_MSKN 0xfffff800
+/* lower bit position of bitfield desc_rate_limit[a:0] */
+#define HW_ATL_TPS_DESC_RATE_LIM_SHIFT 0
+/* width of bitfield desc_rate_limit[a:0] */
+#define HW_ATL_TPS_DESC_RATE_LIM_WIDTH 11
+/* default value of bitfield desc_rate_limit[a:0] */
+#define HW_ATL_TPS_DESC_RATE_LIM_DEFAULT 0x0
+
+/* tx desc_tc_arb_mode[1:0] bitfield definitions
+ * preprocessor definitions for the bitfield "desc_tc_arb_mode[1:0]".
+ * port="pif_tps_desc_tc_arb_mode_i[1:0]"
+ */
+
+/* register address for bitfield desc_tc_arb_mode[1:0] */
+#define HW_ATL_TPS_DESC_TC_ARB_MODE_ADR 0x00007200
+/* bitmask for bitfield desc_tc_arb_mode[1:0] */
+#define HW_ATL_TPS_DESC_TC_ARB_MODE_MSK 0x00000003
+/* inverted bitmask for bitfield desc_tc_arb_mode[1:0] */
+#define HW_ATL_TPS_DESC_TC_ARB_MODE_MSKN 0xfffffffc
+/* lower bit position of bitfield desc_tc_arb_mode[1:0] */
+#define HW_ATL_TPS_DESC_TC_ARB_MODE_SHIFT 0
+/* width of bitfield desc_tc_arb_mode[1:0] */
+#define HW_ATL_TPS_DESC_TC_ARB_MODE_WIDTH 2
+/* default value of bitfield desc_tc_arb_mode[1:0] */
+#define HW_ATL_TPS_DESC_TC_ARB_MODE_DEFAULT 0x0
+
+/* tx desc_tc{t}_credit_max[b:0] bitfield definitions
+ * preprocessor definitions for the bitfield "desc_tc{t}_credit_max[b:0]".
+ * parameter: tc {t} | stride size 0x4 | range [0, 7]
+ * port="pif_tps_desc_tc0_credit_max_i[11:0]"
+ */
+
+/* register address for bitfield desc_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DESC_TCTCREDIT_MAX_ADR(tc) (0x00007210 + (tc) * 0x4)
+/* bitmask for bitfield desc_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DESC_TCTCREDIT_MAX_MSK 0x0fff0000
+/* inverted bitmask for bitfield desc_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DESC_TCTCREDIT_MAX_MSKN 0xf000ffff
+/* lower bit position of bitfield desc_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DESC_TCTCREDIT_MAX_SHIFT 16
+/* width of bitfield desc_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DESC_TCTCREDIT_MAX_WIDTH 12
+/* default value of bitfield desc_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DESC_TCTCREDIT_MAX_DEFAULT 0x0
+
+/* tx desc_tc{t}_weight[8:0] bitfield definitions
+ * preprocessor definitions for the bitfield "desc_tc{t}_weight[8:0]".
+ * parameter: tc {t} | stride size 0x4 | range [0, 7]
+ * port="pif_tps_desc_tc0_weight_i[8:0]"
+ */
+
+/* register address for bitfield desc_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DESC_TCTWEIGHT_ADR(tc) (0x00007210 + (tc) * 0x4)
+/* bitmask for bitfield desc_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DESC_TCTWEIGHT_MSK 0x000001ff
+/* inverted bitmask for bitfield desc_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DESC_TCTWEIGHT_MSKN 0xfffffe00
+/* lower bit position of bitfield desc_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DESC_TCTWEIGHT_SHIFT 0
+/* width of bitfield desc_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DESC_TCTWEIGHT_WIDTH 9
+/* default value of bitfield desc_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DESC_TCTWEIGHT_DEFAULT 0x0
+
+/* tx desc_vm_arb_mode bitfield definitions
+ * preprocessor definitions for the bitfield "desc_vm_arb_mode".
+ * port="pif_tps_desc_vm_arb_mode_i"
+ */
+
+/* register address for bitfield desc_vm_arb_mode */
+#define HW_ATL_TPS_DESC_VM_ARB_MODE_ADR 0x00007300
+/* bitmask for bitfield desc_vm_arb_mode */
+#define HW_ATL_TPS_DESC_VM_ARB_MODE_MSK 0x00000001
+/* inverted bitmask for bitfield desc_vm_arb_mode */
+#define HW_ATL_TPS_DESC_VM_ARB_MODE_MSKN 0xfffffffe
+/* lower bit position of bitfield desc_vm_arb_mode */
+#define HW_ATL_TPS_DESC_VM_ARB_MODE_SHIFT 0
+/* width of bitfield desc_vm_arb_mode */
+#define HW_ATL_TPS_DESC_VM_ARB_MODE_WIDTH 1
+/* default value of bitfield desc_vm_arb_mode */
+#define HW_ATL_TPS_DESC_VM_ARB_MODE_DEFAULT 0x0
+
+/* tx data_tc{t}_credit_max[b:0] bitfield definitions
+ * preprocessor definitions for the bitfield "data_tc{t}_credit_max[b:0]".
+ * parameter: tc {t} | stride size 0x4 | range [0, 7]
+ * port="pif_tps_data_tc0_credit_max_i[11:0]"
+ */
+
+/* register address for bitfield data_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DATA_TCTCREDIT_MAX_ADR(tc) (0x00007110 + (tc) * 0x4)
+/* bitmask for bitfield data_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DATA_TCTCREDIT_MAX_MSK 0x0fff0000
+/* inverted bitmask for bitfield data_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DATA_TCTCREDIT_MAX_MSKN 0xf000ffff
+/* lower bit position of bitfield data_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DATA_TCTCREDIT_MAX_SHIFT 16
+/* width of bitfield data_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DATA_TCTCREDIT_MAX_WIDTH 12
+/* default value of bitfield data_tc{t}_credit_max[b:0] */
+#define HW_ATL_TPS_DATA_TCTCREDIT_MAX_DEFAULT 0x0
+
+/* tx data_tc{t}_weight[8:0] bitfield definitions
+ * preprocessor definitions for the bitfield "data_tc{t}_weight[8:0]".
+ * parameter: tc {t} | stride size 0x4 | range [0, 7]
+ * port="pif_tps_data_tc0_weight_i[8:0]"
+ */
+
+/* register address for bitfield data_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DATA_TCTWEIGHT_ADR(tc) (0x00007110 + (tc) * 0x4)
+/* bitmask for bitfield data_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DATA_TCTWEIGHT_MSK 0x000001ff
+/* inverted bitmask for bitfield data_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DATA_TCTWEIGHT_MSKN 0xfffffe00
+/* lower bit position of bitfield data_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DATA_TCTWEIGHT_SHIFT 0
+/* width of bitfield data_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DATA_TCTWEIGHT_WIDTH 9
+/* default value of bitfield data_tc{t}_weight[8:0] */
+#define HW_ATL_TPS_DATA_TCTWEIGHT_DEFAULT 0x0
+
+/* tx reg_res_dsbl bitfield definitions
+ * preprocessor definitions for the bitfield "reg_res_dsbl".
+ * port="pif_tx_reg_res_dsbl_i"
+ */
+
+/* register address for bitfield reg_res_dsbl */
+#define HW_ATL_TX_REG_RES_DSBL_ADR 0x00007000
+/* bitmask for bitfield reg_res_dsbl */
+#define HW_ATL_TX_REG_RES_DSBL_MSK 0x20000000
+/* inverted bitmask for bitfield reg_res_dsbl */
+#define HW_ATL_TX_REG_RES_DSBL_MSKN 0xdfffffff
+/* lower bit position of bitfield reg_res_dsbl */
+#define HW_ATL_TX_REG_RES_DSBL_SHIFT 29
+/* width of bitfield reg_res_dsbl */
+#define HW_ATL_TX_REG_RES_DSBL_WIDTH 1
+/* default value of bitfield reg_res_dsbl */
+#define HW_ATL_TX_REG_RES_DSBL_DEFAULT 0x1
+
+/* mac_phy register access busy bitfield definitions
+ * preprocessor definitions for the bitfield "register access busy".
+ * port="msm_pif_reg_busy_o"
+ */
+
+/* register address for bitfield register access busy */
+#define HW_ATL_MSM_REG_ACCESS_BUSY_ADR 0x00004400
+/* bitmask for bitfield register access busy */
+#define HW_ATL_MSM_REG_ACCESS_BUSY_MSK 0x00001000
+/* inverted bitmask for bitfield register access busy */
+#define HW_ATL_MSM_REG_ACCESS_BUSY_MSKN 0xffffefff
+/* lower bit position of bitfield register access busy */
+#define HW_ATL_MSM_REG_ACCESS_BUSY_SHIFT 12
+/* width of bitfield register access busy */
+#define HW_ATL_MSM_REG_ACCESS_BUSY_WIDTH 1
+
+/* mac_phy msm register address[7:0] bitfield definitions
+ * preprocessor definitions for the bitfield "msm register address[7:0]".
+ * port="pif_msm_reg_addr_i[7:0]"
+ */
+
+/* register address for bitfield msm register address[7:0] */
+#define HW_ATL_MSM_REG_ADDR_ADR 0x00004400
+/* bitmask for bitfield msm register address[7:0] */
+#define HW_ATL_MSM_REG_ADDR_MSK 0x000000ff
+/* inverted bitmask for bitfield msm register address[7:0] */
+#define HW_ATL_MSM_REG_ADDR_MSKN 0xffffff00
+/* lower bit position of bitfield msm register address[7:0] */
+#define HW_ATL_MSM_REG_ADDR_SHIFT 0
+/* width of bitfield msm register address[7:0] */
+#define HW_ATL_MSM_REG_ADDR_WIDTH 8
+/* default value of bitfield msm register address[7:0] */
+#define HW_ATL_MSM_REG_ADDR_DEFAULT 0x0
+
+/* mac_phy register read strobe bitfield definitions
+ * preprocessor definitions for the bitfield "register read strobe".
+ * port="pif_msm_reg_rden_i"
+ */
+
+/* register address for bitfield register read strobe */
+#define HW_ATL_MSM_REG_RD_STROBE_ADR 0x00004400
+/* bitmask for bitfield register read strobe */
+#define HW_ATL_MSM_REG_RD_STROBE_MSK 0x00000200
+/* inverted bitmask for bitfield register read strobe */
+#define HW_ATL_MSM_REG_RD_STROBE_MSKN 0xfffffdff
+/* lower bit position of bitfield register read strobe */
+#define HW_ATL_MSM_REG_RD_STROBE_SHIFT 9
+/* width of bitfield register read strobe */
+#define HW_ATL_MSM_REG_RD_STROBE_WIDTH 1
+/* default value of bitfield register read strobe */
+#define HW_ATL_MSM_REG_RD_STROBE_DEFAULT 0x0
+
+/* mac_phy msm register read data[31:0] bitfield definitions
+ * preprocessor definitions for the bitfield "msm register read data[31:0]".
+ * port="msm_pif_reg_rd_data_o[31:0]"
+ */
+
+/* register address for bitfield msm register read data[31:0] */
+#define HW_ATL_MSM_REG_RD_DATA_ADR 0x00004408
+/* bitmask for bitfield msm register read data[31:0] */
+#define HW_ATL_MSM_REG_RD_DATA_MSK 0xffffffff
+/* inverted bitmask for bitfield msm register read data[31:0] */
+#define HW_ATL_MSM_REG_RD_DATA_MSKN 0x00000000
+/* lower bit position of bitfield msm register read data[31:0] */
+#define HW_ATL_MSM_REG_RD_DATA_SHIFT 0
+/* width of bitfield msm register read data[31:0] */
+#define HW_ATL_MSM_REG_RD_DATA_WIDTH 32
+
+/* mac_phy msm register write data[31:0] bitfield definitions
+ * preprocessor definitions for the bitfield "msm register write data[31:0]".
+ * port="pif_msm_reg_wr_data_i[31:0]"
+ */
+
+/* register address for bitfield msm register write data[31:0] */
+#define HW_ATL_MSM_REG_WR_DATA_ADR 0x00004404
+/* bitmask for bitfield msm register write data[31:0] */
+#define HW_ATL_MSM_REG_WR_DATA_MSK 0xffffffff
+/* inverted bitmask for bitfield msm register write data[31:0] */
+#define HW_ATL_MSM_REG_WR_DATA_MSKN 0x00000000
+/* lower bit position of bitfield msm register write data[31:0] */
+#define HW_ATL_MSM_REG_WR_DATA_SHIFT 0
+/* width of bitfield msm register write data[31:0] */
+#define HW_ATL_MSM_REG_WR_DATA_WIDTH 32
+/* default value of bitfield msm register write data[31:0] */
+#define HW_ATL_MSM_REG_WR_DATA_DEFAULT 0x0
+
+/* mac_phy register write strobe bitfield definitions
+ * preprocessor definitions for the bitfield "register write strobe".
+ * port="pif_msm_reg_wren_i"
+ */
+
+/* register address for bitfield register write strobe */
+#define HW_ATL_MSM_REG_WR_STROBE_ADR 0x00004400
+/* bitmask for bitfield register write strobe */
+#define HW_ATL_MSM_REG_WR_STROBE_MSK 0x00000100
+/* inverted bitmask for bitfield register write strobe */
+#define HW_ATL_MSM_REG_WR_STROBE_MSKN 0xfffffeff
+/* lower bit position of bitfield register write strobe */
+#define HW_ATL_MSM_REG_WR_STROBE_SHIFT 8
+/* width of bitfield register write strobe */
+#define HW_ATL_MSM_REG_WR_STROBE_WIDTH 1
+/* default value of bitfield register write strobe */
+#define HW_ATL_MSM_REG_WR_STROBE_DEFAULT 0x0
+
+/* mif soft reset bitfield definitions
+ * preprocessor definitions for the bitfield "soft reset".
+ * port="pif_glb_res_i"
+ */
+
+/* register address for bitfield soft reset */
+#define HW_ATL_GLB_SOFT_RES_ADR 0x00000000
+/* bitmask for bitfield soft reset */
+#define HW_ATL_GLB_SOFT_RES_MSK 0x00008000
+/* inverted bitmask for bitfield soft reset */
+#define HW_ATL_GLB_SOFT_RES_MSKN 0xffff7fff
+/* lower bit position of bitfield soft reset */
+#define HW_ATL_GLB_SOFT_RES_SHIFT 15
+/* width of bitfield soft reset */
+#define HW_ATL_GLB_SOFT_RES_WIDTH 1
+/* default value of bitfield soft reset */
+#define HW_ATL_GLB_SOFT_RES_DEFAULT 0x0
+
+/* mif register reset disable bitfield definitions
+ * preprocessor definitions for the bitfield "register reset disable".
+ * port="pif_glb_reg_res_dsbl_i"
+ */
+
+/* register address for bitfield register reset disable */
+#define HW_ATL_GLB_REG_RES_DIS_ADR 0x00000000
+/* bitmask for bitfield register reset disable */
+#define HW_ATL_GLB_REG_RES_DIS_MSK 0x00004000
+/* inverted bitmask for bitfield register reset disable */
+#define HW_ATL_GLB_REG_RES_DIS_MSKN 0xffffbfff
+/* lower bit position of bitfield register reset disable */
+#define HW_ATL_GLB_REG_RES_DIS_SHIFT 14
+/* width of bitfield register reset disable */
+#define HW_ATL_GLB_REG_RES_DIS_WIDTH 1
+/* default value of bitfield register reset disable */
+#define HW_ATL_GLB_REG_RES_DIS_DEFAULT 0x1
+
+/* tx dma debug control definitions */
+#define HW_ATL_TX_DMA_DEBUG_CTL_ADR 0x00008920u
+
+/* tx dma descriptor base address msw definitions */
+#define HW_ATL_TX_DMA_DESC_BASE_ADDRMSW_ADR(descriptor) \
+			(0x00007c04u + (descriptor) * 0x40)
+
+/* tx dma total request limit */
+#define HW_ATL_TX_DMA_TOTAL_REQ_LIMIT_ADR 0x00007b20u
+
+/* tx interrupt moderation control register definitions
+ * Preprocessor definitions for TX Interrupt Moderation Control Register
+ * Base Address: 0x00008980
+ * Parameter: queue {Q} | stride size 0x4 | range [0, 31]
+ */
+
+#define HW_ATL_TX_INTR_MODERATION_CTL_ADR(queue) (0x00008980u + (queue) * 0x4)
+
+/* pcie reg_res_dsbl bitfield definitions
+ * preprocessor definitions for the bitfield "reg_res_dsbl".
+ * port="pif_pci_reg_res_dsbl_i"
+ */
+
+/* register address for bitfield reg_res_dsbl */
+#define HW_ATL_PCI_REG_RES_DSBL_ADR 0x00001000
+/* bitmask for bitfield reg_res_dsbl */
+#define HW_ATL_PCI_REG_RES_DSBL_MSK 0x20000000
+/* inverted bitmask for bitfield reg_res_dsbl */
+#define HW_ATL_PCI_REG_RES_DSBL_MSKN 0xdfffffff
+/* lower bit position of bitfield reg_res_dsbl */
+#define HW_ATL_PCI_REG_RES_DSBL_SHIFT 29
+/* width of bitfield reg_res_dsbl */
+#define HW_ATL_PCI_REG_RES_DSBL_WIDTH 1
+/* default value of bitfield reg_res_dsbl */
+#define HW_ATL_PCI_REG_RES_DSBL_DEFAULT 0x1
+
+/* PCI core control register */
+#define HW_ATL_PCI_REG_CONTROL6_ADR 0x1014u
+
+/* global microprocessor scratch pad definitions */
+#define HW_ATL_GLB_CPU_SCRATCH_SCP_ADR(scratch_scp) \
+	(0x00000300u + (scratch_scp) * 0x4)
+
+/* register address for bitfield uP Force Interrupt */
+#define mcp_up_force_interrupt_adr 0x00000404
+/* bitmask for bitfield uP Force Interrupt */
+#define mcp_up_force_interrupt_msk 0x00000002
+/* inverted bitmask for bitfield uP Force Interrupt */
+#define mcp_up_force_interrupt_mskn 0xFFFFFFFD
+/* lower bit position of bitfield uP Force Interrupt */
+#define mcp_up_force_interrupt_shift 1
+/* width of bitfield uP Force Interrupt */
+#define mcp_up_force_interrupt_width 1
+/* default value of bitfield uP Force Interrupt */
+#define mcp_up_force_interrupt_default 0x0
+
+#endif /* HW_ATL_LLH_INTERNAL_H */
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_utils.c b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_utils.c
new file mode 100644
index 00000000..dc84363
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_utils.c
@@ -0,0 +1,922 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_utils.c: Definition of common functions for Atlantic hardware
+ * abstraction layer.
+ */
+
+#include "../aq_nic.h"
+#include "../aq_hw_utils.h"
+#include "hw_atl_utils.h"
+#include "hw_atl_llh.h"
+#include "hw_atl_llh_internal.h"
+
+#include <linux/random.h>
+
+#define HW_ATL_UCP_0X370_REG    0x0370U
+
+#define HW_ATL_MIF_CMD          0x0200U
+#define HW_ATL_MIF_ADDR         0x0208U
+#define HW_ATL_MIF_VAL          0x020CU
+
+#define HW_ATL_FW_SM_RAM        0x2U
+#define HW_ATL_MPI_FW_VERSION	0x18
+#define HW_ATL_MPI_CONTROL_ADR  0x0368U
+#define HW_ATL_MPI_STATE_ADR    0x036CU
+
+#define HW_ATL_MPI_STATE_MSK      0x00FFU
+#define HW_ATL_MPI_STATE_SHIFT    0U
+#define HW_ATL_MPI_SPEED_MSK      0x00FF0000U
+#define HW_ATL_MPI_SPEED_SHIFT    16U
+#define HW_ATL_MPI_DIRTY_WAKE_MSK 0x02000000U
+
+#define HW_ATL_MPI_DAISY_CHAIN_STATUS	0x704
+#define HW_ATL_MPI_BOOT_EXIT_CODE	0x388
+
+#define HW_ATL_MAC_PHY_CONTROL	0x4000
+#define HW_ATL_MAC_PHY_MPI_RESET_BIT 0x1D
+
+#define HW_ATL_FW_VER_1X 0x01050006U
+#define HW_ATL_FW_VER_2X 0x02000000U
+#define HW_ATL_FW_VER_3X 0x03000000U
+
+#define FORCE_FLASHLESS 0
+
+static int hw_atl_utils_ver_match(u32 ver_expected, u32 ver_actual);
+static int hw_atl_utils_mpi_set_state(struct aq_hw_s *self,
+				      enum hal_atl_utils_fw_state_e state);
+
+int hw_atl_utils_initfw(struct aq_hw_s *self, const struct aq_fw_ops **fw_ops)
+{
+	int err = 0;
+
+	err = hw_atl_utils_soft_reset(self);
+	if (err)
+		return err;
+
+	hw_atl_utils_hw_chip_features_init(self,
+					   &self->chip_features);
+
+	hw_atl_utils_get_fw_version(self, &self->fw_ver_actual);
+
+	if (hw_atl_utils_ver_match(HW_ATL_FW_VER_1X,
+				   self->fw_ver_actual) == 0) {
+		*fw_ops = &aq_fw_1x_ops;
+	} else if (hw_atl_utils_ver_match(HW_ATL_FW_VER_2X,
+					self->fw_ver_actual) == 0) {
+		*fw_ops = &aq_fw_2x_ops;
+	} else if (hw_atl_utils_ver_match(HW_ATL_FW_VER_3X,
+					self->fw_ver_actual) == 0) {
+		*fw_ops = &aq_fw_2x_ops;
+	} else {
+		aq_pr_err("Bad FW version detected: %x\n",
+			  self->fw_ver_actual);
+		return -EOPNOTSUPP;
+	}
+	self->aq_fw_ops = *fw_ops;
+	err = self->aq_fw_ops->init(self);
+	return err;
+}
+
+static int hw_atl_utils_soft_reset_flb(struct aq_hw_s *self)
+{
+	u32 gsr, val;
+	int k = 0;
+
+	aq_hw_write_reg(self, 0x404, 0x40e1);
+	AQ_HW_SLEEP(50);
+
+	/* Cleanup SPI */
+	val = aq_hw_read_reg(self, 0x53C);
+	aq_hw_write_reg(self, 0x53C, val | 0x10);
+
+	gsr = aq_hw_read_reg(self, HW_ATL_GLB_SOFT_RES_ADR);
+	aq_hw_write_reg(self, HW_ATL_GLB_SOFT_RES_ADR, (gsr & 0xBFFF) | 0x8000);
+
+	/* Kickstart MAC */
+	aq_hw_write_reg(self, 0x404, 0x80e0);
+	aq_hw_write_reg(self, 0x32a8, 0x0);
+	aq_hw_write_reg(self, 0x520, 0x1);
+
+	/* Reset SPI again because of possible interrupted SPI burst */
+	val = aq_hw_read_reg(self, 0x53C);
+	aq_hw_write_reg(self, 0x53C, val | 0x10);
+	AQ_HW_SLEEP(10);
+	/* Clear SPI reset state */
+	aq_hw_write_reg(self, 0x53C, val & ~0x10);
+
+	aq_hw_write_reg(self, 0x404, 0x180e0);
+
+	for (k = 0; k < 1000; k++) {
+		u32 flb_status = aq_hw_read_reg(self,
+						HW_ATL_MPI_DAISY_CHAIN_STATUS);
+
+		flb_status = flb_status & 0x10;
+		if (flb_status)
+			break;
+		AQ_HW_SLEEP(10);
+	}
+	if (k == 1000) {
+		aq_pr_err("MAC kickstart failed\n");
+		return -EIO;
+	}
+
+	/* FW reset */
+	aq_hw_write_reg(self, 0x404, 0x80e0);
+	AQ_HW_SLEEP(50);
+	aq_hw_write_reg(self, 0x3a0, 0x1);
+
+	/* Kickstart PHY - skipped */
+
+	/* Global software reset*/
+	hw_atl_rx_rx_reg_res_dis_set(self, 0U);
+	hw_atl_tx_tx_reg_res_dis_set(self, 0U);
+	aq_hw_write_reg_bit(self, HW_ATL_MAC_PHY_CONTROL,
+			    BIT(HW_ATL_MAC_PHY_MPI_RESET_BIT),
+			    HW_ATL_MAC_PHY_MPI_RESET_BIT, 0x0);
+	gsr = aq_hw_read_reg(self, HW_ATL_GLB_SOFT_RES_ADR);
+	aq_hw_write_reg(self, HW_ATL_GLB_SOFT_RES_ADR, (gsr & 0xBFFF) | 0x8000);
+
+	for (k = 0; k < 1000; k++) {
+		u32 fw_state = aq_hw_read_reg(self, HW_ATL_MPI_FW_VERSION);
+
+		if (fw_state)
+			break;
+		AQ_HW_SLEEP(10);
+	}
+	if (k == 1000) {
+		aq_pr_err("FW kickstart failed\n");
+		return -EIO;
+	}
+	/* Old FW requires fixed delay after init */
+	AQ_HW_SLEEP(15);
+
+	return 0;
+}
+
+static int hw_atl_utils_soft_reset_rbl(struct aq_hw_s *self)
+{
+	u32 gsr, val, rbl_status;
+	int k;
+
+	aq_hw_write_reg(self, 0x404, 0x40e1);
+	aq_hw_write_reg(self, 0x3a0, 0x1);
+	aq_hw_write_reg(self, 0x32a8, 0x0);
+
+	/* Alter RBL status */
+	aq_hw_write_reg(self, 0x388, 0xDEAD);
+
+	/* Cleanup SPI */
+	val = aq_hw_read_reg(self, 0x53C);
+	aq_hw_write_reg(self, 0x53C, val | 0x10);
+
+	/* Global software reset*/
+	hw_atl_rx_rx_reg_res_dis_set(self, 0U);
+	hw_atl_tx_tx_reg_res_dis_set(self, 0U);
+	aq_hw_write_reg_bit(self, HW_ATL_MAC_PHY_CONTROL,
+			    BIT(HW_ATL_MAC_PHY_MPI_RESET_BIT),
+			    HW_ATL_MAC_PHY_MPI_RESET_BIT, 0x0);
+	gsr = aq_hw_read_reg(self, HW_ATL_GLB_SOFT_RES_ADR);
+	aq_hw_write_reg(self, HW_ATL_GLB_SOFT_RES_ADR,
+			(gsr & 0xFFFFBFFF) | 0x8000);
+
+	if (FORCE_FLASHLESS)
+		aq_hw_write_reg(self, 0x534, 0x0);
+
+	aq_hw_write_reg(self, 0x404, 0x40e0);
+
+	/* Wait for RBL boot */
+	for (k = 0; k < 1000; k++) {
+		rbl_status = aq_hw_read_reg(self, 0x388) & 0xFFFF;
+		if (rbl_status && rbl_status != 0xDEAD)
+			break;
+		AQ_HW_SLEEP(10);
+	}
+	if (!rbl_status || rbl_status == 0xDEAD) {
+		aq_pr_err("RBL Restart failed");
+		return -EIO;
+	}
+
+	/* Restore NVR */
+	if (FORCE_FLASHLESS)
+		aq_hw_write_reg(self, 0x534, 0xA0);
+
+	if (rbl_status == 0xF1A7) {
+		aq_pr_err("No FW detected. Dynamic FW load not implemented\n");
+		return -ENOTSUPP;
+	}
+
+	for (k = 0; k < 1000; k++) {
+		u32 fw_state = aq_hw_read_reg(self, HW_ATL_MPI_FW_VERSION);
+
+		if (fw_state)
+			break;
+		AQ_HW_SLEEP(10);
+	}
+	if (k == 1000) {
+		aq_pr_err("FW kickstart failed\n");
+		return -EIO;
+	}
+	/* Old FW requires fixed delay after init */
+	AQ_HW_SLEEP(15);
+
+	return 0;
+}
+
+int hw_atl_utils_soft_reset(struct aq_hw_s *self)
+{
+	int k;
+	u32 boot_exit_code = 0;
+
+	for (k = 0; k < 1000; ++k) {
+		u32 flb_status = aq_hw_read_reg(self,
+						HW_ATL_MPI_DAISY_CHAIN_STATUS);
+		boot_exit_code = aq_hw_read_reg(self,
+						HW_ATL_MPI_BOOT_EXIT_CODE);
+		if (flb_status != 0x06000000 || boot_exit_code != 0)
+			break;
+	}
+
+	if (k == 1000) {
+		aq_pr_err("Neither RBL nor FLB firmware started\n");
+		return -EOPNOTSUPP;
+	}
+
+	self->rbl_enabled = (boot_exit_code != 0);
+
+	/* FW 1.x may bootup in an invalid POWER state (WOL feature).
+	 * We should work around this by forcing its state back to DEINIT
+	 */
+	if (!hw_atl_utils_ver_match(HW_ATL_FW_VER_1X,
+				    aq_hw_read_reg(self,
+						   HW_ATL_MPI_FW_VERSION))) {
+		int err = 0;
+
+		hw_atl_utils_mpi_set_state(self, MPI_DEINIT);
+		AQ_HW_WAIT_FOR((aq_hw_read_reg(self, HW_ATL_MPI_STATE_ADR) &
+			       HW_ATL_MPI_STATE_MSK) == MPI_DEINIT,
+			       10, 1000U);
+	}
+
+	if (self->rbl_enabled)
+		return hw_atl_utils_soft_reset_rbl(self);
+	else
+		return hw_atl_utils_soft_reset_flb(self);
+}
+
+int hw_atl_utils_fw_downld_dwords(struct aq_hw_s *self, u32 a,
+				  u32 *p, u32 cnt)
+{
+	int err = 0;
+
+	AQ_HW_WAIT_FOR(hw_atl_reg_glb_cpu_sem_get(self,
+						  HW_ATL_FW_SM_RAM) == 1U,
+						  1U, 10000U);
+
+	if (err < 0) {
+		bool is_locked;
+
+		hw_atl_reg_glb_cpu_sem_set(self, 1U, HW_ATL_FW_SM_RAM);
+		is_locked = hw_atl_reg_glb_cpu_sem_get(self, HW_ATL_FW_SM_RAM);
+		if (!is_locked) {
+			err = -ETIME;
+			goto err_exit;
+		}
+	}
+
+	aq_hw_write_reg(self, HW_ATL_MIF_ADDR, a);
+
+	for (++cnt; --cnt && !err;) {
+		aq_hw_write_reg(self, HW_ATL_MIF_CMD, 0x00008000U);
+
+		if (IS_CHIP_FEATURE(REVISION_B1))
+			AQ_HW_WAIT_FOR(a != aq_hw_read_reg(self,
+							   HW_ATL_MIF_ADDR),
+				       1, 1000U);
+		else
+			AQ_HW_WAIT_FOR(!(0x100 & aq_hw_read_reg(self,
+							   HW_ATL_MIF_CMD)),
+				       1, 1000U);
+
+		*(p++) = aq_hw_read_reg(self, HW_ATL_MIF_VAL);
+		a += 4;
+	}
+
+	hw_atl_reg_glb_cpu_sem_set(self, 1U, HW_ATL_FW_SM_RAM);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_utils_fw_upload_dwords(struct aq_hw_s *self, u32 a, u32 *p,
+					 u32 cnt)
+{
+	int err = 0;
+	bool is_locked;
+
+	is_locked = hw_atl_reg_glb_cpu_sem_get(self, HW_ATL_FW_SM_RAM);
+	if (!is_locked) {
+		err = -ETIME;
+		goto err_exit;
+	}
+	if (IS_CHIP_FEATURE(REVISION_B1)) {
+		u32 offset = 0;
+
+		for (; offset < cnt; ++offset) {
+			aq_hw_write_reg(self, 0x328, p[offset]);
+			aq_hw_write_reg(self, 0x32C,
+				(0x80000000 | (0xFFFF & (offset * 4))));
+			mcp_up_force_intr_set(self, 1);
+			/* 1000 times by 10us = 10ms */
+			AQ_HW_WAIT_FOR((aq_hw_read_reg(self,
+					0x32C) & 0xF0000000) != 0x80000000,
+					10, 1000);
+		}
+	} else {
+		u32 offset = 0;
+
+		aq_hw_write_reg(self, 0x208, a);
+
+		for (; offset < cnt; ++offset) {
+			aq_hw_write_reg(self, 0x20C, p[offset]);
+			aq_hw_write_reg(self, 0x200, 0xC000);
+
+			AQ_HW_WAIT_FOR((aq_hw_read_reg(self, 0x200U)
+					& 0x100) == 0, 10, 1000);
+		}
+	}
+
+	hw_atl_reg_glb_cpu_sem_set(self, 1U, HW_ATL_FW_SM_RAM);
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_utils_ver_match(u32 ver_expected, u32 ver_actual)
+{
+	int err = 0;
+	const u32 dw_major_mask = 0xff000000U;
+	const u32 dw_minor_mask = 0x00ffffffU;
+
+	err = (dw_major_mask & (ver_expected ^ ver_actual)) ? -EOPNOTSUPP : 0;
+	if (err < 0)
+		goto err_exit;
+	err = ((dw_minor_mask & ver_expected) > (dw_minor_mask & ver_actual)) ?
+		-EOPNOTSUPP : 0;
+err_exit:
+	return err;
+}
+
+static int hw_atl_utils_init_ucp(struct aq_hw_s *self,
+				 const struct aq_hw_caps_s *aq_hw_caps)
+{
+	int err = 0;
+
+	if (!aq_hw_read_reg(self, 0x370U)) {
+		unsigned int rnd = 0U;
+		unsigned int ucp_0x370 = 0U;
+
+		get_random_bytes(&rnd, sizeof(unsigned int));
+
+		ucp_0x370 = 0x02020202U | (0xFEFEFEFEU & rnd);
+		aq_hw_write_reg(self, HW_ATL_UCP_0X370_REG, ucp_0x370);
+	}
+
+	hw_atl_reg_glb_cpu_scratch_scp_set(self, 0x00000000U, 25U);
+
+	/* check 10 times by 1ms */
+	AQ_HW_WAIT_FOR(0U != (self->mbox_addr =
+		       aq_hw_read_reg(self, 0x360U)), 1000U, 10U);
+	AQ_HW_WAIT_FOR(0U != (self->rpc_addr =
+		       aq_hw_read_reg(self, 0x334U)), 1000U, 100U);
+
+	return err;
+}
+
+#define HW_ATL_RPC_CONTROL_ADR 0x0338U
+#define HW_ATL_RPC_STATE_ADR   0x033CU
+
+struct aq_hw_atl_utils_fw_rpc_tid_s {
+	union {
+		u32 val;
+		struct {
+			u16 tid;
+			u16 len;
+		};
+	};
+};
+
+#define hw_atl_utils_fw_rpc_init(_H_) hw_atl_utils_fw_rpc_wait(_H_, NULL)
+
+int hw_atl_utils_fw_rpc_call(struct aq_hw_s *self, unsigned int rpc_size)
+{
+	int err = 0;
+	struct aq_hw_atl_utils_fw_rpc_tid_s sw;
+
+	if (!IS_CHIP_FEATURE(MIPS)) {
+		err = -1;
+		goto err_exit;
+	}
+	err = hw_atl_utils_fw_upload_dwords(self, self->rpc_addr,
+					    (u32 *)(void *)&self->rpc,
+					    (rpc_size + sizeof(u32) -
+					    sizeof(u8)) / sizeof(u32));
+	if (err < 0)
+		goto err_exit;
+
+	sw.tid = 0xFFFFU & (++self->rpc_tid);
+	sw.len = (u16)rpc_size;
+	aq_hw_write_reg(self, HW_ATL_RPC_CONTROL_ADR, sw.val);
+
+err_exit:
+	return err;
+}
+
+int hw_atl_utils_fw_rpc_wait(struct aq_hw_s *self,
+				    struct hw_aq_atl_utils_fw_rpc **rpc)
+{
+	int err = 0;
+	struct aq_hw_atl_utils_fw_rpc_tid_s sw;
+	struct aq_hw_atl_utils_fw_rpc_tid_s fw;
+
+	do {
+		sw.val = aq_hw_read_reg(self, HW_ATL_RPC_CONTROL_ADR);
+
+		self->rpc_tid = sw.tid;
+
+		AQ_HW_WAIT_FOR(sw.tid ==
+				(fw.val =
+				aq_hw_read_reg(self, HW_ATL_RPC_STATE_ADR),
+				fw.tid), 1000U, 100U);
+		if (err < 0)
+			goto err_exit;
+
+		if (fw.len == 0xFFFFU) {
+			err = hw_atl_utils_fw_rpc_call(self, sw.len);
+			if (err < 0)
+				goto err_exit;
+		}
+	} while (sw.tid != fw.tid || 0xFFFFU == fw.len);
+	if (err < 0)
+		goto err_exit;
+
+	if (rpc) {
+		if (fw.len) {
+			err =
+			hw_atl_utils_fw_downld_dwords(self,
+						      self->rpc_addr,
+						      (u32 *)(void *)
+						      &self->rpc,
+						      (fw.len + sizeof(u32) -
+						      sizeof(u8)) /
+						      sizeof(u32));
+			if (err < 0)
+				goto err_exit;
+		}
+
+		*rpc = &self->rpc;
+	}
+
+err_exit:
+	return err;
+}
+
+static int hw_atl_utils_mpi_create(struct aq_hw_s *self)
+{
+	int err = 0;
+
+	err = hw_atl_utils_init_ucp(self, self->aq_nic_cfg->aq_hw_caps);
+	if (err < 0)
+		goto err_exit;
+
+	err = hw_atl_utils_fw_rpc_init(self);
+	if (err < 0)
+		goto err_exit;
+
+err_exit:
+	return err;
+}
+
+int hw_atl_utils_mpi_read_mbox(struct aq_hw_s *self,
+			       struct hw_aq_atl_utils_mbox_header *pmbox)
+{
+	return hw_atl_utils_fw_downld_dwords(self,
+				      self->mbox_addr,
+				      (u32 *)(void *)pmbox,
+				      sizeof(*pmbox) / sizeof(u32));
+}
+
+void hw_atl_utils_mpi_read_stats(struct aq_hw_s *self,
+				 struct hw_aq_atl_utils_mbox *pmbox)
+{
+	int err = 0;
+
+	err = hw_atl_utils_fw_downld_dwords(self,
+					    self->mbox_addr,
+					    (u32 *)(void *)pmbox,
+					    sizeof(*pmbox) / sizeof(u32));
+	if (err < 0)
+		goto err_exit;
+
+	if (IS_CHIP_FEATURE(REVISION_A0)) {
+		unsigned int mtu = self->aq_nic_cfg ?
+					self->aq_nic_cfg->mtu : 1514U;
+		pmbox->stats.ubrc = pmbox->stats.uprc * mtu;
+		pmbox->stats.ubtc = pmbox->stats.uptc * mtu;
+		pmbox->stats.dpc = atomic_read(&self->dpc);
+	} else {
+		pmbox->stats.dpc = hw_atl_reg_rx_dma_stat_counter7get(self);
+	}
+
+err_exit:;
+}
+
+int hw_atl_utils_mpi_set_speed(struct aq_hw_s *self, u32 speed)
+{
+	u32 val = aq_hw_read_reg(self, HW_ATL_MPI_CONTROL_ADR);
+
+	val = val & ~HW_ATL_MPI_SPEED_MSK;
+	val |= speed << HW_ATL_MPI_SPEED_SHIFT;
+	aq_hw_write_reg(self, HW_ATL_MPI_CONTROL_ADR, val);
+
+	return 0;
+}
+
+int hw_atl_utils_mpi_set_state(struct aq_hw_s *self,
+				enum hal_atl_utils_fw_state_e state)
+{
+	int err = 0;
+	u32 transaction_id = 0;
+	struct hw_aq_atl_utils_mbox_header mbox;
+	u32 val = aq_hw_read_reg(self, HW_ATL_MPI_CONTROL_ADR);
+
+	if (state == MPI_RESET) {
+		hw_atl_utils_mpi_read_mbox(self, &mbox);
+
+		transaction_id = mbox.transaction_id;
+
+		AQ_HW_WAIT_FOR(transaction_id !=
+				(hw_atl_utils_mpi_read_mbox(self, &mbox),
+				 mbox.transaction_id),
+			       1000U, 100U);
+		if (err < 0)
+			goto err_exit;
+	}
+	/* On interface DEINIT we disable DW (raise bit)
+	 * Otherwise enable DW (clear bit)
+	 */
+	if (state == MPI_DEINIT || state == MPI_POWER)
+		val |= HW_ATL_MPI_DIRTY_WAKE_MSK;
+	else
+		val &= ~HW_ATL_MPI_DIRTY_WAKE_MSK;
+
+	/* Set new state bits */
+	val = val & ~HW_ATL_MPI_STATE_MSK;
+	val |= state & HW_ATL_MPI_STATE_MSK;
+
+	aq_hw_write_reg(self, HW_ATL_MPI_CONTROL_ADR, val);
+err_exit:
+	return err;
+}
+
+int hw_atl_utils_mpi_get_link_status(struct aq_hw_s *self)
+{
+	u32 cp0x036C = aq_hw_read_reg(self, HW_ATL_MPI_STATE_ADR);
+	u32 link_speed_mask = cp0x036C >> HW_ATL_MPI_SPEED_SHIFT;
+	struct aq_hw_link_status_s *link_status = &self->aq_link_status;
+
+	if (!link_speed_mask) {
+		link_status->mbps = 0U;
+	} else {
+		switch (link_speed_mask) {
+		case HAL_ATLANTIC_RATE_10G:
+			link_status->mbps = 10000U;
+			break;
+
+		case HAL_ATLANTIC_RATE_5G:
+		case HAL_ATLANTIC_RATE_5GSR:
+			link_status->mbps = 5000U;
+			break;
+
+		case HAL_ATLANTIC_RATE_2GS:
+			link_status->mbps = 2500U;
+			break;
+
+		case HAL_ATLANTIC_RATE_1G:
+			link_status->mbps = 1000U;
+			break;
+
+		case HAL_ATLANTIC_RATE_100M:
+			link_status->mbps = 100U;
+			break;
+
+		default:
+			return -EBUSY;
+		}
+	}
+
+	return 0;
+}
+
+int hw_atl_utils_get_mac_permanent(struct aq_hw_s *self,
+				   u8 *mac)
+{
+	int err = 0;
+	u32 h = 0U;
+	u32 l = 0U;
+	u32 mac_addr[2];
+
+	if (!aq_hw_read_reg(self, HW_ATL_UCP_0X370_REG)) {
+		unsigned int rnd = 0;
+		unsigned int ucp_0x370 = 0;
+
+		get_random_bytes(&rnd, sizeof(unsigned int));
+
+		ucp_0x370 = 0x02020202 | (0xFEFEFEFE & rnd);
+		aq_hw_write_reg(self, HW_ATL_UCP_0X370_REG, ucp_0x370);
+	}
+
+	err = hw_atl_utils_fw_downld_dwords(self,
+					    aq_hw_read_reg(self, 0x00000374U) +
+					    (40U * 4U),
+					    mac_addr,
+					    ARRAY_SIZE(mac_addr));
+	if (err < 0) {
+		mac_addr[0] = 0U;
+		mac_addr[1] = 0U;
+		err = 0;
+	} else {
+		mac_addr[0] = __swab32(mac_addr[0]);
+		mac_addr[1] = __swab32(mac_addr[1]);
+	}
+
+	ether_addr_copy(mac, (u8 *)mac_addr);
+
+	if ((mac[0] & 0x01U) || ((mac[0] | mac[1] | mac[2]) == 0x00U)) {
+		/* chip revision */
+		l = 0xE3000000U
+			| (0xFFFFU & aq_hw_read_reg(self, HW_ATL_UCP_0X370_REG))
+			| (0x00 << 16);
+		h = 0x8001300EU;
+
+		mac[5] = (u8)(0xFFU & l);
+		l >>= 8;
+		mac[4] = (u8)(0xFFU & l);
+		l >>= 8;
+		mac[3] = (u8)(0xFFU & l);
+		l >>= 8;
+		mac[2] = (u8)(0xFFU & l);
+		mac[1] = (u8)(0xFFU & h);
+		h >>= 8;
+		mac[0] = (u8)(0xFFU & h);
+	}
+
+	return err;
+}
+
+unsigned int hw_atl_utils_mbps_2_speed_index(unsigned int mbps)
+{
+	unsigned int ret = 0U;
+
+	switch (mbps) {
+	case 100U:
+		ret = 5U;
+		break;
+
+	case 1000U:
+		ret = 4U;
+		break;
+
+	case 2500U:
+		ret = 3U;
+		break;
+
+	case 5000U:
+		ret = 1U;
+		break;
+
+	case 10000U:
+		ret = 0U;
+		break;
+
+	default:
+		break;
+	}
+	return ret;
+}
+
+void hw_atl_utils_hw_chip_features_init(struct aq_hw_s *self, u32 *p)
+{
+	u32 chip_features = 0U;
+	u32 val = hw_atl_reg_glb_mif_id_get(self);
+	u32 mif_rev = val & 0xFFU;
+
+	if ((0xFU & mif_rev) == 1U) {
+		chip_features |= HAL_ATLANTIC_UTILS_CHIP_REVISION_A0 |
+			HAL_ATLANTIC_UTILS_CHIP_MPI_AQ |
+			HAL_ATLANTIC_UTILS_CHIP_MIPS;
+	} else if ((0xFU & mif_rev) == 2U) {
+		chip_features |= HAL_ATLANTIC_UTILS_CHIP_REVISION_B0 |
+			HAL_ATLANTIC_UTILS_CHIP_MPI_AQ |
+			HAL_ATLANTIC_UTILS_CHIP_MIPS |
+			HAL_ATLANTIC_UTILS_CHIP_TPO2 |
+			HAL_ATLANTIC_UTILS_CHIP_RPF2;
+	} else if ((0xFU & mif_rev) == 0xAU) {
+		chip_features |= HAL_ATLANTIC_UTILS_CHIP_REVISION_B1 |
+			HAL_ATLANTIC_UTILS_CHIP_MPI_AQ |
+			HAL_ATLANTIC_UTILS_CHIP_MIPS |
+			HAL_ATLANTIC_UTILS_CHIP_TPO2 |
+			HAL_ATLANTIC_UTILS_CHIP_RPF2;
+	}
+
+	*p = chip_features;
+}
+
+static int hw_atl_fw1x_deinit(struct aq_hw_s *self)
+{
+	hw_atl_utils_mpi_set_speed(self, 0);
+	hw_atl_utils_mpi_set_state(self, MPI_DEINIT);
+	return 0;
+}
+
+int hw_atl_utils_update_stats(struct aq_hw_s *self)
+{
+	struct hw_aq_atl_utils_mbox mbox;
+
+	hw_atl_utils_mpi_read_stats(self, &mbox);
+
+#define AQ_SDELTA(_N_) (self->curr_stats._N_ += \
+			mbox.stats._N_ - self->last_stats._N_)
+
+	if (self->aq_link_status.mbps) {
+		AQ_SDELTA(uprc);
+		AQ_SDELTA(mprc);
+		AQ_SDELTA(bprc);
+		AQ_SDELTA(erpt);
+
+		AQ_SDELTA(uptc);
+		AQ_SDELTA(mptc);
+		AQ_SDELTA(bptc);
+		AQ_SDELTA(erpr);
+
+		AQ_SDELTA(ubrc);
+		AQ_SDELTA(ubtc);
+		AQ_SDELTA(mbrc);
+		AQ_SDELTA(mbtc);
+		AQ_SDELTA(bbrc);
+		AQ_SDELTA(bbtc);
+		AQ_SDELTA(dpc);
+	}
+#undef AQ_SDELTA
+	self->curr_stats.dma_pkt_rc = hw_atl_stats_rx_dma_good_pkt_counterlsw_get(self);
+	self->curr_stats.dma_pkt_tc = hw_atl_stats_tx_dma_good_pkt_counterlsw_get(self);
+	self->curr_stats.dma_oct_rc = hw_atl_stats_rx_dma_good_octet_counterlsw_get(self);
+	self->curr_stats.dma_oct_tc = hw_atl_stats_tx_dma_good_octet_counterlsw_get(self);
+
+	memcpy(&self->last_stats, &mbox.stats, sizeof(mbox.stats));
+
+	return 0;
+}
+
+struct aq_stats_s *hw_atl_utils_get_hw_stats(struct aq_hw_s *self)
+{
+	return &self->curr_stats;
+}
+
+static const u32 hw_atl_utils_hw_mac_regs[] = {
+	0x00005580U, 0x00005590U, 0x000055B0U, 0x000055B4U,
+	0x000055C0U, 0x00005B00U, 0x00005B04U, 0x00005B08U,
+	0x00005B0CU, 0x00005B10U, 0x00005B14U, 0x00005B18U,
+	0x00005B1CU, 0x00005B20U, 0x00005B24U, 0x00005B28U,
+	0x00005B2CU, 0x00005B30U, 0x00005B34U, 0x00005B38U,
+	0x00005B3CU, 0x00005B40U, 0x00005B44U, 0x00005B48U,
+	0x00005B4CU, 0x00005B50U, 0x00005B54U, 0x00005B58U,
+	0x00005B5CU, 0x00005B60U, 0x00005B64U, 0x00005B68U,
+	0x00005B6CU, 0x00005B70U, 0x00005B74U, 0x00005B78U,
+	0x00005B7CU, 0x00007C00U, 0x00007C04U, 0x00007C08U,
+	0x00007C0CU, 0x00007C10U, 0x00007C14U, 0x00007C18U,
+	0x00007C1CU, 0x00007C20U, 0x00007C40U, 0x00007C44U,
+	0x00007C48U, 0x00007C4CU, 0x00007C50U, 0x00007C54U,
+	0x00007C58U, 0x00007C5CU, 0x00007C60U, 0x00007C80U,
+	0x00007C84U, 0x00007C88U, 0x00007C8CU, 0x00007C90U,
+	0x00007C94U, 0x00007C98U, 0x00007C9CU, 0x00007CA0U,
+	0x00007CC0U, 0x00007CC4U, 0x00007CC8U, 0x00007CCCU,
+	0x00007CD0U, 0x00007CD4U, 0x00007CD8U, 0x00007CDCU,
+	0x00007CE0U, 0x00000300U, 0x00000304U, 0x00000308U,
+	0x0000030cU, 0x00000310U, 0x00000314U, 0x00000318U,
+	0x0000031cU, 0x00000360U, 0x00000364U, 0x00000368U,
+	0x0000036cU, 0x00000370U, 0x00000374U, 0x00006900U,
+};
+
+int hw_atl_utils_hw_get_regs(struct aq_hw_s *self,
+			     const struct aq_hw_caps_s *aq_hw_caps,
+			     u32 *regs_buff)
+{
+	unsigned int i = 0U;
+
+	for (i = 0; i < aq_hw_caps->mac_regs_count; i++)
+		regs_buff[i] = aq_hw_read_reg(self,
+					      hw_atl_utils_hw_mac_regs[i]);
+	return 0;
+}
+
+int hw_atl_utils_get_fw_version(struct aq_hw_s *self, u32 *fw_version)
+{
+	*fw_version = aq_hw_read_reg(self, 0x18U);
+	return 0;
+}
+
+static int aq_fw1x_set_wol(struct aq_hw_s *self, bool wol_enabled, u8 *mac)
+{
+	struct hw_aq_atl_utils_fw_rpc *prpc = NULL;
+	unsigned int rpc_size = 0U;
+	int err = 0;
+
+	err = hw_atl_utils_fw_rpc_wait(self, &prpc);
+	if (err < 0)
+				goto err_exit;
+
+	memset(prpc, 0, sizeof *prpc);
+
+	if (wol_enabled) {
+		rpc_size = sizeof(prpc->msg_id) + sizeof(prpc->msg_wol);
+
+		prpc->msg_id = HAL_ATLANTIC_UTILS_FW_MSG_WOL_ADD;
+		prpc->msg_wol.priority = 0x10000000; /* normal priority */
+		prpc->msg_wol.pattern_id = 1U;
+		prpc->msg_wol.wol_packet_type = 2U; /* Magic Packet */
+
+		ether_addr_copy((u8 *)&prpc->msg_wol.wol_pattern, mac);
+	} else {
+		rpc_size = sizeof(prpc->msg_id) + sizeof(prpc->msg_del_id);
+
+		prpc->msg_id = HAL_ATLANTIC_UTILS_FW_MSG_WOL_DEL;
+		prpc->msg_wol.pattern_id = 1U;
+	}
+
+	err = hw_atl_utils_fw_rpc_call(self, rpc_size);
+	if (err < 0)
+		goto err_exit;
+err_exit:
+	return err;
+}
+
+int aq_fw1x_set_power(struct aq_hw_s *self,unsigned int power_state,
+		u8 *mac)
+{
+	struct hw_aq_atl_utils_fw_rpc *prpc = NULL;
+	unsigned int rpc_size = 0U;
+	int err = 0;
+	if (self->aq_nic_cfg->wol & AQ_NIC_WOL_ENABLED) {
+		err = aq_fw1x_set_wol(self, 1, mac);
+
+		if (err < 0)
+			goto err_exit;
+
+		rpc_size = sizeof(prpc->msg_id) +
+				sizeof(prpc->msg_enable_wakeup);
+
+		err = hw_atl_utils_fw_rpc_wait(self, &prpc);
+
+		if (err < 0)
+			goto err_exit;
+
+		memset(prpc, 0, rpc_size);
+
+		prpc->msg_id = HAL_ATLANTIC_UTILS_FW_MSG_ENABLE_WAKEUP;
+		prpc->msg_enable_wakeup.pattern_mask = 0x00000002;
+
+		err = hw_atl_utils_fw_rpc_call(self, rpc_size);
+		if (err < 0)
+			goto err_exit;
+	}
+	hw_atl_utils_mpi_set_speed(self, 0);
+	hw_atl_utils_mpi_set_state(self, MPI_POWER);
+err_exit:
+	return err;
+}
+
+
+
+const struct aq_fw_ops aq_fw_1x_ops = {
+	.init = hw_atl_utils_mpi_create,
+	.deinit = hw_atl_fw1x_deinit,
+	.reset = NULL,
+	.get_mac_permanent = hw_atl_utils_get_mac_permanent,
+	.set_link_speed = hw_atl_utils_mpi_set_speed,
+	.set_state = hw_atl_utils_mpi_set_state,
+	.update_link_status = hw_atl_utils_mpi_get_link_status,
+	.update_stats = hw_atl_utils_update_stats,
+	.set_power = aq_fw1x_set_power,
+	.get_temp = NULL,
+	.get_cable_len = NULL,
+	.set_eee_rate = NULL,
+	.get_eee_rate = NULL,
+	.set_flow_control = NULL,
+};
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_utils.h b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_utils.h
new file mode 100644
index 00000000..755b23a
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_utils.h
@@ -0,0 +1,486 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_utils.h: Declaration of common functions for Atlantic hardware
+ * abstraction layer.
+ */
+
+#ifndef HW_ATL_UTILS_H
+#define HW_ATL_UTILS_H
+
+#define HW_ATL_FLUSH() { (void)aq_hw_read_reg(self, 0x10); }
+
+/* Hardware tx descriptor */
+struct __packed hw_atl_txd_s {
+	u64 buf_addr;
+	u32 ctl;
+	u32 ctl2; /* 63..46 - payload length, 45 - ctx enable, 44 - ctx index */
+};
+
+/* Hardware tx context descriptor */
+struct __packed hw_atl_txc_s {
+	u32 rsvd;
+	u32 len;
+	u32 ctl;
+	u32 len2;
+};
+
+/* Hardware rx descriptor */
+struct __packed hw_atl_rxd_s {
+	u64 buf_addr;
+	u64 hdr_addr;
+};
+
+/* Hardware rx descriptor writeback */
+struct __packed hw_atl_rxd_wb_s {
+	u32 type;
+	u32 rss_hash;
+	u16 status;
+	u16 pkt_len;
+	u16 next_desc_ptr;
+	u16 vlan;
+};
+
+struct __packed hw_atl_stats_s {
+	u32 uprc;
+	u32 mprc;
+	u32 bprc;
+	u32 erpt;
+	u32 uptc;
+	u32 mptc;
+	u32 bptc;
+	u32 erpr;
+	u32 mbtc;
+	u32 bbtc;
+	u32 mbrc;
+	u32 bbrc;
+	u32 ubrc;
+	u32 ubtc;
+	u32 dpc;
+};
+
+union __packed ip_addr {
+	struct {
+		u8 addr[16];
+	} v6;
+	struct {
+		u8 padding[12];
+		u8 addr[4];
+	} v4;
+};
+
+struct __packed hw_aq_atl_utils_fw_rpc {
+	u32 msg_id;
+
+	union {
+		struct {
+			u32 pong;
+		} msg_ping;
+
+		struct {
+			u8 mac_addr[6];
+			u32 ip_addr_cnt;
+
+			struct {
+				union ip_addr addr;
+				union ip_addr mask;
+			} ip[1];
+		} msg_arp;
+
+		struct {
+			u32 len;
+			u8 packet[1514U];
+		} msg_inject;
+
+		struct {
+			u32 priority;
+			u32 wol_packet_type;
+			u32 pattern_id;
+			u32 next_wol_pattern_offset;
+			union {
+				struct {
+					u32 flags;
+					u8 ipv4_source_address[4];
+					u8 ipv4_dest_address[4];
+					u16 tcp_source_port_number;
+					u16 tcp_dest_port_number;
+				} ipv4_tcp_syn_parameters;
+
+				struct {
+					u32 flags;
+					u8 ipv6_source_address[16];
+					u8 ipv6_dest_address[16];
+					u16 tcp_source_port_number;
+					u16 tcp_dest_port_number;
+				} ipv6_tcp_syn_parameters;
+
+				struct {
+					u32 flags;
+				} eapol_request_id_message_parameters;
+
+				struct {
+					u32 flags;
+					u32 mask_offset;
+					u32 mask_size;
+					u32 pattern_offset;
+					u32 pattern_size;
+				} wol_bit_map_pattern;
+				struct {
+					u8 mac_addr[6];
+				} wol_magic_packet_pattern;
+
+			} wol_pattern;
+		} msg_wol;
+
+		struct {
+			u16 tcQuanta[8];
+			u16 tcThreshold[8];
+		} msg_msm_pfc_quantas;
+
+		struct {
+			union {
+				u32 pattern_mask;
+				struct {
+					u32 aq_pm_wol_reason_arp_v4_pkt : 1;
+					u32 aq_pm_wol_reason_ipv4_ping_pkt : 1;
+					u32 aq_pm_wol_reason_ipv6_ns_pkt : 1;
+					u32 aq_pm_wol_reason_ipv6_ping_pkt : 1;
+					u32 aq_pm_wol_reason_link_up : 1;
+					u32 aq_pm_wol_reason_link_down : 1;
+					u32 aq_pm_wol_reason_maximum : 1;
+				};
+			};
+			union {
+				u32 offload_mask;
+			};
+		} msg_enable_wakeup;
+
+		struct {
+			u32 priority;
+			u32 protocol_offload_type;
+			u32 protocol_offload_id;
+			u32 next_protocol_offload_offset;
+
+			union {
+				struct {
+					u32 flags;
+					u8 remote_ipv4_addr[4];
+					u8 host_ipv4_addr[4];
+					u8 mac_addr[6];
+				} ipv4_arp_params;
+			};
+		} msg_offload;
+
+		struct {
+			u32 id;
+		} msg_del_id;
+
+	};
+};
+
+struct __packed hw_aq_atl_utils_mbox_header {
+	u32 version;
+	u32 transaction_id;
+	u32 error;
+};
+
+struct __packed hw_aq_info {
+	u8 reserved[6];
+	u16 phy_fault_code;
+	u16 phy_temperature;
+	u8 cable_len;
+	u8 reserved1;
+	u32 cable_diag_data[4];
+	u8 reserved2[32];
+	u32 caps_lo;
+	u32 caps_hi;
+};
+
+struct __packed hw_aq_atl_utils_mbox {
+	struct hw_aq_atl_utils_mbox_header header;
+	struct hw_atl_stats_s stats;
+	struct hw_aq_info info;
+};
+
+/* fw2x */
+typedef u16	in_port_t;
+typedef u32	ip4_addr_t;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+typedef int	int32_t;
+typedef short	int16_t;
+#endif
+typedef u32	fw_offset_t;
+
+struct __packed ip6_addr {
+	u32 addr[4];
+};
+
+struct __packed offload_ka_v4 {
+	u32 timeout;
+	in_port_t local_port;
+	in_port_t remote_port;
+	u8 remote_mac_addr[6];
+	u16 win_size;
+	u32 seq_num;
+	u32 ack_num;
+	ip4_addr_t local_ip;
+	ip4_addr_t remote_ip;
+};
+
+struct __packed offload_ka_v6 {
+	u32 timeout;
+	in_port_t local_port;
+	in_port_t remote_port;
+	u8 remote_mac_addr[6];
+	u16 win_size;
+	u32 seq_num;
+	u32 ack_num;
+	struct ip6_addr local_ip;
+	struct ip6_addr remote_ip;
+};
+
+struct __packed offload_ip_info {
+	u8 v4_local_addr_count;
+	u8 v4_addr_count;
+	u8 v6_local_addr_count;
+	u8 v6_addr_count;
+	fw_offset_t v4_addr;
+	fw_offset_t v4_prefix;
+	fw_offset_t v6_addr;
+	fw_offset_t v6_prefix;
+};
+
+struct __packed offload_port_info {
+	u16 udp_port_count;
+	u16 tcp_port_count;
+	fw_offset_t udp_port;
+	fw_offset_t tcp_port;
+};
+
+struct __packed offload_ka_info {
+	u16 v4_ka_count;
+	u16 v6_ka_count;
+	u32 retry_count;
+	u32 retry_interval;
+	fw_offset_t v4_ka;
+	fw_offset_t v6_ka;
+};
+
+struct __packed offload_rr_info {
+	u32 rr_count;
+	u32 rr_buf_len;
+	fw_offset_t rr_id_x;
+	fw_offset_t rr_buf;
+};
+
+struct __packed offload_info {
+	u32 version;		// current version is 0x00000000
+	u32 len;		// The whole structure length
+				// including the variable-size buf
+	u8 mac_addr[6];		// 8 bytes to keep alignment. Only
+				// first 6 meaningful.
+
+	u8 reserved[2];
+
+	struct offload_ip_info ips;
+	struct offload_port_info ports;
+	struct offload_ka_info kas;
+	struct offload_rr_info rrs;
+	u8 buf[0];
+};
+
+#define HAL_ATLANTIC_UTILS_CHIP_MIPS         0x00000001U
+#define HAL_ATLANTIC_UTILS_CHIP_TPO2         0x00000002U
+#define HAL_ATLANTIC_UTILS_CHIP_RPF2         0x00000004U
+#define HAL_ATLANTIC_UTILS_CHIP_MPI_AQ       0x00000010U
+#define HAL_ATLANTIC_UTILS_CHIP_REVISION_A0  0x01000000U
+#define HAL_ATLANTIC_UTILS_CHIP_REVISION_B0  0x02000000U
+#define HAL_ATLANTIC_UTILS_CHIP_REVISION_B1  0x04000000U
+
+
+#define IS_CHIP_FEATURE(_F_) (HAL_ATLANTIC_UTILS_CHIP_##_F_ & \
+	self->chip_features)
+
+enum hal_atl_utils_fw_state_e {
+	MPI_DEINIT = 0,
+	MPI_RESET = 1,
+	MPI_INIT = 2,
+	MPI_POWER = 4,
+};
+
+#define HAL_ATLANTIC_RATE_10G        BIT(0)
+#define HAL_ATLANTIC_RATE_5G         BIT(1)
+#define HAL_ATLANTIC_RATE_5GSR       BIT(2)
+#define HAL_ATLANTIC_RATE_2GS        BIT(3)
+#define HAL_ATLANTIC_RATE_1G         BIT(4)
+#define HAL_ATLANTIC_RATE_100M       BIT(5)
+#define HAL_ATLANTIC_RATE_INVALID    BIT(6)
+
+#define HAL_ATLANTIC_UTILS_FW_MSG_PING     1U
+#define HAL_ATLANTIC_UTILS_FW_MSG_ARP      2U
+#define HAL_ATLANTIC_UTILS_FW_MSG_INJECT   3U
+#define HAL_ATLANTIC_UTILS_FW_MSG_WOL_ADD 4U
+#define HAL_ATLANTIC_UTILS_FW_MSG_WOL_DEL 5U
+#define HAL_ATLANTIC_UTILS_FW_MSG_ENABLE_WAKEUP 6U
+#define HAL_ATLANTIC_UTILS_FW_MSG_MSM_PFC  7U
+#define HAL_ATLANTIC_UTILS_FW_MSG_PROVISIONING 8U
+#define HAL_ATLANTIC_UTILS_FW_MSG_OFFLOAD_ADD  9U
+#define HAL_ATLANTIC_UTILS_FW_MSG_OFFLOAD_DEL  10U
+#define HAL_ATLANTIC_UTILS_FW_MSG_CABLE_DIAG   13U // 0xd
+
+enum hw_atl_fw2x_rate {
+	FW2X_RATE_100M    = 0x20,
+	FW2X_RATE_1G      = 0x100,
+	FW2X_RATE_2G5     = 0x200,
+	FW2X_RATE_5G      = 0x400,
+	FW2X_RATE_10G     = 0x800,
+};
+
+enum hw_atl_fw2x_caps_lo {
+	CAPS_LO_10BASET_HD = 0x00,
+	CAPS_LO_10BASET_FD,
+	CAPS_LO_100BASETX_HD,
+	CAPS_LO_100BASET4_HD,
+	CAPS_LO_100BASET2_HD,
+	CAPS_LO_100BASETX_FD,
+	CAPS_LO_100BASET2_FD,
+	CAPS_LO_1000BASET_HD,
+	CAPS_LO_1000BASET_FD,
+	CAPS_LO_2P5GBASET_FD,
+	CAPS_LO_5GBASET_FD,
+	CAPS_LO_10GBASET_FD,
+};
+
+enum hw_atl_fw2x_caps_hi {
+	CAPS_HI_RESERVED1 = 0x00,
+	CAPS_HI_10BASET_EEE,
+	CAPS_HI_RESERVED2,
+	CAPS_HI_PAUSE,
+	CAPS_HI_ASYMMETRIC_PAUSE,
+	CAPS_HI_100BASETX_EEE,
+	CAPS_HI_RESERVED3,
+	CAPS_HI_RESERVED4,
+	CAPS_HI_1000BASET_FD_EEE,
+	CAPS_HI_2P5GBASET_FD_EEE,
+	CAPS_HI_5GBASET_FD_EEE,
+	CAPS_HI_10GBASET_FD_EEE,
+	CAPS_HI_RESERVED5,
+	CAPS_HI_RESERVED6,
+	CAPS_HI_RESERVED7,
+	CAPS_HI_RESERVED8,
+	CAPS_HI_RESERVED9,
+	CAPS_HI_CABLE_DIAG,
+	CAPS_HI_TEMPERATURE,
+	CAPS_HI_DOWNSHIFT,
+	CAPS_HI_PTP_AVB_EN,
+	CAPS_HI_MEDIA_DETECT,
+	CAPS_HI_LINK_DROP,
+	CAPS_HI_SLEEP_PROXY,
+	CAPS_HI_WOL,
+	CAPS_HI_MAC_STOP,
+	CAPS_HI_EXT_LOOPBACK,
+	CAPS_HI_INT_LOOPBACK,
+	CAPS_HI_EFUSE_AGENT,
+	CAPS_HI_WOL_TIMER,
+	CAPS_HI_STATISTICS,
+	CAPS_HI_TRANSACTION_ID,
+};
+
+enum hw_atl_fw2x_ctrl {
+	CTRL_RESERVED1 = 0x00,
+	CTRL_RESERVED2,
+	CTRL_RESERVED3,
+	CTRL_PAUSE,
+	CTRL_ASYMMETRIC_PAUSE,
+	CTRL_RESERVED4,
+	CTRL_RESERVED5,
+	CTRL_RESERVED6,
+	CTRL_1GBASET_FD_EEE,
+	CTRL_2P5GBASET_FD_EEE,
+	CTRL_5GBASET_FD_EEE,
+	CTRL_10GBASET_FD_EEE,
+	CTRL_THERMAL_SHUTDOWN,
+	CTRL_PHY_LOGS,
+	CTRL_EEE_AUTO_DISABLE,
+	CTRL_PFC,
+	CTRL_WAKE_ON_LINK,
+	CTRL_CABLE_DIAG,
+	CTRL_TEMPERATURE,
+	CTRL_DOWNSHIFT,
+	CTRL_PTP_AVB,
+	CTRL_RESERVED7,
+	CTRL_LINK_DROP,
+	CTRL_SLEEP_PROXY,
+	CTRL_WOL,
+	CTRL_MAC_STOP,
+	CTRL_EXT_LOOPBACK,
+	CTRL_INT_LOOPBACK,
+	CTRL_RESERVED8,
+	CTRL_WOL_TIMER,
+	CTRL_STATISTICS,
+	CTRL_FORCE_RECONNECT,
+};
+
+struct aq_hw_s;
+struct aq_fw_ops;
+struct aq_hw_caps_s;
+struct aq_hw_link_status_s;
+
+int hw_atl_utils_initfw(struct aq_hw_s *self, const struct aq_fw_ops **fw_ops);
+
+int hw_atl_utils_soft_reset(struct aq_hw_s *self);
+
+void hw_atl_utils_hw_chip_features_init(struct aq_hw_s *self, u32 *p);
+
+int hw_atl_utils_mpi_read_mbox(struct aq_hw_s *self,
+			       struct hw_aq_atl_utils_mbox_header *pmbox);
+
+void hw_atl_utils_mpi_read_stats(struct aq_hw_s *self,
+				 struct hw_aq_atl_utils_mbox *pmbox);
+
+void hw_atl_utils_mpi_set(struct aq_hw_s *self,
+			  enum hal_atl_utils_fw_state_e state,
+			  u32 speed);
+
+int hw_atl_utils_mpi_get_link_status(struct aq_hw_s *self);
+
+int hw_atl_utils_get_mac_permanent(struct aq_hw_s *self,
+				   u8 *mac);
+
+unsigned int hw_atl_utils_mbps_2_speed_index(unsigned int mbps);
+
+int hw_atl_utils_hw_get_regs(struct aq_hw_s *self,
+			     const struct aq_hw_caps_s *aq_hw_caps,
+			     u32 *regs_buff);
+
+int hw_atl_utils_hw_set_power(struct aq_hw_s *self,
+			      unsigned int power_state);
+
+int hw_atl_utils_hw_deinit(struct aq_hw_s *self);
+
+int hw_atl_utils_get_fw_version(struct aq_hw_s *self, u32 *fw_version);
+
+int hw_atl_utils_update_stats(struct aq_hw_s *self);
+
+struct aq_stats_s *hw_atl_utils_get_hw_stats(struct aq_hw_s *self);
+
+int hw_atl_utils_fw_downld_dwords(struct aq_hw_s *self, u32 a,
+				  u32 *p, u32 cnt);
+
+int hw_atl_utils_fw_set_wol(struct aq_hw_s *self, bool wol_enabled, u8 *mac);
+
+int hw_atl_utils_fw_rpc_call(struct aq_hw_s *self, unsigned int rpc_size);
+
+int hw_atl_utils_fw_rpc_wait(struct aq_hw_s *self,
+		    struct hw_aq_atl_utils_fw_rpc **rpc);
+
+extern const struct aq_fw_ops aq_fw_1x_ops;
+extern const struct aq_fw_ops aq_fw_2x_ops;
+
+#endif /* HW_ATL_UTILS_H */
diff --git a/drivers/net/ethernet/aquantia/hw_atl/hw_atl_utils_fw2x.c b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_utils_fw2x.c
new file mode 100644
index 00000000..54e9bfd
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/hw_atl/hw_atl_utils_fw2x.c
@@ -0,0 +1,501 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+/* File hw_atl_utils_fw2x.c: Definition of firmware 2.x functions for
+ * Atlantic hardware abstraction layer.
+ */
+
+#include "../aq_hw.h"
+#include "../aq_hw_utils.h"
+#include "../aq_pci_func.h"
+#include "../aq_ring.h"
+#include "../aq_vec.h"
+#include "../aq_nic.h"
+#include "hw_atl_utils.h"
+#include "hw_atl_llh.h"
+
+#define HW_ATL_FW2X_MPI_EFUSE_ADDR       0x364
+#define HW_ATL_FW2X_MPI_MBOX_ADDR        0x360
+#define HW_ATL_FW2X_MPI_RPC_ADDR         0x334
+
+#define HW_ATL_FW2X_MPI_CONTROL_ADDR     0x368
+#define HW_ATL_FW2X_MPI_CONTROL2_ADDR    0x36C
+
+#define HW_ATL_FW2X_MPI_STATE_ADDR       0x370
+#define HW_ATL_FW2X_MPI_STATE2_ADDR      0x374
+
+#define HW_ATL_FW2X_CAP_SLEEP_PROXY      BIT(CAPS_HI_SLEEP_PROXY)
+#define HW_ATL_FW2X_CAP_WOL              BIT(CAPS_HI_WOL)
+
+#define HW_ATL_FW2X_CAP_EEE_1G_MASK      BIT(CAPS_HI_1000BASET_FD_EEE)
+#define HW_ATL_FW2X_CAP_EEE_2G5_MASK     BIT(CAPS_HI_2P5GBASET_FD_EEE)
+#define HW_ATL_FW2X_CAP_EEE_5G_MASK      BIT(CAPS_HI_5GBASET_FD_EEE)
+#define HW_ATL_FW2X_CAP_EEE_10G_MASK     BIT(CAPS_HI_10GBASET_FD_EEE)
+
+#define HAL_ATLANTIC_WOL_FILTERS_COUNT   8
+#define HAL_ATLANTIC_UTILS_FW2X_MSG_WOL  0x0E
+
+struct __packed fw2x_msg_wol_pattern {
+	u8 mask[16];
+	u32 crc;
+};
+
+struct __packed fw2x_msg_wol {
+	u32 msg_id;
+	u8 hw_addr[6];
+	u8 magic_packet_enabled;
+	u8 filter_count;
+	struct fw2x_msg_wol_pattern filter[HAL_ATLANTIC_WOL_FILTERS_COUNT];
+	u8 link_up_enabled;
+	u8 link_down_enabled;
+	u16 reserved;
+	u32 link_up_timeout;
+	u32 link_down_timeout;
+};
+
+static int aq_fw2x_set_link_speed(struct aq_hw_s *self, u32 speed);
+static int aq_fw2x_set_state(struct aq_hw_s *self,
+			     enum hal_atl_utils_fw_state_e state);
+
+static int aq_fw2x_init(struct aq_hw_s *self)
+{
+	int err = 0;
+
+	/* check 10 times by 1ms */
+	AQ_HW_WAIT_FOR(0U != (self->mbox_addr =
+		       aq_hw_read_reg(self, HW_ATL_FW2X_MPI_MBOX_ADDR)),
+		       1000U, 10U);
+	AQ_HW_WAIT_FOR(0U != (self->rpc_addr =
+		       aq_hw_read_reg(self, HW_ATL_FW2X_MPI_RPC_ADDR)),
+		       1000U, 100U);
+	return err;
+}
+
+static int aq_fw2x_deinit(struct aq_hw_s *self)
+{
+	int err = aq_fw2x_set_link_speed(self, 0);
+
+	if (!err)
+		err = aq_fw2x_set_state(self, MPI_DEINIT);
+
+	return err;
+}
+
+static enum hw_atl_fw2x_rate link_speed_mask_2fw2x_ratemask(u32 speed)
+{
+	enum hw_atl_fw2x_rate rate = 0;
+
+	if (speed & AQ_NIC_RATE_10G)
+		rate |= FW2X_RATE_10G;
+	if (speed & AQ_NIC_RATE_5G)
+		rate |= FW2X_RATE_5G;
+	if (speed & AQ_NIC_RATE_5GSR)
+		rate |= FW2X_RATE_5G;
+	if (speed & AQ_NIC_RATE_2GS)
+		rate |= FW2X_RATE_2G5;
+	if (speed & AQ_NIC_RATE_1G)
+		rate |= FW2X_RATE_1G;
+	if (speed & AQ_NIC_RATE_100M)
+		rate |= FW2X_RATE_100M;
+
+	return rate;
+}
+
+static u32 fw2x_to_eee_mask(u32 speed)
+{
+	u32 rate = 0;
+
+	if (speed & HW_ATL_FW2X_CAP_EEE_10G_MASK)
+		rate |= AQ_NIC_RATE_EEE_10G;
+	if (speed & HW_ATL_FW2X_CAP_EEE_5G_MASK)
+		rate |= AQ_NIC_RATE_EEE_5G;
+	if (speed & HW_ATL_FW2X_CAP_EEE_2G5_MASK)
+		rate |= AQ_NIC_RATE_EEE_2GS;
+	if (speed & HW_ATL_FW2X_CAP_EEE_1G_MASK)
+		rate|= AQ_NIC_RATE_EEE_1G;
+
+	return rate;
+}
+
+static u32 eee_mask_to_fw2x(u32 speed)
+{
+	u32 rate = 0;
+
+	if (speed & AQ_NIC_RATE_EEE_10G)
+		rate |= HW_ATL_FW2X_CAP_EEE_10G_MASK;
+	if (speed & AQ_NIC_RATE_EEE_5G)
+		rate |= HW_ATL_FW2X_CAP_EEE_5G_MASK;
+	if (speed & AQ_NIC_RATE_EEE_2GS)
+		rate |= HW_ATL_FW2X_CAP_EEE_2G5_MASK;
+	if (speed & AQ_NIC_RATE_EEE_1G)
+		rate |= HW_ATL_FW2X_CAP_EEE_1G_MASK;
+
+	return rate;
+}
+
+static int aq_fw2x_set_link_speed(struct aq_hw_s *self, u32 speed)
+{
+	u32 val = link_speed_mask_2fw2x_ratemask(speed);
+
+	aq_hw_write_reg(self, HW_ATL_FW2X_MPI_CONTROL_ADDR, val);
+
+	return 0;
+}
+
+static void aq_fw2x_set_mpi_flow_control(struct aq_hw_s *self, u32 *mpi_state)
+{
+	if (self->aq_nic_cfg->flow_control & AQ_NIC_FC_RX)
+		*mpi_state |= BIT(CAPS_HI_PAUSE);
+	else
+		*mpi_state &= ~BIT(CAPS_HI_PAUSE);
+
+	if (self->aq_nic_cfg->flow_control & AQ_NIC_FC_TX)
+		*mpi_state |= BIT(CAPS_HI_ASYMMETRIC_PAUSE);
+	else
+		*mpi_state &= ~BIT(CAPS_HI_ASYMMETRIC_PAUSE);
+}
+
+static int aq_fw2x_set_state(struct aq_hw_s *self,
+			     enum hal_atl_utils_fw_state_e state)
+{
+	u32 mpi_state = aq_hw_read_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR);
+
+	switch(state) {
+	case MPI_INIT:
+		mpi_state &= ~BIT(CAPS_HI_LINK_DROP);
+		if (self->aq_nic_cfg->eee_enabled)
+			mpi_state |= eee_mask_to_fw2x(self->aq_nic_cfg->eee_enabled);
+		aq_fw2x_set_mpi_flow_control(self, &mpi_state);
+		break;
+	case MPI_DEINIT:
+		mpi_state |= BIT(CAPS_HI_LINK_DROP);
+		break;
+	case MPI_RESET:
+	case MPI_POWER:
+		/* No actions */
+		break;
+	}
+	aq_hw_write_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR, mpi_state);
+	return 0;
+}
+
+static int aq_fw2x_update_link_status(struct aq_hw_s *self)
+{
+	u32 mpi_state = aq_hw_read_reg(self, HW_ATL_FW2X_MPI_STATE_ADDR);
+	u32 speed = mpi_state & (FW2X_RATE_100M | FW2X_RATE_1G |
+				FW2X_RATE_2G5 | FW2X_RATE_5G | FW2X_RATE_10G);
+	struct aq_hw_link_status_s *link_status = &self->aq_link_status;
+
+	if (speed) {
+		if (speed & FW2X_RATE_10G)
+			link_status->mbps = 10000;
+		else if (speed & FW2X_RATE_5G)
+			link_status->mbps = 5000;
+		else if (speed & FW2X_RATE_2G5)
+			link_status->mbps = 2500;
+		else if (speed & FW2X_RATE_1G)
+			link_status->mbps = 1000;
+		else if (speed & FW2X_RATE_100M)
+			link_status->mbps = 100;
+		else
+			link_status->mbps = 10000;
+	} else {
+		link_status->mbps = 0;
+	}
+
+	return 0;
+}
+
+int aq_fw2x_get_mac_permanent(struct aq_hw_s *self, u8 *mac)
+{
+	int err = 0;
+	u32 h = 0U;
+	u32 l = 0U;
+	u32 mac_addr[2] = { 0 };
+	u32 efuse_addr = aq_hw_read_reg(self, HW_ATL_FW2X_MPI_EFUSE_ADDR);
+
+	if (efuse_addr != 0) {
+		err = hw_atl_utils_fw_downld_dwords(self,
+						    efuse_addr + (40U * 4U),
+						    mac_addr,
+						    ARRAY_SIZE(mac_addr));
+		if (err)
+			return err;
+		mac_addr[0] = __swab32(mac_addr[0]);
+		mac_addr[1] = __swab32(mac_addr[1]);
+	}
+
+	ether_addr_copy(mac, (u8 *)mac_addr);
+
+	if ((mac[0] & 0x01U) || ((mac[0] | mac[1] | mac[2]) == 0x00U)) {
+		unsigned int rnd = 0;
+
+		get_random_bytes(&rnd, sizeof(unsigned int));
+
+		l = 0xE3000000U
+			| (0xFFFFU & rnd)
+			| (0x00 << 16);
+		h = 0x8001300EU;
+
+		mac[5] = (u8)(0xFFU & l);
+		l >>= 8;
+		mac[4] = (u8)(0xFFU & l);
+		l >>= 8;
+		mac[3] = (u8)(0xFFU & l);
+		l >>= 8;
+		mac[2] = (u8)(0xFFU & l);
+		mac[1] = (u8)(0xFFU & h);
+		h >>= 8;
+		mac[0] = (u8)(0xFFU & h);
+	}
+	return err;
+}
+
+static int aq_fw2x_update_stats(struct aq_hw_s *self)
+{
+	int err = 0;
+	u32 mpi_opts = aq_hw_read_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR);
+	u32 orig_stats_val = mpi_opts & BIT(CAPS_HI_STATISTICS);
+
+	/* Toggle statistics bit for FW to update */
+	mpi_opts = mpi_opts ^ BIT(CAPS_HI_STATISTICS);
+	aq_hw_write_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR, mpi_opts);
+
+	/* Wait FW to report back */
+	AQ_HW_WAIT_FOR(orig_stats_val !=
+		       (aq_hw_read_reg(self, HW_ATL_FW2X_MPI_STATE2_ADDR) &
+				       BIT(CAPS_HI_STATISTICS)),
+		       1U, 10000U);
+	if (err)
+		return err;
+
+	return hw_atl_utils_update_stats(self);
+}
+
+static int aq_fw2x_get_temp(struct aq_hw_s *self, int *temp)
+{
+	int err = 0;
+	u32 mpi_opts = aq_hw_read_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR);
+	u32 temp_val = mpi_opts & BIT(CAPS_HI_TEMPERATURE);
+	u32 temp_res;
+
+	/* Toggle statistics bit for FW to 0x36C.18 (CAPS_HI_TEMPERATURE) */
+	mpi_opts = mpi_opts ^ BIT(CAPS_HI_TEMPERATURE);
+	aq_hw_write_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR, mpi_opts);
+
+	/* Wait FW to report back */
+	AQ_HW_WAIT_FOR(temp_val !=
+			(aq_hw_read_reg(self, HW_ATL_FW2X_MPI_STATE2_ADDR) &
+					BIT(CAPS_HI_TEMPERATURE)), 1U, 10000U);
+	err = hw_atl_utils_fw_downld_dwords(self,
+				self->mbox_addr +
+				offsetof(struct hw_aq_atl_utils_mbox, info) +
+				offsetof(struct hw_aq_info, phy_temperature),
+				&temp_res,
+				sizeof(temp_res)/sizeof(u32));
+
+	if (err)
+		return err;
+
+	*temp = temp_res  * 100 / 256;
+	return 0;
+}
+
+static int aq_fw2x_get_cable_len(struct aq_hw_s *self, int *cable_len)
+{
+	int err = 0;
+	u32 cable_len_res;
+
+	err = hw_atl_utils_fw_downld_dwords(self,
+				self->mbox_addr +
+				offsetof(struct hw_aq_atl_utils_mbox, info) +
+				offsetof(struct hw_aq_info, phy_temperature),
+				&cable_len_res,
+				sizeof(cable_len_res)/sizeof(u32));
+
+	if (err)
+		return err;
+
+	*cable_len = (cable_len_res >> 16) & 0xFF;
+	return 0;
+}
+
+static int aq_fw2x_set_sleep_proxy(struct aq_hw_s *self, u8 *mac)
+{
+	int err = 0;
+	struct hw_aq_atl_utils_fw_rpc *rpc = NULL;
+	struct offload_info *cfg = NULL;
+	unsigned int rpc_size = 0U;
+	u32 mpi_opts;
+
+	rpc_size = sizeof(rpc->msg_id) + sizeof(*cfg);
+
+	err = hw_atl_utils_fw_rpc_wait(self, &rpc);
+	if (err < 0)
+		goto err_exit;
+
+	memset(rpc, 0, rpc_size);
+	cfg = (struct offload_info *)(&rpc->msg_id + 1);
+
+	memcpy(cfg->mac_addr, mac, ETH_ALEN);
+	cfg->len = sizeof(*cfg);
+
+	/* Clear bit 0x36C.23 and 0x36C.22 */
+	mpi_opts = aq_hw_read_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR);
+	mpi_opts &= ~HW_ATL_FW2X_CAP_SLEEP_PROXY;
+	mpi_opts &= ~BIT(CAPS_HI_LINK_DROP);
+
+	aq_hw_write_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR, mpi_opts);
+
+	err = hw_atl_utils_fw_rpc_call(self, rpc_size);
+	if (err < 0)
+		goto err_exit;
+
+	/* Set bit 0x36C.23 */
+	mpi_opts |= HW_ATL_FW2X_CAP_SLEEP_PROXY;
+	aq_hw_write_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR, mpi_opts);
+
+	AQ_HW_WAIT_FOR((aq_hw_read_reg(self, HW_ATL_FW2X_MPI_STATE2_ADDR) &
+			HW_ATL_FW2X_CAP_SLEEP_PROXY), 1U, 10000U);
+err_exit:
+	return err;
+}
+
+static int aq_fw2x_set_wol_params(struct aq_hw_s *self, u8 *mac)
+{
+	int err = 0;
+	struct fw2x_msg_wol *msg = NULL;
+	u32 mpi_opts;
+
+	struct hw_aq_atl_utils_fw_rpc *rpc = NULL;
+
+	err = hw_atl_utils_fw_rpc_wait(self, &rpc);
+	if (err < 0)
+		goto err_exit;
+
+	msg = (struct fw2x_msg_wol *)rpc;
+
+	msg->msg_id = HAL_ATLANTIC_UTILS_FW2X_MSG_WOL;
+	msg->magic_packet_enabled = true;
+	memcpy(msg->hw_addr, mac, ETH_ALEN);
+
+	mpi_opts = aq_hw_read_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR);
+	mpi_opts &= ~(HW_ATL_FW2X_CAP_SLEEP_PROXY | HW_ATL_FW2X_CAP_WOL);
+
+	aq_hw_write_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR, mpi_opts);
+
+	err = hw_atl_utils_fw_rpc_call(self, sizeof(*msg));
+	if (err < 0)
+		goto err_exit;
+
+	/* Set bit 0x36C.24 */
+	mpi_opts |= HW_ATL_FW2X_CAP_WOL;
+	aq_hw_write_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR, mpi_opts);
+
+	AQ_HW_WAIT_FOR((aq_hw_read_reg(self, HW_ATL_FW2X_MPI_STATE2_ADDR) &
+			HW_ATL_FW2X_CAP_WOL), 1U, 10000U);
+err_exit:
+	return err;
+}
+
+static int aq_fw2x_set_power(struct aq_hw_s *self, unsigned int power_state,
+			     u8 *mac)
+{
+	int err = 0;
+
+	if (self->aq_nic_cfg->wol & AQ_NIC_WOL_ENABLED) {
+		err = aq_fw2x_set_sleep_proxy(self, mac);
+		if (err < 0)
+			goto err_exit;
+		err = aq_fw2x_set_wol_params(self, mac);
+		if (err < 0)
+			goto err_exit;
+	}
+err_exit:
+	return err;
+}
+
+static int aq_fw2x_set_eee_rate(struct aq_hw_s *self, u32 speed)
+{
+	u32 mpi_opts = aq_hw_read_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR);
+	mpi_opts &= ~(HW_ATL_FW2X_CAP_EEE_1G_MASK |
+		HW_ATL_FW2X_CAP_EEE_2G5_MASK | HW_ATL_FW2X_CAP_EEE_5G_MASK |
+		HW_ATL_FW2X_CAP_EEE_10G_MASK);
+
+	mpi_opts |= eee_mask_to_fw2x(speed);
+
+	aq_hw_write_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR, mpi_opts);
+
+	return 0;
+}
+
+static int aq_fw2x_get_eee_rate(struct aq_hw_s *self, u32 *rate,
+				u32 *supported_rates)
+{
+	int err = 0;
+	u32 caps_hi;
+	u32 mpi_state;
+
+	err = hw_atl_utils_fw_downld_dwords(self,
+				self->mbox_addr +
+				offsetof(struct hw_aq_atl_utils_mbox, info) +
+				offsetof(struct hw_aq_info, caps_hi),
+				&caps_hi,
+				sizeof(caps_hi)/sizeof(u32));
+
+	if (err)
+		return err;
+
+	*supported_rates = fw2x_to_eee_mask(caps_hi);
+
+	mpi_state = aq_hw_read_reg(self, HW_ATL_FW2X_MPI_STATE2_ADDR);
+	*rate = fw2x_to_eee_mask(mpi_state);
+
+	return err;
+}
+
+static int aq_fw2x_renegotiate(struct aq_hw_s *self)
+{
+	u32 mpi_opts = aq_hw_read_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR);
+
+	mpi_opts |= BIT(CTRL_FORCE_RECONNECT);
+
+	aq_hw_write_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR, mpi_opts);
+
+	return 0;
+}
+
+static int aq_fw2x_set_flow_control(struct aq_hw_s *self)
+{
+	u32 mpi_state = aq_hw_read_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR);
+
+	aq_fw2x_set_mpi_flow_control(self, &mpi_state);
+
+	aq_hw_write_reg(self, HW_ATL_FW2X_MPI_CONTROL2_ADDR, mpi_state);
+
+	return 0;
+}
+
+const struct aq_fw_ops aq_fw_2x_ops = {
+	.init               = aq_fw2x_init,
+	.deinit             = aq_fw2x_deinit,
+	.reset              = NULL,
+	.renegotiate        = aq_fw2x_renegotiate,
+	.get_mac_permanent  = aq_fw2x_get_mac_permanent,
+	.set_link_speed     = aq_fw2x_set_link_speed,
+	.set_state          = aq_fw2x_set_state,
+	.update_link_status = aq_fw2x_update_link_status,
+	.update_stats       = aq_fw2x_update_stats,
+	.set_power          = aq_fw2x_set_power,
+	.get_temp           = aq_fw2x_get_temp,
+	.get_cable_len      = aq_fw2x_get_cable_len,
+	.set_eee_rate       = aq_fw2x_set_eee_rate,
+	.get_eee_rate       = aq_fw2x_get_eee_rate,
+	.set_flow_control   = aq_fw2x_set_flow_control,
+};
diff --git a/drivers/net/ethernet/aquantia/release_notes.txt b/drivers/net/ethernet/aquantia/release_notes.txt
new file mode 100644
index 00000000..62c8006
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/release_notes.txt
@@ -0,0 +1,276 @@
+Release: 2.0.10.0
+Date: 03/05/2018
+tag: v2.0.10
+================================
+* RM2691: Kernel 2.x support (experimental)
+* RM2692: Linux DKMS packaging
+* RM2698: ethtool negotiate restart should be implemented
+* RM2736: ethtool ring size dynamic change
+* RM2734: EEE settings are lost after link down/up
+* RM2765: Linux driver must support WOL from shutdown
+* RM2697: WoL works in wrong way with FW3.x DW
+* RM2693: Pause frame (flow control) configuration should be done via ethtool
+* RH-1542881 Declare vlan_features bits:
+  http://gitlab.rdc.aquantia.com/drv/Linux/merge_requests/62
+* Leftover bugfixes (msi isr)
+  http://gitlab.rdc.aquantia.com/drv/Linux/merge_requests/61
+
+Release: 2.0.9.0
+Date: 18/04/2018
+tag: v2.0.9
+================================
+* RM2738: Fix RHEL7.5 incompatibility
+
+Release: 2.0.8.0
+Date: 11/04/2018
+tag: v2.0.8
+================================
+* 199177: ASUS XG-C100C 10G Network Adapter no longer working since 4.16
+  FW 1.5.44 and reset sequence collision
+  https://bugzilla.kernel.org/show_bug.cgi?id=199177
+  http://gitlab.rdc.aquantia.com/drv/Linux/merge_requests/54
+
+Release: 2.0.7.0
+Date: 05/04/2018
+tag: v2.0.7
+================================
+* RM2544 Need to make EEE feature configurable with ethtool
+* RM2676 net: aquantia: take care when shutdown on already stopped device
+* RM2667 Disable Dirty Wake on shutdown and suspend
+* (misc) netdev comments 4.16 rc6
+* readme updates on installation
+
+Release: 2.0.6.0
+Date: 15/03/2018
+tag: v2.0.6
+================================
+* RM2574 Post fix (R.Volkov found)
+* Shutdown pci callback closes the link (Synology NAS issues)
+* Introduce rx refill threshold parameter: aq_rx_refill_thres
+
+Release: 2.0.5.0
+Date: 06/03/2018
+tag: v2.0.5
+================================
+* RM2574 B1 hardware never indicates mailbox ready
+* RM2573 Flow control must be enabled by deffault
+* RM2543 Linux driver must set link_drop bit when interface is down
+* Buffer flip&reuse implementation
+  http://gitlab.rdc.aquantia.com/drv/Linux/merge_requests/41
+
+Release: 2.0.4.0
+Date: 16/02/2018
+tag: v2.0.4
+================================
+* RM2508 Indication of the WOL state does not work correctly
+* RM2520 WOL in 2.0.3.0 Linux driver dosn't work with B0 cards
+* RM2512 No traffic on FW 1.5.58 with 2x Linux driver
+* Wrong MTU size checks (< Min or > Max) are now working again on linuxes < 4.10
+* Fix compilation on linux 3.16
+* Reset sequence fix: RBL secure chip reset sequence have to reset SPI
+* RM2536 allow Live MAC change
+* napi_alloc_skb improves performance on high packet rates
+
+Release: 2.0.3.0
+Date: 29/01/2018
+tag: v2.0.3
+================================
+* netdev syncup
+* RM2209: WOL feature (magic packet only)
+* Cable length and temp diagnostics data in sysfs
+* RM2370 Errors are appear during uninstalation linux driver
+
+Upstream Release: 2.0.2.1-kern
+kernel: 4.16
+================================
+d28e9d1 net: aquantia: driver version bump
+fd8221f net: aquantia: Implement pci shutdown callback
+a1c1d63 net: aquantia: Allow live mac address changes
+33a3d54 net: aquantia: Add aq_tx_clean_budget and valid budget handling logic
+002594f net: aquantia: Change inefficient wait loop on fw data reads
+b8d7ecb net: aquantia: Fix a regression with reset on old firmware
+c0a6a02 net: aquantia: Fix hardware reset when SPI may rarely hangup
+
+Release 2.0.2.0
+Upstream: 2.0.2-kern
+tag: v2.0.2
+25/01/2018 f/w 1.x, 2.9.x, 3.x or above
+================================
+* netdev syncup: Do not reset curr_stats on each up/down
+* netdev syncup: typo Octects
+* RM2420:Wrong felicity IDs and link speeds reported
+
+Release 2.0.1.0
+tag: v2.0.1
+30/11/2017 f/w 1.x, 2.9.x, 3.x or above
+================================
+*RM2267:Statistics mistakes and errors
+*RM2128:... PCI errors and NMI
+
+Release 2.0.0.0
+tag: v2.0.0
+17/11/2017 f/w 1.x, 2.9.x, 3.x or above
+================================
++ Reset sequence implemented
+* MAC address readout fixed
+
+Release 2.0.0.0-alpha2
+tag: v2.0.0-alpha2
+11/11/2017 f/w 3.0.3 or above
+================================
+* kernel 3.x build fixed
+
+Release 2.0.0.0-alpha1
+tag: v2.0.0-alpha1
+10/11/2017 f/w 3.0.3 or above
+================================
++ Initial support for both 1.x, 2.x and 3.x FW
+* 64bit wide statistics in ethtool
+! Full reset sequence is not yet implemented
+! Link status is polled, no isr usage yet
+
+
+
+
+
+
+Release 1.6.12.0 master 10_09-2017 f/w 1.5.14 or above
+=============
++QNAP requesting ethtool -c option (#2053)
+*Statistics never gets zeroed upon interface down/up (#2015)
+*Non optimal Interrupt Moderation Rates default settings makes udp very slow (#2041)
+
+Release 1.6.11.0 master 09_25-2017 f/w 1.5.14 or above
+=============
+*Link state is up right after link up command execution for 2 seconds then link goes down (#2033)
+*Netnext mainline syncup
+
+Release 1.6.10.0 master 09_20-2017 f/w 1.5.14 or above
+=============
+*Invalid queue state management causes Tx/Rx to die (#1941)
+*kernel mainline driver does not support jumbo frames (#1985)
+
+Release 1.6.9.0 rel-dev-1.6.9 08_11-2017 f/w 1.5.14 or above
+=============
+*MSM counters are not reset after driver is unloaded/loaded. (#1619).
+*Kernel panic/memory corruption on multicast > 32 (#1864).
+*Incorrect Interrupt moderation values assignment in linux driver (#1918).
+*Fix for enabling incorrect interrupt vectors count on Puma 7 Intel SoC (with Linux Kernel 3.10).
+*Removed unuseful spinlocks from datapath.
+*Minor fixes.
+
+Release 1.6.8.0 rel-dev 07_05-2017 f/w 1.5.14 or above
+=============
+*Fix for RX datapath initialization.
+*Minor fixes.
+
+Release 1.6.7.0 rel-dev 05_05-2017 f/w 1.5.14 or above
+=============
+*Synced with linux sources tree.
+*Support for GRO
+*Fixed Ethtool -S crash
+*Support for kernels >= 3.10
+*Minor fixes.
+
+Release 1.6.2.0 rel-kernel-arm 03_16-2017 f/w 1.5.14 or above
+=============
+*Synced with linux sources tree.
+*Fixed checksumm offloads for IPv6.
+*Added support for ARM.
+*Support for kernels 4.4, 4.8, 4.9
+*Minor fixes.
+
+Release 1.5.345.0 rel-kernel-b0-v3 01_19-2017 f/w 1.5.14 or above
+=============
+*Linux upstream fixes
+*Add fw version checking
+*Fix pm-resume crash.
+
+Release 1.5.335.0 rel-kernel-b0-v3 01_09-2017 f/w 1.5.14 or above
+=============
+*Linux upstream fixes
+
+Release 1.5.324.0 dev-pb-b0-cln-2 12_17-2016 f/w 1.5.14 or above
+=============
+*hibernate fix
+*Minor fixes and code cleanup
+
+Release 1.5.300.0 dev-pb-b0-cln 12_06-2016 f/w 1.5.14 or above
+=============
+*d109 pid support
+*Minor fixes and code cleanup
+
+
+Release 1.5.248.3 dev-pb-b0-clean 11-30-2016 f/w 1.5.14 or above
+=============
+* fix change link speed while NIC down.
+
+Release 1.5.247.3 dev-pb-b0-clean 11-30-2016 f/w 1.5.14 or above
+=============
+* fix netif status
+
+Release 1.5.246.3 dev-pb-b0-clean 11-29-2016 f/w 1.5.14 or above
+=============
++Felicity PID support
+*Updated TX/RX throttling params
+*Minor fixes and code cleanup
+
+Release 1.5.245.3 dev-pb-b0-clean 11-23-2016 f/w 1.5.14 or above
+=============
++CSO error workaround (Bug #701)
++ifconfig filter support (promisc/multicast/broadcast/allmulti)
++Minor fixes and code cleanup
+
+
+Release 1.5.244.3 dev-pb-b0-clean 11-19-2016 f/w 1.5.14 or above
+============
+* Fix #701 workaround 
+
+Release 1.5.243.3 dev-pb-b0-clean 11-16-2016 f/w 1.5.14 or above
+============
++improved ethtool statistics
+
+Release 1.5.239.3 dev-pb-b0-clean 11-11-2016 f/w 1.5.14 or above
+============
++NAPI compliance fix
++Hot unplug fix
++Minor fixes and code cleanup
+
+
+
+Release 1.5.210.3 dev-pb-b0-clean 11-03-2016 f/w 1.5.14 or above
+============
++Fixed Jumbo frames.
++RSS fixes (new hash key, print RSS settings via ethtool)
++Minor fixes and code cleanup
+
+Release 1.5.203.3 dev-pb-b0-clean 10-31-2016 f/w 1.5.14 or above
+=============
++Support SuseServer 12.1
++Fixed kernel panic on CentOS 7.
+
+
+Release 1.5.201.3 dev-pb-b0-clean 10-29-2016 f/w 1.5.14 or above
+=============
++Support Centos
++Minor fixes and code cleanup
+
+Release 1.5.200.3 dev-pb-b0-clean 10-29-2016 f/w 1.5.10 or above
+=============
++Support new VID/PID.
++Fixed and tested the driver for B0 on FPGA.
++Support LRO for B0 on FPGA.
++Fixed link status detect.
+
+Known issues:
+- Build failed on Centos
+
+
+Release 1.5.100.3 10-22-2016 f/w 1.4 or above
+=============
++ Ethtool statistics
+* Debian 6 kernel build
+* A0/B0 support
+
+Know issues:
+- Link status hardcoded always '1G connected'
diff --git a/drivers/net/ethernet/aquantia/rpm-src.spec b/drivers/net/ethernet/aquantia/rpm-src.spec
new file mode 100644
index 00000000..cca9593
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/rpm-src.spec
@@ -0,0 +1,40 @@
+Summary: AQtion Ethernet driver
+Name: Atlantic
+Vendor: aQuantia Corporation
+Version: %{rawver}
+Release: 1
+License: GPLv2
+Group: System Environment/Kernel
+Provides: %{name}
+URL:   http://www.aquantia.com/
+BuildRoot: %{_tmppath}/%{name}-%{version}-root
+BuildArch: noarch
+
+%description
+This package contains aQuantia AQtion Ethernet Linux driver
+
+%prep
+rm -rf Linux/.git
+
+%build
+
+%clean
+rm -rf %{buildroot}
+
+%post
+cd /var/build_aq_drv/%{version}/Linux
+make clean
+make
+make install
+
+%preun
+rm -f /lib/modules/$(shell uname -r)/aquantia/atlantic.ko
+depmod -a $(shell uname -r)
+
+%install
+mkdir -p $RPM_BUILD_ROOT/var/build_aq_drv/%{version}
+cp -r Linux $RPM_BUILD_ROOT/var/build_aq_drv/%{version}
+
+%files
+%defattr(-,root,root,-)
+/var/build_aq_drv/%{version}/Linux
diff --git a/drivers/net/ethernet/aquantia/ver.h b/drivers/net/ethernet/aquantia/ver.h
new file mode 100644
index 00000000..45ca496
--- /dev/null
+++ b/drivers/net/ethernet/aquantia/ver.h
@@ -0,0 +1,20 @@
+/*
+ * aQuantia Corporation Network Driver
+ * Copyright (C) 2014-2017 aQuantia Corporation. All rights reserved
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ */
+
+#ifndef VER_H
+#define VER_H
+
+#define NIC_MAJOR_DRIVER_VERSION           2
+#define NIC_MINOR_DRIVER_VERSION           0
+#define NIC_BUILD_DRIVER_VERSION           10
+#define NIC_REVISION_DRIVER_VERSION        0
+
+#define AQ_CFG_DRV_VERSION_SUFFIX ""
+
+#endif /* VER_H */
diff --git a/drivers/net/ethernet/intel/ixgbe/Makefile b/drivers/net/ethernet/intel/ixgbe/Makefile
index 35e6fa6..a3cc895 100644
--- a/drivers/net/ethernet/intel/ixgbe/Makefile
+++ b/drivers/net/ethernet/intel/ixgbe/Makefile
@@ -1,7 +1,7 @@
 ################################################################################
 #
-# Intel 10 Gigabit PCI Express Linux driver
-# Copyright(c) 1999 - 2013 Intel Corporation.
+# Intel(R) 10GbE PCI Express Linux Network Driver
+# Copyright(c) 1999 - 2017 Intel Corporation.
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
 # FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 # more details.
 #
-# You should have received a copy of the GNU General Public License along with
-# this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-#
 # The full GNU General Public License is included in this distribution in
 # the file called "COPYING".
 #
@@ -26,19 +22,163 @@
 #
 ################################################################################
 
+ifneq ($(KERNELRELEASE),)
+# kbuild part of makefile
 #
-# Makefile for the Intel(R) 10GbE PCI Express ethernet driver
+# Makefile for the Intel(R) 10GbE PCI Express Linux Network Driver
 #
 
 obj-$(CONFIG_IXGBE) += ixgbe.o
 
-ixgbe-objs := ixgbe_main.o ixgbe_common.o ixgbe_ethtool.o \
-              ixgbe_82599.o ixgbe_82598.o ixgbe_phy.o ixgbe_sriov.o \
-              ixgbe_mbx.o ixgbe_x540.o ixgbe_x550.o ixgbe_lib.o ixgbe_ptp.o
+define ixgbe-y
+	ixgbe_main.o
+	ixgbe_api.o
+	ixgbe_common.o
+	ixgbe_dcb.o
+	ixgbe_dcb_82598.o
+	ixgbe_dcb_82599.o
+	ixgbe_ethtool.o
+	ixgbe_lib.o
+	ixgbe_mbx.o
+	ixgbe_sriov.o
+	ixgbe_param.o
+	ixgbe_phy.o
+	ixgbe_procfs.o
+	ixgbe_82598.o
+	ixgbe_82599.o
+	ixgbe_x540.o
+	ixgbe_x550.o
+endef
+ixgbe-y := $(strip ${ixgbe-y})
+
+ixgbe-${CONFIG_DCB} += ixgbe_dcb_nl.o
+
+ixgbe-${CONFIG_DEBUG_FS} += ixgbe_debugfs.o
+
+ixgbe-${CONFIG_FCOE:m=y} += ixgbe_fcoe.o
+
+ixgbe-$(CONFIG_PTP_1588_CLOCK:m=y) += ixgbe_ptp.o
+
+ixgbe-${CONFIG_SYSFS} += ixgbe_sysfs.o
+
+ixgbe-y += kcompat.o
+
+else	# ifneq($(KERNELRELEASE),)
+# normal makefile
+
+DRIVER := ixgbe
+
+ifeq (,$(wildcard common.mk))
+  $(error Cannot find common.mk build rules)
+else
+  include common.mk
+endif
+
+# Check that kernel version is at least 2.6.0, since we don't support 2.4.x
+# kernels with the ixgbe driver. We can't use minimum_kver_check since SLES 10
+# SP4's Make has a bug which causes $(eval) inside an ifeq conditional to error
+# out. This was fixed in Make 3.81, but SLES 10 SP4 does not have a fix for
+# this yet.
+ifeq (0,$(shell [ ${KVER_CODE} -lt $(call get_kvercode,2,6,0) ]; echo "$?"))
+  $(warning *** Aborting the build.)
+  $(error This driver is not supported on kernel versions older than 2.6.0)
+endif
+
+######################
+# Kernel Build Macro #
+######################
+
+# customized kernelbuild function
+#
+# ${1} is the kernel build target
+# ${2} may contain extra rules to pass to kernelbuild macro
+#
+# We customize the kernelbuild target in order to provide our hack to disable
+# CONFIG_PTP_1588_CLOCK support should -DNO_PTP_SUPPORT be defined in the extra
+# cflags given on the command line.
+devkernelbuild = $(call kernelbuild,$(if $(filter -DNO_PTP_SUPPORT,${EXTRA_CFLAGS}),CONFIG_PTP_1588_CLOCK=n) ${2},${1})
+
+###############
+# Build rules #
+###############
+
+# Standard compilation, with regular output
+default:
+	@+$(call devkernelbuild,modules)
+
+# Noisy output, for extra debugging
+noisy:
+	@+$(call devkernelbuild,modules,V=1)
+
+# Silence any output generated
+silent:
+	@+$(call devkernelbuild,modules,>/dev/null)
+
+# Enable higher warning level
+checkwarnings: clean
+	@+$(call devkernelbuild,modules,W=1)
+
+# Run sparse static analyzer
+sparse: clean
+	@+$(call devkernelbuild,modules,C=2 CF="-D__CHECK_ENDIAN__ -Wbitwise -Wcontext")
+
+# Run coccicheck static analyzer
+ccc: clean
+	@+$(call devkernelbuild,modules,coccicheck MODE=report))
+
+# Build manfiles
+manfile:
+	@gzip -c ../${DRIVER}.${MANSECTION} > ${DRIVER}.${MANSECTION}.gz
+
+# Clean the module subdirectories
+clean:
+	@+$(call devkernelbuild,clean)
+	@-rm -rf *.${MANSECTION}.gz *.ko
+
+# Install the modules and manpage
+install: default manfile
+	@echo "Copying manpages..."
+	@install -D -m 644 ${DRIVER}.${MANSECTION}.gz ${INSTALL_MOD_PATH}${MANDIR}/man${MANSECTION}/${DRIVER}.${MANSECTION}.gz
+	@echo "Installing modules..."
+	@+$(call devkernelbuild,modules_install)
+	@echo "Running depmod..."
+	@$(call cmd_depmod)
+
+uninstall:
+	rm -f ${INSTALL_MOD_PATH}/lib/modules/${KVER}/${INSTALL_MOD_DIR}/${DRIVER}.ko;
+	$(call cmd_depmod)
+	if [ -e ${INSTALL_MOD_PATH}${MANDIR}/man${MANSECTION}/${DRIVER}.${MANSECTION}.gz ] ; then \
+		rm -f ${INSTALL_MOD_PATH}${MANDIR}/man${MANSECTION}/${DRIVER}.${MANSECTION}.gz ; \
+	fi;
+
+########
+# Help #
+########
+help:
+	@echo 'Cleaning targets:'
+	@echo '  clean               - Clean files generated by kernel module build'
+	@echo 'Build targets:'
+	@echo '  default             - Build module(s) with standard verbosity'
+	@echo '  noisy               - Build module(s) with V=1 verbosity -- very noisy'
+	@echo '  silent              - Build module(s), squelching all output'
+	@echo 'Static Analysis:'
+	@echo '  checkwarnings       - Clean, then build module(s) with W=1 warnings enabled'
+	@echo '  sparse              - Clean, then check module(s) using sparse'
+	@echo '  ccc                 - Clean, then check module(s) using coccicheck'
+	@echo 'Other targets:'
+	@echo '  manfile             - Generate a gzipped manpage'
+	@echo '  install             - Build then install the module(s) and manpage'
+	@echo '  uninstall           - Uninstall the module(s) and manpage'
+	@echo '  help                - Display this help message'
+	@echo 'Variables:'
+	@echo '  LINUX_VERSION       - Debug tool to force kernel LINUX_VERSION_CODE. Use at your own risk.'
+	@echo '  W=N                 - Kernel variable for setting warning levels'
+	@echo '  V=N                 - Kernel variable for setting output verbosity'
+	@echo '  INSTALL_MOD_PATH    - Add prefix for the module and manpage installation path'
+	@echo '  INSTALL_MOD_DIR     - Use module directory other than updates/drivers/net/ethernet/intel/${DRIVER}'
+	@echo ' Other variables may be available for tuning make process, see'
+	@echo ' Kernel Kbuild documentation for more information'
 
-ixgbe-$(CONFIG_IXGBE_DCB) +=  ixgbe_dcb.o ixgbe_dcb_82598.o \
-                              ixgbe_dcb_82599.o ixgbe_dcb_nl.o
+.PHONY: default noisy clean manfile silent sparse ccc install uninstall help
 
-ixgbe-$(CONFIG_IXGBE_HWMON) += ixgbe_sysfs.o
-ixgbe-$(CONFIG_DEBUG_FS) += ixgbe_debugfs.o
-ixgbe-$(CONFIG_FCOE:m=y) += ixgbe_fcoe.o
+endif	# ifneq($(KERNELRELEASE),)
diff --git a/drivers/net/ethernet/intel/ixgbe/Module.supported b/drivers/net/ethernet/intel/ixgbe/Module.supported
new file mode 100644
index 00000000..af24796
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/Module.supported
@@ -0,0 +1 @@
+ixgbe.ko external
diff --git a/drivers/net/ethernet/intel/ixgbe/common.mk b/drivers/net/ethernet/intel/ixgbe/common.mk
new file mode 100644
index 00000000..aa1af9a
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/common.mk
@@ -0,0 +1,319 @@
+################################################################################
+#
+# Intel(R) 10GbE PCI Express Linux Network Driver
+# Copyright(c) 1999 - 2017 Intel Corporation.
+#
+# This program is free software; you can redistribute it and/or modify it
+# under the terms and conditions of the GNU General Public License,
+# version 2, as published by the Free Software Foundation.
+#
+# This program is distributed in the hope it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+# more details.
+#
+# The full GNU General Public License is included in this distribution in
+# the file called "COPYING".
+#
+# Contact Information:
+# Linux NICS <linux.nics@intel.com>
+# e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+# Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+#
+################################################################################
+
+# common Makefile rules useful for out-of-tree Linux driver builds
+#
+# Usage: include common.mk
+#
+# After including, you probably want to add a minimum_kver_check call
+#
+# Required Variables:
+# DRIVER
+#   -- Set to the lowercase driver name
+
+#####################
+# Helpful functions #
+#####################
+
+readlink = $(shell readlink -f ${1})
+
+# helper functions for converting kernel version to version codes
+get_kver = $(or $(word ${2},$(subst ., ,${1})),0)
+get_kvercode = $(shell [ "${1}" -ge 0 -a "${1}" -le 255 2>/dev/null ] && \
+                       [ "${2}" -ge 0 -a "${2}" -le 255 2>/dev/null ] && \
+                       [ "${3}" -ge 0 -a "${3}" -le 255 2>/dev/null ] && \
+                       printf %d $$(( ( ${1} << 16 ) + ( ${2} << 8 ) + ( ${3} ) )) )
+
+################
+# depmod Macro #
+################
+
+cmd_depmod = /sbin/depmod $(if ${SYSTEM_MAP_FILE},-e -F ${SYSTEM_MAP_FILE}) \
+                          $(if $(strip ${INSTALL_MOD_PATH}),-b ${INSTALL_MOD_PATH}) \
+                          -a ${KVER}
+
+################
+# dracut Macro #
+################
+
+cmd_initrd := $(shell \
+                if which dracut > /dev/null 2>&1 ; then \
+                    echo "dracut --force"; \
+                elif which update-initramfs > /dev/null 2>&1 ; then \
+                    echo "update-initramfs -u"; \
+                fi )
+
+#####################
+# Environment tests #
+#####################
+
+DRIVER_UPPERCASE := $(shell echo ${DRIVER} | tr "[:lower:]" "[:upper:]")
+
+ifeq (,${BUILD_KERNEL})
+BUILD_KERNEL=$(shell uname -r)
+endif
+
+# Kernel Search Path
+# All the places we look for kernel source
+KSP :=  /lib/modules/${BUILD_KERNEL}/source \
+        /lib/modules/${BUILD_KERNEL}/build \
+        /usr/src/linux-${BUILD_KERNEL} \
+        /usr/src/linux-$(${BUILD_KERNEL} | sed 's/-.*//') \
+        /usr/src/kernel-headers-${BUILD_KERNEL} \
+        /usr/src/kernel-source-${BUILD_KERNEL} \
+        /usr/src/linux-$(${BUILD_KERNEL} | sed 's/\([0-9]*\.[0-9]*\)\..*/\1/') \
+        /usr/src/linux \
+        /usr/src/kernels/${BUILD_KERNEL} \
+        /usr/src/kernels
+
+# prune the list down to only values that exist and have an include/linux
+# sub-directory. We can't use include/config because some older kernels don't
+# have this.
+test_dir = $(shell [ -e ${dir}/include/linux ] && echo ${dir})
+KSP := $(foreach dir, ${KSP}, ${test_dir})
+
+# we will use this first valid entry in the search path
+ifeq (,${KSRC})
+  KSRC := $(firstword ${KSP})
+endif
+
+ifeq (,${KSRC})
+  $(warning *** Kernel header files not in any of the expected locations.)
+  $(warning *** Install the appropriate kernel development package, e.g.)
+  $(error kernel-devel, for building kernel modules and try again)
+else
+ifeq (/lib/modules/${BUILD_KERNEL}/source, ${KSRC})
+  KOBJ :=  /lib/modules/${BUILD_KERNEL}/build
+else
+  KOBJ :=  ${KSRC}
+endif
+endif
+
+# Version file Search Path
+VSP :=  ${KOBJ}/include/generated/utsrelease.h \
+        ${KOBJ}/include/linux/utsrelease.h \
+        ${KOBJ}/include/linux/version.h \
+        ${KOBJ}/include/generated/uapi/linux/version.h \
+        /boot/vmlinuz.version.h
+
+# Config file Search Path
+CSP :=  ${KOBJ}/include/generated/autoconf.h \
+        ${KOBJ}/include/linux/autoconf.h \
+        /boot/vmlinuz.autoconf.h
+
+# System.map Search Path (for depmod)
+MSP := ${KSRC}/System.map \
+       /boot/System.map-${BUILD_KERNEL}
+
+# prune the lists down to only files that exist
+test_file = $(shell [ -f ${file} ] && echo ${file})
+VSP := $(foreach file, ${VSP}, ${test_file})
+CSP := $(foreach file, ${CSP}, ${test_file})
+MSP := $(foreach file, ${MSP}, ${test_file})
+
+
+# and use the first valid entry in the Search Paths
+ifeq (,${VERSION_FILE})
+  VERSION_FILE := $(firstword ${VSP})
+endif
+
+ifeq (,${CONFIG_FILE})
+  CONFIG_FILE := $(firstword ${CSP})
+endif
+
+ifeq (,${SYSTEM_MAP_FILE})
+  SYSTEM_MAP_FILE := $(firstword ${MSP})
+endif
+
+ifeq (,$(wildcard ${VERSION_FILE}))
+  $(error Linux kernel source not configured - missing version header file)
+endif
+
+ifeq (,$(wildcard ${CONFIG_FILE}))
+  $(error Linux kernel source not configured - missing autoconf.h)
+endif
+
+ifeq (,$(wildcard ${SYSTEM_MAP_FILE}))
+  $(warning Missing System.map file - depmod will not check for missing symbols)
+endif
+
+#######################
+# Linux Version Setup #
+#######################
+
+# The following command line parameter is intended for development of KCOMPAT
+# against upstream kernels such as net-next which have broken or non-updated
+# version codes in their Makefile. They are intended for debugging and
+# development purpose only so that we can easily test new KCOMPAT early. If you
+# don't know what this means, you do not need to set this flag. There is no
+# arcane magic here.
+
+# Convert LINUX_VERSION into LINUX_VERSION_CODE
+ifneq (${LINUX_VERSION},)
+  LINUX_VERSION_CODE=$(call get_kvercode,$(call get_kver,${LINUX_VERSION},1),$(call get_kver,${LINUX_VERSION},2),$(call get_kver,${LINUX_VERSION},3))
+endif
+
+# Honor LINUX_VERSION_CODE
+ifneq (${LINUX_VERSION_CODE},)
+  $(warning Forcing target kernel to build with LINUX_VERSION_CODE of ${LINUX_VERSION_CODE}$(if ${LINUX_VERSION}, from LINUX_VERSION=${LINUX_VERSION}). Do this at your own risk.)
+  KVER_CODE := ${LINUX_VERSION_CODE}
+  EXTRA_CFLAGS += -DLINUX_VERSION_CODE=${LINUX_VERSION_CODE}
+endif
+
+# Determine SLE_LOCALVERSION_CODE for SuSE SLE >= 11 (needed by kcompat)
+# This assumes SuSE will continue setting CONFIG_LOCALVERSION to the string
+# appended to the stable kernel version on which their kernel is based with
+# additional versioning information (up to 3 numbers), a possible abbreviated
+# git SHA1 commit id and a kernel type, e.g. CONFIG_LOCALVERSION=-1.2.3-default
+# or CONFIG_LOCALVERSION=-999.gdeadbee-default
+ifeq (1,$(shell ${CC} -E -dM ${CONFIG_FILE} 2> /dev/null |\
+          grep -m 1 CONFIG_SUSE_KERNEL | awk '{ print $$3 }'))
+
+ifneq (10,$(shell ${CC} -E -dM ${CONFIG_FILE} 2> /dev/null |\
+	  grep -m 1 CONFIG_SLE_VERSION | awk '{ print $$3 }'))
+
+  LOCALVERSION := $(shell ${CC} -E -dM ${CONFIG_FILE} 2> /dev/null |\
+                    grep -m 1 CONFIG_LOCALVERSION | awk '{ print $$3 }' |\
+                    cut -d'-' -f2 | sed 's/\.g[[:xdigit:]]\{7\}//')
+  LOCALVER_A := $(shell echo ${LOCALVERSION} | cut -d'.' -f1)
+  LOCALVER_B := $(shell echo ${LOCALVERSION} | cut -s -d'.' -f2)
+  LOCALVER_C := $(shell echo ${LOCALVERSION} | cut -s -d'.' -f3)
+  SLE_LOCALVERSION_CODE := $(shell expr ${LOCALVER_A} \* 65536 + \
+                                        0${LOCALVER_B} \* 256 + 0${LOCALVER_C})
+  EXTRA_CFLAGS += -DSLE_LOCALVERSION_CODE=${SLE_LOCALVERSION_CODE}
+endif
+endif
+
+EXTRA_CFLAGS += ${CFLAGS_EXTRA}
+
+# get the kernel version - we use this to find the correct install path
+KVER := $(shell ${CC} ${EXTRA_CFLAGS} -E -dM ${VERSION_FILE} | grep UTS_RELEASE | \
+        awk '{ print $$3 }' | sed 's/\"//g')
+
+# assume source symlink is the same as build, otherwise adjust KOBJ
+ifneq (,$(wildcard /lib/modules/${KVER}/build))
+  ifneq (${KSRC},$(call readlink,/lib/modules/${KVER}/build))
+    KOBJ=/lib/modules/${KVER}/build
+  endif
+endif
+
+ifeq (${KVER_CODE},)
+  KVER_CODE := $(shell ${CC} ${EXTRA_CFLAGS} -E -dM ${VSP} 2> /dev/null |\
+                 grep -m 1 LINUX_VERSION_CODE | awk '{ print $$3 }' | sed 's/\"//g')
+endif
+
+# minimum_kver_check
+#
+# helper function to provide uniform output for different drivers to abort the
+# build based on kernel version check. Usage: "$(call minimum_kver_check,2,6,XX)".
+define _minimum_kver_check
+ifeq (0,$(shell [ ${KVER_CODE} -lt $(call get_kvercode,${1},${2},${3}) ]; echo "$$?"))
+  $$(warning *** Aborting the build.)
+  $$(error This driver is not supported on kernel versions older than ${1}.${2}.${3})
+endif
+endef
+minimum_kver_check = $(eval $(call _minimum_kver_check,${1},${2},${3}))
+
+################
+# Manual Pages #
+################
+
+MANSECTION = 7
+
+ifeq (,${MANDIR})
+  # find the best place to install the man page
+  MANPATH := $(shell (manpath 2>/dev/null || echo $MANPATH) | sed 's/:/ /g')
+  ifneq (,${MANPATH})
+    # test based on inclusion in MANPATH
+    test_dir = $(findstring ${dir}, ${MANPATH})
+  else
+    # no MANPATH, test based on directory existence
+    test_dir = $(shell [ -e ${dir} ] && echo ${dir})
+  endif
+  # our preferred install path
+  # should /usr/local/man be in here ?
+  MANDIR := /usr/share/man /usr/man
+  MANDIR := $(foreach dir, ${MANDIR}, ${test_dir})
+  MANDIR := $(firstword ${MANDIR})
+endif
+ifeq (,${MANDIR})
+  # fallback to /usr/man
+  MANDIR := /usr/man
+endif
+
+####################
+# CCFLAGS variable #
+####################
+
+# set correct CCFLAGS variable for kernels older than 2.6.24
+ifeq (0,$(shell [ ${KVER_CODE} -lt $(call get_kvercode,2,6,24) ]; echo $$?))
+CCFLAGS_VAR := EXTRA_CFLAGS
+else
+CCFLAGS_VAR := ccflags-y
+endif
+
+#################
+# KBUILD_OUTPUT #
+#################
+
+# Only set KBUILD_OUTPUT if the real paths of KOBJ and KSRC differ
+ifneq ($(call readlink,${KSRC}),$(call readlink,${KOBJ}))
+export KBUILD_OUTPUT ?= ${KOBJ}
+endif
+
+############################
+# Module Install Directory #
+############################
+
+# Default to using updates/drivers/net/ethernet/intel/ path, since depmod since
+# v3.1 defaults to checking updates folder first, and only checking kernels/
+# and extra afterwards. We use updates instead of kernel/* due to desire to
+# prevent over-writing built-in modules files.
+export INSTALL_MOD_DIR ?= updates/drivers/net/ethernet/intel/${DRIVER}
+
+######################
+# Kernel Build Macro #
+######################
+
+# kernel build function
+# ${1} is the kernel build target
+# ${2} may contain any extra rules to pass directly to the sub-make process
+#
+# This function is expected to be executed by
+#   @+$(call kernelbuild,<target>,<extra parameters>)
+# from within a Makefile recipe.
+#
+# The following variables are expected to be defined for its use:
+# GCC_I_SYS -- if set it will enable use of gcc-i-sys.sh wrapper to use -isystem
+# CCFLAGS_VAR -- the CCFLAGS variable to set extra CFLAGS
+# EXTRA_CFLAGS -- a set of extra CFLAGS to pass into the ccflags-y variable
+# KSRC -- the location of the kernel source tree to build against
+# DRIVER_UPPERCASE -- the uppercase name of the kernel module, set from DRIVER
+#
+kernelbuild = ${MAKE} $(if ${GCC_I_SYS},CC="${GCC_I_SYS}") \
+                      ${CCFLAGS_VAR}="${EXTRA_CFLAGS}" \
+                      -C "${KSRC}" \
+                      CONFIG_${DRIVER_UPPERCASE}=m \
+                      M="${CURDIR}" \
+                      ${2} ${1}
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe.h b/drivers/net/ethernet/intel/ixgbe/ixgbe.h
index 1d21745..520f533 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe.h
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe.h
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -29,70 +25,151 @@
 #ifndef _IXGBE_H_
 #define _IXGBE_H_
 
-#include <linux/bitops.h>
-#include <linux/types.h>
+#include <net/ip.h>
+
 #include <linux/pci.h>
 #include <linux/netdevice.h>
-#include <linux/cpumask.h>
-#include <linux/aer.h>
-#include <linux/if_vlan.h>
-#include <linux/jiffies.h>
-
-#include <linux/timecounter.h>
-#include <linux/net_tstamp.h>
-#include <linux/ptp_clock_kernel.h>
+#include <linux/vmalloc.h>
 
-#include "ixgbe_type.h"
-#include "ixgbe_common.h"
-#include "ixgbe_dcb.h"
-#if defined(CONFIG_FCOE) || defined(CONFIG_FCOE_MODULE)
-#define IXGBE_FCOE
-#include "ixgbe_fcoe.h"
-#endif /* CONFIG_FCOE or CONFIG_FCOE_MODULE */
-#ifdef CONFIG_IXGBE_DCA
+#ifdef SIOCETHTOOL
+#include <linux/ethtool.h>
+#endif
+#if defined(NETIF_F_HW_VLAN_TX) || defined(NETIF_F_HW_VLAN_CTAG_TX)
+#include <linux/if_vlan.h>
+#endif
+/* Can't use IS_ENABLED until after kcompat is loaded */
+#if defined(CONFIG_DCA) || defined(CONFIG_DCA_MODULE)
+#define IXGBE_DCA
 #include <linux/dca.h>
 #endif
+#include "ixgbe_dcb.h"
 
-#include <net/busy_poll.h>
+#include "kcompat.h"
 
 #ifdef CONFIG_NET_RX_BUSY_POLL
+#include <net/busy_poll.h>
+#ifdef HAVE_NDO_BUSY_POLL
 #define BP_EXTENDED_STATS
 #endif
-/* common prefix used by pr_<> macros */
-#undef pr_fmt
-#define pr_fmt(fmt) KBUILD_MODNAME ": " fmt
+#endif /* CONFIG_NET_RX_BUSY_POLL */
 
-/* TX/RX descriptor defines */
-#define IXGBE_DEFAULT_TXD		    512
-#define IXGBE_DEFAULT_TX_WORK		    256
-#define IXGBE_MAX_TXD			   4096
-#define IXGBE_MIN_TXD			     64
+#ifdef HAVE_SCTP
+#include <linux/sctp.h>
+#endif
 
-#if (PAGE_SIZE < 8192)
-#define IXGBE_DEFAULT_RXD		    512
-#else
-#define IXGBE_DEFAULT_RXD		    128
+#ifdef HAVE_INCLUDE_LINUX_MDIO_H
+#include <linux/mdio.h>
+#endif
+
+#if IS_ENABLED(CONFIG_FCOE)
+#include "ixgbe_fcoe.h"
+#endif /* CONFIG_FCOE */
+
+#include "ixgbe_api.h"
+
+#include "ixgbe_common.h"
+
+#define PFX "ixgbe: "
+#define DPRINTK(nlevel, klevel, fmt, args...) \
+	((void)((NETIF_MSG_##nlevel & adapter->msg_enable) && \
+	printk(KERN_##klevel PFX "%s: %s: " fmt, adapter->netdev->name, \
+		__func__ , ## args)))
+
+#ifdef HAVE_PTP_1588_CLOCK
+#ifdef HAVE_INCLUDE_LINUX_TIMECOUNTER_H
+#include <linux/timecounter.h>
+#endif /* HAVE_INCLUDE_TIMECOUNTER_H */
+#include <linux/clocksource.h>
+#include <linux/net_tstamp.h>
+#include <linux/ptp_clock_kernel.h>
 #endif
-#define IXGBE_MAX_RXD			   4096
-#define IXGBE_MIN_RXD			     64
 
-#define IXGBE_ETH_P_LLDP		 0x88CC
+/* TX/RX descriptor defines */
+#define IXGBE_DEFAULT_TXD		512
+#define IXGBE_DEFAULT_TX_WORK		256
+#define IXGBE_MAX_TXD			4096
+#define IXGBE_MIN_TXD			64
+
+#define IXGBE_DEFAULT_RXD		512
+#define IXGBE_DEFAULT_RX_WORK		256
+#define IXGBE_MAX_RXD			4096
+#define IXGBE_MIN_RXD			64
+
+#define IXGBE_ETH_P_LLDP		0x88CC
 
 /* flow control */
-#define IXGBE_MIN_FCRTL			   0x40
+#define IXGBE_MIN_FCRTL			0x40
 #define IXGBE_MAX_FCRTL			0x7FF80
-#define IXGBE_MIN_FCRTH			  0x600
+#define IXGBE_MIN_FCRTH			0x600
 #define IXGBE_MAX_FCRTH			0x7FFF0
-#define IXGBE_DEFAULT_FCPAUSE		 0xFFFF
-#define IXGBE_MIN_FCPAUSE		      0
-#define IXGBE_MAX_FCPAUSE		 0xFFFF
+#define IXGBE_DEFAULT_FCPAUSE		0xFFFF
+#define IXGBE_MIN_FCPAUSE		0
+#define IXGBE_MAX_FCPAUSE		0xFFFF
 
 /* Supported Rx Buffer Sizes */
-#define IXGBE_RXBUFFER_256    256  /* Used for skb receive header */
-#define IXGBE_RXBUFFER_2K    2048
-#define IXGBE_RXBUFFER_3K    3072
-#define IXGBE_RXBUFFER_4K    4096
-#define IXGBE_MAX_RXBUFFER  16384  /* largest size for a single descriptor */
+#define IXGBE_RXBUFFER_256       256  /* Used for skb receive header */
+#define IXGBE_RXBUFFER_1536	1536
+#define IXGBE_RXBUFFER_2K	2048
+#define IXGBE_RXBUFFER_3K	3072
+#define IXGBE_RXBUFFER_4K	4096
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+#define IXGBE_RXBUFFER_7K	7168
+#define IXGBE_RXBUFFER_8K	8192
+#define IXGBE_RXBUFFER_15K	15360
+#endif /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
+#define IXGBE_MAX_RXBUFFER	16384  /* largest size for single descriptor */
+
+/* Attempt to maximize the headroom available for incoming frames.  We
+ * use a 2K buffer for receives and need 1536/1534 to store the data for
+ * the frame.  This leaves us with 512 bytes of room.  From that we need
+ * to deduct the space needed for the shared info and the padding needed
+ * to IP align the frame.
+ *
+ * Note: For cache line sizes 256 or larger this value is going to end
+ *	 up negative.  In these cases we should fall back to the 3K
+ *	 buffers.
+ */
+#if (PAGE_SIZE < 8192)
+#define IXGBE_MAX_2K_FRAME_BUILD_SKB (IXGBE_RXBUFFER_1536 - NET_IP_ALIGN)
+#define IXGBE_2K_TOO_SMALL_WITH_PADDING \
+((NET_SKB_PAD + IXGBE_RXBUFFER_1536) > SKB_WITH_OVERHEAD(IXGBE_RXBUFFER_2K))
+
+static inline int ixgbe_compute_pad(int rx_buf_len)
+{
+	int page_size, pad_size;
+
+	page_size = ALIGN(rx_buf_len, PAGE_SIZE / 2);
+	pad_size = SKB_WITH_OVERHEAD(page_size) - rx_buf_len;
+
+	return pad_size;
+}
+
+static inline int ixgbe_skb_pad(void)
+{
+	int rx_buf_len;
+
+	/* If a 2K buffer cannot handle a standard Ethernet frame then
+	 * optimize padding for a 3K buffer instead of a 1.5K buffer.
+	 *
+	 * For a 3K buffer we need to add enough padding to allow for
+	 * tailroom due to NET_IP_ALIGN possibly shifting us out of
+	 * cache-line alignment.
+	 */
+	if (IXGBE_2K_TOO_SMALL_WITH_PADDING)
+		rx_buf_len = IXGBE_RXBUFFER_3K + SKB_DATA_ALIGN(NET_IP_ALIGN);
+	else
+		rx_buf_len = IXGBE_RXBUFFER_1536;
+
+	/* if needed make room for NET_IP_ALIGN */
+	rx_buf_len -= NET_IP_ALIGN;
+
+	return ixgbe_compute_pad(rx_buf_len);
+}
+
+#define IXGBE_SKB_PAD	ixgbe_skb_pad()
+#else
+#define IXGBE_SKB_PAD	(NET_SKB_PAD + NET_IP_ALIGN)
+#endif
 
 /*
  * NOTE: netdev_alloc_skb reserves up to 64 bytes, NET_IP_ALIGN means we
@@ -102,11 +179,27 @@
  * Since netdev_alloc_skb now allocates a page fragment we can use a value
  * of 256 and the resultant skb will have a truesize of 960 or less.
  */
-#define IXGBE_RX_HDR_SIZE IXGBE_RXBUFFER_256
+#define IXGBE_RX_HDR_SIZE	IXGBE_RXBUFFER_256
+
+#define MAXIMUM_ETHERNET_VLAN_SIZE	(VLAN_ETH_FRAME_LEN + ETH_FCS_LEN)
 
 /* How many Rx Buffers do we bundle into one write to the hardware ? */
 #define IXGBE_RX_BUFFER_WRITE	16	/* Must be power of 2 */
 
+#ifdef HAVE_STRUCT_DMA_ATTRS
+#define IXGBE_RX_DMA_ATTR NULL
+#else
+#define IXGBE_RX_DMA_ATTR \
+	(DMA_ATTR_SKIP_CPU_SYNC | DMA_ATTR_WEAK_ORDERING)
+#endif
+
+/* assume the kernel supports 8021p to avoid stripping vlan tags */
+#ifdef IXGBE_DISABLE_8021P_SUPPORT
+#ifndef HAVE_8021P_SUPPORT
+#define HAVE_8021P_SUPPORT
+#endif
+#endif /* IXGBE_DISABLE_8021P_SUPPORT */
+
 enum ixgbe_tx_flags {
 	/* cmd_type flags */
 	IXGBE_TX_FLAGS_HW_VLAN	= 0x01,
@@ -126,43 +219,76 @@ enum ixgbe_tx_flags {
 /* VLAN info */
 #define IXGBE_TX_FLAGS_VLAN_MASK	0xffff0000
 #define IXGBE_TX_FLAGS_VLAN_PRIO_MASK	0xe0000000
-#define IXGBE_TX_FLAGS_VLAN_PRIO_SHIFT  29
+#define IXGBE_TX_FLAGS_VLAN_PRIO_SHIFT	29
 #define IXGBE_TX_FLAGS_VLAN_SHIFT	16
 
-#define IXGBE_MAX_VF_MC_ENTRIES         30
-#define IXGBE_MAX_VF_FUNCTIONS          64
-#define IXGBE_MAX_VFTA_ENTRIES          128
-#define MAX_EMULATION_MAC_ADDRS         16
-#define IXGBE_MAX_PF_MACVLANS           15
-#define VMDQ_P(p)   ((p) + adapter->ring_feature[RING_F_VMDQ].offset)
-#define IXGBE_82599_VF_DEVICE_ID        0x10ED
-#define IXGBE_X540_VF_DEVICE_ID         0x1515
+#define IXGBE_MAX_RX_DESC_POLL		10
 
+#define IXGBE_MAX_VF_MC_ENTRIES		30
+#define IXGBE_MAX_VF_FUNCTIONS		64
+#define IXGBE_MAX_VFTA_ENTRIES		128
+#define MAX_EMULATION_MAC_ADDRS		16
+#define IXGBE_MAX_PF_MACVLANS		15
+
+/* must account for pools assigned to VFs. */
+#ifdef CONFIG_PCI_IOV
+#define VMDQ_P(p)	((p) + adapter->ring_feature[RING_F_VMDQ].offset)
+#else
+#define VMDQ_P(p)	(p)
+#endif
+
+#define UPDATE_VF_COUNTER_32bit(reg, last_counter, counter)	\
+	{							\
+		u32 current_counter = IXGBE_READ_REG(hw, reg);	\
+		if (current_counter < last_counter)		\
+			counter += 0x100000000LL;		\
+		last_counter = current_counter;			\
+		counter &= 0xFFFFFFFF00000000LL;		\
+		counter |= current_counter;			\
+	}
+
+#define UPDATE_VF_COUNTER_36bit(reg_lsb, reg_msb, last_counter, counter) \
+	{								 \
+		u64 current_counter_lsb = IXGBE_READ_REG(hw, reg_lsb);	 \
+		u64 current_counter_msb = IXGBE_READ_REG(hw, reg_msb);	 \
+		u64 current_counter = (current_counter_msb << 32) |	 \
+			current_counter_lsb;				 \
+		if (current_counter < last_counter)			 \
+			counter += 0x1000000000LL;			 \
+		last_counter = current_counter;				 \
+		counter &= 0xFFFFFFF000000000LL;			 \
+		counter |= current_counter;				 \
+	}
+
+struct vf_stats {
+	u64 gprc;
+	u64 gorc;
+	u64 gptc;
+	u64 gotc;
+	u64 mprc;
+};
 struct vf_data_storage {
+	struct pci_dev *vfdev;
 	unsigned char vf_mac_addresses[ETH_ALEN];
 	u16 vf_mc_hashes[IXGBE_MAX_VF_MC_ENTRIES];
 	u16 num_vf_mc_hashes;
-	u16 default_vf_vlan_id;
-	u16 vlans_enabled;
 	bool clear_to_send;
+	struct vf_stats vfstats;
+	struct vf_stats last_vfstats;
+	struct vf_stats saved_rst_vfstats;
 	bool pf_set_mac;
 	u16 pf_vlan; /* When set, guest VLAN config not allowed. */
 	u16 pf_qos;
 	u16 tx_rate;
-	u16 vlan_count;
 	u8 spoofchk_enabled;
+#ifdef HAVE_NDO_SET_VF_RSS_QUERY_EN
 	bool rss_query_enabled;
+#endif
 	u8 trusted;
 	int xcast_mode;
 	unsigned int vf_api;
 };
 
-enum ixgbevf_xcast_modes {
-	IXGBEVF_XCAST_MODE_NONE = 0,
-	IXGBEVF_XCAST_MODE_MULTI,
-	IXGBEVF_XCAST_MODE_ALLMULTI,
-};
-
 struct vf_macvlans {
 	struct list_head l;
 	int vf;
@@ -175,8 +301,14 @@ struct vf_macvlans {
 #define IXGBE_MAX_DATA_PER_TXD	(1 << IXGBE_MAX_TXD_PWR)
 
 /* Tx Descriptors needed, worst case */
-#define TXD_USE_COUNT(S) DIV_ROUND_UP((S), IXGBE_MAX_DATA_PER_TXD)
-#define DESC_NEEDED (MAX_SKB_FRAGS + 4)
+#define TXD_USE_COUNT(S)	DIV_ROUND_UP((S), IXGBE_MAX_DATA_PER_TXD)
+#ifndef MAX_SKB_FRAGS
+#define DESC_NEEDED	4
+#elif (MAX_SKB_FRAGS < 16)
+#define DESC_NEEDED	((MAX_SKB_FRAGS * TXD_USE_COUNT(PAGE_SIZE)) + 4)
+#else
+#define DESC_NEEDED	(MAX_SKB_FRAGS + 4)
+#endif
 
 /* wrapper around a pointer to a socket buffer,
  * so a DMA handle can be stored along with the buffer */
@@ -195,8 +327,15 @@ struct ixgbe_tx_buffer {
 struct ixgbe_rx_buffer {
 	struct sk_buff *skb;
 	dma_addr_t dma;
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
 	struct page *page;
-	unsigned int page_offset;
+#if (BITS_PER_LONG > 32) || (PAGE_SIZE >= 65536)
+	__u32 page_offset;
+#else
+	__u16 page_offset;
+#endif
+	__u16 pagecnt_bias;
+#endif
 };
 
 struct ixgbe_queue_stats {
@@ -224,24 +363,27 @@ struct ixgbe_rx_queue_stats {
 	u64 csum_err;
 };
 
+#define IXGBE_TS_HDR_LEN 8
 enum ixgbe_ring_state_t {
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	__IXGBE_RX_3K_BUFFER,
+	__IXGBE_RX_BUILD_SKB_ENABLED,
+#endif
+	__IXGBE_RX_RSC_ENABLED,
+	__IXGBE_RX_CSUM_UDP_ZERO_ERR,
+#if IS_ENABLED(CONFIG_FCOE)
+	__IXGBE_RX_FCOE,
+#endif
 	__IXGBE_TX_FDIR_INIT_DONE,
 	__IXGBE_TX_XPS_INIT_DONE,
 	__IXGBE_TX_DETECT_HANG,
 	__IXGBE_HANG_CHECK_ARMED,
-	__IXGBE_RX_RSC_ENABLED,
-	__IXGBE_RX_CSUM_UDP_ZERO_ERR,
-	__IXGBE_RX_FCOE,
 };
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
 
-struct ixgbe_fwd_adapter {
-	unsigned long active_vlans[BITS_TO_LONGS(VLAN_N_VID)];
-	struct net_device *netdev;
-	struct ixgbe_adapter *real_adapter;
-	unsigned int tx_base_queue;
-	unsigned int rx_base_queue;
-	int pool;
-};
+#define ring_uses_build_skb(ring) \
+	test_bit(__IXGBE_RX_BUILD_SKB_ENABLED, &(ring)->state)
+#endif
 
 #define check_for_tx_hang(ring) \
 	test_bit(__IXGBE_TX_DETECT_HANG, &(ring)->state)
@@ -255,12 +397,15 @@ struct ixgbe_fwd_adapter {
 	set_bit(__IXGBE_RX_RSC_ENABLED, &(ring)->state)
 #define clear_ring_rsc_enabled(ring) \
 	clear_bit(__IXGBE_RX_RSC_ENABLED, &(ring)->state)
+#define netdev_ring(ring) (ring->netdev)
+#define ring_queue_index(ring) (ring->queue_index)
+
+
 struct ixgbe_ring {
 	struct ixgbe_ring *next;	/* pointer to next ring in q_vector */
 	struct ixgbe_q_vector *q_vector; /* backpointer to host q_vector */
 	struct net_device *netdev;	/* netdev ring belongs to */
 	struct device *dev;		/* device for DMA mapping */
-	struct ixgbe_fwd_adapter *l2_accel_priv;
 	void *desc;			/* descriptor ring memory */
 	union {
 		struct ixgbe_tx_buffer *tx_buffer_info;
@@ -282,8 +427,16 @@ struct ixgbe_ring {
 	u16 next_to_use;
 	u16 next_to_clean;
 
+#ifdef HAVE_PTP_1588_CLOCK
+	unsigned long last_rx_timestamp;
+
+#endif
 	union {
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+		u16 rx_buf_len;
+#else
 		u16 next_to_alloc;
+#endif
 		struct {
 			u8 atr_sample_rate;
 			u8 atr_count;
@@ -292,7 +445,9 @@ struct ixgbe_ring {
 
 	u8 dcb_tc;
 	struct ixgbe_queue_stats stats;
+#ifdef HAVE_NDO_GET_STATS64
 	struct u64_stats_sync syncp;
+#endif
 	union {
 		struct ixgbe_tx_queue_stats tx_stats;
 		struct ixgbe_rx_queue_stats rx_stats;
@@ -304,61 +459,69 @@ enum ixgbe_ring_f_enum {
 	RING_F_VMDQ,  /* SR-IOV uses the same ring feature */
 	RING_F_RSS,
 	RING_F_FDIR,
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	RING_F_FCOE,
-#endif /* IXGBE_FCOE */
-
-	RING_F_ARRAY_SIZE      /* must be last in enum set */
+#endif /* CONFIG_FCOE */
+	RING_F_ARRAY_SIZE  /* must be last in enum set */
 };
 
+#define IXGBE_MAX_DCB_INDICES		8
 #define IXGBE_MAX_RSS_INDICES		16
-#define IXGBE_MAX_RSS_INDICES_X550	64
+#define IXGBE_MAX_RSS_INDICES_X550	63
 #define IXGBE_MAX_VMDQ_INDICES		64
-#define IXGBE_MAX_FDIR_INDICES		63	/* based on q_vector limit */
-#define IXGBE_MAX_FCOE_INDICES		8
-#define MAX_RX_QUEUES			(IXGBE_MAX_FDIR_INDICES + 1)
-#define MAX_TX_QUEUES			(IXGBE_MAX_FDIR_INDICES + 1)
-#define IXGBE_MAX_L2A_QUEUES		4
-#define IXGBE_BAD_L2A_QUEUE		3
-#define IXGBE_MAX_MACVLANS		31
-#define IXGBE_MAX_DCBMACVLANS		8
+#define IXGBE_MAX_FDIR_INDICES		63
+#if IS_ENABLED(CONFIG_FCOE)
+#define IXGBE_MAX_FCOE_INDICES	8
+#define MAX_RX_QUEUES	(IXGBE_MAX_FDIR_INDICES + IXGBE_MAX_FCOE_INDICES)
+#define MAX_TX_QUEUES	(IXGBE_MAX_FDIR_INDICES + IXGBE_MAX_FCOE_INDICES)
+#else
+#define MAX_RX_QUEUES	(IXGBE_MAX_FDIR_INDICES + 1)
+#define MAX_TX_QUEUES	(IXGBE_MAX_FDIR_INDICES + 1)
+#endif /* CONFIG_FCOE */
 
 struct ixgbe_ring_feature {
 	u16 limit;	/* upper limit on feature indices */
 	u16 indices;	/* current value of indices */
 	u16 mask;	/* Mask used for feature to ring mapping */
 	u16 offset;	/* offset to start of feature */
-} ____cacheline_internodealigned_in_smp;
+};
 
 #define IXGBE_82599_VMDQ_8Q_MASK 0x78
 #define IXGBE_82599_VMDQ_4Q_MASK 0x7C
 #define IXGBE_82599_VMDQ_2Q_MASK 0x7E
 
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
 /*
  * FCoE requires that all Rx buffers be over 2200 bytes in length.  Since
  * this is twice the size of a half page we need to double the page order
  * for FCoE enabled Rx queues.
  */
-static inline unsigned int ixgbe_rx_bufsz(struct ixgbe_ring *ring)
+static inline unsigned int ixgbe_rx_bufsz(struct ixgbe_ring __maybe_unused *ring)
 {
-#ifdef IXGBE_FCOE
-	if (test_bit(__IXGBE_RX_FCOE, &ring->state))
-		return (PAGE_SIZE < 8192) ? IXGBE_RXBUFFER_4K :
-					    IXGBE_RXBUFFER_3K;
+#if MAX_SKB_FRAGS < 8
+	return ALIGN(IXGBE_MAX_RXBUFFER / MAX_SKB_FRAGS, 1024);
+#else
+	if (test_bit(__IXGBE_RX_3K_BUFFER, &ring->state))
+		return IXGBE_RXBUFFER_3K;
+#if (PAGE_SIZE < 8192)
+	if (ring_uses_build_skb(ring))
+		return IXGBE_MAX_2K_FRAME_BUILD_SKB;
 #endif
 	return IXGBE_RXBUFFER_2K;
+#endif
 }
 
-static inline unsigned int ixgbe_rx_pg_order(struct ixgbe_ring *ring)
+static inline unsigned int ixgbe_rx_pg_order(struct ixgbe_ring __maybe_unused *ring)
 {
-#ifdef IXGBE_FCOE
-	if (test_bit(__IXGBE_RX_FCOE, &ring->state))
-		return (PAGE_SIZE < 8192) ? 1 : 0;
+#if (PAGE_SIZE < 8192)
+	if (test_bit(__IXGBE_RX_3K_BUFFER, &ring->state))
+		return 1;
 #endif
 	return 0;
 }
 #define ixgbe_rx_pg_size(_ring) (PAGE_SIZE << ixgbe_rx_pg_order(_ring))
 
+#endif
 struct ixgbe_ring_container {
 	struct ixgbe_ring *ring;	/* pointer to linked list of rings */
 	unsigned int total_bytes;	/* total bytes processed this int */
@@ -372,39 +535,43 @@ struct ixgbe_ring_container {
 #define ixgbe_for_each_ring(pos, head) \
 	for (pos = (head).ring; pos != NULL; pos = pos->next)
 
-#define MAX_RX_PACKET_BUFFERS ((adapter->flags & IXGBE_FLAG_DCB_ENABLED) \
-			      ? 8 : 1)
-#define MAX_TX_PACKET_BUFFERS MAX_RX_PACKET_BUFFERS
+#define MAX_RX_PACKET_BUFFERS	((adapter->flags & IXGBE_FLAG_DCB_ENABLED) \
+				 ? 8 : 1)
+#define MAX_TX_PACKET_BUFFERS	MAX_RX_PACKET_BUFFERS
 
-/* MAX_Q_VECTORS of these are allocated,
+/* MAX_MSIX_Q_VECTORS of these are allocated,
  * but we only use one per queue-specific vector.
  */
 struct ixgbe_q_vector {
 	struct ixgbe_adapter *adapter;
-#ifdef CONFIG_IXGBE_DCA
-	int cpu;	    /* CPU for DCA */
-#endif
-	u16 v_idx;		/* index of q_vector within array, also used for
-				 * finding the bit in EICR and friends that
-				 * represents the vector for this ring */
-	u16 itr;		/* Interrupt throttle rate written to EITR */
+	int cpu;	/* CPU for DCA */
+	u16 v_idx;	/* index of q_vector within array, also used for
+			 * finding the bit in EICR and friends that
+			 * represents the vector for this ring */
+	u16 itr;	/* Interrupt throttle rate written to EITR */
 	struct ixgbe_ring_container rx, tx;
 
 	struct napi_struct napi;
+#ifndef HAVE_NETDEV_NAPI_LIST
+	struct net_device poll_dev;
+#endif
+#ifdef HAVE_IRQ_AFFINITY_HINT
 	cpumask_t affinity_mask;
+#endif
 	int numa_node;
 	struct rcu_head rcu;	/* to avoid race with update stats on free */
 	char name[IFNAMSIZ + 9];
+	bool netpoll_rx;
 
-#ifdef CONFIG_NET_RX_BUSY_POLL
+#ifdef HAVE_NDO_BUSY_POLL
 	atomic_t state;
-#endif  /* CONFIG_NET_RX_BUSY_POLL */
+#endif  /* HAVE_NDO_BUSY_POLL */
 
 	/* for dynamic allocation of rings associated with this q_vector */
 	struct ixgbe_ring ring[0] ____cacheline_internodealigned_in_smp;
 };
 
-#ifdef CONFIG_NET_RX_BUSY_POLL
+#ifdef HAVE_NDO_BUSY_POLL
 enum ixgbe_qv_state_t {
 	IXGBE_QV_STATE_IDLE = 0,
 	IXGBE_QV_STATE_NAPI,
@@ -480,44 +647,8 @@ static inline bool ixgbe_qv_disable(struct ixgbe_q_vector *q_vector)
 	return rc == IXGBE_QV_STATE_IDLE;
 }
 
-#else /* CONFIG_NET_RX_BUSY_POLL */
-static inline void ixgbe_qv_init_lock(struct ixgbe_q_vector *q_vector)
-{
-}
-
-static inline bool ixgbe_qv_lock_napi(struct ixgbe_q_vector *q_vector)
-{
-	return true;
-}
-
-static inline bool ixgbe_qv_unlock_napi(struct ixgbe_q_vector *q_vector)
-{
-	return false;
-}
-
-static inline bool ixgbe_qv_lock_poll(struct ixgbe_q_vector *q_vector)
-{
-	return false;
-}
-
-static inline bool ixgbe_qv_unlock_poll(struct ixgbe_q_vector *q_vector)
-{
-	return false;
-}
-
-static inline bool ixgbe_qv_busy_polling(struct ixgbe_q_vector *q_vector)
-{
-	return false;
-}
-
-static inline bool ixgbe_qv_disable(struct ixgbe_q_vector *q_vector)
-{
-	return true;
-}
-
-#endif /* CONFIG_NET_RX_BUSY_POLL */
-
-#ifdef CONFIG_IXGBE_HWMON
+#endif /* HAVE_NDO_BUSY_POLL */
+#ifdef IXGBE_HWMON
 
 #define IXGBE_HWMON_TYPE_LOC		0
 #define IXGBE_HWMON_TYPE_TEMP		1
@@ -532,13 +663,11 @@ struct hwmon_attr {
 };
 
 struct hwmon_buff {
-	struct attribute_group group;
-	const struct attribute_group *groups[2];
-	struct attribute *attrs[IXGBE_MAX_SENSORS * 4 + 1];
-	struct hwmon_attr hwmon_list[IXGBE_MAX_SENSORS * 4];
+	struct device *device;
+	struct hwmon_attr *hwmon_list;
 	unsigned int n_hwmon;
 };
-#endif /* CONFIG_IXGBE_HWMON */
+#endif /* IXGBE_HWMON */
 
 /*
  * microsecond values for various ITR rates shifted by 2 to fit itr register
@@ -547,6 +676,7 @@ struct hwmon_buff {
 #define IXGBE_MIN_RSC_ITR	24
 #define IXGBE_100K_ITR		40
 #define IXGBE_20K_ITR		200
+#define IXGBE_16K_ITR		248
 #define IXGBE_12K_ITR		336
 
 /* ixgbe_test_staterr - tests bits in Rx descriptor status and error fields */
@@ -556,6 +686,7 @@ static inline __le32 ixgbe_test_staterr(union ixgbe_adv_rx_desc *rx_desc,
 	return rx_desc->wb.upper.status_error & cpu_to_le32(stat_err_bits);
 }
 
+/* ixgbe_desc_unused - calculate if we have unused descriptors */
 static inline u16 ixgbe_desc_unused(struct ixgbe_ring *ring)
 {
 	u16 ntc = ring->next_to_clean;
@@ -564,49 +695,68 @@ static inline u16 ixgbe_desc_unused(struct ixgbe_ring *ring)
 	return ((ntc > ntu) ? 0 : ring->count) + ntc - ntu - 1;
 }
 
-#define IXGBE_RX_DESC(R, i)	    \
+#define IXGBE_RX_DESC(R, i)	\
 	(&(((union ixgbe_adv_rx_desc *)((R)->desc))[i]))
-#define IXGBE_TX_DESC(R, i)	    \
+#define IXGBE_TX_DESC(R, i)	\
 	(&(((union ixgbe_adv_tx_desc *)((R)->desc))[i]))
-#define IXGBE_TX_CTXTDESC(R, i)	    \
+#define IXGBE_TX_CTXTDESC(R, i)	\
 	(&(((struct ixgbe_adv_tx_context_desc *)((R)->desc))[i]))
 
-#define IXGBE_MAX_JUMBO_FRAME_SIZE	9728 /* Maximum Supported Size 9.5KB */
-#ifdef IXGBE_FCOE
-/* Use 3K as the baby jumbo frame size for FCoE */
-#define IXGBE_FCOE_JUMBO_FRAME_SIZE       3072
-#endif /* IXGBE_FCOE */
+#define IXGBE_MAX_JUMBO_FRAME_SIZE	9728
+#if IS_ENABLED(CONFIG_FCOE)
+/* use 3K as the baby jumbo frame size for FCoE */
+#define IXGBE_FCOE_JUMBO_FRAME_SIZE	3072
+#endif /* CONFIG_FCOE */
 
-#define OTHER_VECTOR 1
-#define NON_Q_VECTORS (OTHER_VECTOR)
+#define TCP_TIMER_VECTOR	0
+#define OTHER_VECTOR	1
+#define NON_Q_VECTORS	(OTHER_VECTOR + TCP_TIMER_VECTOR)
 
-#define MAX_MSIX_VECTORS_82599 64
-#define MAX_Q_VECTORS_82599 64
-#define MAX_MSIX_VECTORS_82598 18
-#define MAX_Q_VECTORS_82598 16
+#define IXGBE_MAX_MSIX_Q_VECTORS_82599	64
+#define IXGBE_MAX_MSIX_Q_VECTORS_82598	16
 
 struct ixgbe_mac_addr {
 	u8 addr[ETH_ALEN];
-	u16 queue;
+	u16 pool;
 	u16 state; /* bitmask */
 };
+
 #define IXGBE_MAC_STATE_DEFAULT		0x1
 #define IXGBE_MAC_STATE_MODIFIED	0x2
 #define IXGBE_MAC_STATE_IN_USE		0x4
 
-#define MAX_Q_VECTORS MAX_Q_VECTORS_82599
-#define MAX_MSIX_COUNT MAX_MSIX_VECTORS_82599
+#ifdef IXGBE_PROCFS
+struct ixgbe_therm_proc_data {
+	struct ixgbe_hw *hw;
+	struct ixgbe_thermal_diode_data *sensor_data;
+};
 
-#define MIN_MSIX_Q_VECTORS 1
-#define MIN_MSIX_COUNT (MIN_MSIX_Q_VECTORS + NON_Q_VECTORS)
+#endif /* IXGBE_PROCFS */
+/*
+ * Only for array allocations in our adapter struct.  On 82598, there will be
+ * unused entries in the array, but that's not a big deal.  Also, in 82599,
+ * we can actually assign 64 queue vectors based on our extended-extended
+ * interrupt registers.  This is different than 82598, which is limited to 16.
+ */
+#define MAX_MSIX_Q_VECTORS	IXGBE_MAX_MSIX_Q_VECTORS_82599
+#define MAX_MSIX_COUNT		IXGBE_MAX_MSIX_VECTORS_82599
+
+#define MIN_MSIX_Q_VECTORS	1
+#define MIN_MSIX_COUNT		(MIN_MSIX_Q_VECTORS + NON_Q_VECTORS)
 
 /* default to trying for four seconds */
-#define IXGBE_TRY_LINK_TIMEOUT (4 * HZ)
-#define IXGBE_SFP_POLL_JIFFIES (2 * HZ)	/* SFP poll every 2 seconds */
+#define IXGBE_TRY_LINK_TIMEOUT	(4 * HZ)
+#define IXGBE_SFP_POLL_JIFFIES	(2 * HZ)	/* SFP poll every 2 seconds */
 
 /* board specific private data structure */
 struct ixgbe_adapter {
+#if defined(NETIF_F_HW_VLAN_TX) || defined(NETIF_F_HW_VLAN_CTAG_TX)
+#ifdef HAVE_VLAN_RX_REGISTER
+	struct vlan_group *vlgrp; /* must be first, see ixgbe_receive_skb */
+#else
 	unsigned long active_vlans[BITS_TO_LONGS(VLAN_N_VID)];
+#endif
+#endif /* NETIF_F_HW_VLAN_TX || NETIF_F_HW_VLAN_CTAG_TX */
 	/* OS defined structs */
 	struct net_device *netdev;
 	struct pci_dev *pdev;
@@ -617,54 +767,95 @@ struct ixgbe_adapter {
 	 * thus the additional *_CAPABLE flags.
 	 */
 	u32 flags;
-#define IXGBE_FLAG_MSI_ENABLED                  (u32)(1 << 1)
-#define IXGBE_FLAG_MSIX_ENABLED                 (u32)(1 << 3)
-#define IXGBE_FLAG_RX_1BUF_CAPABLE              (u32)(1 << 4)
-#define IXGBE_FLAG_RX_PS_CAPABLE                (u32)(1 << 5)
-#define IXGBE_FLAG_RX_PS_ENABLED                (u32)(1 << 6)
-#define IXGBE_FLAG_DCA_ENABLED                  (u32)(1 << 8)
-#define IXGBE_FLAG_DCA_CAPABLE                  (u32)(1 << 9)
-#define IXGBE_FLAG_IMIR_ENABLED                 (u32)(1 << 10)
-#define IXGBE_FLAG_MQ_CAPABLE                   (u32)(1 << 11)
-#define IXGBE_FLAG_DCB_ENABLED                  (u32)(1 << 12)
-#define IXGBE_FLAG_VMDQ_CAPABLE                 (u32)(1 << 13)
-#define IXGBE_FLAG_VMDQ_ENABLED                 (u32)(1 << 14)
-#define IXGBE_FLAG_FAN_FAIL_CAPABLE             (u32)(1 << 15)
-#define IXGBE_FLAG_NEED_LINK_UPDATE             (u32)(1 << 16)
-#define IXGBE_FLAG_NEED_LINK_CONFIG             (u32)(1 << 17)
-#define IXGBE_FLAG_FDIR_HASH_CAPABLE            (u32)(1 << 18)
-#define IXGBE_FLAG_FDIR_PERFECT_CAPABLE         (u32)(1 << 19)
-#define IXGBE_FLAG_FCOE_CAPABLE                 (u32)(1 << 20)
-#define IXGBE_FLAG_FCOE_ENABLED                 (u32)(1 << 21)
-#define IXGBE_FLAG_SRIOV_CAPABLE                (u32)(1 << 22)
-#define IXGBE_FLAG_SRIOV_ENABLED                (u32)(1 << 23)
-#define IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE	BIT(24)
+#define IXGBE_FLAG_MSI_CAPABLE			(u32)(1 << 0)
+#define IXGBE_FLAG_MSI_ENABLED			(u32)(1 << 1)
+#define IXGBE_FLAG_MSIX_CAPABLE			(u32)(1 << 2)
+#define IXGBE_FLAG_MSIX_ENABLED			(u32)(1 << 3)
+#ifndef IXGBE_NO_LLI
+#define IXGBE_FLAG_LLI_PUSH			(u32)(1 << 4)
+#endif
 
-	u32 flags2;
-#define IXGBE_FLAG2_RSC_CAPABLE                 (u32)(1 << 0)
-#define IXGBE_FLAG2_RSC_ENABLED                 (u32)(1 << 1)
-#define IXGBE_FLAG2_TEMP_SENSOR_CAPABLE         (u32)(1 << 2)
-#define IXGBE_FLAG2_TEMP_SENSOR_EVENT           (u32)(1 << 3)
-#define IXGBE_FLAG2_SEARCH_FOR_SFP              (u32)(1 << 4)
-#define IXGBE_FLAG2_SFP_NEEDS_RESET             (u32)(1 << 5)
-#define IXGBE_FLAG2_RESET_REQUESTED             (u32)(1 << 6)
-#define IXGBE_FLAG2_FDIR_REQUIRES_REINIT        (u32)(1 << 7)
-#define IXGBE_FLAG2_RSS_FIELD_IPV4_UDP		(u32)(1 << 8)
-#define IXGBE_FLAG2_RSS_FIELD_IPV6_UDP		(u32)(1 << 9)
-#define IXGBE_FLAG2_PTP_PPS_ENABLED		(u32)(1 << 10)
-#define IXGBE_FLAG2_PHY_INTERRUPT		(u32)(1 << 11)
-#ifdef CONFIG_IXGBE_VXLAN
-#define IXGBE_FLAG2_VXLAN_REREG_NEEDED		BIT(12)
+#if defined(CONFIG_DCA) || defined(CONFIG_DCA_MODULE)
+#define IXGBE_FLAG_DCA_ENABLED			(u32)(1 << 6)
+#define IXGBE_FLAG_DCA_CAPABLE			(u32)(1 << 7)
+#define IXGBE_FLAG_DCA_ENABLED_DATA		(u32)(1 << 8)
+#else
+#define IXGBE_FLAG_DCA_ENABLED			(u32)0
+#define IXGBE_FLAG_DCA_CAPABLE			(u32)0
+#define IXGBE_FLAG_DCA_ENABLED_DATA             (u32)0
 #endif
+#define IXGBE_FLAG_MQ_CAPABLE			(u32)(1 << 9)
+#define IXGBE_FLAG_DCB_ENABLED			(u32)(1 << 10)
+#define IXGBE_FLAG_VMDQ_ENABLED			(u32)(1 << 11)
+#define IXGBE_FLAG_FAN_FAIL_CAPABLE		(u32)(1 << 12)
+#define IXGBE_FLAG_NEED_LINK_UPDATE		(u32)(1 << 13)
+#define IXGBE_FLAG_NEED_LINK_CONFIG		(u32)(1 << 14)
+#define IXGBE_FLAG_FDIR_HASH_CAPABLE		(u32)(1 << 15)
+#define IXGBE_FLAG_FDIR_PERFECT_CAPABLE		(u32)(1 << 16)
+#if IS_ENABLED(CONFIG_FCOE)
+#define IXGBE_FLAG_FCOE_CAPABLE			(u32)(1 << 17)
+#define IXGBE_FLAG_FCOE_ENABLED			(u32)(1 << 18)
+#endif /* CONFIG_FCOE */
+#define IXGBE_FLAG_SRIOV_CAPABLE		(u32)(1 << 19)
+#define IXGBE_FLAG_SRIOV_ENABLED		(u32)(1 << 20)
+#define IXGBE_FLAG_SRIOV_REPLICATION_ENABLE	(u32)(1 << 21)
+#define IXGBE_FLAG_SRIOV_L2SWITCH_ENABLE	(u32)(1 << 22)
+#define IXGBE_FLAG_SRIOV_VEPA_BRIDGE_MODE	(u32)(1 << 23)
+#define IXGBE_FLAG_RX_HWTSTAMP_ENABLED          (u32)(1 << 24)
+#define IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE	(u32)(1 << 25)
+#define IXGBE_FLAG_VXLAN_OFFLOAD_ENABLE		(u32)(1 << 26)
+#define IXGBE_FLAG_RX_HWTSTAMP_IN_REGISTER	(u32)(1 << 27)
+#define IXGBE_FLAG_MDD_ENABLED			(u32)(1 << 29)
+#define IXGBE_FLAG_DCB_CAPABLE			(u32)(1 << 30)
+#define IXGBE_FLAG_GENEVE_OFFLOAD_CAPABLE	BIT(31)
+
+/* preset defaults */
+#define IXGBE_FLAGS_82598_INIT		(IXGBE_FLAG_MSI_CAPABLE |	\
+					 IXGBE_FLAG_MSIX_CAPABLE |	\
+					 IXGBE_FLAG_MQ_CAPABLE)
+
+#define IXGBE_FLAGS_82599_INIT		(IXGBE_FLAGS_82598_INIT |	\
+					 IXGBE_FLAG_SRIOV_CAPABLE)
+
+#define IXGBE_FLAGS_X540_INIT		IXGBE_FLAGS_82599_INIT
+
+#define IXGBE_FLAGS_X550_INIT		(IXGBE_FLAGS_82599_INIT |	\
+					 IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE)
+
+	u32 flags2;
+#define IXGBE_FLAG2_RSC_CAPABLE			(u32)(1 << 0)
+#define IXGBE_FLAG2_RSC_ENABLED			(u32)(1 << 1)
+#define IXGBE_FLAG2_TEMP_SENSOR_CAPABLE		(u32)(1 << 3)
+#define IXGBE_FLAG2_TEMP_SENSOR_EVENT		(u32)(1 << 4)
+#define IXGBE_FLAG2_SEARCH_FOR_SFP		(u32)(1 << 5)
+#define IXGBE_FLAG2_SFP_NEEDS_RESET		(u32)(1 << 6)
+#define IXGBE_FLAG2_FDIR_REQUIRES_REINIT	(u32)(1 << 8)
+#define IXGBE_FLAG2_RSS_FIELD_IPV4_UDP		(u32)(1 << 9)
+#define IXGBE_FLAG2_RSS_FIELD_IPV6_UDP		(u32)(1 << 10)
+#define IXGBE_FLAG2_PTP_PPS_ENABLED		(u32)(1 << 11)
+#define IXGBE_FLAG2_EEE_CAPABLE			(u32)(1 << 14)
+#define IXGBE_FLAG2_EEE_ENABLED			(u32)(1 << 15)
+#define IXGBE_FLAG2_UDP_TUN_REREG_NEEDED	(u32)(1 << 16)
+#define IXGBE_FLAG2_PHY_INTERRUPT		(u32)(1 << 17)
+#define IXGBE_FLAG2_VLAN_PROMISC		(u32)(1 << 18)
+#define IXGBE_FLAG2_RX_LEGACY			(u32)(1 << 19)
 
 	/* Tx fast path data */
 	int num_tx_queues;
 	u16 tx_itr_setting;
 	u16 tx_work_limit;
 
+#if defined(HAVE_UDP_ENC_RX_OFFLOAD) || defined(HAVE_VXLAN_RX_OFFLOAD)
+	__be16 vxlan_port;
+#endif /* HAVE_UDP_ENC_RX_OFFLAD || HAVE_VXLAN_RX_OFFLOAD */
+#ifdef HAVE_UDP_ENC_RX_OFFLOAD
+	__be16 geneve_port;
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD */
+
 	/* Rx fast path data */
 	int num_rx_queues;
 	u16 rx_itr_setting;
+	u16 rx_work_limit;
 
 	/* TX */
 	struct ixgbe_ring *tx_ring[MAX_TX_QUEUES] ____cacheline_aligned_in_smp;
@@ -675,8 +866,8 @@ struct ixgbe_adapter {
 
 	/* RX */
 	struct ixgbe_ring *rx_ring[MAX_RX_QUEUES];
-	int num_rx_pools;		/* == num_rx_queues in 82598 */
-	int num_rx_queues_per_pool;	/* 1 if 82598, can be many if 82599 */
+	int num_rx_pools; /* does not include pools assigned to VFs */
+	int num_rx_queues_per_pool;
 	u64 hw_csum_rx_error;
 	u64 hw_rx_no_dma_resources;
 	u64 rsc_total_count;
@@ -685,37 +876,57 @@ struct ixgbe_adapter {
 	u32 alloc_rx_page_failed;
 	u32 alloc_rx_buff_failed;
 
-	struct ixgbe_q_vector *q_vector[MAX_Q_VECTORS];
+	struct ixgbe_q_vector *q_vector[MAX_MSIX_Q_VECTORS];
 
-	/* DCB parameters */
+#ifdef HAVE_DCBNL_IEEE
 	struct ieee_pfc *ixgbe_ieee_pfc;
 	struct ieee_ets *ixgbe_ieee_ets;
+#endif
 	struct ixgbe_dcb_config dcb_cfg;
 	struct ixgbe_dcb_config temp_dcb_cfg;
 	u8 dcb_set_bitmap;
 	u8 dcbx_cap;
+#ifndef HAVE_MQPRIO
+	u8 dcb_tc;
+#endif
 	enum ixgbe_fc_mode last_lfc_mode;
 
 	int num_q_vectors;	/* current number of q_vectors for device */
-	int max_q_vectors;	/* true count of q_vectors for device */
+	int max_q_vectors;	/* upper limit of q_vectors for device */
 	struct ixgbe_ring_feature ring_feature[RING_F_ARRAY_SIZE];
 	struct msix_entry *msix_entries;
 
+#ifndef HAVE_NETDEV_STATS_IN_NETDEV
+	struct net_device_stats net_stats;
+#endif
+
+#ifdef ETHTOOL_TEST
 	u32 test_icr;
 	struct ixgbe_ring test_tx_ring;
 	struct ixgbe_ring test_rx_ring;
+#endif
 
 	/* structs defined in ixgbe_hw.h */
 	struct ixgbe_hw hw;
 	u16 msg_enable;
 	struct ixgbe_hw_stats stats;
-
+#ifndef IXGBE_NO_LLI
+	u32 lli_port;
+	u32 lli_size;
+	u32 lli_etype;
+	u32 lli_vlan_pri;
+#endif /* IXGBE_NO_LLI */
+
+	u32 *config_space;
 	u64 tx_busy;
 	unsigned int tx_ring_count;
 	unsigned int rx_ring_count;
 
 	u32 link_speed;
 	bool link_up;
+
+	bool cloud_mode;
+
 	unsigned long sfp_poll_time;
 	unsigned long link_check_timeout;
 
@@ -730,21 +941,27 @@ struct ixgbe_adapter {
 	u32 atr_sample_rate;
 	spinlock_t fdir_perfect_lock;
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	struct ixgbe_fcoe fcoe;
-#endif /* IXGBE_FCOE */
-	u8 __iomem *io_addr; /* Mainly for iounmap use */
+#endif /* CONFIG_FCOE */
+	u8 __iomem *io_addr;	/* Mainly for iounmap use */
 	u32 wol;
 
+	u16 bd_number;
+
+#ifdef HAVE_BRIDGE_ATTRIBS
 	u16 bridge_mode;
+#endif
 
-	u16 eeprom_verh;
-	u16 eeprom_verl;
+	char eeprom_id[32];
 	u16 eeprom_cap;
-
+	bool netdev_registered;
 	u32 interrupt_event;
+#ifdef HAVE_ETHTOOL_SET_PHYS_ID
 	u32 led_reg;
+#endif
 
+#ifdef HAVE_PTP_1588_CLOCK
 	struct ptp_clock *ptp_clock;
 	struct ptp_clock_info ptp_caps;
 	struct work_struct ptp_tx_work;
@@ -753,36 +970,46 @@ struct ixgbe_adapter {
 	unsigned long ptp_tx_start;
 	unsigned long last_overflow_check;
 	unsigned long last_rx_ptp_check;
-	unsigned long last_rx_timestamp;
 	spinlock_t tmreg_lock;
-	struct cyclecounter cc;
-	struct timecounter tc;
+	struct cyclecounter hw_cc;
+	struct timecounter hw_tc;
 	u32 base_incval;
+	u32 tx_hwtstamp_timeouts;
+	u32 tx_hwtstamp_skipped;
+	u32 rx_hwtstamp_cleared;
+	void (*ptp_setup_sdp) (struct ixgbe_adapter *);
+#endif /* HAVE_PTP_1588_CLOCK */
 
-	/* SR-IOV */
 	DECLARE_BITMAP(active_vfs, IXGBE_MAX_VF_FUNCTIONS);
 	unsigned int num_vfs;
+	unsigned int max_vfs;
 	struct vf_data_storage *vfinfo;
 	int vf_rate_link_speed;
 	struct vf_macvlans vf_mvs;
 	struct vf_macvlans *mv_list;
-
+#ifdef CONFIG_PCI_IOV
 	u32 timer_event_accumulator;
 	u32 vferr_refcount;
+#endif
 	struct ixgbe_mac_addr *mac_table;
-#ifdef CONFIG_IXGBE_VXLAN
-	u16 vxlan_port;
-#endif
-	struct kobject *info_kobj;
-#ifdef CONFIG_IXGBE_HWMON
-	struct hwmon_buff *ixgbe_hwmon_buff;
-#endif /* CONFIG_IXGBE_HWMON */
-#ifdef CONFIG_DEBUG_FS
+#ifdef IXGBE_SYSFS
+#ifdef IXGBE_HWMON
+	struct hwmon_buff ixgbe_hwmon_buff;
+#endif /* IXGBE_HWMON */
+#else /* IXGBE_SYSFS */
+#ifdef IXGBE_PROCFS
+	struct proc_dir_entry *eth_dir;
+	struct proc_dir_entry *info_dir;
+	u64 old_lsc;
+	struct proc_dir_entry *therm_dir[IXGBE_MAX_SENSORS];
+	struct ixgbe_therm_proc_data therm_data[IXGBE_MAX_SENSORS];
+#endif /* IXGBE_PROCFS */
+#endif /* IXGBE_SYSFS */
+
+#ifdef HAVE_IXGBE_DEBUG_FS
 	struct dentry *ixgbe_dbg_adapter;
-#endif /*CONFIG_DEBUG_FS*/
-
+#endif /*HAVE_IXGBE_DEBUG_FS*/
 	u8 default_up;
-	unsigned long fwd_bitmask; /* Bitmask indicating in use pools */
 
 /* maximum number of RETA entries among all devices supported by ixgbe
  * driver: currently it's x550 device in non-SRIOV mode
@@ -791,7 +1018,21 @@ struct ixgbe_adapter {
 	u8 rss_indir_tbl[IXGBE_MAX_RETA_ENTRIES];
 
 #define IXGBE_RSS_KEY_SIZE     40  /* size of RSS Hash Key in bytes */
-	u32 rss_key[IXGBE_RSS_KEY_SIZE / sizeof(u32)];
+	u32 *rss_key;
+
+#ifdef HAVE_TX_MQ
+#ifndef HAVE_NETDEV_SELECT_QUEUE
+	unsigned int indices;
+#endif
+#endif
+	bool need_crosstalk_fix;
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	struct {
+		int speed;
+		unsigned int link;
+		unsigned long down_tv;
+	} state_cache;
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 };
 
 static inline u8 ixgbe_max_rss_indices(struct ixgbe_adapter *adapter)
@@ -801,19 +1042,23 @@ static inline u8 ixgbe_max_rss_indices(struct ixgbe_adapter *adapter)
 	case ixgbe_mac_82599EB:
 	case ixgbe_mac_X540:
 		return IXGBE_MAX_RSS_INDICES;
+		break;
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		return IXGBE_MAX_RSS_INDICES_X550;
+		break;
 	default:
 		return 0;
+		break;
 	}
 }
 
 struct ixgbe_fdir_filter {
-	struct hlist_node fdir_node;
+	struct  hlist_node fdir_node;
 	union ixgbe_atr_input filter;
 	u16 sw_idx;
-	u16 action;
+	u64 action;
 };
 
 enum ixgbe_state_t {
@@ -821,47 +1066,65 @@ enum ixgbe_state_t {
 	__IXGBE_RESETTING,
 	__IXGBE_DOWN,
 	__IXGBE_DISABLED,
-	__IXGBE_REMOVING,
+	__IXGBE_REMOVE,
 	__IXGBE_SERVICE_SCHED,
 	__IXGBE_SERVICE_INITED,
 	__IXGBE_IN_SFP_INIT,
+#ifdef HAVE_PTP_1588_CLOCK
 	__IXGBE_PTP_RUNNING,
 	__IXGBE_PTP_TX_IN_PROGRESS,
+#endif
+	__IXGBE_RESET_REQUESTED,
 };
 
 struct ixgbe_cb {
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
 	union {				/* Union defining head/tail partner */
 		struct sk_buff *head;
 		struct sk_buff *tail;
 	};
+#endif
 	dma_addr_t dma;
-	u16 append_cnt;
-	bool page_released;
+#ifdef HAVE_VLAN_RX_REGISTER
+	u16	vid;			/* VLAN tag */
+#endif
+	u16	append_cnt;		/* number of skb's appended */
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	bool	page_released;
+#endif
 };
 #define IXGBE_CB(skb) ((struct ixgbe_cb *)(skb)->cb)
 
-enum ixgbe_boards {
-	board_82598,
-	board_82599,
-	board_X540,
-	board_X550,
-	board_X550EM_x,
-};
-
-extern struct ixgbe_info ixgbe_82598_info;
-extern struct ixgbe_info ixgbe_82599_info;
-extern struct ixgbe_info ixgbe_X540_info;
-extern struct ixgbe_info ixgbe_X550_info;
-extern struct ixgbe_info ixgbe_X550EM_x_info;
-#ifdef CONFIG_IXGBE_DCB
-extern const struct dcbnl_rtnl_ops dcbnl_ops;
-#endif
+/* ESX ixgbe CIM IOCTL definition */
 
+#ifdef IXGBE_SYSFS
+void ixgbe_sysfs_exit(struct ixgbe_adapter *adapter);
+int ixgbe_sysfs_init(struct ixgbe_adapter *adapter);
+#endif /* IXGBE_SYSFS */
+#ifdef IXGBE_PROCFS
+void ixgbe_procfs_exit(struct ixgbe_adapter *adapter);
+int ixgbe_procfs_init(struct ixgbe_adapter *adapter);
+int ixgbe_procfs_topdir_init(void);
+void ixgbe_procfs_topdir_exit(void);
+#endif /* IXGBE_PROCFS */
+
+extern struct dcbnl_rtnl_ops ixgbe_dcbnl_ops;
+int ixgbe_copy_dcb_cfg(struct ixgbe_adapter *adapter, int tc_max);
+
+u8 ixgbe_dcb_txq_to_tc(struct ixgbe_adapter *adapter, u8 index);
+
+/* needed by ixgbe_main.c */
+int ixgbe_validate_mac_addr(u8 *mc_addr);
+void ixgbe_check_options(struct ixgbe_adapter *adapter);
+void ixgbe_assign_netdev_ops(struct net_device *netdev);
+
+/* needed by ixgbe_ethtool.c */
+#ifdef HAVE_NON_CONST_PCI_DRIVER_NAME
 extern char ixgbe_driver_name[];
+#else
+extern const char ixgbe_driver_name[];
+#endif
 extern const char ixgbe_driver_version[];
-#ifdef IXGBE_FCOE
-extern char ixgbe_default_device_descr[];
-#endif /* IXGBE_FCOE */
 
 void ixgbe_up(struct ixgbe_adapter *adapter);
 void ixgbe_down(struct ixgbe_adapter *adapter);
@@ -872,115 +1135,161 @@ int ixgbe_setup_rx_resources(struct ixgbe_ring *);
 int ixgbe_setup_tx_resources(struct ixgbe_ring *);
 void ixgbe_free_rx_resources(struct ixgbe_ring *);
 void ixgbe_free_tx_resources(struct ixgbe_ring *);
-void ixgbe_configure_rx_ring(struct ixgbe_adapter *, struct ixgbe_ring *);
-void ixgbe_configure_tx_ring(struct ixgbe_adapter *, struct ixgbe_ring *);
-void ixgbe_disable_rx_queue(struct ixgbe_adapter *adapter, struct ixgbe_ring *);
+void ixgbe_configure_rx_ring(struct ixgbe_adapter *,
+				    struct ixgbe_ring *);
+void ixgbe_configure_tx_ring(struct ixgbe_adapter *,
+				    struct ixgbe_ring *);
 void ixgbe_update_stats(struct ixgbe_adapter *adapter);
 int ixgbe_init_interrupt_scheme(struct ixgbe_adapter *adapter);
-int ixgbe_wol_supported(struct ixgbe_adapter *adapter, u16 device_id,
-			       u16 subdevice_id);
-#ifdef CONFIG_PCI_IOV
-void ixgbe_full_sync_mac_table(struct ixgbe_adapter *adapter);
-#endif
-int ixgbe_add_mac_filter(struct ixgbe_adapter *adapter,
-			 u8 *addr, u16 queue);
-int ixgbe_del_mac_filter(struct ixgbe_adapter *adapter,
-			 u8 *addr, u16 queue);
+void ixgbe_reset_interrupt_capability(struct ixgbe_adapter *adapter);
+void ixgbe_set_interrupt_capability(struct ixgbe_adapter *adapter);
 void ixgbe_clear_interrupt_scheme(struct ixgbe_adapter *adapter);
-netdev_tx_t ixgbe_xmit_frame_ring(struct sk_buff *, struct ixgbe_adapter *,
-				  struct ixgbe_ring *);
+bool ixgbe_is_ixgbe(struct pci_dev *pcidev);
+netdev_tx_t ixgbe_xmit_frame_ring(struct sk_buff *,
+					 struct ixgbe_adapter *,
+					 struct ixgbe_ring *);
 void ixgbe_unmap_and_free_tx_resource(struct ixgbe_ring *,
-				      struct ixgbe_tx_buffer *);
+					     struct ixgbe_tx_buffer *);
 void ixgbe_alloc_rx_buffers(struct ixgbe_ring *, u16);
-void ixgbe_write_eitr(struct ixgbe_q_vector *);
-int ixgbe_poll(struct napi_struct *napi, int budget);
-int ethtool_ioctl(struct ifreq *ifr);
-s32 ixgbe_reinit_fdir_tables_82599(struct ixgbe_hw *hw);
-s32 ixgbe_init_fdir_signature_82599(struct ixgbe_hw *hw, u32 fdirctrl);
-s32 ixgbe_init_fdir_perfect_82599(struct ixgbe_hw *hw, u32 fdirctrl);
-s32 ixgbe_fdir_add_signature_filter_82599(struct ixgbe_hw *hw,
-					  union ixgbe_atr_hash_dword input,
-					  union ixgbe_atr_hash_dword common,
-					  u8 queue);
-s32 ixgbe_fdir_set_input_mask_82599(struct ixgbe_hw *hw,
-				    union ixgbe_atr_input *input_mask);
-s32 ixgbe_fdir_write_perfect_filter_82599(struct ixgbe_hw *hw,
-					  union ixgbe_atr_input *input,
-					  u16 soft_id, u8 queue);
-s32 ixgbe_fdir_erase_perfect_filter_82599(struct ixgbe_hw *hw,
-					  union ixgbe_atr_input *input,
-					  u16 soft_id);
-void ixgbe_atr_compute_perfect_hash_82599(union ixgbe_atr_input *input,
-					  union ixgbe_atr_input *mask);
-void ixgbe_set_rx_mode(struct net_device *netdev);
-#ifdef CONFIG_IXGBE_DCB
-void ixgbe_set_rx_drop_en(struct ixgbe_adapter *adapter);
+void ixgbe_configure_rscctl(struct ixgbe_adapter *adapter,
+				   struct ixgbe_ring *);
+void ixgbe_clear_rscctl(struct ixgbe_adapter *adapter,
+			       struct ixgbe_ring *);
+#if defined(HAVE_UDP_ENC_RX_OFFLOAD) || defined(HAVE_VXLAN_RX_OFFLOAD)
+void ixgbe_clear_udp_tunnel_port(struct ixgbe_adapter *, u32);
 #endif
+void ixgbe_set_rx_mode(struct net_device *netdev);
+int ixgbe_write_mc_addr_list(struct net_device *netdev);
 int ixgbe_setup_tc(struct net_device *dev, u8 tc);
 void ixgbe_tx_ctxtdesc(struct ixgbe_ring *, u32, u32, u32, u32);
 void ixgbe_do_reset(struct net_device *netdev);
-#ifdef CONFIG_IXGBE_HWMON
-void ixgbe_sysfs_exit(struct ixgbe_adapter *adapter);
-int ixgbe_sysfs_init(struct ixgbe_adapter *adapter);
-#endif /* CONFIG_IXGBE_HWMON */
-#ifdef IXGBE_FCOE
+void ixgbe_write_eitr(struct ixgbe_q_vector *q_vector);
+int ixgbe_poll(struct napi_struct *napi, int budget);
+void ixgbe_disable_rx_queue(struct ixgbe_adapter *adapter,
+				   struct ixgbe_ring *);
+void ixgbe_vlan_strip_enable(struct ixgbe_adapter *adapter);
+void ixgbe_vlan_strip_disable(struct ixgbe_adapter *adapter);
+#ifdef ETHTOOL_OPS_COMPAT
+int ethtool_ioctl(struct ifreq *ifr);
+#endif
+
+#if IS_ENABLED(CONFIG_FCOE)
 void ixgbe_configure_fcoe(struct ixgbe_adapter *adapter);
-int ixgbe_fso(struct ixgbe_ring *tx_ring, struct ixgbe_tx_buffer *first,
-	      u8 *hdr_len);
+int ixgbe_fso(struct ixgbe_ring *tx_ring,
+		     struct ixgbe_tx_buffer *first,
+		     u8 *hdr_len);
 int ixgbe_fcoe_ddp(struct ixgbe_adapter *adapter,
-		   union ixgbe_adv_rx_desc *rx_desc, struct sk_buff *skb);
+			  union ixgbe_adv_rx_desc *rx_desc,
+			  struct sk_buff *skb);
 int ixgbe_fcoe_ddp_get(struct net_device *netdev, u16 xid,
-		       struct scatterlist *sgl, unsigned int sgc);
+			      struct scatterlist *sgl, unsigned int sgc);
+#ifdef HAVE_NETDEV_OPS_FCOE_DDP_TARGET
 int ixgbe_fcoe_ddp_target(struct net_device *netdev, u16 xid,
-			  struct scatterlist *sgl, unsigned int sgc);
+				 struct scatterlist *sgl, unsigned int sgc);
+#endif /* HAVE_NETDEV_OPS_FCOE_DDP_TARGET */
 int ixgbe_fcoe_ddp_put(struct net_device *netdev, u16 xid);
 int ixgbe_setup_fcoe_ddp_resources(struct ixgbe_adapter *adapter);
 void ixgbe_free_fcoe_ddp_resources(struct ixgbe_adapter *adapter);
+#ifdef HAVE_NETDEV_OPS_FCOE_ENABLE
 int ixgbe_fcoe_enable(struct net_device *netdev);
 int ixgbe_fcoe_disable(struct net_device *netdev);
-#ifdef CONFIG_IXGBE_DCB
-u8 ixgbe_fcoe_getapp(struct ixgbe_adapter *adapter);
+#else
+int ixgbe_fcoe_ddp_enable(struct ixgbe_adapter *adapter);
+void ixgbe_fcoe_ddp_disable(struct ixgbe_adapter *adapter);
+#endif /* HAVE_NETDEV_OPS_FCOE_ENABLE */
+#if IS_ENABLED(CONFIG_DCB)
+#ifdef HAVE_DCBNL_OPS_GETAPP
+u8 ixgbe_fcoe_getapp(struct net_device *netdev);
+#endif /* HAVE_DCBNL_OPS_GETAPP */
 u8 ixgbe_fcoe_setapp(struct ixgbe_adapter *adapter, u8 up);
-#endif /* CONFIG_IXGBE_DCB */
-int ixgbe_fcoe_get_wwn(struct net_device *netdev, u64 *wwn, int type);
-int ixgbe_fcoe_get_hbainfo(struct net_device *netdev,
-			   struct netdev_fcoe_hbainfo *info);
+#endif /* CONFIG_DCB */
 u8 ixgbe_fcoe_get_tc(struct ixgbe_adapter *adapter);
-#endif /* IXGBE_FCOE */
-#ifdef CONFIG_DEBUG_FS
+#ifdef HAVE_NETDEV_OPS_FCOE_GETWWN
+int ixgbe_fcoe_get_wwn(struct net_device *netdev, u64 *wwn, int type);
+#endif
+#endif /* CONFIG_FCOE */
+
+#ifdef HAVE_IXGBE_DEBUG_FS
 void ixgbe_dbg_adapter_init(struct ixgbe_adapter *adapter);
 void ixgbe_dbg_adapter_exit(struct ixgbe_adapter *adapter);
 void ixgbe_dbg_init(void);
 void ixgbe_dbg_exit(void);
-#else
-static inline void ixgbe_dbg_adapter_init(struct ixgbe_adapter *adapter) {}
-static inline void ixgbe_dbg_adapter_exit(struct ixgbe_adapter *adapter) {}
-static inline void ixgbe_dbg_init(void) {}
-static inline void ixgbe_dbg_exit(void) {}
-#endif /* CONFIG_DEBUG_FS */
+#endif /* HAVE_IXGBE_DEBUG_FS */
+
+#if IS_ENABLED(CONFIG_BQL) || defined(HAVE_SKB_XMIT_MORE)
 static inline struct netdev_queue *txring_txq(const struct ixgbe_ring *ring)
 {
 	return netdev_get_tx_queue(ring->netdev, ring->queue_index);
 }
+#endif
+
+#if IS_ENABLED(CONFIG_DCB)
+#ifdef HAVE_DCBNL_IEEE
+s32 ixgbe_dcb_hw_ets(struct ixgbe_hw *hw, struct ieee_ets *ets, int max_frame);
+#endif /* HAVE_DCBNL_IEEE */
+#endif /* CONFIG_DCB */
 
+bool ixgbe_wol_supported(struct ixgbe_adapter *adapter, u16 device_id,
+			 u16 subdevice_id);
+int ixgbe_write_uc_addr_list(struct net_device *netdev, int vfn);
+void ixgbe_full_sync_mac_table(struct ixgbe_adapter *adapter);
+int ixgbe_add_mac_filter(struct ixgbe_adapter *adapter,
+				const u8 *addr, u16 queue);
+int ixgbe_del_mac_filter(struct ixgbe_adapter *adapter,
+				const u8 *addr, u16 queue);
+int ixgbe_available_rars(struct ixgbe_adapter *adapter, u16 pool);
+void ixgbe_update_pf_promisc_vlvf(struct ixgbe_adapter *adapter, u32 vid);
+#ifndef HAVE_VLAN_RX_REGISTER
+void ixgbe_vlan_mode(struct net_device *, u32);
+#else
+#ifdef CONFIG_PCI_IOV
+int ixgbe_find_vlvf_entry(struct ixgbe_hw *hw, u32 vlan);
+#endif
+#endif
+
+#ifdef HAVE_PTP_1588_CLOCK
 void ixgbe_ptp_init(struct ixgbe_adapter *adapter);
-void ixgbe_ptp_suspend(struct ixgbe_adapter *adapter);
 void ixgbe_ptp_stop(struct ixgbe_adapter *adapter);
+void ixgbe_ptp_suspend(struct ixgbe_adapter *adapter);
 void ixgbe_ptp_overflow_check(struct ixgbe_adapter *adapter);
 void ixgbe_ptp_rx_hang(struct ixgbe_adapter *adapter);
-void ixgbe_ptp_rx_hwtstamp(struct ixgbe_adapter *adapter, struct sk_buff *skb);
-int ixgbe_ptp_set_ts_config(struct ixgbe_adapter *adapter, struct ifreq *ifr);
+void ixgbe_ptp_tx_hang(struct ixgbe_adapter *adapter);
+void ixgbe_ptp_rx_pktstamp(struct ixgbe_q_vector *q_vector,
+				  struct sk_buff *skb);
+void ixgbe_ptp_rx_rgtstamp(struct ixgbe_q_vector *q_vector,
+				  struct sk_buff *skb);
+static inline void ixgbe_ptp_rx_hwtstamp(struct ixgbe_ring *rx_ring,
+					 union ixgbe_adv_rx_desc *rx_desc,
+					 struct sk_buff *skb)
+{
+	if (unlikely(ixgbe_test_staterr(rx_desc, IXGBE_RXD_STAT_TSIP))) {
+		ixgbe_ptp_rx_pktstamp(rx_ring->q_vector, skb);
+		return;
+	}
+
+	if (unlikely(!ixgbe_test_staterr(rx_desc, IXGBE_RXDADV_STAT_TS)))
+		return;
+
+	ixgbe_ptp_rx_rgtstamp(rx_ring->q_vector, skb);
+
+	/* Update the last_rx_timestamp timer in order to enable watchdog check
+	 * for error case of latched timestamp on a dropped packet.
+	 */
+	rx_ring->last_rx_timestamp = jiffies;
+}
+
 int ixgbe_ptp_get_ts_config(struct ixgbe_adapter *adapter, struct ifreq *ifr);
+int ixgbe_ptp_set_ts_config(struct ixgbe_adapter *adapter, struct ifreq *ifr);
 void ixgbe_ptp_start_cyclecounter(struct ixgbe_adapter *adapter);
 void ixgbe_ptp_reset(struct ixgbe_adapter *adapter);
-void ixgbe_ptp_check_pps_event(struct ixgbe_adapter *adapter, u32 eicr);
+void ixgbe_ptp_check_pps_event(struct ixgbe_adapter *adapter);
+#endif /* HAVE_PTP_1588_CLOCK */
 #ifdef CONFIG_PCI_IOV
 void ixgbe_sriov_reinit(struct ixgbe_adapter *adapter);
 #endif
-
-netdev_tx_t ixgbe_xmit_frame_ring(struct sk_buff *skb,
-				  struct ixgbe_adapter *adapter,
-				  struct ixgbe_ring *tx_ring);
 u32 ixgbe_rss_indir_tbl_entries(struct ixgbe_adapter *adapter);
+void ixgbe_store_key(struct ixgbe_adapter *adapter);
 void ixgbe_store_reta(struct ixgbe_adapter *adapter);
+
+void ixgbe_set_rx_drop_en(struct ixgbe_adapter *adapter);
 #endif /* _IXGBE_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_82598.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_82598.c
index 65db69b..8b7fc59 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_82598.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_82598.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,11 +22,10 @@
 
 *******************************************************************************/
 
-#include <linux/pci.h>
-#include <linux/delay.h>
-#include <linux/sched.h>
-
-#include "ixgbe.h"
+#include "ixgbe_type.h"
+#include "ixgbe_82598.h"
+#include "ixgbe_api.h"
+#include "ixgbe_common.h"
 #include "ixgbe_phy.h"
 
 #define IXGBE_82598_MAX_TX_QUEUES 32
@@ -38,14 +33,30 @@
 #define IXGBE_82598_RAR_ENTRIES   16
 #define IXGBE_82598_MC_TBL_SIZE  128
 #define IXGBE_82598_VFT_TBL_SIZE 128
-#define IXGBE_82598_RX_PB_SIZE	 512
+#define IXGBE_82598_RX_PB_SIZE   512
 
-static s32 ixgbe_setup_copper_link_82598(struct ixgbe_hw *hw,
+STATIC s32 ixgbe_get_link_capabilities_82598(struct ixgbe_hw *hw,
+					     ixgbe_link_speed *speed,
+					     bool *autoneg);
+STATIC enum ixgbe_media_type ixgbe_get_media_type_82598(struct ixgbe_hw *hw);
+STATIC s32 ixgbe_start_mac_link_82598(struct ixgbe_hw *hw,
+				      bool autoneg_wait_to_complete);
+STATIC s32 ixgbe_check_mac_link_82598(struct ixgbe_hw *hw,
+				      ixgbe_link_speed *speed, bool *link_up,
+				      bool link_up_wait_to_complete);
+STATIC s32 ixgbe_setup_mac_link_82598(struct ixgbe_hw *hw,
+				      ixgbe_link_speed speed,
+				      bool autoneg_wait_to_complete);
+STATIC s32 ixgbe_setup_copper_link_82598(struct ixgbe_hw *hw,
 					 ixgbe_link_speed speed,
 					 bool autoneg_wait_to_complete);
-static s32 ixgbe_read_i2c_eeprom_82598(struct ixgbe_hw *hw, u8 byte_offset,
-				       u8 *eeprom_data);
-
+STATIC s32 ixgbe_reset_hw_82598(struct ixgbe_hw *hw);
+STATIC s32 ixgbe_clear_vmdq_82598(struct ixgbe_hw *hw, u32 rar, u32 vmdq);
+STATIC s32 ixgbe_clear_vfta_82598(struct ixgbe_hw *hw);
+STATIC void ixgbe_set_rxpba_82598(struct ixgbe_hw *hw, int num_pb,
+				  u32 headroom, int strategy);
+STATIC s32 ixgbe_read_i2c_sff8472_82598(struct ixgbe_hw *hw, u8 byte_offset,
+					u8 *sff8472_data);
 /**
  *  ixgbe_set_pcie_completion_timeout - set pci-e completion timeout
  *  @hw: pointer to the HW structure
@@ -56,14 +67,11 @@ static s32 ixgbe_read_i2c_eeprom_82598(struct ixgbe_hw *hw, u8 byte_offset,
  *  increase the value to either 10ms to 250ms for capability version 1 config,
  *  or 16ms to 55ms for version 2.
  **/
-static void ixgbe_set_pcie_completion_timeout(struct ixgbe_hw *hw)
+void ixgbe_set_pcie_completion_timeout(struct ixgbe_hw *hw)
 {
 	u32 gcr = IXGBE_READ_REG(hw, IXGBE_GCR);
 	u16 pcie_devctl2;
 
-	if (ixgbe_removed(hw->hw_addr))
-		return;
-
 	/* only take action if timeout value is defaulted to 0 */
 	if (gcr & IXGBE_GCR_CMPL_TMOUT_MASK)
 		goto out;
@@ -82,31 +90,82 @@ static void ixgbe_set_pcie_completion_timeout(struct ixgbe_hw *hw)
 	 * directly in order to set the completion timeout value for
 	 * 16ms to 55ms
 	 */
-	pcie_devctl2 = ixgbe_read_pci_cfg_word(hw, IXGBE_PCI_DEVICE_CONTROL2);
+	pcie_devctl2 = IXGBE_READ_PCIE_WORD(hw, IXGBE_PCI_DEVICE_CONTROL2);
 	pcie_devctl2 |= IXGBE_PCI_DEVICE_CONTROL2_16ms;
-	ixgbe_write_pci_cfg_word(hw, IXGBE_PCI_DEVICE_CONTROL2, pcie_devctl2);
+	IXGBE_WRITE_PCIE_WORD(hw, IXGBE_PCI_DEVICE_CONTROL2, pcie_devctl2);
 out:
 	/* disable completion timeout resend */
 	gcr &= ~IXGBE_GCR_CMPL_TMOUT_RESEND;
 	IXGBE_WRITE_REG(hw, IXGBE_GCR, gcr);
 }
 
-static s32 ixgbe_get_invariants_82598(struct ixgbe_hw *hw)
+/**
+ *  ixgbe_init_ops_82598 - Inits func ptrs and MAC type
+ *  @hw: pointer to hardware structure
+ *
+ *  Initialize the function pointers and assign the MAC type for 82598.
+ *  Does not touch the hardware.
+ **/
+s32 ixgbe_init_ops_82598(struct ixgbe_hw *hw)
 {
 	struct ixgbe_mac_info *mac = &hw->mac;
+	struct ixgbe_phy_info *phy = &hw->phy;
+	s32 ret_val;
 
-	/* Call PHY identify routine to get the phy type */
-	ixgbe_identify_phy_generic(hw);
-
-	mac->mcft_size = IXGBE_82598_MC_TBL_SIZE;
-	mac->vft_size = IXGBE_82598_VFT_TBL_SIZE;
-	mac->num_rar_entries = IXGBE_82598_RAR_ENTRIES;
-	mac->rx_pb_size = IXGBE_82598_RX_PB_SIZE;
-	mac->max_rx_queues = IXGBE_82598_MAX_RX_QUEUES;
-	mac->max_tx_queues = IXGBE_82598_MAX_TX_QUEUES;
-	mac->max_msix_vectors = ixgbe_get_pcie_msix_count_generic(hw);
-
-	return 0;
+	DEBUGFUNC("ixgbe_init_ops_82598");
+
+	ret_val = ixgbe_init_phy_ops_generic(hw);
+	ret_val = ixgbe_init_ops_generic(hw);
+
+	/* PHY */
+	phy->ops.init = ixgbe_init_phy_ops_82598;
+
+	/* MAC */
+	mac->ops.start_hw = ixgbe_start_hw_82598;
+	mac->ops.reset_hw = ixgbe_reset_hw_82598;
+	mac->ops.get_media_type = ixgbe_get_media_type_82598;
+	mac->ops.get_supported_physical_layer =
+				ixgbe_get_supported_physical_layer_82598;
+	mac->ops.read_analog_reg8 = ixgbe_read_analog_reg8_82598;
+	mac->ops.write_analog_reg8 = ixgbe_write_analog_reg8_82598;
+	mac->ops.set_lan_id = ixgbe_set_lan_id_multi_port_pcie_82598;
+	mac->ops.enable_rx_dma = ixgbe_enable_rx_dma_82598;
+
+	/* RAR, Multicast, VLAN */
+	mac->ops.set_vmdq = ixgbe_set_vmdq_82598;
+	mac->ops.clear_vmdq = ixgbe_clear_vmdq_82598;
+	mac->ops.set_vfta = ixgbe_set_vfta_82598;
+	mac->ops.set_vlvf = NULL;
+	mac->ops.clear_vfta = ixgbe_clear_vfta_82598;
+
+	/* Flow Control */
+	mac->ops.fc_enable = ixgbe_fc_enable_82598;
+
+	mac->mcft_size		= IXGBE_82598_MC_TBL_SIZE;
+	mac->vft_size		= IXGBE_82598_VFT_TBL_SIZE;
+	mac->num_rar_entries	= IXGBE_82598_RAR_ENTRIES;
+	mac->rx_pb_size		= IXGBE_82598_RX_PB_SIZE;
+	mac->max_rx_queues	= IXGBE_82598_MAX_RX_QUEUES;
+	mac->max_tx_queues	= IXGBE_82598_MAX_TX_QUEUES;
+	mac->max_msix_vectors	= ixgbe_get_pcie_msix_count_generic(hw);
+
+	/* SFP+ Module */
+	phy->ops.read_i2c_eeprom = ixgbe_read_i2c_eeprom_82598;
+	phy->ops.read_i2c_sff8472 = ixgbe_read_i2c_sff8472_82598;
+
+	/* Link */
+	mac->ops.check_link = ixgbe_check_mac_link_82598;
+	mac->ops.setup_link = ixgbe_setup_mac_link_82598;
+	mac->ops.flap_tx_laser = NULL;
+	mac->ops.get_link_capabilities = ixgbe_get_link_capabilities_82598;
+	mac->ops.setup_rxpba = ixgbe_set_rxpba_82598;
+
+	/* Manageability interface */
+	mac->ops.set_fw_drv_ver = NULL;
+
+	mac->ops.get_rtrup2tc = NULL;
+
+	return ret_val;
 }
 
 /**
@@ -114,56 +173,63 @@ static s32 ixgbe_get_invariants_82598(struct ixgbe_hw *hw)
  *  @hw: pointer to hardware structure
  *
  *  Initialize any function pointers that were not able to be
- *  set during get_invariants because the PHY/SFP type was
+ *  set during init_shared_code because the PHY/SFP type was
  *  not known.  Perform the SFP init if necessary.
  *
  **/
-static s32 ixgbe_init_phy_ops_82598(struct ixgbe_hw *hw)
+s32 ixgbe_init_phy_ops_82598(struct ixgbe_hw *hw)
 {
 	struct ixgbe_mac_info *mac = &hw->mac;
 	struct ixgbe_phy_info *phy = &hw->phy;
-	s32 ret_val;
+	s32 ret_val = IXGBE_SUCCESS;
 	u16 list_offset, data_offset;
 
+	DEBUGFUNC("ixgbe_init_phy_ops_82598");
+
 	/* Identify the PHY */
 	phy->ops.identify(hw);
 
 	/* Overwrite the link function pointers if copper PHY */
 	if (mac->ops.get_media_type(hw) == ixgbe_media_type_copper) {
-		mac->ops.setup_link = &ixgbe_setup_copper_link_82598;
+		mac->ops.setup_link = ixgbe_setup_copper_link_82598;
 		mac->ops.get_link_capabilities =
-			&ixgbe_get_copper_link_capabilities_generic;
+				ixgbe_get_copper_link_capabilities_generic;
 	}
 
 	switch (hw->phy.type) {
 	case ixgbe_phy_tn:
-		phy->ops.setup_link = &ixgbe_setup_phy_link_tnx;
-		phy->ops.check_link = &ixgbe_check_phy_link_tnx;
+		phy->ops.setup_link = ixgbe_setup_phy_link_tnx;
+		phy->ops.check_link = ixgbe_check_phy_link_tnx;
 		phy->ops.get_firmware_version =
-			     &ixgbe_get_phy_firmware_version_tnx;
+					ixgbe_get_phy_firmware_version_tnx;
 		break;
 	case ixgbe_phy_nl:
-		phy->ops.reset = &ixgbe_reset_phy_nl;
+		phy->ops.reset = ixgbe_reset_phy_nl;
 
 		/* Call SFP+ identify routine to get the SFP+ module type */
 		ret_val = phy->ops.identify_sfp(hw);
-		if (ret_val)
-			return ret_val;
-		if (hw->phy.sfp_type == ixgbe_sfp_type_unknown)
-			return IXGBE_ERR_SFP_NOT_SUPPORTED;
+		if (ret_val != IXGBE_SUCCESS)
+			goto out;
+		else if (hw->phy.sfp_type == ixgbe_sfp_type_unknown) {
+			ret_val = IXGBE_ERR_SFP_NOT_SUPPORTED;
+			goto out;
+		}
 
 		/* Check to see if SFP+ module is supported */
 		ret_val = ixgbe_get_sfp_init_sequence_offsets(hw,
-							    &list_offset,
-							    &data_offset);
-		if (ret_val)
-			return IXGBE_ERR_SFP_NOT_SUPPORTED;
+							      &list_offset,
+							      &data_offset);
+		if (ret_val != IXGBE_SUCCESS) {
+			ret_val = IXGBE_ERR_SFP_NOT_SUPPORTED;
+			goto out;
+		}
 		break;
 	default:
 		break;
 	}
 
-	return 0;
+out:
+	return ret_val;
 }
 
 /**
@@ -171,21 +237,21 @@ static s32 ixgbe_init_phy_ops_82598(struct ixgbe_hw *hw)
  *  @hw: pointer to hardware structure
  *
  *  Starts the hardware using the generic start_hw function.
- *  Disables relaxed ordering for archs other than SPARC
- *  Then set pcie completion timeout
+ *  Disables relaxed ordering Then set pcie completion timeout
  *
  **/
-static s32 ixgbe_start_hw_82598(struct ixgbe_hw *hw)
+s32 ixgbe_start_hw_82598(struct ixgbe_hw *hw)
 {
-#ifndef CONFIG_SPARC
 	u32 regval;
 	u32 i;
-#endif
-	s32 ret_val;
+	s32 ret_val = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_start_hw_82598");
 
 	ret_val = ixgbe_start_hw_generic(hw);
+	if (ret_val)
+		return ret_val;
 
-#ifndef CONFIG_SPARC
 	/* Disable relaxed ordering */
 	for (i = 0; ((i < hw->mac.max_tx_queues) &&
 	     (i < IXGBE_DCA_MAX_QUEUES_82598)); i++) {
@@ -201,14 +267,11 @@ static s32 ixgbe_start_hw_82598(struct ixgbe_hw *hw)
 			    IXGBE_DCA_RXCTRL_HEAD_WRO_EN);
 		IXGBE_WRITE_REG(hw, IXGBE_DCA_RXCTRL(i), regval);
 	}
-#endif
-	if (ret_val)
-		return ret_val;
 
 	/* set the completion timeout for interface */
 	ixgbe_set_pcie_completion_timeout(hw);
 
-	return 0;
+	return ret_val;
 }
 
 /**
@@ -219,12 +282,15 @@ static s32 ixgbe_start_hw_82598(struct ixgbe_hw *hw)
  *
  *  Determines the link capabilities by reading the AUTOC register.
  **/
-static s32 ixgbe_get_link_capabilities_82598(struct ixgbe_hw *hw,
+STATIC s32 ixgbe_get_link_capabilities_82598(struct ixgbe_hw *hw,
 					     ixgbe_link_speed *speed,
 					     bool *autoneg)
 {
+	s32 status = IXGBE_SUCCESS;
 	u32 autoc = 0;
 
+	DEBUGFUNC("ixgbe_get_link_capabilities_82598");
+
 	/*
 	 * Determine link capabilities based on the stored value of AUTOC,
 	 * which represents EEPROM defaults.  If AUTOC value has not been
@@ -262,10 +328,11 @@ static s32 ixgbe_get_link_capabilities_82598(struct ixgbe_hw *hw,
 		break;
 
 	default:
-		return IXGBE_ERR_LINK_SETUP;
+		status = IXGBE_ERR_LINK_SETUP;
+		break;
 	}
 
-	return 0;
+	return status;
 }
 
 /**
@@ -274,14 +341,18 @@ static s32 ixgbe_get_link_capabilities_82598(struct ixgbe_hw *hw,
  *
  *  Returns the media type (fiber, copper, backplane)
  **/
-static enum ixgbe_media_type ixgbe_get_media_type_82598(struct ixgbe_hw *hw)
+STATIC enum ixgbe_media_type ixgbe_get_media_type_82598(struct ixgbe_hw *hw)
 {
+	enum ixgbe_media_type media_type;
+
+	DEBUGFUNC("ixgbe_get_media_type_82598");
+
 	/* Detect if there is a copper PHY attached. */
 	switch (hw->phy.type) {
 	case ixgbe_phy_cu_unknown:
 	case ixgbe_phy_tn:
-		return ixgbe_media_type_copper;
-
+		media_type = ixgbe_media_type_copper;
+		goto out;
 	default:
 		break;
 	}
@@ -291,27 +362,30 @@ static enum ixgbe_media_type ixgbe_get_media_type_82598(struct ixgbe_hw *hw)
 	case IXGBE_DEV_ID_82598:
 	case IXGBE_DEV_ID_82598_BX:
 		/* Default device ID is mezzanine card KX/KX4 */
-		return ixgbe_media_type_backplane;
-
+		media_type = ixgbe_media_type_backplane;
+		break;
 	case IXGBE_DEV_ID_82598AF_DUAL_PORT:
 	case IXGBE_DEV_ID_82598AF_SINGLE_PORT:
 	case IXGBE_DEV_ID_82598_DA_DUAL_PORT:
 	case IXGBE_DEV_ID_82598_SR_DUAL_PORT_EM:
 	case IXGBE_DEV_ID_82598EB_XF_LR:
 	case IXGBE_DEV_ID_82598EB_SFP_LOM:
-		return ixgbe_media_type_fiber;
-
+		media_type = ixgbe_media_type_fiber;
+		break;
 	case IXGBE_DEV_ID_82598EB_CX4:
 	case IXGBE_DEV_ID_82598_CX4_DUAL_PORT:
-		return ixgbe_media_type_cx4;
-
+		media_type = ixgbe_media_type_cx4;
+		break;
 	case IXGBE_DEV_ID_82598AT:
 	case IXGBE_DEV_ID_82598AT2:
-		return ixgbe_media_type_copper;
-
+		media_type = ixgbe_media_type_copper;
+		break;
 	default:
-		return ixgbe_media_type_unknown;
+		media_type = ixgbe_media_type_unknown;
+		break;
 	}
+out:
+	return media_type;
 }
 
 /**
@@ -320,8 +394,9 @@ static enum ixgbe_media_type ixgbe_get_media_type_82598(struct ixgbe_hw *hw)
  *
  *  Enable flow control according to the current settings.
  **/
-static s32 ixgbe_fc_enable_82598(struct ixgbe_hw *hw)
+s32 ixgbe_fc_enable_82598(struct ixgbe_hw *hw)
 {
+	s32 ret_val = IXGBE_SUCCESS;
 	u32 fctrl_reg;
 	u32 rmcs_reg;
 	u32 reg;
@@ -330,18 +405,23 @@ static s32 ixgbe_fc_enable_82598(struct ixgbe_hw *hw)
 	int i;
 	bool link_up;
 
+	DEBUGFUNC("ixgbe_fc_enable_82598");
+
 	/* Validate the water mark configuration */
-	if (!hw->fc.pause_time)
-		return IXGBE_ERR_INVALID_LINK_SETTINGS;
+	if (!hw->fc.pause_time) {
+		ret_val = IXGBE_ERR_INVALID_LINK_SETTINGS;
+		goto out;
+	}
 
 	/* Low water mark of zero causes XOFF floods */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		if ((hw->fc.current_mode & ixgbe_fc_tx_pause) &&
 		    hw->fc.high_water[i]) {
 			if (!hw->fc.low_water[i] ||
 			    hw->fc.low_water[i] >= hw->fc.high_water[i]) {
-				hw_dbg(hw, "Invalid water mark configuration\n");
-				return IXGBE_ERR_INVALID_LINK_SETTINGS;
+				DEBUGOUT("Invalid water mark configuration\n");
+				ret_val = IXGBE_ERR_INVALID_LINK_SETTINGS;
+				goto out;
 			}
 		}
 	}
@@ -417,8 +497,10 @@ static s32 ixgbe_fc_enable_82598(struct ixgbe_hw *hw)
 		rmcs_reg |= IXGBE_RMCS_TFCE_802_3X;
 		break;
 	default:
-		hw_dbg(hw, "Flow control param set incorrectly\n");
-		return IXGBE_ERR_CONFIG;
+		DEBUGOUT("Flow control param set incorrectly\n");
+		ret_val = IXGBE_ERR_CONFIG;
+		goto out;
+		break;
 	}
 
 	/* Set 802.3x based flow control settings. */
@@ -427,7 +509,7 @@ static s32 ixgbe_fc_enable_82598(struct ixgbe_hw *hw)
 	IXGBE_WRITE_REG(hw, IXGBE_RMCS, rmcs_reg);
 
 	/* Set up and enable Rx high/low water mark thresholds, enable XON. */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		if ((hw->fc.current_mode & ixgbe_fc_tx_pause) &&
 		    hw->fc.high_water[i]) {
 			fcrtl = (hw->fc.low_water[i] << 10) | IXGBE_FCRTL_XONE;
@@ -443,13 +525,14 @@ static s32 ixgbe_fc_enable_82598(struct ixgbe_hw *hw)
 
 	/* Configure pause time (2 TCs per register) */
 	reg = hw->fc.pause_time * 0x00010001;
-	for (i = 0; i < (MAX_TRAFFIC_CLASS / 2); i++)
+	for (i = 0; i < (IXGBE_DCB_MAX_TRAFFIC_CLASS / 2); i++)
 		IXGBE_WRITE_REG(hw, IXGBE_FCTTV(i), reg);
 
 	/* Configure flow control refresh threshold value */
 	IXGBE_WRITE_REG(hw, IXGBE_FCRTV, hw->fc.pause_time / 2);
 
-	return 0;
+out:
+	return ret_val;
 }
 
 /**
@@ -459,13 +542,15 @@ static s32 ixgbe_fc_enable_82598(struct ixgbe_hw *hw)
  *  Configures link settings based on values in the ixgbe_hw struct.
  *  Restarts the link.  Performs autonegotiation if needed.
  **/
-static s32 ixgbe_start_mac_link_82598(struct ixgbe_hw *hw,
+STATIC s32 ixgbe_start_mac_link_82598(struct ixgbe_hw *hw,
 				      bool autoneg_wait_to_complete)
 {
 	u32 autoc_reg;
 	u32 links_reg;
 	u32 i;
-	s32 status = 0;
+	s32 status = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_start_mac_link_82598");
 
 	/* Restart link */
 	autoc_reg = IXGBE_READ_REG(hw, IXGBE_AUTOC);
@@ -483,17 +568,17 @@ static s32 ixgbe_start_mac_link_82598(struct ixgbe_hw *hw,
 				links_reg = IXGBE_READ_REG(hw, IXGBE_LINKS);
 				if (links_reg & IXGBE_LINKS_KX_AN_COMP)
 					break;
-				msleep(100);
+				msec_delay(100);
 			}
 			if (!(links_reg & IXGBE_LINKS_KX_AN_COMP)) {
 				status = IXGBE_ERR_AUTONEG_NOT_COMPLETE;
-				hw_dbg(hw, "Autonegotiation did not complete.\n");
+				DEBUGOUT("Autonegotiation did not complete.\n");
 			}
 		}
 	}
 
 	/* Add delay to filter out noises during initial link setup */
-	msleep(50);
+	msec_delay(50);
 
 	return status;
 }
@@ -505,31 +590,32 @@ static s32 ixgbe_start_mac_link_82598(struct ixgbe_hw *hw,
  *  Function indicates success when phy link is available. If phy is not ready
  *  within 5 seconds of MAC indicating link, the function returns error.
  **/
-static s32 ixgbe_validate_link_ready(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_validate_link_ready(struct ixgbe_hw *hw)
 {
 	u32 timeout;
 	u16 an_reg;
 
 	if (hw->device_id != IXGBE_DEV_ID_82598AT2)
-		return 0;
+		return IXGBE_SUCCESS;
 
 	for (timeout = 0;
 	     timeout < IXGBE_VALIDATE_LINK_READY_TIMEOUT; timeout++) {
-		hw->phy.ops.read_reg(hw, MDIO_STAT1, MDIO_MMD_AN, &an_reg);
+		hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_STATUS,
+				     IXGBE_MDIO_AUTO_NEG_DEV_TYPE, &an_reg);
 
-		if ((an_reg & MDIO_AN_STAT1_COMPLETE) &&
-		    (an_reg & MDIO_STAT1_LSTATUS))
+		if ((an_reg & IXGBE_MII_AUTONEG_COMPLETE) &&
+		    (an_reg & IXGBE_MII_AUTONEG_LINK_UP))
 			break;
 
-		msleep(100);
+		msec_delay(100);
 	}
 
 	if (timeout == IXGBE_VALIDATE_LINK_READY_TIMEOUT) {
-		hw_dbg(hw, "Link was indicated but link is down\n");
+		DEBUGOUT("Link was indicated but link is down\n");
 		return IXGBE_ERR_LINK_SETUP;
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -541,7 +627,7 @@ static s32 ixgbe_validate_link_ready(struct ixgbe_hw *hw)
  *
  *  Reads the links register to determine if link is up and the current speed
  **/
-static s32 ixgbe_check_mac_link_82598(struct ixgbe_hw *hw,
+STATIC s32 ixgbe_check_mac_link_82598(struct ixgbe_hw *hw,
 				      ixgbe_link_speed *speed, bool *link_up,
 				      bool link_up_wait_to_complete)
 {
@@ -549,19 +635,21 @@ static s32 ixgbe_check_mac_link_82598(struct ixgbe_hw *hw,
 	u32 i;
 	u16 link_reg, adapt_comp_reg;
 
+	DEBUGFUNC("ixgbe_check_mac_link_82598");
+
 	/*
-	 * SERDES PHY requires us to read link status from register 0xC79F.
-	 * Bit 0 set indicates link is up/ready; clear indicates link down.
-	 * 0xC00C is read to check that the XAUI lanes are active.  Bit 0
-	 * clear indicates active; set indicates inactive.
+	 * SERDES PHY requires us to read link status from undocumented
+	 * register 0xC79F.  Bit 0 set indicates link is up/ready; clear
+	 * indicates link down.  OxC00C is read to check that the XAUI lanes
+	 * are active.  Bit 0 clear indicates active; set indicates inactive.
 	 */
 	if (hw->phy.type == ixgbe_phy_nl) {
-		hw->phy.ops.read_reg(hw, 0xC79F, MDIO_MMD_PMAPMD, &link_reg);
-		hw->phy.ops.read_reg(hw, 0xC79F, MDIO_MMD_PMAPMD, &link_reg);
-		hw->phy.ops.read_reg(hw, 0xC00C, MDIO_MMD_PMAPMD,
+		hw->phy.ops.read_reg(hw, 0xC79F, IXGBE_TWINAX_DEV, &link_reg);
+		hw->phy.ops.read_reg(hw, 0xC79F, IXGBE_TWINAX_DEV, &link_reg);
+		hw->phy.ops.read_reg(hw, 0xC00C, IXGBE_TWINAX_DEV,
 				     &adapt_comp_reg);
 		if (link_up_wait_to_complete) {
-			for (i = 0; i < IXGBE_LINK_UP_TIME; i++) {
+			for (i = 0; i < hw->mac.max_link_up_time; i++) {
 				if ((link_reg & 1) &&
 				    ((adapt_comp_reg & 1) == 0)) {
 					*link_up = true;
@@ -569,12 +657,12 @@ static s32 ixgbe_check_mac_link_82598(struct ixgbe_hw *hw,
 				} else {
 					*link_up = false;
 				}
-				msleep(100);
+				msec_delay(100);
 				hw->phy.ops.read_reg(hw, 0xC79F,
-						     MDIO_MMD_PMAPMD,
+						     IXGBE_TWINAX_DEV,
 						     &link_reg);
 				hw->phy.ops.read_reg(hw, 0xC00C,
-						     MDIO_MMD_PMAPMD,
+						     IXGBE_TWINAX_DEV,
 						     &adapt_comp_reg);
 			}
 		} else {
@@ -584,20 +672,20 @@ static s32 ixgbe_check_mac_link_82598(struct ixgbe_hw *hw,
 				*link_up = false;
 		}
 
-		if (!*link_up)
-			return 0;
+		if (*link_up == false)
+			goto out;
 	}
 
 	links_reg = IXGBE_READ_REG(hw, IXGBE_LINKS);
 	if (link_up_wait_to_complete) {
-		for (i = 0; i < IXGBE_LINK_UP_TIME; i++) {
+		for (i = 0; i < hw->mac.max_link_up_time; i++) {
 			if (links_reg & IXGBE_LINKS_UP) {
 				*link_up = true;
 				break;
 			} else {
 				*link_up = false;
 			}
-			msleep(100);
+			msec_delay(100);
 			links_reg = IXGBE_READ_REG(hw, IXGBE_LINKS);
 		}
 	} else {
@@ -612,11 +700,12 @@ static s32 ixgbe_check_mac_link_82598(struct ixgbe_hw *hw,
 	else
 		*speed = IXGBE_LINK_SPEED_1GB_FULL;
 
-	if ((hw->device_id == IXGBE_DEV_ID_82598AT2) && *link_up &&
-	    (ixgbe_validate_link_ready(hw) != 0))
+	if ((hw->device_id == IXGBE_DEV_ID_82598AT2) && (*link_up == true) &&
+	    (ixgbe_validate_link_ready(hw) != IXGBE_SUCCESS))
 		*link_up = false;
 
-	return 0;
+out:
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -627,22 +716,25 @@ static s32 ixgbe_check_mac_link_82598(struct ixgbe_hw *hw,
  *
  *  Set the link speed in the AUTOC register and restarts link.
  **/
-static s32 ixgbe_setup_mac_link_82598(struct ixgbe_hw *hw,
+STATIC s32 ixgbe_setup_mac_link_82598(struct ixgbe_hw *hw,
 				      ixgbe_link_speed speed,
 				      bool autoneg_wait_to_complete)
 {
-	bool		 autoneg	   = false;
+	bool autoneg = false;
+	s32 status = IXGBE_SUCCESS;
 	ixgbe_link_speed link_capabilities = IXGBE_LINK_SPEED_UNKNOWN;
-	u32              curr_autoc        = IXGBE_READ_REG(hw, IXGBE_AUTOC);
-	u32              autoc             = curr_autoc;
-	u32              link_mode         = autoc & IXGBE_AUTOC_LMS_MASK;
+	u32 curr_autoc = IXGBE_READ_REG(hw, IXGBE_AUTOC);
+	u32 autoc = curr_autoc;
+	u32 link_mode = autoc & IXGBE_AUTOC_LMS_MASK;
+
+	DEBUGFUNC("ixgbe_setup_mac_link_82598");
 
 	/* Check to see if speed passed in is supported. */
-	ixgbe_get_link_capabilities_82598(hw, &link_capabilities, &autoneg);
+	ixgbe_get_link_capabilities(hw, &link_capabilities, &autoneg);
 	speed &= link_capabilities;
 
 	if (speed == IXGBE_LINK_SPEED_UNKNOWN)
-		return IXGBE_ERR_LINK_SETUP;
+		status = IXGBE_ERR_LINK_SETUP;
 
 	/* Set KX4/KX support according to speed requested */
 	else if (link_mode == IXGBE_AUTOC_LMS_KX4_AN ||
@@ -656,11 +748,17 @@ static s32 ixgbe_setup_mac_link_82598(struct ixgbe_hw *hw,
 			IXGBE_WRITE_REG(hw, IXGBE_AUTOC, autoc);
 	}
 
-	/* Setup and restart the link based on the new values in
-	 * ixgbe_hw This will write the AUTOC register based on the new
-	 * stored values
-	 */
-	return ixgbe_start_mac_link_82598(hw, autoneg_wait_to_complete);
+	if (status == IXGBE_SUCCESS) {
+		/*
+		 * Setup and restart the link based on the new values in
+		 * ixgbe_hw This will write the AUTOC register based on the new
+		 * stored values
+		 */
+		status = ixgbe_start_mac_link_82598(hw,
+						    autoneg_wait_to_complete);
+	}
+
+	return status;
 }
 
 
@@ -672,12 +770,14 @@ static s32 ixgbe_setup_mac_link_82598(struct ixgbe_hw *hw,
  *
  *  Sets the link speed in the AUTOC register in the MAC and restarts link.
  **/
-static s32 ixgbe_setup_copper_link_82598(struct ixgbe_hw *hw,
-					       ixgbe_link_speed speed,
-					       bool autoneg_wait_to_complete)
+STATIC s32 ixgbe_setup_copper_link_82598(struct ixgbe_hw *hw,
+					 ixgbe_link_speed speed,
+					 bool autoneg_wait_to_complete)
 {
 	s32 status;
 
+	DEBUGFUNC("ixgbe_setup_copper_link_82598");
+
 	/* Setup the PHY according to input speed */
 	status = hw->phy.ops.setup_link_speed(hw, speed,
 					      autoneg_wait_to_complete);
@@ -695,20 +795,22 @@ static s32 ixgbe_setup_copper_link_82598(struct ixgbe_hw *hw,
  *  clears all interrupts, performing a PHY reset, and performing a link (MAC)
  *  reset.
  **/
-static s32 ixgbe_reset_hw_82598(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_reset_hw_82598(struct ixgbe_hw *hw)
 {
-	s32 status;
-	s32 phy_status = 0;
+	s32 status = IXGBE_SUCCESS;
+	s32 phy_status = IXGBE_SUCCESS;
 	u32 ctrl;
 	u32 gheccr;
 	u32 i;
 	u32 autoc;
 	u8  analog_val;
 
+	DEBUGFUNC("ixgbe_reset_hw_82598");
+
 	/* Call adapter stop to disable tx/rx and clear interrupts */
 	status = hw->mac.ops.stop_adapter(hw);
-	if (status)
-		return status;
+	if (status != IXGBE_SUCCESS)
+		goto reset_hw_out;
 
 	/*
 	 * Power up the Atlas Tx lanes if they are currently powered down.
@@ -750,7 +852,7 @@ static s32 ixgbe_reset_hw_82598(struct ixgbe_hw *hw)
 		/* Init PHY and function pointers, perform SFP setup */
 		phy_status = hw->phy.ops.init(hw);
 		if (phy_status == IXGBE_ERR_SFP_NOT_SUPPORTED)
-			return phy_status;
+			goto reset_hw_out;
 		if (phy_status == IXGBE_ERR_SFP_NOT_PRESENT)
 			goto mac_reset_top;
 
@@ -768,17 +870,17 @@ mac_reset_top:
 
 	/* Poll for reset bit to self-clear indicating reset is complete */
 	for (i = 0; i < 10; i++) {
-		udelay(1);
+		usec_delay(1);
 		ctrl = IXGBE_READ_REG(hw, IXGBE_CTRL);
 		if (!(ctrl & IXGBE_CTRL_RST))
 			break;
 	}
 	if (ctrl & IXGBE_CTRL_RST) {
 		status = IXGBE_ERR_RESET_FAILED;
-		hw_dbg(hw, "Reset polling failed to complete.\n");
+		DEBUGOUT("Reset polling failed to complete.\n");
 	}
 
-	msleep(50);
+	msec_delay(50);
 
 	/*
 	 * Double resets are required for recovery from certain error
@@ -816,7 +918,8 @@ mac_reset_top:
 	 */
 	hw->mac.ops.init_rx_addrs(hw);
 
-	if (phy_status)
+reset_hw_out:
+	if (phy_status != IXGBE_SUCCESS)
 		status = phy_status;
 
 	return status;
@@ -828,14 +931,16 @@ mac_reset_top:
  *  @rar: receive address register index to associate with a VMDq index
  *  @vmdq: VMDq set index
  **/
-static s32 ixgbe_set_vmdq_82598(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
+s32 ixgbe_set_vmdq_82598(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
 {
 	u32 rar_high;
 	u32 rar_entries = hw->mac.num_rar_entries;
 
+	DEBUGFUNC("ixgbe_set_vmdq_82598");
+
 	/* Make sure we are using a valid rar index range */
 	if (rar >= rar_entries) {
-		hw_dbg(hw, "RAR index %d is out of range.\n", rar);
+		DEBUGOUT1("RAR index %d is out of range.\n", rar);
 		return IXGBE_ERR_INVALID_ARGUMENT;
 	}
 
@@ -843,7 +948,7 @@ static s32 ixgbe_set_vmdq_82598(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
 	rar_high &= ~IXGBE_RAH_VIND_MASK;
 	rar_high |= ((vmdq << IXGBE_RAH_VIND_SHIFT) & IXGBE_RAH_VIND_MASK);
 	IXGBE_WRITE_REG(hw, IXGBE_RAH(rar), rar_high);
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -852,15 +957,16 @@ static s32 ixgbe_set_vmdq_82598(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
  *  @rar: receive address register index to associate with a VMDq index
  *  @vmdq: VMDq clear index (not used in 82598, but elsewhere)
  **/
-static s32 ixgbe_clear_vmdq_82598(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
+STATIC s32 ixgbe_clear_vmdq_82598(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
 {
 	u32 rar_high;
 	u32 rar_entries = hw->mac.num_rar_entries;
 
+	UNREFERENCED_1PARAMETER(vmdq);
 
 	/* Make sure we are using a valid rar index range */
 	if (rar >= rar_entries) {
-		hw_dbg(hw, "RAR index %d is out of range.\n", rar);
+		DEBUGOUT1("RAR index %d is out of range.\n", rar);
 		return IXGBE_ERR_INVALID_ARGUMENT;
 	}
 
@@ -870,7 +976,7 @@ static s32 ixgbe_clear_vmdq_82598(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
 		IXGBE_WRITE_REG(hw, IXGBE_RAH(rar), rar_high);
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -879,17 +985,22 @@ static s32 ixgbe_clear_vmdq_82598(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
  *  @vlan: VLAN id to write to VLAN filter
  *  @vind: VMDq output index that maps queue to VLAN id in VFTA
  *  @vlan_on: boolean flag to turn on/off VLAN in VFTA
+ *  @vlvf_bypass: boolean flag - unused
  *
  *  Turn on/off specified VLAN in the VLAN filter table.
  **/
-static s32 ixgbe_set_vfta_82598(struct ixgbe_hw *hw, u32 vlan, u32 vind,
-				bool vlan_on)
+s32 ixgbe_set_vfta_82598(struct ixgbe_hw *hw, u32 vlan, u32 vind,
+			 bool vlan_on, bool vlvf_bypass)
 {
 	u32 regindex;
 	u32 bitindex;
 	u32 bits;
 	u32 vftabyte;
 
+	UNREFERENCED_1PARAMETER(vlvf_bypass);
+
+	DEBUGFUNC("ixgbe_set_vfta_82598");
+
 	if (vlan > 4095)
 		return IXGBE_ERR_PARAM;
 
@@ -918,7 +1029,7 @@ static s32 ixgbe_set_vfta_82598(struct ixgbe_hw *hw, u32 vlan, u32 vind,
 		bits &= ~(1 << bitindex);
 	IXGBE_WRITE_REG(hw, IXGBE_VFTA(regindex), bits);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -927,11 +1038,13 @@ static s32 ixgbe_set_vfta_82598(struct ixgbe_hw *hw, u32 vlan, u32 vind,
  *
  *  Clears the VLAN filer table, and the VMDq index associated with the filter
  **/
-static s32 ixgbe_clear_vfta_82598(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_clear_vfta_82598(struct ixgbe_hw *hw)
 {
 	u32 offset;
 	u32 vlanbyte;
 
+	DEBUGFUNC("ixgbe_clear_vfta_82598");
+
 	for (offset = 0; offset < hw->mac.vft_size; offset++)
 		IXGBE_WRITE_REG(hw, IXGBE_VFTA(offset), 0);
 
@@ -940,7 +1053,7 @@ static s32 ixgbe_clear_vfta_82598(struct ixgbe_hw *hw)
 			IXGBE_WRITE_REG(hw, IXGBE_VFTAVIND(vlanbyte, offset),
 					0);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -951,18 +1064,20 @@ static s32 ixgbe_clear_vfta_82598(struct ixgbe_hw *hw)
  *
  *  Performs read operation to Atlas analog register specified.
  **/
-static s32 ixgbe_read_analog_reg8_82598(struct ixgbe_hw *hw, u32 reg, u8 *val)
+s32 ixgbe_read_analog_reg8_82598(struct ixgbe_hw *hw, u32 reg, u8 *val)
 {
 	u32  atlas_ctl;
 
+	DEBUGFUNC("ixgbe_read_analog_reg8_82598");
+
 	IXGBE_WRITE_REG(hw, IXGBE_ATLASCTL,
 			IXGBE_ATLASCTL_WRITE_CMD | (reg << 8));
 	IXGBE_WRITE_FLUSH(hw);
-	udelay(10);
+	usec_delay(10);
 	atlas_ctl = IXGBE_READ_REG(hw, IXGBE_ATLASCTL);
 	*val = (u8)atlas_ctl;
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -973,16 +1088,18 @@ static s32 ixgbe_read_analog_reg8_82598(struct ixgbe_hw *hw, u32 reg, u8 *val)
  *
  *  Performs write operation to Atlas analog register specified.
  **/
-static s32 ixgbe_write_analog_reg8_82598(struct ixgbe_hw *hw, u32 reg, u8 val)
+s32 ixgbe_write_analog_reg8_82598(struct ixgbe_hw *hw, u32 reg, u8 val)
 {
 	u32  atlas_ctl;
 
+	DEBUGFUNC("ixgbe_write_analog_reg8_82598");
+
 	atlas_ctl = (reg << 8) | val;
 	IXGBE_WRITE_REG(hw, IXGBE_ATLASCTL, atlas_ctl);
 	IXGBE_WRITE_FLUSH(hw);
-	udelay(10);
+	usec_delay(10);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -992,60 +1109,62 @@ static s32 ixgbe_write_analog_reg8_82598(struct ixgbe_hw *hw, u32 reg, u8 val)
  *  @byte_offset: byte offset to read from dev_addr
  *  @eeprom_data: value read
  *
- *  Performs 8 byte read operation to SFP module's data over I2C interface.
+ *  Performs 8 byte read operation to SFP module's EEPROM over I2C interface.
  **/
-static s32 ixgbe_read_i2c_phy_82598(struct ixgbe_hw *hw, u8 dev_addr,
+STATIC s32 ixgbe_read_i2c_phy_82598(struct ixgbe_hw *hw, u8 dev_addr,
 				    u8 byte_offset, u8 *eeprom_data)
 {
-	s32 status = 0;
+	s32 status = IXGBE_SUCCESS;
 	u16 sfp_addr = 0;
 	u16 sfp_data = 0;
 	u16 sfp_stat = 0;
 	u16 gssr;
 	u32 i;
 
+	DEBUGFUNC("ixgbe_read_i2c_phy_82598");
+
 	if (IXGBE_READ_REG(hw, IXGBE_STATUS) & IXGBE_STATUS_LAN_ID_1)
 		gssr = IXGBE_GSSR_PHY1_SM;
 	else
 		gssr = IXGBE_GSSR_PHY0_SM;
 
-	if (hw->mac.ops.acquire_swfw_sync(hw, gssr) != 0)
+	if (hw->mac.ops.acquire_swfw_sync(hw, gssr) != IXGBE_SUCCESS)
 		return IXGBE_ERR_SWFW_SYNC;
 
 	if (hw->phy.type == ixgbe_phy_nl) {
 		/*
-		 * phy SDA/SCL registers are at addresses 0xC30A to
-		 * 0xC30D.  These registers are used to talk to the SFP+
+		 * NetLogic phy SDA/SCL registers are at addresses 0xC30A to
+		 * 0xC30D. These registers are used to talk to the SFP+
 		 * module's EEPROM through the SDA/SCL (I2C) interface.
 		 */
 		sfp_addr = (dev_addr << 8) + byte_offset;
 		sfp_addr = (sfp_addr | IXGBE_I2C_EEPROM_READ_MASK);
 		hw->phy.ops.write_reg_mdi(hw,
 					  IXGBE_MDIO_PMA_PMD_SDA_SCL_ADDR,
-					  MDIO_MMD_PMAPMD,
+					  IXGBE_MDIO_PMA_PMD_DEV_TYPE,
 					  sfp_addr);
 
 		/* Poll status */
 		for (i = 0; i < 100; i++) {
 			hw->phy.ops.read_reg_mdi(hw,
 						IXGBE_MDIO_PMA_PMD_SDA_SCL_STAT,
-						MDIO_MMD_PMAPMD,
+						IXGBE_MDIO_PMA_PMD_DEV_TYPE,
 						&sfp_stat);
 			sfp_stat = sfp_stat & IXGBE_I2C_EEPROM_STATUS_MASK;
 			if (sfp_stat != IXGBE_I2C_EEPROM_STATUS_IN_PROGRESS)
 				break;
-			usleep_range(10000, 20000);
+			msec_delay(10);
 		}
 
 		if (sfp_stat != IXGBE_I2C_EEPROM_STATUS_PASS) {
-			hw_dbg(hw, "EEPROM read did not pass.\n");
+			DEBUGOUT("EEPROM read did not pass.\n");
 			status = IXGBE_ERR_SFP_NOT_PRESENT;
 			goto out;
 		}
 
 		/* Read data */
 		hw->phy.ops.read_reg_mdi(hw, IXGBE_MDIO_PMA_PMD_SDA_SCL_DATA,
-					MDIO_MMD_PMAPMD, &sfp_data);
+					IXGBE_MDIO_PMA_PMD_DEV_TYPE, &sfp_data);
 
 		*eeprom_data = (u8)(sfp_data >> 8);
 	} else {
@@ -1065,8 +1184,8 @@ out:
  *
  *  Performs 8 byte read operation to SFP module's EEPROM over I2C interface.
  **/
-static s32 ixgbe_read_i2c_eeprom_82598(struct ixgbe_hw *hw, u8 byte_offset,
-				       u8 *eeprom_data)
+s32 ixgbe_read_i2c_eeprom_82598(struct ixgbe_hw *hw, u8 byte_offset,
+				u8 *eeprom_data)
 {
 	return ixgbe_read_i2c_phy_82598(hw, IXGBE_I2C_EEPROM_DEV_ADDR,
 					byte_offset, eeprom_data);
@@ -1080,14 +1199,116 @@ static s32 ixgbe_read_i2c_eeprom_82598(struct ixgbe_hw *hw, u8 byte_offset,
  *
  *  Performs 8 byte read operation to SFP module's SFF-8472 data over I2C
  **/
-static s32 ixgbe_read_i2c_sff8472_82598(struct ixgbe_hw *hw, u8 byte_offset,
-				       u8 *sff8472_data)
+STATIC s32 ixgbe_read_i2c_sff8472_82598(struct ixgbe_hw *hw, u8 byte_offset,
+					u8 *sff8472_data)
 {
 	return ixgbe_read_i2c_phy_82598(hw, IXGBE_I2C_EEPROM_DEV_ADDR2,
 					byte_offset, sff8472_data);
 }
 
 /**
+ *  ixgbe_get_supported_physical_layer_82598 - Returns physical layer type
+ *  @hw: pointer to hardware structure
+ *
+ *  Determines physical layer capabilities of the current configuration.
+ **/
+u64 ixgbe_get_supported_physical_layer_82598(struct ixgbe_hw *hw)
+{
+	u64 physical_layer = IXGBE_PHYSICAL_LAYER_UNKNOWN;
+	u32 autoc = IXGBE_READ_REG(hw, IXGBE_AUTOC);
+	u32 pma_pmd_10g = autoc & IXGBE_AUTOC_10G_PMA_PMD_MASK;
+	u32 pma_pmd_1g = autoc & IXGBE_AUTOC_1G_PMA_PMD_MASK;
+	u16 ext_ability = 0;
+
+	DEBUGFUNC("ixgbe_get_supported_physical_layer_82598");
+
+	hw->phy.ops.identify(hw);
+
+	/* Copper PHY must be checked before AUTOC LMS to determine correct
+	 * physical layer because 10GBase-T PHYs use LMS = KX4/KX */
+	switch (hw->phy.type) {
+	case ixgbe_phy_tn:
+	case ixgbe_phy_cu_unknown:
+		hw->phy.ops.read_reg(hw, IXGBE_MDIO_PHY_EXT_ABILITY,
+		IXGBE_MDIO_PMA_PMD_DEV_TYPE, &ext_ability);
+		if (ext_ability & IXGBE_MDIO_PHY_10GBASET_ABILITY)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_10GBASE_T;
+		if (ext_ability & IXGBE_MDIO_PHY_1000BASET_ABILITY)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_1000BASE_T;
+		if (ext_ability & IXGBE_MDIO_PHY_100BASETX_ABILITY)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_100BASE_TX;
+		goto out;
+	default:
+		break;
+	}
+
+	switch (autoc & IXGBE_AUTOC_LMS_MASK) {
+	case IXGBE_AUTOC_LMS_1G_AN:
+	case IXGBE_AUTOC_LMS_1G_LINK_NO_AN:
+		if (pma_pmd_1g == IXGBE_AUTOC_1G_KX)
+			physical_layer = IXGBE_PHYSICAL_LAYER_1000BASE_KX;
+		else
+			physical_layer = IXGBE_PHYSICAL_LAYER_1000BASE_BX;
+		break;
+	case IXGBE_AUTOC_LMS_10G_LINK_NO_AN:
+		if (pma_pmd_10g == IXGBE_AUTOC_10G_CX4)
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_CX4;
+		else if (pma_pmd_10g == IXGBE_AUTOC_10G_KX4)
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_KX4;
+		else /* XAUI */
+			physical_layer = IXGBE_PHYSICAL_LAYER_UNKNOWN;
+		break;
+	case IXGBE_AUTOC_LMS_KX4_AN:
+	case IXGBE_AUTOC_LMS_KX4_AN_1G_AN:
+		if (autoc & IXGBE_AUTOC_KX_SUPP)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_1000BASE_KX;
+		if (autoc & IXGBE_AUTOC_KX4_SUPP)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_10GBASE_KX4;
+		break;
+	default:
+		break;
+	}
+
+	if (hw->phy.type == ixgbe_phy_nl) {
+		hw->phy.ops.identify_sfp(hw);
+
+		switch (hw->phy.sfp_type) {
+		case ixgbe_sfp_type_da_cu:
+			physical_layer = IXGBE_PHYSICAL_LAYER_SFP_PLUS_CU;
+			break;
+		case ixgbe_sfp_type_sr:
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_SR;
+			break;
+		case ixgbe_sfp_type_lr:
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_LR;
+			break;
+		default:
+			physical_layer = IXGBE_PHYSICAL_LAYER_UNKNOWN;
+			break;
+		}
+	}
+
+	switch (hw->device_id) {
+	case IXGBE_DEV_ID_82598_DA_DUAL_PORT:
+		physical_layer = IXGBE_PHYSICAL_LAYER_SFP_PLUS_CU;
+		break;
+	case IXGBE_DEV_ID_82598AF_DUAL_PORT:
+	case IXGBE_DEV_ID_82598AF_SINGLE_PORT:
+	case IXGBE_DEV_ID_82598_SR_DUAL_PORT_EM:
+		physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_SR;
+		break;
+	case IXGBE_DEV_ID_82598EB_XF_LR:
+		physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_LR;
+		break;
+	default:
+		break;
+	}
+
+out:
+	return physical_layer;
+}
+
+/**
  *  ixgbe_set_lan_id_multi_port_pcie_82598 - Set LAN id for PCIe multiple
  *  port devices.
  *  @hw: pointer to the HW structure
@@ -1095,12 +1316,14 @@ static s32 ixgbe_read_i2c_sff8472_82598(struct ixgbe_hw *hw, u8 byte_offset,
  *  Calls common function and corrects issue with some single port devices
  *  that enable LAN1 but not LAN0.
  **/
-static void ixgbe_set_lan_id_multi_port_pcie_82598(struct ixgbe_hw *hw)
+void ixgbe_set_lan_id_multi_port_pcie_82598(struct ixgbe_hw *hw)
 {
 	struct ixgbe_bus_info *bus = &hw->bus;
 	u16 pci_gen = 0;
 	u16 pci_ctrl2 = 0;
 
+	DEBUGFUNC("ixgbe_set_lan_id_multi_port_pcie_82598");
+
 	ixgbe_set_lan_id_multi_port_pcie(hw);
 
 	/* check if LAN0 is disabled */
@@ -1126,11 +1349,12 @@ static void ixgbe_set_lan_id_multi_port_pcie_82598(struct ixgbe_hw *hw)
  * @headroom: reserve n KB of headroom
  * @strategy: packet buffer allocation strategy
  **/
-static void ixgbe_set_rxpba_82598(struct ixgbe_hw *hw, int num_pb,
+STATIC void ixgbe_set_rxpba_82598(struct ixgbe_hw *hw, int num_pb,
 				  u32 headroom, int strategy)
 {
 	u32 rxpktsize = IXGBE_RXPBSIZE_64KB;
-	u8  i = 0;
+	u8 i = 0;
+	UNREFERENCED_1PARAMETER(headroom);
 
 	if (!num_pb)
 		return;
@@ -1158,81 +1382,18 @@ static void ixgbe_set_rxpba_82598(struct ixgbe_hw *hw, int num_pb,
 		IXGBE_WRITE_REG(hw, IXGBE_TXPBSIZE(i), IXGBE_TXPBSIZE_40KB);
 }
 
-static struct ixgbe_mac_operations mac_ops_82598 = {
-	.init_hw		= &ixgbe_init_hw_generic,
-	.reset_hw		= &ixgbe_reset_hw_82598,
-	.start_hw		= &ixgbe_start_hw_82598,
-	.clear_hw_cntrs		= &ixgbe_clear_hw_cntrs_generic,
-	.get_media_type		= &ixgbe_get_media_type_82598,
-	.enable_rx_dma          = &ixgbe_enable_rx_dma_generic,
-	.get_mac_addr		= &ixgbe_get_mac_addr_generic,
-	.stop_adapter		= &ixgbe_stop_adapter_generic,
-	.get_bus_info           = &ixgbe_get_bus_info_generic,
-	.set_lan_id             = &ixgbe_set_lan_id_multi_port_pcie_82598,
-	.read_analog_reg8	= &ixgbe_read_analog_reg8_82598,
-	.write_analog_reg8	= &ixgbe_write_analog_reg8_82598,
-	.setup_link		= &ixgbe_setup_mac_link_82598,
-	.set_rxpba		= &ixgbe_set_rxpba_82598,
-	.check_link		= &ixgbe_check_mac_link_82598,
-	.get_link_capabilities	= &ixgbe_get_link_capabilities_82598,
-	.led_on			= &ixgbe_led_on_generic,
-	.led_off		= &ixgbe_led_off_generic,
-	.blink_led_start	= &ixgbe_blink_led_start_generic,
-	.blink_led_stop		= &ixgbe_blink_led_stop_generic,
-	.set_rar		= &ixgbe_set_rar_generic,
-	.clear_rar		= &ixgbe_clear_rar_generic,
-	.set_vmdq		= &ixgbe_set_vmdq_82598,
-	.clear_vmdq		= &ixgbe_clear_vmdq_82598,
-	.init_rx_addrs		= &ixgbe_init_rx_addrs_generic,
-	.update_mc_addr_list	= &ixgbe_update_mc_addr_list_generic,
-	.enable_mc		= &ixgbe_enable_mc_generic,
-	.disable_mc		= &ixgbe_disable_mc_generic,
-	.clear_vfta		= &ixgbe_clear_vfta_82598,
-	.set_vfta		= &ixgbe_set_vfta_82598,
-	.fc_enable		= &ixgbe_fc_enable_82598,
-	.set_fw_drv_ver         = NULL,
-	.acquire_swfw_sync      = &ixgbe_acquire_swfw_sync,
-	.release_swfw_sync      = &ixgbe_release_swfw_sync,
-	.get_thermal_sensor_data = NULL,
-	.init_thermal_sensor_thresh = NULL,
-	.prot_autoc_read	= &prot_autoc_read_generic,
-	.prot_autoc_write	= &prot_autoc_write_generic,
-	.enable_rx		= &ixgbe_enable_rx_generic,
-	.disable_rx		= &ixgbe_disable_rx_generic,
-};
-
-static struct ixgbe_eeprom_operations eeprom_ops_82598 = {
-	.init_params		= &ixgbe_init_eeprom_params_generic,
-	.read			= &ixgbe_read_eerd_generic,
-	.write			= &ixgbe_write_eeprom_generic,
-	.write_buffer		= &ixgbe_write_eeprom_buffer_bit_bang_generic,
-	.read_buffer		= &ixgbe_read_eerd_buffer_generic,
-	.calc_checksum          = &ixgbe_calc_eeprom_checksum_generic,
-	.validate_checksum	= &ixgbe_validate_eeprom_checksum_generic,
-	.update_checksum	= &ixgbe_update_eeprom_checksum_generic,
-};
-
-static struct ixgbe_phy_operations phy_ops_82598 = {
-	.identify		= &ixgbe_identify_phy_generic,
-	.identify_sfp		= &ixgbe_identify_module_generic,
-	.init			= &ixgbe_init_phy_ops_82598,
-	.reset			= &ixgbe_reset_phy_generic,
-	.read_reg		= &ixgbe_read_phy_reg_generic,
-	.write_reg		= &ixgbe_write_phy_reg_generic,
-	.read_reg_mdi		= &ixgbe_read_phy_reg_mdi,
-	.write_reg_mdi		= &ixgbe_write_phy_reg_mdi,
-	.setup_link		= &ixgbe_setup_phy_link_generic,
-	.setup_link_speed	= &ixgbe_setup_phy_link_speed_generic,
-	.read_i2c_sff8472	= &ixgbe_read_i2c_sff8472_82598,
-	.read_i2c_eeprom	= &ixgbe_read_i2c_eeprom_82598,
-	.check_overtemp		= &ixgbe_tn_check_overtemp,
-};
-
-struct ixgbe_info ixgbe_82598_info = {
-	.mac			= ixgbe_mac_82598EB,
-	.get_invariants		= &ixgbe_get_invariants_82598,
-	.mac_ops		= &mac_ops_82598,
-	.eeprom_ops		= &eeprom_ops_82598,
-	.phy_ops		= &phy_ops_82598,
-	.mvals			= ixgbe_mvals_8259X,
-};
+/**
+ *  ixgbe_enable_rx_dma_82598 - Enable the Rx DMA unit
+ *  @hw: pointer to hardware structure
+ *  @regval: register value to write to RXCTRL
+ *
+ *  Enables the Rx DMA unit
+ **/
+s32 ixgbe_enable_rx_dma_82598(struct ixgbe_hw *hw, u32 regval)
+{
+	DEBUGFUNC("ixgbe_enable_rx_dma_82598");
+
+	IXGBE_WRITE_REG(hw, IXGBE_RXCTRL, regval);
+
+	return IXGBE_SUCCESS;
+}
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_82598.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_82598.h
new file mode 100644
index 00000000..1e0c15a
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_82598.h
@@ -0,0 +1,43 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#ifndef _IXGBE_82598_H_
+#define _IXGBE_82598_H_
+
+u32 ixgbe_get_pcie_msix_count_82598(struct ixgbe_hw *hw);
+s32 ixgbe_fc_enable_82598(struct ixgbe_hw *hw);
+s32 ixgbe_start_hw_82598(struct ixgbe_hw *hw);
+s32 ixgbe_set_vmdq_82598(struct ixgbe_hw *hw, u32 rar, u32 vmdq);
+s32 ixgbe_set_vfta_82598(struct ixgbe_hw *hw, u32 vlan, u32 vind, bool vlan_on,
+			 bool vlvf_bypass);
+s32 ixgbe_read_analog_reg8_82598(struct ixgbe_hw *hw, u32 reg, u8 *val);
+s32 ixgbe_write_analog_reg8_82598(struct ixgbe_hw *hw, u32 reg, u8 val);
+s32 ixgbe_read_i2c_eeprom_82598(struct ixgbe_hw *hw, u8 byte_offset,
+				u8 *eeprom_data);
+u64 ixgbe_get_supported_physical_layer_82598(struct ixgbe_hw *hw);
+s32 ixgbe_init_phy_ops_82598(struct ixgbe_hw *hw);
+void ixgbe_set_lan_id_multi_port_pcie_82598(struct ixgbe_hw *hw);
+void ixgbe_set_pcie_completion_timeout(struct ixgbe_hw *hw);
+s32 ixgbe_enable_rx_dma_82598(struct ixgbe_hw *hw, u32 regval);
+#endif /* _IXGBE_82598_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_82599.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_82599.c
index a39afcf..0164233 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_82599.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_82599.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2015 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,13 +22,11 @@
 
 *******************************************************************************/
 
-#include <linux/pci.h>
-#include <linux/delay.h>
-#include <linux/sched.h>
-
-#include "ixgbe.h"
+#include "ixgbe_type.h"
+#include "ixgbe_82599.h"
+#include "ixgbe_api.h"
+#include "ixgbe_common.h"
 #include "ixgbe_phy.h"
-#include "ixgbe_mbx.h"
 
 #define IXGBE_82599_MAX_TX_QUEUES 128
 #define IXGBE_82599_MAX_RX_QUEUES 128
@@ -41,64 +35,37 @@
 #define IXGBE_82599_VFT_TBL_SIZE  128
 #define IXGBE_82599_RX_PB_SIZE	  512
 
-static void ixgbe_disable_tx_laser_multispeed_fiber(struct ixgbe_hw *hw);
-static void ixgbe_enable_tx_laser_multispeed_fiber(struct ixgbe_hw *hw);
-static void ixgbe_flap_tx_laser_multispeed_fiber(struct ixgbe_hw *hw);
-static void
-ixgbe_set_hard_rate_select_speed(struct ixgbe_hw *, ixgbe_link_speed);
-static s32 ixgbe_setup_mac_link_smartspeed(struct ixgbe_hw *hw,
-					   ixgbe_link_speed speed,
-					   bool autoneg_wait_to_complete);
-static void ixgbe_stop_mac_link_on_d3_82599(struct ixgbe_hw *hw);
-static s32 ixgbe_start_mac_link_82599(struct ixgbe_hw *hw,
-				      bool autoneg_wait_to_complete);
-static s32 ixgbe_setup_mac_link_82599(struct ixgbe_hw *hw,
-			       ixgbe_link_speed speed,
-			       bool autoneg_wait_to_complete);
-static s32 ixgbe_setup_copper_link_82599(struct ixgbe_hw *hw,
+STATIC s32 ixgbe_setup_copper_link_82599(struct ixgbe_hw *hw,
 					 ixgbe_link_speed speed,
 					 bool autoneg_wait_to_complete);
-static s32 ixgbe_verify_fw_version_82599(struct ixgbe_hw *hw);
-static s32 ixgbe_read_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
-				     u8 dev_addr, u8 *data);
-static s32 ixgbe_write_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
-				      u8 dev_addr, u8 data);
-static s32 ixgbe_reset_pipeline_82599(struct ixgbe_hw *hw);
-static bool ixgbe_verify_lesm_fw_enabled_82599(struct ixgbe_hw *hw);
-
-bool ixgbe_mng_enabled(struct ixgbe_hw *hw)
-{
-	u32 fwsm, manc, factps;
-
-	fwsm = IXGBE_READ_REG(hw, IXGBE_FWSM(hw));
-	if ((fwsm & IXGBE_FWSM_MODE_MASK) != IXGBE_FWSM_FW_MODE_PT)
-		return false;
-
-	manc = IXGBE_READ_REG(hw, IXGBE_MANC);
-	if (!(manc & IXGBE_MANC_RCV_TCO_EN))
-		return false;
-
-	factps = IXGBE_READ_REG(hw, IXGBE_FACTPS(hw));
-	if (factps & IXGBE_FACTPS_MNGCG)
-		return false;
-
-	return true;
-}
-
-static void ixgbe_init_mac_link_ops_82599(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_verify_fw_version_82599(struct ixgbe_hw *hw);
+STATIC s32 ixgbe_read_eeprom_82599(struct ixgbe_hw *hw,
+				   u16 offset, u16 *data);
+STATIC s32 ixgbe_read_eeprom_buffer_82599(struct ixgbe_hw *hw, u16 offset,
+					  u16 words, u16 *data);
+STATIC s32 ixgbe_read_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
+					u8 dev_addr, u8 *data);
+STATIC s32 ixgbe_write_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
+					u8 dev_addr, u8 data);
+
+void ixgbe_init_mac_link_ops_82599(struct ixgbe_hw *hw)
 {
 	struct ixgbe_mac_info *mac = &hw->mac;
 
-	/* enable the laser control functions for SFP+ fiber
+	DEBUGFUNC("ixgbe_init_mac_link_ops_82599");
+
+	/*
+	 * enable the laser control functions for SFP+ fiber
 	 * and MNG not enabled
 	 */
 	if ((mac->ops.get_media_type(hw) == ixgbe_media_type_fiber) &&
 	    !ixgbe_mng_enabled(hw)) {
 		mac->ops.disable_tx_laser =
-				       &ixgbe_disable_tx_laser_multispeed_fiber;
+				       ixgbe_disable_tx_laser_multispeed_fiber;
 		mac->ops.enable_tx_laser =
-					&ixgbe_enable_tx_laser_multispeed_fiber;
-		mac->ops.flap_tx_laser = &ixgbe_flap_tx_laser_multispeed_fiber;
+					ixgbe_enable_tx_laser_multispeed_fiber;
+		mac->ops.flap_tx_laser = ixgbe_flap_tx_laser_multispeed_fiber;
+
 	} else {
 		mac->ops.disable_tx_laser = NULL;
 		mac->ops.enable_tx_laser = NULL;
@@ -107,27 +74,96 @@ static void ixgbe_init_mac_link_ops_82599(struct ixgbe_hw *hw)
 
 	if (hw->phy.multispeed_fiber) {
 		/* Set up dual speed SFP+ support */
-		mac->ops.setup_link = &ixgbe_setup_mac_link_multispeed_fiber;
+		mac->ops.setup_link = ixgbe_setup_mac_link_multispeed_fiber;
 		mac->ops.setup_mac_link = ixgbe_setup_mac_link_82599;
 		mac->ops.set_rate_select_speed =
 					       ixgbe_set_hard_rate_select_speed;
 	} else {
-		if ((mac->ops.get_media_type(hw) ==
-		     ixgbe_media_type_backplane) &&
-		    (hw->phy.smart_speed == ixgbe_smart_speed_auto ||
-		     hw->phy.smart_speed == ixgbe_smart_speed_on) &&
-		     !ixgbe_verify_lesm_fw_enabled_82599(hw))
-			mac->ops.setup_link = &ixgbe_setup_mac_link_smartspeed;
-		else
-			mac->ops.setup_link = &ixgbe_setup_mac_link_82599;
+		if ((ixgbe_get_media_type(hw) == ixgbe_media_type_backplane) &&
+		     (hw->phy.smart_speed == ixgbe_smart_speed_auto ||
+		      hw->phy.smart_speed == ixgbe_smart_speed_on) &&
+		      !ixgbe_verify_lesm_fw_enabled_82599(hw)) {
+			mac->ops.setup_link = ixgbe_setup_mac_link_smartspeed;
+		} else {
+			mac->ops.setup_link = ixgbe_setup_mac_link_82599;
+		}
 	}
 }
 
-static s32 ixgbe_setup_sfp_modules_82599(struct ixgbe_hw *hw)
+/**
+ *  ixgbe_init_phy_ops_82599 - PHY/SFP specific init
+ *  @hw: pointer to hardware structure
+ *
+ *  Initialize any function pointers that were not able to be
+ *  set during init_shared_code because the PHY/SFP type was
+ *  not known.  Perform the SFP init if necessary.
+ *
+ **/
+s32 ixgbe_init_phy_ops_82599(struct ixgbe_hw *hw)
 {
-	s32 ret_val;
+	struct ixgbe_mac_info *mac = &hw->mac;
+	struct ixgbe_phy_info *phy = &hw->phy;
+	s32 ret_val = IXGBE_SUCCESS;
+	u32 esdp;
+
+	DEBUGFUNC("ixgbe_init_phy_ops_82599");
+
+	if (hw->device_id == IXGBE_DEV_ID_82599_QSFP_SF_QP) {
+		/* Store flag indicating I2C bus access control unit. */
+		hw->phy.qsfp_shared_i2c_bus = TRUE;
+
+		/* Initialize access to QSFP+ I2C bus */
+		esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
+		esdp |= IXGBE_ESDP_SDP0_DIR;
+		esdp &= ~IXGBE_ESDP_SDP1_DIR;
+		esdp &= ~IXGBE_ESDP_SDP0;
+		esdp &= ~IXGBE_ESDP_SDP0_NATIVE;
+		esdp &= ~IXGBE_ESDP_SDP1_NATIVE;
+		IXGBE_WRITE_REG(hw, IXGBE_ESDP, esdp);
+		IXGBE_WRITE_FLUSH(hw);
+
+		phy->ops.read_i2c_byte = ixgbe_read_i2c_byte_82599;
+		phy->ops.write_i2c_byte = ixgbe_write_i2c_byte_82599;
+	}
+	/* Identify the PHY or SFP module */
+	ret_val = phy->ops.identify(hw);
+	if (ret_val == IXGBE_ERR_SFP_NOT_SUPPORTED)
+		goto init_phy_ops_out;
+
+	/* Setup function pointers based on detected SFP module and speeds */
+	ixgbe_init_mac_link_ops_82599(hw);
+	if (hw->phy.sfp_type != ixgbe_sfp_type_unknown)
+		hw->phy.ops.reset = NULL;
+
+	/* If copper media, overwrite with copper function pointers */
+	if (mac->ops.get_media_type(hw) == ixgbe_media_type_copper) {
+		mac->ops.setup_link = ixgbe_setup_copper_link_82599;
+		mac->ops.get_link_capabilities =
+				  ixgbe_get_copper_link_capabilities_generic;
+	}
+
+	/* Set necessary function pointers based on PHY type */
+	switch (hw->phy.type) {
+	case ixgbe_phy_tn:
+		phy->ops.setup_link = ixgbe_setup_phy_link_tnx;
+		phy->ops.check_link = ixgbe_check_phy_link_tnx;
+		phy->ops.get_firmware_version =
+			     ixgbe_get_phy_firmware_version_tnx;
+		break;
+	default:
+		break;
+	}
+init_phy_ops_out:
+	return ret_val;
+}
+
+s32 ixgbe_setup_sfp_modules_82599(struct ixgbe_hw *hw)
+{
+	s32 ret_val = IXGBE_SUCCESS;
 	u16 list_offset, data_offset, data_value;
 
+	DEBUGFUNC("ixgbe_setup_sfp_modules_82599");
+
 	if (hw->phy.sfp_type != ixgbe_sfp_type_unknown) {
 		ixgbe_init_mac_link_ops_82599(hw);
 
@@ -135,14 +171,16 @@ static s32 ixgbe_setup_sfp_modules_82599(struct ixgbe_hw *hw)
 
 		ret_val = ixgbe_get_sfp_init_sequence_offsets(hw, &list_offset,
 							      &data_offset);
-		if (ret_val)
-			return ret_val;
+		if (ret_val != IXGBE_SUCCESS)
+			goto setup_sfp_out;
 
 		/* PHY config will finish before releasing the semaphore */
 		ret_val = hw->mac.ops.acquire_swfw_sync(hw,
 							IXGBE_GSSR_MAC_CSR_SM);
-		if (ret_val)
-			return IXGBE_ERR_SWFW_SYNC;
+		if (ret_val != IXGBE_SUCCESS) {
+			ret_val = IXGBE_ERR_SWFW_SYNC;
+			goto setup_sfp_out;
+		}
 
 		if (hw->eeprom.ops.read(hw, ++data_offset, &data_value))
 			goto setup_sfp_err;
@@ -155,12 +193,10 @@ static s32 ixgbe_setup_sfp_modules_82599(struct ixgbe_hw *hw)
 
 		/* Release the semaphore */
 		hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_MAC_CSR_SM);
-		/*
-		 * Delay obtaining semaphore again to allow FW access,
-		 * semaphore_delay is in ms usleep_range needs us.
+		/* Delay obtaining semaphore again to allow FW access
+		 * prot_autoc_write uses the semaphore too.
 		 */
-		usleep_range(hw->eeprom.semaphore_delay * 1000,
-			     hw->eeprom.semaphore_delay * 2000);
+		msec_delay(hw->eeprom.semaphore_delay);
 
 		/* Restart DSP and set SFI mode */
 		ret_val = hw->mac.ops.prot_autoc_write(hw,
@@ -168,23 +204,24 @@ static s32 ixgbe_setup_sfp_modules_82599(struct ixgbe_hw *hw)
 			false);
 
 		if (ret_val) {
-			hw_dbg(hw, " sfp module setup not complete\n");
-			return IXGBE_ERR_SFP_SETUP_NOT_COMPLETE;
+			DEBUGOUT("sfp module setup not complete\n");
+			ret_val = IXGBE_ERR_SFP_SETUP_NOT_COMPLETE;
+			goto setup_sfp_out;
 		}
+
 	}
 
-	return 0;
+setup_sfp_out:
+	return ret_val;
 
 setup_sfp_err:
 	/* Release the semaphore */
 	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_MAC_CSR_SM);
-	/* Delay obtaining semaphore again to allow FW access,
-	 * semaphore_delay is in ms usleep_range needs us.
-	 */
-	usleep_range(hw->eeprom.semaphore_delay * 1000,
-		     hw->eeprom.semaphore_delay * 2000);
-	hw_err(hw, "eeprom read at offset %d failed\n", data_offset);
-	return IXGBE_ERR_SFP_SETUP_NOT_COMPLETE;
+	/* Delay obtaining semaphore again to allow FW access */
+	msec_delay(hw->eeprom.semaphore_delay);
+	ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+		      "eeprom read at offset %d failed", data_offset);
+	return IXGBE_ERR_PHY;
 }
 
 /**
@@ -195,27 +232,25 @@ setup_sfp_err:
  *
  *  For this part (82599) we need to wrap read-modify-writes with a possible
  *  FW/SW lock.  It is assumed this lock will be freed with the next
- *  prot_autoc_write_82599().  Note, that locked can only be true in cases
- *  where this function doesn't return an error.
- **/
-static s32 prot_autoc_read_82599(struct ixgbe_hw *hw, bool *locked,
-				 u32 *reg_val)
+ *  prot_autoc_write_82599().
+ */
+s32 prot_autoc_read_82599(struct ixgbe_hw *hw, bool *locked, u32 *reg_val)
 {
 	s32 ret_val;
 
 	*locked = false;
-	/* If LESM is on then we need to hold the SW/FW semaphore. */
+	 /* If LESM is on then we need to hold the SW/FW semaphore. */
 	if (ixgbe_verify_lesm_fw_enabled_82599(hw)) {
 		ret_val = hw->mac.ops.acquire_swfw_sync(hw,
 					IXGBE_GSSR_MAC_CSR_SM);
-		if (ret_val)
+		if (ret_val != IXGBE_SUCCESS)
 			return IXGBE_ERR_SWFW_SYNC;
 
 		*locked = true;
 	}
 
 	*reg_val = IXGBE_READ_REG(hw, IXGBE_AUTOC);
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -223,14 +258,14 @@ static s32 prot_autoc_read_82599(struct ixgbe_hw *hw, bool *locked,
  * @hw: pointer to hardware structure
  * @reg_val: value to write to AUTOC
  * @locked: bool to indicate whether the SW/FW lock was already taken by
- *	     previous proc_autoc_read_82599.
+ *           previous proc_autoc_read_82599.
  *
- * This part (82599) may need to hold a the SW/FW lock around all writes to
+ * This part (82599) may need to hold the SW/FW lock around all writes to
  * AUTOC. Likewise after a write we need to do a pipeline reset.
- **/
-static s32 prot_autoc_write_82599(struct ixgbe_hw *hw, u32 autoc, bool locked)
+ */
+s32 prot_autoc_write_82599(struct ixgbe_hw *hw, u32 autoc, bool locked)
 {
-	s32 ret_val = 0;
+	s32 ret_val = IXGBE_SUCCESS;
 
 	/* Blocked by MNG FW so bail */
 	if (ixgbe_check_reset_blocked(hw))
@@ -243,7 +278,7 @@ static s32 prot_autoc_write_82599(struct ixgbe_hw *hw, u32 autoc, bool locked)
 	if (!locked && ixgbe_verify_lesm_fw_enabled_82599(hw)) {
 		ret_val = hw->mac.ops.acquire_swfw_sync(hw,
 					IXGBE_GSSR_MAC_CSR_SM);
-		if (ret_val)
+		if (ret_val != IXGBE_SUCCESS)
 			return IXGBE_ERR_SWFW_SYNC;
 
 		locked = true;
@@ -262,81 +297,95 @@ out:
 	return ret_val;
 }
 
-static s32 ixgbe_get_invariants_82599(struct ixgbe_hw *hw)
-{
-	struct ixgbe_mac_info *mac = &hw->mac;
-
-	ixgbe_init_mac_link_ops_82599(hw);
-
-	mac->mcft_size = IXGBE_82599_MC_TBL_SIZE;
-	mac->vft_size = IXGBE_82599_VFT_TBL_SIZE;
-	mac->num_rar_entries = IXGBE_82599_RAR_ENTRIES;
-	mac->rx_pb_size = IXGBE_82599_RX_PB_SIZE;
-	mac->max_rx_queues = IXGBE_82599_MAX_RX_QUEUES;
-	mac->max_tx_queues = IXGBE_82599_MAX_TX_QUEUES;
-	mac->max_msix_vectors = ixgbe_get_pcie_msix_count_generic(hw);
-
-	return 0;
-}
-
 /**
- *  ixgbe_init_phy_ops_82599 - PHY/SFP specific init
+ *  ixgbe_init_ops_82599 - Inits func ptrs and MAC type
  *  @hw: pointer to hardware structure
  *
- *  Initialize any function pointers that were not able to be
- *  set during get_invariants because the PHY/SFP type was
- *  not known.  Perform the SFP init if necessary.
- *
+ *  Initialize the function pointers and assign the MAC type for 82599.
+ *  Does not touch the hardware.
  **/
-static s32 ixgbe_init_phy_ops_82599(struct ixgbe_hw *hw)
+
+s32 ixgbe_init_ops_82599(struct ixgbe_hw *hw)
 {
 	struct ixgbe_mac_info *mac = &hw->mac;
 	struct ixgbe_phy_info *phy = &hw->phy;
+	struct ixgbe_eeprom_info *eeprom = &hw->eeprom;
 	s32 ret_val;
-	u32 esdp;
 
-	if (hw->device_id == IXGBE_DEV_ID_82599_QSFP_SF_QP) {
-		/* Store flag indicating I2C bus access control unit. */
-		hw->phy.qsfp_shared_i2c_bus = true;
+	DEBUGFUNC("ixgbe_init_ops_82599");
+
+	ixgbe_init_phy_ops_generic(hw);
+	ret_val = ixgbe_init_ops_generic(hw);
+
+	/* PHY */
+	phy->ops.identify = ixgbe_identify_phy_82599;
+	phy->ops.init = ixgbe_init_phy_ops_82599;
+
+	/* MAC */
+	mac->ops.reset_hw = ixgbe_reset_hw_82599;
+	mac->ops.get_media_type = ixgbe_get_media_type_82599;
+	mac->ops.get_supported_physical_layer =
+				    ixgbe_get_supported_physical_layer_82599;
+	mac->ops.disable_sec_rx_path = ixgbe_disable_sec_rx_path_generic;
+	mac->ops.enable_sec_rx_path = ixgbe_enable_sec_rx_path_generic;
+	mac->ops.enable_rx_dma = ixgbe_enable_rx_dma_82599;
+	mac->ops.read_analog_reg8 = ixgbe_read_analog_reg8_82599;
+	mac->ops.write_analog_reg8 = ixgbe_write_analog_reg8_82599;
+	mac->ops.start_hw = ixgbe_start_hw_82599;
+	mac->ops.get_san_mac_addr = ixgbe_get_san_mac_addr_generic;
+	mac->ops.set_san_mac_addr = ixgbe_set_san_mac_addr_generic;
+	mac->ops.get_device_caps = ixgbe_get_device_caps_generic;
+	mac->ops.get_wwn_prefix = ixgbe_get_wwn_prefix_generic;
+	mac->ops.get_fcoe_boot_status = ixgbe_get_fcoe_boot_status_generic;
+	mac->ops.prot_autoc_read = prot_autoc_read_82599;
+	mac->ops.prot_autoc_write = prot_autoc_write_82599;
+
+	/* RAR, Multicast, VLAN */
+	mac->ops.set_vmdq = ixgbe_set_vmdq_generic;
+	mac->ops.set_vmdq_san_mac = ixgbe_set_vmdq_san_mac_generic;
+	mac->ops.clear_vmdq = ixgbe_clear_vmdq_generic;
+	mac->ops.insert_mac_addr = ixgbe_insert_mac_addr_generic;
+	mac->rar_highwater = 1;
+	mac->ops.set_vfta = ixgbe_set_vfta_generic;
+	mac->ops.set_vlvf = ixgbe_set_vlvf_generic;
+	mac->ops.clear_vfta = ixgbe_clear_vfta_generic;
+	mac->ops.init_uta_tables = ixgbe_init_uta_tables_generic;
+	mac->ops.setup_sfp = ixgbe_setup_sfp_modules_82599;
+	mac->ops.set_mac_anti_spoofing = ixgbe_set_mac_anti_spoofing;
+	mac->ops.set_vlan_anti_spoofing = ixgbe_set_vlan_anti_spoofing;
+
+	/* Link */
+	mac->ops.get_link_capabilities = ixgbe_get_link_capabilities_82599;
+	mac->ops.check_link = ixgbe_check_mac_link_generic;
+	mac->ops.setup_rxpba = ixgbe_set_rxpba_generic;
+	ixgbe_init_mac_link_ops_82599(hw);
 
-		/* Initialize access to QSFP+ I2C bus */
-		esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
-		esdp |= IXGBE_ESDP_SDP0_DIR;
-		esdp &= ~IXGBE_ESDP_SDP1_DIR;
-		esdp &= ~IXGBE_ESDP_SDP0;
-		esdp &= ~IXGBE_ESDP_SDP0_NATIVE;
-		esdp &= ~IXGBE_ESDP_SDP1_NATIVE;
-		IXGBE_WRITE_REG(hw, IXGBE_ESDP, esdp);
-		IXGBE_WRITE_FLUSH(hw);
+	mac->mcft_size		= IXGBE_82599_MC_TBL_SIZE;
+	mac->vft_size		= IXGBE_82599_VFT_TBL_SIZE;
+	mac->num_rar_entries	= IXGBE_82599_RAR_ENTRIES;
+	mac->rx_pb_size		= IXGBE_82599_RX_PB_SIZE;
+	mac->max_rx_queues	= IXGBE_82599_MAX_RX_QUEUES;
+	mac->max_tx_queues	= IXGBE_82599_MAX_TX_QUEUES;
+	mac->max_msix_vectors	= ixgbe_get_pcie_msix_count_generic(hw);
 
-		phy->ops.read_i2c_byte = &ixgbe_read_i2c_byte_82599;
-		phy->ops.write_i2c_byte = &ixgbe_write_i2c_byte_82599;
-	}
+	mac->arc_subsystem_valid = !!(IXGBE_READ_REG(hw, IXGBE_FWSM_BY_MAC(hw))
+				      & IXGBE_FWSM_MODE_MASK);
 
-	/* Identify the PHY or SFP module */
-	ret_val = phy->ops.identify(hw);
+	hw->mbx.ops.init_params = ixgbe_init_mbx_params_pf;
 
-	/* Setup function pointers based on detected SFP module and speeds */
-	ixgbe_init_mac_link_ops_82599(hw);
+	/* EEPROM */
+	eeprom->ops.read = ixgbe_read_eeprom_82599;
+	eeprom->ops.read_buffer = ixgbe_read_eeprom_buffer_82599;
 
-	/* If copper media, overwrite with copper function pointers */
-	if (mac->ops.get_media_type(hw) == ixgbe_media_type_copper) {
-		mac->ops.setup_link = &ixgbe_setup_copper_link_82599;
-		mac->ops.get_link_capabilities =
-			&ixgbe_get_copper_link_capabilities_generic;
-	}
+	/* Manageability interface */
+	mac->ops.set_fw_drv_ver = ixgbe_set_fw_drv_ver_generic;
 
-	/* Set necessary function pointers based on phy type */
-	switch (hw->phy.type) {
-	case ixgbe_phy_tn:
-		phy->ops.check_link = &ixgbe_check_phy_link_tnx;
-		phy->ops.setup_link = &ixgbe_setup_phy_link_tnx;
-		phy->ops.get_firmware_version =
-			     &ixgbe_get_phy_firmware_version_tnx;
-		break;
-	default:
-		break;
-	}
+	mac->ops.get_thermal_sensor_data =
+					 ixgbe_get_thermal_sensor_data_generic;
+	mac->ops.init_thermal_sensor_thresh =
+				      ixgbe_init_thermal_sensor_thresh_generic;
+
+	mac->ops.get_rtrup2tc = ixgbe_dcb_get_rtrup2tc_generic;
 
 	return ret_val;
 }
@@ -349,13 +398,17 @@ static s32 ixgbe_init_phy_ops_82599(struct ixgbe_hw *hw)
  *
  *  Determines the link capabilities by reading the AUTOC register.
  **/
-static s32 ixgbe_get_link_capabilities_82599(struct ixgbe_hw *hw,
-					     ixgbe_link_speed *speed,
-					     bool *autoneg)
+s32 ixgbe_get_link_capabilities_82599(struct ixgbe_hw *hw,
+				      ixgbe_link_speed *speed,
+				      bool *autoneg)
 {
+	s32 status = IXGBE_SUCCESS;
 	u32 autoc = 0;
 
-	/* Determine 1G link capabilities off of SFP+ type */
+	DEBUGFUNC("ixgbe_get_link_capabilities_82599");
+
+
+	/* Check if 1G SFP module. */
 	if (hw->phy.sfp_type == ixgbe_sfp_type_1g_cu_core0 ||
 	    hw->phy.sfp_type == ixgbe_sfp_type_1g_cu_core1 ||
 	    hw->phy.sfp_type == ixgbe_sfp_type_1g_lx_core0 ||
@@ -364,13 +417,13 @@ static s32 ixgbe_get_link_capabilities_82599(struct ixgbe_hw *hw,
 	    hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core1) {
 		*speed = IXGBE_LINK_SPEED_1GB_FULL;
 		*autoneg = true;
-		return 0;
+		goto out;
 	}
 
 	/*
 	 * Determine link capabilities based on the stored value of AUTOC,
-	 * which represents EEPROM defaults.  If AUTOC value has not been
-	 * stored, use the current register value.
+	 * which represents EEPROM defaults.  If AUTOC value has not
+	 * been stored, use the current register values.
 	 */
 	if (hw->mac.orig_link_settings_stored)
 		autoc = hw->mac.orig_autoc;
@@ -427,21 +480,26 @@ static s32 ixgbe_get_link_capabilities_82599(struct ixgbe_hw *hw,
 		break;
 
 	default:
-		return IXGBE_ERR_LINK_SETUP;
+		status = IXGBE_ERR_LINK_SETUP;
+		goto out;
+		break;
 	}
 
 	if (hw->phy.multispeed_fiber) {
 		*speed |= IXGBE_LINK_SPEED_10GB_FULL |
 			  IXGBE_LINK_SPEED_1GB_FULL;
 
-		/* QSFP must not enable auto-negotiation */
+		/* QSFP must not enable full auto-negotiation
+		 * Limited autoneg is enabled at 1G
+		 */
 		if (hw->phy.media_type == ixgbe_media_type_fiber_qsfp)
 			*autoneg = false;
 		else
 			*autoneg = true;
 	}
 
-	return 0;
+out:
+	return status;
 }
 
 /**
@@ -450,14 +508,18 @@ static s32 ixgbe_get_link_capabilities_82599(struct ixgbe_hw *hw,
  *
  *  Returns the media type (fiber, copper, backplane)
  **/
-static enum ixgbe_media_type ixgbe_get_media_type_82599(struct ixgbe_hw *hw)
+enum ixgbe_media_type ixgbe_get_media_type_82599(struct ixgbe_hw *hw)
 {
+	enum ixgbe_media_type media_type;
+
+	DEBUGFUNC("ixgbe_get_media_type_82599");
+
 	/* Detect if there is a copper PHY attached. */
 	switch (hw->phy.type) {
 	case ixgbe_phy_cu_unknown:
 	case ixgbe_phy_tn:
-		return ixgbe_media_type_copper;
-
+		media_type = ixgbe_media_type_copper;
+		goto out;
 	default:
 		break;
 	}
@@ -470,46 +532,50 @@ static enum ixgbe_media_type ixgbe_get_media_type_82599(struct ixgbe_hw *hw)
 	case IXGBE_DEV_ID_82599_BACKPLANE_FCOE:
 	case IXGBE_DEV_ID_82599_XAUI_LOM:
 		/* Default device ID is mezzanine card KX/KX4 */
-		return ixgbe_media_type_backplane;
-
+		media_type = ixgbe_media_type_backplane;
+		break;
 	case IXGBE_DEV_ID_82599_SFP:
 	case IXGBE_DEV_ID_82599_SFP_FCOE:
 	case IXGBE_DEV_ID_82599_SFP_EM:
 	case IXGBE_DEV_ID_82599_SFP_SF2:
 	case IXGBE_DEV_ID_82599_SFP_SF_QP:
 	case IXGBE_DEV_ID_82599EN_SFP:
-		return ixgbe_media_type_fiber;
-
+		media_type = ixgbe_media_type_fiber;
+		break;
 	case IXGBE_DEV_ID_82599_CX4:
-		return ixgbe_media_type_cx4;
-
+		media_type = ixgbe_media_type_cx4;
+		break;
 	case IXGBE_DEV_ID_82599_T3_LOM:
-		return ixgbe_media_type_copper;
-
+		media_type = ixgbe_media_type_copper;
+		break;
 	case IXGBE_DEV_ID_82599_LS:
-		return ixgbe_media_type_fiber_lco;
-
+		media_type = ixgbe_media_type_fiber_lco;
+		break;
 	case IXGBE_DEV_ID_82599_QSFP_SF_QP:
-		return ixgbe_media_type_fiber_qsfp;
-
+		media_type = ixgbe_media_type_fiber_qsfp;
+		break;
 	default:
-		return ixgbe_media_type_unknown;
+		media_type = ixgbe_media_type_unknown;
+		break;
 	}
+out:
+	return media_type;
 }
 
 /**
- * ixgbe_stop_mac_link_on_d3_82599 - Disables link on D3
- * @hw: pointer to hardware structure
+ *  ixgbe_stop_mac_link_on_d3_82599 - Disables link on D3
+ *  @hw: pointer to hardware structure
  *
- * Disables link, should be called during D3 power down sequence.
+ *  Disables link during D3 power down sequence.
  *
  **/
-static void ixgbe_stop_mac_link_on_d3_82599(struct ixgbe_hw *hw)
+void ixgbe_stop_mac_link_on_d3_82599(struct ixgbe_hw *hw)
 {
 	u32 autoc2_reg;
 	u16 ee_ctrl_2 = 0;
 
-	hw->eeprom.ops.read(hw, IXGBE_EEPROM_CTRL_2, &ee_ctrl_2);
+	DEBUGFUNC("ixgbe_stop_mac_link_on_d3_82599");
+	ixgbe_read_eeprom(hw, IXGBE_EEPROM_CTRL_2, &ee_ctrl_2);
 
 	if (!ixgbe_mng_present(hw) && !hw->wol_enabled &&
 	    ee_ctrl_2 & IXGBE_EEPROM_CCD_BIT) {
@@ -527,20 +593,25 @@ static void ixgbe_stop_mac_link_on_d3_82599(struct ixgbe_hw *hw)
  *  Configures link settings based on values in the ixgbe_hw struct.
  *  Restarts the link.  Performs autonegotiation if needed.
  **/
-static s32 ixgbe_start_mac_link_82599(struct ixgbe_hw *hw,
+s32 ixgbe_start_mac_link_82599(struct ixgbe_hw *hw,
 			       bool autoneg_wait_to_complete)
 {
 	u32 autoc_reg;
 	u32 links_reg;
 	u32 i;
-	s32 status = 0;
+	s32 status = IXGBE_SUCCESS;
 	bool got_lock = false;
 
+	DEBUGFUNC("ixgbe_start_mac_link_82599");
+
+	/*  reset_pipeline requires us to hold this lock as it writes to
+	 *  AUTOC.
+	 */
 	if (ixgbe_verify_lesm_fw_enabled_82599(hw)) {
 		status = hw->mac.ops.acquire_swfw_sync(hw,
-						IXGBE_GSSR_MAC_CSR_SM);
-		if (status)
-			return status;
+						       IXGBE_GSSR_MAC_CSR_SM);
+		if (status != IXGBE_SUCCESS)
+			goto out;
 
 		got_lock = true;
 	}
@@ -565,18 +636,19 @@ static s32 ixgbe_start_mac_link_82599(struct ixgbe_hw *hw,
 				links_reg = IXGBE_READ_REG(hw, IXGBE_LINKS);
 				if (links_reg & IXGBE_LINKS_KX_AN_COMP)
 					break;
-				msleep(100);
+				msec_delay(100);
 			}
 			if (!(links_reg & IXGBE_LINKS_KX_AN_COMP)) {
 				status = IXGBE_ERR_AUTONEG_NOT_COMPLETE;
-				hw_dbg(hw, "Autoneg did not complete.\n");
+				DEBUGOUT("Autoneg did not complete.\n");
 			}
 		}
 	}
 
 	/* Add delay to filter out noises during initial link setup */
-	msleep(50);
+	msec_delay(50);
 
+out:
 	return status;
 }
 
@@ -588,7 +660,7 @@ static s32 ixgbe_start_mac_link_82599(struct ixgbe_hw *hw,
  *  PHY states.  This includes selectively shutting down the Tx
  *  laser on the PHY, effectively halting physical link.
  **/
-static void ixgbe_disable_tx_laser_multispeed_fiber(struct ixgbe_hw *hw)
+void ixgbe_disable_tx_laser_multispeed_fiber(struct ixgbe_hw *hw)
 {
 	u32 esdp_reg = IXGBE_READ_REG(hw, IXGBE_ESDP);
 
@@ -596,11 +668,11 @@ static void ixgbe_disable_tx_laser_multispeed_fiber(struct ixgbe_hw *hw)
 	if (ixgbe_check_reset_blocked(hw))
 		return;
 
-	/* Disable tx laser; allow 100us to go dark per spec */
+	/* Disable Tx laser; allow 100us to go dark per spec */
 	esdp_reg |= IXGBE_ESDP_SDP3;
 	IXGBE_WRITE_REG(hw, IXGBE_ESDP, esdp_reg);
 	IXGBE_WRITE_FLUSH(hw);
-	udelay(100);
+	usec_delay(100);
 }
 
 /**
@@ -611,15 +683,15 @@ static void ixgbe_disable_tx_laser_multispeed_fiber(struct ixgbe_hw *hw)
  *  PHY states.  This includes selectively turning on the Tx
  *  laser on the PHY, effectively starting physical link.
  **/
-static void ixgbe_enable_tx_laser_multispeed_fiber(struct ixgbe_hw *hw)
+void ixgbe_enable_tx_laser_multispeed_fiber(struct ixgbe_hw *hw)
 {
 	u32 esdp_reg = IXGBE_READ_REG(hw, IXGBE_ESDP);
 
-	/* Enable tx laser; allow 100ms to light up */
+	/* Enable Tx laser; allow 100ms to light up */
 	esdp_reg &= ~IXGBE_ESDP_SDP3;
 	IXGBE_WRITE_REG(hw, IXGBE_ESDP, esdp_reg);
 	IXGBE_WRITE_FLUSH(hw);
-	msleep(100);
+	msec_delay(100);
 }
 
 /**
@@ -629,13 +701,15 @@ static void ixgbe_enable_tx_laser_multispeed_fiber(struct ixgbe_hw *hw)
  *  When the driver changes the link speeds that it can support,
  *  it sets autotry_restart to true to indicate that we need to
  *  initiate a new autotry session with the link partner.  To do
- *  so, we set the speed then disable and re-enable the tx laser, to
+ *  so, we set the speed then disable and re-enable the Tx laser, to
  *  alert the link partner that it also needs to restart autotry on its
  *  end.  This is consistent with true clause 37 autoneg, which also
  *  involves a loss of signal.
  **/
-static void ixgbe_flap_tx_laser_multispeed_fiber(struct ixgbe_hw *hw)
+void ixgbe_flap_tx_laser_multispeed_fiber(struct ixgbe_hw *hw)
 {
+	DEBUGFUNC("ixgbe_flap_tx_laser_multispeed_fiber");
+
 	/* Blocked by MNG FW so bail */
 	if (ixgbe_check_reset_blocked(hw))
 		return;
@@ -648,14 +722,14 @@ static void ixgbe_flap_tx_laser_multispeed_fiber(struct ixgbe_hw *hw)
 }
 
 /**
- * ixgbe_set_hard_rate_select_speed - Set module link speed
- * @hw: pointer to hardware structure
- * @speed: link speed to set
+ *  ixgbe_set_hard_rate_select_speed - Set module link speed
+ *  @hw: pointer to hardware structure
+ *  @speed: link speed to set
  *
- * Set module link speed via RS0/RS1 rate select pins.
+ *  Set module link speed via RS0/RS1 rate select pins.
  */
-static void
-ixgbe_set_hard_rate_select_speed(struct ixgbe_hw *hw, ixgbe_link_speed speed)
+void ixgbe_set_hard_rate_select_speed(struct ixgbe_hw *hw,
+					ixgbe_link_speed speed)
 {
 	u32 esdp_reg = IXGBE_READ_REG(hw, IXGBE_ESDP);
 
@@ -668,7 +742,7 @@ ixgbe_set_hard_rate_select_speed(struct ixgbe_hw *hw, ixgbe_link_speed speed)
 		esdp_reg |= IXGBE_ESDP_SDP5_DIR;
 		break;
 	default:
-		hw_dbg(hw, "Invalid fixed module speed\n");
+		DEBUGOUT("Invalid fixed module speed\n");
 		return;
 	}
 
@@ -684,16 +758,18 @@ ixgbe_set_hard_rate_select_speed(struct ixgbe_hw *hw, ixgbe_link_speed speed)
  *
  *  Implements the Intel SmartSpeed algorithm.
  **/
-static s32 ixgbe_setup_mac_link_smartspeed(struct ixgbe_hw *hw,
-				     ixgbe_link_speed speed,
-				     bool autoneg_wait_to_complete)
+s32 ixgbe_setup_mac_link_smartspeed(struct ixgbe_hw *hw,
+				    ixgbe_link_speed speed,
+				    bool autoneg_wait_to_complete)
 {
-	s32 status = 0;
+	s32 status = IXGBE_SUCCESS;
 	ixgbe_link_speed link_speed = IXGBE_LINK_SPEED_UNKNOWN;
 	s32 i, j;
 	bool link_up = false;
 	u32 autoc_reg = IXGBE_READ_REG(hw, IXGBE_AUTOC);
 
+	DEBUGFUNC("ixgbe_setup_mac_link_smartspeed");
+
 	 /* Set autoneg_advertised value based on input link speed */
 	hw->phy.autoneg_advertised = 0;
 
@@ -718,7 +794,7 @@ static s32 ixgbe_setup_mac_link_smartspeed(struct ixgbe_hw *hw,
 	for (j = 0; j < IXGBE_SMARTSPEED_MAX_RETRIES; j++) {
 		status = ixgbe_setup_mac_link_82599(hw, speed,
 						    autoneg_wait_to_complete);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto out;
 
 		/*
@@ -728,12 +804,12 @@ static s32 ixgbe_setup_mac_link_smartspeed(struct ixgbe_hw *hw,
 		 * Table 9 in the AN MAS.
 		 */
 		for (i = 0; i < 5; i++) {
-			mdelay(100);
+			msec_delay(100);
 
 			/* If we have link, just jump out */
-			status = hw->mac.ops.check_link(hw, &link_speed,
-							&link_up, false);
-			if (status != 0)
+			status = ixgbe_check_link(hw, &link_speed, &link_up,
+						  false);
+			if (status != IXGBE_SUCCESS)
 				goto out;
 
 			if (link_up)
@@ -753,7 +829,7 @@ static s32 ixgbe_setup_mac_link_smartspeed(struct ixgbe_hw *hw,
 	hw->phy.smart_speed_active = true;
 	status = ixgbe_setup_mac_link_82599(hw, speed,
 					    autoneg_wait_to_complete);
-	if (status != 0)
+	if (status != IXGBE_SUCCESS)
 		goto out;
 
 	/*
@@ -763,12 +839,11 @@ static s32 ixgbe_setup_mac_link_smartspeed(struct ixgbe_hw *hw,
 	 * connect attempts as defined in the AN MAS table 73-7.
 	 */
 	for (i = 0; i < 6; i++) {
-		mdelay(100);
+		msec_delay(100);
 
 		/* If we have link, just jump out */
-		status = hw->mac.ops.check_link(hw, &link_speed,
-						&link_up, false);
-		if (status != 0)
+		status = ixgbe_check_link(hw, &link_speed, &link_up, false);
+		if (status != IXGBE_SUCCESS)
 			goto out;
 
 		if (link_up)
@@ -782,7 +857,8 @@ static s32 ixgbe_setup_mac_link_smartspeed(struct ixgbe_hw *hw,
 
 out:
 	if (link_up && (link_speed == IXGBE_LINK_SPEED_1GB_FULL))
-		hw_dbg(hw, "Smartspeed has downgraded the link speed from the maximum advertised\n");
+		DEBUGOUT("Smartspeed has downgraded the link speed "
+		"from the maximum advertised\n");
 	return status;
 }
 
@@ -794,34 +870,35 @@ out:
  *
  *  Set the link speed in the AUTOC register and restarts link.
  **/
-static s32 ixgbe_setup_mac_link_82599(struct ixgbe_hw *hw,
-				      ixgbe_link_speed speed,
-				      bool autoneg_wait_to_complete)
+s32 ixgbe_setup_mac_link_82599(struct ixgbe_hw *hw,
+			       ixgbe_link_speed speed,
+			       bool autoneg_wait_to_complete)
 {
 	bool autoneg = false;
-	s32 status;
-	u32 pma_pmd_1g, link_mode, links_reg, i;
+	s32 status = IXGBE_SUCCESS;
+	u32 pma_pmd_1g, link_mode;
+	u32 current_autoc = IXGBE_READ_REG(hw, IXGBE_AUTOC); /* holds the value of AUTOC register at this current point in time */
+	u32 orig_autoc = 0; /* holds the cached value of AUTOC register */
+	u32 autoc = current_autoc; /* Temporary variable used for comparison purposes */
 	u32 autoc2 = IXGBE_READ_REG(hw, IXGBE_AUTOC2);
 	u32 pma_pmd_10g_serial = autoc2 & IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_MASK;
+	u32 links_reg;
+	u32 i;
 	ixgbe_link_speed link_capabilities = IXGBE_LINK_SPEED_UNKNOWN;
 
-	/* holds the value of AUTOC register at this current point in time */
-	u32 current_autoc = IXGBE_READ_REG(hw, IXGBE_AUTOC);
-	/* holds the cached value of AUTOC register */
-	u32 orig_autoc = 0;
-	/* temporary variable used for comparison purposes */
-	u32 autoc = current_autoc;
+	DEBUGFUNC("ixgbe_setup_mac_link_82599");
 
 	/* Check to see if speed passed in is supported. */
-	status = hw->mac.ops.get_link_capabilities(hw, &link_capabilities,
-						   &autoneg);
+	status = ixgbe_get_link_capabilities(hw, &link_capabilities, &autoneg);
 	if (status)
-		return status;
+		goto out;
 
 	speed &= link_capabilities;
 
-	if (speed == IXGBE_LINK_SPEED_UNKNOWN)
-		return IXGBE_ERR_LINK_SETUP;
+	if (speed == IXGBE_LINK_SPEED_UNKNOWN) {
+		status = IXGBE_ERR_LINK_SETUP;
+		goto out;
+	}
 
 	/* Use stored value (EEPROM defaults) of AUTOC to find KR/KX4 support*/
 	if (hw->mac.orig_link_settings_stored)
@@ -861,7 +938,7 @@ static s32 ixgbe_setup_mac_link_82599(struct ixgbe_hw *hw,
 		if ((speed == IXGBE_LINK_SPEED_1GB_FULL) &&
 		    (pma_pmd_1g == IXGBE_AUTOC_1G_SFI)) {
 			autoc &= ~IXGBE_AUTOC_LMS_MASK;
-			if (autoneg)
+			if (autoneg || hw->phy.type == ixgbe_phy_qsfp_intel)
 				autoc |= IXGBE_AUTOC_LMS_1G_AN;
 			else
 				autoc |= IXGBE_AUTOC_LMS_1G_LINK_NO_AN;
@@ -871,8 +948,8 @@ static s32 ixgbe_setup_mac_link_82599(struct ixgbe_hw *hw,
 	if (autoc != current_autoc) {
 		/* Restart link */
 		status = hw->mac.ops.prot_autoc_write(hw, autoc, false);
-		if (status)
-			return status;
+		if (status != IXGBE_SUCCESS)
+			goto out;
 
 		/* Only poll for autoneg to complete if specified to do so */
 		if (autoneg_wait_to_complete) {
@@ -885,20 +962,21 @@ static s32 ixgbe_setup_mac_link_82599(struct ixgbe_hw *hw,
 					       IXGBE_READ_REG(hw, IXGBE_LINKS);
 					if (links_reg & IXGBE_LINKS_KX_AN_COMP)
 						break;
-					msleep(100);
+					msec_delay(100);
 				}
 				if (!(links_reg & IXGBE_LINKS_KX_AN_COMP)) {
 					status =
 						IXGBE_ERR_AUTONEG_NOT_COMPLETE;
-					hw_dbg(hw, "Autoneg did not complete.\n");
+					DEBUGOUT("Autoneg did not complete.\n");
 				}
 			}
 		}
 
 		/* Add delay to filter out noises during initial link setup */
-		msleep(50);
+		msec_delay(50);
 	}
 
+out:
 	return status;
 }
 
@@ -910,12 +988,14 @@ static s32 ixgbe_setup_mac_link_82599(struct ixgbe_hw *hw,
  *
  *  Restarts link on PHY and MAC based on settings passed in.
  **/
-static s32 ixgbe_setup_copper_link_82599(struct ixgbe_hw *hw,
+STATIC s32 ixgbe_setup_copper_link_82599(struct ixgbe_hw *hw,
 					 ixgbe_link_speed speed,
 					 bool autoneg_wait_to_complete)
 {
 	s32 status;
 
+	DEBUGFUNC("ixgbe_setup_copper_link_82599");
+
 	/* Setup the PHY according to input speed */
 	status = hw->phy.ops.setup_link_speed(hw, speed,
 					      autoneg_wait_to_complete);
@@ -933,18 +1013,21 @@ static s32 ixgbe_setup_copper_link_82599(struct ixgbe_hw *hw,
  *  and clears all interrupts, perform a PHY reset, and perform a link (MAC)
  *  reset.
  **/
-static s32 ixgbe_reset_hw_82599(struct ixgbe_hw *hw)
+s32 ixgbe_reset_hw_82599(struct ixgbe_hw *hw)
 {
 	ixgbe_link_speed link_speed;
 	s32 status;
-	u32 ctrl, i, autoc, autoc2;
+	u32 ctrl = 0;
+	u32 i, autoc, autoc2;
 	u32 curr_lms;
 	bool link_up = false;
 
+	DEBUGFUNC("ixgbe_reset_hw_82599");
+
 	/* Call adapter stop to disable tx/rx and clear interrupts */
 	status = hw->mac.ops.stop_adapter(hw);
-	if (status)
-		return status;
+	if (status != IXGBE_SUCCESS)
+		goto reset_hw_out;
 
 	/* flush pending Tx transactions */
 	ixgbe_clear_tx_pending(hw);
@@ -955,7 +1038,7 @@ static s32 ixgbe_reset_hw_82599(struct ixgbe_hw *hw)
 	status = hw->phy.ops.init(hw);
 
 	if (status == IXGBE_ERR_SFP_NOT_SUPPORTED)
-		return status;
+		goto reset_hw_out;
 
 	/* Setup SFP module if there is one present. */
 	if (hw->phy.sfp_setup_needed) {
@@ -964,7 +1047,7 @@ static s32 ixgbe_reset_hw_82599(struct ixgbe_hw *hw)
 	}
 
 	if (status == IXGBE_ERR_SFP_NOT_SUPPORTED)
-		return status;
+		goto reset_hw_out;
 
 	/* Reset PHY */
 	if (hw->phy.reset_disable == false && hw->phy.ops.reset != NULL)
@@ -975,7 +1058,7 @@ static s32 ixgbe_reset_hw_82599(struct ixgbe_hw *hw)
 
 mac_reset_top:
 	/*
-	 * Issue global reset to the MAC. Needs to be SW reset if link is up.
+	 * Issue global reset to the MAC.  Needs to be SW reset if link is up.
 	 * If link reset is used when link is up, it might reset the PHY when
 	 * mng is using it.  If link is down or the flag to force full link
 	 * reset is set, then perform link reset.
@@ -991,9 +1074,9 @@ mac_reset_top:
 	IXGBE_WRITE_REG(hw, IXGBE_CTRL, ctrl);
 	IXGBE_WRITE_FLUSH(hw);
 
-	/* Poll for reset bit to self-clear indicating reset is complete */
+	/* Poll for reset bit to self-clear meaning reset is complete */
 	for (i = 0; i < 10; i++) {
-		udelay(1);
+		usec_delay(1);
 		ctrl = IXGBE_READ_REG(hw, IXGBE_CTRL);
 		if (!(ctrl & IXGBE_CTRL_RST_MASK))
 			break;
@@ -1001,15 +1084,15 @@ mac_reset_top:
 
 	if (ctrl & IXGBE_CTRL_RST_MASK) {
 		status = IXGBE_ERR_RESET_FAILED;
-		hw_dbg(hw, "Reset polling failed to complete.\n");
+		DEBUGOUT("Reset polling failed to complete.\n");
 	}
 
-	msleep(50);
+	msec_delay(50);
 
 	/*
 	 * Double resets are required for recovery from certain error
-	 * conditions.  Between resets, it is necessary to stall to allow time
-	 * for any pending HW events to complete.
+	 * conditions.  Between resets, it is necessary to stall to
+	 * allow time for any pending HW events to complete.
 	 */
 	if (hw->mac.flags & IXGBE_FLAGS_DOUBLE_RESET_REQUIRED) {
 		hw->mac.flags &= ~IXGBE_FLAGS_DOUBLE_RESET_REQUIRED;
@@ -1041,7 +1124,7 @@ mac_reset_top:
 		 * doesn't autoneg with out driver support we need to
 		 * leave LMS in the state it was before we MAC reset.
 		 * Likewise if we support WoL we don't want change the
-		 * LMS state either.
+		 * LMS state.
 		 */
 		if ((hw->phy.multispeed_fiber && ixgbe_mng_enabled(hw)) ||
 		    hw->wol_enabled)
@@ -1053,8 +1136,8 @@ mac_reset_top:
 			status = hw->mac.ops.prot_autoc_write(hw,
 							hw->mac.orig_autoc,
 							false);
-			if (status)
-				return status;
+			if (status != IXGBE_SUCCESS)
+				goto reset_hw_out;
 		}
 
 		if ((autoc2 & IXGBE_AUTOC2_UPPER_MASK) !=
@@ -1081,21 +1164,26 @@ mac_reset_top:
 	hw->mac.ops.get_san_mac_addr(hw, hw->mac.san_addr);
 
 	/* Add the SAN MAC address to the RAR only if it's a valid address */
-	if (is_valid_ether_addr(hw->mac.san_addr)) {
-		hw->mac.ops.set_rar(hw, hw->mac.num_rar_entries - 1,
-				    hw->mac.san_addr, 0, IXGBE_RAH_AV);
-
+	if (ixgbe_validate_mac_addr(hw->mac.san_addr) == 0) {
 		/* Save the SAN MAC RAR index */
 		hw->mac.san_mac_rar_index = hw->mac.num_rar_entries - 1;
 
+		hw->mac.ops.set_rar(hw, hw->mac.san_mac_rar_index,
+				    hw->mac.san_addr, 0, IXGBE_RAH_AV);
+
+		/* clear VMDq pool/queue selection for this RAR */
+		hw->mac.ops.clear_vmdq(hw, hw->mac.san_mac_rar_index,
+				       IXGBE_CLEAR_VMDQ_ALL);
+
 		/* Reserve the last RAR for the SAN MAC address */
 		hw->mac.num_rar_entries--;
 	}
 
 	/* Store the alternative WWNN/WWPN prefix */
 	hw->mac.ops.get_wwn_prefix(hw, &hw->mac.wwnn_prefix,
-				       &hw->mac.wwpn_prefix);
+				   &hw->mac.wwpn_prefix);
 
+reset_hw_out:
 	return status;
 }
 
@@ -1104,15 +1192,15 @@ mac_reset_top:
  * @hw: pointer to hardware structure
  * @fdircmd: current value of FDIRCMD register
  */
-static s32 ixgbe_fdir_check_cmd_complete(struct ixgbe_hw *hw, u32 *fdircmd)
+STATIC s32 ixgbe_fdir_check_cmd_complete(struct ixgbe_hw *hw, u32 *fdircmd)
 {
 	int i;
 
 	for (i = 0; i < IXGBE_FDIRCMD_CMD_POLL; i++) {
 		*fdircmd = IXGBE_READ_REG(hw, IXGBE_FDIRCMD);
 		if (!(*fdircmd & IXGBE_FDIRCMD_CMD_MASK))
-			return 0;
-		udelay(10);
+			return IXGBE_SUCCESS;
+		usec_delay(10);
 	}
 
 	return IXGBE_ERR_FDIR_CMD_INCOMPLETE;
@@ -1124,20 +1212,21 @@ static s32 ixgbe_fdir_check_cmd_complete(struct ixgbe_hw *hw, u32 *fdircmd)
  **/
 s32 ixgbe_reinit_fdir_tables_82599(struct ixgbe_hw *hw)
 {
+	s32 err;
 	int i;
 	u32 fdirctrl = IXGBE_READ_REG(hw, IXGBE_FDIRCTRL);
 	u32 fdircmd;
-	s32 err;
-
 	fdirctrl &= ~IXGBE_FDIRCTRL_INIT_DONE;
 
+	DEBUGFUNC("ixgbe_reinit_fdir_tables_82599");
+
 	/*
 	 * Before starting reinitialization process,
 	 * FDIRCMD.CMD must be zero.
 	 */
 	err = ixgbe_fdir_check_cmd_complete(hw, &fdircmd);
 	if (err) {
-		hw_dbg(hw, "Flow Director previous command did not complete, aborting table re-initialization.\n");
+		DEBUGOUT("Flow Director previous command did not complete, aborting table re-initialization.\n");
 		return err;
 	}
 
@@ -1173,10 +1262,10 @@ s32 ixgbe_reinit_fdir_tables_82599(struct ixgbe_hw *hw)
 		if (IXGBE_READ_REG(hw, IXGBE_FDIRCTRL) &
 				   IXGBE_FDIRCTRL_INIT_DONE)
 			break;
-		usleep_range(1000, 2000);
+		msec_delay(1);
 	}
 	if (i >= IXGBE_FDIR_INIT_DONE_POLL) {
-		hw_dbg(hw, "Flow Director Signature poll time exceeded!\n");
+		DEBUGOUT("Flow Director Signature poll time exceeded!\n");
 		return IXGBE_ERR_FDIR_REINIT_FAILED;
 	}
 
@@ -1187,7 +1276,7 @@ s32 ixgbe_reinit_fdir_tables_82599(struct ixgbe_hw *hw)
 	IXGBE_READ_REG(hw, IXGBE_FDIRMISS);
 	IXGBE_READ_REG(hw, IXGBE_FDIRLEN);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -1195,10 +1284,12 @@ s32 ixgbe_reinit_fdir_tables_82599(struct ixgbe_hw *hw)
  *  @hw: pointer to hardware structure
  *  @fdirctrl: value to write to flow director control register
  **/
-static void ixgbe_fdir_enable_82599(struct ixgbe_hw *hw, u32 fdirctrl)
+STATIC void ixgbe_fdir_enable_82599(struct ixgbe_hw *hw, u32 fdirctrl)
 {
 	int i;
 
+	DEBUGFUNC("ixgbe_fdir_enable_82599");
+
 	/* Prime the keys for hashing */
 	IXGBE_WRITE_REG(hw, IXGBE_FDIRHKEY, IXGBE_ATR_BUCKET_HASH_KEY);
 	IXGBE_WRITE_REG(hw, IXGBE_FDIRSKEY, IXGBE_ATR_SIGNATURE_HASH_KEY);
@@ -1222,21 +1313,23 @@ static void ixgbe_fdir_enable_82599(struct ixgbe_hw *hw, u32 fdirctrl)
 		if (IXGBE_READ_REG(hw, IXGBE_FDIRCTRL) &
 				   IXGBE_FDIRCTRL_INIT_DONE)
 			break;
-		usleep_range(1000, 2000);
+		msec_delay(1);
 	}
 
 	if (i >= IXGBE_FDIR_INIT_DONE_POLL)
-		hw_dbg(hw, "Flow Director poll time exceeded!\n");
+		DEBUGOUT("Flow Director poll time exceeded!\n");
 }
 
 /**
  *  ixgbe_init_fdir_signature_82599 - Initialize Flow Director signature filters
  *  @hw: pointer to hardware structure
  *  @fdirctrl: value to write to flow director control register, initially
- *             contains just the value of the Rx packet buffer allocation
+ *	     contains just the value of the Rx packet buffer allocation
  **/
 s32 ixgbe_init_fdir_signature_82599(struct ixgbe_hw *hw, u32 fdirctrl)
 {
+	DEBUGFUNC("ixgbe_init_fdir_signature_82599");
+
 	/*
 	 * Continue setup of fdirctrl register bits:
 	 *  Move the flexible bytes to use the ethertype - shift 6 words
@@ -1250,35 +1343,79 @@ s32 ixgbe_init_fdir_signature_82599(struct ixgbe_hw *hw, u32 fdirctrl)
 	/* write hashes and fdirctrl register, poll for completion */
 	ixgbe_fdir_enable_82599(hw, fdirctrl);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
  *  ixgbe_init_fdir_perfect_82599 - Initialize Flow Director perfect filters
  *  @hw: pointer to hardware structure
  *  @fdirctrl: value to write to flow director control register, initially
- *             contains just the value of the Rx packet buffer allocation
+ *	     contains just the value of the Rx packet buffer allocation
+ *  @cloud_mode: true - cloud mode, false - other mode
  **/
-s32 ixgbe_init_fdir_perfect_82599(struct ixgbe_hw *hw, u32 fdirctrl)
+s32 ixgbe_init_fdir_perfect_82599(struct ixgbe_hw *hw, u32 fdirctrl,
+			bool cloud_mode)
 {
+	DEBUGFUNC("ixgbe_init_fdir_perfect_82599");
+
 	/*
 	 * Continue setup of fdirctrl register bits:
 	 *  Turn perfect match filtering on
-	 *  Initialize the drop queue
+	 *  Report hash in RSS field of Rx wb descriptor
+	 *  Initialize the drop queue to queue 127
 	 *  Move the flexible bytes to use the ethertype - shift 6 words
 	 *  Set the maximum length per hash bucket to 0xA filters
 	 *  Send interrupt when 64 (0x4 * 16) filters are left
 	 */
 	fdirctrl |= IXGBE_FDIRCTRL_PERFECT_MATCH |
+		    IXGBE_FDIRCTRL_REPORT_STATUS |
 		    (IXGBE_FDIR_DROP_QUEUE << IXGBE_FDIRCTRL_DROP_Q_SHIFT) |
 		    (0x6 << IXGBE_FDIRCTRL_FLEX_SHIFT) |
 		    (0xA << IXGBE_FDIRCTRL_MAX_LENGTH_SHIFT) |
 		    (4 << IXGBE_FDIRCTRL_FULL_THRESH_SHIFT);
 
+	if (cloud_mode)
+		fdirctrl |=(IXGBE_FDIRCTRL_FILTERMODE_CLOUD <<
+					IXGBE_FDIRCTRL_FILTERMODE_SHIFT);
+
 	/* write hashes and fdirctrl register, poll for completion */
 	ixgbe_fdir_enable_82599(hw, fdirctrl);
 
-	return 0;
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_set_fdir_drop_queue_82599 - Set Flow Director drop queue
+ *  @hw: pointer to hardware structure
+ *  @dropqueue: Rx queue index used for the dropped packets
+ **/
+void ixgbe_set_fdir_drop_queue_82599(struct ixgbe_hw *hw, u8 dropqueue)
+{
+	u32 fdirctrl;
+
+	DEBUGFUNC("ixgbe_set_fdir_drop_queue_82599");
+	/* Clear init done bit and drop queue field */
+	fdirctrl = IXGBE_READ_REG(hw, IXGBE_FDIRCTRL);
+	fdirctrl &= ~(IXGBE_FDIRCTRL_DROP_Q_MASK | IXGBE_FDIRCTRL_INIT_DONE);
+
+	/* Set drop queue */
+	fdirctrl |= (dropqueue << IXGBE_FDIRCTRL_DROP_Q_SHIFT);
+	if ((hw->mac.type == ixgbe_mac_X550) ||
+	    (hw->mac.type == ixgbe_mac_X550EM_x) ||
+	    (hw->mac.type == ixgbe_mac_X550EM_a))
+		fdirctrl |= IXGBE_FDIRCTRL_DROP_NO_MATCH;
+
+	IXGBE_WRITE_REG(hw, IXGBE_FDIRCMD,
+			(IXGBE_READ_REG(hw, IXGBE_FDIRCMD) |
+			 IXGBE_FDIRCMD_CLEARHT));
+	IXGBE_WRITE_FLUSH(hw);
+	IXGBE_WRITE_REG(hw, IXGBE_FDIRCMD,
+			(IXGBE_READ_REG(hw, IXGBE_FDIRCMD) &
+			 ~IXGBE_FDIRCMD_CLEARHT));
+	IXGBE_WRITE_FLUSH(hw);
+
+	/* write hashes and fdirctrl register, poll for completion */
+	ixgbe_fdir_enable_82599(hw, fdirctrl);
 }
 
 /*
@@ -1310,22 +1447,22 @@ do { \
  *  @stream: input bitstream to compute the hash on
  *
  *  This function is almost identical to the function above but contains
- *  several optomizations such as unwinding all of the loops, letting the
+ *  several optimizations such as unwinding all of the loops, letting the
  *  compiler work out all of the conditional ifs since the keys are static
  *  defines, and computing two keys at once since the hashed dword stream
  *  will be the same for both keys.
  **/
-static u32 ixgbe_atr_compute_sig_hash_82599(union ixgbe_atr_hash_dword input,
-					    union ixgbe_atr_hash_dword common)
+u32 ixgbe_atr_compute_sig_hash_82599(union ixgbe_atr_hash_dword input,
+				     union ixgbe_atr_hash_dword common)
 {
 	u32 hi_hash_dword, lo_hash_dword, flow_vm_vlan;
 	u32 sig_hash = 0, bucket_hash = 0, common_hash = 0;
 
 	/* record the flow_vm_vlan bits as they are a key part to the hash */
-	flow_vm_vlan = ntohl(input.dword);
+	flow_vm_vlan = IXGBE_NTOHL(input.dword);
 
 	/* generate common hash dword */
-	hi_hash_dword = ntohl(common.dword);
+	hi_hash_dword = IXGBE_NTOHL(common.dword);
 
 	/* low dword is word swapped version of common */
 	lo_hash_dword = (hi_hash_dword >> 16) | (hi_hash_dword << 16);
@@ -1339,7 +1476,7 @@ static u32 ixgbe_atr_compute_sig_hash_82599(union ixgbe_atr_hash_dword input,
 	/*
 	 * apply flow ID/VM pool/VLAN ID bits to lo hash dword, we had to
 	 * delay this because bit 0 of the stream should not be processed
-	 * so we do not add the vlan until after bit 0 was processed
+	 * so we do not add the VLAN until after bit 0 was processed
 	 */
 	lo_hash_dword ^= flow_vm_vlan ^ (flow_vm_vlan << 16);
 
@@ -1381,19 +1518,22 @@ static u32 ixgbe_atr_compute_sig_hash_82599(union ixgbe_atr_hash_dword input,
  * Note that the tunnel bit in input must not be set when the hardware
  * tunneling support does not exist.
  **/
-s32 ixgbe_fdir_add_signature_filter_82599(struct ixgbe_hw *hw,
-					  union ixgbe_atr_hash_dword input,
-					  union ixgbe_atr_hash_dword common,
-					  u8 queue)
+void ixgbe_fdir_add_signature_filter_82599(struct ixgbe_hw *hw,
+					   union ixgbe_atr_hash_dword input,
+					   union ixgbe_atr_hash_dword common,
+					   u8 queue)
 {
 	u64 fdirhashcmd;
 	u8 flow_type;
 	bool tunnel;
 	u32 fdircmd;
 
+	DEBUGFUNC("ixgbe_fdir_add_signature_filter_82599");
+
 	/*
 	 * Get the flow_type in order to program FDIRCMD properly
 	 * lowest 2 bits are FDIRCMD.L4TYPE, third lowest bit is FDIRCMD.IPV6
+	 * fifth is FDIRCMD.TUNNEL_FILTER
 	 */
 	tunnel = !!(input.formatted.flow_type & IXGBE_ATR_L4TYPE_TUNNEL_MASK);
 	flow_type = input.formatted.flow_type &
@@ -1407,8 +1547,8 @@ s32 ixgbe_fdir_add_signature_filter_82599(struct ixgbe_hw *hw,
 	case IXGBE_ATR_FLOW_TYPE_SCTPV6:
 		break;
 	default:
-		hw_dbg(hw, " Error on flow type input\n");
-		return IXGBE_ERR_CONFIG;
+		DEBUGOUT(" Error on flow type input\n");
+		return;
 	}
 
 	/* configure FDIRCMD register */
@@ -1427,9 +1567,9 @@ s32 ixgbe_fdir_add_signature_filter_82599(struct ixgbe_hw *hw,
 	fdirhashcmd |= ixgbe_atr_compute_sig_hash_82599(input, common);
 	IXGBE_WRITE_REG64(hw, IXGBE_FDIRHASH, fdirhashcmd);
 
-	hw_dbg(hw, "Tx Queue=%x hash=%x\n", queue, (u32)fdirhashcmd);
+	DEBUGOUT2("Tx Queue=%x hash=%x\n", queue, (u32)fdirhashcmd);
 
-	return 0;
+	return;
 }
 
 #define IXGBE_COMPUTE_BKT_HASH_ITERATION(_n) \
@@ -1446,7 +1586,7 @@ do { \
  *  @atr_input: input bitstream to compute the hash on
  *  @input_mask: mask for the input bitstream
  *
- *  This function serves two main purposes.  First it applys the input_mask
+ *  This function serves two main purposes.  First it applies the input_mask
  *  to the atr_input resulting in a cleaned up atr_input data stream.
  *  Secondly it computes the hash and stores it in the bkt_hash field at
  *  the end of the input byte stream.  This way it will be available for
@@ -1457,20 +1597,21 @@ void ixgbe_atr_compute_perfect_hash_82599(union ixgbe_atr_input *input,
 {
 
 	u32 hi_hash_dword, lo_hash_dword, flow_vm_vlan;
-	u32 bucket_hash = 0, hi_dword = 0;
-	int i;
+	u32 bucket_hash = 0;
+	u32 hi_dword = 0;
+	u32 i = 0;
 
 	/* Apply masks to input data */
-	for (i = 0; i <= 10; i++)
-		input->dword_stream[i] &= input_mask->dword_stream[i];
+	for (i = 0; i < 14; i++)
+		input->dword_stream[i]  &= input_mask->dword_stream[i];
 
 	/* record the flow_vm_vlan bits as they are a key part to the hash */
-	flow_vm_vlan = ntohl(input->dword_stream[0]);
+	flow_vm_vlan = IXGBE_NTOHL(input->dword_stream[0]);
 
 	/* generate common hash dword */
-	for (i = 1; i <= 10; i++)
+	for (i = 1; i <= 13; i++)
 		hi_dword ^= input->dword_stream[i];
-	hi_hash_dword = ntohl(hi_dword);
+	hi_hash_dword = IXGBE_NTOHL(hi_dword);
 
 	/* low dword is word swapped version of common */
 	lo_hash_dword = (hi_hash_dword >> 16) | (hi_hash_dword << 16);
@@ -1484,7 +1625,7 @@ void ixgbe_atr_compute_perfect_hash_82599(union ixgbe_atr_input *input,
 	/*
 	 * apply flow ID/VM pool/VLAN ID bits to lo hash dword, we had to
 	 * delay this because bit 0 of the stream should not be processed
-	 * so we do not add the vlan until after bit 0 was processed
+	 * so we do not add the VLAN until after bit 0 was processed
 	 */
 	lo_hash_dword ^= flow_vm_vlan ^ (flow_vm_vlan << 16);
 
@@ -1500,7 +1641,7 @@ void ixgbe_atr_compute_perfect_hash_82599(union ixgbe_atr_input *input,
 }
 
 /**
- *  ixgbe_get_fdirtcpm_82599 - generate a tcp port from atr_input_masks
+ *  ixgbe_get_fdirtcpm_82599 - generate a TCP port from atr_input_masks
  *  @input_mask: mask to be bit swapped
  *
  *  The source and destination port masks for flow director are bit swapped
@@ -1508,12 +1649,11 @@ void ixgbe_atr_compute_perfect_hash_82599(union ixgbe_atr_input *input,
  *  generate a correctly swapped value we need to bit swap the mask and that
  *  is what is accomplished by this function.
  **/
-static u32 ixgbe_get_fdirtcpm_82599(union ixgbe_atr_input *input_mask)
+STATIC u32 ixgbe_get_fdirtcpm_82599(union ixgbe_atr_input *input_mask)
 {
-	u32 mask = ntohs(input_mask->formatted.dst_port);
-
+	u32 mask = IXGBE_NTOHS(input_mask->formatted.dst_port);
 	mask <<= IXGBE_FDIRTCPM_DPORTM_SHIFT;
-	mask |= ntohs(input_mask->formatted.src_port);
+	mask |= IXGBE_NTOHS(input_mask->formatted.src_port);
 	mask = ((mask & 0x55555555) << 1) | ((mask & 0xAAAAAAAA) >> 1);
 	mask = ((mask & 0x33333333) << 2) | ((mask & 0xCCCCCCCC) >> 2);
 	mask = ((mask & 0x0F0F0F0F) << 4) | ((mask & 0xF0F0F0F0) >> 4);
@@ -1532,17 +1672,19 @@ static u32 ixgbe_get_fdirtcpm_82599(union ixgbe_atr_input *input_mask)
 	 (((u32)(_value) & 0x0000FF00) << 8) | ((u32)(_value) << 24))
 
 #define IXGBE_WRITE_REG_BE32(a, reg, value) \
-	IXGBE_WRITE_REG((a), (reg), IXGBE_STORE_AS_BE32(ntohl(value)))
+	IXGBE_WRITE_REG((a), (reg), IXGBE_STORE_AS_BE32(IXGBE_NTOHL(value)))
 
 #define IXGBE_STORE_AS_BE16(_value) \
-	ntohs(((u16)(_value) >> 8) | ((u16)(_value) << 8))
+	IXGBE_NTOHS(((u16)(_value) >> 8) | ((u16)(_value) << 8))
 
 s32 ixgbe_fdir_set_input_mask_82599(struct ixgbe_hw *hw,
-				    union ixgbe_atr_input *input_mask)
+				    union ixgbe_atr_input *input_mask, bool cloud_mode)
 {
 	/* mask IPv6 since it is currently not supported */
 	u32 fdirm = IXGBE_FDIRM_DIPv6;
 	u32 fdirtcpm;
+	u32 fdirip6m;
+	DEBUGFUNC("ixgbe_fdir_set_atr_input_mask_82599");
 
 	/*
 	 * Program the relevant mask registers.  If src/dst_port or src/dst_addr
@@ -1556,7 +1698,7 @@ s32 ixgbe_fdir_set_input_mask_82599(struct ixgbe_hw *hw,
 
 	/* verify bucket hash is cleared on hash generation */
 	if (input_mask->formatted.bkt_hash)
-		hw_dbg(hw, " bucket hash should always be 0 in mask\n");
+		DEBUGOUT(" bucket hash should always be 0 in mask\n");
 
 	/* Program FDIRM and verify partial masks */
 	switch (input_mask->formatted.vm_pool & 0x7F) {
@@ -1565,7 +1707,7 @@ s32 ixgbe_fdir_set_input_mask_82599(struct ixgbe_hw *hw,
 	case 0x7F:
 		break;
 	default:
-		hw_dbg(hw, " Error on vm pool mask\n");
+		DEBUGOUT(" Error on vm pool mask\n");
 		return IXGBE_ERR_CONFIG;
 	}
 
@@ -1574,108 +1716,199 @@ s32 ixgbe_fdir_set_input_mask_82599(struct ixgbe_hw *hw,
 		fdirm |= IXGBE_FDIRM_L4P;
 		if (input_mask->formatted.dst_port ||
 		    input_mask->formatted.src_port) {
-			hw_dbg(hw, " Error on src/dst port mask\n");
+			DEBUGOUT(" Error on src/dst port mask\n");
 			return IXGBE_ERR_CONFIG;
 		}
 	case IXGBE_ATR_L4TYPE_MASK:
 		break;
 	default:
-		hw_dbg(hw, " Error on flow type mask\n");
+		DEBUGOUT(" Error on flow type mask\n");
 		return IXGBE_ERR_CONFIG;
 	}
 
-	switch (ntohs(input_mask->formatted.vlan_id) & 0xEFFF) {
+	switch (IXGBE_NTOHS(input_mask->formatted.vlan_id) & 0xEFFF) {
 	case 0x0000:
-		/* mask VLAN ID, fall through to mask VLAN priority */
+		/* mask VLAN ID */
 		fdirm |= IXGBE_FDIRM_VLANID;
+		/* fall through */
 	case 0x0FFF:
 		/* mask VLAN priority */
 		fdirm |= IXGBE_FDIRM_VLANP;
 		break;
 	case 0xE000:
-		/* mask VLAN ID only, fall through */
+		/* mask VLAN ID only */
 		fdirm |= IXGBE_FDIRM_VLANID;
+		/* fall through */
 	case 0xEFFF:
 		/* no VLAN fields masked */
 		break;
 	default:
-		hw_dbg(hw, " Error on VLAN mask\n");
+		DEBUGOUT(" Error on VLAN mask\n");
 		return IXGBE_ERR_CONFIG;
 	}
 
 	switch (input_mask->formatted.flex_bytes & 0xFFFF) {
 	case 0x0000:
-		/* Mask Flex Bytes, fall through */
+		/* Mask Flex Bytes */
 		fdirm |= IXGBE_FDIRM_FLEX;
+		/* fall through */
 	case 0xFFFF:
 		break;
 	default:
-		hw_dbg(hw, " Error on flexible byte mask\n");
+		DEBUGOUT(" Error on flexible byte mask\n");
 		return IXGBE_ERR_CONFIG;
 	}
 
-	/* Now mask VM pool and destination IPv6 - bits 5 and 2 */
-	IXGBE_WRITE_REG(hw, IXGBE_FDIRM, fdirm);
+	if (cloud_mode) {
+		fdirm |= IXGBE_FDIRM_L3P;
+		fdirip6m = ((u32) 0xFFFFU << IXGBE_FDIRIP6M_DIPM_SHIFT);
+		fdirip6m |= IXGBE_FDIRIP6M_ALWAYS_MASK;
 
-	/* store the TCP/UDP port masks, bit reversed from port layout */
-	fdirtcpm = ixgbe_get_fdirtcpm_82599(input_mask);
+		switch (input_mask->formatted.inner_mac[0] & 0xFF) {
+		case 0x00:
+			/* Mask inner MAC, fall through */
+			fdirip6m |= IXGBE_FDIRIP6M_INNER_MAC;
+		case 0xFF:
+			break;
+		default:
+			DEBUGOUT(" Error on inner_mac byte mask\n");
+			return IXGBE_ERR_CONFIG;
+		}
 
-	/* write both the same so that UDP and TCP use the same mask */
-	IXGBE_WRITE_REG(hw, IXGBE_FDIRTCPM, ~fdirtcpm);
-	IXGBE_WRITE_REG(hw, IXGBE_FDIRUDPM, ~fdirtcpm);
+		switch (input_mask->formatted.tni_vni & 0xFFFFFFFF) {
+		case 0x0:
+			/* Mask vxlan id */
+			fdirip6m |= IXGBE_FDIRIP6M_TNI_VNI;
+			break;
+		case 0x00FFFFFF:
+			fdirip6m |= IXGBE_FDIRIP6M_TNI_VNI_24;
+			break;
+		case 0xFFFFFFFF:
+			break;
+		default:
+			DEBUGOUT(" Error on TNI/VNI byte mask\n");
+			return IXGBE_ERR_CONFIG;
+		}
 
-	/* also use it for SCTP */
-	switch (hw->mac.type) {
-	case ixgbe_mac_X550:
-	case ixgbe_mac_X550EM_x:
-		IXGBE_WRITE_REG(hw, IXGBE_FDIRSCTPM, ~fdirtcpm);
-		break;
-	default:
-		break;
+		switch (input_mask->formatted.tunnel_type & 0xFFFF) {
+		case 0x0:
+			/* Mask turnnel type, fall through */
+			fdirip6m |= IXGBE_FDIRIP6M_TUNNEL_TYPE;
+		case 0xFFFF:
+			break;
+		default:
+			DEBUGOUT(" Error on tunnel type byte mask\n");
+			return IXGBE_ERR_CONFIG;
+		}
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRIP6M, fdirip6m);
+
+		/* Set all bits in FDIRTCPM, FDIRUDPM, FDIRSCTPM,
+		 * FDIRSIP4M and FDIRDIP4M in cloud mode to allow
+		 * L3/L3 packets to tunnel.
+		 */
+		IXGBE_WRITE_REG(hw, IXGBE_FDIRTCPM, 0xFFFFFFFF);
+		IXGBE_WRITE_REG(hw, IXGBE_FDIRUDPM, 0xFFFFFFFF);
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRDIP4M, 0xFFFFFFFF);
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIP4M, 0xFFFFFFFF);
+		switch (hw->mac.type) {
+		case ixgbe_mac_X550:
+		case ixgbe_mac_X550EM_x:
+		case ixgbe_mac_X550EM_a:
+			IXGBE_WRITE_REG(hw, IXGBE_FDIRSCTPM, 0xFFFFFFFF);
+			break;
+		default:
+			break;
+		}
 	}
 
-	/* store source and destination IP masks (big-enian) */
-	IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIP4M,
-			     ~input_mask->formatted.src_ip[0]);
-	IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRDIP4M,
-			     ~input_mask->formatted.dst_ip[0]);
+	/* Now mask VM pool and destination IPv6 - bits 5 and 2 */
+	IXGBE_WRITE_REG(hw, IXGBE_FDIRM, fdirm);
+
+	if (!cloud_mode) {
+		/* store the TCP/UDP port masks, bit reversed from port
+		 * layout */
+		fdirtcpm = ixgbe_get_fdirtcpm_82599(input_mask);
+
+		/* write both the same so that UDP and TCP use the same mask */
+		IXGBE_WRITE_REG(hw, IXGBE_FDIRTCPM, ~fdirtcpm);
+		IXGBE_WRITE_REG(hw, IXGBE_FDIRUDPM, ~fdirtcpm);
+		/* also use it for SCTP */
+		switch (hw->mac.type) {
+		case ixgbe_mac_X550:
+		case ixgbe_mac_X550EM_x:
+		case ixgbe_mac_X550EM_a:
+			IXGBE_WRITE_REG(hw, IXGBE_FDIRSCTPM, ~fdirtcpm);
+			break;
+		default:
+			break;
+		}
 
-	return 0;
+		/* store source and destination IP masks (big-enian) */
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIP4M,
+				     ~input_mask->formatted.src_ip[0]);
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRDIP4M,
+				     ~input_mask->formatted.dst_ip[0]);
+	}
+	return IXGBE_SUCCESS;
 }
 
 s32 ixgbe_fdir_write_perfect_filter_82599(struct ixgbe_hw *hw,
 					  union ixgbe_atr_input *input,
-					  u16 soft_id, u8 queue)
+					  u16 soft_id, u8 queue, bool cloud_mode)
 {
 	u32 fdirport, fdirvlan, fdirhash, fdircmd;
+	u32 addr_low, addr_high;
+	u32 cloud_type = 0;
 	s32 err;
 
-	/* currently IPv6 is not supported, must be programmed with 0 */
-	IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIPv6(0),
-			     input->formatted.src_ip[0]);
-	IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIPv6(1),
-			     input->formatted.src_ip[1]);
-	IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIPv6(2),
-			     input->formatted.src_ip[2]);
-
-	/* record the source address (big-endian) */
-	IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRIPSA, input->formatted.src_ip[0]);
-
-	/* record the first 32 bits of the destination address (big-endian) */
-	IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRIPDA, input->formatted.dst_ip[0]);
-
-	/* record source and destination port (little-endian)*/
-	fdirport = ntohs(input->formatted.dst_port);
-	fdirport <<= IXGBE_FDIRPORT_DESTINATION_SHIFT;
-	fdirport |= ntohs(input->formatted.src_port);
-	IXGBE_WRITE_REG(hw, IXGBE_FDIRPORT, fdirport);
+	DEBUGFUNC("ixgbe_fdir_write_perfect_filter_82599");
+	if (!cloud_mode) {
+		/* currently IPv6 is not supported, must be programmed with 0 */
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIPv6(0),
+				     input->formatted.src_ip[0]);
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIPv6(1),
+				     input->formatted.src_ip[1]);
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIPv6(2),
+				     input->formatted.src_ip[2]);
+
+		/* record the source address (big-endian) */
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRIPSA,
+			input->formatted.src_ip[0]);
+
+		/* record the first 32 bits of the destination address
+		 * (big-endian) */
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRIPDA,
+			input->formatted.dst_ip[0]);
+
+		/* record source and destination port (little-endian)*/
+		fdirport = IXGBE_NTOHS(input->formatted.dst_port);
+		fdirport <<= IXGBE_FDIRPORT_DESTINATION_SHIFT;
+		fdirport |= IXGBE_NTOHS(input->formatted.src_port);
+		IXGBE_WRITE_REG(hw, IXGBE_FDIRPORT, fdirport);
+	}
 
-	/* record vlan (little-endian) and flex_bytes(big-endian) */
+	/* record VLAN (little-endian) and flex_bytes(big-endian) */
 	fdirvlan = IXGBE_STORE_AS_BE16(input->formatted.flex_bytes);
 	fdirvlan <<= IXGBE_FDIRVLAN_FLEX_SHIFT;
-	fdirvlan |= ntohs(input->formatted.vlan_id);
+	fdirvlan |= IXGBE_NTOHS(input->formatted.vlan_id);
 	IXGBE_WRITE_REG(hw, IXGBE_FDIRVLAN, fdirvlan);
 
+	if (cloud_mode) {
+		if (input->formatted.tunnel_type != 0)
+			cloud_type = 0x80000000;
+
+		addr_low = ((u32)input->formatted.inner_mac[0] |
+				((u32)input->formatted.inner_mac[1] << 8) |
+				((u32)input->formatted.inner_mac[2] << 16) |
+				((u32)input->formatted.inner_mac[3] << 24));
+		addr_high = ((u32)input->formatted.inner_mac[4] |
+				((u32)input->formatted.inner_mac[5] << 8));
+		cloud_type |= addr_high;
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIPv6(0), addr_low);
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIPv6(1), cloud_type);
+		IXGBE_WRITE_REG_BE32(hw, IXGBE_FDIRSIPv6(2), input->formatted.tni_vni);
+	}
+
 	/* configure FDIRHASH register */
 	fdirhash = input->formatted.bkt_hash;
 	fdirhash |= soft_id << IXGBE_FDIRHASH_SIG_SW_INDEX_SHIFT;
@@ -1692,6 +1925,8 @@ s32 ixgbe_fdir_write_perfect_filter_82599(struct ixgbe_hw *hw,
 		  IXGBE_FDIRCMD_LAST | IXGBE_FDIRCMD_QUEUE_EN;
 	if (queue == IXGBE_FDIR_DROP_QUEUE)
 		fdircmd |= IXGBE_FDIRCMD_DROP;
+	if (input->formatted.flow_type & IXGBE_ATR_L4TYPE_TUNNEL_MASK)
+		fdircmd |= IXGBE_FDIRCMD_TUNNEL_FILTER;
 	fdircmd |= input->formatted.flow_type << IXGBE_FDIRCMD_FLOW_TYPE_SHIFT;
 	fdircmd |= (u32)queue << IXGBE_FDIRCMD_RX_QUEUE_SHIFT;
 	fdircmd |= (u32)input->formatted.vm_pool << IXGBE_FDIRCMD_VT_POOL_SHIFT;
@@ -1699,11 +1934,11 @@ s32 ixgbe_fdir_write_perfect_filter_82599(struct ixgbe_hw *hw,
 	IXGBE_WRITE_REG(hw, IXGBE_FDIRCMD, fdircmd);
 	err = ixgbe_fdir_check_cmd_complete(hw, &fdircmd);
 	if (err) {
-		hw_dbg(hw, "Flow Director command did not complete!\n");
+		DEBUGOUT("Flow Director command did not complete!\n");
 		return err;
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 s32 ixgbe_fdir_erase_perfect_filter_82599(struct ixgbe_hw *hw,
@@ -1727,7 +1962,7 @@ s32 ixgbe_fdir_erase_perfect_filter_82599(struct ixgbe_hw *hw,
 
 	err = ixgbe_fdir_check_cmd_complete(hw, &fdircmd);
 	if (err) {
-		hw_dbg(hw, "Flow Director command did not complete!\n");
+		DEBUGOUT("Flow Director command did not complete!\n");
 		return err;
 	}
 
@@ -1739,7 +1974,72 @@ s32 ixgbe_fdir_erase_perfect_filter_82599(struct ixgbe_hw *hw,
 				IXGBE_FDIRCMD_CMD_REMOVE_FLOW);
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_fdir_add_perfect_filter_82599 - Adds a perfect filter
+ *  @hw: pointer to hardware structure
+ *  @input: input bitstream
+ *  @input_mask: mask for the input bitstream
+ *  @soft_id: software index for the filters
+ *  @queue: queue index to direct traffic to
+ *
+ *  Note that the caller to this function must lock before calling, since the
+ *  hardware writes must be protected from one another.
+ **/
+s32 ixgbe_fdir_add_perfect_filter_82599(struct ixgbe_hw *hw,
+					union ixgbe_atr_input *input,
+					union ixgbe_atr_input *input_mask,
+					u16 soft_id, u8 queue, bool cloud_mode)
+{
+	s32 err = IXGBE_ERR_CONFIG;
+
+	DEBUGFUNC("ixgbe_fdir_add_perfect_filter_82599");
+
+	/*
+	 * Check flow_type formatting, and bail out before we touch the hardware
+	 * if there's a configuration issue
+	 */
+	switch (input->formatted.flow_type) {
+	case IXGBE_ATR_FLOW_TYPE_IPV4:
+	case IXGBE_ATR_FLOW_TYPE_TUNNELED_IPV4:
+		input_mask->formatted.flow_type = IXGBE_ATR_L4TYPE_IPV6_MASK;
+		if (input->formatted.dst_port || input->formatted.src_port) {
+			DEBUGOUT(" Error on src/dst port\n");
+			return IXGBE_ERR_CONFIG;
+		}
+		break;
+	case IXGBE_ATR_FLOW_TYPE_SCTPV4:
+	case IXGBE_ATR_FLOW_TYPE_TUNNELED_SCTPV4:
+		if (input->formatted.dst_port || input->formatted.src_port) {
+			DEBUGOUT(" Error on src/dst port\n");
+			return IXGBE_ERR_CONFIG;
+		}
+		/* fall through */
+	case IXGBE_ATR_FLOW_TYPE_TCPV4:
+	case IXGBE_ATR_FLOW_TYPE_TUNNELED_TCPV4:
+	case IXGBE_ATR_FLOW_TYPE_UDPV4:
+	case IXGBE_ATR_FLOW_TYPE_TUNNELED_UDPV4:
+		input_mask->formatted.flow_type = IXGBE_ATR_L4TYPE_IPV6_MASK |
+						  IXGBE_ATR_L4TYPE_MASK;
+		break;
+	default:
+		DEBUGOUT(" Error on flow type input\n");
+		return err;
+	}
+
+	/* program input mask into the HW */
+	err = ixgbe_fdir_set_input_mask_82599(hw, input_mask, cloud_mode);
+	if (err)
+		return err;
+
+	/* apply mask and compute/store hash */
+	ixgbe_atr_compute_perfect_hash_82599(input, input_mask);
+
+	/* program filters to filter memory */
+	return ixgbe_fdir_write_perfect_filter_82599(hw, input,
+						     soft_id, queue, cloud_mode);
 }
 
 /**
@@ -1750,18 +2050,20 @@ s32 ixgbe_fdir_erase_perfect_filter_82599(struct ixgbe_hw *hw,
  *
  *  Performs read operation to Omer analog register specified.
  **/
-static s32 ixgbe_read_analog_reg8_82599(struct ixgbe_hw *hw, u32 reg, u8 *val)
+s32 ixgbe_read_analog_reg8_82599(struct ixgbe_hw *hw, u32 reg, u8 *val)
 {
 	u32  core_ctl;
 
+	DEBUGFUNC("ixgbe_read_analog_reg8_82599");
+
 	IXGBE_WRITE_REG(hw, IXGBE_CORECTL, IXGBE_CORECTL_WRITE_CMD |
 			(reg << 8));
 	IXGBE_WRITE_FLUSH(hw);
-	udelay(10);
+	usec_delay(10);
 	core_ctl = IXGBE_READ_REG(hw, IXGBE_CORECTL);
 	*val = (u8)core_ctl;
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -1772,16 +2074,18 @@ static s32 ixgbe_read_analog_reg8_82599(struct ixgbe_hw *hw, u32 reg, u8 *val)
  *
  *  Performs write operation to Omer analog register specified.
  **/
-static s32 ixgbe_write_analog_reg8_82599(struct ixgbe_hw *hw, u32 reg, u8 val)
+s32 ixgbe_write_analog_reg8_82599(struct ixgbe_hw *hw, u32 reg, u8 val)
 {
 	u32  core_ctl;
 
+	DEBUGFUNC("ixgbe_write_analog_reg8_82599");
+
 	core_ctl = (reg << 8) | val;
 	IXGBE_WRITE_REG(hw, IXGBE_CORECTL, core_ctl);
 	IXGBE_WRITE_FLUSH(hw);
-	udelay(10);
+	usec_delay(10);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -1792,25 +2096,27 @@ static s32 ixgbe_write_analog_reg8_82599(struct ixgbe_hw *hw, u32 reg, u8 val)
  *  and the generation start_hw function.
  *  Then performs revision-specific operations, if any.
  **/
-static s32 ixgbe_start_hw_82599(struct ixgbe_hw *hw)
+s32 ixgbe_start_hw_82599(struct ixgbe_hw *hw)
 {
-	s32 ret_val = 0;
+	s32 ret_val = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_start_hw_82599");
 
 	ret_val = ixgbe_start_hw_generic(hw);
-	if (ret_val)
-		return ret_val;
+	if (ret_val != IXGBE_SUCCESS)
+		goto out;
 
 	ret_val = ixgbe_start_hw_gen2(hw);
-	if (ret_val)
-		return ret_val;
+	if (ret_val != IXGBE_SUCCESS)
+		goto out;
 
 	/* We need to run link autotry after the driver loads */
 	hw->mac.autotry_restart = true;
 
-	if (ret_val)
-		return ret_val;
-
-	return ixgbe_verify_fw_version_82599(hw);
+	if (ret_val == IXGBE_SUCCESS)
+		ret_val = ixgbe_verify_fw_version_82599(hw);
+out:
+	return ret_val;
 }
 
 /**
@@ -1821,23 +2127,26 @@ static s32 ixgbe_start_hw_82599(struct ixgbe_hw *hw)
  *  If PHY already detected, maintains current PHY type in hw struct,
  *  otherwise executes the PHY detection routine.
  **/
-static s32 ixgbe_identify_phy_82599(struct ixgbe_hw *hw)
+s32 ixgbe_identify_phy_82599(struct ixgbe_hw *hw)
 {
 	s32 status;
 
+	DEBUGFUNC("ixgbe_identify_phy_82599");
+
 	/* Detect PHY if not unknown - returns success if already detected. */
 	status = ixgbe_identify_phy_generic(hw);
-	if (status) {
+	if (status != IXGBE_SUCCESS) {
 		/* 82599 10GBASE-T requires an external PHY */
 		if (hw->mac.ops.get_media_type(hw) == ixgbe_media_type_copper)
 			return status;
-		status = ixgbe_identify_module_generic(hw);
+		else
+			status = ixgbe_identify_module_generic(hw);
 	}
 
 	/* Set PHY type none if no PHY detected */
 	if (hw->phy.type == ixgbe_phy_unknown) {
 		hw->phy.type = ixgbe_phy_none;
-		status = 0;
+		return IXGBE_SUCCESS;
 	}
 
 	/* Return error if SFP module has been detected but is not supported */
@@ -1848,34 +2157,125 @@ static s32 ixgbe_identify_phy_82599(struct ixgbe_hw *hw)
 }
 
 /**
+ *  ixgbe_get_supported_physical_layer_82599 - Returns physical layer type
+ *  @hw: pointer to hardware structure
+ *
+ *  Determines physical layer capabilities of the current configuration.
+ **/
+u64 ixgbe_get_supported_physical_layer_82599(struct ixgbe_hw *hw)
+{
+	u64 physical_layer = IXGBE_PHYSICAL_LAYER_UNKNOWN;
+	u32 autoc = IXGBE_READ_REG(hw, IXGBE_AUTOC);
+	u32 autoc2 = IXGBE_READ_REG(hw, IXGBE_AUTOC2);
+	u32 pma_pmd_10g_serial = autoc2 & IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_MASK;
+	u32 pma_pmd_10g_parallel = autoc & IXGBE_AUTOC_10G_PMA_PMD_MASK;
+	u32 pma_pmd_1g = autoc & IXGBE_AUTOC_1G_PMA_PMD_MASK;
+	u16 ext_ability = 0;
+
+	DEBUGFUNC("ixgbe_get_support_physical_layer_82599");
+
+	hw->phy.ops.identify(hw);
+
+	switch (hw->phy.type) {
+	case ixgbe_phy_tn:
+	case ixgbe_phy_cu_unknown:
+		hw->phy.ops.read_reg(hw, IXGBE_MDIO_PHY_EXT_ABILITY,
+		IXGBE_MDIO_PMA_PMD_DEV_TYPE, &ext_ability);
+		if (ext_ability & IXGBE_MDIO_PHY_10GBASET_ABILITY)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_10GBASE_T;
+		if (ext_ability & IXGBE_MDIO_PHY_1000BASET_ABILITY)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_1000BASE_T;
+		if (ext_ability & IXGBE_MDIO_PHY_100BASETX_ABILITY)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_100BASE_TX;
+		goto out;
+	default:
+		break;
+	}
+
+	switch (autoc & IXGBE_AUTOC_LMS_MASK) {
+	case IXGBE_AUTOC_LMS_1G_AN:
+	case IXGBE_AUTOC_LMS_1G_LINK_NO_AN:
+		if (pma_pmd_1g == IXGBE_AUTOC_1G_KX_BX) {
+			physical_layer = IXGBE_PHYSICAL_LAYER_1000BASE_KX |
+			    IXGBE_PHYSICAL_LAYER_1000BASE_BX;
+			goto out;
+		} else
+			/* SFI mode so read SFP module */
+			goto sfp_check;
+		break;
+	case IXGBE_AUTOC_LMS_10G_LINK_NO_AN:
+		if (pma_pmd_10g_parallel == IXGBE_AUTOC_10G_CX4)
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_CX4;
+		else if (pma_pmd_10g_parallel == IXGBE_AUTOC_10G_KX4)
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_KX4;
+		else if (pma_pmd_10g_parallel == IXGBE_AUTOC_10G_XAUI)
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_XAUI;
+		goto out;
+		break;
+	case IXGBE_AUTOC_LMS_10G_SERIAL:
+		if (pma_pmd_10g_serial == IXGBE_AUTOC2_10G_KR) {
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_KR;
+			goto out;
+		} else if (pma_pmd_10g_serial == IXGBE_AUTOC2_10G_SFI)
+			goto sfp_check;
+		break;
+	case IXGBE_AUTOC_LMS_KX4_KX_KR:
+	case IXGBE_AUTOC_LMS_KX4_KX_KR_1G_AN:
+		if (autoc & IXGBE_AUTOC_KX_SUPP)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_1000BASE_KX;
+		if (autoc & IXGBE_AUTOC_KX4_SUPP)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_10GBASE_KX4;
+		if (autoc & IXGBE_AUTOC_KR_SUPP)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_10GBASE_KR;
+		goto out;
+		break;
+	default:
+		goto out;
+		break;
+	}
+
+sfp_check:
+	/* SFP check must be done last since DA modules are sometimes used to
+	 * test KR mode -  we need to id KR mode correctly before SFP module.
+	 * Call identify_sfp because the pluggable module may have changed */
+	physical_layer = ixgbe_get_supported_phy_sfp_layer_generic(hw);
+out:
+	return physical_layer;
+}
+
+/**
  *  ixgbe_enable_rx_dma_82599 - Enable the Rx DMA unit on 82599
  *  @hw: pointer to hardware structure
  *  @regval: register value to write to RXCTRL
  *
  *  Enables the Rx DMA unit for 82599
  **/
-static s32 ixgbe_enable_rx_dma_82599(struct ixgbe_hw *hw, u32 regval)
+s32 ixgbe_enable_rx_dma_82599(struct ixgbe_hw *hw, u32 regval)
 {
+
+	DEBUGFUNC("ixgbe_enable_rx_dma_82599");
+
 	/*
 	 * Workaround for 82599 silicon errata when enabling the Rx datapath.
 	 * If traffic is incoming before we enable the Rx unit, it could hang
 	 * the Rx DMA unit.  Therefore, make sure the security engine is
 	 * completely disabled prior to enabling the Rx unit.
 	 */
-	hw->mac.ops.disable_rx_buff(hw);
+
+	hw->mac.ops.disable_sec_rx_path(hw);
 
 	if (regval & IXGBE_RXCTRL_RXEN)
-		hw->mac.ops.enable_rx(hw);
+		ixgbe_enable_rx(hw);
 	else
-		hw->mac.ops.disable_rx(hw);
+		ixgbe_disable_rx(hw);
 
-	hw->mac.ops.enable_rx_buff(hw);
+	hw->mac.ops.enable_sec_rx_path(hw);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
- *  ixgbe_verify_fw_version_82599 - verify fw version for 82599
+ *  ixgbe_verify_fw_version_82599 - verify FW version for 82599
  *  @hw: pointer to hardware structure
  *
  *  Verifies that installed the firmware version is 0.6 or higher
@@ -1884,46 +2284,58 @@ static s32 ixgbe_enable_rx_dma_82599(struct ixgbe_hw *hw, u32 regval)
  *  Returns IXGBE_ERR_EEPROM_VERSION if the FW is not present or
  *  if the FW version is not supported.
  **/
-static s32 ixgbe_verify_fw_version_82599(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_verify_fw_version_82599(struct ixgbe_hw *hw)
 {
 	s32 status = IXGBE_ERR_EEPROM_VERSION;
 	u16 fw_offset, fw_ptp_cfg_offset;
-	u16 offset;
-	u16 fw_version = 0;
+	u16 fw_version;
+
+	DEBUGFUNC("ixgbe_verify_fw_version_82599");
 
 	/* firmware check is only necessary for SFI devices */
-	if (hw->phy.media_type != ixgbe_media_type_fiber)
-		return 0;
+	if (hw->phy.media_type != ixgbe_media_type_fiber) {
+		status = IXGBE_SUCCESS;
+		goto fw_version_out;
+	}
 
 	/* get the offset to the Firmware Module block */
-	offset = IXGBE_FW_PTR;
-	if (hw->eeprom.ops.read(hw, offset, &fw_offset))
-		goto fw_version_err;
-
-	if (fw_offset == 0 || fw_offset == 0xFFFF)
+	if (hw->eeprom.ops.read(hw, IXGBE_FW_PTR, &fw_offset)) {
+		ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+			      "eeprom read at offset %d failed", IXGBE_FW_PTR);
 		return IXGBE_ERR_EEPROM_VERSION;
+	}
 
-	/* get the offset to the Pass Through Patch Configuration block */
-	offset = fw_offset + IXGBE_FW_PASSTHROUGH_PATCH_CONFIG_PTR;
-	if (hw->eeprom.ops.read(hw, offset, &fw_ptp_cfg_offset))
-		goto fw_version_err;
+	if ((fw_offset == 0) || (fw_offset == 0xFFFF))
+		goto fw_version_out;
 
-	if (fw_ptp_cfg_offset == 0 || fw_ptp_cfg_offset == 0xFFFF)
+	/* get the offset to the Pass Through Patch Configuration block */
+	if (hw->eeprom.ops.read(hw, (fw_offset +
+				 IXGBE_FW_PASSTHROUGH_PATCH_CONFIG_PTR),
+				 &fw_ptp_cfg_offset)) {
+		ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+			      "eeprom read at offset %d failed",
+			      fw_offset +
+			      IXGBE_FW_PASSTHROUGH_PATCH_CONFIG_PTR);
 		return IXGBE_ERR_EEPROM_VERSION;
+	}
+
+	if ((fw_ptp_cfg_offset == 0) || (fw_ptp_cfg_offset == 0xFFFF))
+		goto fw_version_out;
 
 	/* get the firmware version */
-	offset = fw_ptp_cfg_offset + IXGBE_FW_PATCH_VERSION_4;
-	if (hw->eeprom.ops.read(hw, offset, &fw_version))
-		goto fw_version_err;
+	if (hw->eeprom.ops.read(hw, (fw_ptp_cfg_offset +
+			    IXGBE_FW_PATCH_VERSION_4), &fw_version)) {
+		ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+			      "eeprom read at offset %d failed",
+			      fw_ptp_cfg_offset + IXGBE_FW_PATCH_VERSION_4);
+		return IXGBE_ERR_EEPROM_VERSION;
+	}
 
 	if (fw_version > 0x5)
-		status = 0;
+		status = IXGBE_SUCCESS;
 
+fw_version_out:
 	return status;
-
-fw_version_err:
-	hw_err(hw, "eeprom read at offset %d failed\n", offset);
-	return IXGBE_ERR_EEPROM_VERSION;
 }
 
 /**
@@ -1933,35 +2345,41 @@ fw_version_err:
  *  Returns true if the LESM FW module is present and enabled. Otherwise
  *  returns false. Smart Speed must be disabled if LESM FW module is enabled.
  **/
-static bool ixgbe_verify_lesm_fw_enabled_82599(struct ixgbe_hw *hw)
+bool ixgbe_verify_lesm_fw_enabled_82599(struct ixgbe_hw *hw)
 {
+	bool lesm_enabled = false;
 	u16 fw_offset, fw_lesm_param_offset, fw_lesm_state;
 	s32 status;
 
+	DEBUGFUNC("ixgbe_verify_lesm_fw_enabled_82599");
+
 	/* get the offset to the Firmware Module block */
 	status = hw->eeprom.ops.read(hw, IXGBE_FW_PTR, &fw_offset);
 
-	if (status || fw_offset == 0 || fw_offset == 0xFFFF)
-		return false;
+	if ((status != IXGBE_SUCCESS) ||
+	    (fw_offset == 0) || (fw_offset == 0xFFFF))
+		goto out;
 
 	/* get the offset to the LESM Parameters block */
 	status = hw->eeprom.ops.read(hw, (fw_offset +
 				     IXGBE_FW_LESM_PARAMETERS_PTR),
 				     &fw_lesm_param_offset);
 
-	if (status ||
-	    fw_lesm_param_offset == 0 || fw_lesm_param_offset == 0xFFFF)
-		return false;
+	if ((status != IXGBE_SUCCESS) ||
+	    (fw_lesm_param_offset == 0) || (fw_lesm_param_offset == 0xFFFF))
+		goto out;
 
-	/* get the lesm state word */
+	/* get the LESM state word */
 	status = hw->eeprom.ops.read(hw, (fw_lesm_param_offset +
 				     IXGBE_FW_LESM_STATE_1),
 				     &fw_lesm_state);
 
-	if (!status && (fw_lesm_state & IXGBE_FW_LESM_STATE_ENABLED))
-		return true;
+	if ((status == IXGBE_SUCCESS) &&
+	    (fw_lesm_state & IXGBE_FW_LESM_STATE_ENABLED))
+		lesm_enabled = true;
 
-	return false;
+out:
+	return lesm_enabled;
 }
 
 /**
@@ -1975,20 +2393,28 @@ static bool ixgbe_verify_lesm_fw_enabled_82599(struct ixgbe_hw *hw)
  *
  *  Retrieves 16 bit word(s) read from EEPROM
  **/
-static s32 ixgbe_read_eeprom_buffer_82599(struct ixgbe_hw *hw, u16 offset,
+STATIC s32 ixgbe_read_eeprom_buffer_82599(struct ixgbe_hw *hw, u16 offset,
 					  u16 words, u16 *data)
 {
 	struct ixgbe_eeprom_info *eeprom = &hw->eeprom;
+	s32 ret_val = IXGBE_ERR_CONFIG;
 
-	/* If EEPROM is detected and can be addressed using 14 bits,
+	DEBUGFUNC("ixgbe_read_eeprom_buffer_82599");
+
+	/*
+	 * If EEPROM is detected and can be addressed using 14 bits,
 	 * use EERD otherwise use bit bang
 	 */
-	if (eeprom->type == ixgbe_eeprom_spi &&
-	    offset + (words - 1) <= IXGBE_EERD_MAX_ADDR)
-		return ixgbe_read_eerd_buffer_generic(hw, offset, words, data);
-
-	return ixgbe_read_eeprom_buffer_bit_bang_generic(hw, offset, words,
+	if ((eeprom->type == ixgbe_eeprom_spi) &&
+	    (offset + (words - 1) <= IXGBE_EERD_MAX_ADDR))
+		ret_val = ixgbe_read_eerd_buffer_generic(hw, offset, words,
 							 data);
+	else
+		ret_val = ixgbe_read_eeprom_buffer_bit_bang_generic(hw, offset,
+								    words,
+								    data);
+
+	return ret_val;
 }
 
 /**
@@ -2001,31 +2427,36 @@ static s32 ixgbe_read_eeprom_buffer_82599(struct ixgbe_hw *hw, u16 offset,
  *
  *  Reads a 16 bit word from the EEPROM
  **/
-static s32 ixgbe_read_eeprom_82599(struct ixgbe_hw *hw,
+STATIC s32 ixgbe_read_eeprom_82599(struct ixgbe_hw *hw,
 				   u16 offset, u16 *data)
 {
 	struct ixgbe_eeprom_info *eeprom = &hw->eeprom;
+	s32 ret_val = IXGBE_ERR_CONFIG;
+
+	DEBUGFUNC("ixgbe_read_eeprom_82599");
 
 	/*
 	 * If EEPROM is detected and can be addressed using 14 bits,
 	 * use EERD otherwise use bit bang
 	 */
-	if (eeprom->type == ixgbe_eeprom_spi && offset <= IXGBE_EERD_MAX_ADDR)
-		return ixgbe_read_eerd_generic(hw, offset, data);
+	if ((eeprom->type == ixgbe_eeprom_spi) &&
+	    (offset <= IXGBE_EERD_MAX_ADDR))
+		ret_val = ixgbe_read_eerd_generic(hw, offset, data);
+	else
+		ret_val = ixgbe_read_eeprom_bit_bang_generic(hw, offset, data);
 
-	return ixgbe_read_eeprom_bit_bang_generic(hw, offset, data);
+	return ret_val;
 }
 
 /**
  * ixgbe_reset_pipeline_82599 - perform pipeline reset
  *
- * @hw: pointer to hardware structure
+ *  @hw: pointer to hardware structure
  *
  * Reset pipeline by asserting Restart_AN together with LMS change to ensure
- * full pipeline reset.  Note - We must hold the SW/FW semaphore before writing
- * to AUTOC, so this function assumes the semaphore is held.
+ * full pipeline reset.  This function assumes the SW/FW lock is held.
  **/
-static s32 ixgbe_reset_pipeline_82599(struct ixgbe_hw *hw)
+s32 ixgbe_reset_pipeline_82599(struct ixgbe_hw *hw)
 {
 	s32 ret_val;
 	u32 anlp1_reg = 0;
@@ -2041,26 +2472,24 @@ static s32 ixgbe_reset_pipeline_82599(struct ixgbe_hw *hw)
 
 	autoc_reg = IXGBE_READ_REG(hw, IXGBE_AUTOC);
 	autoc_reg |= IXGBE_AUTOC_AN_RESTART;
-
 	/* Write AUTOC register with toggled LMS[2] bit and Restart_AN */
 	IXGBE_WRITE_REG(hw, IXGBE_AUTOC,
 			autoc_reg ^ (0x4 << IXGBE_AUTOC_LMS_SHIFT));
-
 	/* Wait for AN to leave state 0 */
 	for (i = 0; i < 10; i++) {
-		usleep_range(4000, 8000);
+		msec_delay(4);
 		anlp1_reg = IXGBE_READ_REG(hw, IXGBE_ANLP1);
 		if (anlp1_reg & IXGBE_ANLP1_AN_STATE_MASK)
 			break;
 	}
 
 	if (!(anlp1_reg & IXGBE_ANLP1_AN_STATE_MASK)) {
-		hw_dbg(hw, "auto negotiation not completed\n");
+		DEBUGOUT("auto negotiation not completed\n");
 		ret_val = IXGBE_ERR_RESET_FAILED;
 		goto reset_pipeline_out;
 	}
 
-	ret_val = 0;
+	ret_val = IXGBE_SUCCESS;
 
 reset_pipeline_out:
 	/* Write AUTOC register with original LMS field and Restart_AN */
@@ -2079,14 +2508,16 @@ reset_pipeline_out:
  *  Performs byte read operation to SFP module's EEPROM over I2C interface at
  *  a specified device address.
  **/
-static s32 ixgbe_read_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
-				     u8 dev_addr, u8 *data)
+STATIC s32 ixgbe_read_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
+				u8 dev_addr, u8 *data)
 {
 	u32 esdp;
 	s32 status;
 	s32 timeout = 200;
 
-	if (hw->phy.qsfp_shared_i2c_bus == true) {
+	DEBUGFUNC("ixgbe_read_i2c_byte_82599");
+
+	if (hw->phy.qsfp_shared_i2c_bus == TRUE) {
 		/* Acquire I2C bus ownership. */
 		esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
 		esdp |= IXGBE_ESDP_SDP0;
@@ -2098,12 +2529,13 @@ static s32 ixgbe_read_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
 			if (esdp & IXGBE_ESDP_SDP1)
 				break;
 
-			usleep_range(5000, 10000);
+			msec_delay(5);
 			timeout--;
 		}
 
 		if (!timeout) {
-			hw_dbg(hw, "Driver can't access resource, acquiring I2C bus timeout.\n");
+			DEBUGOUT("Driver can't access resource,"
+				 " acquiring I2C bus timeout.\n");
 			status = IXGBE_ERR_I2C;
 			goto release_i2c_access;
 		}
@@ -2112,7 +2544,8 @@ static s32 ixgbe_read_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
 	status = ixgbe_read_i2c_byte_generic(hw, byte_offset, dev_addr, data);
 
 release_i2c_access:
-	if (hw->phy.qsfp_shared_i2c_bus == true) {
+
+	if (hw->phy.qsfp_shared_i2c_bus == TRUE) {
 		/* Release I2C bus ownership. */
 		esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
 		esdp &= ~IXGBE_ESDP_SDP0;
@@ -2132,14 +2565,16 @@ release_i2c_access:
  *  Performs byte write operation to SFP module's EEPROM over I2C interface at
  *  a specified device address.
  **/
-static s32 ixgbe_write_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
-				      u8 dev_addr, u8 data)
+STATIC s32 ixgbe_write_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
+				 u8 dev_addr, u8 data)
 {
 	u32 esdp;
 	s32 status;
 	s32 timeout = 200;
 
-	if (hw->phy.qsfp_shared_i2c_bus == true) {
+	DEBUGFUNC("ixgbe_write_i2c_byte_82599");
+
+	if (hw->phy.qsfp_shared_i2c_bus == TRUE) {
 		/* Acquire I2C bus ownership. */
 		esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
 		esdp |= IXGBE_ESDP_SDP0;
@@ -2151,12 +2586,13 @@ static s32 ixgbe_write_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
 			if (esdp & IXGBE_ESDP_SDP1)
 				break;
 
-			usleep_range(5000, 10000);
+			msec_delay(5);
 			timeout--;
 		}
 
 		if (!timeout) {
-			hw_dbg(hw, "Driver can't access resource, acquiring I2C bus timeout.\n");
+			DEBUGOUT("Driver can't access resource,"
+				 " acquiring I2C bus timeout.\n");
 			status = IXGBE_ERR_I2C;
 			goto release_i2c_access;
 		}
@@ -2165,7 +2601,8 @@ static s32 ixgbe_write_i2c_byte_82599(struct ixgbe_hw *hw, u8 byte_offset,
 	status = ixgbe_write_i2c_byte_generic(hw, byte_offset, dev_addr, data);
 
 release_i2c_access:
-	if (hw->phy.qsfp_shared_i2c_bus == true) {
+
+	if (hw->phy.qsfp_shared_i2c_bus == TRUE) {
 		/* Release I2C bus ownership. */
 		esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
 		esdp &= ~IXGBE_ESDP_SDP0;
@@ -2175,95 +2612,3 @@ release_i2c_access:
 
 	return status;
 }
-
-static struct ixgbe_mac_operations mac_ops_82599 = {
-	.init_hw                = &ixgbe_init_hw_generic,
-	.reset_hw               = &ixgbe_reset_hw_82599,
-	.start_hw               = &ixgbe_start_hw_82599,
-	.clear_hw_cntrs         = &ixgbe_clear_hw_cntrs_generic,
-	.get_media_type         = &ixgbe_get_media_type_82599,
-	.enable_rx_dma          = &ixgbe_enable_rx_dma_82599,
-	.disable_rx_buff	= &ixgbe_disable_rx_buff_generic,
-	.enable_rx_buff		= &ixgbe_enable_rx_buff_generic,
-	.get_mac_addr           = &ixgbe_get_mac_addr_generic,
-	.get_san_mac_addr       = &ixgbe_get_san_mac_addr_generic,
-	.get_device_caps        = &ixgbe_get_device_caps_generic,
-	.get_wwn_prefix         = &ixgbe_get_wwn_prefix_generic,
-	.stop_adapter           = &ixgbe_stop_adapter_generic,
-	.get_bus_info           = &ixgbe_get_bus_info_generic,
-	.set_lan_id             = &ixgbe_set_lan_id_multi_port_pcie,
-	.read_analog_reg8       = &ixgbe_read_analog_reg8_82599,
-	.write_analog_reg8      = &ixgbe_write_analog_reg8_82599,
-	.stop_link_on_d3	= &ixgbe_stop_mac_link_on_d3_82599,
-	.setup_link             = &ixgbe_setup_mac_link_82599,
-	.set_rxpba		= &ixgbe_set_rxpba_generic,
-	.check_link             = &ixgbe_check_mac_link_generic,
-	.get_link_capabilities  = &ixgbe_get_link_capabilities_82599,
-	.led_on                 = &ixgbe_led_on_generic,
-	.led_off                = &ixgbe_led_off_generic,
-	.blink_led_start        = &ixgbe_blink_led_start_generic,
-	.blink_led_stop         = &ixgbe_blink_led_stop_generic,
-	.set_rar                = &ixgbe_set_rar_generic,
-	.clear_rar              = &ixgbe_clear_rar_generic,
-	.set_vmdq               = &ixgbe_set_vmdq_generic,
-	.set_vmdq_san_mac	= &ixgbe_set_vmdq_san_mac_generic,
-	.clear_vmdq             = &ixgbe_clear_vmdq_generic,
-	.init_rx_addrs          = &ixgbe_init_rx_addrs_generic,
-	.update_mc_addr_list    = &ixgbe_update_mc_addr_list_generic,
-	.enable_mc              = &ixgbe_enable_mc_generic,
-	.disable_mc             = &ixgbe_disable_mc_generic,
-	.clear_vfta             = &ixgbe_clear_vfta_generic,
-	.set_vfta               = &ixgbe_set_vfta_generic,
-	.fc_enable              = &ixgbe_fc_enable_generic,
-	.set_fw_drv_ver         = &ixgbe_set_fw_drv_ver_generic,
-	.init_uta_tables        = &ixgbe_init_uta_tables_generic,
-	.setup_sfp              = &ixgbe_setup_sfp_modules_82599,
-	.set_mac_anti_spoofing  = &ixgbe_set_mac_anti_spoofing,
-	.set_vlan_anti_spoofing = &ixgbe_set_vlan_anti_spoofing,
-	.acquire_swfw_sync      = &ixgbe_acquire_swfw_sync,
-	.release_swfw_sync      = &ixgbe_release_swfw_sync,
-	.get_thermal_sensor_data = &ixgbe_get_thermal_sensor_data_generic,
-	.init_thermal_sensor_thresh = &ixgbe_init_thermal_sensor_thresh_generic,
-	.prot_autoc_read	= &prot_autoc_read_82599,
-	.prot_autoc_write	= &prot_autoc_write_82599,
-	.enable_rx		= &ixgbe_enable_rx_generic,
-	.disable_rx		= &ixgbe_disable_rx_generic,
-};
-
-static struct ixgbe_eeprom_operations eeprom_ops_82599 = {
-	.init_params		= &ixgbe_init_eeprom_params_generic,
-	.read			= &ixgbe_read_eeprom_82599,
-	.read_buffer		= &ixgbe_read_eeprom_buffer_82599,
-	.write			= &ixgbe_write_eeprom_generic,
-	.write_buffer		= &ixgbe_write_eeprom_buffer_bit_bang_generic,
-	.calc_checksum		= &ixgbe_calc_eeprom_checksum_generic,
-	.validate_checksum	= &ixgbe_validate_eeprom_checksum_generic,
-	.update_checksum	= &ixgbe_update_eeprom_checksum_generic,
-};
-
-static struct ixgbe_phy_operations phy_ops_82599 = {
-	.identify		= &ixgbe_identify_phy_82599,
-	.identify_sfp		= &ixgbe_identify_module_generic,
-	.init			= &ixgbe_init_phy_ops_82599,
-	.reset			= &ixgbe_reset_phy_generic,
-	.read_reg		= &ixgbe_read_phy_reg_generic,
-	.write_reg		= &ixgbe_write_phy_reg_generic,
-	.setup_link		= &ixgbe_setup_phy_link_generic,
-	.setup_link_speed	= &ixgbe_setup_phy_link_speed_generic,
-	.read_i2c_byte		= &ixgbe_read_i2c_byte_generic,
-	.write_i2c_byte		= &ixgbe_write_i2c_byte_generic,
-	.read_i2c_sff8472	= &ixgbe_read_i2c_sff8472_generic,
-	.read_i2c_eeprom	= &ixgbe_read_i2c_eeprom_generic,
-	.write_i2c_eeprom	= &ixgbe_write_i2c_eeprom_generic,
-	.check_overtemp		= &ixgbe_tn_check_overtemp,
-};
-
-struct ixgbe_info ixgbe_82599_info = {
-	.mac                    = ixgbe_mac_82599EB,
-	.get_invariants         = &ixgbe_get_invariants_82599,
-	.mac_ops                = &mac_ops_82599,
-	.eeprom_ops             = &eeprom_ops_82599,
-	.phy_ops                = &phy_ops_82599,
-	.mbx_ops                = &mbx_ops_generic,
-	.mvals			= ixgbe_mvals_8259X,
-};
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_82599.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_82599.h
new file mode 100644
index 00000000..7d928b8
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_82599.h
@@ -0,0 +1,55 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#ifndef _IXGBE_82599_H_
+#define _IXGBE_82599_H_
+
+s32 ixgbe_get_link_capabilities_82599(struct ixgbe_hw *hw,
+				      ixgbe_link_speed *speed, bool *autoneg);
+enum ixgbe_media_type ixgbe_get_media_type_82599(struct ixgbe_hw *hw);
+void ixgbe_disable_tx_laser_multispeed_fiber(struct ixgbe_hw *hw);
+void ixgbe_enable_tx_laser_multispeed_fiber(struct ixgbe_hw *hw);
+void ixgbe_flap_tx_laser_multispeed_fiber(struct ixgbe_hw *hw);
+void ixgbe_set_hard_rate_select_speed(struct ixgbe_hw *hw,
+					ixgbe_link_speed speed);
+s32 ixgbe_setup_mac_link_smartspeed(struct ixgbe_hw *hw,
+				    ixgbe_link_speed speed,
+				    bool autoneg_wait_to_complete);
+s32 ixgbe_start_mac_link_82599(struct ixgbe_hw *hw,
+			       bool autoneg_wait_to_complete);
+s32 ixgbe_setup_mac_link_82599(struct ixgbe_hw *hw, ixgbe_link_speed speed,
+			       bool autoneg_wait_to_complete);
+s32 ixgbe_setup_sfp_modules_82599(struct ixgbe_hw *hw);
+void ixgbe_init_mac_link_ops_82599(struct ixgbe_hw *hw);
+s32 ixgbe_reset_hw_82599(struct ixgbe_hw *hw);
+s32 ixgbe_read_analog_reg8_82599(struct ixgbe_hw *hw, u32 reg, u8 *val);
+s32 ixgbe_write_analog_reg8_82599(struct ixgbe_hw *hw, u32 reg, u8 val);
+s32 ixgbe_start_hw_82599(struct ixgbe_hw *hw);
+s32 ixgbe_identify_phy_82599(struct ixgbe_hw *hw);
+s32 ixgbe_init_phy_ops_82599(struct ixgbe_hw *hw);
+u64 ixgbe_get_supported_physical_layer_82599(struct ixgbe_hw *hw);
+s32 ixgbe_enable_rx_dma_82599(struct ixgbe_hw *hw, u32 regval);
+s32 prot_autoc_read_82599(struct ixgbe_hw *hw, bool *locked, u32 *reg_val);
+s32 prot_autoc_write_82599(struct ixgbe_hw *hw, u32 reg_val, bool locked);
+#endif /* _IXGBE_82599_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_api.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_api.c
new file mode 100644
index 00000000..3251a71
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_api.c
@@ -0,0 +1,1624 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#include "ixgbe_api.h"
+#include "ixgbe_common.h"
+
+#define IXGBE_EMPTY_PARAM
+
+static const u32 ixgbe_mvals_base[IXGBE_MVALS_IDX_LIMIT] = {
+	IXGBE_MVALS_INIT(IXGBE_EMPTY_PARAM)
+};
+
+static const u32 ixgbe_mvals_X540[IXGBE_MVALS_IDX_LIMIT] = {
+	IXGBE_MVALS_INIT(_X540)
+};
+
+static const u32 ixgbe_mvals_X550[IXGBE_MVALS_IDX_LIMIT] = {
+	IXGBE_MVALS_INIT(_X550)
+};
+
+static const u32 ixgbe_mvals_X550EM_x[IXGBE_MVALS_IDX_LIMIT] = {
+	IXGBE_MVALS_INIT(_X550EM_x)
+};
+
+static const u32 ixgbe_mvals_X550EM_a[IXGBE_MVALS_IDX_LIMIT] = {
+	IXGBE_MVALS_INIT(_X550EM_a)
+};
+
+/**
+ * ixgbe_dcb_get_rtrup2tc - read rtrup2tc reg
+ * @hw: pointer to hardware structure
+ * @map: pointer to u8 arr for returning map
+ *
+ * Read the rtrup2tc HW register and resolve its content into map
+ **/
+void ixgbe_dcb_get_rtrup2tc(struct ixgbe_hw *hw, u8 *map)
+{
+	if (hw->mac.ops.get_rtrup2tc)
+		hw->mac.ops.get_rtrup2tc(hw, map);
+}
+
+/**
+ *  ixgbe_init_shared_code - Initialize the shared code
+ *  @hw: pointer to hardware structure
+ *
+ *  This will assign function pointers and assign the MAC type and PHY code.
+ *  Does not touch the hardware. This function must be called prior to any
+ *  other function in the shared code. The ixgbe_hw structure should be
+ *  memset to 0 prior to calling this function.  The following fields in
+ *  hw structure should be filled in prior to calling this function:
+ *  hw_addr, back, device_id, vendor_id, subsystem_device_id,
+ *  subsystem_vendor_id, and revision_id
+ **/
+s32 ixgbe_init_shared_code(struct ixgbe_hw *hw)
+{
+	s32 status;
+
+	DEBUGFUNC("ixgbe_init_shared_code");
+
+	/*
+	 * Set the mac type
+	 */
+	ixgbe_set_mac_type(hw);
+
+	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		status = ixgbe_init_ops_82598(hw);
+		break;
+	case ixgbe_mac_82599EB:
+		status = ixgbe_init_ops_82599(hw);
+		break;
+	case ixgbe_mac_X540:
+		status = ixgbe_init_ops_X540(hw);
+		break;
+	case ixgbe_mac_X550:
+		status = ixgbe_init_ops_X550(hw);
+		break;
+	case ixgbe_mac_X550EM_x:
+		status = ixgbe_init_ops_X550EM_x(hw);
+		break;
+	case ixgbe_mac_X550EM_a:
+		status = ixgbe_init_ops_X550EM_a(hw);
+		break;
+	default:
+		status = IXGBE_ERR_DEVICE_NOT_SUPPORTED;
+		break;
+	}
+	hw->mac.max_link_up_time = IXGBE_LINK_UP_TIME;
+
+	return status;
+}
+
+/**
+ *  ixgbe_set_mac_type - Sets MAC type
+ *  @hw: pointer to the HW structure
+ *
+ *  This function sets the mac type of the adapter based on the
+ *  vendor ID and device ID stored in the hw structure.
+ **/
+s32 ixgbe_set_mac_type(struct ixgbe_hw *hw)
+{
+	s32 ret_val = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_set_mac_type\n");
+
+	if (hw->vendor_id != IXGBE_INTEL_VENDOR_ID) {
+		ERROR_REPORT2(IXGBE_ERROR_UNSUPPORTED,
+			     "Unsupported vendor id: %x", hw->vendor_id);
+		return IXGBE_ERR_DEVICE_NOT_SUPPORTED;
+	}
+
+	hw->mvals = ixgbe_mvals_base;
+
+	switch (hw->device_id) {
+	case IXGBE_DEV_ID_82598:
+	case IXGBE_DEV_ID_82598_BX:
+	case IXGBE_DEV_ID_82598AF_SINGLE_PORT:
+	case IXGBE_DEV_ID_82598AF_DUAL_PORT:
+	case IXGBE_DEV_ID_82598AT:
+	case IXGBE_DEV_ID_82598AT2:
+	case IXGBE_DEV_ID_82598EB_CX4:
+	case IXGBE_DEV_ID_82598_CX4_DUAL_PORT:
+	case IXGBE_DEV_ID_82598_DA_DUAL_PORT:
+	case IXGBE_DEV_ID_82598_SR_DUAL_PORT_EM:
+	case IXGBE_DEV_ID_82598EB_XF_LR:
+	case IXGBE_DEV_ID_82598EB_SFP_LOM:
+		hw->mac.type = ixgbe_mac_82598EB;
+		break;
+	case IXGBE_DEV_ID_82599_KX4:
+	case IXGBE_DEV_ID_82599_KX4_MEZZ:
+	case IXGBE_DEV_ID_82599_XAUI_LOM:
+	case IXGBE_DEV_ID_82599_COMBO_BACKPLANE:
+	case IXGBE_DEV_ID_82599_KR:
+	case IXGBE_DEV_ID_82599_SFP:
+	case IXGBE_DEV_ID_82599_BACKPLANE_FCOE:
+	case IXGBE_DEV_ID_82599_SFP_FCOE:
+	case IXGBE_DEV_ID_82599_SFP_EM:
+	case IXGBE_DEV_ID_82599_SFP_SF2:
+	case IXGBE_DEV_ID_82599_SFP_SF_QP:
+	case IXGBE_DEV_ID_82599_QSFP_SF_QP:
+	case IXGBE_DEV_ID_82599EN_SFP:
+	case IXGBE_DEV_ID_82599_CX4:
+	case IXGBE_DEV_ID_82599_LS:
+	case IXGBE_DEV_ID_82599_T3_LOM:
+		hw->mac.type = ixgbe_mac_82599EB;
+		break;
+	case IXGBE_DEV_ID_X540T:
+	case IXGBE_DEV_ID_X540T1:
+		hw->mac.type = ixgbe_mac_X540;
+		hw->mvals = ixgbe_mvals_X540;
+		break;
+	case IXGBE_DEV_ID_X550T:
+	case IXGBE_DEV_ID_X550T1:
+		hw->mac.type = ixgbe_mac_X550;
+		hw->mvals = ixgbe_mvals_X550;
+		break;
+	case IXGBE_DEV_ID_X550EM_X_KX4:
+	case IXGBE_DEV_ID_X550EM_X_KR:
+	case IXGBE_DEV_ID_X550EM_X_10G_T:
+	case IXGBE_DEV_ID_X550EM_X_1G_T:
+	case IXGBE_DEV_ID_X550EM_X_SFP:
+	case IXGBE_DEV_ID_X550EM_X_XFI:
+		hw->mac.type = ixgbe_mac_X550EM_x;
+		hw->mvals = ixgbe_mvals_X550EM_x;
+		break;
+	case IXGBE_DEV_ID_X550EM_A_KR:
+	case IXGBE_DEV_ID_X550EM_A_KR_L:
+	case IXGBE_DEV_ID_X550EM_A_SFP_N:
+	case IXGBE_DEV_ID_X550EM_A_SGMII:
+	case IXGBE_DEV_ID_X550EM_A_SGMII_L:
+	case IXGBE_DEV_ID_X550EM_A_1G_T:
+	case IXGBE_DEV_ID_X550EM_A_1G_T_L:
+	case IXGBE_DEV_ID_X550EM_A_10G_T:
+	case IXGBE_DEV_ID_X550EM_A_QSFP:
+	case IXGBE_DEV_ID_X550EM_A_QSFP_N:
+	case IXGBE_DEV_ID_X550EM_A_SFP:
+		hw->mac.type = ixgbe_mac_X550EM_a;
+		hw->mvals = ixgbe_mvals_X550EM_a;
+		break;
+	default:
+		ret_val = IXGBE_ERR_DEVICE_NOT_SUPPORTED;
+		ERROR_REPORT2(IXGBE_ERROR_UNSUPPORTED,
+			     "Unsupported device id: %x",
+			     hw->device_id);
+		break;
+	}
+
+	DEBUGOUT2("ixgbe_set_mac_type found mac: %d, returns: %d\n",
+		  hw->mac.type, ret_val);
+	return ret_val;
+}
+
+/**
+ *  ixgbe_init_hw - Initialize the hardware
+ *  @hw: pointer to hardware structure
+ *
+ *  Initialize the hardware by resetting and then starting the hardware
+ **/
+s32 ixgbe_init_hw(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.init_hw, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_reset_hw - Performs a hardware reset
+ *  @hw: pointer to hardware structure
+ *
+ *  Resets the hardware by resetting the transmit and receive units, masks and
+ *  clears all interrupts, performs a PHY reset, and performs a MAC reset
+ **/
+s32 ixgbe_reset_hw(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.reset_hw, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_start_hw - Prepares hardware for Rx/Tx
+ *  @hw: pointer to hardware structure
+ *
+ *  Starts the hardware by filling the bus info structure and media type,
+ *  clears all on chip counters, initializes receive address registers,
+ *  multicast table, VLAN filter table, calls routine to setup link and
+ *  flow control settings, and leaves transmit and receive units disabled
+ *  and uninitialized.
+ **/
+s32 ixgbe_start_hw(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.start_hw, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_clear_hw_cntrs - Clear hardware counters
+ *  @hw: pointer to hardware structure
+ *
+ *  Clears all hardware statistics counters by reading them from the hardware
+ *  Statistics counters are clear on read.
+ **/
+s32 ixgbe_clear_hw_cntrs(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.clear_hw_cntrs, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_get_media_type - Get media type
+ *  @hw: pointer to hardware structure
+ *
+ *  Returns the media type (fiber, copper, backplane)
+ **/
+enum ixgbe_media_type ixgbe_get_media_type(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.get_media_type, (hw),
+			       ixgbe_media_type_unknown);
+}
+
+/**
+ *  ixgbe_get_mac_addr - Get MAC address
+ *  @hw: pointer to hardware structure
+ *  @mac_addr: Adapter MAC address
+ *
+ *  Reads the adapter's MAC address from the first Receive Address Register
+ *  (RAR0) A reset of the adapter must have been performed prior to calling
+ *  this function in order for the MAC address to have been loaded from the
+ *  EEPROM into RAR0
+ **/
+s32 ixgbe_get_mac_addr(struct ixgbe_hw *hw, u8 *mac_addr)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.get_mac_addr,
+			       (hw, mac_addr), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_get_san_mac_addr - Get SAN MAC address
+ *  @hw: pointer to hardware structure
+ *  @san_mac_addr: SAN MAC address
+ *
+ *  Reads the SAN MAC address from the EEPROM, if it's available.  This is
+ *  per-port, so set_lan_id() must be called before reading the addresses.
+ **/
+s32 ixgbe_get_san_mac_addr(struct ixgbe_hw *hw, u8 *san_mac_addr)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.get_san_mac_addr,
+			       (hw, san_mac_addr), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_set_san_mac_addr - Write a SAN MAC address
+ *  @hw: pointer to hardware structure
+ *  @san_mac_addr: SAN MAC address
+ *
+ *  Writes A SAN MAC address to the EEPROM.
+ **/
+s32 ixgbe_set_san_mac_addr(struct ixgbe_hw *hw, u8 *san_mac_addr)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.set_san_mac_addr,
+			       (hw, san_mac_addr), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_get_device_caps - Get additional device capabilities
+ *  @hw: pointer to hardware structure
+ *  @device_caps: the EEPROM word for device capabilities
+ *
+ *  Reads the extra device capabilities from the EEPROM
+ **/
+s32 ixgbe_get_device_caps(struct ixgbe_hw *hw, u16 *device_caps)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.get_device_caps,
+			       (hw, device_caps), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_get_wwn_prefix - Get alternative WWNN/WWPN prefix from the EEPROM
+ *  @hw: pointer to hardware structure
+ *  @wwnn_prefix: the alternative WWNN prefix
+ *  @wwpn_prefix: the alternative WWPN prefix
+ *
+ *  This function will read the EEPROM from the alternative SAN MAC address
+ *  block to check the support for the alternative WWNN/WWPN prefix support.
+ **/
+s32 ixgbe_get_wwn_prefix(struct ixgbe_hw *hw, u16 *wwnn_prefix,
+			 u16 *wwpn_prefix)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.get_wwn_prefix,
+			       (hw, wwnn_prefix, wwpn_prefix),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_get_fcoe_boot_status -  Get FCOE boot status from EEPROM
+ *  @hw: pointer to hardware structure
+ *  @bs: the fcoe boot status
+ *
+ *  This function will read the FCOE boot status from the iSCSI FCOE block
+ **/
+s32 ixgbe_get_fcoe_boot_status(struct ixgbe_hw *hw, u16 *bs)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.get_fcoe_boot_status,
+			       (hw, bs),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_get_bus_info - Set PCI bus info
+ *  @hw: pointer to hardware structure
+ *
+ *  Sets the PCI bus info (speed, width, type) within the ixgbe_hw structure
+ **/
+s32 ixgbe_get_bus_info(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.get_bus_info, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_get_num_of_tx_queues - Get Tx queues
+ *  @hw: pointer to hardware structure
+ *
+ *  Returns the number of transmit queues for the given adapter.
+ **/
+u32 ixgbe_get_num_of_tx_queues(struct ixgbe_hw *hw)
+{
+	return hw->mac.max_tx_queues;
+}
+
+/**
+ *  ixgbe_get_num_of_rx_queues - Get Rx queues
+ *  @hw: pointer to hardware structure
+ *
+ *  Returns the number of receive queues for the given adapter.
+ **/
+u32 ixgbe_get_num_of_rx_queues(struct ixgbe_hw *hw)
+{
+	return hw->mac.max_rx_queues;
+}
+
+/**
+ *  ixgbe_stop_adapter - Disable Rx/Tx units
+ *  @hw: pointer to hardware structure
+ *
+ *  Sets the adapter_stopped flag within ixgbe_hw struct. Clears interrupts,
+ *  disables transmit and receive units. The adapter_stopped flag is used by
+ *  the shared code and drivers to determine if the adapter is in a stopped
+ *  state and should not touch the hardware.
+ **/
+s32 ixgbe_stop_adapter(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.stop_adapter, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_read_pba_string - Reads part number string from EEPROM
+ *  @hw: pointer to hardware structure
+ *  @pba_num: stores the part number string from the EEPROM
+ *  @pba_num_size: part number string buffer length
+ *
+ *  Reads the part number string from the EEPROM.
+ **/
+s32 ixgbe_read_pba_string(struct ixgbe_hw *hw, u8 *pba_num, u32 pba_num_size)
+{
+	return ixgbe_read_pba_string_generic(hw, pba_num, pba_num_size);
+}
+
+/**
+ *  ixgbe_identify_phy - Get PHY type
+ *  @hw: pointer to hardware structure
+ *
+ *  Determines the physical layer module found on the current adapter.
+ **/
+s32 ixgbe_identify_phy(struct ixgbe_hw *hw)
+{
+	s32 status = IXGBE_SUCCESS;
+
+	if (hw->phy.type == ixgbe_phy_unknown) {
+		status = ixgbe_call_func(hw, hw->phy.ops.identify, (hw),
+					 IXGBE_NOT_IMPLEMENTED);
+	}
+
+	return status;
+}
+
+/**
+ *  ixgbe_reset_phy - Perform a PHY reset
+ *  @hw: pointer to hardware structure
+ **/
+s32 ixgbe_reset_phy(struct ixgbe_hw *hw)
+{
+	s32 status = IXGBE_SUCCESS;
+
+	if (hw->phy.type == ixgbe_phy_unknown) {
+		if (ixgbe_identify_phy(hw) != IXGBE_SUCCESS)
+			status = IXGBE_ERR_PHY;
+	}
+
+	if (status == IXGBE_SUCCESS) {
+		status = ixgbe_call_func(hw, hw->phy.ops.reset, (hw),
+					 IXGBE_NOT_IMPLEMENTED);
+	}
+	return status;
+}
+
+/**
+ *  ixgbe_get_phy_firmware_version -
+ *  @hw: pointer to hardware structure
+ *  @firmware_version: pointer to firmware version
+ **/
+s32 ixgbe_get_phy_firmware_version(struct ixgbe_hw *hw, u16 *firmware_version)
+{
+	s32 status = IXGBE_SUCCESS;
+
+	status = ixgbe_call_func(hw, hw->phy.ops.get_firmware_version,
+				 (hw, firmware_version),
+				 IXGBE_NOT_IMPLEMENTED);
+	return status;
+}
+
+/**
+ *  ixgbe_read_phy_reg - Read PHY register
+ *  @hw: pointer to hardware structure
+ *  @reg_addr: 32 bit address of PHY register to read
+ *  @phy_data: Pointer to read data from PHY register
+ *
+ *  Reads a value from a specified PHY register
+ **/
+s32 ixgbe_read_phy_reg(struct ixgbe_hw *hw, u32 reg_addr, u32 device_type,
+		       u16 *phy_data)
+{
+	if (hw->phy.id == 0)
+		ixgbe_identify_phy(hw);
+
+	return ixgbe_call_func(hw, hw->phy.ops.read_reg, (hw, reg_addr,
+			       device_type, phy_data), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_write_phy_reg - Write PHY register
+ *  @hw: pointer to hardware structure
+ *  @reg_addr: 32 bit PHY register to write
+ *  @phy_data: Data to write to the PHY register
+ *
+ *  Writes a value to specified PHY register
+ **/
+s32 ixgbe_write_phy_reg(struct ixgbe_hw *hw, u32 reg_addr, u32 device_type,
+			u16 phy_data)
+{
+	if (hw->phy.id == 0)
+		ixgbe_identify_phy(hw);
+
+	return ixgbe_call_func(hw, hw->phy.ops.write_reg, (hw, reg_addr,
+			       device_type, phy_data), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_setup_phy_link - Restart PHY autoneg
+ *  @hw: pointer to hardware structure
+ *
+ *  Restart autonegotiation and PHY and waits for completion.
+ **/
+s32 ixgbe_setup_phy_link(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.setup_link, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ * ixgbe_setup_internal_phy - Configure integrated PHY
+ * @hw: pointer to hardware structure
+ *
+ * Reconfigure the integrated PHY in order to enable talk to the external PHY.
+ * Returns success if not implemented, since nothing needs to be done in this
+ * case.
+ */
+s32 ixgbe_setup_internal_phy(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.setup_internal_link, (hw),
+			       IXGBE_SUCCESS);
+}
+
+/**
+ *  ixgbe_check_phy_link - Determine link and speed status
+ *  @hw: pointer to hardware structure
+ *
+ *  Reads a PHY register to determine if link is up and the current speed for
+ *  the PHY.
+ **/
+s32 ixgbe_check_phy_link(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
+			 bool *link_up)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.check_link, (hw, speed,
+			       link_up), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_setup_phy_link_speed - Set auto advertise
+ *  @hw: pointer to hardware structure
+ *  @speed: new link speed
+ *
+ *  Sets the auto advertised capabilities
+ **/
+s32 ixgbe_setup_phy_link_speed(struct ixgbe_hw *hw, ixgbe_link_speed speed,
+			       bool autoneg_wait_to_complete)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.setup_link_speed, (hw, speed,
+			       autoneg_wait_to_complete),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ * ixgbe_set_phy_power - Control the phy power state
+ * @hw: pointer to hardware structure
+ * @on: true for on, false for off
+ */
+s32 ixgbe_set_phy_power(struct ixgbe_hw *hw, bool on)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.set_phy_power, (hw, on),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_check_link - Get link and speed status
+ *  @hw: pointer to hardware structure
+ *
+ *  Reads the links register to determine if link is up and the current speed
+ **/
+s32 ixgbe_check_link(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
+		     bool *link_up, bool link_up_wait_to_complete)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.check_link, (hw, speed,
+			       link_up, link_up_wait_to_complete),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_disable_tx_laser - Disable Tx laser
+ *  @hw: pointer to hardware structure
+ *
+ *  If the driver needs to disable the laser on SFI optics.
+ **/
+void ixgbe_disable_tx_laser(struct ixgbe_hw *hw)
+{
+	if (hw->mac.ops.disable_tx_laser)
+		hw->mac.ops.disable_tx_laser(hw);
+}
+
+/**
+ *  ixgbe_enable_tx_laser - Enable Tx laser
+ *  @hw: pointer to hardware structure
+ *
+ *  If the driver needs to enable the laser on SFI optics.
+ **/
+void ixgbe_enable_tx_laser(struct ixgbe_hw *hw)
+{
+	if (hw->mac.ops.enable_tx_laser)
+		hw->mac.ops.enable_tx_laser(hw);
+}
+
+/**
+ *  ixgbe_flap_tx_laser - flap Tx laser to start autotry process
+ *  @hw: pointer to hardware structure
+ *
+ *  When the driver changes the link speeds that it can support then
+ *  flap the tx laser to alert the link partner to start autotry
+ *  process on its end.
+ **/
+void ixgbe_flap_tx_laser(struct ixgbe_hw *hw)
+{
+	if (hw->mac.ops.flap_tx_laser)
+		hw->mac.ops.flap_tx_laser(hw);
+}
+
+/**
+ *  ixgbe_setup_link - Set link speed
+ *  @hw: pointer to hardware structure
+ *  @speed: new link speed
+ *
+ *  Configures link settings.  Restarts the link.
+ *  Performs autonegotiation if needed.
+ **/
+s32 ixgbe_setup_link(struct ixgbe_hw *hw, ixgbe_link_speed speed,
+		     bool autoneg_wait_to_complete)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.setup_link, (hw, speed,
+			       autoneg_wait_to_complete),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_setup_mac_link - Set link speed
+ *  @hw: pointer to hardware structure
+ *  @speed: new link speed
+ *
+ *  Configures link settings.  Restarts the link.
+ *  Performs autonegotiation if needed.
+ **/
+s32 ixgbe_setup_mac_link(struct ixgbe_hw *hw, ixgbe_link_speed speed,
+			 bool autoneg_wait_to_complete)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.setup_mac_link, (hw, speed,
+			       autoneg_wait_to_complete),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_get_link_capabilities - Returns link capabilities
+ *  @hw: pointer to hardware structure
+ *
+ *  Determines the link capabilities of the current configuration.
+ **/
+s32 ixgbe_get_link_capabilities(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
+				bool *autoneg)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.get_link_capabilities, (hw,
+			       speed, autoneg), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_led_on - Turn on LEDs
+ *  @hw: pointer to hardware structure
+ *  @index: led number to turn on
+ *
+ *  Turns on the software controllable LEDs.
+ **/
+s32 ixgbe_led_on(struct ixgbe_hw *hw, u32 index)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.led_on, (hw, index),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_led_off - Turn off LEDs
+ *  @hw: pointer to hardware structure
+ *  @index: led number to turn off
+ *
+ *  Turns off the software controllable LEDs.
+ **/
+s32 ixgbe_led_off(struct ixgbe_hw *hw, u32 index)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.led_off, (hw, index),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_blink_led_start - Blink LEDs
+ *  @hw: pointer to hardware structure
+ *  @index: led number to blink
+ *
+ *  Blink LED based on index.
+ **/
+s32 ixgbe_blink_led_start(struct ixgbe_hw *hw, u32 index)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.blink_led_start, (hw, index),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_blink_led_stop - Stop blinking LEDs
+ *  @hw: pointer to hardware structure
+ *
+ *  Stop blinking LED based on index.
+ **/
+s32 ixgbe_blink_led_stop(struct ixgbe_hw *hw, u32 index)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.blink_led_stop, (hw, index),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_init_eeprom_params - Initialize EEPROM parameters
+ *  @hw: pointer to hardware structure
+ *
+ *  Initializes the EEPROM parameters ixgbe_eeprom_info within the
+ *  ixgbe_hw struct in order to set up EEPROM access.
+ **/
+s32 ixgbe_init_eeprom_params(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->eeprom.ops.init_params, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+
+/**
+ *  ixgbe_write_eeprom - Write word to EEPROM
+ *  @hw: pointer to hardware structure
+ *  @offset: offset within the EEPROM to be written to
+ *  @data: 16 bit word to be written to the EEPROM
+ *
+ *  Writes 16 bit value to EEPROM. If ixgbe_eeprom_update_checksum is not
+ *  called after this function, the EEPROM will most likely contain an
+ *  invalid checksum.
+ **/
+s32 ixgbe_write_eeprom(struct ixgbe_hw *hw, u16 offset, u16 data)
+{
+	return ixgbe_call_func(hw, hw->eeprom.ops.write, (hw, offset, data),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_write_eeprom_buffer - Write word(s) to EEPROM
+ *  @hw: pointer to hardware structure
+ *  @offset: offset within the EEPROM to be written to
+ *  @data: 16 bit word(s) to be written to the EEPROM
+ *  @words: number of words
+ *
+ *  Writes 16 bit word(s) to EEPROM. If ixgbe_eeprom_update_checksum is not
+ *  called after this function, the EEPROM will most likely contain an
+ *  invalid checksum.
+ **/
+s32 ixgbe_write_eeprom_buffer(struct ixgbe_hw *hw, u16 offset, u16 words,
+			      u16 *data)
+{
+	return ixgbe_call_func(hw, hw->eeprom.ops.write_buffer,
+			       (hw, offset, words, data),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_read_eeprom - Read word from EEPROM
+ *  @hw: pointer to hardware structure
+ *  @offset: offset within the EEPROM to be read
+ *  @data: read 16 bit value from EEPROM
+ *
+ *  Reads 16 bit value from EEPROM
+ **/
+s32 ixgbe_read_eeprom(struct ixgbe_hw *hw, u16 offset, u16 *data)
+{
+	return ixgbe_call_func(hw, hw->eeprom.ops.read, (hw, offset, data),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_read_eeprom_buffer - Read word(s) from EEPROM
+ *  @hw: pointer to hardware structure
+ *  @offset: offset within the EEPROM to be read
+ *  @data: read 16 bit word(s) from EEPROM
+ *  @words: number of words
+ *
+ *  Reads 16 bit word(s) from EEPROM
+ **/
+s32 ixgbe_read_eeprom_buffer(struct ixgbe_hw *hw, u16 offset,
+			     u16 words, u16 *data)
+{
+	return ixgbe_call_func(hw, hw->eeprom.ops.read_buffer,
+			       (hw, offset, words, data),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_validate_eeprom_checksum - Validate EEPROM checksum
+ *  @hw: pointer to hardware structure
+ *  @checksum_val: calculated checksum
+ *
+ *  Performs checksum calculation and validates the EEPROM checksum
+ **/
+s32 ixgbe_validate_eeprom_checksum(struct ixgbe_hw *hw, u16 *checksum_val)
+{
+	return ixgbe_call_func(hw, hw->eeprom.ops.validate_checksum,
+			       (hw, checksum_val), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_eeprom_update_checksum - Updates the EEPROM checksum
+ *  @hw: pointer to hardware structure
+ **/
+s32 ixgbe_update_eeprom_checksum(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->eeprom.ops.update_checksum, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_insert_mac_addr - Find a RAR for this mac address
+ *  @hw: pointer to hardware structure
+ *  @addr: Address to put into receive address register
+ *  @vmdq: VMDq pool to assign
+ *
+ *  Puts an ethernet address into a receive address register, or
+ *  finds the rar that it is aleady in; adds to the pool list
+ **/
+s32 ixgbe_insert_mac_addr(struct ixgbe_hw *hw, u8 *addr, u32 vmdq)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.insert_mac_addr,
+			       (hw, addr, vmdq),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_set_rar - Set Rx address register
+ *  @hw: pointer to hardware structure
+ *  @index: Receive address register to write
+ *  @addr: Address to put into receive address register
+ *  @vmdq: VMDq "set"
+ *  @enable_addr: set flag that address is active
+ *
+ *  Puts an ethernet address into a receive address register.
+ **/
+s32 ixgbe_set_rar(struct ixgbe_hw *hw, u32 index, u8 *addr, u32 vmdq,
+		  u32 enable_addr)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.set_rar, (hw, index, addr, vmdq,
+			       enable_addr), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_clear_rar - Clear Rx address register
+ *  @hw: pointer to hardware structure
+ *  @index: Receive address register to write
+ *
+ *  Puts an ethernet address into a receive address register.
+ **/
+s32 ixgbe_clear_rar(struct ixgbe_hw *hw, u32 index)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.clear_rar, (hw, index),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_set_vmdq - Associate a VMDq index with a receive address
+ *  @hw: pointer to hardware structure
+ *  @rar: receive address register index to associate with VMDq index
+ *  @vmdq: VMDq set or pool index
+ **/
+s32 ixgbe_set_vmdq(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.set_vmdq, (hw, rar, vmdq),
+			       IXGBE_NOT_IMPLEMENTED);
+
+}
+
+/**
+ *  ixgbe_set_vmdq_san_mac - Associate VMDq index 127 with a receive address
+ *  @hw: pointer to hardware structure
+ *  @vmdq: VMDq default pool index
+ **/
+s32 ixgbe_set_vmdq_san_mac(struct ixgbe_hw *hw, u32 vmdq)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.set_vmdq_san_mac,
+			       (hw, vmdq), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_clear_vmdq - Disassociate a VMDq index from a receive address
+ *  @hw: pointer to hardware structure
+ *  @rar: receive address register index to disassociate with VMDq index
+ *  @vmdq: VMDq set or pool index
+ **/
+s32 ixgbe_clear_vmdq(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.clear_vmdq, (hw, rar, vmdq),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_init_rx_addrs - Initializes receive address filters.
+ *  @hw: pointer to hardware structure
+ *
+ *  Places the MAC address in receive address register 0 and clears the rest
+ *  of the receive address registers. Clears the multicast table. Assumes
+ *  the receiver is in reset when the routine is called.
+ **/
+s32 ixgbe_init_rx_addrs(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.init_rx_addrs, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_get_num_rx_addrs - Returns the number of RAR entries.
+ *  @hw: pointer to hardware structure
+ **/
+u32 ixgbe_get_num_rx_addrs(struct ixgbe_hw *hw)
+{
+	return hw->mac.num_rar_entries;
+}
+
+/**
+ *  ixgbe_update_uc_addr_list - Updates the MAC's list of secondary addresses
+ *  @hw: pointer to hardware structure
+ *  @addr_list: the list of new multicast addresses
+ *  @addr_count: number of addresses
+ *  @func: iterator function to walk the multicast address list
+ *
+ *  The given list replaces any existing list. Clears the secondary addrs from
+ *  receive address registers. Uses unused receive address registers for the
+ *  first secondary addresses, and falls back to promiscuous mode as needed.
+ **/
+s32 ixgbe_update_uc_addr_list(struct ixgbe_hw *hw, u8 *addr_list,
+			      u32 addr_count, ixgbe_mc_addr_itr func)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.update_uc_addr_list, (hw,
+			       addr_list, addr_count, func),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_update_mc_addr_list - Updates the MAC's list of multicast addresses
+ *  @hw: pointer to hardware structure
+ *  @mc_addr_list: the list of new multicast addresses
+ *  @mc_addr_count: number of addresses
+ *  @func: iterator function to walk the multicast address list
+ *
+ *  The given list replaces any existing list. Clears the MC addrs from receive
+ *  address registers and the multicast table. Uses unused receive address
+ *  registers for the first multicast addresses, and hashes the rest into the
+ *  multicast table.
+ **/
+s32 ixgbe_update_mc_addr_list(struct ixgbe_hw *hw, u8 *mc_addr_list,
+			      u32 mc_addr_count, ixgbe_mc_addr_itr func,
+			      bool clear)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.update_mc_addr_list, (hw,
+			       mc_addr_list, mc_addr_count, func, clear),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_enable_mc - Enable multicast address in RAR
+ *  @hw: pointer to hardware structure
+ *
+ *  Enables multicast address in RAR and the use of the multicast hash table.
+ **/
+s32 ixgbe_enable_mc(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.enable_mc, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_disable_mc - Disable multicast address in RAR
+ *  @hw: pointer to hardware structure
+ *
+ *  Disables multicast address in RAR and the use of the multicast hash table.
+ **/
+s32 ixgbe_disable_mc(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.disable_mc, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_clear_vfta - Clear VLAN filter table
+ *  @hw: pointer to hardware structure
+ *
+ *  Clears the VLAN filer table, and the VMDq index associated with the filter
+ **/
+s32 ixgbe_clear_vfta(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.clear_vfta, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_set_vfta - Set VLAN filter table
+ *  @hw: pointer to hardware structure
+ *  @vlan: VLAN id to write to VLAN filter
+ *  @vind: VMDq output index that maps queue to VLAN id in VLVFB
+ *  @vlan_on: boolean flag to turn on/off VLAN
+ *  @vlvf_bypass: boolean flag indicating updating the default pool is okay
+ *
+ *  Turn on/off specified VLAN in the VLAN filter table.
+ **/
+s32 ixgbe_set_vfta(struct ixgbe_hw *hw, u32 vlan, u32 vind, bool vlan_on,
+		   bool vlvf_bypass)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.set_vfta, (hw, vlan, vind,
+			       vlan_on, vlvf_bypass), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_set_vlvf - Set VLAN Pool Filter
+ *  @hw: pointer to hardware structure
+ *  @vlan: VLAN id to write to VLAN filter
+ *  @vind: VMDq output index that maps queue to VLAN id in VLVFB
+ *  @vlan_on: boolean flag to turn on/off VLAN in VLVF
+ *  @vfta_delta: pointer to the difference between the current value of VFTA
+ *		 and the desired value
+ *  @vfta: the desired value of the VFTA
+ *  @vlvf_bypass: boolean flag indicating updating the default pool is okay
+ *
+ *  Turn on/off specified bit in VLVF table.
+ **/
+s32 ixgbe_set_vlvf(struct ixgbe_hw *hw, u32 vlan, u32 vind, bool vlan_on,
+		   u32 *vfta_delta, u32 vfta, bool vlvf_bypass)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.set_vlvf, (hw, vlan, vind,
+			       vlan_on, vfta_delta, vfta, vlvf_bypass),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_fc_enable - Enable flow control
+ *  @hw: pointer to hardware structure
+ *
+ *  Configures the flow control settings based on SW configuration.
+ **/
+s32 ixgbe_fc_enable(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.fc_enable, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_setup_fc - Set up flow control
+ *  @hw: pointer to hardware structure
+ *
+ *  Called at init time to set up flow control.
+ **/
+s32 ixgbe_setup_fc(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.setup_fc, (hw),
+		IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ * ixgbe_set_fw_drv_ver - Try to send the driver version number FW
+ * @hw: pointer to hardware structure
+ * @maj: driver major number to be sent to firmware
+ * @min: driver minor number to be sent to firmware
+ * @build: driver build number to be sent to firmware
+ * @ver: driver version number to be sent to firmware
+ * @len: length of driver_ver string
+ * @driver_ver: driver string
+ **/
+s32 ixgbe_set_fw_drv_ver(struct ixgbe_hw *hw, u8 maj, u8 min, u8 build,
+			 u8 ver, u16 len, char *driver_ver)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.set_fw_drv_ver, (hw, maj, min,
+			       build, ver, len, driver_ver),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_get_thermal_sensor_data - Gathers thermal sensor data
+ *  @hw: pointer to hardware structure
+ *
+ *  Updates the temperatures in mac.thermal_sensor_data
+ **/
+s32 ixgbe_get_thermal_sensor_data(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.get_thermal_sensor_data, (hw),
+				IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_init_thermal_sensor_thresh - Inits thermal sensor thresholds
+ *  @hw: pointer to hardware structure
+ *
+ *  Inits the thermal sensor thresholds according to the NVM map
+ **/
+s32 ixgbe_init_thermal_sensor_thresh(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.init_thermal_sensor_thresh, (hw),
+				IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_dmac_config - Configure DMA Coalescing registers.
+ *  @hw: pointer to hardware structure
+ *
+ *  Configure DMA coalescing. If enabling dmac, dmac is activated.
+ *  When disabling dmac, dmac enable dmac bit is cleared.
+ **/
+s32 ixgbe_dmac_config(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.dmac_config, (hw),
+				IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_dmac_update_tcs - Configure DMA Coalescing registers.
+ *  @hw: pointer to hardware structure
+ *
+ *  Disables dmac, updates per TC settings, and then enable dmac.
+ **/
+s32 ixgbe_dmac_update_tcs(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.dmac_update_tcs, (hw),
+				IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_dmac_config_tcs - Configure DMA Coalescing registers.
+ *  @hw: pointer to hardware structure
+ *
+ *  Configure DMA coalescing threshold per TC and set high priority bit for
+ *  FCOE TC. The dmac enable bit must be cleared before configuring.
+ **/
+s32 ixgbe_dmac_config_tcs(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.dmac_config_tcs, (hw),
+				IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_setup_eee - Enable/disable EEE support
+ *  @hw: pointer to the HW structure
+ *  @enable_eee: boolean flag to enable EEE
+ *
+ *  Enable/disable EEE based on enable_ee flag.
+ *  Auto-negotiation must be started after BASE-T EEE bits in PHY register 7.3C
+ *  are modified.
+ *
+ **/
+s32 ixgbe_setup_eee(struct ixgbe_hw *hw, bool enable_eee)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.setup_eee, (hw, enable_eee),
+			IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ * ixgbe_set_source_address_pruning - Enable/Disable source address pruning
+ * @hw: pointer to hardware structure
+ * @enbale: enable or disable source address pruning
+ * @pool: Rx pool - Rx pool to toggle source address pruning
+ **/
+void ixgbe_set_source_address_pruning(struct ixgbe_hw *hw, bool enable,
+				      unsigned int pool)
+{
+	if (hw->mac.ops.set_source_address_pruning)
+		hw->mac.ops.set_source_address_pruning(hw, enable, pool);
+}
+
+/**
+ *  ixgbe_set_ethertype_anti_spoofing - Enable/Disable Ethertype anti-spoofing
+ *  @hw: pointer to hardware structure
+ *  @enable: enable or disable switch for Ethertype anti-spoofing
+ *  @vf: Virtual Function pool - VF Pool to set for Ethertype anti-spoofing
+ *
+ **/
+void ixgbe_set_ethertype_anti_spoofing(struct ixgbe_hw *hw, bool enable, int vf)
+{
+	if (hw->mac.ops.set_ethertype_anti_spoofing)
+		hw->mac.ops.set_ethertype_anti_spoofing(hw, enable, vf);
+}
+
+/**
+ *  ixgbe_read_iosf_sb_reg - Read 32 bit PHY register
+ *  @hw: pointer to hardware structure
+ *  @reg_addr: 32 bit address of PHY register to read
+ *  @device_type: type of device you want to communicate with
+ *  @phy_data: Pointer to read data from PHY register
+ *
+ *  Reads a value from a specified PHY register
+ **/
+s32 ixgbe_read_iosf_sb_reg(struct ixgbe_hw *hw, u32 reg_addr,
+			   u32 device_type, u32 *phy_data)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.read_iosf_sb_reg, (hw, reg_addr,
+			       device_type, phy_data), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_write_iosf_sb_reg - Write 32 bit register through IOSF Sideband
+ *  @hw: pointer to hardware structure
+ *  @reg_addr: 32 bit PHY register to write
+ *  @device_type: type of device you want to communicate with
+ *  @phy_data: Data to write to the PHY register
+ *
+ *  Writes a value to specified PHY register
+ **/
+s32 ixgbe_write_iosf_sb_reg(struct ixgbe_hw *hw, u32 reg_addr,
+			    u32 device_type, u32 phy_data)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.write_iosf_sb_reg, (hw, reg_addr,
+			       device_type, phy_data), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_disable_mdd - Disable malicious driver detection
+ *  @hw: pointer to hardware structure
+ *
+ **/
+void ixgbe_disable_mdd(struct ixgbe_hw *hw)
+{
+	if (hw->mac.ops.disable_mdd)
+		hw->mac.ops.disable_mdd(hw);
+}
+
+/**
+ *  ixgbe_enable_mdd - Enable malicious driver detection
+ *  @hw: pointer to hardware structure
+ *
+ **/
+void ixgbe_enable_mdd(struct ixgbe_hw *hw)
+{
+	if (hw->mac.ops.enable_mdd)
+		hw->mac.ops.enable_mdd(hw);
+}
+
+/**
+ *  ixgbe_mdd_event - Handle malicious driver detection event
+ *  @hw: pointer to hardware structure
+ *  @vf_bitmap: vf bitmap of malicious vfs
+ *
+ **/
+void ixgbe_mdd_event(struct ixgbe_hw *hw, u32 *vf_bitmap)
+{
+	if (hw->mac.ops.mdd_event)
+		hw->mac.ops.mdd_event(hw, vf_bitmap);
+}
+
+/**
+ *  ixgbe_restore_mdd_vf - Restore VF that was disabled during malicious driver
+ *  detection event
+ *  @hw: pointer to hardware structure
+ *  @vf: vf index
+ *
+ **/
+void ixgbe_restore_mdd_vf(struct ixgbe_hw *hw, u32 vf)
+{
+	if (hw->mac.ops.restore_mdd_vf)
+		hw->mac.ops.restore_mdd_vf(hw, vf);
+}
+
+/**
+ *  ixgbe_enter_lplu - Transition to low power states
+ *  @hw: pointer to hardware structure
+ *
+ * Configures Low Power Link Up on transition to low power states
+ * (from D0 to non-D0).
+ **/
+s32 ixgbe_enter_lplu(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.enter_lplu, (hw),
+				IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ * ixgbe_handle_lasi - Handle external Base T PHY interrupt
+ * @hw: pointer to hardware structure
+ *
+ * Handle external Base T PHY interrupt. If high temperature
+ * failure alarm then return error, else if link status change
+ * then setup internal/external PHY link
+ *
+ * Return IXGBE_ERR_OVERTEMP if interrupt is high temperature
+ * failure alarm, else return PHY access status.
+ */
+s32 ixgbe_handle_lasi(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.handle_lasi, (hw),
+				IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_read_analog_reg8 - Reads 8 bit analog register
+ *  @hw: pointer to hardware structure
+ *  @reg: analog register to read
+ *  @val: read value
+ *
+ *  Performs write operation to analog register specified.
+ **/
+s32 ixgbe_read_analog_reg8(struct ixgbe_hw *hw, u32 reg, u8 *val)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.read_analog_reg8, (hw, reg,
+			       val), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_write_analog_reg8 - Writes 8 bit analog register
+ *  @hw: pointer to hardware structure
+ *  @reg: analog register to write
+ *  @val: value to write
+ *
+ *  Performs write operation to Atlas analog register specified.
+ **/
+s32 ixgbe_write_analog_reg8(struct ixgbe_hw *hw, u32 reg, u8 val)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.write_analog_reg8, (hw, reg,
+			       val), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_init_uta_tables - Initializes Unicast Table Arrays.
+ *  @hw: pointer to hardware structure
+ *
+ *  Initializes the Unicast Table Arrays to zero on device load.  This
+ *  is part of the Rx init addr execution path.
+ **/
+s32 ixgbe_init_uta_tables(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.init_uta_tables, (hw),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_read_i2c_byte - Reads 8 bit word over I2C at specified device address
+ *  @hw: pointer to hardware structure
+ *  @byte_offset: byte offset to read
+ *  @dev_addr: I2C bus address to read from
+ *  @data: value read
+ *
+ *  Performs byte read operation to SFP module's EEPROM over I2C interface.
+ **/
+s32 ixgbe_read_i2c_byte(struct ixgbe_hw *hw, u8 byte_offset, u8 dev_addr,
+			u8 *data)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.read_i2c_byte, (hw, byte_offset,
+			       dev_addr, data), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_read_i2c_byte_unlocked - Reads 8 bit word via I2C from device address
+ *  @hw: pointer to hardware structure
+ *  @byte_offset: byte offset to read
+ *  @dev_addr: I2C bus address to read from
+ *  @data: value read
+ *
+ *  Performs byte read operation to SFP module's EEPROM over I2C interface.
+ **/
+s32 ixgbe_read_i2c_byte_unlocked(struct ixgbe_hw *hw, u8 byte_offset,
+				 u8 dev_addr, u8 *data)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.read_i2c_byte_unlocked,
+			       (hw, byte_offset, dev_addr, data),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ * ixgbe_read_link - Perform read operation on link device
+ * @hw: pointer to the hardware structure
+ * @addr: bus address to read from
+ * @reg: device register to read from
+ * @val: pointer to location to receive read value
+ *
+ * Returns an error code on error.
+ */
+s32 ixgbe_read_link(struct ixgbe_hw *hw, u8 addr, u16 reg, u16 *val)
+{
+	return ixgbe_call_func(hw, hw->link.ops.read_link, (hw, addr,
+			       reg, val), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ * ixgbe_read_link_unlocked - Perform read operation on link device
+ * @hw: pointer to the hardware structure
+ * @addr: bus address to read from
+ * @reg: device register to read from
+ * @val: pointer to location to receive read value
+ *
+ * Returns an error code on error.
+ **/
+s32 ixgbe_read_link_unlocked(struct ixgbe_hw *hw, u8 addr, u16 reg, u16 *val)
+{
+	return ixgbe_call_func(hw, hw->link.ops.read_link_unlocked,
+			       (hw, addr, reg, val), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_write_i2c_byte - Writes 8 bit word over I2C
+ *  @hw: pointer to hardware structure
+ *  @byte_offset: byte offset to write
+ *  @dev_addr: I2C bus address to write to
+ *  @data: value to write
+ *
+ *  Performs byte write operation to SFP module's EEPROM over I2C interface
+ *  at a specified device address.
+ **/
+s32 ixgbe_write_i2c_byte(struct ixgbe_hw *hw, u8 byte_offset, u8 dev_addr,
+			 u8 data)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.write_i2c_byte, (hw, byte_offset,
+			       dev_addr, data), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_write_i2c_byte_unlocked - Writes 8 bit word over I2C
+ *  @hw: pointer to hardware structure
+ *  @byte_offset: byte offset to write
+ *  @dev_addr: I2C bus address to write to
+ *  @data: value to write
+ *
+ *  Performs byte write operation to SFP module's EEPROM over I2C interface
+ *  at a specified device address.
+ **/
+s32 ixgbe_write_i2c_byte_unlocked(struct ixgbe_hw *hw, u8 byte_offset,
+				  u8 dev_addr, u8 data)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.write_i2c_byte_unlocked,
+			       (hw, byte_offset, dev_addr, data),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ * ixgbe_write_link - Perform write operation on link device
+ * @hw: pointer to the hardware structure
+ * @addr: bus address to write to
+ * @reg: device register to write to
+ * @val: value to write
+ *
+ * Returns an error code on error.
+ */
+s32 ixgbe_write_link(struct ixgbe_hw *hw, u8 addr, u16 reg, u16 val)
+{
+	return ixgbe_call_func(hw, hw->link.ops.write_link,
+			       (hw, addr, reg, val), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ * ixgbe_write_link_unlocked - Perform write operation on link device
+ * @hw: pointer to the hardware structure
+ * @addr: bus address to write to
+ * @reg: device register to write to
+ * @val: value to write
+ *
+ * Returns an error code on error.
+ **/
+s32 ixgbe_write_link_unlocked(struct ixgbe_hw *hw, u8 addr, u16 reg, u16 val)
+{
+	return ixgbe_call_func(hw, hw->link.ops.write_link_unlocked,
+			       (hw, addr, reg, val), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_write_i2c_eeprom - Writes 8 bit EEPROM word over I2C interface
+ *  @hw: pointer to hardware structure
+ *  @byte_offset: EEPROM byte offset to write
+ *  @eeprom_data: value to write
+ *
+ *  Performs byte write operation to SFP module's EEPROM over I2C interface.
+ **/
+s32 ixgbe_write_i2c_eeprom(struct ixgbe_hw *hw,
+			   u8 byte_offset, u8 eeprom_data)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.write_i2c_eeprom,
+			       (hw, byte_offset, eeprom_data),
+			       IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_read_i2c_eeprom - Reads 8 bit EEPROM word over I2C interface
+ *  @hw: pointer to hardware structure
+ *  @byte_offset: EEPROM byte offset to read
+ *  @eeprom_data: value read
+ *
+ *  Performs byte read operation to SFP module's EEPROM over I2C interface.
+ **/
+s32 ixgbe_read_i2c_eeprom(struct ixgbe_hw *hw, u8 byte_offset, u8 *eeprom_data)
+{
+	return ixgbe_call_func(hw, hw->phy.ops.read_i2c_eeprom,
+			      (hw, byte_offset, eeprom_data),
+			      IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_get_supported_physical_layer - Returns physical layer type
+ *  @hw: pointer to hardware structure
+ *
+ *  Determines physical layer capabilities of the current configuration.
+ **/
+u64 ixgbe_get_supported_physical_layer(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.get_supported_physical_layer,
+			       (hw), IXGBE_PHYSICAL_LAYER_UNKNOWN);
+}
+
+/**
+ *  ixgbe_enable_rx_dma - Enables Rx DMA unit, dependent on device specifics
+ *  @hw: pointer to hardware structure
+ *  @regval: bitfield to write to the Rx DMA register
+ *
+ *  Enables the Rx DMA unit of the device.
+ **/
+s32 ixgbe_enable_rx_dma(struct ixgbe_hw *hw, u32 regval)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.enable_rx_dma,
+			       (hw, regval), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_disable_sec_rx_path - Stops the receive data path
+ *  @hw: pointer to hardware structure
+ *
+ *  Stops the receive data path.
+ **/
+s32 ixgbe_disable_sec_rx_path(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.disable_sec_rx_path,
+				(hw), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_enable_sec_rx_path - Enables the receive data path
+ *  @hw: pointer to hardware structure
+ *
+ *  Enables the receive data path.
+ **/
+s32 ixgbe_enable_sec_rx_path(struct ixgbe_hw *hw)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.enable_sec_rx_path,
+				(hw), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_acquire_swfw_semaphore - Acquire SWFW semaphore
+ *  @hw: pointer to hardware structure
+ *  @mask: Mask to specify which semaphore to acquire
+ *
+ *  Acquires the SWFW semaphore through SW_FW_SYNC register for the specified
+ *  function (CSR, PHY0, PHY1, EEPROM, Flash)
+ **/
+s32 ixgbe_acquire_swfw_semaphore(struct ixgbe_hw *hw, u32 mask)
+{
+	return ixgbe_call_func(hw, hw->mac.ops.acquire_swfw_sync,
+			       (hw, mask), IXGBE_NOT_IMPLEMENTED);
+}
+
+/**
+ *  ixgbe_release_swfw_semaphore - Release SWFW semaphore
+ *  @hw: pointer to hardware structure
+ *  @mask: Mask to specify which semaphore to release
+ *
+ *  Releases the SWFW semaphore through SW_FW_SYNC register for the specified
+ *  function (CSR, PHY0, PHY1, EEPROM, Flash)
+ **/
+void ixgbe_release_swfw_semaphore(struct ixgbe_hw *hw, u32 mask)
+{
+	if (hw->mac.ops.release_swfw_sync)
+		hw->mac.ops.release_swfw_sync(hw, mask);
+}
+
+/**
+ *  ixgbe_init_swfw_semaphore - Clean up SWFW semaphore
+ *  @hw: pointer to hardware structure
+ *
+ *  Attempts to acquire the SWFW semaphore through SW_FW_SYNC register.
+ *  Regardless of whether is succeeds or not it then release the semaphore.
+ *  This is function is called to recover from catastrophic failures that
+ *  may have left the semaphore locked.
+ **/
+void ixgbe_init_swfw_semaphore(struct ixgbe_hw *hw)
+{
+	if (hw->mac.ops.init_swfw_sync)
+		hw->mac.ops.init_swfw_sync(hw);
+}
+
+void ixgbe_disable_rx(struct ixgbe_hw *hw)
+{
+	if (hw->mac.ops.disable_rx)
+		hw->mac.ops.disable_rx(hw);
+}
+
+void ixgbe_enable_rx(struct ixgbe_hw *hw)
+{
+	if (hw->mac.ops.enable_rx)
+		hw->mac.ops.enable_rx(hw);
+}
+
+/**
+ *  ixgbe_set_rate_select_speed - Set module link speed
+ *  @hw: pointer to hardware structure
+ *  @speed: link speed to set
+ *
+ *  Set module link speed via the rate select.
+ */
+void ixgbe_set_rate_select_speed(struct ixgbe_hw *hw, ixgbe_link_speed speed)
+{
+	if (hw->mac.ops.set_rate_select_speed)
+		hw->mac.ops.set_rate_select_speed(hw, speed);
+}
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_api.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_api.h
new file mode 100644
index 00000000..8016a49
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_api.h
@@ -0,0 +1,213 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#ifndef _IXGBE_API_H_
+#define _IXGBE_API_H_
+
+#include "ixgbe_type.h"
+
+void ixgbe_dcb_get_rtrup2tc(struct ixgbe_hw *hw, u8 *map);
+
+s32 ixgbe_init_shared_code(struct ixgbe_hw *hw);
+
+extern s32 ixgbe_init_ops_82598(struct ixgbe_hw *hw);
+extern s32 ixgbe_init_ops_82599(struct ixgbe_hw *hw);
+extern s32 ixgbe_init_ops_X540(struct ixgbe_hw *hw);
+extern s32 ixgbe_init_ops_X550(struct ixgbe_hw *hw);
+extern s32 ixgbe_init_ops_X550EM(struct ixgbe_hw *hw);
+extern s32 ixgbe_init_ops_X550EM_x(struct ixgbe_hw *hw);
+extern s32 ixgbe_init_ops_X550EM_a(struct ixgbe_hw *hw);
+
+s32 ixgbe_set_mac_type(struct ixgbe_hw *hw);
+s32 ixgbe_init_hw(struct ixgbe_hw *hw);
+s32 ixgbe_reset_hw(struct ixgbe_hw *hw);
+s32 ixgbe_start_hw(struct ixgbe_hw *hw);
+s32 ixgbe_clear_hw_cntrs(struct ixgbe_hw *hw);
+enum ixgbe_media_type ixgbe_get_media_type(struct ixgbe_hw *hw);
+s32 ixgbe_get_mac_addr(struct ixgbe_hw *hw, u8 *mac_addr);
+s32 ixgbe_get_bus_info(struct ixgbe_hw *hw);
+u32 ixgbe_get_num_of_tx_queues(struct ixgbe_hw *hw);
+u32 ixgbe_get_num_of_rx_queues(struct ixgbe_hw *hw);
+s32 ixgbe_stop_adapter(struct ixgbe_hw *hw);
+s32 ixgbe_read_pba_string(struct ixgbe_hw *hw, u8 *pba_num, u32 pba_num_size);
+
+s32 ixgbe_identify_phy(struct ixgbe_hw *hw);
+s32 ixgbe_reset_phy(struct ixgbe_hw *hw);
+s32 ixgbe_read_phy_reg(struct ixgbe_hw *hw, u32 reg_addr, u32 device_type,
+		       u16 *phy_data);
+s32 ixgbe_write_phy_reg(struct ixgbe_hw *hw, u32 reg_addr, u32 device_type,
+			u16 phy_data);
+
+s32 ixgbe_setup_phy_link(struct ixgbe_hw *hw);
+s32 ixgbe_setup_internal_phy(struct ixgbe_hw *hw);
+s32 ixgbe_check_phy_link(struct ixgbe_hw *hw,
+			 ixgbe_link_speed *speed,
+			 bool *link_up);
+s32 ixgbe_setup_phy_link_speed(struct ixgbe_hw *hw,
+			       ixgbe_link_speed speed,
+			       bool autoneg_wait_to_complete);
+s32 ixgbe_set_phy_power(struct ixgbe_hw *, bool on);
+void ixgbe_disable_tx_laser(struct ixgbe_hw *hw);
+void ixgbe_enable_tx_laser(struct ixgbe_hw *hw);
+void ixgbe_flap_tx_laser(struct ixgbe_hw *hw);
+s32 ixgbe_setup_link(struct ixgbe_hw *hw, ixgbe_link_speed speed,
+		     bool autoneg_wait_to_complete);
+s32 ixgbe_setup_mac_link(struct ixgbe_hw *hw, ixgbe_link_speed speed,
+			 bool autoneg_wait_to_complete);
+s32 ixgbe_check_link(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
+		     bool *link_up, bool link_up_wait_to_complete);
+s32 ixgbe_get_link_capabilities(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
+				bool *autoneg);
+s32 ixgbe_led_on(struct ixgbe_hw *hw, u32 index);
+s32 ixgbe_led_off(struct ixgbe_hw *hw, u32 index);
+s32 ixgbe_blink_led_start(struct ixgbe_hw *hw, u32 index);
+s32 ixgbe_blink_led_stop(struct ixgbe_hw *hw, u32 index);
+
+s32 ixgbe_init_eeprom_params(struct ixgbe_hw *hw);
+s32 ixgbe_write_eeprom(struct ixgbe_hw *hw, u16 offset, u16 data);
+s32 ixgbe_write_eeprom_buffer(struct ixgbe_hw *hw, u16 offset,
+			      u16 words, u16 *data);
+s32 ixgbe_read_eeprom(struct ixgbe_hw *hw, u16 offset, u16 *data);
+s32 ixgbe_read_eeprom_buffer(struct ixgbe_hw *hw, u16 offset,
+			     u16 words, u16 *data);
+
+s32 ixgbe_validate_eeprom_checksum(struct ixgbe_hw *hw, u16 *checksum_val);
+s32 ixgbe_update_eeprom_checksum(struct ixgbe_hw *hw);
+
+s32 ixgbe_insert_mac_addr(struct ixgbe_hw *hw, u8 *addr, u32 vmdq);
+s32 ixgbe_set_rar(struct ixgbe_hw *hw, u32 index, u8 *addr, u32 vmdq,
+		  u32 enable_addr);
+s32 ixgbe_clear_rar(struct ixgbe_hw *hw, u32 index);
+s32 ixgbe_set_vmdq(struct ixgbe_hw *hw, u32 rar, u32 vmdq);
+s32 ixgbe_set_vmdq_san_mac(struct ixgbe_hw *hw, u32 vmdq);
+s32 ixgbe_clear_vmdq(struct ixgbe_hw *hw, u32 rar, u32 vmdq);
+s32 ixgbe_init_rx_addrs(struct ixgbe_hw *hw);
+u32 ixgbe_get_num_rx_addrs(struct ixgbe_hw *hw);
+s32 ixgbe_update_uc_addr_list(struct ixgbe_hw *hw, u8 *addr_list,
+			      u32 addr_count, ixgbe_mc_addr_itr func);
+s32 ixgbe_update_mc_addr_list(struct ixgbe_hw *hw, u8 *mc_addr_list,
+			      u32 mc_addr_count, ixgbe_mc_addr_itr func,
+			      bool clear);
+void ixgbe_add_uc_addr(struct ixgbe_hw *hw, u8 *addr_list, u32 vmdq);
+s32 ixgbe_enable_mc(struct ixgbe_hw *hw);
+s32 ixgbe_disable_mc(struct ixgbe_hw *hw);
+s32 ixgbe_clear_vfta(struct ixgbe_hw *hw);
+s32 ixgbe_set_vfta(struct ixgbe_hw *hw, u32 vlan,
+		   u32 vind, bool vlan_on, bool vlvf_bypass);
+s32 ixgbe_set_vlvf(struct ixgbe_hw *hw, u32 vlan, u32 vind,
+		   bool vlan_on, u32 *vfta_delta, u32 vfta,
+		   bool vlvf_bypass);
+s32 ixgbe_fc_enable(struct ixgbe_hw *hw);
+s32 ixgbe_setup_fc(struct ixgbe_hw *hw);
+s32 ixgbe_set_fw_drv_ver(struct ixgbe_hw *hw, u8 maj, u8 min, u8 build,
+			 u8 ver, u16 len, char *driver_ver);
+s32 ixgbe_get_thermal_sensor_data(struct ixgbe_hw *hw);
+s32 ixgbe_init_thermal_sensor_thresh(struct ixgbe_hw *hw);
+void ixgbe_set_mta(struct ixgbe_hw *hw, u8 *mc_addr);
+s32 ixgbe_get_phy_firmware_version(struct ixgbe_hw *hw,
+				   u16 *firmware_version);
+s32 ixgbe_read_analog_reg8(struct ixgbe_hw *hw, u32 reg, u8 *val);
+s32 ixgbe_write_analog_reg8(struct ixgbe_hw *hw, u32 reg, u8 val);
+s32 ixgbe_init_uta_tables(struct ixgbe_hw *hw);
+s32 ixgbe_read_i2c_eeprom(struct ixgbe_hw *hw, u8 byte_offset, u8 *eeprom_data);
+u64 ixgbe_get_supported_physical_layer(struct ixgbe_hw *hw);
+s32 ixgbe_enable_rx_dma(struct ixgbe_hw *hw, u32 regval);
+s32 ixgbe_disable_sec_rx_path(struct ixgbe_hw *hw);
+s32 ixgbe_enable_sec_rx_path(struct ixgbe_hw *hw);
+s32 ixgbe_mng_fw_enabled(struct ixgbe_hw *hw);
+s32 ixgbe_reinit_fdir_tables_82599(struct ixgbe_hw *hw);
+s32 ixgbe_init_fdir_signature_82599(struct ixgbe_hw *hw, u32 fdirctrl);
+s32 ixgbe_init_fdir_perfect_82599(struct ixgbe_hw *hw, u32 fdirctrl,
+					bool cloud_mode);
+void ixgbe_fdir_add_signature_filter_82599(struct ixgbe_hw *hw,
+					   union ixgbe_atr_hash_dword input,
+					   union ixgbe_atr_hash_dword common,
+					   u8 queue);
+s32 ixgbe_fdir_set_input_mask_82599(struct ixgbe_hw *hw,
+				    union ixgbe_atr_input *input_mask, bool cloud_mode);
+s32 ixgbe_fdir_write_perfect_filter_82599(struct ixgbe_hw *hw,
+					  union ixgbe_atr_input *input,
+					  u16 soft_id, u8 queue, bool cloud_mode);
+s32 ixgbe_fdir_erase_perfect_filter_82599(struct ixgbe_hw *hw,
+					  union ixgbe_atr_input *input,
+					  u16 soft_id);
+s32 ixgbe_fdir_add_perfect_filter_82599(struct ixgbe_hw *hw,
+					union ixgbe_atr_input *input,
+					union ixgbe_atr_input *mask,
+					u16 soft_id,
+					u8 queue,
+					bool cloud_mode);
+void ixgbe_atr_compute_perfect_hash_82599(union ixgbe_atr_input *input,
+					  union ixgbe_atr_input *mask);
+u32 ixgbe_atr_compute_sig_hash_82599(union ixgbe_atr_hash_dword input,
+				     union ixgbe_atr_hash_dword common);
+bool ixgbe_verify_lesm_fw_enabled_82599(struct ixgbe_hw *hw);
+s32 ixgbe_read_i2c_byte(struct ixgbe_hw *hw, u8 byte_offset, u8 dev_addr,
+			u8 *data);
+s32 ixgbe_read_i2c_byte_unlocked(struct ixgbe_hw *hw, u8 byte_offset,
+				 u8 dev_addr, u8 *data);
+s32 ixgbe_read_link(struct ixgbe_hw *hw, u8 addr, u16 reg, u16 *val);
+s32 ixgbe_read_link_unlocked(struct ixgbe_hw *hw, u8 addr, u16 reg, u16 *val);
+s32 ixgbe_write_i2c_byte(struct ixgbe_hw *hw, u8 byte_offset, u8 dev_addr,
+			 u8 data);
+void ixgbe_set_fdir_drop_queue_82599(struct ixgbe_hw *hw, u8 dropqueue);
+s32 ixgbe_write_i2c_byte_unlocked(struct ixgbe_hw *hw, u8 byte_offset,
+				  u8 dev_addr, u8 data);
+s32 ixgbe_write_link(struct ixgbe_hw *hw, u8 addr, u16 reg, u16 val);
+s32 ixgbe_write_link_unlocked(struct ixgbe_hw *hw, u8 addr, u16 reg, u16 val);
+s32 ixgbe_write_i2c_eeprom(struct ixgbe_hw *hw, u8 byte_offset, u8 eeprom_data);
+s32 ixgbe_get_san_mac_addr(struct ixgbe_hw *hw, u8 *san_mac_addr);
+s32 ixgbe_set_san_mac_addr(struct ixgbe_hw *hw, u8 *san_mac_addr);
+s32 ixgbe_get_device_caps(struct ixgbe_hw *hw, u16 *device_caps);
+s32 ixgbe_acquire_swfw_semaphore(struct ixgbe_hw *hw, u32 mask);
+void ixgbe_release_swfw_semaphore(struct ixgbe_hw *hw, u32 mask);
+void ixgbe_init_swfw_semaphore(struct ixgbe_hw *hw);
+s32 ixgbe_get_wwn_prefix(struct ixgbe_hw *hw, u16 *wwnn_prefix,
+			 u16 *wwpn_prefix);
+s32 ixgbe_get_fcoe_boot_status(struct ixgbe_hw *hw, u16 *bs);
+s32 ixgbe_dmac_config(struct ixgbe_hw *hw);
+s32 ixgbe_dmac_update_tcs(struct ixgbe_hw *hw);
+s32 ixgbe_dmac_config_tcs(struct ixgbe_hw *hw);
+s32 ixgbe_setup_eee(struct ixgbe_hw *hw, bool enable_eee);
+void ixgbe_set_source_address_pruning(struct ixgbe_hw *hw, bool enable,
+				      unsigned int vf);
+void ixgbe_set_ethertype_anti_spoofing(struct ixgbe_hw *hw, bool enable,
+				       int vf);
+s32 ixgbe_read_iosf_sb_reg(struct ixgbe_hw *hw, u32 reg_addr,
+			u32 device_type, u32 *phy_data);
+s32 ixgbe_write_iosf_sb_reg(struct ixgbe_hw *hw, u32 reg_addr,
+			u32 device_type, u32 phy_data);
+void ixgbe_disable_mdd(struct ixgbe_hw *hw);
+void ixgbe_enable_mdd(struct ixgbe_hw *hw);
+void ixgbe_mdd_event(struct ixgbe_hw *hw, u32 *vf_bitmap);
+void ixgbe_restore_mdd_vf(struct ixgbe_hw *hw, u32 vf);
+s32 ixgbe_enter_lplu(struct ixgbe_hw *hw);
+s32 ixgbe_handle_lasi(struct ixgbe_hw *hw);
+void ixgbe_set_rate_select_speed(struct ixgbe_hw *hw, ixgbe_link_speed speed);
+void ixgbe_disable_rx(struct ixgbe_hw *hw);
+void ixgbe_enable_rx(struct ixgbe_hw *hw);
+s32 ixgbe_negotiate_fc(struct ixgbe_hw *hw, u32 adv_reg, u32 lp_reg,
+			u32 adv_sym, u32 adv_asm, u32 lp_sym, u32 lp_asm);
+
+#endif /* _IXGBE_API_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_cna.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_cna.c
new file mode 100644
index 00000000..5f51629
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_cna.c
@@ -0,0 +1,168 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+
+#include "ixgbe.h"
+#include "ixgbe_cna.h"
+#include "ixgbe_vmdq.h"
+
+static int ixgbe_cna_open(struct net_device *cnadev)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(cnadev);
+	strcpy(cnadev->name, adapter->netdev->name);
+	DPRINTK(PROBE, INFO, "CNA pseudo device opened %s\n", cnadev->name);
+	return 0;
+}
+
+static int ixgbe_cna_close(struct net_device *cnadev)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(cnadev);
+
+	DPRINTK(PROBE, INFO, "CNA pseudo device closed %s\n", cnadev->name);
+	return 0;
+}
+
+static int ixgbe_cna_change_mtu(struct net_device *cnadev, int new_mtu)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(cnadev);
+	int max_frame = new_mtu + ETH_HLEN + ETH_FCS_LEN;
+
+	/* MTU < 68 is an error and causes problems on some kernels */
+	if ((new_mtu < 68) || (max_frame > IXGBE_MAX_JUMBO_FRAME_SIZE))
+		return -EINVAL;
+
+	DPRINTK(PROBE, INFO, "changing MTU from %d to %d\n",
+		cnadev->mtu, new_mtu);
+	/* must set new MTU before calling down or up */
+	cnadev->mtu = new_mtu;
+
+	return 0;
+}
+
+int ixgbe_cna_enable(struct ixgbe_adapter *adapter)
+{
+	struct net_device *cnadev;
+	struct net_device *netdev;
+	int err;
+	u64 wwpn;
+	u64 wwnn;
+
+	netdev = adapter->netdev;
+	/*
+	 * Oppositely to regular net device, CNA device doesn't have
+	 * a private allocated region as we don't want to duplicate
+	 * ixgbe_adapter information. Though, the CNA device still need
+	 * to access the ixgbe_adapter while allocating queues or such. Thereby,
+	 * cnadev->priv needs to point to netdev->priv.
+	 */
+	cnadev = alloc_etherdev_mq(0, MAX_TX_QUEUES);
+	if (!cnadev) {
+		err = -ENOMEM;
+		goto err_alloc_etherdev;
+	}
+	adapter->cnadev = cnadev;
+	SET_MODULE_OWNER(cnadev);
+
+	cnadev->priv = adapter;
+
+	cnadev->open		= &ixgbe_cna_open;
+	cnadev->stop		= &ixgbe_cna_close;
+	cnadev->change_mtu	= &ixgbe_cna_change_mtu;
+	cnadev->do_ioctl	= netdev->do_ioctl;
+	cnadev->hard_start_xmit	= netdev->hard_start_xmit;
+#if defined(NETIF_F_HW_VLAN_TX) || defined(NETIF_F_HW_VLAN_CTAG_TX)
+	cnadev->vlan_rx_register = netdev->vlan_rx_register;
+	cnadev->vlan_rx_add_vid  = netdev->vlan_rx_add_vid;
+	cnadev->vlan_rx_kill_vid = netdev->vlan_rx_kill_vid;
+#endif
+	ixgbe_set_ethtool_ops(cnadev);
+
+#if IS_ENABLED(CONFIG_DCB)
+	cnadev->dcbnl_ops = netdev->dcbnl_ops;
+#endif /* CONFIG_DCB */
+
+	cnadev->mtu = netdev->mtu;
+	cnadev->pdev = netdev->pdev;
+	cnadev->gso_max_size = GSO_MAX_SIZE;
+	cnadev->features = netdev->features | NETIF_F_CNA | NETIF_F_HW_VLAN_FILTER;
+
+	/* set the MAC address to SAN mac address */
+	if (ixgbe_validate_mac_addr(adapter->hw.mac.san_addr) == 0)
+		memcpy(cnadev->dev_addr,
+		       adapter->hw.mac.san_addr,
+		       cnadev->addr_len);
+
+	cnadev->features |= NETIF_F_FCOE_CRC |
+			    NETIF_F_FCOE_MTU |
+			    NETIF_F_FSO;
+
+	cnadev->ndo_fcoe_ddp_setup = &ixgbe_fcoe_ddp_get;
+	cnadev->ndo_fcoe_ddp_done = &ixgbe_fcoe_ddp_put;
+	cnadev->fcoe_ddp_xid = IXGBE_FCOE_DDP_MAX - 1;
+
+	netif_carrier_off(cnadev);
+	netif_tx_stop_all_queues(cnadev);
+
+	VMKNETDDI_REGISTER_QUEUEOPS(cnadev, ixgbe_netqueue_ops);
+
+	err = register_netdev(cnadev);
+	if (err)
+		goto err_register;
+
+	DPRINTK(PROBE, INFO, "CNA pseudo device registered %s\n", netdev->name);
+
+	return err;
+
+err_register:
+	DPRINTK(PROBE, INFO, "CNA pseudo device cannot be registered %s\n",
+		netdev->name);
+	free_netdev(cnadev);
+err_alloc_etherdev:
+	DPRINTK(PROBE, INFO, "CNA cannot be enabled on %s\n", netdev->name);
+	adapter->flags2 &= ~IXGBE_FLAG2_CNA_ENABLED;
+	adapter->flags &= ~IXGBE_FLAG_FCOE_ENABLED;
+	adapter->ring_feature[RING_F_FCOE].indices = 0;
+	return err;
+}
+
+void ixgbe_cna_disable(struct ixgbe_adapter *adapter)
+{
+	if (!(adapter->flags2 & IXGBE_FLAG2_CNA_ENABLED))
+		return;
+
+	adapter->flags2 &= ~IXGBE_FLAG2_CNA_ENABLED;
+	adapter->flags &= ~IXGBE_FLAG_FCOE_ENABLED;
+	adapter->ring_feature[RING_F_FCOE].indices = 0;
+
+	if (adapter->cnadev) {
+		unregister_netdev(adapter->cnadev);
+		DPRINTK(PROBE, INFO, "CNA pseudo device unregistered %s\n",
+			adapter->cnadev->name);
+
+		free_netdev(adapter->cnadev);
+ 		adapter->cnadev = NULL;
+ 	}
+}
+
+/* ixgbe_cna.c */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_cna.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_cna.h
new file mode 100644
index 00000000..ee40480
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_cna.h
@@ -0,0 +1,31 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#ifndef _IXGBE_CNA_H_
+#define _IXGBE_CNA_H_
+
+int ixgbe_cna_enable(struct ixgbe_adapter *adapter);
+void ixgbe_cna_disable(struct ixgbe_adapter *adapter);
+
+#endif /* _IXGBE_CNA_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_common.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_common.c
index 105dd00..eb7840a 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_common.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_common.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,50 +22,132 @@
 
 *******************************************************************************/
 
-#include <linux/pci.h>
-#include <linux/delay.h>
-#include <linux/sched.h>
-#include <linux/netdevice.h>
-
-#include "ixgbe.h"
 #include "ixgbe_common.h"
 #include "ixgbe_phy.h"
-
-static s32 ixgbe_acquire_eeprom(struct ixgbe_hw *hw);
-static s32 ixgbe_get_eeprom_semaphore(struct ixgbe_hw *hw);
-static void ixgbe_release_eeprom_semaphore(struct ixgbe_hw *hw);
-static s32 ixgbe_ready_eeprom(struct ixgbe_hw *hw);
-static void ixgbe_standby_eeprom(struct ixgbe_hw *hw);
-static void ixgbe_shift_out_eeprom_bits(struct ixgbe_hw *hw, u16 data,
+#include "ixgbe_dcb.h"
+#include "ixgbe_dcb_82599.h"
+#include "ixgbe_api.h"
+
+STATIC s32 ixgbe_acquire_eeprom(struct ixgbe_hw *hw);
+STATIC s32 ixgbe_get_eeprom_semaphore(struct ixgbe_hw *hw);
+STATIC void ixgbe_release_eeprom_semaphore(struct ixgbe_hw *hw);
+STATIC s32 ixgbe_ready_eeprom(struct ixgbe_hw *hw);
+STATIC void ixgbe_standby_eeprom(struct ixgbe_hw *hw);
+STATIC void ixgbe_shift_out_eeprom_bits(struct ixgbe_hw *hw, u16 data,
 					u16 count);
-static u16 ixgbe_shift_in_eeprom_bits(struct ixgbe_hw *hw, u16 count);
-static void ixgbe_raise_eeprom_clk(struct ixgbe_hw *hw, u32 *eec);
-static void ixgbe_lower_eeprom_clk(struct ixgbe_hw *hw, u32 *eec);
-static void ixgbe_release_eeprom(struct ixgbe_hw *hw);
-
-static s32 ixgbe_mta_vector(struct ixgbe_hw *hw, u8 *mc_addr);
-static s32 ixgbe_poll_eerd_eewr_done(struct ixgbe_hw *hw, u32 ee_reg);
-static s32 ixgbe_read_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
-					     u16 words, u16 *data);
-static s32 ixgbe_write_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
+STATIC u16 ixgbe_shift_in_eeprom_bits(struct ixgbe_hw *hw, u16 count);
+STATIC void ixgbe_raise_eeprom_clk(struct ixgbe_hw *hw, u32 *eec);
+STATIC void ixgbe_lower_eeprom_clk(struct ixgbe_hw *hw, u32 *eec);
+STATIC void ixgbe_release_eeprom(struct ixgbe_hw *hw);
+
+STATIC s32 ixgbe_mta_vector(struct ixgbe_hw *hw, u8 *mc_addr);
+STATIC s32 ixgbe_get_san_mac_addr_offset(struct ixgbe_hw *hw,
+					 u16 *san_mac_offset);
+STATIC s32 ixgbe_read_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
 					     u16 words, u16 *data);
-static s32 ixgbe_detect_eeprom_page_size_generic(struct ixgbe_hw *hw,
+STATIC s32 ixgbe_write_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
+					      u16 words, u16 *data);
+STATIC s32 ixgbe_detect_eeprom_page_size_generic(struct ixgbe_hw *hw,
 						 u16 offset);
-static s32 ixgbe_disable_pcie_master(struct ixgbe_hw *hw);
 
-/* Base table for registers values that change by MAC */
-const u32 ixgbe_mvals_8259X[IXGBE_MVALS_IDX_LIMIT] = {
-	IXGBE_MVALS_INIT(8259X)
-};
+/**
+ *  ixgbe_init_ops_generic - Inits function ptrs
+ *  @hw: pointer to the hardware structure
+ *
+ *  Initialize the function pointers.
+ **/
+s32 ixgbe_init_ops_generic(struct ixgbe_hw *hw)
+{
+	struct ixgbe_eeprom_info *eeprom = &hw->eeprom;
+	struct ixgbe_mac_info *mac = &hw->mac;
+	u32 eec = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
+
+	DEBUGFUNC("ixgbe_init_ops_generic");
+
+	/* EEPROM */
+	eeprom->ops.init_params = ixgbe_init_eeprom_params_generic;
+	/* If EEPROM is valid (bit 8 = 1), use EERD otherwise use bit bang */
+	if (eec & IXGBE_EEC_PRES) {
+		eeprom->ops.read = ixgbe_read_eerd_generic;
+		eeprom->ops.read_buffer = ixgbe_read_eerd_buffer_generic;
+	} else {
+		eeprom->ops.read = ixgbe_read_eeprom_bit_bang_generic;
+		eeprom->ops.read_buffer =
+				 ixgbe_read_eeprom_buffer_bit_bang_generic;
+	}
+	eeprom->ops.write = ixgbe_write_eeprom_generic;
+	eeprom->ops.write_buffer = ixgbe_write_eeprom_buffer_bit_bang_generic;
+	eeprom->ops.validate_checksum =
+				      ixgbe_validate_eeprom_checksum_generic;
+	eeprom->ops.update_checksum = ixgbe_update_eeprom_checksum_generic;
+	eeprom->ops.calc_checksum = ixgbe_calc_eeprom_checksum_generic;
+
+	/* MAC */
+	mac->ops.init_hw = ixgbe_init_hw_generic;
+	mac->ops.reset_hw = NULL;
+	mac->ops.start_hw = ixgbe_start_hw_generic;
+	mac->ops.clear_hw_cntrs = ixgbe_clear_hw_cntrs_generic;
+	mac->ops.get_media_type = NULL;
+	mac->ops.get_supported_physical_layer = NULL;
+	mac->ops.enable_rx_dma = ixgbe_enable_rx_dma_generic;
+	mac->ops.get_mac_addr = ixgbe_get_mac_addr_generic;
+	mac->ops.stop_adapter = ixgbe_stop_adapter_generic;
+	mac->ops.get_bus_info = ixgbe_get_bus_info_generic;
+	mac->ops.set_lan_id = ixgbe_set_lan_id_multi_port_pcie;
+	mac->ops.acquire_swfw_sync = ixgbe_acquire_swfw_sync;
+	mac->ops.release_swfw_sync = ixgbe_release_swfw_sync;
+	mac->ops.prot_autoc_read = prot_autoc_read_generic;
+	mac->ops.prot_autoc_write = prot_autoc_write_generic;
+
+	/* LEDs */
+	mac->ops.led_on = ixgbe_led_on_generic;
+	mac->ops.led_off = ixgbe_led_off_generic;
+	mac->ops.blink_led_start = ixgbe_blink_led_start_generic;
+	mac->ops.blink_led_stop = ixgbe_blink_led_stop_generic;
+	mac->ops.init_led_link_act = ixgbe_init_led_link_act_generic;
+
+	/* RAR, Multicast, VLAN */
+	mac->ops.set_rar = ixgbe_set_rar_generic;
+	mac->ops.clear_rar = ixgbe_clear_rar_generic;
+	mac->ops.insert_mac_addr = NULL;
+	mac->ops.set_vmdq = NULL;
+	mac->ops.clear_vmdq = NULL;
+	mac->ops.init_rx_addrs = ixgbe_init_rx_addrs_generic;
+	mac->ops.update_uc_addr_list = ixgbe_update_uc_addr_list_generic;
+	mac->ops.update_mc_addr_list = ixgbe_update_mc_addr_list_generic;
+	mac->ops.enable_mc = ixgbe_enable_mc_generic;
+	mac->ops.disable_mc = ixgbe_disable_mc_generic;
+	mac->ops.clear_vfta = NULL;
+	mac->ops.set_vfta = NULL;
+	mac->ops.set_vlvf = NULL;
+	mac->ops.init_uta_tables = NULL;
+	mac->ops.enable_rx = ixgbe_enable_rx_generic;
+	mac->ops.disable_rx = ixgbe_disable_rx_generic;
+
+	/* Flow Control */
+	mac->ops.fc_enable = ixgbe_fc_enable_generic;
+	mac->ops.setup_fc = ixgbe_setup_fc_generic;
+	mac->ops.fc_autoneg = ixgbe_fc_autoneg;
+
+	/* Link */
+	mac->ops.get_link_capabilities = NULL;
+	mac->ops.setup_link = NULL;
+	mac->ops.check_link = NULL;
+	mac->ops.dmac_config = NULL;
+	mac->ops.dmac_update_tcs = NULL;
+	mac->ops.dmac_config_tcs = NULL;
+
+	return IXGBE_SUCCESS;
+}
 
 /**
- *  ixgbe_device_supports_autoneg_fc - Check if phy supports autoneg flow
- *  control
- *  @hw: pointer to hardware structure
+ * ixgbe_device_supports_autoneg_fc - Check if device supports autonegotiation
+ * of flow control
+ * @hw: pointer to hardware structure
+ *
+ * This function returns true if the device supports flow control
+ * autonegotiation, and false if it does not.
  *
- *  There are several phys that do not support autoneg flow control. This
- *  function check the device id to see if the associated phy supports
- *  autoneg flow control.
  **/
 bool ixgbe_device_supports_autoneg_fc(struct ixgbe_hw *hw)
 {
@@ -77,18 +155,35 @@ bool ixgbe_device_supports_autoneg_fc(struct ixgbe_hw *hw)
 	ixgbe_link_speed speed;
 	bool link_up;
 
+	DEBUGFUNC("ixgbe_device_supports_autoneg_fc");
+
 	switch (hw->phy.media_type) {
+	case ixgbe_media_type_fiber_qsfp:
 	case ixgbe_media_type_fiber:
-		hw->mac.ops.check_link(hw, &speed, &link_up, false);
-		/* if link is down, assume supported */
-		if (link_up)
-			supported = speed == IXGBE_LINK_SPEED_1GB_FULL ?
+		/* flow control autoneg black list */
+		switch (hw->device_id) {
+		case IXGBE_DEV_ID_X550EM_A_SFP:
+		case IXGBE_DEV_ID_X550EM_A_SFP_N:
+		case IXGBE_DEV_ID_X550EM_A_QSFP:
+		case IXGBE_DEV_ID_X550EM_A_QSFP_N:
+			supported = false;
+			break;
+		default:
+			hw->mac.ops.check_link(hw, &speed, &link_up, false);
+			/* if link is down, assume supported */
+			if (link_up)
+				supported = speed == IXGBE_LINK_SPEED_1GB_FULL ?
 				true : false;
-		else
-			supported = true;
+			else
+				supported = true;
+		}
+
 		break;
 	case ixgbe_media_type_backplane:
-		supported = true;
+		if (hw->device_id == IXGBE_DEV_ID_X550EM_X_XFI)
+			supported = false;
+		else
+			supported = true;
 		break;
 	case ixgbe_media_type_copper:
 		/* only some copper devices support flow control autoneg */
@@ -97,39 +192,48 @@ bool ixgbe_device_supports_autoneg_fc(struct ixgbe_hw *hw)
 		case IXGBE_DEV_ID_X540T:
 		case IXGBE_DEV_ID_X540T1:
 		case IXGBE_DEV_ID_X550T:
+		case IXGBE_DEV_ID_X550T1:
 		case IXGBE_DEV_ID_X550EM_X_10G_T:
+		case IXGBE_DEV_ID_X550EM_A_10G_T:
+		case IXGBE_DEV_ID_X550EM_A_1G_T:
+		case IXGBE_DEV_ID_X550EM_A_1G_T_L:
 			supported = true;
 			break;
 		default:
-			break;
+			supported = false;
 		}
 	default:
 		break;
 	}
 
+	if (!supported)
+		ERROR_REPORT2(IXGBE_ERROR_UNSUPPORTED,
+			      "Device %x does not support flow control autoneg",
+			      hw->device_id);
 	return supported;
 }
 
 /**
- *  ixgbe_setup_fc - Set up flow control
+ *  ixgbe_setup_fc_generic - Set up flow control
  *  @hw: pointer to hardware structure
  *
  *  Called at init time to set up flow control.
  **/
-static s32 ixgbe_setup_fc(struct ixgbe_hw *hw)
+s32 ixgbe_setup_fc_generic(struct ixgbe_hw *hw)
 {
-	s32 ret_val = 0;
+	s32 ret_val = IXGBE_SUCCESS;
 	u32 reg = 0, reg_bp = 0;
 	u16 reg_cu = 0;
 	bool locked = false;
 
-	/*
-	 * Validate the requested mode.  Strict IEEE mode does not allow
-	 * ixgbe_fc_rx_pause because it will cause us to fail at UNH.
-	 */
+	DEBUGFUNC("ixgbe_setup_fc_generic");
+
+	/* Validate the requested mode */
 	if (hw->fc.strict_ieee && hw->fc.requested_mode == ixgbe_fc_rx_pause) {
-		hw_dbg(hw, "ixgbe_fc_rx_pause not valid in strict IEEE mode\n");
-		return IXGBE_ERR_INVALID_LINK_SETTINGS;
+		ERROR_REPORT1(IXGBE_ERROR_UNSUPPORTED,
+			   "ixgbe_fc_rx_pause not valid in strict IEEE mode\n");
+		ret_val = IXGBE_ERR_INVALID_LINK_SETTINGS;
+		goto out;
 	}
 
 	/*
@@ -148,17 +252,18 @@ static s32 ixgbe_setup_fc(struct ixgbe_hw *hw)
 	case ixgbe_media_type_backplane:
 		/* some MAC's need RMW protection on AUTOC */
 		ret_val = hw->mac.ops.prot_autoc_read(hw, &locked, &reg_bp);
-		if (ret_val)
-			return ret_val;
+		if (ret_val != IXGBE_SUCCESS)
+			goto out;
 
-		/* only backplane uses autoc so fall though */
+		/* fall through - only backplane uses autoc */
+	case ixgbe_media_type_fiber_qsfp:
 	case ixgbe_media_type_fiber:
 		reg = IXGBE_READ_REG(hw, IXGBE_PCS1GANA);
 
 		break;
 	case ixgbe_media_type_copper:
-		hw->phy.ops.read_reg(hw, MDIO_AN_ADVERTISE,
-					MDIO_MMD_AN, &reg_cu);
+		hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_ADVT,
+				     IXGBE_MDIO_AUTO_NEG_DEV_TYPE, &reg_cu);
 		break;
 	default:
 		break;
@@ -219,11 +324,14 @@ static s32 ixgbe_setup_fc(struct ixgbe_hw *hw)
 			reg_cu |= IXGBE_TAF_SYM_PAUSE | IXGBE_TAF_ASM_PAUSE;
 		break;
 	default:
-		hw_dbg(hw, "Flow control param set incorrectly\n");
-		return IXGBE_ERR_CONFIG;
+		ERROR_REPORT1(IXGBE_ERROR_ARGUMENT,
+			     "Flow control param set incorrectly\n");
+		ret_val = IXGBE_ERR_CONFIG;
+		goto out;
+		break;
 	}
 
-	if (hw->mac.type != ixgbe_mac_X540) {
+	if (hw->mac.type < ixgbe_mac_X540) {
 		/*
 		 * Enable auto-negotiation between the MAC & PHY;
 		 * the MAC will advertise clause 37 flow control.
@@ -236,7 +344,7 @@ static s32 ixgbe_setup_fc(struct ixgbe_hw *hw)
 			reg &= ~IXGBE_PCS1GLCTL_AN_1G_TIMEOUT_EN;
 
 		IXGBE_WRITE_REG(hw, IXGBE_PCS1GLCTL, reg);
-		hw_dbg(hw, "Set up FC; PCS1GLCTL = 0x%08X\n", reg);
+		DEBUGOUT1("Set up FC; PCS1GLCTL = 0x%08X\n", reg);
 	}
 
 	/*
@@ -245,21 +353,18 @@ static s32 ixgbe_setup_fc(struct ixgbe_hw *hw)
 	 *
 	 */
 	if (hw->phy.media_type == ixgbe_media_type_backplane) {
-		/* Need the SW/FW semaphore around AUTOC writes if 82599 and
-		 * LESM is on, likewise reset_pipeline requries the lock as
-		 * it also writes AUTOC.
-		 */
+		reg_bp |= IXGBE_AUTOC_AN_RESTART;
 		ret_val = hw->mac.ops.prot_autoc_write(hw, reg_bp, locked);
 		if (ret_val)
-			return ret_val;
-
+			goto out;
 	} else if ((hw->phy.media_type == ixgbe_media_type_copper) &&
-		   ixgbe_device_supports_autoneg_fc(hw)) {
-		hw->phy.ops.write_reg(hw, MDIO_AN_ADVERTISE,
-				      MDIO_MMD_AN, reg_cu);
+		    (ixgbe_device_supports_autoneg_fc(hw))) {
+		hw->phy.ops.write_reg(hw, IXGBE_MDIO_AUTO_NEG_ADVT,
+				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE, reg_cu);
 	}
 
-	hw_dbg(hw, "Set up FC; IXGBE_AUTOC = 0x%08X\n", reg);
+	DEBUGOUT1("Set up FC; PCS1GLCTL = 0x%08X\n", reg);
+out:
 	return ret_val;
 }
 
@@ -276,12 +381,14 @@ s32 ixgbe_start_hw_generic(struct ixgbe_hw *hw)
 {
 	s32 ret_val;
 	u32 ctrl_ext;
+	u16 device_caps;
+
+	DEBUGFUNC("ixgbe_start_hw_generic");
 
 	/* Set the media type */
 	hw->phy.media_type = hw->mac.ops.get_media_type(hw);
 
-	/* Identify the PHY */
-	hw->phy.ops.identify(hw);
+	/* PHY ops initialization must be done in reset_hw() */
 
 	/* Clear the VLAN filter table */
 	hw->mac.ops.clear_vfta(hw);
@@ -297,13 +404,31 @@ s32 ixgbe_start_hw_generic(struct ixgbe_hw *hw)
 
 	/* Setup flow control */
 	ret_val = ixgbe_setup_fc(hw);
-	if (ret_val)
+	if (ret_val != IXGBE_SUCCESS && ret_val != IXGBE_NOT_IMPLEMENTED) {
+		DEBUGOUT1("Flow control setup failed, returning %d\n", ret_val);
 		return ret_val;
+	}
+
+	/* Cache bit indicating need for crosstalk fix */
+	switch (hw->mac.type) {
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		hw->mac.ops.get_device_caps(hw, &device_caps);
+		if (device_caps & IXGBE_DEVICE_CAPS_NO_CROSSTALK_WR)
+			hw->need_crosstalk_fix = false;
+		else
+			hw->need_crosstalk_fix = true;
+		break;
+	default:
+		hw->need_crosstalk_fix = false;
+		break;
+	}
 
 	/* Clear adapter stopped flag */
 	hw->adapter_stopped = false;
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -319,6 +444,7 @@ s32 ixgbe_start_hw_generic(struct ixgbe_hw *hw)
 s32 ixgbe_start_hw_gen2(struct ixgbe_hw *hw)
 {
 	u32 i;
+	u32 regval;
 
 	/* Clear the rate limiters */
 	for (i = 0; i < hw->mac.max_tx_queues; i++) {
@@ -327,26 +453,21 @@ s32 ixgbe_start_hw_gen2(struct ixgbe_hw *hw)
 	}
 	IXGBE_WRITE_FLUSH(hw);
 
-#ifndef CONFIG_SPARC
 	/* Disable relaxed ordering */
 	for (i = 0; i < hw->mac.max_tx_queues; i++) {
-		u32 regval;
-
 		regval = IXGBE_READ_REG(hw, IXGBE_DCA_TXCTRL_82599(i));
 		regval &= ~IXGBE_DCA_TXCTRL_DESC_WRO_EN;
 		IXGBE_WRITE_REG(hw, IXGBE_DCA_TXCTRL_82599(i), regval);
 	}
 
 	for (i = 0; i < hw->mac.max_rx_queues; i++) {
-		u32 regval;
-
 		regval = IXGBE_READ_REG(hw, IXGBE_DCA_RXCTRL(i));
 		regval &= ~(IXGBE_DCA_RXCTRL_DATA_WRO_EN |
 			    IXGBE_DCA_RXCTRL_HEAD_WRO_EN);
 		IXGBE_WRITE_REG(hw, IXGBE_DCA_RXCTRL(i), regval);
 	}
-#endif
-	return 0;
+
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -363,14 +484,23 @@ s32 ixgbe_init_hw_generic(struct ixgbe_hw *hw)
 {
 	s32 status;
 
+	DEBUGFUNC("ixgbe_init_hw_generic");
+
 	/* Reset the hardware */
 	status = hw->mac.ops.reset_hw(hw);
 
-	if (status == 0) {
+	if (status == IXGBE_SUCCESS || status == IXGBE_ERR_SFP_NOT_PRESENT) {
 		/* Start the HW */
 		status = hw->mac.ops.start_hw(hw);
 	}
 
+	/* Initialize the LED link active for LED blink support */
+	if (hw->mac.ops.init_led_link_act)
+		hw->mac.ops.init_led_link_act(hw);
+
+	if (status != IXGBE_SUCCESS)
+		DEBUGOUT1("Failed to initialize HW, STATUS = %d\n", status);
+
 	return status;
 }
 
@@ -385,6 +515,8 @@ s32 ixgbe_clear_hw_cntrs_generic(struct ixgbe_hw *hw)
 {
 	u16 i = 0;
 
+	DEBUGFUNC("ixgbe_clear_hw_cntrs_generic");
+
 	IXGBE_READ_REG(hw, IXGBE_CRCERRS);
 	IXGBE_READ_REG(hw, IXGBE_ILLERRC);
 	IXGBE_READ_REG(hw, IXGBE_ERRBC);
@@ -472,14 +604,18 @@ s32 ixgbe_clear_hw_cntrs_generic(struct ixgbe_hw *hw)
 
 	if (hw->mac.type == ixgbe_mac_X550 || hw->mac.type == ixgbe_mac_X540) {
 		if (hw->phy.id == 0)
-			hw->phy.ops.identify(hw);
-		hw->phy.ops.read_reg(hw, IXGBE_PCRC8ECL, MDIO_MMD_PCS, &i);
-		hw->phy.ops.read_reg(hw, IXGBE_PCRC8ECH, MDIO_MMD_PCS, &i);
-		hw->phy.ops.read_reg(hw, IXGBE_LDPCECL, MDIO_MMD_PCS, &i);
-		hw->phy.ops.read_reg(hw, IXGBE_LDPCECH, MDIO_MMD_PCS, &i);
+			ixgbe_identify_phy(hw);
+		hw->phy.ops.read_reg(hw, IXGBE_PCRC8ECL,
+				     IXGBE_MDIO_PCS_DEV_TYPE, &i);
+		hw->phy.ops.read_reg(hw, IXGBE_PCRC8ECH,
+				     IXGBE_MDIO_PCS_DEV_TYPE, &i);
+		hw->phy.ops.read_reg(hw, IXGBE_LDPCECL,
+				     IXGBE_MDIO_PCS_DEV_TYPE, &i);
+		hw->phy.ops.read_reg(hw, IXGBE_LDPCECH,
+				     IXGBE_MDIO_PCS_DEV_TYPE, &i);
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -499,20 +635,22 @@ s32 ixgbe_read_pba_string_generic(struct ixgbe_hw *hw, u8 *pba_num,
 	u16 offset;
 	u16 length;
 
+	DEBUGFUNC("ixgbe_read_pba_string_generic");
+
 	if (pba_num == NULL) {
-		hw_dbg(hw, "PBA string buffer was null\n");
+		DEBUGOUT("PBA string buffer was null\n");
 		return IXGBE_ERR_INVALID_ARGUMENT;
 	}
 
 	ret_val = hw->eeprom.ops.read(hw, IXGBE_PBANUM0_PTR, &data);
 	if (ret_val) {
-		hw_dbg(hw, "NVM Read Error\n");
+		DEBUGOUT("NVM Read Error\n");
 		return ret_val;
 	}
 
 	ret_val = hw->eeprom.ops.read(hw, IXGBE_PBANUM1_PTR, &pba_ptr);
 	if (ret_val) {
-		hw_dbg(hw, "NVM Read Error\n");
+		DEBUGOUT("NVM Read Error\n");
 		return ret_val;
 	}
 
@@ -522,11 +660,11 @@ s32 ixgbe_read_pba_string_generic(struct ixgbe_hw *hw, u8 *pba_num,
 	 * and we can decode it into an ascii string
 	 */
 	if (data != IXGBE_PBANUM_PTR_GUARD) {
-		hw_dbg(hw, "NVM PBA number is not stored as string\n");
+		DEBUGOUT("NVM PBA number is not stored as string\n");
 
 		/* we will need 11 characters to store the PBA */
 		if (pba_num_size < 11) {
-			hw_dbg(hw, "PBA string buffer too small\n");
+			DEBUGOUT("PBA string buffer too small\n");
 			return IXGBE_ERR_NO_SPACE;
 		}
 
@@ -553,23 +691,23 @@ s32 ixgbe_read_pba_string_generic(struct ixgbe_hw *hw, u8 *pba_num,
 				pba_num[offset] += 'A' - 0xA;
 		}
 
-		return 0;
+		return IXGBE_SUCCESS;
 	}
 
 	ret_val = hw->eeprom.ops.read(hw, pba_ptr, &length);
 	if (ret_val) {
-		hw_dbg(hw, "NVM Read Error\n");
+		DEBUGOUT("NVM Read Error\n");
 		return ret_val;
 	}
 
 	if (length == 0xFFFF || length == 0) {
-		hw_dbg(hw, "NVM PBA number section invalid length\n");
+		DEBUGOUT("NVM PBA number section invalid length\n");
 		return IXGBE_ERR_PBA_SECTION;
 	}
 
 	/* check if pba_num buffer is big enough */
 	if (pba_num_size  < (((u32)length * 2) - 1)) {
-		hw_dbg(hw, "PBA string buffer too small\n");
+		DEBUGOUT("PBA string buffer too small\n");
 		return IXGBE_ERR_NO_SPACE;
 	}
 
@@ -580,7 +718,7 @@ s32 ixgbe_read_pba_string_generic(struct ixgbe_hw *hw, u8 *pba_num,
 	for (offset = 0; offset < length; offset++) {
 		ret_val = hw->eeprom.ops.read(hw, pba_ptr + offset, &data);
 		if (ret_val) {
-			hw_dbg(hw, "NVM Read Error\n");
+			DEBUGOUT("NVM Read Error\n");
 			return ret_val;
 		}
 		pba_num[offset * 2] = (u8)(data >> 8);
@@ -588,7 +726,7 @@ s32 ixgbe_read_pba_string_generic(struct ixgbe_hw *hw, u8 *pba_num,
 	}
 	pba_num[offset * 2] = '\0';
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -606,6 +744,8 @@ s32 ixgbe_get_mac_addr_generic(struct ixgbe_hw *hw, u8 *mac_addr)
 	u32 rar_low;
 	u16 i;
 
+	DEBUGFUNC("ixgbe_get_mac_addr_generic");
+
 	rar_high = IXGBE_READ_REG(hw, IXGBE_RAH(0));
 	rar_low = IXGBE_READ_REG(hw, IXGBE_RAL(0));
 
@@ -615,82 +755,111 @@ s32 ixgbe_get_mac_addr_generic(struct ixgbe_hw *hw, u8 *mac_addr)
 	for (i = 0; i < 2; i++)
 		mac_addr[i+4] = (u8)(rar_high >> (i*8));
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
-enum ixgbe_bus_width ixgbe_convert_bus_width(u16 link_status)
+/**
+ *  ixgbe_set_pci_config_data_generic - Generic store PCI bus info
+ *  @hw: pointer to hardware structure
+ *  @link_status: the link status returned by the PCI config space
+ *
+ *  Stores the PCI bus info (speed, width, type) within the ixgbe_hw structure
+ **/
+void ixgbe_set_pci_config_data_generic(struct ixgbe_hw *hw, u16 link_status)
 {
+	struct ixgbe_mac_info *mac = &hw->mac;
+
+	if (hw->bus.type == ixgbe_bus_type_unknown)
+		hw->bus.type = ixgbe_bus_type_pci_express;
+
 	switch (link_status & IXGBE_PCI_LINK_WIDTH) {
 	case IXGBE_PCI_LINK_WIDTH_1:
-		return ixgbe_bus_width_pcie_x1;
+		hw->bus.width = ixgbe_bus_width_pcie_x1;
+		break;
 	case IXGBE_PCI_LINK_WIDTH_2:
-		return ixgbe_bus_width_pcie_x2;
+		hw->bus.width = ixgbe_bus_width_pcie_x2;
+		break;
 	case IXGBE_PCI_LINK_WIDTH_4:
-		return ixgbe_bus_width_pcie_x4;
+		hw->bus.width = ixgbe_bus_width_pcie_x4;
+		break;
 	case IXGBE_PCI_LINK_WIDTH_8:
-		return ixgbe_bus_width_pcie_x8;
+		hw->bus.width = ixgbe_bus_width_pcie_x8;
+		break;
 	default:
-		return ixgbe_bus_width_unknown;
+		hw->bus.width = ixgbe_bus_width_unknown;
+		break;
 	}
-}
 
-enum ixgbe_bus_speed ixgbe_convert_bus_speed(u16 link_status)
-{
 	switch (link_status & IXGBE_PCI_LINK_SPEED) {
 	case IXGBE_PCI_LINK_SPEED_2500:
-		return ixgbe_bus_speed_2500;
+		hw->bus.speed = ixgbe_bus_speed_2500;
+		break;
 	case IXGBE_PCI_LINK_SPEED_5000:
-		return ixgbe_bus_speed_5000;
+		hw->bus.speed = ixgbe_bus_speed_5000;
+		break;
 	case IXGBE_PCI_LINK_SPEED_8000:
-		return ixgbe_bus_speed_8000;
+		hw->bus.speed = ixgbe_bus_speed_8000;
+		break;
 	default:
-		return ixgbe_bus_speed_unknown;
+		hw->bus.speed = ixgbe_bus_speed_unknown;
+		break;
 	}
+
+	mac->ops.set_lan_id(hw);
 }
 
 /**
  *  ixgbe_get_bus_info_generic - Generic set PCI bus info
  *  @hw: pointer to hardware structure
  *
- *  Sets the PCI bus info (speed, width, type) within the ixgbe_hw structure
+ *  Gets the PCI bus info (speed, width, type) then calls helper function to
+ *  store this data within the ixgbe_hw structure.
  **/
 s32 ixgbe_get_bus_info_generic(struct ixgbe_hw *hw)
 {
 	u16 link_status;
 
-	hw->bus.type = ixgbe_bus_type_pci_express;
+	DEBUGFUNC("ixgbe_get_bus_info_generic");
 
 	/* Get the negotiated link width and speed from PCI config space */
-	link_status = ixgbe_read_pci_cfg_word(hw, IXGBE_PCI_LINK_STATUS);
+	link_status = IXGBE_READ_PCIE_WORD(hw, IXGBE_PCI_LINK_STATUS);
 
-	hw->bus.width = ixgbe_convert_bus_width(link_status);
-	hw->bus.speed = ixgbe_convert_bus_speed(link_status);
+	ixgbe_set_pci_config_data_generic(hw, link_status);
 
-	hw->mac.ops.set_lan_id(hw);
-
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
  *  ixgbe_set_lan_id_multi_port_pcie - Set LAN id for PCIe multiple port devices
  *  @hw: pointer to the HW structure
  *
- *  Determines the LAN function id by reading memory-mapped registers
- *  and swaps the port value if requested.
+ *  Determines the LAN function id by reading memory-mapped registers and swaps
+ *  the port value if requested, and set MAC instance for devices that share
+ *  CS4227.
  **/
 void ixgbe_set_lan_id_multi_port_pcie(struct ixgbe_hw *hw)
 {
 	struct ixgbe_bus_info *bus = &hw->bus;
 	u32 reg;
+	u16 ee_ctrl_4;
+
+	DEBUGFUNC("ixgbe_set_lan_id_multi_port_pcie");
 
 	reg = IXGBE_READ_REG(hw, IXGBE_STATUS);
 	bus->func = (reg & IXGBE_STATUS_LAN_ID) >> IXGBE_STATUS_LAN_ID_SHIFT;
-	bus->lan_id = bus->func;
+	bus->lan_id = (u8)bus->func;
 
 	/* check for a port swap */
-	reg = IXGBE_READ_REG(hw, IXGBE_FACTPS(hw));
+	reg = IXGBE_READ_REG(hw, IXGBE_FACTPS_BY_MAC(hw));
 	if (reg & IXGBE_FACTPS_LFS)
 		bus->func ^= 0x1;
+
+	/* Get MAC instance from EEPROM for configuring CS4227 */
+	if (hw->device_id == IXGBE_DEV_ID_X550EM_A_SFP) {
+		hw->eeprom.ops.read(hw, IXGBE_EEPROM_CTRL_4, &ee_ctrl_4);
+		bus->instance_id = (ee_ctrl_4 & IXGBE_EE_CTRL_4_INST_ID) >>
+				   IXGBE_EE_CTRL_4_INST_ID_SHIFT;
+	}
 }
 
 /**
@@ -707,6 +876,8 @@ s32 ixgbe_stop_adapter_generic(struct ixgbe_hw *hw)
 	u32 reg_val;
 	u16 i;
 
+	DEBUGFUNC("ixgbe_stop_adapter_generic");
+
 	/*
 	 * Set the adapter_stopped flag so other driver functions stop touching
 	 * the hardware
@@ -714,7 +885,7 @@ s32 ixgbe_stop_adapter_generic(struct ixgbe_hw *hw)
 	hw->adapter_stopped = true;
 
 	/* Disable the receive unit */
-	hw->mac.ops.disable_rx(hw);
+	ixgbe_disable_rx(hw);
 
 	/* Clear interrupt mask to stop interrupts from being generated */
 	IXGBE_WRITE_REG(hw, IXGBE_EIMC, IXGBE_IRQ_CLEAR_MASK);
@@ -736,16 +907,57 @@ s32 ixgbe_stop_adapter_generic(struct ixgbe_hw *hw)
 
 	/* flush all queues disables */
 	IXGBE_WRITE_FLUSH(hw);
-	usleep_range(1000, 2000);
+	msec_delay(2);
 
 	/*
-	 * Prevent the PCI-E bus from from hanging by disabling PCI-E master
+	 * Prevent the PCI-E bus from hanging by disabling PCI-E master
 	 * access and verify no pending requests
 	 */
 	return ixgbe_disable_pcie_master(hw);
 }
 
 /**
+ *  ixgbe_init_led_link_act_generic - Store the LED index link/activity.
+ *  @hw: pointer to hardware structure
+ *
+ *  Store the index for the link active LED. This will be used to support
+ *  blinking the LED.
+ **/
+s32 ixgbe_init_led_link_act_generic(struct ixgbe_hw *hw)
+{
+	struct ixgbe_mac_info *mac = &hw->mac;
+	u32 led_reg, led_mode;
+	u8 i;
+
+	led_reg = IXGBE_READ_REG(hw, IXGBE_LEDCTL);
+
+	/* Get LED link active from the LEDCTL register */
+	for (i = 0; i < 4; i++) {
+		led_mode = led_reg >> IXGBE_LED_MODE_SHIFT(i);
+
+		if ((led_mode & IXGBE_LED_MODE_MASK_BASE) ==
+		     IXGBE_LED_LINK_ACTIVE) {
+			mac->led_link_act = i;
+			return IXGBE_SUCCESS;
+		}
+	}
+
+	/*
+	 * If LEDCTL register does not have the LED link active set, then use
+	 * known MAC defaults.
+	 */
+	switch (hw->mac.type) {
+	case ixgbe_mac_X550EM_a:
+	case ixgbe_mac_X550EM_x:
+		mac->led_link_act = 1;
+		break;
+	default:
+		mac->led_link_act = 2;
+	}
+	return IXGBE_SUCCESS;
+}
+
+/**
  *  ixgbe_led_on_generic - Turns on the software controllable LEDs.
  *  @hw: pointer to hardware structure
  *  @index: led number to turn on
@@ -754,13 +966,18 @@ s32 ixgbe_led_on_generic(struct ixgbe_hw *hw, u32 index)
 {
 	u32 led_reg = IXGBE_READ_REG(hw, IXGBE_LEDCTL);
 
+	DEBUGFUNC("ixgbe_led_on_generic");
+
+	if (index > 3)
+		return IXGBE_ERR_PARAM;
+
 	/* To turn on the LED, set mode to ON. */
 	led_reg &= ~IXGBE_LED_MODE_MASK(index);
 	led_reg |= IXGBE_LED_ON << IXGBE_LED_MODE_SHIFT(index);
 	IXGBE_WRITE_REG(hw, IXGBE_LEDCTL, led_reg);
 	IXGBE_WRITE_FLUSH(hw);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -772,13 +989,18 @@ s32 ixgbe_led_off_generic(struct ixgbe_hw *hw, u32 index)
 {
 	u32 led_reg = IXGBE_READ_REG(hw, IXGBE_LEDCTL);
 
+	DEBUGFUNC("ixgbe_led_off_generic");
+
+	if (index > 3)
+		return IXGBE_ERR_PARAM;
+
 	/* To turn off the LED, set mode to OFF. */
 	led_reg &= ~IXGBE_LED_MODE_MASK(index);
 	led_reg |= IXGBE_LED_OFF << IXGBE_LED_MODE_SHIFT(index);
 	IXGBE_WRITE_REG(hw, IXGBE_LEDCTL, led_reg);
 	IXGBE_WRITE_FLUSH(hw);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -794,6 +1016,8 @@ s32 ixgbe_init_eeprom_params_generic(struct ixgbe_hw *hw)
 	u32 eec;
 	u16 eeprom_size;
 
+	DEBUGFUNC("ixgbe_init_eeprom_params_generic");
+
 	if (eeprom->type == ixgbe_eeprom_uninitialized) {
 		eeprom->type = ixgbe_eeprom_none;
 		/* Set default semaphore delay to 10ms which is a well
@@ -806,7 +1030,7 @@ s32 ixgbe_init_eeprom_params_generic(struct ixgbe_hw *hw)
 		 * Check for EEPROM present first.
 		 * If not present leave as none
 		 */
-		eec = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
+		eec = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
 		if (eec & IXGBE_EEC_PRES) {
 			eeprom->type = ixgbe_eeprom_spi;
 
@@ -817,25 +1041,26 @@ s32 ixgbe_init_eeprom_params_generic(struct ixgbe_hw *hw)
 			eeprom_size = (u16)((eec & IXGBE_EEC_SIZE) >>
 					    IXGBE_EEC_SIZE_SHIFT);
 			eeprom->word_size = 1 << (eeprom_size +
-						  IXGBE_EEPROM_WORD_SIZE_SHIFT);
+					     IXGBE_EEPROM_WORD_SIZE_SHIFT);
 		}
 
 		if (eec & IXGBE_EEC_ADDR_SIZE)
 			eeprom->address_bits = 16;
 		else
 			eeprom->address_bits = 8;
-		hw_dbg(hw, "Eeprom params: type = %d, size = %d, address bits: %d\n",
-		       eeprom->type, eeprom->word_size, eeprom->address_bits);
+		DEBUGOUT3("Eeprom params: type = %d, size = %d, address bits: "
+			  "%d\n", eeprom->type, eeprom->word_size,
+			  eeprom->address_bits);
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
  *  ixgbe_write_eeprom_buffer_bit_bang_generic - Write EEPROM using bit-bang
  *  @hw: pointer to hardware structure
  *  @offset: offset within the EEPROM to write
- *  @words: number of words
+ *  @words: number of word(s)
  *  @data: 16 bit word(s) to write to EEPROM
  *
  *  Reads 16 bit word(s) from EEPROM through bit-bang method
@@ -843,16 +1068,22 @@ s32 ixgbe_init_eeprom_params_generic(struct ixgbe_hw *hw)
 s32 ixgbe_write_eeprom_buffer_bit_bang_generic(struct ixgbe_hw *hw, u16 offset,
 					       u16 words, u16 *data)
 {
-	s32 status;
+	s32 status = IXGBE_SUCCESS;
 	u16 i, count;
 
+	DEBUGFUNC("ixgbe_write_eeprom_buffer_bit_bang_generic");
+
 	hw->eeprom.ops.init_params(hw);
 
-	if (words == 0)
-		return IXGBE_ERR_INVALID_ARGUMENT;
+	if (words == 0) {
+		status = IXGBE_ERR_INVALID_ARGUMENT;
+		goto out;
+	}
 
-	if (offset + words > hw->eeprom.word_size)
-		return IXGBE_ERR_EEPROM;
+	if (offset + words > hw->eeprom.word_size) {
+		status = IXGBE_ERR_EEPROM;
+		goto out;
+	}
 
 	/*
 	 * The EEPROM page size cannot be queried from the chip. We do lazy
@@ -869,14 +1100,15 @@ s32 ixgbe_write_eeprom_buffer_bit_bang_generic(struct ixgbe_hw *hw, u16 offset,
 	 */
 	for (i = 0; i < words; i += IXGBE_EEPROM_RD_BUFFER_MAX_COUNT) {
 		count = (words - i) / IXGBE_EEPROM_RD_BUFFER_MAX_COUNT > 0 ?
-			 IXGBE_EEPROM_RD_BUFFER_MAX_COUNT : (words - i);
+			IXGBE_EEPROM_RD_BUFFER_MAX_COUNT : (words - i);
 		status = ixgbe_write_eeprom_buffer_bit_bang(hw, offset + i,
 							    count, &data[i]);
 
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			break;
 	}
 
+out:
 	return status;
 }
 
@@ -890,7 +1122,7 @@ s32 ixgbe_write_eeprom_buffer_bit_bang_generic(struct ixgbe_hw *hw, u16 offset,
  *  If ixgbe_eeprom_update_checksum is not called after this function, the
  *  EEPROM will most likely contain an invalid checksum.
  **/
-static s32 ixgbe_write_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
+STATIC s32 ixgbe_write_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
 					      u16 words, u16 *data)
 {
 	s32 status;
@@ -899,63 +1131,68 @@ static s32 ixgbe_write_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
 	u16 i;
 	u8 write_opcode = IXGBE_EEPROM_WRITE_OPCODE_SPI;
 
+	DEBUGFUNC("ixgbe_write_eeprom_buffer_bit_bang");
+
 	/* Prepare the EEPROM for writing  */
 	status = ixgbe_acquire_eeprom(hw);
-	if (status)
-		return status;
 
-	if (ixgbe_ready_eeprom(hw) != 0) {
-		ixgbe_release_eeprom(hw);
-		return IXGBE_ERR_EEPROM;
+	if (status == IXGBE_SUCCESS) {
+		if (ixgbe_ready_eeprom(hw) != IXGBE_SUCCESS) {
+			ixgbe_release_eeprom(hw);
+			status = IXGBE_ERR_EEPROM;
+		}
 	}
 
-	for (i = 0; i < words; i++) {
-		ixgbe_standby_eeprom(hw);
-
-		/* Send the WRITE ENABLE command (8 bit opcode) */
-		ixgbe_shift_out_eeprom_bits(hw,
-					    IXGBE_EEPROM_WREN_OPCODE_SPI,
-					    IXGBE_EEPROM_OPCODE_BITS);
-
-		ixgbe_standby_eeprom(hw);
-
-		/* Some SPI eeproms use the 8th address bit embedded
-		 * in the opcode
-		 */
-		if ((hw->eeprom.address_bits == 8) &&
-		    ((offset + i) >= 128))
-			write_opcode |= IXGBE_EEPROM_A8_OPCODE_SPI;
-
-		/* Send the Write command (8-bit opcode + addr) */
-		ixgbe_shift_out_eeprom_bits(hw, write_opcode,
-					    IXGBE_EEPROM_OPCODE_BITS);
-		ixgbe_shift_out_eeprom_bits(hw, (u16)((offset + i) * 2),
-					    hw->eeprom.address_bits);
-
-		page_size = hw->eeprom.word_page_size;
-
-		/* Send the data in burst via SPI */
-		do {
-			word = data[i];
-			word = (word >> 8) | (word << 8);
-			ixgbe_shift_out_eeprom_bits(hw, word, 16);
+	if (status == IXGBE_SUCCESS) {
+		for (i = 0; i < words; i++) {
+			ixgbe_standby_eeprom(hw);
 
-			if (page_size == 0)
-				break;
+			/*  Send the WRITE ENABLE command (8 bit opcode )  */
+			ixgbe_shift_out_eeprom_bits(hw,
+						   IXGBE_EEPROM_WREN_OPCODE_SPI,
+						   IXGBE_EEPROM_OPCODE_BITS);
 
-			/* do not wrap around page */
-			if (((offset + i) & (page_size - 1)) ==
-			    (page_size - 1))
-				break;
-		} while (++i < words);
+			ixgbe_standby_eeprom(hw);
 
-		ixgbe_standby_eeprom(hw);
-		usleep_range(10000, 20000);
+			/*
+			 * Some SPI eeproms use the 8th address bit embedded
+			 * in the opcode
+			 */
+			if ((hw->eeprom.address_bits == 8) &&
+			    ((offset + i) >= 128))
+				write_opcode |= IXGBE_EEPROM_A8_OPCODE_SPI;
+
+			/* Send the Write command (8-bit opcode + addr) */
+			ixgbe_shift_out_eeprom_bits(hw, write_opcode,
+						    IXGBE_EEPROM_OPCODE_BITS);
+			ixgbe_shift_out_eeprom_bits(hw, (u16)((offset + i) * 2),
+						    hw->eeprom.address_bits);
+
+			page_size = hw->eeprom.word_page_size;
+
+			/* Send the data in burst via SPI*/
+			do {
+				word = data[i];
+				word = (word >> 8) | (word << 8);
+				ixgbe_shift_out_eeprom_bits(hw, word, 16);
+
+				if (page_size == 0)
+					break;
+
+				/* do not wrap around page */
+				if (((offset + i) & (page_size - 1)) ==
+				    (page_size - 1))
+					break;
+			} while (++i < words);
+
+			ixgbe_standby_eeprom(hw);
+			msec_delay(10);
+		}
+		/* Done with writing - release the EEPROM */
+		ixgbe_release_eeprom(hw);
 	}
-	/* Done with writing - release the EEPROM */
-	ixgbe_release_eeprom(hw);
 
-	return 0;
+	return status;
 }
 
 /**
@@ -969,36 +1206,51 @@ static s32 ixgbe_write_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
  **/
 s32 ixgbe_write_eeprom_generic(struct ixgbe_hw *hw, u16 offset, u16 data)
 {
+	s32 status;
+
+	DEBUGFUNC("ixgbe_write_eeprom_generic");
+
 	hw->eeprom.ops.init_params(hw);
 
-	if (offset >= hw->eeprom.word_size)
-		return IXGBE_ERR_EEPROM;
+	if (offset >= hw->eeprom.word_size) {
+		status = IXGBE_ERR_EEPROM;
+		goto out;
+	}
+
+	status = ixgbe_write_eeprom_buffer_bit_bang(hw, offset, 1, &data);
 
-	return ixgbe_write_eeprom_buffer_bit_bang(hw, offset, 1, &data);
+out:
+	return status;
 }
 
 /**
  *  ixgbe_read_eeprom_buffer_bit_bang_generic - Read EEPROM using bit-bang
  *  @hw: pointer to hardware structure
  *  @offset: offset within the EEPROM to be read
- *  @words: number of word(s)
  *  @data: read 16 bit words(s) from EEPROM
+ *  @words: number of word(s)
  *
  *  Reads 16 bit word(s) from EEPROM through bit-bang method
  **/
 s32 ixgbe_read_eeprom_buffer_bit_bang_generic(struct ixgbe_hw *hw, u16 offset,
 					      u16 words, u16 *data)
 {
-	s32 status;
+	s32 status = IXGBE_SUCCESS;
 	u16 i, count;
 
+	DEBUGFUNC("ixgbe_read_eeprom_buffer_bit_bang_generic");
+
 	hw->eeprom.ops.init_params(hw);
 
-	if (words == 0)
-		return IXGBE_ERR_INVALID_ARGUMENT;
+	if (words == 0) {
+		status = IXGBE_ERR_INVALID_ARGUMENT;
+		goto out;
+	}
 
-	if (offset + words > hw->eeprom.word_size)
-		return IXGBE_ERR_EEPROM;
+	if (offset + words > hw->eeprom.word_size) {
+		status = IXGBE_ERR_EEPROM;
+		goto out;
+	}
 
 	/*
 	 * We cannot hold synchronization semaphores for too long
@@ -1007,16 +1259,17 @@ s32 ixgbe_read_eeprom_buffer_bit_bang_generic(struct ixgbe_hw *hw, u16 offset,
 	 */
 	for (i = 0; i < words; i += IXGBE_EEPROM_RD_BUFFER_MAX_COUNT) {
 		count = (words - i) / IXGBE_EEPROM_RD_BUFFER_MAX_COUNT > 0 ?
-			 IXGBE_EEPROM_RD_BUFFER_MAX_COUNT : (words - i);
+			IXGBE_EEPROM_RD_BUFFER_MAX_COUNT : (words - i);
 
 		status = ixgbe_read_eeprom_buffer_bit_bang(hw, offset + i,
 							   count, &data[i]);
 
-		if (status)
-			return status;
+		if (status != IXGBE_SUCCESS)
+			break;
 	}
 
-	return 0;
+out:
+	return status;
 }
 
 /**
@@ -1028,7 +1281,7 @@ s32 ixgbe_read_eeprom_buffer_bit_bang_generic(struct ixgbe_hw *hw, u16 offset,
  *
  *  Reads 16 bit word(s) from EEPROM through bit-bang method
  **/
-static s32 ixgbe_read_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
+STATIC s32 ixgbe_read_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
 					     u16 words, u16 *data)
 {
 	s32 status;
@@ -1036,40 +1289,45 @@ static s32 ixgbe_read_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
 	u8 read_opcode = IXGBE_EEPROM_READ_OPCODE_SPI;
 	u16 i;
 
+	DEBUGFUNC("ixgbe_read_eeprom_buffer_bit_bang");
+
 	/* Prepare the EEPROM for reading  */
 	status = ixgbe_acquire_eeprom(hw);
-	if (status)
-		return status;
 
-	if (ixgbe_ready_eeprom(hw) != 0) {
-		ixgbe_release_eeprom(hw);
-		return IXGBE_ERR_EEPROM;
+	if (status == IXGBE_SUCCESS) {
+		if (ixgbe_ready_eeprom(hw) != IXGBE_SUCCESS) {
+			ixgbe_release_eeprom(hw);
+			status = IXGBE_ERR_EEPROM;
+		}
 	}
 
-	for (i = 0; i < words; i++) {
-		ixgbe_standby_eeprom(hw);
-		/* Some SPI eeproms use the 8th address bit embedded
-		 * in the opcode
-		 */
-		if ((hw->eeprom.address_bits == 8) &&
-		    ((offset + i) >= 128))
-			read_opcode |= IXGBE_EEPROM_A8_OPCODE_SPI;
-
-		/* Send the READ command (opcode + addr) */
-		ixgbe_shift_out_eeprom_bits(hw, read_opcode,
-					    IXGBE_EEPROM_OPCODE_BITS);
-		ixgbe_shift_out_eeprom_bits(hw, (u16)((offset + i) * 2),
-					    hw->eeprom.address_bits);
+	if (status == IXGBE_SUCCESS) {
+		for (i = 0; i < words; i++) {
+			ixgbe_standby_eeprom(hw);
+			/*
+			 * Some SPI eeproms use the 8th address bit embedded
+			 * in the opcode
+			 */
+			if ((hw->eeprom.address_bits == 8) &&
+			    ((offset + i) >= 128))
+				read_opcode |= IXGBE_EEPROM_A8_OPCODE_SPI;
+
+			/* Send the READ command (opcode + addr) */
+			ixgbe_shift_out_eeprom_bits(hw, read_opcode,
+						    IXGBE_EEPROM_OPCODE_BITS);
+			ixgbe_shift_out_eeprom_bits(hw, (u16)((offset + i) * 2),
+						    hw->eeprom.address_bits);
+
+			/* Read the data. */
+			word_in = ixgbe_shift_in_eeprom_bits(hw, 16);
+			data[i] = (word_in >> 8) | (word_in << 8);
+		}
 
-		/* Read the data. */
-		word_in = ixgbe_shift_in_eeprom_bits(hw, 16);
-		data[i] = (word_in >> 8) | (word_in << 8);
+		/* End this read operation */
+		ixgbe_release_eeprom(hw);
 	}
 
-	/* End this read operation */
-	ixgbe_release_eeprom(hw);
-
-	return 0;
+	return status;
 }
 
 /**
@@ -1083,12 +1341,21 @@ static s32 ixgbe_read_eeprom_buffer_bit_bang(struct ixgbe_hw *hw, u16 offset,
 s32 ixgbe_read_eeprom_bit_bang_generic(struct ixgbe_hw *hw, u16 offset,
 				       u16 *data)
 {
+	s32 status;
+
+	DEBUGFUNC("ixgbe_read_eeprom_bit_bang_generic");
+
 	hw->eeprom.ops.init_params(hw);
 
-	if (offset >= hw->eeprom.word_size)
-		return IXGBE_ERR_EEPROM;
+	if (offset >= hw->eeprom.word_size) {
+		status = IXGBE_ERR_EEPROM;
+		goto out;
+	}
+
+	status = ixgbe_read_eeprom_buffer_bit_bang(hw, offset, 1, data);
 
-	return ixgbe_read_eeprom_buffer_bit_bang(hw, offset, 1, data);
+out:
+	return status;
 }
 
 /**
@@ -1104,16 +1371,24 @@ s32 ixgbe_read_eerd_buffer_generic(struct ixgbe_hw *hw, u16 offset,
 				   u16 words, u16 *data)
 {
 	u32 eerd;
-	s32 status;
+	s32 status = IXGBE_SUCCESS;
 	u32 i;
 
+	DEBUGFUNC("ixgbe_read_eerd_buffer_generic");
+
 	hw->eeprom.ops.init_params(hw);
 
-	if (words == 0)
-		return IXGBE_ERR_INVALID_ARGUMENT;
+	if (words == 0) {
+		status = IXGBE_ERR_INVALID_ARGUMENT;
+		ERROR_REPORT1(IXGBE_ERROR_ARGUMENT, "Invalid EEPROM words");
+		goto out;
+	}
 
-	if (offset >= hw->eeprom.word_size)
-		return IXGBE_ERR_EEPROM;
+	if (offset >= hw->eeprom.word_size) {
+		status = IXGBE_ERR_EEPROM;
+		ERROR_REPORT1(IXGBE_ERROR_ARGUMENT, "Invalid EEPROM offset");
+		goto out;
+	}
 
 	for (i = 0; i < words; i++) {
 		eerd = ((offset + i) << IXGBE_EEPROM_RW_ADDR_SHIFT) |
@@ -1122,16 +1397,16 @@ s32 ixgbe_read_eerd_buffer_generic(struct ixgbe_hw *hw, u16 offset,
 		IXGBE_WRITE_REG(hw, IXGBE_EERD, eerd);
 		status = ixgbe_poll_eerd_eewr_done(hw, IXGBE_NVM_POLL_READ);
 
-		if (status == 0) {
+		if (status == IXGBE_SUCCESS) {
 			data[i] = (IXGBE_READ_REG(hw, IXGBE_EERD) >>
 				   IXGBE_EEPROM_RW_REG_DATA);
 		} else {
-			hw_dbg(hw, "Eeprom read timed out\n");
-			return status;
+			DEBUGOUT("Eeprom read timed out\n");
+			goto out;
 		}
 	}
-
-	return 0;
+out:
+	return status;
 }
 
 /**
@@ -1143,13 +1418,15 @@ s32 ixgbe_read_eerd_buffer_generic(struct ixgbe_hw *hw, u16 offset,
  *  This function is called only when we are writing a new large buffer
  *  at given offset so the data would be overwritten anyway.
  **/
-static s32 ixgbe_detect_eeprom_page_size_generic(struct ixgbe_hw *hw,
+STATIC s32 ixgbe_detect_eeprom_page_size_generic(struct ixgbe_hw *hw,
 						 u16 offset)
 {
 	u16 data[IXGBE_EEPROM_PAGE_SIZE_MAX];
-	s32 status;
+	s32 status = IXGBE_SUCCESS;
 	u16 i;
 
+	DEBUGFUNC("ixgbe_detect_eeprom_page_size_generic");
+
 	for (i = 0; i < IXGBE_EEPROM_PAGE_SIZE_MAX; i++)
 		data[i] = i;
 
@@ -1157,12 +1434,12 @@ static s32 ixgbe_detect_eeprom_page_size_generic(struct ixgbe_hw *hw,
 	status = ixgbe_write_eeprom_buffer_bit_bang(hw, offset,
 					     IXGBE_EEPROM_PAGE_SIZE_MAX, data);
 	hw->eeprom.word_page_size = 0;
-	if (status)
-		return status;
+	if (status != IXGBE_SUCCESS)
+		goto out;
 
 	status = ixgbe_read_eeprom_buffer_bit_bang(hw, offset, 1, data);
-	if (status)
-		return status;
+	if (status != IXGBE_SUCCESS)
+		goto out;
 
 	/*
 	 * When writing in burst more than the actual page size
@@ -1170,9 +1447,10 @@ static s32 ixgbe_detect_eeprom_page_size_generic(struct ixgbe_hw *hw,
 	 */
 	hw->eeprom.word_page_size = IXGBE_EEPROM_PAGE_SIZE_MAX - data[0];
 
-	hw_dbg(hw, "Detected EEPROM page size = %d words.\n",
-	       hw->eeprom.word_page_size);
-	return 0;
+	DEBUGOUT1("Detected EEPROM page size = %d words.",
+		  hw->eeprom.word_page_size);
+out:
+	return status;
 }
 
 /**
@@ -1192,7 +1470,7 @@ s32 ixgbe_read_eerd_generic(struct ixgbe_hw *hw, u16 offset, u16 *data)
  *  ixgbe_write_eewr_buffer_generic - Write EEPROM word(s) using EEWR
  *  @hw: pointer to hardware structure
  *  @offset: offset of  word in the EEPROM to write
- *  @words: number of words
+ *  @words: number of word(s)
  *  @data: word(s) write to the EEPROM
  *
  *  Write a 16 bit word(s) to the EEPROM using the EEWR register.
@@ -1201,38 +1479,47 @@ s32 ixgbe_write_eewr_buffer_generic(struct ixgbe_hw *hw, u16 offset,
 				    u16 words, u16 *data)
 {
 	u32 eewr;
-	s32 status;
+	s32 status = IXGBE_SUCCESS;
 	u16 i;
 
+	DEBUGFUNC("ixgbe_write_eewr_generic");
+
 	hw->eeprom.ops.init_params(hw);
 
-	if (words == 0)
-		return IXGBE_ERR_INVALID_ARGUMENT;
+	if (words == 0) {
+		status = IXGBE_ERR_INVALID_ARGUMENT;
+		ERROR_REPORT1(IXGBE_ERROR_ARGUMENT, "Invalid EEPROM words");
+		goto out;
+	}
 
-	if (offset >= hw->eeprom.word_size)
-		return IXGBE_ERR_EEPROM;
+	if (offset >= hw->eeprom.word_size) {
+		status = IXGBE_ERR_EEPROM;
+		ERROR_REPORT1(IXGBE_ERROR_ARGUMENT, "Invalid EEPROM offset");
+		goto out;
+	}
 
 	for (i = 0; i < words; i++) {
 		eewr = ((offset + i) << IXGBE_EEPROM_RW_ADDR_SHIFT) |
-		       (data[i] << IXGBE_EEPROM_RW_REG_DATA) |
-		       IXGBE_EEPROM_RW_REG_START;
+			(data[i] << IXGBE_EEPROM_RW_REG_DATA) |
+			IXGBE_EEPROM_RW_REG_START;
 
 		status = ixgbe_poll_eerd_eewr_done(hw, IXGBE_NVM_POLL_WRITE);
-		if (status) {
-			hw_dbg(hw, "Eeprom write EEWR timed out\n");
-			return status;
+		if (status != IXGBE_SUCCESS) {
+			DEBUGOUT("Eeprom write EEWR timed out\n");
+			goto out;
 		}
 
 		IXGBE_WRITE_REG(hw, IXGBE_EEWR, eewr);
 
 		status = ixgbe_poll_eerd_eewr_done(hw, IXGBE_NVM_POLL_WRITE);
-		if (status) {
-			hw_dbg(hw, "Eeprom write EEWR timed out\n");
-			return status;
+		if (status != IXGBE_SUCCESS) {
+			DEBUGOUT("Eeprom write EEWR timed out\n");
+			goto out;
 		}
 	}
 
-	return 0;
+out:
+	return status;
 }
 
 /**
@@ -1256,10 +1543,13 @@ s32 ixgbe_write_eewr_generic(struct ixgbe_hw *hw, u16 offset, u16 data)
  *  Polls the status bit (bit 1) of the EERD or EEWR to determine when the
  *  read or write is done respectively.
  **/
-static s32 ixgbe_poll_eerd_eewr_done(struct ixgbe_hw *hw, u32 ee_reg)
+s32 ixgbe_poll_eerd_eewr_done(struct ixgbe_hw *hw, u32 ee_reg)
 {
 	u32 i;
 	u32 reg;
+	s32 status = IXGBE_ERR_EEPROM;
+
+	DEBUGFUNC("ixgbe_poll_eerd_eewr_done");
 
 	for (i = 0; i < IXGBE_EERD_EEWR_ATTEMPTS; i++) {
 		if (ee_reg == IXGBE_NVM_POLL_READ)
@@ -1268,11 +1558,17 @@ static s32 ixgbe_poll_eerd_eewr_done(struct ixgbe_hw *hw, u32 ee_reg)
 			reg = IXGBE_READ_REG(hw, IXGBE_EEWR);
 
 		if (reg & IXGBE_EEPROM_RW_REG_DONE) {
-			return 0;
+			status = IXGBE_SUCCESS;
+			break;
 		}
-		udelay(5);
+		usec_delay(5);
 	}
-	return IXGBE_ERR_EEPROM;
+
+	if (i == IXGBE_EERD_EEWR_ATTEMPTS)
+		ERROR_REPORT1(IXGBE_ERROR_POLLING,
+			     "EEPROM read/write done polling timed out");
+
+	return status;
 }
 
 /**
@@ -1282,44 +1578,52 @@ static s32 ixgbe_poll_eerd_eewr_done(struct ixgbe_hw *hw, u32 ee_reg)
  *  Prepares EEPROM for access using bit-bang method. This function should
  *  be called before issuing a command to the EEPROM.
  **/
-static s32 ixgbe_acquire_eeprom(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_acquire_eeprom(struct ixgbe_hw *hw)
 {
+	s32 status = IXGBE_SUCCESS;
 	u32 eec;
 	u32 i;
 
-	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM) != 0)
-		return IXGBE_ERR_SWFW_SYNC;
+	DEBUGFUNC("ixgbe_acquire_eeprom");
 
-	eec = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
+	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM)
+	    != IXGBE_SUCCESS)
+		status = IXGBE_ERR_SWFW_SYNC;
 
-	/* Request EEPROM Access */
-	eec |= IXGBE_EEC_REQ;
-	IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), eec);
+	if (status == IXGBE_SUCCESS) {
+		eec = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
 
-	for (i = 0; i < IXGBE_EEPROM_GRANT_ATTEMPTS; i++) {
-		eec = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
-		if (eec & IXGBE_EEC_GNT)
-			break;
-		udelay(5);
-	}
+		/* Request EEPROM Access */
+		eec |= IXGBE_EEC_REQ;
+		IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), eec);
 
-	/* Release if grant not acquired */
-	if (!(eec & IXGBE_EEC_GNT)) {
-		eec &= ~IXGBE_EEC_REQ;
-		IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), eec);
-		hw_dbg(hw, "Could not acquire EEPROM grant\n");
+		for (i = 0; i < IXGBE_EEPROM_GRANT_ATTEMPTS; i++) {
+			eec = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
+			if (eec & IXGBE_EEC_GNT)
+				break;
+			usec_delay(5);
+		}
 
-		hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
-		return IXGBE_ERR_EEPROM;
-	}
+		/* Release if grant not acquired */
+		if (!(eec & IXGBE_EEC_GNT)) {
+			eec &= ~IXGBE_EEC_REQ;
+			IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), eec);
+			DEBUGOUT("Could not acquire EEPROM grant\n");
 
-	/* Setup EEPROM for Read/Write */
-	/* Clear CS and SK */
-	eec &= ~(IXGBE_EEC_CS | IXGBE_EEC_SK);
-	IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), eec);
-	IXGBE_WRITE_FLUSH(hw);
-	udelay(1);
-	return 0;
+			hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
+			status = IXGBE_ERR_EEPROM;
+		}
+
+		/* Setup EEPROM for Read/Write */
+		if (status == IXGBE_SUCCESS) {
+			/* Clear CS and SK */
+			eec &= ~(IXGBE_EEC_CS | IXGBE_EEC_SK);
+			IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), eec);
+			IXGBE_WRITE_FLUSH(hw);
+			usec_delay(1);
+		}
+	}
+	return status;
 }
 
 /**
@@ -1328,73 +1632,88 @@ static s32 ixgbe_acquire_eeprom(struct ixgbe_hw *hw)
  *
  *  Sets the hardware semaphores so EEPROM access can occur for bit-bang method
  **/
-static s32 ixgbe_get_eeprom_semaphore(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_get_eeprom_semaphore(struct ixgbe_hw *hw)
 {
+	s32 status = IXGBE_ERR_EEPROM;
 	u32 timeout = 2000;
 	u32 i;
 	u32 swsm;
 
+	DEBUGFUNC("ixgbe_get_eeprom_semaphore");
+
 	/* Get SMBI software semaphore between device drivers first */
 	for (i = 0; i < timeout; i++) {
 		/*
 		 * If the SMBI bit is 0 when we read it, then the bit will be
 		 * set and we have the semaphore
 		 */
-		swsm = IXGBE_READ_REG(hw, IXGBE_SWSM(hw));
-		if (!(swsm & IXGBE_SWSM_SMBI))
+		swsm = IXGBE_READ_REG(hw, IXGBE_SWSM_BY_MAC(hw));
+		if (!(swsm & IXGBE_SWSM_SMBI)) {
+			status = IXGBE_SUCCESS;
 			break;
-		usleep_range(50, 100);
+		}
+		usec_delay(50);
 	}
 
 	if (i == timeout) {
-		hw_dbg(hw, "Driver can't access the Eeprom - SMBI Semaphore not granted.\n");
-		/* this release is particularly important because our attempts
+		DEBUGOUT("Driver can't access the Eeprom - SMBI Semaphore "
+			 "not granted.\n");
+		/*
+		 * this release is particularly important because our attempts
 		 * above to get the semaphore may have succeeded, and if there
 		 * was a timeout, we should unconditionally clear the semaphore
 		 * bits to free the driver to make progress
 		 */
 		ixgbe_release_eeprom_semaphore(hw);
 
-		usleep_range(50, 100);
-		/* one last try
+		usec_delay(50);
+		/*
+		 * one last try
 		 * If the SMBI bit is 0 when we read it, then the bit will be
 		 * set and we have the semaphore
 		 */
-		swsm = IXGBE_READ_REG(hw, IXGBE_SWSM(hw));
-		if (swsm & IXGBE_SWSM_SMBI) {
-			hw_dbg(hw, "Software semaphore SMBI between device drivers not granted.\n");
-			return IXGBE_ERR_EEPROM;
-		}
+		swsm = IXGBE_READ_REG(hw, IXGBE_SWSM_BY_MAC(hw));
+		if (!(swsm & IXGBE_SWSM_SMBI))
+			status = IXGBE_SUCCESS;
 	}
 
 	/* Now get the semaphore between SW/FW through the SWESMBI bit */
-	for (i = 0; i < timeout; i++) {
-		swsm = IXGBE_READ_REG(hw, IXGBE_SWSM(hw));
+	if (status == IXGBE_SUCCESS) {
+		for (i = 0; i < timeout; i++) {
+			swsm = IXGBE_READ_REG(hw, IXGBE_SWSM_BY_MAC(hw));
 
-		/* Set the SW EEPROM semaphore bit to request access */
-		swsm |= IXGBE_SWSM_SWESMBI;
-		IXGBE_WRITE_REG(hw, IXGBE_SWSM(hw), swsm);
+			/* Set the SW EEPROM semaphore bit to request access */
+			swsm |= IXGBE_SWSM_SWESMBI;
+			IXGBE_WRITE_REG(hw, IXGBE_SWSM_BY_MAC(hw), swsm);
 
-		/* If we set the bit successfully then we got the
-		 * semaphore.
-		 */
-		swsm = IXGBE_READ_REG(hw, IXGBE_SWSM(hw));
-		if (swsm & IXGBE_SWSM_SWESMBI)
-			break;
+			/*
+			 * If we set the bit successfully then we got the
+			 * semaphore.
+			 */
+			swsm = IXGBE_READ_REG(hw, IXGBE_SWSM_BY_MAC(hw));
+			if (swsm & IXGBE_SWSM_SWESMBI)
+				break;
 
-		usleep_range(50, 100);
-	}
+			usec_delay(50);
+		}
 
-	/* Release semaphores and return error if SW EEPROM semaphore
-	 * was not granted because we don't have access to the EEPROM
-	 */
-	if (i >= timeout) {
-		hw_dbg(hw, "SWESMBI Software EEPROM semaphore not granted.\n");
-		ixgbe_release_eeprom_semaphore(hw);
-		return IXGBE_ERR_EEPROM;
+		/*
+		 * Release semaphores and return error if SW EEPROM semaphore
+		 * was not granted because we don't have access to the EEPROM
+		 */
+		if (i >= timeout) {
+			ERROR_REPORT1(IXGBE_ERROR_POLLING,
+			    "SWESMBI Software EEPROM semaphore not granted.\n");
+			ixgbe_release_eeprom_semaphore(hw);
+			status = IXGBE_ERR_EEPROM;
+		}
+	} else {
+		ERROR_REPORT1(IXGBE_ERROR_POLLING,
+			     "Software semaphore SMBI between device drivers "
+			     "not granted.\n");
 	}
 
-	return 0;
+	return status;
 }
 
 /**
@@ -1403,15 +1722,17 @@ static s32 ixgbe_get_eeprom_semaphore(struct ixgbe_hw *hw)
  *
  *  This function clears hardware semaphore bits.
  **/
-static void ixgbe_release_eeprom_semaphore(struct ixgbe_hw *hw)
+STATIC void ixgbe_release_eeprom_semaphore(struct ixgbe_hw *hw)
 {
 	u32 swsm;
 
-	swsm = IXGBE_READ_REG(hw, IXGBE_SWSM(hw));
+	DEBUGFUNC("ixgbe_release_eeprom_semaphore");
+
+	swsm = IXGBE_READ_REG(hw, IXGBE_SWSM);
 
 	/* Release both semaphores by writing 0 to the bits SWESMBI and SMBI */
 	swsm &= ~(IXGBE_SWSM_SWESMBI | IXGBE_SWSM_SMBI);
-	IXGBE_WRITE_REG(hw, IXGBE_SWSM(hw), swsm);
+	IXGBE_WRITE_REG(hw, IXGBE_SWSM, swsm);
 	IXGBE_WRITE_FLUSH(hw);
 }
 
@@ -1419,11 +1740,14 @@ static void ixgbe_release_eeprom_semaphore(struct ixgbe_hw *hw)
  *  ixgbe_ready_eeprom - Polls for EEPROM ready
  *  @hw: pointer to hardware structure
  **/
-static s32 ixgbe_ready_eeprom(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_ready_eeprom(struct ixgbe_hw *hw)
 {
+	s32 status = IXGBE_SUCCESS;
 	u16 i;
 	u8 spi_stat_reg;
 
+	DEBUGFUNC("ixgbe_ready_eeprom");
+
 	/*
 	 * Read "Status Register" repeatedly until the LSB is cleared.  The
 	 * EEPROM will signal that the command has been completed by clearing
@@ -1437,41 +1761,43 @@ static s32 ixgbe_ready_eeprom(struct ixgbe_hw *hw)
 		if (!(spi_stat_reg & IXGBE_EEPROM_STATUS_RDY_SPI))
 			break;
 
-		udelay(5);
+		usec_delay(5);
 		ixgbe_standby_eeprom(hw);
-	}
+	};
 
 	/*
 	 * On some parts, SPI write time could vary from 0-20mSec on 3.3V
 	 * devices (and only 0-5mSec on 5V devices)
 	 */
 	if (i >= IXGBE_EEPROM_MAX_RETRY_SPI) {
-		hw_dbg(hw, "SPI EEPROM Status error\n");
-		return IXGBE_ERR_EEPROM;
+		DEBUGOUT("SPI EEPROM Status error\n");
+		status = IXGBE_ERR_EEPROM;
 	}
 
-	return 0;
+	return status;
 }
 
 /**
  *  ixgbe_standby_eeprom - Returns EEPROM to a "standby" state
  *  @hw: pointer to hardware structure
  **/
-static void ixgbe_standby_eeprom(struct ixgbe_hw *hw)
+STATIC void ixgbe_standby_eeprom(struct ixgbe_hw *hw)
 {
 	u32 eec;
 
-	eec = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
+	DEBUGFUNC("ixgbe_standby_eeprom");
+
+	eec = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
 
 	/* Toggle CS to flush commands */
 	eec |= IXGBE_EEC_CS;
-	IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), eec);
+	IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), eec);
 	IXGBE_WRITE_FLUSH(hw);
-	udelay(1);
+	usec_delay(1);
 	eec &= ~IXGBE_EEC_CS;
-	IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), eec);
+	IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), eec);
 	IXGBE_WRITE_FLUSH(hw);
-	udelay(1);
+	usec_delay(1);
 }
 
 /**
@@ -1480,14 +1806,16 @@ static void ixgbe_standby_eeprom(struct ixgbe_hw *hw)
  *  @data: data to send to the EEPROM
  *  @count: number of bits to shift out
  **/
-static void ixgbe_shift_out_eeprom_bits(struct ixgbe_hw *hw, u16 data,
+STATIC void ixgbe_shift_out_eeprom_bits(struct ixgbe_hw *hw, u16 data,
 					u16 count)
 {
 	u32 eec;
 	u32 mask;
 	u32 i;
 
-	eec = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
+	DEBUGFUNC("ixgbe_shift_out_eeprom_bits");
+
+	eec = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
 
 	/*
 	 * Mask is used to shift "count" bits of "data" out to the EEPROM
@@ -1508,10 +1836,10 @@ static void ixgbe_shift_out_eeprom_bits(struct ixgbe_hw *hw, u16 data,
 		else
 			eec &= ~IXGBE_EEC_DI;
 
-		IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), eec);
+		IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), eec);
 		IXGBE_WRITE_FLUSH(hw);
 
-		udelay(1);
+		usec_delay(1);
 
 		ixgbe_raise_eeprom_clk(hw, &eec);
 		ixgbe_lower_eeprom_clk(hw, &eec);
@@ -1521,11 +1849,11 @@ static void ixgbe_shift_out_eeprom_bits(struct ixgbe_hw *hw, u16 data,
 		 * EEPROM
 		 */
 		mask = mask >> 1;
-	}
+	};
 
 	/* We leave the "DI" bit set to "0" when we leave this routine. */
 	eec &= ~IXGBE_EEC_DI;
-	IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), eec);
+	IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), eec);
 	IXGBE_WRITE_FLUSH(hw);
 }
 
@@ -1533,12 +1861,14 @@ static void ixgbe_shift_out_eeprom_bits(struct ixgbe_hw *hw, u16 data,
  *  ixgbe_shift_in_eeprom_bits - Shift data bits in from the EEPROM
  *  @hw: pointer to hardware structure
  **/
-static u16 ixgbe_shift_in_eeprom_bits(struct ixgbe_hw *hw, u16 count)
+STATIC u16 ixgbe_shift_in_eeprom_bits(struct ixgbe_hw *hw, u16 count)
 {
 	u32 eec;
 	u32 i;
 	u16 data = 0;
 
+	DEBUGFUNC("ixgbe_shift_in_eeprom_bits");
+
 	/*
 	 * In order to read a register from the EEPROM, we need to shift
 	 * 'count' bits in from the EEPROM. Bits are "shifted in" by raising
@@ -1546,7 +1876,7 @@ static u16 ixgbe_shift_in_eeprom_bits(struct ixgbe_hw *hw, u16 count)
 	 * the value of the "DO" bit.  During this "shifting in" process the
 	 * "DI" bit should always be clear.
 	 */
-	eec = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
+	eec = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
 
 	eec &= ~(IXGBE_EEC_DO | IXGBE_EEC_DI);
 
@@ -1554,7 +1884,7 @@ static u16 ixgbe_shift_in_eeprom_bits(struct ixgbe_hw *hw, u16 count)
 		data = data << 1;
 		ixgbe_raise_eeprom_clk(hw, &eec);
 
-		eec = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
+		eec = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
 
 		eec &= ~(IXGBE_EEC_DI);
 		if (eec & IXGBE_EEC_DO)
@@ -1571,16 +1901,18 @@ static u16 ixgbe_shift_in_eeprom_bits(struct ixgbe_hw *hw, u16 count)
  *  @hw: pointer to hardware structure
  *  @eec: EEC register's current value
  **/
-static void ixgbe_raise_eeprom_clk(struct ixgbe_hw *hw, u32 *eec)
+STATIC void ixgbe_raise_eeprom_clk(struct ixgbe_hw *hw, u32 *eec)
 {
+	DEBUGFUNC("ixgbe_raise_eeprom_clk");
+
 	/*
 	 * Raise the clock input to the EEPROM
 	 * (setting the SK bit), then delay
 	 */
 	*eec = *eec | IXGBE_EEC_SK;
-	IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), *eec);
+	IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), *eec);
 	IXGBE_WRITE_FLUSH(hw);
-	udelay(1);
+	usec_delay(1);
 }
 
 /**
@@ -1588,53 +1920,55 @@ static void ixgbe_raise_eeprom_clk(struct ixgbe_hw *hw, u32 *eec)
  *  @hw: pointer to hardware structure
  *  @eecd: EECD's current value
  **/
-static void ixgbe_lower_eeprom_clk(struct ixgbe_hw *hw, u32 *eec)
+STATIC void ixgbe_lower_eeprom_clk(struct ixgbe_hw *hw, u32 *eec)
 {
+	DEBUGFUNC("ixgbe_lower_eeprom_clk");
+
 	/*
 	 * Lower the clock input to the EEPROM (clearing the SK bit), then
 	 * delay
 	 */
 	*eec = *eec & ~IXGBE_EEC_SK;
-	IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), *eec);
+	IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), *eec);
 	IXGBE_WRITE_FLUSH(hw);
-	udelay(1);
+	usec_delay(1);
 }
 
 /**
  *  ixgbe_release_eeprom - Release EEPROM, release semaphores
  *  @hw: pointer to hardware structure
  **/
-static void ixgbe_release_eeprom(struct ixgbe_hw *hw)
+STATIC void ixgbe_release_eeprom(struct ixgbe_hw *hw)
 {
 	u32 eec;
 
-	eec = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
+	DEBUGFUNC("ixgbe_release_eeprom");
+
+	eec = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
 
 	eec |= IXGBE_EEC_CS;  /* Pull CS high */
 	eec &= ~IXGBE_EEC_SK; /* Lower SCK */
 
-	IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), eec);
+	IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), eec);
 	IXGBE_WRITE_FLUSH(hw);
 
-	udelay(1);
+	usec_delay(1);
 
 	/* Stop requesting EEPROM access */
 	eec &= ~IXGBE_EEC_REQ;
-	IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), eec);
+	IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), eec);
 
 	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
 
-	/*
-	 * Delay before attempt to obtain semaphore again to allow FW
-	 * access. semaphore_delay is in ms we need us for usleep_range
-	 */
-	usleep_range(hw->eeprom.semaphore_delay * 1000,
-		     hw->eeprom.semaphore_delay * 2000);
+	/* Delay before attempt to obtain semaphore again to allow FW access */
+	msec_delay(hw->eeprom.semaphore_delay);
 }
 
 /**
  *  ixgbe_calc_eeprom_checksum_generic - Calculates and returns the checksum
  *  @hw: pointer to hardware structure
+ *
+ *  Returns a negative error code on error, or the 16-bit checksum
  **/
 s32 ixgbe_calc_eeprom_checksum_generic(struct ixgbe_hw *hw)
 {
@@ -1645,11 +1979,13 @@ s32 ixgbe_calc_eeprom_checksum_generic(struct ixgbe_hw *hw)
 	u16 pointer = 0;
 	u16 word = 0;
 
+	DEBUGFUNC("ixgbe_calc_eeprom_checksum_generic");
+
 	/* Include 0x0-0x3F in the checksum */
 	for (i = 0; i < IXGBE_EEPROM_CHECKSUM; i++) {
 		if (hw->eeprom.ops.read(hw, i, &word)) {
-			hw_dbg(hw, "EEPROM read failed\n");
-			break;
+			DEBUGOUT("EEPROM read failed\n");
+			return IXGBE_ERR_EEPROM;
 		}
 		checksum += word;
 	}
@@ -1657,7 +1993,7 @@ s32 ixgbe_calc_eeprom_checksum_generic(struct ixgbe_hw *hw)
 	/* Include all data from pointers except for the fw pointer */
 	for (i = IXGBE_PCIE_ANALOG_PTR; i < IXGBE_FW_PTR; i++) {
 		if (hw->eeprom.ops.read(hw, i, &pointer)) {
-			hw_dbg(hw, "EEPROM read failed\n");
+			DEBUGOUT("EEPROM read failed\n");
 			return IXGBE_ERR_EEPROM;
 		}
 
@@ -1666,7 +2002,7 @@ s32 ixgbe_calc_eeprom_checksum_generic(struct ixgbe_hw *hw)
 			continue;
 
 		if (hw->eeprom.ops.read(hw, pointer, &length)) {
-			hw_dbg(hw, "EEPROM read failed\n");
+			DEBUGOUT("EEPROM read failed\n");
 			return IXGBE_ERR_EEPROM;
 		}
 
@@ -1675,7 +2011,7 @@ s32 ixgbe_calc_eeprom_checksum_generic(struct ixgbe_hw *hw)
 
 		for (j = pointer + 1; j <= pointer + length; j++) {
 			if (hw->eeprom.ops.read(hw, j, &word)) {
-				hw_dbg(hw, "EEPROM read failed\n");
+				DEBUGOUT("EEPROM read failed\n");
 				return IXGBE_ERR_EEPROM;
 			}
 			checksum += word;
@@ -1702,14 +2038,15 @@ s32 ixgbe_validate_eeprom_checksum_generic(struct ixgbe_hw *hw,
 	u16 checksum;
 	u16 read_checksum = 0;
 
-	/*
-	 * Read the first word from the EEPROM. If this times out or fails, do
+	DEBUGFUNC("ixgbe_validate_eeprom_checksum_generic");
+
+	/* Read the first word from the EEPROM. If this times out or fails, do
 	 * not continue or we could be in for a very long wait while every
 	 * EEPROM read fails
 	 */
 	status = hw->eeprom.ops.read(hw, 0, &checksum);
 	if (status) {
-		hw_dbg(hw, "EEPROM read failed\n");
+		DEBUGOUT("EEPROM read failed\n");
 		return status;
 	}
 
@@ -1721,7 +2058,7 @@ s32 ixgbe_validate_eeprom_checksum_generic(struct ixgbe_hw *hw,
 
 	status = hw->eeprom.ops.read(hw, IXGBE_EEPROM_CHECKSUM, &read_checksum);
 	if (status) {
-		hw_dbg(hw, "EEPROM read failed\n");
+		DEBUGOUT("EEPROM read failed\n");
 		return status;
 	}
 
@@ -1747,14 +2084,15 @@ s32 ixgbe_update_eeprom_checksum_generic(struct ixgbe_hw *hw)
 	s32 status;
 	u16 checksum;
 
-	/*
-	 * Read the first word from the EEPROM. If this times out or fails, do
+	DEBUGFUNC("ixgbe_update_eeprom_checksum_generic");
+
+	/* Read the first word from the EEPROM. If this times out or fails, do
 	 * not continue or we could be in for a very long wait while every
 	 * EEPROM read fails
 	 */
 	status = hw->eeprom.ops.read(hw, 0, &checksum);
 	if (status) {
-		hw_dbg(hw, "EEPROM read failed\n");
+		DEBUGOUT("EEPROM read failed\n");
 		return status;
 	}
 
@@ -1770,6 +2108,32 @@ s32 ixgbe_update_eeprom_checksum_generic(struct ixgbe_hw *hw)
 }
 
 /**
+ *  ixgbe_validate_mac_addr - Validate MAC address
+ *  @mac_addr: pointer to MAC address.
+ *
+ *  Tests a MAC address to ensure it is a valid Individual Address.
+ **/
+s32 ixgbe_validate_mac_addr(u8 *mac_addr)
+{
+	s32 status = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_validate_mac_addr");
+
+	/* Make sure it is not a multicast address */
+	if (IXGBE_IS_MULTICAST(mac_addr)) {
+		status = IXGBE_ERR_INVALID_MAC_ADDR;
+	/* Not a broadcast address */
+	} else if (IXGBE_IS_BROADCAST(mac_addr)) {
+		status = IXGBE_ERR_INVALID_MAC_ADDR;
+	/* Reject the zero address */
+	} else if (mac_addr[0] == 0 && mac_addr[1] == 0 && mac_addr[2] == 0 &&
+		   mac_addr[3] == 0 && mac_addr[4] == 0 && mac_addr[5] == 0) {
+		status = IXGBE_ERR_INVALID_MAC_ADDR;
+	}
+	return status;
+}
+
+/**
  *  ixgbe_set_rar_generic - Set Rx address register
  *  @hw: pointer to hardware structure
  *  @index: Receive address register to write
@@ -1785,9 +2149,12 @@ s32 ixgbe_set_rar_generic(struct ixgbe_hw *hw, u32 index, u8 *addr, u32 vmdq,
 	u32 rar_low, rar_high;
 	u32 rar_entries = hw->mac.num_rar_entries;
 
+	DEBUGFUNC("ixgbe_set_rar_generic");
+
 	/* Make sure we are using a valid rar index range */
 	if (index >= rar_entries) {
-		hw_dbg(hw, "RAR index %d is out of range.\n", index);
+		ERROR_REPORT2(IXGBE_ERROR_ARGUMENT,
+			     "RAR index %d is out of range.\n", index);
 		return IXGBE_ERR_INVALID_ARGUMENT;
 	}
 
@@ -1817,7 +2184,7 @@ s32 ixgbe_set_rar_generic(struct ixgbe_hw *hw, u32 index, u8 *addr, u32 vmdq,
 	IXGBE_WRITE_REG(hw, IXGBE_RAL(index), rar_low);
 	IXGBE_WRITE_REG(hw, IXGBE_RAH(index), rar_high);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -1832,9 +2199,12 @@ s32 ixgbe_clear_rar_generic(struct ixgbe_hw *hw, u32 index)
 	u32 rar_high;
 	u32 rar_entries = hw->mac.num_rar_entries;
 
+	DEBUGFUNC("ixgbe_clear_rar_generic");
+
 	/* Make sure we are using a valid rar index range */
 	if (index >= rar_entries) {
-		hw_dbg(hw, "RAR index %d is out of range.\n", index);
+		ERROR_REPORT2(IXGBE_ERROR_ARGUMENT,
+			     "RAR index %d is out of range.\n", index);
 		return IXGBE_ERR_INVALID_ARGUMENT;
 	}
 
@@ -1852,7 +2222,7 @@ s32 ixgbe_clear_rar_generic(struct ixgbe_hw *hw, u32 index)
 	/* clear VMDq pool/queue selection for this RAR */
 	hw->mac.ops.clear_vmdq(hw, index, IXGBE_CLEAR_VMDQ_ALL);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -1868,32 +2238,44 @@ s32 ixgbe_init_rx_addrs_generic(struct ixgbe_hw *hw)
 	u32 i;
 	u32 rar_entries = hw->mac.num_rar_entries;
 
+	DEBUGFUNC("ixgbe_init_rx_addrs_generic");
+
 	/*
 	 * If the current mac address is valid, assume it is a software override
 	 * to the permanent address.
 	 * Otherwise, use the permanent address from the eeprom.
 	 */
-	if (!is_valid_ether_addr(hw->mac.addr)) {
+	if (ixgbe_validate_mac_addr(hw->mac.addr) ==
+	    IXGBE_ERR_INVALID_MAC_ADDR) {
 		/* Get the MAC address from the RAR0 for later reference */
 		hw->mac.ops.get_mac_addr(hw, hw->mac.addr);
 
-		hw_dbg(hw, " Keeping Current RAR0 Addr =%pM\n", hw->mac.addr);
+		DEBUGOUT3(" Keeping Current RAR0 Addr =%.2X %.2X %.2X ",
+			  hw->mac.addr[0], hw->mac.addr[1],
+			  hw->mac.addr[2]);
+		DEBUGOUT3("%.2X %.2X %.2X\n", hw->mac.addr[3],
+			  hw->mac.addr[4], hw->mac.addr[5]);
 	} else {
 		/* Setup the receive address. */
-		hw_dbg(hw, "Overriding MAC Address in RAR[0]\n");
-		hw_dbg(hw, " New MAC Addr =%pM\n", hw->mac.addr);
+		DEBUGOUT("Overriding MAC Address in RAR[0]\n");
+		DEBUGOUT3(" New MAC Addr =%.2X %.2X %.2X ",
+			  hw->mac.addr[0], hw->mac.addr[1],
+			  hw->mac.addr[2]);
+		DEBUGOUT3("%.2X %.2X %.2X\n", hw->mac.addr[3],
+			  hw->mac.addr[4], hw->mac.addr[5]);
 
 		hw->mac.ops.set_rar(hw, 0, hw->mac.addr, 0, IXGBE_RAH_AV);
-
-		/*  clear VMDq pool/queue selection for RAR 0 */
-		hw->mac.ops.clear_vmdq(hw, 0, IXGBE_CLEAR_VMDQ_ALL);
 	}
+
+	/* clear VMDq pool/queue selection for RAR 0 */
+	hw->mac.ops.clear_vmdq(hw, 0, IXGBE_CLEAR_VMDQ_ALL);
+
 	hw->addr_ctrl.overflow_promisc = 0;
 
 	hw->addr_ctrl.rar_used_count = 1;
 
 	/* Zero out the other receive addresses. */
-	hw_dbg(hw, "Clearing RAR[1-%d]\n", rar_entries - 1);
+	DEBUGOUT1("Clearing RAR[1-%d]\n", rar_entries - 1);
 	for (i = 1; i < rar_entries; i++) {
 		IXGBE_WRITE_REG(hw, IXGBE_RAL(i), 0);
 		IXGBE_WRITE_REG(hw, IXGBE_RAH(i), 0);
@@ -1903,14 +2285,116 @@ s32 ixgbe_init_rx_addrs_generic(struct ixgbe_hw *hw)
 	hw->addr_ctrl.mta_in_use = 0;
 	IXGBE_WRITE_REG(hw, IXGBE_MCSTCTRL, hw->mac.mc_filter_type);
 
-	hw_dbg(hw, " Clearing MTA\n");
+	DEBUGOUT(" Clearing MTA\n");
 	for (i = 0; i < hw->mac.mcft_size; i++)
 		IXGBE_WRITE_REG(hw, IXGBE_MTA(i), 0);
 
-	if (hw->mac.ops.init_uta_tables)
-		hw->mac.ops.init_uta_tables(hw);
+	ixgbe_init_uta_tables(hw);
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_add_uc_addr - Adds a secondary unicast address.
+ *  @hw: pointer to hardware structure
+ *  @addr: new address
+ *
+ *  Adds it to unused receive address register or goes into promiscuous mode.
+ **/
+void ixgbe_add_uc_addr(struct ixgbe_hw *hw, u8 *addr, u32 vmdq)
+{
+	u32 rar_entries = hw->mac.num_rar_entries;
+	u32 rar;
+
+	DEBUGFUNC("ixgbe_add_uc_addr");
+
+	DEBUGOUT6(" UC Addr = %.2X %.2X %.2X %.2X %.2X %.2X\n",
+		  addr[0], addr[1], addr[2], addr[3], addr[4], addr[5]);
+
+	/*
+	 * Place this address in the RAR if there is room,
+	 * else put the controller into promiscuous mode
+	 */
+	if (hw->addr_ctrl.rar_used_count < rar_entries) {
+		rar = hw->addr_ctrl.rar_used_count;
+		hw->mac.ops.set_rar(hw, rar, addr, vmdq, IXGBE_RAH_AV);
+		DEBUGOUT1("Added a secondary address to RAR[%d]\n", rar);
+		hw->addr_ctrl.rar_used_count++;
+	} else {
+		hw->addr_ctrl.overflow_promisc++;
+	}
+
+	DEBUGOUT("ixgbe_add_uc_addr Complete\n");
+}
+
+/**
+ *  ixgbe_update_uc_addr_list_generic - Updates MAC list of secondary addresses
+ *  @hw: pointer to hardware structure
+ *  @addr_list: the list of new addresses
+ *  @addr_count: number of addresses
+ *  @next: iterator function to walk the address list
+ *
+ *  The given list replaces any existing list.  Clears the secondary addrs from
+ *  receive address registers.  Uses unused receive address registers for the
+ *  first secondary addresses, and falls back to promiscuous mode as needed.
+ *
+ *  Drivers using secondary unicast addresses must set user_set_promisc when
+ *  manually putting the device into promiscuous mode.
+ **/
+s32 ixgbe_update_uc_addr_list_generic(struct ixgbe_hw *hw, u8 *addr_list,
+				      u32 addr_count, ixgbe_mc_addr_itr next)
+{
+	u8 *addr;
+	u32 i;
+	u32 old_promisc_setting = hw->addr_ctrl.overflow_promisc;
+	u32 uc_addr_in_use;
+	u32 fctrl;
+	u32 vmdq;
+
+	DEBUGFUNC("ixgbe_update_uc_addr_list_generic");
+
+	/*
+	 * Clear accounting of old secondary address list,
+	 * don't count RAR[0]
+	 */
+	uc_addr_in_use = hw->addr_ctrl.rar_used_count - 1;
+	hw->addr_ctrl.rar_used_count -= uc_addr_in_use;
+	hw->addr_ctrl.overflow_promisc = 0;
+
+	/* Zero out the other receive addresses */
+	DEBUGOUT1("Clearing RAR[1-%d]\n", uc_addr_in_use+1);
+	for (i = 0; i < uc_addr_in_use; i++) {
+		IXGBE_WRITE_REG(hw, IXGBE_RAL(1+i), 0);
+		IXGBE_WRITE_REG(hw, IXGBE_RAH(1+i), 0);
+	}
+
+	/* Add the new addresses */
+	for (i = 0; i < addr_count; i++) {
+		DEBUGOUT(" Adding the secondary addresses:\n");
+		addr = next(hw, &addr_list, &vmdq);
+		ixgbe_add_uc_addr(hw, addr, vmdq);
+	}
+
+	if (hw->addr_ctrl.overflow_promisc) {
+		/* enable promisc if not already in overflow or set by user */
+		if (!old_promisc_setting && !hw->addr_ctrl.user_set_promisc) {
+			DEBUGOUT(" Entering address overflow promisc mode\n");
+			fctrl = IXGBE_READ_REG(hw, IXGBE_FCTRL);
+			fctrl |= IXGBE_FCTRL_UPE;
+			IXGBE_WRITE_REG(hw, IXGBE_FCTRL, fctrl);
+		}
+	} else {
+		/* only disable if set by overflow, not by user */
+		if (old_promisc_setting && !hw->addr_ctrl.user_set_promisc) {
+			DEBUGOUT(" Leaving address overflow promisc mode\n");
+			fctrl = IXGBE_READ_REG(hw, IXGBE_FCTRL);
+			fctrl &= ~IXGBE_FCTRL_UPE;
+			IXGBE_WRITE_REG(hw, IXGBE_FCTRL, fctrl);
+		}
+	}
 
-	return 0;
+	DEBUGOUT("ixgbe_update_uc_addr_list_generic Complete\n");
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -1925,10 +2409,12 @@ s32 ixgbe_init_rx_addrs_generic(struct ixgbe_hw *hw)
  *  by the MO field of the MCSTCTRL. The MO field is set during initialization
  *  to mc_filter_type.
  **/
-static s32 ixgbe_mta_vector(struct ixgbe_hw *hw, u8 *mc_addr)
+STATIC s32 ixgbe_mta_vector(struct ixgbe_hw *hw, u8 *mc_addr)
 {
 	u32 vector = 0;
 
+	DEBUGFUNC("ixgbe_mta_vector");
+
 	switch (hw->mac.mc_filter_type) {
 	case 0:   /* use bits [47:36] of the address */
 		vector = ((mc_addr[4] >> 4) | (((u16)mc_addr[5]) << 4));
@@ -1943,7 +2429,8 @@ static s32 ixgbe_mta_vector(struct ixgbe_hw *hw, u8 *mc_addr)
 		vector = ((mc_addr[4]) | (((u16)mc_addr[5]) << 8));
 		break;
 	default:  /* Invalid mc_filter_type */
-		hw_dbg(hw, "MC filter type param set incorrectly\n");
+		DEBUGOUT("MC filter type param set incorrectly\n");
+		ASSERT(0);
 		break;
 	}
 
@@ -1959,16 +2446,18 @@ static s32 ixgbe_mta_vector(struct ixgbe_hw *hw, u8 *mc_addr)
  *
  *  Sets the bit-vector in the multicast table.
  **/
-static void ixgbe_set_mta(struct ixgbe_hw *hw, u8 *mc_addr)
+void ixgbe_set_mta(struct ixgbe_hw *hw, u8 *mc_addr)
 {
 	u32 vector;
 	u32 vector_bit;
 	u32 vector_reg;
 
+	DEBUGFUNC("ixgbe_set_mta");
+
 	hw->addr_ctrl.mta_in_use++;
 
 	vector = ixgbe_mta_vector(hw, mc_addr);
-	hw_dbg(hw, " bit-vector = 0x%03X\n", vector);
+	DEBUGOUT1(" bit-vector = 0x%03X\n", vector);
 
 	/*
 	 * The MTA is a register array of 128 32-bit registers. It is treated
@@ -1987,34 +2476,40 @@ static void ixgbe_set_mta(struct ixgbe_hw *hw, u8 *mc_addr)
 /**
  *  ixgbe_update_mc_addr_list_generic - Updates MAC list of multicast addresses
  *  @hw: pointer to hardware structure
- *  @netdev: pointer to net device structure
+ *  @mc_addr_list: the list of new multicast addresses
+ *  @mc_addr_count: number of addresses
+ *  @next: iterator function to walk the multicast address list
+ *  @clear: flag, when set clears the table beforehand
  *
- *  The given list replaces any existing list. Clears the MC addrs from receive
- *  address registers and the multicast table. Uses unused receive address
- *  registers for the first multicast addresses, and hashes the rest into the
- *  multicast table.
+ *  When the clear flag is set, the given list replaces any existing list.
+ *  Hashes the given addresses into the multicast table.
  **/
-s32 ixgbe_update_mc_addr_list_generic(struct ixgbe_hw *hw,
-				      struct net_device *netdev)
+s32 ixgbe_update_mc_addr_list_generic(struct ixgbe_hw *hw, u8 *mc_addr_list,
+				      u32 mc_addr_count, ixgbe_mc_addr_itr next,
+				      bool clear)
 {
-	struct netdev_hw_addr *ha;
 	u32 i;
+	u32 vmdq;
+
+	DEBUGFUNC("ixgbe_update_mc_addr_list_generic");
 
 	/*
 	 * Set the new number of MC addresses that we are being requested to
 	 * use.
 	 */
-	hw->addr_ctrl.num_mc_addrs = netdev_mc_count(netdev);
+	hw->addr_ctrl.num_mc_addrs = mc_addr_count;
 	hw->addr_ctrl.mta_in_use = 0;
 
 	/* Clear mta_shadow */
-	hw_dbg(hw, " Clearing MTA\n");
-	memset(&hw->mac.mta_shadow, 0, sizeof(hw->mac.mta_shadow));
+	if (clear) {
+		DEBUGOUT(" Clearing MTA\n");
+		memset(&hw->mac.mta_shadow, 0, sizeof(hw->mac.mta_shadow));
+	}
 
-	/* Update mta shadow */
-	netdev_for_each_mc_addr(ha, netdev) {
-		hw_dbg(hw, " Adding the multicast addresses:\n");
-		ixgbe_set_mta(hw, ha->addr);
+	/* Update mta_shadow */
+	for (i = 0; i < mc_addr_count; i++) {
+		DEBUGOUT(" Adding the multicast addresses:\n");
+		ixgbe_set_mta(hw, next(hw, &mc_addr_list, &vmdq));
 	}
 
 	/* Enable mta */
@@ -2026,8 +2521,8 @@ s32 ixgbe_update_mc_addr_list_generic(struct ixgbe_hw *hw,
 		IXGBE_WRITE_REG(hw, IXGBE_MCSTCTRL,
 				IXGBE_MCSTCTRL_MFE | hw->mac.mc_filter_type);
 
-	hw_dbg(hw, "ixgbe_update_mc_addr_list_generic Complete\n");
-	return 0;
+	DEBUGOUT("ixgbe_update_mc_addr_list_generic Complete\n");
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2040,11 +2535,13 @@ s32 ixgbe_enable_mc_generic(struct ixgbe_hw *hw)
 {
 	struct ixgbe_addr_filter_info *a = &hw->addr_ctrl;
 
+	DEBUGFUNC("ixgbe_enable_mc_generic");
+
 	if (a->mta_in_use > 0)
 		IXGBE_WRITE_REG(hw, IXGBE_MCSTCTRL, IXGBE_MCSTCTRL_MFE |
 				hw->mac.mc_filter_type);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2057,10 +2554,12 @@ s32 ixgbe_disable_mc_generic(struct ixgbe_hw *hw)
 {
 	struct ixgbe_addr_filter_info *a = &hw->addr_ctrl;
 
+	DEBUGFUNC("ixgbe_disable_mc_generic");
+
 	if (a->mta_in_use > 0)
 		IXGBE_WRITE_REG(hw, IXGBE_MCSTCTRL, hw->mac.mc_filter_type);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2071,29 +2570,35 @@ s32 ixgbe_disable_mc_generic(struct ixgbe_hw *hw)
  **/
 s32 ixgbe_fc_enable_generic(struct ixgbe_hw *hw)
 {
+	s32 ret_val = IXGBE_SUCCESS;
 	u32 mflcn_reg, fccfg_reg;
 	u32 reg;
 	u32 fcrtl, fcrth;
 	int i;
 
-	/* Validate the water mark configuration. */
-	if (!hw->fc.pause_time)
-		return IXGBE_ERR_INVALID_LINK_SETTINGS;
+	DEBUGFUNC("ixgbe_fc_enable_generic");
+
+	/* Validate the water mark configuration */
+	if (!hw->fc.pause_time) {
+		ret_val = IXGBE_ERR_INVALID_LINK_SETTINGS;
+		goto out;
+	}
 
 	/* Low water mark of zero causes XOFF floods */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		if ((hw->fc.current_mode & ixgbe_fc_tx_pause) &&
 		    hw->fc.high_water[i]) {
 			if (!hw->fc.low_water[i] ||
 			    hw->fc.low_water[i] >= hw->fc.high_water[i]) {
-				hw_dbg(hw, "Invalid water mark configuration\n");
-				return IXGBE_ERR_INVALID_LINK_SETTINGS;
+				DEBUGOUT("Invalid water mark configuration\n");
+				ret_val = IXGBE_ERR_INVALID_LINK_SETTINGS;
+				goto out;
 			}
 		}
 	}
 
 	/* Negotiate the fc mode to use */
-	ixgbe_fc_autoneg(hw);
+	hw->mac.ops.fc_autoneg(hw);
 
 	/* Disable any previous flow control settings */
 	mflcn_reg = IXGBE_READ_REG(hw, IXGBE_MFLCN);
@@ -2143,8 +2648,11 @@ s32 ixgbe_fc_enable_generic(struct ixgbe_hw *hw)
 		fccfg_reg |= IXGBE_FCCFG_TFCE_802_3X;
 		break;
 	default:
-		hw_dbg(hw, "Flow control param set incorrectly\n");
-		return IXGBE_ERR_CONFIG;
+		ERROR_REPORT1(IXGBE_ERROR_ARGUMENT,
+			     "Flow control param set incorrectly\n");
+		ret_val = IXGBE_ERR_CONFIG;
+		goto out;
+		break;
 	}
 
 	/* Set 802.3x based flow control settings. */
@@ -2152,8 +2660,9 @@ s32 ixgbe_fc_enable_generic(struct ixgbe_hw *hw)
 	IXGBE_WRITE_REG(hw, IXGBE_MFLCN, mflcn_reg);
 	IXGBE_WRITE_REG(hw, IXGBE_FCCFG, fccfg_reg);
 
+
 	/* Set up and enable Rx high/low water mark thresholds, enable XON. */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		if ((hw->fc.current_mode & ixgbe_fc_tx_pause) &&
 		    hw->fc.high_water[i]) {
 			fcrtl = (hw->fc.low_water[i] << 10) | IXGBE_FCRTL_XONE;
@@ -2176,12 +2685,14 @@ s32 ixgbe_fc_enable_generic(struct ixgbe_hw *hw)
 
 	/* Configure pause time (2 TCs per register) */
 	reg = hw->fc.pause_time * 0x00010001;
-	for (i = 0; i < (MAX_TRAFFIC_CLASS / 2); i++)
+	for (i = 0; i < (IXGBE_DCB_MAX_TRAFFIC_CLASS / 2); i++)
 		IXGBE_WRITE_REG(hw, IXGBE_FCTTV(i), reg);
 
+	/* Configure flow control refresh threshold value */
 	IXGBE_WRITE_REG(hw, IXGBE_FCRTV, hw->fc.pause_time / 2);
 
-	return 0;
+out:
+	return ret_val;
 }
 
 /**
@@ -2197,11 +2708,16 @@ s32 ixgbe_fc_enable_generic(struct ixgbe_hw *hw)
  *  Find the intersection between advertised settings and link partner's
  *  advertised settings
  **/
-static s32 ixgbe_negotiate_fc(struct ixgbe_hw *hw, u32 adv_reg, u32 lp_reg,
-			      u32 adv_sym, u32 adv_asm, u32 lp_sym, u32 lp_asm)
+s32 ixgbe_negotiate_fc(struct ixgbe_hw *hw, u32 adv_reg, u32 lp_reg,
+		       u32 adv_sym, u32 adv_asm, u32 lp_sym, u32 lp_asm)
 {
-	if ((!(adv_reg)) ||  (!(lp_reg)))
+	if ((!(adv_reg)) ||  (!(lp_reg))) {
+		ERROR_REPORT3(IXGBE_ERROR_UNSUPPORTED,
+			     "Local or link partner's advertised flow control "
+			     "settings are NULL. Local: %x, link partner: %x\n",
+			     adv_reg, lp_reg);
 		return IXGBE_ERR_FC_NOT_NEGOTIATED;
+	}
 
 	if ((adv_reg & adv_sym) && (lp_reg & lp_sym)) {
 		/*
@@ -2213,24 +2729,24 @@ static s32 ixgbe_negotiate_fc(struct ixgbe_hw *hw, u32 adv_reg, u32 lp_reg,
 		 */
 		if (hw->fc.requested_mode == ixgbe_fc_full) {
 			hw->fc.current_mode = ixgbe_fc_full;
-			hw_dbg(hw, "Flow Control = FULL.\n");
+			DEBUGOUT("Flow Control = FULL.\n");
 		} else {
 			hw->fc.current_mode = ixgbe_fc_rx_pause;
-			hw_dbg(hw, "Flow Control=RX PAUSE frames only\n");
+			DEBUGOUT("Flow Control=RX PAUSE frames only\n");
 		}
 	} else if (!(adv_reg & adv_sym) && (adv_reg & adv_asm) &&
 		   (lp_reg & lp_sym) && (lp_reg & lp_asm)) {
 		hw->fc.current_mode = ixgbe_fc_tx_pause;
-		hw_dbg(hw, "Flow Control = TX PAUSE frames only.\n");
+		DEBUGOUT("Flow Control = TX PAUSE frames only.\n");
 	} else if ((adv_reg & adv_sym) && (adv_reg & adv_asm) &&
 		   !(lp_reg & lp_sym) && (lp_reg & lp_asm)) {
 		hw->fc.current_mode = ixgbe_fc_rx_pause;
-		hw_dbg(hw, "Flow Control = RX PAUSE frames only.\n");
+		DEBUGOUT("Flow Control = RX PAUSE frames only.\n");
 	} else {
 		hw->fc.current_mode = ixgbe_fc_none;
-		hw_dbg(hw, "Flow Control = NONE.\n");
+		DEBUGOUT("Flow Control = NONE.\n");
 	}
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2239,10 +2755,10 @@ static s32 ixgbe_negotiate_fc(struct ixgbe_hw *hw, u32 adv_reg, u32 lp_reg,
  *
  *  Enable flow control according on 1 gig fiber.
  **/
-static s32 ixgbe_fc_autoneg_fiber(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_fc_autoneg_fiber(struct ixgbe_hw *hw)
 {
 	u32 pcs_anadv_reg, pcs_lpab_reg, linkstat;
-	s32 ret_val;
+	s32 ret_val = IXGBE_ERR_FC_NOT_NEGOTIATED;
 
 	/*
 	 * On multispeed fiber at 1g, bail out if
@@ -2252,18 +2768,21 @@ static s32 ixgbe_fc_autoneg_fiber(struct ixgbe_hw *hw)
 
 	linkstat = IXGBE_READ_REG(hw, IXGBE_PCS1GLSTA);
 	if ((!!(linkstat & IXGBE_PCS1GLSTA_AN_COMPLETE) == 0) ||
-	    (!!(linkstat & IXGBE_PCS1GLSTA_AN_TIMED_OUT) == 1))
-		return IXGBE_ERR_FC_NOT_NEGOTIATED;
+	    (!!(linkstat & IXGBE_PCS1GLSTA_AN_TIMED_OUT) == 1)) {
+		DEBUGOUT("Auto-Negotiation did not complete or timed out\n");
+		goto out;
+	}
 
 	pcs_anadv_reg = IXGBE_READ_REG(hw, IXGBE_PCS1GANA);
 	pcs_lpab_reg = IXGBE_READ_REG(hw, IXGBE_PCS1GANLP);
 
 	ret_val =  ixgbe_negotiate_fc(hw, pcs_anadv_reg,
-			       pcs_lpab_reg, IXGBE_PCS1GANA_SYM_PAUSE,
-			       IXGBE_PCS1GANA_ASM_PAUSE,
-			       IXGBE_PCS1GANA_SYM_PAUSE,
-			       IXGBE_PCS1GANA_ASM_PAUSE);
+				      pcs_lpab_reg, IXGBE_PCS1GANA_SYM_PAUSE,
+				      IXGBE_PCS1GANA_ASM_PAUSE,
+				      IXGBE_PCS1GANA_SYM_PAUSE,
+				      IXGBE_PCS1GANA_ASM_PAUSE);
 
+out:
 	return ret_val;
 }
 
@@ -2273,10 +2792,10 @@ static s32 ixgbe_fc_autoneg_fiber(struct ixgbe_hw *hw)
  *
  *  Enable flow control according to IEEE clause 37.
  **/
-static s32 ixgbe_fc_autoneg_backplane(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_fc_autoneg_backplane(struct ixgbe_hw *hw)
 {
 	u32 links2, anlp1_reg, autoc_reg, links;
-	s32 ret_val;
+	s32 ret_val = IXGBE_ERR_FC_NOT_NEGOTIATED;
 
 	/*
 	 * On backplane, bail out if
@@ -2284,13 +2803,17 @@ static s32 ixgbe_fc_autoneg_backplane(struct ixgbe_hw *hw)
 	 * - we are 82599 and link partner is not AN enabled
 	 */
 	links = IXGBE_READ_REG(hw, IXGBE_LINKS);
-	if ((links & IXGBE_LINKS_KX_AN_COMP) == 0)
-		return IXGBE_ERR_FC_NOT_NEGOTIATED;
+	if ((links & IXGBE_LINKS_KX_AN_COMP) == 0) {
+		DEBUGOUT("Auto-Negotiation did not complete\n");
+		goto out;
+	}
 
 	if (hw->mac.type == ixgbe_mac_82599EB) {
 		links2 = IXGBE_READ_REG(hw, IXGBE_LINKS2);
-		if ((links2 & IXGBE_LINKS2_AN_SUPPORTED) == 0)
-			return IXGBE_ERR_FC_NOT_NEGOTIATED;
+		if ((links2 & IXGBE_LINKS2_AN_SUPPORTED) == 0) {
+			DEBUGOUT("Link partner is not AN enabled\n");
+			goto out;
+		}
 	}
 	/*
 	 * Read the 10g AN autoc and LP ability registers and resolve
@@ -2303,6 +2826,7 @@ static s32 ixgbe_fc_autoneg_backplane(struct ixgbe_hw *hw)
 		anlp1_reg, IXGBE_AUTOC_SYM_PAUSE, IXGBE_AUTOC_ASM_PAUSE,
 		IXGBE_ANLP1_SYM_PAUSE, IXGBE_ANLP1_ASM_PAUSE);
 
+out:
 	return ret_val;
 }
 
@@ -2312,16 +2836,16 @@ static s32 ixgbe_fc_autoneg_backplane(struct ixgbe_hw *hw)
  *
  *  Enable flow control according to IEEE clause 37.
  **/
-static s32 ixgbe_fc_autoneg_copper(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_fc_autoneg_copper(struct ixgbe_hw *hw)
 {
 	u16 technology_ability_reg = 0;
 	u16 lp_technology_ability_reg = 0;
 
-	hw->phy.ops.read_reg(hw, MDIO_AN_ADVERTISE,
-			     MDIO_MMD_AN,
+	hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_ADVT,
+			     IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
 			     &technology_ability_reg);
-	hw->phy.ops.read_reg(hw, MDIO_AN_LPA,
-			     MDIO_MMD_AN,
+	hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_LP,
+			     IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
 			     &lp_technology_ability_reg);
 
 	return ixgbe_negotiate_fc(hw, (u32)technology_ability_reg,
@@ -2343,24 +2867,29 @@ void ixgbe_fc_autoneg(struct ixgbe_hw *hw)
 	ixgbe_link_speed speed;
 	bool link_up;
 
+	DEBUGFUNC("ixgbe_fc_autoneg");
+
 	/*
 	 * AN should have completed when the cable was plugged in.
 	 * Look for reasons to bail out.  Bail out if:
 	 * - FC autoneg is disabled, or if
 	 * - link is not up.
-	 *
-	 * Since we're being called from an LSC, link is already known to be up.
-	 * So use link_up_wait_to_complete=false.
 	 */
-	if (hw->fc.disable_fc_autoneg)
+	if (hw->fc.disable_fc_autoneg) {
+		ERROR_REPORT1(IXGBE_ERROR_UNSUPPORTED,
+			     "Flow control autoneg is disabled");
 		goto out;
+	}
 
 	hw->mac.ops.check_link(hw, &speed, &link_up, false);
-	if (!link_up)
+	if (!link_up) {
+		ERROR_REPORT1(IXGBE_ERROR_SOFTWARE, "The link is down");
 		goto out;
+	}
 
 	switch (hw->phy.media_type) {
 	/* Autoneg flow control on fiber adapters */
+	case ixgbe_media_type_fiber_qsfp:
 	case ixgbe_media_type_fiber:
 		if (speed == IXGBE_LINK_SPEED_1GB_FULL)
 			ret_val = ixgbe_fc_autoneg_fiber(hw);
@@ -2382,7 +2911,7 @@ void ixgbe_fc_autoneg(struct ixgbe_hw *hw)
 	}
 
 out:
-	if (ret_val == 0) {
+	if (ret_val == IXGBE_SUCCESS) {
 		hw->fc.fc_was_autonegged = true;
 	} else {
 		hw->fc.fc_was_autonegged = false;
@@ -2390,46 +2919,46 @@ out:
 	}
 }
 
-/**
+/*
  * ixgbe_pcie_timeout_poll - Return number of times to poll for completion
  * @hw: pointer to hardware structure
  *
  * System-wide timeout range is encoded in PCIe Device Control2 register.
  *
- *  Add 10% to specified maximum and return the number of times to poll for
- *  completion timeout, in units of 100 microsec.  Never return less than
- *  800 = 80 millisec.
- **/
-static u32 ixgbe_pcie_timeout_poll(struct ixgbe_hw *hw)
+ * Add 10% to specified maximum and return the number of times to poll for
+ * completion timeout, in units of 100 microsec.  Never return less than
+ * 800 = 80 millisec.
+ */
+STATIC u32 ixgbe_pcie_timeout_poll(struct ixgbe_hw *hw)
 {
 	s16 devctl2;
 	u32 pollcnt;
 
-	devctl2 = ixgbe_read_pci_cfg_word(hw, IXGBE_PCI_DEVICE_CONTROL2);
+	devctl2 = IXGBE_READ_PCIE_WORD(hw, IXGBE_PCI_DEVICE_CONTROL2);
 	devctl2 &= IXGBE_PCIDEVCTRL2_TIMEO_MASK;
 
 	switch (devctl2) {
 	case IXGBE_PCIDEVCTRL2_65_130ms:
-		 pollcnt = 1300;         /* 130 millisec */
+		pollcnt = 1300;		/* 130 millisec */
 		break;
 	case IXGBE_PCIDEVCTRL2_260_520ms:
-		pollcnt = 5200;         /* 520 millisec */
+		pollcnt = 5200;		/* 520 millisec */
 		break;
 	case IXGBE_PCIDEVCTRL2_1_2s:
-		pollcnt = 20000;        /* 2 sec */
+		pollcnt = 20000;	/* 2 sec */
 		break;
 	case IXGBE_PCIDEVCTRL2_4_8s:
-		pollcnt = 80000;        /* 8 sec */
+		pollcnt = 80000;	/* 8 sec */
 		break;
 	case IXGBE_PCIDEVCTRL2_17_34s:
-		pollcnt = 34000;        /* 34 sec */
+		pollcnt = 34000;	/* 34 sec */
 		break;
-	case IXGBE_PCIDEVCTRL2_50_100us:        /* 100 microsecs */
-	case IXGBE_PCIDEVCTRL2_1_2ms:           /* 2 millisecs */
-	case IXGBE_PCIDEVCTRL2_16_32ms:         /* 32 millisec */
-	case IXGBE_PCIDEVCTRL2_16_32ms_def:     /* 32 millisec default */
+	case IXGBE_PCIDEVCTRL2_50_100us:	/* 100 microsecs */
+	case IXGBE_PCIDEVCTRL2_1_2ms:		/* 2 millisecs */
+	case IXGBE_PCIDEVCTRL2_16_32ms:		/* 32 millisec */
+	case IXGBE_PCIDEVCTRL2_16_32ms_def:	/* 32 millisec default */
 	default:
-		pollcnt = 800;          /* 80 millisec minimum */
+		pollcnt = 800;		/* 80 millisec minimum */
 		break;
 	}
 
@@ -2443,27 +2972,30 @@ static u32 ixgbe_pcie_timeout_poll(struct ixgbe_hw *hw)
  *
  *  Disables PCI-Express master access and verifies there are no pending
  *  requests. IXGBE_ERR_MASTER_REQUESTS_PENDING is returned if master disable
- *  bit hasn't caused the master requests to be disabled, else 0
+ *  bit hasn't caused the master requests to be disabled, else IXGBE_SUCCESS
  *  is returned signifying master requests disabled.
  **/
-static s32 ixgbe_disable_pcie_master(struct ixgbe_hw *hw)
+s32 ixgbe_disable_pcie_master(struct ixgbe_hw *hw)
 {
+	s32 status = IXGBE_SUCCESS;
 	u32 i, poll;
 	u16 value;
 
+	DEBUGFUNC("ixgbe_disable_pcie_master");
+
 	/* Always set this bit to ensure any future transactions are blocked */
 	IXGBE_WRITE_REG(hw, IXGBE_CTRL, IXGBE_CTRL_GIO_DIS);
 
 	/* Exit if master requests are blocked */
 	if (!(IXGBE_READ_REG(hw, IXGBE_STATUS) & IXGBE_STATUS_GIO) ||
-	    ixgbe_removed(hw->hw_addr))
-		return 0;
+	    IXGBE_REMOVED(hw->hw_addr))
+		goto out;
 
 	/* Poll for master request bit to clear */
 	for (i = 0; i < IXGBE_PCI_MASTER_DISABLE_TIMEOUT; i++) {
-		udelay(100);
+		usec_delay(100);
 		if (!(IXGBE_READ_REG(hw, IXGBE_STATUS) & IXGBE_STATUS_GIO))
-			return 0;
+			goto out;
 	}
 
 	/*
@@ -2474,11 +3006,11 @@ static s32 ixgbe_disable_pcie_master(struct ixgbe_hw *hw)
 	 * remaining completions from the PCIe bus to trickle in, and then reset
 	 * again to clear out any effects they may have had on our device.
 	 */
-	hw_dbg(hw, "GIO Master Disable bit didn't clear - requesting resets\n");
+	DEBUGOUT("GIO Master Disable bit didn't clear - requesting resets\n");
 	hw->mac.flags |= IXGBE_FLAGS_DOUBLE_RESET_REQUIRED;
 
 	if (hw->mac.type >= ixgbe_mac_X550)
-		return 0;
+		goto out;
 
 	/*
 	 * Before proceeding, make sure that the PCIe block does not have
@@ -2486,16 +3018,20 @@ static s32 ixgbe_disable_pcie_master(struct ixgbe_hw *hw)
 	 */
 	poll = ixgbe_pcie_timeout_poll(hw);
 	for (i = 0; i < poll; i++) {
-		udelay(100);
-		value = ixgbe_read_pci_cfg_word(hw, IXGBE_PCI_DEVICE_STATUS);
-		if (ixgbe_removed(hw->hw_addr))
-			return 0;
+		usec_delay(100);
+		value = IXGBE_READ_PCIE_WORD(hw, IXGBE_PCI_DEVICE_STATUS);
+		if (IXGBE_REMOVED(hw->hw_addr))
+			goto out;
 		if (!(value & IXGBE_PCI_DEVICE_STATUS_TRANSACTION_PENDING))
-			return 0;
+			goto out;
 	}
 
-	hw_dbg(hw, "PCIe transaction pending bit also did not clear.\n");
-	return IXGBE_ERR_MASTER_REQUESTS_PENDING;
+	ERROR_REPORT1(IXGBE_ERROR_POLLING,
+		     "PCIe transaction pending bit also did not clear.\n");
+	status = IXGBE_ERR_MASTER_REQUESTS_PENDING;
+
+out:
+	return status;
 }
 
 /**
@@ -2514,6 +3050,8 @@ s32 ixgbe_acquire_swfw_sync(struct ixgbe_hw *hw, u32 mask)
 	u32 timeout = 200;
 	u32 i;
 
+	DEBUGFUNC("ixgbe_acquire_swfw_sync");
+
 	for (i = 0; i < timeout; i++) {
 		/*
 		 * SW NVM semaphore bit is used for access to all
@@ -2527,11 +3065,11 @@ s32 ixgbe_acquire_swfw_sync(struct ixgbe_hw *hw, u32 mask)
 			gssr |= swmask;
 			IXGBE_WRITE_REG(hw, IXGBE_GSSR, gssr);
 			ixgbe_release_eeprom_semaphore(hw);
-			return 0;
+			return IXGBE_SUCCESS;
 		} else {
 			/* Resource is currently in use by FW or SW */
 			ixgbe_release_eeprom_semaphore(hw);
-			usleep_range(5000, 10000);
+			msec_delay(5);
 		}
 	}
 
@@ -2539,7 +3077,7 @@ s32 ixgbe_acquire_swfw_sync(struct ixgbe_hw *hw, u32 mask)
 	if (gssr & (fwmask | swmask))
 		ixgbe_release_swfw_sync(hw, gssr & (fwmask | swmask));
 
-	usleep_range(5000, 10000);
+	msec_delay(5);
 	return IXGBE_ERR_SWFW_SYNC;
 }
 
@@ -2556,6 +3094,8 @@ void ixgbe_release_swfw_sync(struct ixgbe_hw *hw, u32 mask)
 	u32 gssr;
 	u32 swmask = mask;
 
+	DEBUGFUNC("ixgbe_release_swfw_sync");
+
 	ixgbe_get_eeprom_semaphore(hw);
 
 	gssr = IXGBE_READ_REG(hw, IXGBE_GSSR);
@@ -2566,47 +3106,21 @@ void ixgbe_release_swfw_sync(struct ixgbe_hw *hw, u32 mask)
 }
 
 /**
- * prot_autoc_read_generic - Hides MAC differences needed for AUTOC read
- * @hw: pointer to hardware structure
- * @reg_val: Value we read from AUTOC
- * @locked: bool to indicate whether the SW/FW lock should be taken.  Never
- *	    true in this the generic case.
- *
- * The default case requires no protection so just to the register read.
- **/
-s32 prot_autoc_read_generic(struct ixgbe_hw *hw, bool *locked, u32 *reg_val)
-{
-	*locked = false;
-	*reg_val = IXGBE_READ_REG(hw, IXGBE_AUTOC);
-	return 0;
-}
-
-/**
- * prot_autoc_write_generic - Hides MAC differences needed for AUTOC write
- * @hw: pointer to hardware structure
- * @reg_val: value to write to AUTOC
- * @locked: bool to indicate whether the SW/FW lock was already taken by
- *	    previous read.
- **/
-s32 prot_autoc_write_generic(struct ixgbe_hw *hw, u32 reg_val, bool locked)
-{
-	IXGBE_WRITE_REG(hw, IXGBE_AUTOC, reg_val);
-	return 0;
-}
-
-/**
- *  ixgbe_disable_rx_buff_generic - Stops the receive data path
+ *  ixgbe_disable_sec_rx_path_generic - Stops the receive data path
  *  @hw: pointer to hardware structure
  *
- *  Stops the receive data path and waits for the HW to internally
- *  empty the Rx security block.
+ *  Stops the receive data path and waits for the HW to internally empty
+ *  the Rx security block
  **/
-s32 ixgbe_disable_rx_buff_generic(struct ixgbe_hw *hw)
+s32 ixgbe_disable_sec_rx_path_generic(struct ixgbe_hw *hw)
 {
-#define IXGBE_MAX_SECRX_POLL 40
+#define IXGBE_MAX_SECRX_POLL 4000
+
 	int i;
 	int secrxreg;
 
+	DEBUGFUNC("ixgbe_disable_sec_rx_path_generic");
+
 	secrxreg = IXGBE_READ_REG(hw, IXGBE_SECRXCTRL);
 	secrxreg |= IXGBE_SECRXCTRL_RX_DIS;
 	IXGBE_WRITE_REG(hw, IXGBE_SECRXCTRL, secrxreg);
@@ -2616,33 +3130,66 @@ s32 ixgbe_disable_rx_buff_generic(struct ixgbe_hw *hw)
 			break;
 		else
 			/* Use interrupt-safe sleep just in case */
-			udelay(1000);
+			usec_delay(10);
 	}
 
 	/* For informational purposes only */
 	if (i >= IXGBE_MAX_SECRX_POLL)
-		hw_dbg(hw, "Rx unit being enabled before security path fully disabled. Continuing with init.\n");
+		DEBUGOUT("Rx unit being enabled before security "
+			 "path fully disabled.  Continuing with init.\n");
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  prot_autoc_read_generic - Hides MAC differences needed for AUTOC read
+ *  @hw: pointer to hardware structure
+ *  @reg_val: Value we read from AUTOC
+ *
+ *  The default case requires no protection so just to the register read.
+ */
+s32 prot_autoc_read_generic(struct ixgbe_hw *hw, bool *locked, u32 *reg_val)
+{
+	*locked = false;
+	*reg_val = IXGBE_READ_REG(hw, IXGBE_AUTOC);
+	return IXGBE_SUCCESS;
+}
 
-	return 0;
+/**
+ * prot_autoc_write_generic - Hides MAC differences needed for AUTOC write
+ * @hw: pointer to hardware structure
+ * @reg_val: value to write to AUTOC
+ * @locked: bool to indicate whether the SW/FW lock was already taken by
+ *           previous read.
+ *
+ * The default case requires no protection so just to the register write.
+ */
+s32 prot_autoc_write_generic(struct ixgbe_hw *hw, u32 reg_val, bool locked)
+{
+	UNREFERENCED_1PARAMETER(locked);
 
+	IXGBE_WRITE_REG(hw, IXGBE_AUTOC, reg_val);
+	return IXGBE_SUCCESS;
 }
 
 /**
- *  ixgbe_enable_rx_buff - Enables the receive data path
+ *  ixgbe_enable_sec_rx_path_generic - Enables the receive data path
  *  @hw: pointer to hardware structure
  *
- *  Enables the receive data path
+ *  Enables the receive data path.
  **/
-s32 ixgbe_enable_rx_buff_generic(struct ixgbe_hw *hw)
+s32 ixgbe_enable_sec_rx_path_generic(struct ixgbe_hw *hw)
 {
-	int secrxreg;
+	u32 secrxreg;
+
+	DEBUGFUNC("ixgbe_enable_sec_rx_path_generic");
 
 	secrxreg = IXGBE_READ_REG(hw, IXGBE_SECRXCTRL);
 	secrxreg &= ~IXGBE_SECRXCTRL_RX_DIS;
 	IXGBE_WRITE_REG(hw, IXGBE_SECRXCTRL, secrxreg);
 	IXGBE_WRITE_FLUSH(hw);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2654,12 +3201,14 @@ s32 ixgbe_enable_rx_buff_generic(struct ixgbe_hw *hw)
  **/
 s32 ixgbe_enable_rx_dma_generic(struct ixgbe_hw *hw, u32 regval)
 {
+	DEBUGFUNC("ixgbe_enable_rx_dma_generic");
+
 	if (regval & IXGBE_RXCTRL_RXEN)
-		hw->mac.ops.enable_rx(hw);
+		ixgbe_enable_rx(hw);
 	else
-		hw->mac.ops.disable_rx(hw);
+		ixgbe_disable_rx(hw);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2670,11 +3219,16 @@ s32 ixgbe_enable_rx_dma_generic(struct ixgbe_hw *hw, u32 regval)
 s32 ixgbe_blink_led_start_generic(struct ixgbe_hw *hw, u32 index)
 {
 	ixgbe_link_speed speed = 0;
-	bool link_up = false;
-	u32 autoc_reg = IXGBE_READ_REG(hw, IXGBE_AUTOC);
+	bool link_up = 0;
+	u32 autoc_reg = 0;
 	u32 led_reg = IXGBE_READ_REG(hw, IXGBE_LEDCTL);
+	s32 ret_val = IXGBE_SUCCESS;
 	bool locked = false;
-	s32 ret_val;
+
+	DEBUGFUNC("ixgbe_blink_led_start_generic");
+
+	if (index > 3)
+		return IXGBE_ERR_PARAM;
 
 	/*
 	 * Link must be up to auto-blink the LEDs;
@@ -2684,19 +3238,18 @@ s32 ixgbe_blink_led_start_generic(struct ixgbe_hw *hw, u32 index)
 
 	if (!link_up) {
 		ret_val = hw->mac.ops.prot_autoc_read(hw, &locked, &autoc_reg);
-		if (ret_val)
-			return ret_val;
+		if (ret_val != IXGBE_SUCCESS)
+			goto out;
 
 		autoc_reg |= IXGBE_AUTOC_AN_RESTART;
 		autoc_reg |= IXGBE_AUTOC_FLU;
 
 		ret_val = hw->mac.ops.prot_autoc_write(hw, autoc_reg, locked);
-		if (ret_val)
-			return ret_val;
+		if (ret_val != IXGBE_SUCCESS)
+			goto out;
 
 		IXGBE_WRITE_FLUSH(hw);
-
-		usleep_range(10000, 20000);
+		msec_delay(10);
 	}
 
 	led_reg &= ~IXGBE_LED_MODE_MASK(index);
@@ -2704,7 +3257,8 @@ s32 ixgbe_blink_led_start_generic(struct ixgbe_hw *hw, u32 index)
 	IXGBE_WRITE_REG(hw, IXGBE_LEDCTL, led_reg);
 	IXGBE_WRITE_FLUSH(hw);
 
-	return 0;
+out:
+	return ret_val;
 }
 
 /**
@@ -2716,19 +3270,24 @@ s32 ixgbe_blink_led_stop_generic(struct ixgbe_hw *hw, u32 index)
 {
 	u32 autoc_reg = 0;
 	u32 led_reg = IXGBE_READ_REG(hw, IXGBE_LEDCTL);
+	s32 ret_val = IXGBE_SUCCESS;
 	bool locked = false;
-	s32 ret_val;
+
+	DEBUGFUNC("ixgbe_blink_led_stop_generic");
+
+	if (index > 3)
+		return IXGBE_ERR_PARAM;
 
 	ret_val = hw->mac.ops.prot_autoc_read(hw, &locked, &autoc_reg);
-	if (ret_val)
-		return ret_val;
+	if (ret_val != IXGBE_SUCCESS)
+		goto out;
 
 	autoc_reg &= ~IXGBE_AUTOC_FLU;
 	autoc_reg |= IXGBE_AUTOC_AN_RESTART;
 
 	ret_val = hw->mac.ops.prot_autoc_write(hw, autoc_reg, locked);
-	if (ret_val)
-		return ret_val;
+	if (ret_val != IXGBE_SUCCESS)
+		goto out;
 
 	led_reg &= ~IXGBE_LED_MODE_MASK(index);
 	led_reg &= ~IXGBE_LED_BLINK(index);
@@ -2736,7 +3295,8 @@ s32 ixgbe_blink_led_stop_generic(struct ixgbe_hw *hw, u32 index)
 	IXGBE_WRITE_REG(hw, IXGBE_LEDCTL, led_reg);
 	IXGBE_WRITE_FLUSH(hw);
 
-	return 0;
+out:
+	return ret_val;
 }
 
 /**
@@ -2748,20 +3308,24 @@ s32 ixgbe_blink_led_stop_generic(struct ixgbe_hw *hw, u32 index)
  *  pointer, and returns the value at that location.  This is used in both
  *  get and set mac_addr routines.
  **/
-static s32 ixgbe_get_san_mac_addr_offset(struct ixgbe_hw *hw,
-					u16 *san_mac_offset)
+STATIC s32 ixgbe_get_san_mac_addr_offset(struct ixgbe_hw *hw,
+					 u16 *san_mac_offset)
 {
 	s32 ret_val;
 
+	DEBUGFUNC("ixgbe_get_san_mac_addr_offset");
+
 	/*
 	 * First read the EEPROM pointer to see if the MAC addresses are
 	 * available.
 	 */
 	ret_val = hw->eeprom.ops.read(hw, IXGBE_SAN_MAC_ADDR_PTR,
 				      san_mac_offset);
-	if (ret_val)
-		hw_err(hw, "eeprom read at offset %d failed\n",
-		       IXGBE_SAN_MAC_ADDR_PTR);
+	if (ret_val) {
+		ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+			      "eeprom at offset %d failed",
+			      IXGBE_SAN_MAC_ADDR_PTR);
+	}
 
 	return ret_val;
 }
@@ -2782,14 +3346,15 @@ s32 ixgbe_get_san_mac_addr_generic(struct ixgbe_hw *hw, u8 *san_mac_addr)
 	u8 i;
 	s32 ret_val;
 
+	DEBUGFUNC("ixgbe_get_san_mac_addr_generic");
+
 	/*
 	 * First read the EEPROM pointer to see if the MAC addresses are
 	 * available.  If they're not, no point in calling set_lan_id() here.
 	 */
 	ret_val = ixgbe_get_san_mac_addr_offset(hw, &san_mac_offset);
 	if (ret_val || san_mac_offset == 0 || san_mac_offset == 0xFFFF)
-
-		goto san_mac_addr_clr;
+		goto san_mac_addr_out;
 
 	/* make sure we know which port we need to program */
 	hw->mac.ops.set_lan_id(hw);
@@ -2800,23 +3365,61 @@ s32 ixgbe_get_san_mac_addr_generic(struct ixgbe_hw *hw, u8 *san_mac_addr)
 		ret_val = hw->eeprom.ops.read(hw, san_mac_offset,
 					      &san_mac_data);
 		if (ret_val) {
-			hw_err(hw, "eeprom read at offset %d failed\n",
-			       san_mac_offset);
-			goto san_mac_addr_clr;
+			ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+				      "eeprom read at offset %d failed",
+				      san_mac_offset);
+			goto san_mac_addr_out;
 		}
 		san_mac_addr[i * 2] = (u8)(san_mac_data);
 		san_mac_addr[i * 2 + 1] = (u8)(san_mac_data >> 8);
 		san_mac_offset++;
 	}
-	return 0;
+	return IXGBE_SUCCESS;
 
-san_mac_addr_clr:
-	/* No addresses available in this EEPROM.  It's not necessarily an
+san_mac_addr_out:
+	/*
+	 * No addresses available in this EEPROM.  It's not an
 	 * error though, so just wipe the local address and return.
 	 */
 	for (i = 0; i < 6; i++)
 		san_mac_addr[i] = 0xFF;
-	return ret_val;
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_set_san_mac_addr_generic - Write the SAN MAC address to the EEPROM
+ *  @hw: pointer to hardware structure
+ *  @san_mac_addr: SAN MAC address
+ *
+ *  Write a SAN MAC address to the EEPROM.
+ **/
+s32 ixgbe_set_san_mac_addr_generic(struct ixgbe_hw *hw, u8 *san_mac_addr)
+{
+	s32 ret_val;
+	u16 san_mac_data, san_mac_offset;
+	u8 i;
+
+	DEBUGFUNC("ixgbe_set_san_mac_addr_generic");
+
+	/* Look for SAN mac address pointer.  If not defined, return */
+	ret_val = ixgbe_get_san_mac_addr_offset(hw, &san_mac_offset);
+	if (ret_val || san_mac_offset == 0 || san_mac_offset == 0xFFFF)
+		return IXGBE_ERR_NO_SAN_ADDR_PTR;
+
+	/* Make sure we know which port we need to write */
+	hw->mac.ops.set_lan_id(hw);
+	/* Apply the port offset to the address offset */
+	(hw->bus.func) ? (san_mac_offset += IXGBE_SAN_MAC_ADDR_PORT1_OFFSET) :
+			 (san_mac_offset += IXGBE_SAN_MAC_ADDR_PORT0_OFFSET);
+
+	for (i = 0; i < 3; i++) {
+		san_mac_data = (u16)((u16)(san_mac_addr[i * 2 + 1]) << 8);
+		san_mac_data |= (u16)(san_mac_addr[i * 2]);
+		hw->eeprom.ops.write(hw, san_mac_offset, san_mac_data);
+		san_mac_offset++;
+	}
+
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2828,7 +3431,7 @@ san_mac_addr_clr:
  **/
 u16 ixgbe_get_pcie_msix_count_generic(struct ixgbe_hw *hw)
 {
-	u16 msix_count;
+	u16 msix_count = 1;
 	u16 max_msix_count;
 	u16 pcie_offset;
 
@@ -2841,15 +3444,17 @@ u16 ixgbe_get_pcie_msix_count_generic(struct ixgbe_hw *hw)
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		pcie_offset = IXGBE_PCIE_MSIX_82599_CAPS;
 		max_msix_count = IXGBE_MAX_MSIX_VECTORS_82599;
 		break;
 	default:
-		return 1;
+		return msix_count;
 	}
 
-	msix_count = ixgbe_read_pci_cfg_word(hw, pcie_offset);
-	if (ixgbe_removed(hw->hw_addr))
+	DEBUGFUNC("ixgbe_get_pcie_msix_count_generic");
+	msix_count = IXGBE_READ_PCIE_WORD(hw, pcie_offset);
+	if (IXGBE_REMOVED(hw->hw_addr))
 		msix_count = 0;
 	msix_count &= IXGBE_PCIE_MSIX_TBL_SZ_MASK;
 
@@ -2863,30 +3468,102 @@ u16 ixgbe_get_pcie_msix_count_generic(struct ixgbe_hw *hw)
 }
 
 /**
- *  ixgbe_clear_vmdq_generic - Disassociate a VMDq pool index from a rx address
- *  @hw: pointer to hardware struct
- *  @rar: receive address register index to disassociate
- *  @vmdq: VMDq pool index to remove from the rar
- **/
-s32 ixgbe_clear_vmdq_generic(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
+ *  ixgbe_insert_mac_addr_generic - Find a RAR for this mac address
+ *  @hw: pointer to hardware structure
+ *  @addr: Address to put into receive address register
+ *  @vmdq: VMDq pool to assign
+ *
+ *  Puts an ethernet address into a receive address register, or
+ *  finds the rar that it is aleady in; adds to the pool list
+ **/
+s32 ixgbe_insert_mac_addr_generic(struct ixgbe_hw *hw, u8 *addr, u32 vmdq)
+{
+	static const u32 NO_EMPTY_RAR_FOUND = 0xFFFFFFFF;
+	u32 first_empty_rar = NO_EMPTY_RAR_FOUND;
+	u32 rar;
+	u32 rar_low, rar_high;
+	u32 addr_low, addr_high;
+
+	DEBUGFUNC("ixgbe_insert_mac_addr_generic");
+
+	/* swap bytes for HW little endian */
+	addr_low  = addr[0] | (addr[1] << 8)
+			    | (addr[2] << 16)
+			    | (addr[3] << 24);
+	addr_high = addr[4] | (addr[5] << 8);
+
+	/*
+	 * Either find the mac_id in rar or find the first empty space.
+	 * rar_highwater points to just after the highest currently used
+	 * rar in order to shorten the search.  It grows when we add a new
+	 * rar to the top.
+	 */
+	for (rar = 0; rar < hw->mac.rar_highwater; rar++) {
+		rar_high = IXGBE_READ_REG(hw, IXGBE_RAH(rar));
+
+		if (((IXGBE_RAH_AV & rar_high) == 0)
+		    && first_empty_rar == NO_EMPTY_RAR_FOUND) {
+			first_empty_rar = rar;
+		} else if ((rar_high & 0xFFFF) == addr_high) {
+			rar_low = IXGBE_READ_REG(hw, IXGBE_RAL(rar));
+			if (rar_low == addr_low)
+				break;    /* found it already in the rars */
+		}
+	}
+
+	if (rar < hw->mac.rar_highwater) {
+		/* already there so just add to the pool bits */
+		ixgbe_set_vmdq(hw, rar, vmdq);
+	} else if (first_empty_rar != NO_EMPTY_RAR_FOUND) {
+		/* stick it into first empty RAR slot we found */
+		rar = first_empty_rar;
+		ixgbe_set_rar(hw, rar, addr, vmdq, IXGBE_RAH_AV);
+	} else if (rar == hw->mac.rar_highwater) {
+		/* add it to the top of the list and inc the highwater mark */
+		ixgbe_set_rar(hw, rar, addr, vmdq, IXGBE_RAH_AV);
+		hw->mac.rar_highwater++;
+	} else if (rar >= hw->mac.num_rar_entries) {
+		return IXGBE_ERR_INVALID_MAC_ADDR;
+	}
+
+	/*
+	 * If we found rar[0], make sure the default pool bit (we use pool 0)
+	 * remains cleared to be sure default pool packets will get delivered
+	 */
+	if (rar == 0)
+		ixgbe_clear_vmdq(hw, rar, 0);
+
+	return rar;
+}
+
+/**
+ *  ixgbe_clear_vmdq_generic - Disassociate a VMDq pool index from a rx address
+ *  @hw: pointer to hardware struct
+ *  @rar: receive address register index to disassociate
+ *  @vmdq: VMDq pool index to remove from the rar
+ **/
+s32 ixgbe_clear_vmdq_generic(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
 {
 	u32 mpsar_lo, mpsar_hi;
 	u32 rar_entries = hw->mac.num_rar_entries;
 
+	DEBUGFUNC("ixgbe_clear_vmdq_generic");
+
 	/* Make sure we are using a valid rar index range */
 	if (rar >= rar_entries) {
-		hw_dbg(hw, "RAR index %d is out of range.\n", rar);
+		ERROR_REPORT2(IXGBE_ERROR_ARGUMENT,
+			     "RAR index %d is out of range.\n", rar);
 		return IXGBE_ERR_INVALID_ARGUMENT;
 	}
 
 	mpsar_lo = IXGBE_READ_REG(hw, IXGBE_MPSAR_LO(rar));
 	mpsar_hi = IXGBE_READ_REG(hw, IXGBE_MPSAR_HI(rar));
 
-	if (ixgbe_removed(hw->hw_addr))
-		return 0;
+	if (IXGBE_REMOVED(hw->hw_addr))
+		goto done;
 
 	if (!mpsar_lo && !mpsar_hi)
-		return 0;
+		goto done;
 
 	if (vmdq == IXGBE_CLEAR_VMDQ_ALL) {
 		if (mpsar_lo) {
@@ -2906,9 +3583,11 @@ s32 ixgbe_clear_vmdq_generic(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
 	}
 
 	/* was that the last pool using this rar? */
-	if (mpsar_lo == 0 && mpsar_hi == 0 && rar != 0)
+	if (mpsar_lo == 0 && mpsar_hi == 0 &&
+	    rar != 0 && rar != hw->mac.san_mac_rar_index)
 		hw->mac.ops.clear_rar(hw, rar);
-	return 0;
+done:
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2922,9 +3601,12 @@ s32 ixgbe_set_vmdq_generic(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
 	u32 mpsar;
 	u32 rar_entries = hw->mac.num_rar_entries;
 
+	DEBUGFUNC("ixgbe_set_vmdq_generic");
+
 	/* Make sure we are using a valid rar index range */
 	if (rar >= rar_entries) {
-		hw_dbg(hw, "RAR index %d is out of range.\n", rar);
+		ERROR_REPORT2(IXGBE_ERROR_ARGUMENT,
+			     "RAR index %d is out of range.\n", rar);
 		return IXGBE_ERR_INVALID_ARGUMENT;
 	}
 
@@ -2937,7 +3619,7 @@ s32 ixgbe_set_vmdq_generic(struct ixgbe_hw *hw, u32 rar, u32 vmdq)
 		mpsar |= 1 << (vmdq - 32);
 		IXGBE_WRITE_REG(hw, IXGBE_MPSAR_HI(rar), mpsar);
 	}
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2954,6 +3636,8 @@ s32 ixgbe_set_vmdq_san_mac_generic(struct ixgbe_hw *hw, u32 vmdq)
 {
 	u32 rar = hw->mac.san_mac_rar_index;
 
+	DEBUGFUNC("ixgbe_set_vmdq_san_mac");
+
 	if (vmdq < 32) {
 		IXGBE_WRITE_REG(hw, IXGBE_MPSAR_LO(rar), 1 << vmdq);
 		IXGBE_WRITE_REG(hw, IXGBE_MPSAR_HI(rar), 0);
@@ -2962,7 +3646,7 @@ s32 ixgbe_set_vmdq_san_mac_generic(struct ixgbe_hw *hw, u32 vmdq)
 		IXGBE_WRITE_REG(hw, IXGBE_MPSAR_HI(rar), 1 << (vmdq - 32));
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2973,10 +3657,13 @@ s32 ixgbe_init_uta_tables_generic(struct ixgbe_hw *hw)
 {
 	int i;
 
+	DEBUGFUNC("ixgbe_init_uta_tables_generic");
+	DEBUGOUT(" Clearing UTA\n");
+
 	for (i = 0; i < 128; i++)
 		IXGBE_WRITE_REG(hw, IXGBE_UTA(i), 0);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2987,66 +3674,65 @@ s32 ixgbe_init_uta_tables_generic(struct ixgbe_hw *hw)
  *  return the VLVF index where this VLAN id should be placed
  *
  **/
-static s32 ixgbe_find_vlvf_slot(struct ixgbe_hw *hw, u32 vlan)
+s32 ixgbe_find_vlvf_slot(struct ixgbe_hw *hw, u32 vlan, bool vlvf_bypass)
 {
-	u32 bits = 0;
-	u32 first_empty_slot = 0;
-	s32 regindex;
+	s32 regindex, first_empty_slot;
+	u32 bits;
 
 	/* short cut the special case */
 	if (vlan == 0)
 		return 0;
 
-	/*
-	  * Search for the vlan id in the VLVF entries. Save off the first empty
-	  * slot found along the way
-	  */
-	for (regindex = 1; regindex < IXGBE_VLVF_ENTRIES; regindex++) {
+	/* if vlvf_bypass is set we don't want to use an empty slot, we
+	 * will simply bypass the VLVF if there are no entries present in the
+	 * VLVF that contain our VLAN
+	 */
+	first_empty_slot = vlvf_bypass ? IXGBE_ERR_NO_SPACE : 0;
+
+	/* add VLAN enable bit for comparison */
+	vlan |= IXGBE_VLVF_VIEN;
+
+	/* Search for the vlan id in the VLVF entries. Save off the first empty
+	 * slot found along the way.
+	 *
+	 * pre-decrement loop covering (IXGBE_VLVF_ENTRIES - 1) .. 1
+	 */
+	for (regindex = IXGBE_VLVF_ENTRIES; --regindex;) {
 		bits = IXGBE_READ_REG(hw, IXGBE_VLVF(regindex));
-		if (!bits && !(first_empty_slot))
+		if (bits == vlan)
+			return regindex;
+		if (!first_empty_slot && !bits)
 			first_empty_slot = regindex;
-		else if ((bits & 0x0FFF) == vlan)
-			break;
 	}
 
-	/*
-	  * If regindex is less than IXGBE_VLVF_ENTRIES, then we found the vlan
-	  * in the VLVF. Else use the first empty VLVF register for this
-	  * vlan id.
-	  */
-	if (regindex >= IXGBE_VLVF_ENTRIES) {
-		if (first_empty_slot)
-			regindex = first_empty_slot;
-		else {
-			hw_dbg(hw, "No space in VLVF.\n");
-			regindex = IXGBE_ERR_NO_SPACE;
-		}
-	}
+	/* If we are here then we didn't find the VLAN.  Return first empty
+	 * slot we found during our search, else error.
+	 */
+	if (!first_empty_slot)
+		ERROR_REPORT1(IXGBE_ERROR_SOFTWARE, "No space in VLVF.\n");
 
-	return regindex;
+	return first_empty_slot ? first_empty_slot : IXGBE_ERR_NO_SPACE;
 }
 
 /**
  *  ixgbe_set_vfta_generic - Set VLAN filter table
  *  @hw: pointer to hardware structure
  *  @vlan: VLAN id to write to VLAN filter
- *  @vind: VMDq output index that maps queue to VLAN id in VFVFB
- *  @vlan_on: boolean flag to turn on/off VLAN in VFVF
+ *  @vind: VMDq output index that maps queue to VLAN id in VLVFB
+ *  @vlan_on: boolean flag to turn on/off VLAN
+ *  @vlvf_bypass: boolean flag indicating updating default pool is okay
  *
  *  Turn on/off specified VLAN in the VLAN filter table.
  **/
 s32 ixgbe_set_vfta_generic(struct ixgbe_hw *hw, u32 vlan, u32 vind,
-			   bool vlan_on)
+			   bool vlan_on, bool vlvf_bypass)
 {
-	s32 regindex;
-	u32 bitindex;
-	u32 vfta;
-	u32 bits;
-	u32 vt;
-	u32 targetbit;
-	bool vfta_changed = false;
+	u32 regidx, vfta_delta, vfta;
+	s32 ret_val;
+
+	DEBUGFUNC("ixgbe_set_vfta_generic");
 
-	if (vlan > 4095)
+	if (vlan > 4095 || vind > 63)
 		return IXGBE_ERR_PARAM;
 
 	/*
@@ -3061,112 +3747,124 @@ s32 ixgbe_set_vfta_generic(struct ixgbe_hw *hw, u32 vlan, u32 vind,
 	 *    bits[11-5]: which register
 	 *    bits[4-0]:  which bit in the register
 	 */
-	regindex = (vlan >> 5) & 0x7F;
-	bitindex = vlan & 0x1F;
-	targetbit = (1 << bitindex);
-	vfta = IXGBE_READ_REG(hw, IXGBE_VFTA(regindex));
-
-	if (vlan_on) {
-		if (!(vfta & targetbit)) {
-			vfta |= targetbit;
-			vfta_changed = true;
-		}
-	} else {
-		if ((vfta & targetbit)) {
-			vfta &= ~targetbit;
-			vfta_changed = true;
-		}
-	}
+	regidx = vlan / 32;
+	vfta_delta = 1 << (vlan % 32);
+	vfta = IXGBE_READ_REG(hw, IXGBE_VFTA(regidx));
+
+	/*
+	 * vfta_delta represents the difference between the current value
+	 * of vfta and the value we want in the register.  Since the diff
+	 * is an XOR mask we can just update the vfta using an XOR
+	 */
+	vfta_delta &= vlan_on ? ~vfta : vfta;
+	vfta ^= vfta_delta;
 
 	/* Part 2
-	 * If VT Mode is set
+	 * Call ixgbe_set_vlvf_generic to set VLVFB and VLVF
+	 */
+	ret_val = ixgbe_set_vlvf_generic(hw, vlan, vind, vlan_on, &vfta_delta,
+					 vfta, vlvf_bypass);
+	if (ret_val != IXGBE_SUCCESS) {
+		if (vlvf_bypass)
+			goto vfta_update;
+		return ret_val;
+	}
+
+vfta_update:
+	/* Update VFTA now that we are ready for traffic */
+	if (vfta_delta)
+		IXGBE_WRITE_REG(hw, IXGBE_VFTA(regidx), vfta);
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_set_vlvf_generic - Set VLAN Pool Filter
+ *  @hw: pointer to hardware structure
+ *  @vlan: VLAN id to write to VLAN filter
+ *  @vind: VMDq output index that maps queue to VLAN id in VLVFB
+ *  @vlan_on: boolean flag to turn on/off VLAN in VLVF
+ *  @vfta_delta: pointer to the difference between the current value of VFTA
+ *		 and the desired value
+ *  @vfta: the desired value of the VFTA
+ *  @vlvf_bypass: boolean flag indicating updating default pool is okay
+ *
+ *  Turn on/off specified bit in VLVF table.
+ **/
+s32 ixgbe_set_vlvf_generic(struct ixgbe_hw *hw, u32 vlan, u32 vind,
+			   bool vlan_on, u32 *vfta_delta, u32 vfta,
+			   bool vlvf_bypass)
+{
+	u32 bits;
+	s32 vlvf_index;
+
+	DEBUGFUNC("ixgbe_set_vlvf_generic");
+
+	if (vlan > 4095 || vind > 63)
+		return IXGBE_ERR_PARAM;
+
+	/* If VT Mode is set
 	 *   Either vlan_on
 	 *     make sure the vlan is in VLVF
 	 *     set the vind bit in the matching VLVFB
 	 *   Or !vlan_on
 	 *     clear the pool bit and possibly the vind
 	 */
-	vt = IXGBE_READ_REG(hw, IXGBE_VT_CTL);
-	if (vt & IXGBE_VT_CTL_VT_ENABLE) {
-		s32 vlvf_index;
-
-		vlvf_index = ixgbe_find_vlvf_slot(hw, vlan);
-		if (vlvf_index < 0)
-			return vlvf_index;
-
-		if (vlan_on) {
-			/* set the pool bit */
-			if (vind < 32) {
-				bits = IXGBE_READ_REG(hw,
-						IXGBE_VLVFB(vlvf_index*2));
-				bits |= (1 << vind);
-				IXGBE_WRITE_REG(hw,
-						IXGBE_VLVFB(vlvf_index*2),
-						bits);
-			} else {
-				bits = IXGBE_READ_REG(hw,
-						IXGBE_VLVFB((vlvf_index*2)+1));
-				bits |= (1 << (vind-32));
-				IXGBE_WRITE_REG(hw,
-						IXGBE_VLVFB((vlvf_index*2)+1),
-						bits);
-			}
-		} else {
-			/* clear the pool bit */
-			if (vind < 32) {
-				bits = IXGBE_READ_REG(hw,
-						IXGBE_VLVFB(vlvf_index*2));
-				bits &= ~(1 << vind);
-				IXGBE_WRITE_REG(hw,
-						IXGBE_VLVFB(vlvf_index*2),
-						bits);
-				bits |= IXGBE_READ_REG(hw,
-						IXGBE_VLVFB((vlvf_index*2)+1));
-			} else {
-				bits = IXGBE_READ_REG(hw,
-						IXGBE_VLVFB((vlvf_index*2)+1));
-				bits &= ~(1 << (vind-32));
-				IXGBE_WRITE_REG(hw,
-						IXGBE_VLVFB((vlvf_index*2)+1),
-						bits);
-				bits |= IXGBE_READ_REG(hw,
-						IXGBE_VLVFB(vlvf_index*2));
-			}
-		}
+	if (!(IXGBE_READ_REG(hw, IXGBE_VT_CTL) & IXGBE_VT_CTL_VT_ENABLE))
+		return IXGBE_SUCCESS;
 
-		/*
-		 * If there are still bits set in the VLVFB registers
-		 * for the VLAN ID indicated we need to see if the
-		 * caller is requesting that we clear the VFTA entry bit.
-		 * If the caller has requested that we clear the VFTA
-		 * entry bit but there are still pools/VFs using this VLAN
-		 * ID entry then ignore the request.  We're not worried
-		 * about the case where we're turning the VFTA VLAN ID
-		 * entry bit on, only when requested to turn it off as
-		 * there may be multiple pools and/or VFs using the
-		 * VLAN ID entry.  In that case we cannot clear the
-		 * VFTA bit until all pools/VFs using that VLAN ID have also
-		 * been cleared.  This will be indicated by "bits" being
-		 * zero.
+	vlvf_index = ixgbe_find_vlvf_slot(hw, vlan, vlvf_bypass);
+	if (vlvf_index < 0)
+		return vlvf_index;
+
+	bits = IXGBE_READ_REG(hw, IXGBE_VLVFB(vlvf_index * 2 + vind / 32));
+
+	/* set the pool bit */
+	bits |= 1 << (vind % 32);
+	if (vlan_on)
+		goto vlvf_update;
+
+	/* clear the pool bit */
+	bits ^= 1 << (vind % 32);
+
+	if (!bits &&
+	    !IXGBE_READ_REG(hw, IXGBE_VLVFB(vlvf_index * 2 + 1 - vind / 32))) {
+		/* Clear VFTA first, then disable VLVF.  Otherwise
+		 * we run the risk of stray packets leaking into
+		 * the PF via the default pool
 		 */
-		if (bits) {
-			IXGBE_WRITE_REG(hw, IXGBE_VLVF(vlvf_index),
-					(IXGBE_VLVF_VIEN | vlan));
-			if (!vlan_on) {
-				/* someone wants to clear the vfta entry
-				 * but some pools/VFs are still using it.
-				 * Ignore it. */
-				vfta_changed = false;
-			}
-		} else {
-			IXGBE_WRITE_REG(hw, IXGBE_VLVF(vlvf_index), 0);
-		}
+		if (*vfta_delta)
+			IXGBE_WRITE_REG(hw, IXGBE_VFTA(vlan / 32), vfta);
+
+		/* disable VLVF and clear remaining bit from pool */
+		IXGBE_WRITE_REG(hw, IXGBE_VLVF(vlvf_index), 0);
+		IXGBE_WRITE_REG(hw, IXGBE_VLVFB(vlvf_index * 2 + vind / 32), 0);
+
+		return IXGBE_SUCCESS;
 	}
 
-	if (vfta_changed)
-		IXGBE_WRITE_REG(hw, IXGBE_VFTA(regindex), vfta);
+	/* If there are still bits set in the VLVFB registers
+	 * for the VLAN ID indicated we need to see if the
+	 * caller is requesting that we clear the VFTA entry bit.
+	 * If the caller has requested that we clear the VFTA
+	 * entry bit but there are still pools/VFs using this VLAN
+	 * ID entry then ignore the request.  We're not worried
+	 * about the case where we're turning the VFTA VLAN ID
+	 * entry bit on, only when requested to turn it off as
+	 * there may be multiple pools and/or VFs using the
+	 * VLAN ID entry.  In that case we cannot clear the
+	 * VFTA bit until all pools/VFs using that VLAN ID have also
+	 * been cleared.  This will be indicated by "bits" being
+	 * zero.
+	 */
+	*vfta_delta = 0;
+
+vlvf_update:
+	/* record pool change and enable VLAN ID if not already enabled */
+	IXGBE_WRITE_REG(hw, IXGBE_VLVFB(vlvf_index * 2 + vind / 32), bits);
+	IXGBE_WRITE_REG(hw, IXGBE_VLVF(vlvf_index), IXGBE_VLVF_VIEN | vlan);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -3179,16 +3877,44 @@ s32 ixgbe_clear_vfta_generic(struct ixgbe_hw *hw)
 {
 	u32 offset;
 
+	DEBUGFUNC("ixgbe_clear_vfta_generic");
+
 	for (offset = 0; offset < hw->mac.vft_size; offset++)
 		IXGBE_WRITE_REG(hw, IXGBE_VFTA(offset), 0);
 
 	for (offset = 0; offset < IXGBE_VLVF_ENTRIES; offset++) {
 		IXGBE_WRITE_REG(hw, IXGBE_VLVF(offset), 0);
-		IXGBE_WRITE_REG(hw, IXGBE_VLVFB(offset*2), 0);
-		IXGBE_WRITE_REG(hw, IXGBE_VLVFB((offset*2)+1), 0);
+		IXGBE_WRITE_REG(hw, IXGBE_VLVFB(offset * 2), 0);
+		IXGBE_WRITE_REG(hw, IXGBE_VLVFB(offset * 2 + 1), 0);
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_need_crosstalk_fix - Determine if we need to do cross talk fix
+ *  @hw: pointer to hardware structure
+ *
+ *  Contains the logic to identify if we need to verify link for the
+ *  crosstalk fix
+ **/
+static bool ixgbe_need_crosstalk_fix(struct ixgbe_hw *hw)
+{
+
+	/* Does FW say we need the fix */
+	if (!hw->need_crosstalk_fix)
+		return false;
+
+	/* Only consider SFP+ PHYs i.e. media type fiber */
+	switch (hw->mac.ops.get_media_type(hw)) {
+	case ixgbe_media_type_fiber:
+	case ixgbe_media_type_fiber_qsfp:
+		break;
+	default:
+		return false;
+	}
+
+	return true;
 }
 
 /**
@@ -3206,25 +3932,56 @@ s32 ixgbe_check_mac_link_generic(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
 	u32 links_reg, links_orig;
 	u32 i;
 
+	DEBUGFUNC("ixgbe_check_mac_link_generic");
+
+	/* If Crosstalk fix enabled do the sanity check of making sure
+	 * the SFP+ cage is full.
+	 */
+	if (ixgbe_need_crosstalk_fix(hw)) {
+		u32 sfp_cage_full;
+
+		switch (hw->mac.type) {
+		case ixgbe_mac_82599EB:
+			sfp_cage_full = IXGBE_READ_REG(hw, IXGBE_ESDP) &
+					IXGBE_ESDP_SDP2;
+			break;
+		case ixgbe_mac_X550EM_x:
+		case ixgbe_mac_X550EM_a:
+			sfp_cage_full = IXGBE_READ_REG(hw, IXGBE_ESDP) &
+					IXGBE_ESDP_SDP0;
+			break;
+		default:
+			/* sanity check - No SFP+ devices here */
+			sfp_cage_full = false;
+			break;
+		}
+
+		if (!sfp_cage_full) {
+			*link_up = false;
+			*speed = IXGBE_LINK_SPEED_UNKNOWN;
+			return IXGBE_SUCCESS;
+		}
+	}
+
 	/* clear the old state */
 	links_orig = IXGBE_READ_REG(hw, IXGBE_LINKS);
 
 	links_reg = IXGBE_READ_REG(hw, IXGBE_LINKS);
 
 	if (links_orig != links_reg) {
-		hw_dbg(hw, "LINKS changed from %08X to %08X\n",
-		       links_orig, links_reg);
+		DEBUGOUT2("LINKS changed from %08X to %08X\n",
+			  links_orig, links_reg);
 	}
 
 	if (link_up_wait_to_complete) {
-		for (i = 0; i < IXGBE_LINK_UP_TIME; i++) {
+		for (i = 0; i < hw->mac.max_link_up_time; i++) {
 			if (links_reg & IXGBE_LINKS_UP) {
 				*link_up = true;
 				break;
 			} else {
 				*link_up = false;
 			}
-			msleep(100);
+			msec_delay(100);
 			links_reg = IXGBE_READ_REG(hw, IXGBE_LINKS);
 		}
 	} else {
@@ -3236,27 +3993,33 @@ s32 ixgbe_check_mac_link_generic(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
 
 	switch (links_reg & IXGBE_LINKS_SPEED_82599) {
 	case IXGBE_LINKS_SPEED_10G_82599:
-		if ((hw->mac.type >= ixgbe_mac_X550) &&
-		    (links_reg & IXGBE_LINKS_SPEED_NON_STD))
-			*speed = IXGBE_LINK_SPEED_2_5GB_FULL;
-		else
-			*speed = IXGBE_LINK_SPEED_10GB_FULL;
+		*speed = IXGBE_LINK_SPEED_10GB_FULL;
+		if (hw->mac.type >= ixgbe_mac_X550) {
+			if (links_reg & IXGBE_LINKS_SPEED_NON_STD)
+				*speed = IXGBE_LINK_SPEED_2_5GB_FULL;
+		}
 		break;
 	case IXGBE_LINKS_SPEED_1G_82599:
 		*speed = IXGBE_LINK_SPEED_1GB_FULL;
 		break;
 	case IXGBE_LINKS_SPEED_100_82599:
-		if ((hw->mac.type >= ixgbe_mac_X550) &&
-		    (links_reg & IXGBE_LINKS_SPEED_NON_STD))
-			*speed = IXGBE_LINK_SPEED_5GB_FULL;
-		else
-			*speed = IXGBE_LINK_SPEED_100_FULL;
+		*speed = IXGBE_LINK_SPEED_100_FULL;
+		if (hw->mac.type == ixgbe_mac_X550) {
+			if (links_reg & IXGBE_LINKS_SPEED_NON_STD)
+				*speed = IXGBE_LINK_SPEED_5GB_FULL;
+		}
+		break;
+	case IXGBE_LINKS_SPEED_10_X550EM_A:
+		*speed = IXGBE_LINK_SPEED_UNKNOWN;
+		if (hw->device_id == IXGBE_DEV_ID_X550EM_A_1G_T ||
+		    hw->device_id == IXGBE_DEV_ID_X550EM_A_1G_T_L)
+			*speed = IXGBE_LINK_SPEED_10_FULL;
 		break;
 	default:
 		*speed = IXGBE_LINK_SPEED_UNKNOWN;
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -3270,11 +4033,13 @@ s32 ixgbe_check_mac_link_generic(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
  *  block to check the support for the alternative WWNN/WWPN prefix support.
  **/
 s32 ixgbe_get_wwn_prefix_generic(struct ixgbe_hw *hw, u16 *wwnn_prefix,
-					u16 *wwpn_prefix)
+				 u16 *wwpn_prefix)
 {
 	u16 offset, caps;
 	u16 alt_san_mac_blk_offset;
 
+	DEBUGFUNC("ixgbe_get_wwn_prefix_generic");
+
 	/* clear output first */
 	*wwnn_prefix = 0xFFFF;
 	*wwpn_prefix = 0xFFFF;
@@ -3286,78 +4051,113 @@ s32 ixgbe_get_wwn_prefix_generic(struct ixgbe_hw *hw, u16 *wwnn_prefix,
 
 	if ((alt_san_mac_blk_offset == 0) ||
 	    (alt_san_mac_blk_offset == 0xFFFF))
-		return 0;
+		goto wwn_prefix_out;
 
 	/* check capability in alternative san mac address block */
 	offset = alt_san_mac_blk_offset + IXGBE_ALT_SAN_MAC_ADDR_CAPS_OFFSET;
 	if (hw->eeprom.ops.read(hw, offset, &caps))
 		goto wwn_prefix_err;
 	if (!(caps & IXGBE_ALT_SAN_MAC_ADDR_CAPS_ALTWWN))
-		return 0;
+		goto wwn_prefix_out;
 
 	/* get the corresponding prefix for WWNN/WWPN */
 	offset = alt_san_mac_blk_offset + IXGBE_ALT_SAN_MAC_ADDR_WWNN_OFFSET;
-	if (hw->eeprom.ops.read(hw, offset, wwnn_prefix))
-		hw_err(hw, "eeprom read at offset %d failed\n", offset);
+	if (hw->eeprom.ops.read(hw, offset, wwnn_prefix)) {
+		ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+			      "eeprom read at offset %d failed", offset);
+	}
 
 	offset = alt_san_mac_blk_offset + IXGBE_ALT_SAN_MAC_ADDR_WWPN_OFFSET;
 	if (hw->eeprom.ops.read(hw, offset, wwpn_prefix))
 		goto wwn_prefix_err;
 
-	return 0;
+wwn_prefix_out:
+	return IXGBE_SUCCESS;
 
 wwn_prefix_err:
-	hw_err(hw, "eeprom read at offset %d failed\n", offset);
-	return 0;
+	ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+		      "eeprom read at offset %d failed", offset);
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_get_fcoe_boot_status_generic - Get FCOE boot status from EEPROM
+ *  @hw: pointer to hardware structure
+ *  @bs: the fcoe boot status
+ *
+ *  This function will read the FCOE boot status from the iSCSI FCOE block
+ **/
+s32 ixgbe_get_fcoe_boot_status_generic(struct ixgbe_hw *hw, u16 *bs)
+{
+	u16 offset, caps, flags;
+	s32 status;
+
+	DEBUGFUNC("ixgbe_get_fcoe_boot_status_generic");
+
+	/* clear output first */
+	*bs = ixgbe_fcoe_bootstatus_unavailable;
+
+	/* check if FCOE IBA block is present */
+	offset = IXGBE_FCOE_IBA_CAPS_BLK_PTR;
+	status = hw->eeprom.ops.read(hw, offset, &caps);
+	if (status != IXGBE_SUCCESS)
+		goto out;
+
+	if (!(caps & IXGBE_FCOE_IBA_CAPS_FCOE))
+		goto out;
+
+	/* check if iSCSI FCOE block is populated */
+	status = hw->eeprom.ops.read(hw, IXGBE_ISCSI_FCOE_BLK_PTR, &offset);
+	if (status != IXGBE_SUCCESS)
+		goto out;
+
+	if ((offset == 0) || (offset == 0xFFFF))
+		goto out;
+
+	/* read fcoe flags in iSCSI FCOE block */
+	offset = offset + IXGBE_ISCSI_FCOE_FLAGS_OFFSET;
+	status = hw->eeprom.ops.read(hw, offset, &flags);
+	if (status != IXGBE_SUCCESS)
+		goto out;
+
+	if (flags & IXGBE_ISCSI_FCOE_FLAGS_ENABLE)
+		*bs = ixgbe_fcoe_bootstatus_enabled;
+	else
+		*bs = ixgbe_fcoe_bootstatus_disabled;
+
+out:
+	return status;
 }
 
 /**
  *  ixgbe_set_mac_anti_spoofing - Enable/Disable MAC anti-spoofing
  *  @hw: pointer to hardware structure
- *  @enable: enable or disable switch for anti-spoofing
- *  @pf: Physical Function pool - do not enable anti-spoofing for the PF
+ *  @enable: enable or disable switch for MAC anti-spoofing
+ *  @vf: Virtual Function pool - VF Pool to set for MAC anti-spoofing
  *
  **/
-void ixgbe_set_mac_anti_spoofing(struct ixgbe_hw *hw, bool enable, int pf)
+void ixgbe_set_mac_anti_spoofing(struct ixgbe_hw *hw, bool enable, int vf)
 {
-	int j;
-	int pf_target_reg = pf >> 3;
-	int pf_target_shift = pf % 8;
-	u32 pfvfspoof = 0;
+	int vf_target_reg = vf >> 3;
+	int vf_target_shift = vf % 8;
+	u32 pfvfspoof;
 
 	if (hw->mac.type == ixgbe_mac_82598EB)
 		return;
 
+	pfvfspoof = IXGBE_READ_REG(hw, IXGBE_PFVFSPOOF(vf_target_reg));
 	if (enable)
-		pfvfspoof = IXGBE_SPOOF_MACAS_MASK;
-
-	/*
-	 * PFVFSPOOF register array is size 8 with 8 bits assigned to
-	 * MAC anti-spoof enables in each register array element.
-	 */
-	for (j = 0; j < pf_target_reg; j++)
-		IXGBE_WRITE_REG(hw, IXGBE_PFVFSPOOF(j), pfvfspoof);
-
-	/*
-	 * The PF should be allowed to spoof so that it can support
-	 * emulation mode NICs.  Do not set the bits assigned to the PF
-	 */
-	pfvfspoof &= (1 << pf_target_shift) - 1;
-	IXGBE_WRITE_REG(hw, IXGBE_PFVFSPOOF(j), pfvfspoof);
-
-	/*
-	 * Remaining pools belong to the PF so they do not need to have
-	 * anti-spoofing enabled.
-	 */
-	for (j++; j < IXGBE_PFVFSPOOF_REG_COUNT; j++)
-		IXGBE_WRITE_REG(hw, IXGBE_PFVFSPOOF(j), 0);
+		pfvfspoof |= (1 << vf_target_shift);
+	else
+		pfvfspoof &= ~(1 << vf_target_shift);
+	IXGBE_WRITE_REG(hw, IXGBE_PFVFSPOOF(vf_target_reg), pfvfspoof);
 }
 
 /**
  *  ixgbe_set_vlan_anti_spoofing - Enable/Disable VLAN anti-spoofing
  *  @hw: pointer to hardware structure
  *  @enable: enable or disable switch for VLAN anti-spoofing
- *  @pf: Virtual Function pool - VF Pool to set for VLAN anti-spoofing
+ *  @vf: Virtual Function pool - VF Pool to set for VLAN anti-spoofing
  *
  **/
 void ixgbe_set_vlan_anti_spoofing(struct ixgbe_hw *hw, bool enable, int vf)
@@ -3387,90 +4187,27 @@ void ixgbe_set_vlan_anti_spoofing(struct ixgbe_hw *hw, bool enable, int vf)
  **/
 s32 ixgbe_get_device_caps_generic(struct ixgbe_hw *hw, u16 *device_caps)
 {
-	hw->eeprom.ops.read(hw, IXGBE_DEVICE_CAPS, device_caps);
-
-	return 0;
-}
-
-/**
- * ixgbe_set_rxpba_generic - Initialize RX packet buffer
- * @hw: pointer to hardware structure
- * @num_pb: number of packet buffers to allocate
- * @headroom: reserve n KB of headroom
- * @strategy: packet buffer allocation strategy
- **/
-void ixgbe_set_rxpba_generic(struct ixgbe_hw *hw,
-			     int num_pb,
-			     u32 headroom,
-			     int strategy)
-{
-	u32 pbsize = hw->mac.rx_pb_size;
-	int i = 0;
-	u32 rxpktsize, txpktsize, txpbthresh;
-
-	/* Reserve headroom */
-	pbsize -= headroom;
-
-	if (!num_pb)
-		num_pb = 1;
+	DEBUGFUNC("ixgbe_get_device_caps_generic");
 
-	/* Divide remaining packet buffer space amongst the number
-	 * of packet buffers requested using supplied strategy.
-	 */
-	switch (strategy) {
-	case (PBA_STRATEGY_WEIGHTED):
-		/* pba_80_48 strategy weight first half of packet buffer with
-		 * 5/8 of the packet buffer space.
-		 */
-		rxpktsize = ((pbsize * 5 * 2) / (num_pb * 8));
-		pbsize -= rxpktsize * (num_pb / 2);
-		rxpktsize <<= IXGBE_RXPBSIZE_SHIFT;
-		for (; i < (num_pb / 2); i++)
-			IXGBE_WRITE_REG(hw, IXGBE_RXPBSIZE(i), rxpktsize);
-		/* Fall through to configure remaining packet buffers */
-	case (PBA_STRATEGY_EQUAL):
-		/* Divide the remaining Rx packet buffer evenly among the TCs */
-		rxpktsize = (pbsize / (num_pb - i)) << IXGBE_RXPBSIZE_SHIFT;
-		for (; i < num_pb; i++)
-			IXGBE_WRITE_REG(hw, IXGBE_RXPBSIZE(i), rxpktsize);
-		break;
-	default:
-		break;
-	}
-
-	/*
-	 * Setup Tx packet buffer and threshold equally for all TCs
-	 * TXPBTHRESH register is set in K so divide by 1024 and subtract
-	 * 10 since the largest packet we support is just over 9K.
-	 */
-	txpktsize = IXGBE_TXPBSIZE_MAX / num_pb;
-	txpbthresh = (txpktsize / 1024) - IXGBE_TXPKT_SIZE_MAX;
-	for (i = 0; i < num_pb; i++) {
-		IXGBE_WRITE_REG(hw, IXGBE_TXPBSIZE(i), txpktsize);
-		IXGBE_WRITE_REG(hw, IXGBE_TXPBTHRESH(i), txpbthresh);
-	}
+	hw->eeprom.ops.read(hw, IXGBE_DEVICE_CAPS, device_caps);
 
-	/* Clear unused TCs, if any, to zero buffer size*/
-	for (; i < IXGBE_MAX_PB; i++) {
-		IXGBE_WRITE_REG(hw, IXGBE_RXPBSIZE(i), 0);
-		IXGBE_WRITE_REG(hw, IXGBE_TXPBSIZE(i), 0);
-		IXGBE_WRITE_REG(hw, IXGBE_TXPBTHRESH(i), 0);
-	}
+	return IXGBE_SUCCESS;
 }
 
 /**
  *  ixgbe_calculate_checksum - Calculate checksum for buffer
  *  @buffer: pointer to EEPROM
  *  @length: size of EEPROM to calculate a checksum for
- *
  *  Calculates the checksum for some buffer on a specified length.  The
  *  checksum calculated is returned.
  **/
-static u8 ixgbe_calculate_checksum(u8 *buffer, u32 length)
+u8 ixgbe_calculate_checksum(u8 *buffer, u32 length)
 {
 	u32 i;
 	u8 sum = 0;
 
+	DEBUGFUNC("ixgbe_calculate_checksum");
+
 	if (!buffer)
 		return 0;
 
@@ -3481,32 +4218,29 @@ static u8 ixgbe_calculate_checksum(u8 *buffer, u32 length)
 }
 
 /**
- *  ixgbe_host_interface_command - Issue command to manageability block
+ *  ixgbe_hic_unlocked - Issue command to manageability block unlocked
  *  @hw: pointer to the HW structure
- *  @buffer: contains the command to write and where the return status will
- *           be placed
+ *  @buffer: command to write and where the return status will be placed
  *  @length: length of buffer, must be multiple of 4 bytes
  *  @timeout: time in ms to wait for command completion
- *  @return_data: read and return data from the buffer (true) or not (false)
- *  Needed because FW structures are big endian and decoding of
- *  these fields can be 8 bit or 16 bit based on command. Decoding
- *  is not easily understood without making a table of commands.
- *  So we will leave this up to the caller to read back the data
- *  in these cases.
  *
- *  Communicates with the manageability block.  On success return 0
- *  else return IXGBE_ERR_HOST_INTERFACE_COMMAND.
+ *  Communicates with the manageability block. On success return IXGBE_SUCCESS
+ *  else returns semaphore error when encountering an error acquiring
+ *  semaphore or IXGBE_ERR_HOST_INTERFACE_COMMAND when command fails.
+ *
+ *  This function assumes that the IXGBE_GSSR_SW_MNG_SM semaphore is held
+ *  by the caller.
  **/
-s32 ixgbe_host_interface_command(struct ixgbe_hw *hw, u32 *buffer,
-				 u32 length, u32 timeout,
-				 bool return_data)
+s32 ixgbe_hic_unlocked(struct ixgbe_hw *hw, u32 *buffer, u32 length,
+		       u32 timeout)
 {
-	u32 hicr, i, bi, fwsts;
-	u32 hdr_size = sizeof(struct ixgbe_hic_hdr);
-	u16 buf_len, dword_len;
+	u32 hicr, i, fwsts;
+	u16 dword_len;
 
-	if (length == 0 || length > IXGBE_HI_MAX_BLOCK_BYTE_LENGTH) {
-		hw_dbg(hw, "Buffer length failure buffersize-%d.\n", length);
+	DEBUGFUNC("ixgbe_hic_unlocked");
+
+	if (!length || length > IXGBE_HI_MAX_BLOCK_BYTE_LENGTH) {
+		DEBUGOUT1("Buffer length failure buffersize=%d.\n", length);
 		return IXGBE_ERR_HOST_INTERFACE_COMMAND;
 	}
 
@@ -3516,26 +4250,25 @@ s32 ixgbe_host_interface_command(struct ixgbe_hw *hw, u32 *buffer,
 
 	/* Check that the host interface is enabled. */
 	hicr = IXGBE_READ_REG(hw, IXGBE_HICR);
-	if ((hicr & IXGBE_HICR_EN) == 0) {
-		hw_dbg(hw, "IXGBE_HOST_EN bit disabled.\n");
+	if (!(hicr & IXGBE_HICR_EN)) {
+		DEBUGOUT("IXGBE_HOST_EN bit disabled.\n");
 		return IXGBE_ERR_HOST_INTERFACE_COMMAND;
 	}
 
 	/* Calculate length in DWORDs. We must be DWORD aligned */
-	if ((length % (sizeof(u32))) != 0) {
-		hw_dbg(hw, "Buffer length failure, not aligned to dword");
+	if (length % sizeof(u32)) {
+		DEBUGOUT("Buffer length failure, not aligned to dword");
 		return IXGBE_ERR_INVALID_ARGUMENT;
 	}
 
 	dword_len = length >> 2;
 
-	/*
-	 * The device driver writes the relevant command block
+	/* The device driver writes the relevant command block
 	 * into the ram area.
 	 */
 	for (i = 0; i < dword_len; i++)
 		IXGBE_WRITE_REG_ARRAY(hw, IXGBE_FLEX_MNG,
-				      i, cpu_to_le32(buffer[i]));
+				      i, IXGBE_CPU_TO_LE32(buffer[i]));
 
 	/* Setting this bit tells the ARC that a new command is pending. */
 	IXGBE_WRITE_REG(hw, IXGBE_HICR, hicr | IXGBE_HICR_C);
@@ -3544,18 +4277,65 @@ s32 ixgbe_host_interface_command(struct ixgbe_hw *hw, u32 *buffer,
 		hicr = IXGBE_READ_REG(hw, IXGBE_HICR);
 		if (!(hicr & IXGBE_HICR_C))
 			break;
-		usleep_range(1000, 2000);
+		msec_delay(1);
 	}
 
-	/* Check command successful completion. */
-	if ((timeout != 0 && i == timeout) ||
-	    (!(IXGBE_READ_REG(hw, IXGBE_HICR) & IXGBE_HICR_SV))) {
-		hw_dbg(hw, "Command has failed with no status valid.\n");
+	/* Check command completion */
+	if ((timeout && i == timeout) ||
+	    !(IXGBE_READ_REG(hw, IXGBE_HICR) & IXGBE_HICR_SV)) {
+		ERROR_REPORT1(IXGBE_ERROR_CAUTION,
+			     "Command has failed with no status valid.\n");
+		return IXGBE_ERR_HOST_INTERFACE_COMMAND;
+	}
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_host_interface_command - Issue command to manageability block
+ *  @hw: pointer to the HW structure
+ *  @buffer: contains the command to write and where the return status will
+ *   be placed
+ *  @length: length of buffer, must be multiple of 4 bytes
+ *  @timeout: time in ms to wait for command completion
+ *  @return_data: read and return data from the buffer (true) or not (false)
+ *   Needed because FW structures are big endian and decoding of
+ *   these fields can be 8 bit or 16 bit based on command. Decoding
+ *   is not easily understood without making a table of commands.
+ *   So we will leave this up to the caller to read back the data
+ *   in these cases.
+ *
+ *  Communicates with the manageability block. On success return IXGBE_SUCCESS
+ *  else returns semaphore error when encountering an error acquiring
+ *  semaphore or IXGBE_ERR_HOST_INTERFACE_COMMAND when command fails.
+ **/
+s32 ixgbe_host_interface_command(struct ixgbe_hw *hw, u32 *buffer,
+				 u32 length, u32 timeout, bool return_data)
+{
+	u32 hdr_size = sizeof(struct ixgbe_hic_hdr);
+	u16 dword_len;
+	u16 buf_len;
+	s32 status;
+	u32 bi;
+
+	DEBUGFUNC("ixgbe_host_interface_command");
+
+	if (length == 0 || length > IXGBE_HI_MAX_BLOCK_BYTE_LENGTH) {
+		DEBUGOUT1("Buffer length failure buffersize=%d.\n", length);
 		return IXGBE_ERR_HOST_INTERFACE_COMMAND;
 	}
 
+	/* Take management host interface semaphore */
+	status = hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_SW_MNG_SM);
+	if (status)
+		return status;
+
+	status = ixgbe_hic_unlocked(hw, buffer, length, timeout);
+	if (status)
+		goto rel_out;
+
 	if (!return_data)
-		return 0;
+		goto rel_out;
 
 	/* Calculate length in DWORDs */
 	dword_len = hdr_size >> 2;
@@ -3563,29 +4343,33 @@ s32 ixgbe_host_interface_command(struct ixgbe_hw *hw, u32 *buffer,
 	/* first pull in the header so we know the buffer length */
 	for (bi = 0; bi < dword_len; bi++) {
 		buffer[bi] = IXGBE_READ_REG_ARRAY(hw, IXGBE_FLEX_MNG, bi);
-		le32_to_cpus(&buffer[bi]);
+		IXGBE_LE32_TO_CPUS(&buffer[bi]);
 	}
 
 	/* If there is any thing in data position pull it in */
 	buf_len = ((struct ixgbe_hic_hdr *)buffer)->buf_len;
-	if (buf_len == 0)
-		return 0;
+	if (!buf_len)
+		goto rel_out;
 
-	if (length < (buf_len + hdr_size)) {
-		hw_dbg(hw, "Buffer not large enough for reply message.\n");
-		return IXGBE_ERR_HOST_INTERFACE_COMMAND;
+	if (length < buf_len + hdr_size) {
+		DEBUGOUT("Buffer not large enough for reply message.\n");
+		status = IXGBE_ERR_HOST_INTERFACE_COMMAND;
+		goto rel_out;
 	}
 
 	/* Calculate length in DWORDs, add 3 for odd lengths */
 	dword_len = (buf_len + 3) >> 2;
 
-	/* Pull in the rest of the buffer (bi is where we left off)*/
+	/* Pull in the rest of the buffer (bi is where we left off) */
 	for (; bi <= dword_len; bi++) {
 		buffer[bi] = IXGBE_READ_REG_ARRAY(hw, IXGBE_FLEX_MNG, bi);
-		le32_to_cpus(&buffer[bi]);
+		IXGBE_LE32_TO_CPUS(&buffer[bi]);
 	}
 
-	return 0;
+rel_out:
+	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_SW_MNG_SM);
+
+	return status;
 }
 
 /**
@@ -3597,19 +4381,20 @@ s32 ixgbe_host_interface_command(struct ixgbe_hw *hw, u32 *buffer,
  *  @sub: driver version sub build number
  *
  *  Sends driver version number to firmware through the manageability
- *  block.  On success return 0
+ *  block.  On success return IXGBE_SUCCESS
  *  else returns IXGBE_ERR_SWFW_SYNC when encountering an error acquiring
  *  semaphore or IXGBE_ERR_HOST_INTERFACE_COMMAND when command fails.
  **/
 s32 ixgbe_set_fw_drv_ver_generic(struct ixgbe_hw *hw, u8 maj, u8 min,
-				 u8 build, u8 sub)
+				 u8 build, u8 sub, u16 len,
+				 const char *driver_ver)
 {
 	struct ixgbe_hic_drv_info fw_cmd;
 	int i;
-	s32 ret_val;
+	s32 ret_val = IXGBE_SUCCESS;
 
-	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_SW_MNG_SM))
-		return IXGBE_ERR_SWFW_SYNC;
+	DEBUGFUNC("ixgbe_set_fw_drv_ver_generic");
+	UNREFERENCED_2PARAMETER(len, driver_ver);
 
 	fw_cmd.hdr.cmd = FW_CEM_CMD_DRIVER_INFO;
 	fw_cmd.hdr.buf_len = FW_CEM_CMD_DRIVER_INFO_LEN;
@@ -3630,23 +4415,81 @@ s32 ixgbe_set_fw_drv_ver_generic(struct ixgbe_hw *hw, u8 maj, u8 min,
 						       sizeof(fw_cmd),
 						       IXGBE_HI_COMMAND_TIMEOUT,
 						       true);
-		if (ret_val != 0)
+		if (ret_val != IXGBE_SUCCESS)
 			continue;
 
 		if (fw_cmd.hdr.cmd_or_resp.ret_status ==
 		    FW_CEM_RESP_STATUS_SUCCESS)
-			ret_val = 0;
+			ret_val = IXGBE_SUCCESS;
 		else
 			ret_val = IXGBE_ERR_HOST_INTERFACE_COMMAND;
 
 		break;
 	}
 
-	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_SW_MNG_SM);
 	return ret_val;
 }
 
 /**
+ * ixgbe_set_rxpba_generic - Initialize Rx packet buffer
+ * @hw: pointer to hardware structure
+ * @num_pb: number of packet buffers to allocate
+ * @headroom: reserve n KB of headroom
+ * @strategy: packet buffer allocation strategy
+ **/
+void ixgbe_set_rxpba_generic(struct ixgbe_hw *hw, int num_pb, u32 headroom,
+			     int strategy)
+{
+	u32 pbsize = hw->mac.rx_pb_size;
+	int i = 0;
+	u32 rxpktsize, txpktsize, txpbthresh;
+
+	/* Reserve headroom */
+	pbsize -= headroom;
+
+	if (!num_pb)
+		num_pb = 1;
+
+	/* Divide remaining packet buffer space amongst the number of packet
+	 * buffers requested using supplied strategy.
+	 */
+	switch (strategy) {
+	case PBA_STRATEGY_WEIGHTED:
+		/* ixgbe_dcb_pba_80_48 strategy weight first half of packet
+		 * buffer with 5/8 of the packet buffer space.
+		 */
+		rxpktsize = (pbsize * 5) / (num_pb * 4);
+		pbsize -= rxpktsize * (num_pb / 2);
+		rxpktsize <<= IXGBE_RXPBSIZE_SHIFT;
+		for (; i < (num_pb / 2); i++)
+			IXGBE_WRITE_REG(hw, IXGBE_RXPBSIZE(i), rxpktsize);
+		/* fall through - configure remaining packet buffers */
+	case PBA_STRATEGY_EQUAL:
+		rxpktsize = (pbsize / (num_pb - i)) << IXGBE_RXPBSIZE_SHIFT;
+		for (; i < num_pb; i++)
+			IXGBE_WRITE_REG(hw, IXGBE_RXPBSIZE(i), rxpktsize);
+		break;
+	default:
+		break;
+	}
+
+	/* Only support an equally distributed Tx packet buffer strategy. */
+	txpktsize = IXGBE_TXPBSIZE_MAX / num_pb;
+	txpbthresh = (txpktsize / 1024) - IXGBE_TXPKT_SIZE_MAX;
+	for (i = 0; i < num_pb; i++) {
+		IXGBE_WRITE_REG(hw, IXGBE_TXPBSIZE(i), txpktsize);
+		IXGBE_WRITE_REG(hw, IXGBE_TXPBTHRESH(i), txpbthresh);
+	}
+
+	/* Clear unused TCs, if any, to zero buffer size*/
+	for (; i < IXGBE_MAX_PB; i++) {
+		IXGBE_WRITE_REG(hw, IXGBE_RXPBSIZE(i), 0);
+		IXGBE_WRITE_REG(hw, IXGBE_TXPBSIZE(i), 0);
+		IXGBE_WRITE_REG(hw, IXGBE_TXPBTHRESH(i), 0);
+	}
+}
+
+/**
  * ixgbe_clear_tx_pending - Clear pending TX work from the PCIe fifo
  * @hw: pointer to the hardware structure
  *
@@ -3674,23 +4517,25 @@ void ixgbe_clear_tx_pending(struct ixgbe_hw *hw)
 	hlreg0 = IXGBE_READ_REG(hw, IXGBE_HLREG0);
 	IXGBE_WRITE_REG(hw, IXGBE_HLREG0, hlreg0 | IXGBE_HLREG0_LPBK);
 
-	/* wait for a last completion before clearing buffers */
+	/* Wait for a last completion before clearing buffers */
 	IXGBE_WRITE_FLUSH(hw);
-	usleep_range(3000, 6000);
+	msec_delay(3);
 
-	/* Before proceeding, make sure that the PCIe block does not have
+	/*
+	 * Before proceeding, make sure that the PCIe block does not have
 	 * transactions pending.
 	 */
 	poll = ixgbe_pcie_timeout_poll(hw);
 	for (i = 0; i < poll; i++) {
-		usleep_range(100, 200);
-		value = ixgbe_read_pci_cfg_word(hw, IXGBE_PCI_DEVICE_STATUS);
-		if (ixgbe_removed(hw->hw_addr))
-			break;
+		usec_delay(100);
+		value = IXGBE_READ_PCIE_WORD(hw, IXGBE_PCI_DEVICE_STATUS);
+		if (IXGBE_REMOVED(hw->hw_addr))
+			goto out;
 		if (!(value & IXGBE_PCI_DEVICE_STATUS_TRANSACTION_PENDING))
-			break;
+			goto out;
 	}
 
+out:
 	/* initiate cleaning flow for buffers in the PCIe transaction layer */
 	gcr_ext = IXGBE_READ_REG(hw, IXGBE_GCR_EXT);
 	IXGBE_WRITE_REG(hw, IXGBE_GCR_EXT,
@@ -3698,20 +4543,20 @@ void ixgbe_clear_tx_pending(struct ixgbe_hw *hw)
 
 	/* Flush all writes and allow 20usec for all transactions to clear */
 	IXGBE_WRITE_FLUSH(hw);
-	udelay(20);
+	usec_delay(20);
 
 	/* restore previous register values */
 	IXGBE_WRITE_REG(hw, IXGBE_GCR_EXT, gcr_ext);
 	IXGBE_WRITE_REG(hw, IXGBE_HLREG0, hlreg0);
 }
 
-static const u8 ixgbe_emc_temp_data[4] = {
+STATIC const u8 ixgbe_emc_temp_data[4] = {
 	IXGBE_EMC_INTERNAL_DATA,
 	IXGBE_EMC_DIODE1_DATA,
 	IXGBE_EMC_DIODE2_DATA,
 	IXGBE_EMC_DIODE3_DATA
 };
-static const u8 ixgbe_emc_therm_limit[4] = {
+STATIC const u8 ixgbe_emc_therm_limit[4] = {
 	IXGBE_EMC_INTERNAL_THERM_LIMIT,
 	IXGBE_EMC_DIODE1_THERM_LIMIT,
 	IXGBE_EMC_DIODE2_THERM_LIMIT,
@@ -3719,71 +4564,61 @@ static const u8 ixgbe_emc_therm_limit[4] = {
 };
 
 /**
- *  ixgbe_get_ets_data - Extracts the ETS bit data
- *  @hw: pointer to hardware structure
- *  @ets_cfg: extected ETS data
- *  @ets_offset: offset of ETS data
- *
- *  Returns error code.
- **/
-static s32 ixgbe_get_ets_data(struct ixgbe_hw *hw, u16 *ets_cfg,
-			      u16 *ets_offset)
-{
-	s32 status;
-
-	status = hw->eeprom.ops.read(hw, IXGBE_ETS_CFG, ets_offset);
-	if (status)
-		return status;
-
-	if ((*ets_offset == 0x0000) || (*ets_offset == 0xFFFF))
-		return IXGBE_NOT_IMPLEMENTED;
-
-	status = hw->eeprom.ops.read(hw, *ets_offset, ets_cfg);
-	if (status)
-		return status;
-
-	if ((*ets_cfg & IXGBE_ETS_TYPE_MASK) != IXGBE_ETS_TYPE_EMC_SHIFTED)
-		return IXGBE_NOT_IMPLEMENTED;
-
-	return 0;
-}
-
-/**
  *  ixgbe_get_thermal_sensor_data - Gathers thermal sensor data
  *  @hw: pointer to hardware structure
+ *  @data: pointer to the thermal sensor data structure
  *
  *  Returns the thermal sensor data structure
  **/
 s32 ixgbe_get_thermal_sensor_data_generic(struct ixgbe_hw *hw)
 {
-	s32 status;
+	s32 status = IXGBE_SUCCESS;
 	u16 ets_offset;
 	u16 ets_cfg;
 	u16 ets_sensor;
 	u8  num_sensors;
+	u8  sensor_index;
+	u8  sensor_location;
 	u8  i;
 	struct ixgbe_thermal_sensor_data *data = &hw->mac.thermal_sensor_data;
 
-	/* Only support thermal sensors attached to physical port 0 */
-	if ((IXGBE_READ_REG(hw, IXGBE_STATUS) & IXGBE_STATUS_LAN_ID_1))
-		return IXGBE_NOT_IMPLEMENTED;
+	DEBUGFUNC("ixgbe_get_thermal_sensor_data_generic");
+
+	/* Only support thermal sensors attached to 82599 physical port 0 */
+	if ((hw->mac.type != ixgbe_mac_82599EB) ||
+	    (IXGBE_READ_REG(hw, IXGBE_STATUS) & IXGBE_STATUS_LAN_ID_1)) {
+		status = IXGBE_NOT_IMPLEMENTED;
+		goto out;
+	}
 
-	status = ixgbe_get_ets_data(hw, &ets_cfg, &ets_offset);
+	status = hw->eeprom.ops.read(hw, IXGBE_ETS_CFG, &ets_offset);
 	if (status)
-		return status;
+		goto out;
+
+	if ((ets_offset == 0x0000) || (ets_offset == 0xFFFF)) {
+		status = IXGBE_NOT_IMPLEMENTED;
+		goto out;
+	}
+
+	status = hw->eeprom.ops.read(hw, ets_offset, &ets_cfg);
+	if (status)
+		goto out;
+
+	if (((ets_cfg & IXGBE_ETS_TYPE_MASK) >> IXGBE_ETS_TYPE_SHIFT)
+		!= IXGBE_ETS_TYPE_EMC) {
+		status = IXGBE_NOT_IMPLEMENTED;
+		goto out;
+	}
 
 	num_sensors = (ets_cfg & IXGBE_ETS_NUM_SENSORS_MASK);
 	if (num_sensors > IXGBE_MAX_SENSORS)
 		num_sensors = IXGBE_MAX_SENSORS;
 
 	for (i = 0; i < num_sensors; i++) {
-		u8  sensor_index;
-		u8  sensor_location;
-
 		status = hw->eeprom.ops.read(hw, (ets_offset + 1 + i),
 					     &ets_sensor);
 		if (status)
-			return status;
+			goto out;
 
 		sensor_index = ((ets_sensor & IXGBE_ETS_DATA_INDEX_MASK) >>
 				IXGBE_ETS_DATA_INDEX_SHIFT);
@@ -3796,55 +4631,67 @@ s32 ixgbe_get_thermal_sensor_data_generic(struct ixgbe_hw *hw)
 					IXGBE_I2C_THERMAL_SENSOR_ADDR,
 					&data->sensor[i].temp);
 			if (status)
-				return status;
+				goto out;
 		}
 	}
-
-	return 0;
+out:
+	return status;
 }
 
 /**
- * ixgbe_init_thermal_sensor_thresh_generic - Inits thermal sensor thresholds
- * @hw: pointer to hardware structure
+ *  ixgbe_init_thermal_sensor_thresh_generic - Inits thermal sensor thresholds
+ *  @hw: pointer to hardware structure
  *
- * Inits the thermal sensor thresholds according to the NVM map
- * and save off the threshold and location values into mac.thermal_sensor_data
+ *  Inits the thermal sensor thresholds according to the NVM map
+ *  and save off the threshold and location values into mac.thermal_sensor_data
  **/
 s32 ixgbe_init_thermal_sensor_thresh_generic(struct ixgbe_hw *hw)
 {
-	s32 status;
+	s32 status = IXGBE_SUCCESS;
+	u16 offset;
 	u16 ets_offset;
 	u16 ets_cfg;
 	u16 ets_sensor;
 	u8  low_thresh_delta;
 	u8  num_sensors;
+	u8  sensor_index;
+	u8  sensor_location;
 	u8  therm_limit;
 	u8  i;
 	struct ixgbe_thermal_sensor_data *data = &hw->mac.thermal_sensor_data;
 
+	DEBUGFUNC("ixgbe_init_thermal_sensor_thresh_generic");
+
 	memset(data, 0, sizeof(struct ixgbe_thermal_sensor_data));
 
-	/* Only support thermal sensors attached to physical port 0 */
-	if ((IXGBE_READ_REG(hw, IXGBE_STATUS) & IXGBE_STATUS_LAN_ID_1))
+	/* Only support thermal sensors attached to 82599 physical port 0 */
+	if ((hw->mac.type != ixgbe_mac_82599EB) ||
+	    (IXGBE_READ_REG(hw, IXGBE_STATUS) & IXGBE_STATUS_LAN_ID_1))
 		return IXGBE_NOT_IMPLEMENTED;
 
-	status = ixgbe_get_ets_data(hw, &ets_cfg, &ets_offset);
-	if (status)
-		return status;
+	offset = IXGBE_ETS_CFG;
+	if (hw->eeprom.ops.read(hw, offset, &ets_offset))
+		goto eeprom_err;
+	if ((ets_offset == 0x0000) || (ets_offset == 0xFFFF))
+		return IXGBE_NOT_IMPLEMENTED;
+
+	offset = ets_offset;
+	if (hw->eeprom.ops.read(hw, offset, &ets_cfg))
+		goto eeprom_err;
+	if (((ets_cfg & IXGBE_ETS_TYPE_MASK) >> IXGBE_ETS_TYPE_SHIFT)
+		!= IXGBE_ETS_TYPE_EMC)
+		return IXGBE_NOT_IMPLEMENTED;
 
 	low_thresh_delta = ((ets_cfg & IXGBE_ETS_LTHRES_DELTA_MASK) >>
 			     IXGBE_ETS_LTHRES_DELTA_SHIFT);
 	num_sensors = (ets_cfg & IXGBE_ETS_NUM_SENSORS_MASK);
-	if (num_sensors > IXGBE_MAX_SENSORS)
-		num_sensors = IXGBE_MAX_SENSORS;
 
 	for (i = 0; i < num_sensors; i++) {
-		u8  sensor_index;
-		u8  sensor_location;
-
-		if (hw->eeprom.ops.read(hw, ets_offset + 1 + i, &ets_sensor)) {
-			hw_err(hw, "eeprom read at offset %d failed\n",
-			       ets_offset + 1 + i);
+		offset = ets_offset + 1 + i;
+		if (hw->eeprom.ops.read(hw, offset, &ets_sensor)) {
+			ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+				      "eeprom read at offset %d failed",
+				      offset);
 			continue;
 		}
 		sensor_index = ((ets_sensor & IXGBE_ETS_DATA_INDEX_MASK) >>
@@ -3857,26 +4704,158 @@ s32 ixgbe_init_thermal_sensor_thresh_generic(struct ixgbe_hw *hw)
 			ixgbe_emc_therm_limit[sensor_index],
 			IXGBE_I2C_THERMAL_SENSOR_ADDR, therm_limit);
 
-		if (sensor_location == 0)
-			continue;
+		if ((i < IXGBE_MAX_SENSORS) && (sensor_location != 0)) {
+			data->sensor[i].location = sensor_location;
+			data->sensor[i].caution_thresh = therm_limit;
+			data->sensor[i].max_op_thresh = therm_limit -
+							low_thresh_delta;
+		}
+	}
+	return status;
+
+eeprom_err:
+	ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+		      "eeprom read at offset %d failed", offset);
+	return IXGBE_NOT_IMPLEMENTED;
+}
+
+/**
+ *  ixgbe_get_orom_version - Return option ROM from EEPROM
+ *
+ *  @hw: pointer to hardware structure
+ *  @nvm_ver: pointer to output structure
+ *
+ *  if valid option ROM version, nvm_ver->or_valid set to true
+ *  else nvm_ver->or_valid is false.
+ **/
+void ixgbe_get_orom_version(struct ixgbe_hw *hw,
+			    struct ixgbe_nvm_version *nvm_ver)
+{
+	u16 offset, eeprom_cfg_blkh, eeprom_cfg_blkl;
+
+	nvm_ver->or_valid = false;
+	/* Option Rom may or may not be present.  Start with pointer */
+	hw->eeprom.ops.read(hw, NVM_OROM_OFFSET, &offset);
+
+	/* make sure offset is valid */
+	if ((offset == 0x0) || (offset == NVM_INVALID_PTR))
+		return;
+
+	hw->eeprom.ops.read(hw, offset + NVM_OROM_BLK_HI, &eeprom_cfg_blkh);
+	hw->eeprom.ops.read(hw, offset + NVM_OROM_BLK_LOW, &eeprom_cfg_blkl);
+
+	/* option rom exists and is valid */
+	if ((eeprom_cfg_blkl | eeprom_cfg_blkh) == 0x0 ||
+	    eeprom_cfg_blkl == NVM_VER_INVALID ||
+	    eeprom_cfg_blkh == NVM_VER_INVALID)
+		return;
+
+	nvm_ver->or_valid = true;
+	nvm_ver->or_major = eeprom_cfg_blkl >> NVM_OROM_SHIFT;
+	nvm_ver->or_build = (eeprom_cfg_blkl << NVM_OROM_SHIFT) |
+			    (eeprom_cfg_blkh >> NVM_OROM_SHIFT);
+	nvm_ver->or_patch = eeprom_cfg_blkh & NVM_OROM_PATCH_MASK;
+}
+
+/**
+ *  ixgbe_get_oem_prod_version - Return OEM Product version
+ *
+ *  @hw: pointer to hardware structure
+ *  @nvm_ver: pointer to output structure
+ *
+ *  if valid OEM product version, nvm_ver->oem_valid set to true
+ *  else nvm_ver->oem_valid is false.
+ **/
+void ixgbe_get_oem_prod_version(struct ixgbe_hw *hw,
+				struct ixgbe_nvm_version *nvm_ver)
+{
+	u16 rel_num, prod_ver, mod_len, cap, offset;
 
-		data->sensor[i].location = sensor_location;
-		data->sensor[i].caution_thresh = therm_limit;
-		data->sensor[i].max_op_thresh = therm_limit - low_thresh_delta;
+	nvm_ver->oem_valid = false;
+	hw->eeprom.ops.read(hw, NVM_OEM_PROD_VER_PTR, &offset);
+
+	/* Return is offset to OEM Product Version block is invalid */
+	if (offset == 0x0 && offset == NVM_INVALID_PTR)
+		return;
+
+	/* Read product version block */
+	hw->eeprom.ops.read(hw, offset, &mod_len);
+	hw->eeprom.ops.read(hw, offset + NVM_OEM_PROD_VER_CAP_OFF, &cap);
+
+	/* Return if OEM product version block is invalid */
+	if (mod_len != NVM_OEM_PROD_VER_MOD_LEN ||
+	    (cap & NVM_OEM_PROD_VER_CAP_MASK) != 0x0)
+		return;
+
+	hw->eeprom.ops.read(hw, offset + NVM_OEM_PROD_VER_OFF_L, &prod_ver);
+	hw->eeprom.ops.read(hw, offset + NVM_OEM_PROD_VER_OFF_H, &rel_num);
+
+	/* Return if version is invalid */
+	if ((rel_num | prod_ver) == 0x0 ||
+	    rel_num == NVM_VER_INVALID || prod_ver == NVM_VER_INVALID)
+		return;
+
+	nvm_ver->oem_major = prod_ver >> NVM_VER_SHIFT;
+	nvm_ver->oem_minor = prod_ver & NVM_VER_MASK;
+	nvm_ver->oem_release = rel_num;
+	nvm_ver->oem_valid = true;
+}
+
+/**
+ *  ixgbe_get_etk_id - Return Etrack ID from EEPROM
+ *
+ *  @hw: pointer to hardware structure
+ *  @nvm_ver: pointer to output structure
+ *
+ *  word read errors will return 0xFFFF
+ **/
+void ixgbe_get_etk_id(struct ixgbe_hw *hw, struct ixgbe_nvm_version *nvm_ver)
+{
+	u16 etk_id_l, etk_id_h;
+
+	if (hw->eeprom.ops.read(hw, NVM_ETK_OFF_LOW, &etk_id_l))
+		etk_id_l = NVM_VER_INVALID;
+	if (hw->eeprom.ops.read(hw, NVM_ETK_OFF_HI, &etk_id_h))
+		etk_id_h = NVM_VER_INVALID;
+
+	/* The word order for the version format is determined by high order
+	 * word bit 15.
+	 */
+	if ((etk_id_h & NVM_ETK_VALID) == 0) {
+		nvm_ver->etk_id = etk_id_h;
+		nvm_ver->etk_id |= (etk_id_l << NVM_ETK_SHIFT);
+	} else {
+		nvm_ver->etk_id = etk_id_l;
+		nvm_ver->etk_id |= (etk_id_h << NVM_ETK_SHIFT);
 	}
+}
+
+/**
+ * ixgbe_dcb_get_rtrup2tc_generic - read rtrup2tc reg
+ * @hw: pointer to hardware structure
+ * @map: pointer to u8 arr for returning map
+ *
+ * Read the rtrup2tc HW register and resolve its content into map
+ **/
+void ixgbe_dcb_get_rtrup2tc_generic(struct ixgbe_hw *hw, u8 *map)
+{
+	u32 reg, i;
 
-	return 0;
+	reg = IXGBE_READ_REG(hw, IXGBE_RTRUP2TC);
+	for (i = 0; i < IXGBE_DCB_MAX_USER_PRIORITY; i++)
+		map[i] = IXGBE_RTRUP2TC_UP_MASK &
+			(reg >> (i * IXGBE_RTRUP2TC_UP_SHIFT));
+	return;
 }
 
 void ixgbe_disable_rx_generic(struct ixgbe_hw *hw)
 {
+	u32 pfdtxgswc;
 	u32 rxctrl;
 
 	rxctrl = IXGBE_READ_REG(hw, IXGBE_RXCTRL);
 	if (rxctrl & IXGBE_RXCTRL_RXEN) {
 		if (hw->mac.type != ixgbe_mac_82598EB) {
-			u32 pfdtxgswc;
-
 			pfdtxgswc = IXGBE_READ_REG(hw, IXGBE_PFDTXGSWC);
 			if (pfdtxgswc & IXGBE_PFDTXGSWC_VT_LBEN) {
 				pfdtxgswc &= ~IXGBE_PFDTXGSWC_VT_LBEN;
@@ -3893,6 +4872,7 @@ void ixgbe_disable_rx_generic(struct ixgbe_hw *hw)
 
 void ixgbe_enable_rx_generic(struct ixgbe_hw *hw)
 {
+	u32 pfdtxgswc;
 	u32 rxctrl;
 
 	rxctrl = IXGBE_READ_REG(hw, IXGBE_RXCTRL);
@@ -3900,8 +4880,6 @@ void ixgbe_enable_rx_generic(struct ixgbe_hw *hw)
 
 	if (hw->mac.type != ixgbe_mac_82598EB) {
 		if (hw->mac.set_lben) {
-			u32 pfdtxgswc;
-
 			pfdtxgswc = IXGBE_READ_REG(hw, IXGBE_PFDTXGSWC);
 			pfdtxgswc |= IXGBE_PFDTXGSWC_VT_LBEN;
 			IXGBE_WRITE_REG(hw, IXGBE_PFDTXGSWC, pfdtxgswc);
@@ -3910,9 +4888,10 @@ void ixgbe_enable_rx_generic(struct ixgbe_hw *hw)
 	}
 }
 
-/** ixgbe_mng_present - returns true when management capability is present
+/**
+ * ixgbe_mng_present - returns true when management capability is present
  * @hw: pointer to hardware structure
- **/
+ */
 bool ixgbe_mng_present(struct ixgbe_hw *hw)
 {
 	u32 fwsm;
@@ -3920,9 +4899,36 @@ bool ixgbe_mng_present(struct ixgbe_hw *hw)
 	if (hw->mac.type < ixgbe_mac_82599EB)
 		return false;
 
-	fwsm = IXGBE_READ_REG(hw, IXGBE_FWSM(hw));
-	fwsm &= IXGBE_FWSM_MODE_MASK;
-	return fwsm == IXGBE_FWSM_FW_MODE_PT;
+	fwsm = IXGBE_READ_REG(hw, IXGBE_FWSM_BY_MAC(hw));
+
+	return !!(fwsm & IXGBE_FWSM_FW_MODE_PT);
+}
+
+/**
+ * ixgbe_mng_enabled - Is the manageability engine enabled?
+ * @hw: pointer to hardware structure
+ *
+ * Returns true if the manageability engine is enabled.
+ **/
+bool ixgbe_mng_enabled(struct ixgbe_hw *hw)
+{
+	u32 fwsm, manc, factps;
+
+	fwsm = IXGBE_READ_REG(hw, IXGBE_FWSM_BY_MAC(hw));
+	if ((fwsm & IXGBE_FWSM_MODE_MASK) != IXGBE_FWSM_FW_MODE_PT)
+		return false;
+
+	manc = IXGBE_READ_REG(hw, IXGBE_MANC);
+	if (!(manc & IXGBE_MANC_RCV_TCO_EN))
+		return false;
+
+	if (hw->mac.type <= ixgbe_mac_X540) {
+		factps = IXGBE_READ_REG(hw, IXGBE_FACTPS_BY_MAC(hw));
+		if (factps & IXGBE_FACTPS_MNGCG)
+			return false;
+	}
+
+	return true;
 }
 
 /**
@@ -3932,21 +4938,23 @@ bool ixgbe_mng_present(struct ixgbe_hw *hw)
  *  @autoneg_wait_to_complete: true when waiting for completion is needed
  *
  *  Set the link speed in the MAC and/or PHY register and restarts link.
- */
+ **/
 s32 ixgbe_setup_mac_link_multispeed_fiber(struct ixgbe_hw *hw,
 					  ixgbe_link_speed speed,
 					  bool autoneg_wait_to_complete)
 {
 	ixgbe_link_speed link_speed = IXGBE_LINK_SPEED_UNKNOWN;
 	ixgbe_link_speed highest_link_speed = IXGBE_LINK_SPEED_UNKNOWN;
-	s32 status = 0;
+	s32 status = IXGBE_SUCCESS;
 	u32 speedcnt = 0;
 	u32 i = 0;
 	bool autoneg, link_up = false;
 
+	DEBUGFUNC("ixgbe_setup_mac_link_multispeed_fiber");
+
 	/* Mask off requested but non-supported speeds */
-	status = hw->mac.ops.get_link_capabilities(hw, &link_speed, &autoneg);
-	if (status)
+	status = ixgbe_get_link_capabilities(hw, &link_speed, &autoneg);
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	speed &= link_speed;
@@ -3958,41 +4966,31 @@ s32 ixgbe_setup_mac_link_multispeed_fiber(struct ixgbe_hw *hw,
 		speedcnt++;
 		highest_link_speed = IXGBE_LINK_SPEED_10GB_FULL;
 
-		/* If we already have link at this speed, just jump out */
-		status = hw->mac.ops.check_link(hw, &link_speed, &link_up,
-						false);
-		if (status)
-			return status;
-
-		if (link_speed == IXGBE_LINK_SPEED_10GB_FULL && link_up)
-			goto out;
-
 		/* Set the module link speed */
 		switch (hw->phy.media_type) {
 		case ixgbe_media_type_fiber:
-			hw->mac.ops.set_rate_select_speed(hw,
+			ixgbe_set_rate_select_speed(hw,
 						    IXGBE_LINK_SPEED_10GB_FULL);
 			break;
 		case ixgbe_media_type_fiber_qsfp:
 			/* QSFP module automatically detects MAC link speed */
 			break;
 		default:
-			hw_dbg(hw, "Unexpected media type\n");
+			DEBUGOUT("Unexpected media type.\n");
 			break;
 		}
 
 		/* Allow module to change analog characteristics (1G->10G) */
-		msleep(40);
+		msec_delay(40);
 
-		status = hw->mac.ops.setup_mac_link(hw,
-						    IXGBE_LINK_SPEED_10GB_FULL,
-						    autoneg_wait_to_complete);
-		if (status)
+		status = ixgbe_setup_mac_link(hw,
+					      IXGBE_LINK_SPEED_10GB_FULL,
+					      autoneg_wait_to_complete);
+		if (status != IXGBE_SUCCESS)
 			return status;
 
 		/* Flap the Tx laser if it has not already been done */
-		if (hw->mac.ops.flap_tx_laser)
-			hw->mac.ops.flap_tx_laser(hw);
+		ixgbe_flap_tx_laser(hw);
 
 		/* Wait for the controller to acquire link.  Per IEEE 802.3ap,
 		 * Section 73.10.2, we may have to wait up to 500ms if KR is
@@ -4000,12 +4998,12 @@ s32 ixgbe_setup_mac_link_multispeed_fiber(struct ixgbe_hw *hw,
 		 */
 		for (i = 0; i < 5; i++) {
 			/* Wait for the link partner to also set speed */
-			msleep(100);
+			msec_delay(100);
 
 			/* If we have link, just jump out */
-			status = hw->mac.ops.check_link(hw, &link_speed,
-							&link_up, false);
-			if (status)
+			status = ixgbe_check_link(hw, &link_speed,
+						  &link_up, false);
+			if (status != IXGBE_SUCCESS)
 				return status;
 
 			if (link_up)
@@ -4018,49 +5016,38 @@ s32 ixgbe_setup_mac_link_multispeed_fiber(struct ixgbe_hw *hw,
 		if (highest_link_speed == IXGBE_LINK_SPEED_UNKNOWN)
 			highest_link_speed = IXGBE_LINK_SPEED_1GB_FULL;
 
-		/* If we already have link at this speed, just jump out */
-		status = hw->mac.ops.check_link(hw, &link_speed, &link_up,
-						false);
-		if (status)
-			return status;
-
-		if (link_speed == IXGBE_LINK_SPEED_1GB_FULL && link_up)
-			goto out;
-
 		/* Set the module link speed */
 		switch (hw->phy.media_type) {
 		case ixgbe_media_type_fiber:
-			hw->mac.ops.set_rate_select_speed(hw,
-						     IXGBE_LINK_SPEED_1GB_FULL);
+			ixgbe_set_rate_select_speed(hw,
+						    IXGBE_LINK_SPEED_1GB_FULL);
 			break;
 		case ixgbe_media_type_fiber_qsfp:
 			/* QSFP module automatically detects link speed */
 			break;
 		default:
-			hw_dbg(hw, "Unexpected media type\n");
+			DEBUGOUT("Unexpected media type.\n");
 			break;
 		}
 
 		/* Allow module to change analog characteristics (10G->1G) */
-		msleep(40);
+		msec_delay(40);
 
-		status = hw->mac.ops.setup_mac_link(hw,
-						    IXGBE_LINK_SPEED_1GB_FULL,
-						    autoneg_wait_to_complete);
-		if (status)
+		status = ixgbe_setup_mac_link(hw,
+					      IXGBE_LINK_SPEED_1GB_FULL,
+					      autoneg_wait_to_complete);
+		if (status != IXGBE_SUCCESS)
 			return status;
 
 		/* Flap the Tx laser if it has not already been done */
-		if (hw->mac.ops.flap_tx_laser)
-			hw->mac.ops.flap_tx_laser(hw);
+		ixgbe_flap_tx_laser(hw);
 
 		/* Wait for the link partner to also set speed */
-		msleep(100);
+		msec_delay(100);
 
 		/* If we have link, just jump out */
-		status = hw->mac.ops.check_link(hw, &link_speed, &link_up,
-						false);
-		if (status)
+		status = ixgbe_check_link(hw, &link_speed, &link_up, false);
+		if (status != IXGBE_SUCCESS)
 			return status;
 
 		if (link_up)
@@ -4097,7 +5084,7 @@ out:
  *  Set module link speed via the soft rate select.
  */
 void ixgbe_set_soft_rate_select_speed(struct ixgbe_hw *hw,
-				      ixgbe_link_speed speed)
+					ixgbe_link_speed speed)
 {
 	s32 status;
 	u8 rs, eeprom_data;
@@ -4111,7 +5098,7 @@ void ixgbe_set_soft_rate_select_speed(struct ixgbe_hw *hw,
 		rs = IXGBE_SFF_SOFT_RS_SELECT_1G;
 		break;
 	default:
-		hw_dbg(hw, "Invalid fixed module speed\n");
+		DEBUGOUT("Invalid fixed module speed\n");
 		return;
 	}
 
@@ -4120,8 +5107,8 @@ void ixgbe_set_soft_rate_select_speed(struct ixgbe_hw *hw,
 					   IXGBE_I2C_EEPROM_DEV_ADDR2,
 					   &eeprom_data);
 	if (status) {
-		hw_dbg(hw, "Failed to read Rx Rate Select RS0\n");
-		return;
+		DEBUGOUT("Failed to read Rx Rate Select RS0\n");
+		goto out;
 	}
 
 	eeprom_data = (eeprom_data & ~IXGBE_SFF_SOFT_RS_SELECT_MASK) | rs;
@@ -4130,7 +5117,28 @@ void ixgbe_set_soft_rate_select_speed(struct ixgbe_hw *hw,
 					    IXGBE_I2C_EEPROM_DEV_ADDR2,
 					    eeprom_data);
 	if (status) {
-		hw_dbg(hw, "Failed to write Rx Rate Select RS0\n");
-		return;
+		DEBUGOUT("Failed to write Rx Rate Select RS0\n");
+		goto out;
 	}
+
+	/* Set RS1 */
+	status = hw->phy.ops.read_i2c_byte(hw, IXGBE_SFF_SFF_8472_ESCB,
+					   IXGBE_I2C_EEPROM_DEV_ADDR2,
+					   &eeprom_data);
+	if (status) {
+		DEBUGOUT("Failed to read Rx Rate Select RS1\n");
+		goto out;
+	}
+
+	eeprom_data = (eeprom_data & ~IXGBE_SFF_SOFT_RS_SELECT_MASK) | rs;
+
+	status = hw->phy.ops.write_i2c_byte(hw, IXGBE_SFF_SFF_8472_ESCB,
+					    IXGBE_I2C_EEPROM_DEV_ADDR2,
+					    eeprom_data);
+	if (status) {
+		DEBUGOUT("Failed to write Rx Rate Select RS1\n");
+		goto out;
+	}
+out:
+	return;
 }
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_common.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_common.h
index a0044e4..4b65730 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_common.h
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_common.h
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -30,7 +26,8 @@
 #define _IXGBE_COMMON_H_
 
 #include "ixgbe_type.h"
-#include "ixgbe.h"
+
+void ixgbe_dcb_get_rtrup2tc_generic(struct ixgbe_hw *hw, u8 *map);
 
 u16 ixgbe_get_pcie_msix_count_generic(struct ixgbe_hw *hw);
 s32 ixgbe_init_ops_generic(struct ixgbe_hw *hw);
@@ -41,14 +38,14 @@ s32 ixgbe_clear_hw_cntrs_generic(struct ixgbe_hw *hw);
 s32 ixgbe_read_pba_string_generic(struct ixgbe_hw *hw, u8 *pba_num,
 				  u32 pba_num_size);
 s32 ixgbe_get_mac_addr_generic(struct ixgbe_hw *hw, u8 *mac_addr);
-enum ixgbe_bus_width ixgbe_convert_bus_width(u16 link_status);
-enum ixgbe_bus_speed ixgbe_convert_bus_speed(u16 link_status);
 s32 ixgbe_get_bus_info_generic(struct ixgbe_hw *hw);
+void ixgbe_set_pci_config_data_generic(struct ixgbe_hw *hw, u16 link_status);
 void ixgbe_set_lan_id_multi_port_pcie(struct ixgbe_hw *hw);
 s32 ixgbe_stop_adapter_generic(struct ixgbe_hw *hw);
 
 s32 ixgbe_led_on_generic(struct ixgbe_hw *hw, u32 index);
 s32 ixgbe_led_off_generic(struct ixgbe_hw *hw, u32 index);
+s32 ixgbe_init_led_link_act_generic(struct ixgbe_hw *hw);
 
 s32 ixgbe_init_eeprom_params_generic(struct ixgbe_hw *hw);
 s32 ixgbe_write_eeprom_generic(struct ixgbe_hw *hw, u16 offset, u16 data);
@@ -68,59 +65,84 @@ s32 ixgbe_calc_eeprom_checksum_generic(struct ixgbe_hw *hw);
 s32 ixgbe_validate_eeprom_checksum_generic(struct ixgbe_hw *hw,
 					   u16 *checksum_val);
 s32 ixgbe_update_eeprom_checksum_generic(struct ixgbe_hw *hw);
+s32 ixgbe_poll_eerd_eewr_done(struct ixgbe_hw *hw, u32 ee_reg);
 
 s32 ixgbe_set_rar_generic(struct ixgbe_hw *hw, u32 index, u8 *addr, u32 vmdq,
 			  u32 enable_addr);
 s32 ixgbe_clear_rar_generic(struct ixgbe_hw *hw, u32 index);
 s32 ixgbe_init_rx_addrs_generic(struct ixgbe_hw *hw);
-s32 ixgbe_update_mc_addr_list_generic(struct ixgbe_hw *hw,
-				      struct net_device *netdev);
+s32 ixgbe_update_mc_addr_list_generic(struct ixgbe_hw *hw, u8 *mc_addr_list,
+				      u32 mc_addr_count,
+				      ixgbe_mc_addr_itr func, bool clear);
+s32 ixgbe_update_uc_addr_list_generic(struct ixgbe_hw *hw, u8 *addr_list,
+				      u32 addr_count, ixgbe_mc_addr_itr func);
 s32 ixgbe_enable_mc_generic(struct ixgbe_hw *hw);
 s32 ixgbe_disable_mc_generic(struct ixgbe_hw *hw);
-s32 ixgbe_disable_rx_buff_generic(struct ixgbe_hw *hw);
-s32 ixgbe_enable_rx_buff_generic(struct ixgbe_hw *hw);
 s32 ixgbe_enable_rx_dma_generic(struct ixgbe_hw *hw, u32 regval);
+s32 ixgbe_disable_sec_rx_path_generic(struct ixgbe_hw *hw);
+s32 ixgbe_enable_sec_rx_path_generic(struct ixgbe_hw *hw);
+
 s32 ixgbe_fc_enable_generic(struct ixgbe_hw *hw);
 bool ixgbe_device_supports_autoneg_fc(struct ixgbe_hw *hw);
 void ixgbe_fc_autoneg(struct ixgbe_hw *hw);
+s32 ixgbe_setup_fc_generic(struct ixgbe_hw *hw);
 
+s32 ixgbe_validate_mac_addr(u8 *mac_addr);
 s32 ixgbe_acquire_swfw_sync(struct ixgbe_hw *hw, u32 mask);
 void ixgbe_release_swfw_sync(struct ixgbe_hw *hw, u32 mask);
+s32 ixgbe_disable_pcie_master(struct ixgbe_hw *hw);
+
+s32 prot_autoc_read_generic(struct ixgbe_hw *hw, bool *, u32 *reg_val);
+s32 prot_autoc_write_generic(struct ixgbe_hw *hw, u32 reg_val, bool locked);
+
+s32 ixgbe_blink_led_start_generic(struct ixgbe_hw *hw, u32 index);
+s32 ixgbe_blink_led_stop_generic(struct ixgbe_hw *hw, u32 index);
+
 s32 ixgbe_get_san_mac_addr_generic(struct ixgbe_hw *hw, u8 *san_mac_addr);
+s32 ixgbe_set_san_mac_addr_generic(struct ixgbe_hw *hw, u8 *san_mac_addr);
+
 s32 ixgbe_set_vmdq_generic(struct ixgbe_hw *hw, u32 rar, u32 vmdq);
 s32 ixgbe_set_vmdq_san_mac_generic(struct ixgbe_hw *hw, u32 vmdq);
 s32 ixgbe_clear_vmdq_generic(struct ixgbe_hw *hw, u32 rar, u32 vmdq);
+s32 ixgbe_insert_mac_addr_generic(struct ixgbe_hw *hw, u8 *addr, u32 vmdq);
 s32 ixgbe_init_uta_tables_generic(struct ixgbe_hw *hw);
 s32 ixgbe_set_vfta_generic(struct ixgbe_hw *hw, u32 vlan,
-			   u32 vind, bool vlan_on);
+			 u32 vind, bool vlan_on, bool vlvf_bypass);
+s32 ixgbe_set_vlvf_generic(struct ixgbe_hw *hw, u32 vlan, u32 vind,
+			   bool vlan_on, u32 *vfta_delta, u32 vfta,
+			   bool vlvf_bypass);
 s32 ixgbe_clear_vfta_generic(struct ixgbe_hw *hw);
+s32 ixgbe_find_vlvf_slot(struct ixgbe_hw *hw, u32 vlan, bool vlvf_bypass);
+
 s32 ixgbe_check_mac_link_generic(struct ixgbe_hw *hw,
-				 ixgbe_link_speed *speed,
-				 bool *link_up, bool link_up_wait_to_complete);
+			       ixgbe_link_speed *speed,
+			       bool *link_up, bool link_up_wait_to_complete);
+
 s32 ixgbe_get_wwn_prefix_generic(struct ixgbe_hw *hw, u16 *wwnn_prefix,
 				 u16 *wwpn_prefix);
 
-s32 prot_autoc_read_generic(struct ixgbe_hw *hw, bool *, u32 *reg_val);
-s32 prot_autoc_write_generic(struct ixgbe_hw *hw, u32 reg_val, bool locked);
-
-s32 ixgbe_blink_led_start_generic(struct ixgbe_hw *hw, u32 index);
-s32 ixgbe_blink_led_stop_generic(struct ixgbe_hw *hw, u32 index);
-void ixgbe_set_mac_anti_spoofing(struct ixgbe_hw *hw, bool enable, int pf);
+s32 ixgbe_get_fcoe_boot_status_generic(struct ixgbe_hw *hw, u16 *bs);
+void ixgbe_set_mac_anti_spoofing(struct ixgbe_hw *hw, bool enable, int vf);
 void ixgbe_set_vlan_anti_spoofing(struct ixgbe_hw *hw, bool enable, int vf);
 s32 ixgbe_get_device_caps_generic(struct ixgbe_hw *hw, u16 *device_caps);
+void ixgbe_set_rxpba_generic(struct ixgbe_hw *hw, int num_pb, u32 headroom,
+			     int strategy);
 s32 ixgbe_set_fw_drv_ver_generic(struct ixgbe_hw *hw, u8 maj, u8 min,
-				 u8 build, u8 ver);
+				 u8 build, u8 ver, u16 len, const char *str);
+u8 ixgbe_calculate_checksum(u8 *buffer, u32 length);
 s32 ixgbe_host_interface_command(struct ixgbe_hw *hw, u32 *buffer,
 				 u32 length, u32 timeout, bool return_data);
+s32 ixgbe_hic_unlocked(struct ixgbe_hw *, u32 *buffer, u32 length, u32 timeout);
+s32 ixgbe_shutdown_fw_phy(struct ixgbe_hw *);
+s32 ixgbe_fw_phy_activity(struct ixgbe_hw *, u16 activity,
+			  u32 (*data)[FW_PHY_ACT_DATA_COUNT]);
 void ixgbe_clear_tx_pending(struct ixgbe_hw *hw);
+
+extern s32 ixgbe_reset_pipeline_82599(struct ixgbe_hw *hw);
+extern void ixgbe_stop_mac_link_on_d3_82599(struct ixgbe_hw *hw);
 bool ixgbe_mng_present(struct ixgbe_hw *hw);
 bool ixgbe_mng_enabled(struct ixgbe_hw *hw);
 
-void ixgbe_set_rxpba_generic(struct ixgbe_hw *hw, int num_pb,
-			     u32 headroom, int strategy);
-
-extern const u32 ixgbe_mvals_8259X[IXGBE_MVALS_IDX_LIMIT];
-
 #define IXGBE_I2C_THERMAL_SENSOR_ADDR	0xF8
 #define IXGBE_EMC_INTERNAL_DATA		0x00
 #define IXGBE_EMC_INTERNAL_THERM_LIMIT	0x20
@@ -133,6 +155,12 @@ extern const u32 ixgbe_mvals_8259X[IXGBE_MVALS_IDX_LIMIT];
 
 s32 ixgbe_get_thermal_sensor_data_generic(struct ixgbe_hw *hw);
 s32 ixgbe_init_thermal_sensor_thresh_generic(struct ixgbe_hw *hw);
+
+void ixgbe_get_etk_id(struct ixgbe_hw *hw, struct ixgbe_nvm_version *nvm_ver);
+void ixgbe_get_oem_prod_version(struct ixgbe_hw *hw,
+				struct ixgbe_nvm_version *nvm_ver);
+void ixgbe_get_orom_version(struct ixgbe_hw *hw,
+			    struct ixgbe_nvm_version *nvm_ver);
 void ixgbe_disable_rx_generic(struct ixgbe_hw *hw);
 void ixgbe_enable_rx_generic(struct ixgbe_hw *hw);
 s32 ixgbe_setup_mac_link_multispeed_fiber(struct ixgbe_hw *hw,
@@ -140,79 +168,4 @@ s32 ixgbe_setup_mac_link_multispeed_fiber(struct ixgbe_hw *hw,
 					  bool autoneg_wait_to_complete);
 void ixgbe_set_soft_rate_select_speed(struct ixgbe_hw *hw,
 				      ixgbe_link_speed speed);
-
-#define IXGBE_FAILED_READ_REG 0xffffffffU
-#define IXGBE_FAILED_READ_CFG_DWORD 0xffffffffU
-#define IXGBE_FAILED_READ_CFG_WORD 0xffffU
-
-u16 ixgbe_read_pci_cfg_word(struct ixgbe_hw *hw, u32 reg);
-void ixgbe_write_pci_cfg_word(struct ixgbe_hw *hw, u32 reg, u16 value);
-
-static inline bool ixgbe_removed(void __iomem *addr)
-{
-	return unlikely(!addr);
-}
-
-static inline void ixgbe_write_reg(struct ixgbe_hw *hw, u32 reg, u32 value)
-{
-	u8 __iomem *reg_addr = ACCESS_ONCE(hw->hw_addr);
-
-	if (ixgbe_removed(reg_addr))
-		return;
-	writel(value, reg_addr + reg);
-}
-#define IXGBE_WRITE_REG(a, reg, value) ixgbe_write_reg((a), (reg), (value))
-
-#ifndef writeq
-#define writeq writeq
-static inline void writeq(u64 val, void __iomem *addr)
-{
-	writel((u32)val, addr);
-	writel((u32)(val >> 32), addr + 4);
-}
-#endif
-
-static inline void ixgbe_write_reg64(struct ixgbe_hw *hw, u32 reg, u64 value)
-{
-	u8 __iomem *reg_addr = ACCESS_ONCE(hw->hw_addr);
-
-	if (ixgbe_removed(reg_addr))
-		return;
-	writeq(value, reg_addr + reg);
-}
-#define IXGBE_WRITE_REG64(a, reg, value) ixgbe_write_reg64((a), (reg), (value))
-
-u32 ixgbe_read_reg(struct ixgbe_hw *hw, u32 reg);
-#define IXGBE_READ_REG(a, reg) ixgbe_read_reg((a), (reg))
-
-#define IXGBE_WRITE_REG_ARRAY(a, reg, offset, value) \
-		ixgbe_write_reg((a), (reg) + ((offset) << 2), (value))
-
-#define IXGBE_READ_REG_ARRAY(a, reg, offset) \
-		ixgbe_read_reg((a), (reg) + ((offset) << 2))
-
-#define IXGBE_WRITE_FLUSH(a) ixgbe_read_reg((a), IXGBE_STATUS)
-
-#define ixgbe_hw_to_netdev(hw) (((struct ixgbe_adapter *)(hw)->back)->netdev)
-
-#define hw_dbg(hw, format, arg...) \
-	netdev_dbg(ixgbe_hw_to_netdev(hw), format, ## arg)
-#define hw_err(hw, format, arg...) \
-	netdev_err(ixgbe_hw_to_netdev(hw), format, ## arg)
-#define e_dev_info(format, arg...) \
-	dev_info(&adapter->pdev->dev, format, ## arg)
-#define e_dev_warn(format, arg...) \
-	dev_warn(&adapter->pdev->dev, format, ## arg)
-#define e_dev_err(format, arg...) \
-	dev_err(&adapter->pdev->dev, format, ## arg)
-#define e_dev_notice(format, arg...) \
-	dev_notice(&adapter->pdev->dev, format, ## arg)
-#define e_info(msglvl, format, arg...) \
-	netif_info(adapter, msglvl, adapter->netdev, format, ## arg)
-#define e_err(msglvl, format, arg...) \
-	netif_err(adapter, msglvl, adapter->netdev, format, ## arg)
-#define e_warn(msglvl, format, arg...) \
-	netif_warn(adapter, msglvl, adapter->netdev, format, ## arg)
-#define e_crit(msglvl, format, arg...) \
-	netif_crit(adapter, msglvl, adapter->netdev, format, ## arg)
 #endif /* IXGBE_COMMON */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb.c
index a507a6f..3eee95c 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -27,30 +23,29 @@
 *******************************************************************************/
 
 
-#include "ixgbe.h"
 #include "ixgbe_type.h"
 #include "ixgbe_dcb.h"
 #include "ixgbe_dcb_82598.h"
 #include "ixgbe_dcb_82599.h"
 
 /**
- * ixgbe_ieee_credits - This calculates the ieee traffic class
+ * ixgbe_dcb_calculate_tc_credits - This calculates the ieee traffic class
  * credits from the configured bandwidth percentages. Credits
  * are the smallest unit programmable into the underlying
  * hardware. The IEEE 802.1Qaz specification do not use bandwidth
  * groups so this is much simplified from the CEE case.
  */
-static s32 ixgbe_ieee_credits(__u8 *bw, __u16 *refill,
-			      __u16 *max, int max_frame)
+s32 ixgbe_dcb_calculate_tc_credits(u8 *bw, u16 *refill, u16 *max,
+				   int max_frame_size)
 {
 	int min_percent = 100;
 	int min_credit, multiplier;
 	int i;
 
-	min_credit = ((max_frame / 2) + DCB_CREDIT_QUANTUM - 1) /
-			DCB_CREDIT_QUANTUM;
+	min_credit = ((max_frame_size / 2) + IXGBE_DCB_CREDIT_QUANTUM - 1) /
+			IXGBE_DCB_CREDIT_QUANTUM;
 
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		if (bw[i] < min_percent && bw[i])
 			min_percent = bw[i];
 	}
@@ -58,50 +53,54 @@ static s32 ixgbe_ieee_credits(__u8 *bw, __u16 *refill,
 	multiplier = (min_credit / min_percent) + 1;
 
 	/* Find out the hw credits for each TC */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
-		int val = min(bw[i] * multiplier, MAX_CREDIT_REFILL);
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
+		int val = min(bw[i] * multiplier, IXGBE_DCB_MAX_CREDIT_REFILL);
 
 		if (val < min_credit)
 			val = min_credit;
-		refill[i] = val;
+		refill[i] = (u16)val;
 
-		max[i] = bw[i] ? (bw[i] * MAX_CREDIT)/100 : min_credit;
+		max[i] = bw[i] ? (bw[i]*IXGBE_DCB_MAX_CREDIT)/100 : min_credit;
 	}
+
 	return 0;
 }
 
 /**
- * ixgbe_dcb_calculate_tc_credits - Calculates traffic class credits
+ * ixgbe_dcb_calculate_tc_credits_cee - Calculates traffic class credits
  * @ixgbe_dcb_config: Struct containing DCB settings.
  * @direction: Configuring either Tx or Rx.
  *
  * This function calculates the credits allocated to each traffic class.
  * It should be called only after the rules are checked by
- * ixgbe_dcb_check_config().
+ * ixgbe_dcb_check_config_cee().
  */
-s32 ixgbe_dcb_calculate_tc_credits(struct ixgbe_hw *hw,
+s32 ixgbe_dcb_calculate_tc_credits_cee(struct ixgbe_hw *hw,
 				   struct ixgbe_dcb_config *dcb_config,
-				   int max_frame, u8 direction)
+				   u32 max_frame_size, u8 direction)
 {
-	struct tc_bw_alloc *p;
-	int min_credit;
-	int min_multiplier;
-	int min_percent = 100;
+	struct ixgbe_dcb_tc_path *p;
+	u32 min_multiplier	= 0;
+	u16 min_percent		= 100;
+	s32 ret_val =		IXGBE_SUCCESS;
 	/* Initialization values default for Tx settings */
-	u32 credit_refill       = 0;
-	u32 credit_max          = 0;
-	u16 link_percentage     = 0;
-	u8  bw_percent          = 0;
+	u32 min_credit		= 0;
+	u32 credit_refill	= 0;
+	u32 credit_max		= 0;
+	u16 link_percentage	= 0;
+	u8  bw_percent		= 0;
 	u8  i;
 
-	if (!dcb_config)
-		return DCB_ERR_CONFIG;
+	if (dcb_config == NULL) {
+		ret_val = IXGBE_ERR_CONFIG;
+		goto out;
+	}
 
-	min_credit = ((max_frame / 2) + DCB_CREDIT_QUANTUM - 1) /
-			DCB_CREDIT_QUANTUM;
+	min_credit = ((max_frame_size / 2) + IXGBE_DCB_CREDIT_QUANTUM - 1) /
+		     IXGBE_DCB_CREDIT_QUANTUM;
 
 	/* Find smallest link percentage */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		p = &dcb_config->tc_config[i].path[direction];
 		bw_percent = dcb_config->bw_percentage[direction][p->bwg_id];
 		link_percentage = p->bwg_percent;
@@ -123,7 +122,7 @@ s32 ixgbe_dcb_calculate_tc_credits(struct ixgbe_hw *hw,
 	min_multiplier = (min_credit / min_percent) + 1;
 
 	/* Find out the link percentage for each TC first */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		p = &dcb_config->tc_config[i].path[direction];
 		bw_percent = dcb_config->bw_percentage[direction][p->bwg_id];
 
@@ -138,101 +137,122 @@ s32 ixgbe_dcb_calculate_tc_credits(struct ixgbe_hw *hw,
 
 		/* Calculate credit refill ratio using multiplier */
 		credit_refill = min(link_percentage * min_multiplier,
-				    MAX_CREDIT_REFILL);
+				    (u32)IXGBE_DCB_MAX_CREDIT_REFILL);
+
+		/* Refill at least minimum credit */
+		if (credit_refill < min_credit)
+			credit_refill = min_credit;
+
 		p->data_credits_refill = (u16)credit_refill;
 
 		/* Calculate maximum credit for the TC */
-		credit_max = (link_percentage * MAX_CREDIT) / 100;
+		credit_max = (link_percentage * IXGBE_DCB_MAX_CREDIT) / 100;
 
 		/*
 		 * Adjustment based on rule checking, if the percentage
 		 * of a TC is too small, the maximum credit may not be
 		 * enough to send out a jumbo frame in data plane arbitration.
 		 */
-		if (credit_max && (credit_max < min_credit))
+		if (credit_max < min_credit)
 			credit_max = min_credit;
 
-		if (direction == DCB_TX_CONFIG) {
+		if (direction == IXGBE_DCB_TX_CONFIG) {
 			/*
 			 * Adjustment based on rule checking, if the
 			 * percentage of a TC is too small, the maximum
 			 * credit may not be enough to send out a TSO
 			 * packet in descriptor plane arbitration.
 			 */
-			if ((hw->mac.type == ixgbe_mac_82598EB) &&
-			    credit_max &&
-			    (credit_max < MINIMUM_CREDIT_FOR_TSO))
-				credit_max = MINIMUM_CREDIT_FOR_TSO;
+			if (credit_max && (credit_max <
+			    IXGBE_DCB_MIN_TSO_CREDIT)
+			    && (hw->mac.type == ixgbe_mac_82598EB))
+				credit_max = IXGBE_DCB_MIN_TSO_CREDIT;
 
 			dcb_config->tc_config[i].desc_credits_max =
-				(u16)credit_max;
+								(u16)credit_max;
 		}
 
 		p->data_credits_max = (u16)credit_max;
 	}
 
-	return 0;
+out:
+	return ret_val;
 }
 
-void ixgbe_dcb_unpack_pfc(struct ixgbe_dcb_config *cfg, u8 *pfc_en)
+/**
+ * ixgbe_dcb_unpack_pfc_cee - Unpack dcb_config PFC info
+ * @cfg: dcb configuration to unpack into hardware consumable fields
+ * @map: user priority to traffic class map
+ * @pfc_up: u8 to store user priority PFC bitmask
+ *
+ * This unpacks the dcb configuration PFC info which is stored per
+ * traffic class into a 8bit user priority bitmask that can be
+ * consumed by hardware routines. The priority to tc map must be
+ * updated before calling this routine to use current up-to maps.
+ */
+void ixgbe_dcb_unpack_pfc_cee(struct ixgbe_dcb_config *cfg, u8 *map, u8 *pfc_up)
 {
-	struct tc_configuration *tc_config = &cfg->tc_config[0];
-	int tc;
+	struct ixgbe_dcb_tc_config *tc_config = &cfg->tc_config[0];
+	int up;
 
-	for (*pfc_en = 0, tc = 0; tc < MAX_TRAFFIC_CLASS; tc++) {
-		if (tc_config[tc].dcb_pfc != pfc_disabled)
-			*pfc_en |= 1 << tc;
+	/*
+	 * If the TC for this user priority has PFC enabled then set the
+	 * matching bit in 'pfc_up' to reflect that PFC is enabled.
+	 */
+	for (*pfc_up = 0, up = 0; up < IXGBE_DCB_MAX_USER_PRIORITY; up++) {
+		if (tc_config[map[up]].pfc != ixgbe_dcb_pfc_disabled)
+			*pfc_up |= 1 << up;
 	}
 }
 
-void ixgbe_dcb_unpack_refill(struct ixgbe_dcb_config *cfg, int direction,
+void ixgbe_dcb_unpack_refill_cee(struct ixgbe_dcb_config *cfg, int direction,
 			     u16 *refill)
 {
-	struct tc_configuration *tc_config = &cfg->tc_config[0];
+	struct ixgbe_dcb_tc_config *tc_config = &cfg->tc_config[0];
 	int tc;
 
-	for (tc = 0; tc < MAX_TRAFFIC_CLASS; tc++)
+	for (tc = 0; tc < IXGBE_DCB_MAX_TRAFFIC_CLASS; tc++)
 		refill[tc] = tc_config[tc].path[direction].data_credits_refill;
 }
 
-void ixgbe_dcb_unpack_max(struct ixgbe_dcb_config *cfg, u16 *max)
+void ixgbe_dcb_unpack_max_cee(struct ixgbe_dcb_config *cfg, u16 *max)
 {
-	struct tc_configuration *tc_config = &cfg->tc_config[0];
+	struct ixgbe_dcb_tc_config *tc_config = &cfg->tc_config[0];
 	int tc;
 
-	for (tc = 0; tc < MAX_TRAFFIC_CLASS; tc++)
+	for (tc = 0; tc < IXGBE_DCB_MAX_TRAFFIC_CLASS; tc++)
 		max[tc] = tc_config[tc].desc_credits_max;
 }
 
-void ixgbe_dcb_unpack_bwgid(struct ixgbe_dcb_config *cfg, int direction,
+void ixgbe_dcb_unpack_bwgid_cee(struct ixgbe_dcb_config *cfg, int direction,
 			    u8 *bwgid)
 {
-	struct tc_configuration *tc_config = &cfg->tc_config[0];
+	struct ixgbe_dcb_tc_config *tc_config = &cfg->tc_config[0];
 	int tc;
 
-	for (tc = 0; tc < MAX_TRAFFIC_CLASS; tc++)
+	for (tc = 0; tc < IXGBE_DCB_MAX_TRAFFIC_CLASS; tc++)
 		bwgid[tc] = tc_config[tc].path[direction].bwg_id;
 }
 
-void ixgbe_dcb_unpack_prio(struct ixgbe_dcb_config *cfg, int direction,
-			    u8 *ptype)
+void ixgbe_dcb_unpack_tsa_cee(struct ixgbe_dcb_config *cfg, int direction,
+			   u8 *tsa)
 {
-	struct tc_configuration *tc_config = &cfg->tc_config[0];
+	struct ixgbe_dcb_tc_config *tc_config = &cfg->tc_config[0];
 	int tc;
 
-	for (tc = 0; tc < MAX_TRAFFIC_CLASS; tc++)
-		ptype[tc] = tc_config[tc].path[direction].prio_type;
+	for (tc = 0; tc < IXGBE_DCB_MAX_TRAFFIC_CLASS; tc++)
+		tsa[tc] = tc_config[tc].path[direction].tsa;
 }
 
 u8 ixgbe_dcb_get_tc_from_up(struct ixgbe_dcb_config *cfg, int direction, u8 up)
 {
-	struct tc_configuration *tc_config = &cfg->tc_config[0];
+	struct ixgbe_dcb_tc_config *tc_config = &cfg->tc_config[0];
 	u8 prio_mask = 1 << up;
 	u8 tc = cfg->num_tcs.pg_tcs;
 
 	/* If tc is 0 then DCB is likely not enabled or supported */
 	if (!tc)
-		return 0;
+		goto out;
 
 	/*
 	 * Test from maximum TC to 1 and report the first match we find.  If
@@ -243,159 +263,456 @@ u8 ixgbe_dcb_get_tc_from_up(struct ixgbe_dcb_config *cfg, int direction, u8 up)
 		if (prio_mask & tc_config[tc].path[direction].up_to_tc_bitmap)
 			break;
 	}
-
+out:
 	return tc;
 }
 
-void ixgbe_dcb_unpack_map(struct ixgbe_dcb_config *cfg, int direction, u8 *map)
+void ixgbe_dcb_unpack_map_cee(struct ixgbe_dcb_config *cfg, int direction,
+			      u8 *map)
 {
 	u8 up;
 
-	for (up = 0; up < MAX_USER_PRIORITY; up++)
+	for (up = 0; up < IXGBE_DCB_MAX_USER_PRIORITY; up++)
 		map[up] = ixgbe_dcb_get_tc_from_up(cfg, direction, up);
 }
 
 /**
- * ixgbe_dcb_hw_config - Config and enable DCB
+ * ixgbe_dcb_config - Struct containing DCB settings.
+ * @dcb_config: Pointer to DCB config structure
+ *
+ * This function checks DCB rules for DCB settings.
+ * The following rules are checked:
+ * 1. The sum of bandwidth percentages of all Bandwidth Groups must total 100%.
+ * 2. The sum of bandwidth percentages of all Traffic Classes within a Bandwidth
+ *    Group must total 100.
+ * 3. A Traffic Class should not be set to both Link Strict Priority
+ *    and Group Strict Priority.
+ * 4. Link strict Bandwidth Groups can only have link strict traffic classes
+ *    with zero bandwidth.
+ */
+s32 ixgbe_dcb_check_config_cee(struct ixgbe_dcb_config *dcb_config)
+{
+	struct ixgbe_dcb_tc_path *p;
+	s32 ret_val = IXGBE_SUCCESS;
+	u8 i, j, bw = 0, bw_id;
+	u8 bw_sum[2][IXGBE_DCB_MAX_BW_GROUP];
+	bool link_strict[2][IXGBE_DCB_MAX_BW_GROUP];
+
+	memset(bw_sum, 0, sizeof(bw_sum));
+	memset(link_strict, 0, sizeof(link_strict));
+
+	/* First Tx, then Rx */
+	for (i = 0; i < 2; i++) {
+		/* Check each traffic class for rule violation */
+		for (j = 0; j < IXGBE_DCB_MAX_TRAFFIC_CLASS; j++) {
+			p = &dcb_config->tc_config[j].path[i];
+
+			bw = p->bwg_percent;
+			bw_id = p->bwg_id;
+
+			if (bw_id >= IXGBE_DCB_MAX_BW_GROUP) {
+				ret_val = IXGBE_ERR_CONFIG;
+				goto err_config;
+			}
+			if (p->tsa == ixgbe_dcb_tsa_strict) {
+				link_strict[i][bw_id] = true;
+				/* Link strict should have zero bandwidth */
+				if (bw) {
+					ret_val = IXGBE_ERR_CONFIG;
+					goto err_config;
+				}
+			} else if (!bw) {
+				/*
+				 * Traffic classes without link strict
+				 * should have non-zero bandwidth.
+				 */
+				ret_val = IXGBE_ERR_CONFIG;
+				goto err_config;
+			}
+			bw_sum[i][bw_id] += bw;
+		}
+
+		bw = 0;
+
+		/* Check each bandwidth group for rule violation */
+		for (j = 0; j < IXGBE_DCB_MAX_BW_GROUP; j++) {
+			bw += dcb_config->bw_percentage[i][j];
+			/*
+			 * Sum of bandwidth percentages of all traffic classes
+			 * within a Bandwidth Group must total 100 except for
+			 * link strict group (zero bandwidth).
+			 */
+			if (link_strict[i][j]) {
+				if (bw_sum[i][j]) {
+					/*
+					 * Link strict group should have zero
+					 * bandwidth.
+					 */
+					ret_val = IXGBE_ERR_CONFIG;
+					goto err_config;
+				}
+			} else if (bw_sum[i][j] != IXGBE_DCB_BW_PERCENT &&
+				   bw_sum[i][j] != 0) {
+				ret_val = IXGBE_ERR_CONFIG;
+				goto err_config;
+			}
+		}
+
+		if (bw != IXGBE_DCB_BW_PERCENT) {
+			ret_val = IXGBE_ERR_CONFIG;
+			goto err_config;
+		}
+	}
+
+err_config:
+
+	return ret_val;
+}
+
+/**
+ * ixgbe_dcb_get_tc_stats - Returns status of each traffic class
+ * @hw: pointer to hardware structure
+ * @stats: pointer to statistics structure
+ * @tc_count:  Number of elements in bwg_array.
+ *
+ * This function returns the status data for each of the Traffic Classes in use.
+ */
+s32 ixgbe_dcb_get_tc_stats(struct ixgbe_hw *hw, struct ixgbe_hw_stats *stats,
+			   u8 tc_count)
+{
+	s32 ret = IXGBE_NOT_IMPLEMENTED;
+	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		ret = ixgbe_dcb_get_tc_stats_82598(hw, stats, tc_count);
+		break;
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		ret = ixgbe_dcb_get_tc_stats_82599(hw, stats, tc_count);
+		break;
+	default:
+		break;
+	}
+	return ret;
+}
+
+/**
+ * ixgbe_dcb_get_pfc_stats - Returns CBFC status of each traffic class
+ * @hw: pointer to hardware structure
+ * @stats: pointer to statistics structure
+ * @tc_count:  Number of elements in bwg_array.
+ *
+ * This function returns the CBFC status data for each of the Traffic Classes.
+ */
+s32 ixgbe_dcb_get_pfc_stats(struct ixgbe_hw *hw, struct ixgbe_hw_stats *stats,
+			    u8 tc_count)
+{
+	s32 ret = IXGBE_NOT_IMPLEMENTED;
+	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		ret = ixgbe_dcb_get_pfc_stats_82598(hw, stats, tc_count);
+		break;
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		ret = ixgbe_dcb_get_pfc_stats_82599(hw, stats, tc_count);
+		break;
+	default:
+		break;
+	}
+	return ret;
+}
+
+/**
+ * ixgbe_dcb_config_rx_arbiter_cee - Config Rx arbiter
  * @hw: pointer to hardware structure
  * @dcb_config: pointer to ixgbe_dcb_config structure
  *
- * Configure dcb settings and enable dcb mode.
+ * Configure Rx Data Arbiter and credits for each traffic class.
  */
-s32 ixgbe_dcb_hw_config(struct ixgbe_hw *hw,
-			struct ixgbe_dcb_config *dcb_config)
+s32 ixgbe_dcb_config_rx_arbiter_cee(struct ixgbe_hw *hw,
+				struct ixgbe_dcb_config *dcb_config)
 {
-	u8 pfc_en;
-	u8 ptype[MAX_TRAFFIC_CLASS];
-	u8 bwgid[MAX_TRAFFIC_CLASS];
-	u8 prio_tc[MAX_TRAFFIC_CLASS];
-	u16 refill[MAX_TRAFFIC_CLASS];
-	u16 max[MAX_TRAFFIC_CLASS];
+	s32 ret = IXGBE_NOT_IMPLEMENTED;
+	u8 tsa[IXGBE_DCB_MAX_TRAFFIC_CLASS]	= { 0 };
+	u8 bwgid[IXGBE_DCB_MAX_TRAFFIC_CLASS]	= { 0 };
+	u8 map[IXGBE_DCB_MAX_USER_PRIORITY]	= { 0 };
+	u16 refill[IXGBE_DCB_MAX_TRAFFIC_CLASS]	= { 0 };
+	u16 max[IXGBE_DCB_MAX_TRAFFIC_CLASS]	= { 0 };
+
+	ixgbe_dcb_unpack_refill_cee(dcb_config, IXGBE_DCB_TX_CONFIG, refill);
+	ixgbe_dcb_unpack_max_cee(dcb_config, max);
+	ixgbe_dcb_unpack_bwgid_cee(dcb_config, IXGBE_DCB_TX_CONFIG, bwgid);
+	ixgbe_dcb_unpack_tsa_cee(dcb_config, IXGBE_DCB_TX_CONFIG, tsa);
+	ixgbe_dcb_unpack_map_cee(dcb_config, IXGBE_DCB_TX_CONFIG, map);
 
-	/* Unpack CEE standard containers */
-	ixgbe_dcb_unpack_pfc(dcb_config, &pfc_en);
-	ixgbe_dcb_unpack_refill(dcb_config, DCB_TX_CONFIG, refill);
-	ixgbe_dcb_unpack_max(dcb_config, max);
-	ixgbe_dcb_unpack_bwgid(dcb_config, DCB_TX_CONFIG, bwgid);
-	ixgbe_dcb_unpack_prio(dcb_config, DCB_TX_CONFIG, ptype);
-	ixgbe_dcb_unpack_map(dcb_config, DCB_TX_CONFIG, prio_tc);
+	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		ret = ixgbe_dcb_config_rx_arbiter_82598(hw, refill, max, tsa);
+		break;
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		ret = ixgbe_dcb_config_rx_arbiter_82599(hw, refill, max, bwgid,
+							tsa, map);
+		break;
+	default:
+		break;
+	}
+	return ret;
+}
+
+/**
+ * ixgbe_dcb_config_tx_desc_arbiter_cee - Config Tx Desc arbiter
+ * @hw: pointer to hardware structure
+ * @dcb_config: pointer to ixgbe_dcb_config structure
+ *
+ * Configure Tx Descriptor Arbiter and credits for each traffic class.
+ */
+s32 ixgbe_dcb_config_tx_desc_arbiter_cee(struct ixgbe_hw *hw,
+				     struct ixgbe_dcb_config *dcb_config)
+{
+	s32 ret = IXGBE_NOT_IMPLEMENTED;
+	u8 tsa[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+	u8 bwgid[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+	u16 refill[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+	u16 max[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+
+	ixgbe_dcb_unpack_refill_cee(dcb_config, IXGBE_DCB_TX_CONFIG, refill);
+	ixgbe_dcb_unpack_max_cee(dcb_config, max);
+	ixgbe_dcb_unpack_bwgid_cee(dcb_config, IXGBE_DCB_TX_CONFIG, bwgid);
+	ixgbe_dcb_unpack_tsa_cee(dcb_config, IXGBE_DCB_TX_CONFIG, tsa);
 
 	switch (hw->mac.type) {
 	case ixgbe_mac_82598EB:
-		return ixgbe_dcb_hw_config_82598(hw, pfc_en, refill, max,
-						 bwgid, ptype);
+		ret = ixgbe_dcb_config_tx_desc_arbiter_82598(hw, refill, max,
+							     bwgid, tsa);
+		break;
 	case ixgbe_mac_82599EB:
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
-		return ixgbe_dcb_hw_config_82599(hw, pfc_en, refill, max,
-						 bwgid, ptype, prio_tc);
+	case ixgbe_mac_X550EM_a:
+		ret = ixgbe_dcb_config_tx_desc_arbiter_82599(hw, refill, max,
+							     bwgid, tsa);
+		break;
 	default:
 		break;
 	}
-	return 0;
+	return ret;
 }
 
-/* Helper routines to abstract HW specifics from DCB netlink ops */
-s32 ixgbe_dcb_hw_pfc_config(struct ixgbe_hw *hw, u8 pfc_en, u8 *prio_tc)
+/**
+ * ixgbe_dcb_config_tx_data_arbiter_cee - Config Tx data arbiter
+ * @hw: pointer to hardware structure
+ * @dcb_config: pointer to ixgbe_dcb_config structure
+ *
+ * Configure Tx Data Arbiter and credits for each traffic class.
+ */
+s32 ixgbe_dcb_config_tx_data_arbiter_cee(struct ixgbe_hw *hw,
+				     struct ixgbe_dcb_config *dcb_config)
 {
+	s32 ret = IXGBE_NOT_IMPLEMENTED;
+	u8 tsa[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+	u8 bwgid[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+	u8 map[IXGBE_DCB_MAX_USER_PRIORITY] = { 0 };
+	u16 refill[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+	u16 max[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+
+	ixgbe_dcb_unpack_refill_cee(dcb_config, IXGBE_DCB_TX_CONFIG, refill);
+	ixgbe_dcb_unpack_max_cee(dcb_config, max);
+	ixgbe_dcb_unpack_bwgid_cee(dcb_config, IXGBE_DCB_TX_CONFIG, bwgid);
+	ixgbe_dcb_unpack_tsa_cee(dcb_config, IXGBE_DCB_TX_CONFIG, tsa);
+	ixgbe_dcb_unpack_map_cee(dcb_config, IXGBE_DCB_TX_CONFIG, map);
+
 	switch (hw->mac.type) {
 	case ixgbe_mac_82598EB:
-		return ixgbe_dcb_config_pfc_82598(hw, pfc_en);
+		ret = ixgbe_dcb_config_tx_data_arbiter_82598(hw, refill, max,
+							     bwgid, tsa);
+		break;
 	case ixgbe_mac_82599EB:
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
-		return ixgbe_dcb_config_pfc_82599(hw, pfc_en, prio_tc);
+	case ixgbe_mac_X550EM_a:
+		ret = ixgbe_dcb_config_tx_data_arbiter_82599(hw, refill, max,
+							     bwgid, tsa,
+							     map);
+		break;
 	default:
 		break;
 	}
-	return -EINVAL;
+	return ret;
 }
 
-s32 ixgbe_dcb_hw_ets(struct ixgbe_hw *hw, struct ieee_ets *ets, int max_frame)
+/**
+ * ixgbe_dcb_config_pfc_cee - Config priority flow control
+ * @hw: pointer to hardware structure
+ * @dcb_config: pointer to ixgbe_dcb_config structure
+ *
+ * Configure Priority Flow Control for each traffic class.
+ */
+s32 ixgbe_dcb_config_pfc_cee(struct ixgbe_hw *hw,
+			 struct ixgbe_dcb_config *dcb_config)
 {
-	__u16 refill[IEEE_8021QAZ_MAX_TCS], max[IEEE_8021QAZ_MAX_TCS];
-	__u8 prio_type[IEEE_8021QAZ_MAX_TCS];
-	int i;
+	s32 ret = IXGBE_NOT_IMPLEMENTED;
+	u8 pfc_en;
+	u8 map[IXGBE_DCB_MAX_USER_PRIORITY] = { 0 };
 
-	/* naively give each TC a bwg to map onto CEE hardware */
-	__u8 bwg_id[IEEE_8021QAZ_MAX_TCS] = {0, 1, 2, 3, 4, 5, 6, 7};
+	ixgbe_dcb_unpack_map_cee(dcb_config, IXGBE_DCB_TX_CONFIG, map);
+	ixgbe_dcb_unpack_pfc_cee(dcb_config, map, &pfc_en);
 
-	/* Map TSA onto CEE prio type */
-	for (i = 0; i < IEEE_8021QAZ_MAX_TCS; i++) {
-		switch (ets->tc_tsa[i]) {
-		case IEEE_8021QAZ_TSA_STRICT:
-			prio_type[i] = 2;
-			break;
-		case IEEE_8021QAZ_TSA_ETS:
-			prio_type[i] = 0;
-			break;
-		default:
-			/* Hardware only supports priority strict or
-			 * ETS transmission selection algorithms if
-			 * we receive some other value from dcbnl
-			 * throw an error
-			 */
-			return -EINVAL;
-		}
+	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		ret = ixgbe_dcb_config_pfc_82598(hw, pfc_en);
+		break;
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		ret = ixgbe_dcb_config_pfc_82599(hw, pfc_en, map);
+		break;
+	default:
+		break;
 	}
+	return ret;
+}
 
-	ixgbe_ieee_credits(ets->tc_tx_bw, refill, max, max_frame);
-	return ixgbe_dcb_hw_ets_config(hw, refill, max,
-				       bwg_id, prio_type, ets->prio_tc);
+/**
+ * ixgbe_dcb_config_tc_stats - Config traffic class statistics
+ * @hw: pointer to hardware structure
+ *
+ * Configure queue statistics registers, all queues belonging to same traffic
+ * class uses a single set of queue statistics counters.
+ */
+s32 ixgbe_dcb_config_tc_stats(struct ixgbe_hw *hw)
+{
+	s32 ret = IXGBE_NOT_IMPLEMENTED;
+	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		ret = ixgbe_dcb_config_tc_stats_82598(hw);
+		break;
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		ret = ixgbe_dcb_config_tc_stats_82599(hw, NULL);
+		break;
+	default:
+		break;
+	}
+	return ret;
 }
 
-s32 ixgbe_dcb_hw_ets_config(struct ixgbe_hw *hw,
-			    u16 *refill, u16 *max, u8 *bwg_id,
-			    u8 *prio_type, u8 *prio_tc)
+/**
+ * ixgbe_dcb_hw_config_cee - Config and enable DCB
+ * @hw: pointer to hardware structure
+ * @dcb_config: pointer to ixgbe_dcb_config structure
+ *
+ * Configure dcb settings and enable dcb mode.
+ */
+s32 ixgbe_dcb_hw_config_cee(struct ixgbe_hw *hw,
+			struct ixgbe_dcb_config *dcb_config)
 {
+	s32 ret = IXGBE_NOT_IMPLEMENTED;
+	u8 pfc_en;
+	u8 tsa[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+	u8 bwgid[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+	u8 map[IXGBE_DCB_MAX_USER_PRIORITY] = { 0 };
+	u16 refill[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+	u16 max[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+
+	/* Unpack CEE standard containers */
+	ixgbe_dcb_unpack_refill_cee(dcb_config, IXGBE_DCB_TX_CONFIG, refill);
+	ixgbe_dcb_unpack_max_cee(dcb_config, max);
+	ixgbe_dcb_unpack_bwgid_cee(dcb_config, IXGBE_DCB_TX_CONFIG, bwgid);
+	ixgbe_dcb_unpack_tsa_cee(dcb_config, IXGBE_DCB_TX_CONFIG, tsa);
+	ixgbe_dcb_unpack_map_cee(dcb_config, IXGBE_DCB_TX_CONFIG, map);
+
 	switch (hw->mac.type) {
 	case ixgbe_mac_82598EB:
-		ixgbe_dcb_config_rx_arbiter_82598(hw, refill, max,
-							prio_type);
-		ixgbe_dcb_config_tx_desc_arbiter_82598(hw, refill, max,
-							     bwg_id, prio_type);
-		ixgbe_dcb_config_tx_data_arbiter_82598(hw, refill, max,
-							     bwg_id, prio_type);
+		ret = ixgbe_dcb_hw_config_82598(hw, dcb_config->link_speed,
+						refill, max, bwgid, tsa);
 		break;
 	case ixgbe_mac_82599EB:
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
-		ixgbe_dcb_config_rx_arbiter_82599(hw, refill, max,
-						  bwg_id, prio_type, prio_tc);
-		ixgbe_dcb_config_tx_desc_arbiter_82599(hw, refill, max,
-						       bwg_id, prio_type);
-		ixgbe_dcb_config_tx_data_arbiter_82599(hw, refill, max, bwg_id,
-						       prio_type, prio_tc);
+	case ixgbe_mac_X550EM_a:
+		ixgbe_dcb_config_82599(hw, dcb_config);
+		ret = ixgbe_dcb_hw_config_82599(hw, dcb_config->link_speed,
+						refill, max, bwgid,
+						tsa, map);
+
+		ixgbe_dcb_config_tc_stats_82599(hw, dcb_config);
 		break;
 	default:
 		break;
 	}
-	return 0;
+
+	if (!ret && dcb_config->pfc_mode_enable) {
+		ixgbe_dcb_unpack_pfc_cee(dcb_config, map, &pfc_en);
+		ret = ixgbe_dcb_config_pfc(hw, pfc_en, map);
+	}
+
+	return ret;
 }
 
-static void ixgbe_dcb_read_rtrup2tc_82599(struct ixgbe_hw *hw, u8 *map)
+/* Helper routines to abstract HW specifics from DCB netlink ops */
+s32 ixgbe_dcb_config_pfc(struct ixgbe_hw *hw, u8 pfc_en, u8 *map)
 {
-	u32 reg, i;
+	int ret = IXGBE_ERR_PARAM;
 
-	reg = IXGBE_READ_REG(hw, IXGBE_RTRUP2TC);
-	for (i = 0; i < MAX_USER_PRIORITY; i++)
-		map[i] = IXGBE_RTRUP2TC_UP_MASK &
-			(reg >> (i * IXGBE_RTRUP2TC_UP_SHIFT));
+	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		ret = ixgbe_dcb_config_pfc_82598(hw, pfc_en);
+		break;
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		ret = ixgbe_dcb_config_pfc_82599(hw, pfc_en, map);
+		break;
+	default:
+		break;
+	}
+	return ret;
 }
 
-void ixgbe_dcb_read_rtrup2tc(struct ixgbe_hw *hw, u8 *map)
+s32 ixgbe_dcb_hw_config(struct ixgbe_hw *hw, u16 *refill, u16 *max,
+			    u8 *bwg_id, u8 *tsa, u8 *map)
 {
 	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		ixgbe_dcb_config_rx_arbiter_82598(hw, refill, max, tsa);
+		ixgbe_dcb_config_tx_desc_arbiter_82598(hw, refill, max, bwg_id,
+						       tsa);
+		ixgbe_dcb_config_tx_data_arbiter_82598(hw, refill, max, bwg_id,
+						       tsa);
+		break;
 	case ixgbe_mac_82599EB:
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
-		ixgbe_dcb_read_rtrup2tc_82599(hw, map);
+	case ixgbe_mac_X550EM_a:
+		ixgbe_dcb_config_rx_arbiter_82599(hw, refill, max, bwg_id,
+						  tsa, map);
+		ixgbe_dcb_config_tx_desc_arbiter_82599(hw, refill, max, bwg_id,
+						       tsa);
+		ixgbe_dcb_config_tx_data_arbiter_82599(hw, refill, max, bwg_id,
+						       tsa, map);
 		break;
 	default:
 		break;
 	}
+	return 0;
 }
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb.h
index fc0a2dd..d19c3c2 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb.h
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb.h
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,146 +22,144 @@
 
 *******************************************************************************/
 
-#ifndef _DCB_CONFIG_H_
-#define _DCB_CONFIG_H_
+#ifndef _IXGBE_DCB_H_
+#define _IXGBE_DCB_H_
 
-#include <linux/dcbnl.h>
 #include "ixgbe_type.h"
 
-/* DCB data structures */
-
-#define IXGBE_MAX_PACKET_BUFFERS 8
-#define MAX_USER_PRIORITY        8
-#define MAX_BW_GROUP             8
-#define BW_PERCENT               100
-
-#define DCB_TX_CONFIG            0
-#define DCB_RX_CONFIG            1
-
-/* DCB error Codes */
-#define DCB_SUCCESS              0
-#define DCB_ERR_CONFIG           -1
-#define DCB_ERR_PARAM            -2
-
-/* Transmit and receive Errors */
-/* Error in bandwidth group allocation */
-#define DCB_ERR_BW_GROUP        -3
-/* Error in traffic class bandwidth allocation */
-#define DCB_ERR_TC_BW           -4
-/* Traffic class has both link strict and group strict enabled */
-#define DCB_ERR_LS_GS           -5
-/* Link strict traffic class has non zero bandwidth */
-#define DCB_ERR_LS_BW_NONZERO   -6
-/* Link strict bandwidth group has non zero bandwidth */
-#define DCB_ERR_LS_BWG_NONZERO  -7
-/*  Traffic class has zero bandwidth */
-#define DCB_ERR_TC_BW_ZERO      -8
-
-#define DCB_NOT_IMPLEMENTED      0x7FFFFFFF
-
-struct dcb_pfc_tc_debug {
-	u8  tc;
-	u8  pause_status;
-	u64 pause_quanta;
-};
+/* DCB defines */
+/* DCB credit calculation defines */
+#define IXGBE_DCB_CREDIT_QUANTUM	64
+#define IXGBE_DCB_MAX_CREDIT_REFILL	200   /* 200 * 64B = 12800B */
+#define IXGBE_DCB_MAX_TSO_SIZE		(32 * 1024) /* Max TSO pkt size in DCB*/
+#define IXGBE_DCB_MAX_CREDIT		(2 * IXGBE_DCB_MAX_CREDIT_REFILL)
 
-enum strict_prio_type {
-	prio_none = 0,
-	prio_group,
-	prio_link
-};
+/* 513 for 32KB TSO packet */
+#define IXGBE_DCB_MIN_TSO_CREDIT	\
+	((IXGBE_DCB_MAX_TSO_SIZE / IXGBE_DCB_CREDIT_QUANTUM) + 1)
 
-/* DCB capability definitions */
-#define IXGBE_DCB_PG_SUPPORT        0x00000001
-#define IXGBE_DCB_PFC_SUPPORT       0x00000002
-#define IXGBE_DCB_BCN_SUPPORT       0x00000004
-#define IXGBE_DCB_UP2TC_SUPPORT     0x00000008
-#define IXGBE_DCB_GSP_SUPPORT       0x00000010
+/* DCB configuration defines */
+#define IXGBE_DCB_MAX_USER_PRIORITY	8
+#define IXGBE_DCB_MAX_BW_GROUP		8
+#define IXGBE_DCB_BW_PERCENT		100
 
-#define IXGBE_DCB_8_TC_SUPPORT      0x80
+#define IXGBE_DCB_TX_CONFIG		0
+#define IXGBE_DCB_RX_CONFIG		1
 
-struct dcb_support {
-	/* DCB capabilities */
-	u32 capabilities;
+/* DCB capability defines */
+#define IXGBE_DCB_PG_SUPPORT	0x00000001
+#define IXGBE_DCB_PFC_SUPPORT	0x00000002
+#define IXGBE_DCB_BCN_SUPPORT	0x00000004
+#define IXGBE_DCB_UP2TC_SUPPORT	0x00000008
+#define IXGBE_DCB_GSP_SUPPORT	0x00000010
+
+struct ixgbe_dcb_support {
+	u32 capabilities; /* DCB capabilities */
 
 	/* Each bit represents a number of TCs configurable in the hw.
-	 * If 8 traffic classes can be configured, the value is 0x80.
-	 */
-	u8  traffic_classes;
-	u8  pfc_traffic_classes;
+	 * If 8 traffic classes can be configured, the value is 0x80. */
+	u8 traffic_classes;
+	u8 pfc_traffic_classes;
+};
+
+enum ixgbe_dcb_tsa {
+	ixgbe_dcb_tsa_ets = 0,
+	ixgbe_dcb_tsa_group_strict_cee,
+	ixgbe_dcb_tsa_strict
 };
 
 /* Traffic class bandwidth allocation per direction */
-struct tc_bw_alloc {
-	u8 bwg_id;		  /* Bandwidth Group (BWG) ID */
-	u8 bwg_percent;		  /* % of BWG's bandwidth */
-	u8 link_percent;	  /* % of link bandwidth */
-	u8 up_to_tc_bitmap;	  /* User Priority to Traffic Class mapping */
-	u16 data_credits_refill;  /* Credit refill amount in 64B granularity */
-	u16 data_credits_max;	  /* Max credits for a configured packet buffer
-				   * in 64B granularity.*/
-	enum strict_prio_type prio_type; /* Link or Group Strict Priority */
+struct ixgbe_dcb_tc_path {
+	u8 bwg_id; /* Bandwidth Group (BWG) ID */
+	u8 bwg_percent; /* % of BWG's bandwidth */
+	u8 link_percent; /* % of link bandwidth */
+	u8 up_to_tc_bitmap; /* User Priority to Traffic Class mapping */
+	u16 data_credits_refill; /* Credit refill amount in 64B granularity */
+	u16 data_credits_max; /* Max credits for a configured packet buffer
+			       * in 64B granularity.*/
+	enum ixgbe_dcb_tsa tsa; /* Link or Group Strict Priority */
 };
 
-enum dcb_pfc_type {
-	pfc_disabled = 0,
-	pfc_enabled_full,
-	pfc_enabled_tx,
-	pfc_enabled_rx
+enum ixgbe_dcb_pfc {
+	ixgbe_dcb_pfc_disabled = 0,
+	ixgbe_dcb_pfc_enabled,
+	ixgbe_dcb_pfc_enabled_txonly,
+	ixgbe_dcb_pfc_enabled_rxonly
 };
 
 /* Traffic class configuration */
-struct tc_configuration {
-	struct tc_bw_alloc path[2]; /* One each for Tx/Rx */
-	enum dcb_pfc_type  dcb_pfc; /* Class based flow control setting */
+struct ixgbe_dcb_tc_config {
+	struct ixgbe_dcb_tc_path path[2]; /* One each for Tx/Rx */
+	enum ixgbe_dcb_pfc pfc; /* Class based flow control setting */
 
 	u16 desc_credits_max; /* For Tx Descriptor arbitration */
 	u8 tc; /* Traffic class (TC) */
 };
 
-struct dcb_num_tcs {
+enum ixgbe_dcb_pba {
+	/* PBA[0-7] each use 64KB FIFO */
+	ixgbe_dcb_pba_equal = PBA_STRATEGY_EQUAL,
+	/* PBA[0-3] each use 80KB, PBA[4-7] each use 48KB */
+	ixgbe_dcb_pba_80_48 = PBA_STRATEGY_WEIGHTED
+};
+
+struct ixgbe_dcb_num_tcs {
 	u8 pg_tcs;
 	u8 pfc_tcs;
 };
 
 struct ixgbe_dcb_config {
-	struct dcb_support support;
-	struct dcb_num_tcs num_tcs;
-	struct tc_configuration tc_config[MAX_TRAFFIC_CLASS];
-	u8     bw_percentage[2][MAX_BW_GROUP]; /* One each for Tx/Rx */
-	bool   pfc_mode_enable;
-
-	u32  dcb_cfg_version; /* Not used...OS-specific? */
-	u32  link_speed; /* For bandwidth allocation validation purpose */
+	struct ixgbe_dcb_tc_config tc_config[IXGBE_DCB_MAX_TRAFFIC_CLASS];
+	struct ixgbe_dcb_support support;
+	struct ixgbe_dcb_num_tcs num_tcs;
+	u8 bw_percentage[2][IXGBE_DCB_MAX_BW_GROUP]; /* One each for Tx/Rx */
+	bool pfc_mode_enable;
+	bool round_robin_enable;
+
+	enum ixgbe_dcb_pba rx_pba_cfg;
+
+	u32 dcb_cfg_version; /* Not used...OS-specific? */
+	u32 link_speed; /* For bandwidth allocation validation purpose */
+	bool vt_mode;
 };
 
 /* DCB driver APIs */
-void ixgbe_dcb_unpack_pfc(struct ixgbe_dcb_config *cfg, u8 *pfc_en);
-void ixgbe_dcb_unpack_refill(struct ixgbe_dcb_config *, int, u16 *);
-void ixgbe_dcb_unpack_max(struct ixgbe_dcb_config *, u16 *);
-void ixgbe_dcb_unpack_bwgid(struct ixgbe_dcb_config *, int, u8 *);
-void ixgbe_dcb_unpack_prio(struct ixgbe_dcb_config *, int, u8 *);
-void ixgbe_dcb_unpack_map(struct ixgbe_dcb_config *, int, u8 *);
-u8 ixgbe_dcb_get_tc_from_up(struct ixgbe_dcb_config *, int, u8);
+
+/* DCB rule checking */
+s32 ixgbe_dcb_check_config_cee(struct ixgbe_dcb_config *);
 
 /* DCB credits calculation */
-s32 ixgbe_dcb_calculate_tc_credits(struct ixgbe_hw *,
-				   struct ixgbe_dcb_config *, int, u8);
-
-/* DCB hw initialization */
-s32 ixgbe_dcb_hw_ets(struct ixgbe_hw *hw, struct ieee_ets *ets, int max);
-s32 ixgbe_dcb_hw_ets_config(struct ixgbe_hw *hw, u16 *refill, u16 *max,
-			    u8 *bwg_id, u8 *prio_type, u8 *tc_prio);
-s32 ixgbe_dcb_hw_pfc_config(struct ixgbe_hw *hw, u8 pfc_en, u8 *tc_prio);
-s32 ixgbe_dcb_hw_config(struct ixgbe_hw *, struct ixgbe_dcb_config *);
-
-void ixgbe_dcb_read_rtrup2tc(struct ixgbe_hw *hw, u8 *map);
-
-/* DCB definitions for credit calculation */
-#define DCB_CREDIT_QUANTUM	64   /* DCB Quantum */
-#define MAX_CREDIT_REFILL       511  /* 0x1FF * 64B = 32704B */
-#define DCB_MAX_TSO_SIZE        (32*1024) /* MAX TSO packet size supported in DCB mode */
-#define MINIMUM_CREDIT_FOR_TSO  (DCB_MAX_TSO_SIZE/64 + 1) /* 513 for 32KB TSO packet */
-#define MAX_CREDIT              4095 /* Maximum credit supported: 256KB * 1204 / 64B */
-
-#endif /* _DCB_CONFIG_H */
+s32 ixgbe_dcb_calculate_tc_credits(u8 *, u16 *, u16 *, int);
+s32 ixgbe_dcb_calculate_tc_credits_cee(struct ixgbe_hw *,
+				       struct ixgbe_dcb_config *, u32, u8);
+
+/* DCB PFC */
+s32 ixgbe_dcb_config_pfc(struct ixgbe_hw *, u8, u8 *);
+s32 ixgbe_dcb_config_pfc_cee(struct ixgbe_hw *, struct ixgbe_dcb_config *);
+
+/* DCB stats */
+s32 ixgbe_dcb_config_tc_stats(struct ixgbe_hw *);
+s32 ixgbe_dcb_get_tc_stats(struct ixgbe_hw *, struct ixgbe_hw_stats *, u8);
+s32 ixgbe_dcb_get_pfc_stats(struct ixgbe_hw *, struct ixgbe_hw_stats *, u8);
+
+/* DCB config arbiters */
+s32 ixgbe_dcb_config_tx_desc_arbiter_cee(struct ixgbe_hw *,
+					 struct ixgbe_dcb_config *);
+s32 ixgbe_dcb_config_tx_data_arbiter_cee(struct ixgbe_hw *,
+					 struct ixgbe_dcb_config *);
+s32 ixgbe_dcb_config_rx_arbiter_cee(struct ixgbe_hw *,
+				    struct ixgbe_dcb_config *);
+
+/* DCB unpack routines */
+void ixgbe_dcb_unpack_pfc_cee(struct ixgbe_dcb_config *, u8 *, u8 *);
+void ixgbe_dcb_unpack_refill_cee(struct ixgbe_dcb_config *, int, u16 *);
+void ixgbe_dcb_unpack_max_cee(struct ixgbe_dcb_config *, u16 *);
+void ixgbe_dcb_unpack_bwgid_cee(struct ixgbe_dcb_config *, int, u8 *);
+void ixgbe_dcb_unpack_tsa_cee(struct ixgbe_dcb_config *, int, u8 *);
+void ixgbe_dcb_unpack_map_cee(struct ixgbe_dcb_config *, int, u8 *);
+u8 ixgbe_dcb_get_tc_from_up(struct ixgbe_dcb_config *, int, u8);
+
+/* DCB initialization */
+s32 ixgbe_dcb_hw_config(struct ixgbe_hw *, u16 *, u16 *, u8 *, u8 *, u8 *);
+s32 ixgbe_dcb_hw_config_cee(struct ixgbe_hw *, struct ixgbe_dcb_config *);
+#endif /* _IXGBE_DCB_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82598.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82598.c
index d3ba63f..b1d8df9 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82598.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82598.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,27 +22,96 @@
 
 *******************************************************************************/
 
-#include "ixgbe.h"
+
 #include "ixgbe_type.h"
 #include "ixgbe_dcb.h"
 #include "ixgbe_dcb_82598.h"
 
 /**
+ * ixgbe_dcb_get_tc_stats_82598 - Return status data for each traffic class
+ * @hw: pointer to hardware structure
+ * @stats: pointer to statistics structure
+ * @tc_count:  Number of elements in bwg_array.
+ *
+ * This function returns the status data for each of the Traffic Classes in use.
+ */
+s32 ixgbe_dcb_get_tc_stats_82598(struct ixgbe_hw *hw,
+				 struct ixgbe_hw_stats *stats,
+				 u8 tc_count)
+{
+	int tc;
+
+	DEBUGFUNC("dcb_get_tc_stats");
+
+	if (tc_count > IXGBE_DCB_MAX_TRAFFIC_CLASS)
+		return IXGBE_ERR_PARAM;
+
+	/* Statistics pertaining to each traffic class */
+	for (tc = 0; tc < tc_count; tc++) {
+		/* Transmitted Packets */
+		stats->qptc[tc] += IXGBE_READ_REG(hw, IXGBE_QPTC(tc));
+		/* Transmitted Bytes */
+		stats->qbtc[tc] += IXGBE_READ_REG(hw, IXGBE_QBTC(tc));
+		/* Received Packets */
+		stats->qprc[tc] += IXGBE_READ_REG(hw, IXGBE_QPRC(tc));
+		/* Received Bytes */
+		stats->qbrc[tc] += IXGBE_READ_REG(hw, IXGBE_QBRC(tc));
+
+#if 0
+		/* Can we get rid of these??  Consequently, getting rid
+		 * of the tc_stats structure.
+		 */
+		tc_stats_array[up]->in_overflow_discards = 0;
+		tc_stats_array[up]->out_overflow_discards = 0;
+#endif
+	}
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ * ixgbe_dcb_get_pfc_stats_82598 - Returns CBFC status data
+ * @hw: pointer to hardware structure
+ * @stats: pointer to statistics structure
+ * @tc_count:  Number of elements in bwg_array.
+ *
+ * This function returns the CBFC status data for each of the Traffic Classes.
+ */
+s32 ixgbe_dcb_get_pfc_stats_82598(struct ixgbe_hw *hw,
+				  struct ixgbe_hw_stats *stats,
+				  u8 tc_count)
+{
+	int tc;
+
+	DEBUGFUNC("dcb_get_pfc_stats");
+
+	if (tc_count > IXGBE_DCB_MAX_TRAFFIC_CLASS)
+		return IXGBE_ERR_PARAM;
+
+	for (tc = 0; tc < tc_count; tc++) {
+		/* Priority XOFF Transmitted */
+		stats->pxofftxc[tc] += IXGBE_READ_REG(hw, IXGBE_PXOFFTXC(tc));
+		/* Priority XOFF Received */
+		stats->pxoffrxc[tc] += IXGBE_READ_REG(hw, IXGBE_PXOFFRXC(tc));
+	}
+
+	return IXGBE_SUCCESS;
+}
+
+/**
  * ixgbe_dcb_config_rx_arbiter_82598 - Config Rx data arbiter
  * @hw: pointer to hardware structure
  * @dcb_config: pointer to ixgbe_dcb_config structure
  *
  * Configure Rx Data Arbiter and credits for each traffic class.
  */
-s32 ixgbe_dcb_config_rx_arbiter_82598(struct ixgbe_hw *hw,
-					u16 *refill,
-					u16 *max,
-					u8 *prio_type)
+s32 ixgbe_dcb_config_rx_arbiter_82598(struct ixgbe_hw *hw, u16 *refill,
+				      u16 *max, u8 *tsa)
 {
-	u32    reg           = 0;
-	u32    credit_refill = 0;
-	u32    credit_max    = 0;
-	u8     i             = 0;
+	u32 reg = 0;
+	u32 credit_refill = 0;
+	u32 credit_max = 0;
+	u8 i = 0;
 
 	reg = IXGBE_READ_REG(hw, IXGBE_RUPPBMR) | IXGBE_RUPPBMR_MQA;
 	IXGBE_WRITE_REG(hw, IXGBE_RUPPBMR, reg);
@@ -62,13 +127,13 @@ s32 ixgbe_dcb_config_rx_arbiter_82598(struct ixgbe_hw *hw,
 	IXGBE_WRITE_REG(hw, IXGBE_RMCS, reg);
 
 	/* Configure traffic class credits and priority */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		credit_refill = refill[i];
-		credit_max    = max[i];
+		credit_max = max[i];
 
 		reg = credit_refill | (credit_max << IXGBE_RT2CR_MCL_SHIFT);
 
-		if (prio_type[i] == prio_link)
+		if (tsa[i] == ixgbe_dcb_tsa_strict)
 			reg |= IXGBE_RT2CR_LSP;
 
 		IXGBE_WRITE_REG(hw, IXGBE_RT2CR(i), reg);
@@ -85,7 +150,7 @@ s32 ixgbe_dcb_config_rx_arbiter_82598(struct ixgbe_hw *hw,
 	reg &= ~IXGBE_RXCTRL_DMBYPS;
 	IXGBE_WRITE_REG(hw, IXGBE_RXCTRL, reg);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -96,13 +161,11 @@ s32 ixgbe_dcb_config_rx_arbiter_82598(struct ixgbe_hw *hw,
  * Configure Tx Descriptor Arbiter and credits for each traffic class.
  */
 s32 ixgbe_dcb_config_tx_desc_arbiter_82598(struct ixgbe_hw *hw,
-						u16 *refill,
-						u16 *max,
-						u8 *bwg_id,
-						u8 *prio_type)
+					   u16 *refill, u16 *max, u8 *bwg_id,
+					   u8 *tsa)
 {
-	u32    reg, max_credits;
-	u8     i;
+	u32 reg, max_credits;
+	u8 i;
 
 	reg = IXGBE_READ_REG(hw, IXGBE_DPMCS);
 
@@ -116,22 +179,22 @@ s32 ixgbe_dcb_config_tx_desc_arbiter_82598(struct ixgbe_hw *hw,
 	IXGBE_WRITE_REG(hw, IXGBE_DPMCS, reg);
 
 	/* Configure traffic class credits and priority */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		max_credits = max[i];
 		reg = max_credits << IXGBE_TDTQ2TCCR_MCL_SHIFT;
 		reg |= refill[i];
 		reg |= (u32)(bwg_id[i]) << IXGBE_TDTQ2TCCR_BWG_SHIFT;
 
-		if (prio_type[i] == prio_group)
+		if (tsa[i] == ixgbe_dcb_tsa_group_strict_cee)
 			reg |= IXGBE_TDTQ2TCCR_GSP;
 
-		if (prio_type[i] == prio_link)
+		if (tsa[i] == ixgbe_dcb_tsa_strict)
 			reg |= IXGBE_TDTQ2TCCR_LSP;
 
 		IXGBE_WRITE_REG(hw, IXGBE_TDTQ2TCCR(i), reg);
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -142,10 +205,8 @@ s32 ixgbe_dcb_config_tx_desc_arbiter_82598(struct ixgbe_hw *hw,
  * Configure Tx Data Arbiter and credits for each traffic class.
  */
 s32 ixgbe_dcb_config_tx_data_arbiter_82598(struct ixgbe_hw *hw,
-						u16 *refill,
-						u16 *max,
-						u8 *bwg_id,
-						u8 *prio_type)
+					   u16 *refill, u16 *max, u8 *bwg_id,
+					   u8 *tsa)
 {
 	u32 reg;
 	u8 i;
@@ -159,15 +220,15 @@ s32 ixgbe_dcb_config_tx_data_arbiter_82598(struct ixgbe_hw *hw,
 	IXGBE_WRITE_REG(hw, IXGBE_PDPMCS, reg);
 
 	/* Configure traffic class credits and priority */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		reg = refill[i];
 		reg |= (u32)(max[i]) << IXGBE_TDPT2TCCR_MCL_SHIFT;
 		reg |= (u32)(bwg_id[i]) << IXGBE_TDPT2TCCR_BWG_SHIFT;
 
-		if (prio_type[i] == prio_group)
+		if (tsa[i] == ixgbe_dcb_tsa_group_strict_cee)
 			reg |= IXGBE_TDPT2TCCR_GSP;
 
-		if (prio_type[i] == prio_link)
+		if (tsa[i] == ixgbe_dcb_tsa_strict)
 			reg |= IXGBE_TDPT2TCCR_LSP;
 
 		IXGBE_WRITE_REG(hw, IXGBE_TDPT2TCCR(i), reg);
@@ -178,7 +239,7 @@ s32 ixgbe_dcb_config_tx_data_arbiter_82598(struct ixgbe_hw *hw,
 	reg |= IXGBE_DTXCTL_ENDBUBD;
 	IXGBE_WRITE_REG(hw, IXGBE_DTXCTL, reg);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -191,7 +252,7 @@ s32 ixgbe_dcb_config_tx_data_arbiter_82598(struct ixgbe_hw *hw,
 s32 ixgbe_dcb_config_pfc_82598(struct ixgbe_hw *hw, u8 pfc_en)
 {
 	u32 fcrtl, reg;
-	u8  i;
+	u8 i;
 
 	/* Enable Transmit Priority Flow Control */
 	reg = IXGBE_READ_REG(hw, IXGBE_RMCS);
@@ -209,7 +270,7 @@ s32 ixgbe_dcb_config_pfc_82598(struct ixgbe_hw *hw, u8 pfc_en)
 	IXGBE_WRITE_REG(hw, IXGBE_FCTRL, reg);
 
 	/* Configure PFC Tx thresholds per TC */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		if (!(pfc_en & (1 << i))) {
 			IXGBE_WRITE_REG(hw, IXGBE_FCRTL(i), 0);
 			IXGBE_WRITE_REG(hw, IXGBE_FCRTH(i), 0);
@@ -223,15 +284,14 @@ s32 ixgbe_dcb_config_pfc_82598(struct ixgbe_hw *hw, u8 pfc_en)
 	}
 
 	/* Configure pause time */
-	reg = hw->fc.pause_time * 0x00010001;
-	for (i = 0; i < (MAX_TRAFFIC_CLASS / 2); i++)
+	reg = hw->fc.pause_time | (hw->fc.pause_time << 16);
+	for (i = 0; i < (IXGBE_DCB_MAX_TRAFFIC_CLASS / 2); i++)
 		IXGBE_WRITE_REG(hw, IXGBE_FCTTV(i), reg);
 
 	/* Configure flow control refresh threshold value */
 	IXGBE_WRITE_REG(hw, IXGBE_FCRTV, hw->fc.pause_time / 2);
 
-
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -241,11 +301,11 @@ s32 ixgbe_dcb_config_pfc_82598(struct ixgbe_hw *hw, u8 pfc_en)
  * Configure queue statistics registers, all queues belonging to same traffic
  * class uses a single set of queue statistics counters.
  */
-static s32 ixgbe_dcb_config_tc_stats_82598(struct ixgbe_hw *hw)
+s32 ixgbe_dcb_config_tc_stats_82598(struct ixgbe_hw *hw)
 {
 	u32 reg = 0;
-	u8  i   = 0;
-	u8  j   = 0;
+	u8 i = 0;
+	u8 j = 0;
 
 	/* Receive Queues stats setting -  8 queues per statistics reg */
 	for (i = 0, j = 0; i < 15 && j < 8; i = i + 2, j++) {
@@ -256,14 +316,14 @@ static s32 ixgbe_dcb_config_tc_stats_82598(struct ixgbe_hw *hw)
 		reg |= ((0x1010101) * j);
 		IXGBE_WRITE_REG(hw, IXGBE_RQSMR(i + 1), reg);
 	}
-	/* Transmit Queues stats setting -  4 queues per statistics reg */
+	/* Transmit Queues stats setting -  4 queues per statistics reg*/
 	for (i = 0; i < 8; i++) {
 		reg = IXGBE_READ_REG(hw, IXGBE_TQSMR(i));
 		reg |= ((0x1010101) * i);
 		IXGBE_WRITE_REG(hw, IXGBE_TQSMR(i), reg);
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -273,16 +333,18 @@ static s32 ixgbe_dcb_config_tc_stats_82598(struct ixgbe_hw *hw)
  *
  * Configure dcb settings and enable dcb mode.
  */
-s32 ixgbe_dcb_hw_config_82598(struct ixgbe_hw *hw, u8 pfc_en, u16 *refill,
-			      u16 *max, u8 *bwg_id, u8 *prio_type)
+s32 ixgbe_dcb_hw_config_82598(struct ixgbe_hw *hw, int link_speed,
+			      u16 *refill, u16 *max, u8 *bwg_id,
+			      u8 *tsa)
 {
-	ixgbe_dcb_config_rx_arbiter_82598(hw, refill, max, prio_type);
-	ixgbe_dcb_config_tx_desc_arbiter_82598(hw, refill, max,
-					       bwg_id, prio_type);
-	ixgbe_dcb_config_tx_data_arbiter_82598(hw, refill, max,
-					       bwg_id, prio_type);
-	ixgbe_dcb_config_pfc_82598(hw, pfc_en);
+	UNREFERENCED_1PARAMETER(link_speed);
+
+	ixgbe_dcb_config_rx_arbiter_82598(hw, refill, max, tsa);
+	ixgbe_dcb_config_tx_desc_arbiter_82598(hw, refill, max, bwg_id,
+					       tsa);
+	ixgbe_dcb_config_tx_data_arbiter_82598(hw, refill, max, bwg_id,
+					       tsa);
 	ixgbe_dcb_config_tc_stats_82598(hw);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82598.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82598.h
index 3164f54..d340a69 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82598.h
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82598.h
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,72 +22,69 @@
 
 *******************************************************************************/
 
-#ifndef _DCB_82598_CONFIG_H_
-#define _DCB_82598_CONFIG_H_
+#ifndef _IXGBE_DCB_82598_H_
+#define _IXGBE_DCB_82598_H_
 
 /* DCB register definitions */
 
-#define IXGBE_DPMCS_MTSOS_SHIFT 16
-#define IXGBE_DPMCS_TDPAC       0x00000001 /* 0 Round Robin, 1 DFP - Deficit Fixed Priority */
-#define IXGBE_DPMCS_TRM         0x00000010 /* Transmit Recycle Mode */
-#define IXGBE_DPMCS_ARBDIS      0x00000040 /* DCB arbiter disable */
-#define IXGBE_DPMCS_TSOEF       0x00080000 /* TSO Expand Factor: 0=x4, 1=x2 */
-
-#define IXGBE_RUPPBMR_MQA       0x80000000 /* Enable UP to queue mapping */
-
-#define IXGBE_RT2CR_MCL_SHIFT   12 /* Offset to Max Credit Limit setting */
-#define IXGBE_RT2CR_LSP         0x80000000 /* LSP enable bit */
-
-#define IXGBE_RDRXCTL_MPBEN     0x00000010 /* DMA config for multiple packet buffers enable */
-#define IXGBE_RDRXCTL_MCEN      0x00000040 /* DMA config for multiple cores (RSS) enable */
-
-#define IXGBE_TDTQ2TCCR_MCL_SHIFT   12
-#define IXGBE_TDTQ2TCCR_BWG_SHIFT   9
-#define IXGBE_TDTQ2TCCR_GSP     0x40000000
-#define IXGBE_TDTQ2TCCR_LSP     0x80000000
-
-#define IXGBE_TDPT2TCCR_MCL_SHIFT   12
-#define IXGBE_TDPT2TCCR_BWG_SHIFT   9
-#define IXGBE_TDPT2TCCR_GSP     0x40000000
-#define IXGBE_TDPT2TCCR_LSP     0x80000000
-
-#define IXGBE_PDPMCS_TPPAC      0x00000020 /* 0 Round Robin, 1 for DFP - Deficit Fixed Priority */
-#define IXGBE_PDPMCS_ARBDIS     0x00000040 /* Arbiter disable */
-#define IXGBE_PDPMCS_TRM        0x00000100 /* Transmit Recycle Mode enable */
-
-#define IXGBE_DTXCTL_ENDBUBD    0x00000004 /* Enable DBU buffer division */
-
-#define IXGBE_TXPBSIZE_40KB     0x0000A000 /* 40KB Packet Buffer */
-#define IXGBE_RXPBSIZE_48KB     0x0000C000 /* 48KB Packet Buffer */
-#define IXGBE_RXPBSIZE_64KB     0x00010000 /* 64KB Packet Buffer */
-#define IXGBE_RXPBSIZE_80KB     0x00014000 /* 80KB Packet Buffer */
-
-#define IXGBE_RDRXCTL_RDMTS_1_2 0x00000000
-
-/* DCB hardware-specific driver APIs */
-
-/* DCB PFC functions */
-s32 ixgbe_dcb_config_pfc_82598(struct ixgbe_hw *, u8 pfc_en);
-
-/* DCB hw initialization */
-s32 ixgbe_dcb_config_rx_arbiter_82598(struct ixgbe_hw *hw,
-					u16 *refill,
-					u16 *max,
-					u8 *prio_type);
-
-s32 ixgbe_dcb_config_tx_desc_arbiter_82598(struct ixgbe_hw *hw,
-						u16 *refill,
-						u16 *max,
-						u8 *bwg_id,
-						u8 *prio_type);
-
-s32 ixgbe_dcb_config_tx_data_arbiter_82598(struct ixgbe_hw *hw,
-						u16 *refill,
-						u16 *max,
-						u8 *bwg_id,
-						u8 *prio_type);
-
-s32 ixgbe_dcb_hw_config_82598(struct ixgbe_hw *hw, u8 pfc_en, u16 *refill,
-			      u16 *max, u8 *bwg_id, u8 *prio_type);
-
-#endif /* _DCB_82598_CONFIG_H */
+#define IXGBE_DPMCS_MTSOS_SHIFT	16
+#define IXGBE_DPMCS_TDPAC	0x00000001 /* 0 Round Robin,
+					    * 1 DFP - Deficit Fixed Priority */
+#define IXGBE_DPMCS_TRM		0x00000010 /* Transmit Recycle Mode */
+#define IXGBE_DPMCS_ARBDIS	0x00000040 /* DCB arbiter disable */
+#define IXGBE_DPMCS_TSOEF	0x00080000 /* TSO Expand Factor: 0=x4, 1=x2 */
+
+#define IXGBE_RUPPBMR_MQA	0x80000000 /* Enable UP to queue mapping */
+
+#define IXGBE_RT2CR_MCL_SHIFT	12 /* Offset to Max Credit Limit setting */
+#define IXGBE_RT2CR_LSP		0x80000000 /* LSP enable bit */
+
+#define IXGBE_RDRXCTL_MPBEN	0x00000010 /* DMA config for multiple packet
+					    * buffers enable */
+#define IXGBE_RDRXCTL_MCEN	0x00000040 /* DMA config for multiple cores
+					    * (RSS) enable */
+
+#define IXGBE_TDTQ2TCCR_MCL_SHIFT	12
+#define IXGBE_TDTQ2TCCR_BWG_SHIFT	9
+#define IXGBE_TDTQ2TCCR_GSP	0x40000000
+#define IXGBE_TDTQ2TCCR_LSP	0x80000000
+
+#define IXGBE_TDPT2TCCR_MCL_SHIFT	12
+#define IXGBE_TDPT2TCCR_BWG_SHIFT	9
+#define IXGBE_TDPT2TCCR_GSP	0x40000000
+#define IXGBE_TDPT2TCCR_LSP	0x80000000
+
+#define IXGBE_PDPMCS_TPPAC	0x00000020 /* 0 Round Robin,
+					    * 1 DFP - Deficit Fixed Priority */
+#define IXGBE_PDPMCS_ARBDIS	0x00000040 /* Arbiter disable */
+#define IXGBE_PDPMCS_TRM	0x00000100 /* Transmit Recycle Mode enable */
+
+#define IXGBE_DTXCTL_ENDBUBD	0x00000004 /* Enable DBU buffer division */
+
+#define IXGBE_TXPBSIZE_40KB	0x0000A000 /* 40KB Packet Buffer */
+#define IXGBE_RXPBSIZE_48KB	0x0000C000 /* 48KB Packet Buffer */
+#define IXGBE_RXPBSIZE_64KB	0x00010000 /* 64KB Packet Buffer */
+#define IXGBE_RXPBSIZE_80KB	0x00014000 /* 80KB Packet Buffer */
+
+/* DCB driver APIs */
+
+/* DCB PFC */
+s32 ixgbe_dcb_config_pfc_82598(struct ixgbe_hw *, u8);
+
+/* DCB stats */
+s32 ixgbe_dcb_config_tc_stats_82598(struct ixgbe_hw *);
+s32 ixgbe_dcb_get_tc_stats_82598(struct ixgbe_hw *,
+				 struct ixgbe_hw_stats *, u8);
+s32 ixgbe_dcb_get_pfc_stats_82598(struct ixgbe_hw *,
+				  struct ixgbe_hw_stats *, u8);
+
+/* DCB config arbiters */
+s32 ixgbe_dcb_config_tx_desc_arbiter_82598(struct ixgbe_hw *, u16 *, u16 *,
+					   u8 *, u8 *);
+s32 ixgbe_dcb_config_tx_data_arbiter_82598(struct ixgbe_hw *, u16 *, u16 *,
+					   u8 *, u8 *);
+s32 ixgbe_dcb_config_rx_arbiter_82598(struct ixgbe_hw *, u16 *, u16 *, u8 *);
+
+/* DCB initialization */
+s32 ixgbe_dcb_hw_config_82598(struct ixgbe_hw *, int, u16 *, u16 *, u8 *, u8 *);
+#endif /* _IXGBE_DCB_82958_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82599.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82599.c
index 23277ab..b0c5e52 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82599.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82599.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,32 +22,96 @@
 
 *******************************************************************************/
 
-#include "ixgbe.h"
+
 #include "ixgbe_type.h"
 #include "ixgbe_dcb.h"
 #include "ixgbe_dcb_82599.h"
 
 /**
+ * ixgbe_dcb_get_tc_stats_82599 - Returns status for each traffic class
+ * @hw: pointer to hardware structure
+ * @stats: pointer to statistics structure
+ * @tc_count:  Number of elements in bwg_array.
+ *
+ * This function returns the status data for each of the Traffic Classes in use.
+ */
+s32 ixgbe_dcb_get_tc_stats_82599(struct ixgbe_hw *hw,
+				 struct ixgbe_hw_stats *stats,
+				 u8 tc_count)
+{
+	int tc;
+
+	DEBUGFUNC("dcb_get_tc_stats");
+
+	if (tc_count > IXGBE_DCB_MAX_TRAFFIC_CLASS)
+		return IXGBE_ERR_PARAM;
+
+	/* Statistics pertaining to each traffic class */
+	for (tc = 0; tc < tc_count; tc++) {
+		/* Transmitted Packets */
+		stats->qptc[tc] += IXGBE_READ_REG(hw, IXGBE_QPTC(tc));
+		/* Transmitted Bytes (read low first to prevent missed carry) */
+		stats->qbtc[tc] += IXGBE_READ_REG(hw, IXGBE_QBTC_L(tc));
+		stats->qbtc[tc] +=
+			(((u64)(IXGBE_READ_REG(hw, IXGBE_QBTC_H(tc)))) << 32);
+		/* Received Packets */
+		stats->qprc[tc] += IXGBE_READ_REG(hw, IXGBE_QPRC(tc));
+		/* Received Bytes (read low first to prevent missed carry) */
+		stats->qbrc[tc] += IXGBE_READ_REG(hw, IXGBE_QBRC_L(tc));
+		stats->qbrc[tc] +=
+			(((u64)(IXGBE_READ_REG(hw, IXGBE_QBRC_H(tc)))) << 32);
+
+		/* Received Dropped Packet */
+		stats->qprdc[tc] += IXGBE_READ_REG(hw, IXGBE_QPRDC(tc));
+	}
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ * ixgbe_dcb_get_pfc_stats_82599 - Return CBFC status data
+ * @hw: pointer to hardware structure
+ * @stats: pointer to statistics structure
+ * @tc_count:  Number of elements in bwg_array.
+ *
+ * This function returns the CBFC status data for each of the Traffic Classes.
+ */
+s32 ixgbe_dcb_get_pfc_stats_82599(struct ixgbe_hw *hw,
+				  struct ixgbe_hw_stats *stats,
+				  u8 tc_count)
+{
+	int tc;
+
+	DEBUGFUNC("dcb_get_pfc_stats");
+
+	if (tc_count > IXGBE_DCB_MAX_TRAFFIC_CLASS)
+		return IXGBE_ERR_PARAM;
+
+	for (tc = 0; tc < tc_count; tc++) {
+		/* Priority XOFF Transmitted */
+		stats->pxofftxc[tc] += IXGBE_READ_REG(hw, IXGBE_PXOFFTXC(tc));
+		/* Priority XOFF Received */
+		stats->pxoffrxc[tc] += IXGBE_READ_REG(hw, IXGBE_PXOFFRXCNT(tc));
+	}
+
+	return IXGBE_SUCCESS;
+}
+
+/**
  * ixgbe_dcb_config_rx_arbiter_82599 - Config Rx Data arbiter
  * @hw: pointer to hardware structure
- * @refill: refill credits index by traffic class
- * @max: max credits index by traffic class
- * @bwg_id: bandwidth grouping indexed by traffic class
- * @prio_type: priority type indexed by traffic class
+ * @dcb_config: pointer to ixgbe_dcb_config structure
  *
  * Configure Rx Packet Arbiter and credits for each traffic class.
  */
-s32 ixgbe_dcb_config_rx_arbiter_82599(struct ixgbe_hw *hw,
-				      u16 *refill,
-				      u16 *max,
-				      u8 *bwg_id,
-				      u8 *prio_type,
-				      u8 *prio_tc)
+s32 ixgbe_dcb_config_rx_arbiter_82599(struct ixgbe_hw *hw, u16 *refill,
+				      u16 *max, u8 *bwg_id, u8 *tsa,
+				      u8 *map)
 {
-	u32    reg           = 0;
-	u32    credit_refill = 0;
-	u32    credit_max    = 0;
-	u8     i             = 0;
+	u32 reg = 0;
+	u32 credit_refill = 0;
+	u32 credit_max = 0;
+	u8  i = 0;
 
 	/*
 	 * Disable the arbiter before changing parameters
@@ -60,21 +120,27 @@ s32 ixgbe_dcb_config_rx_arbiter_82599(struct ixgbe_hw *hw,
 	reg = IXGBE_RTRPCS_RRM | IXGBE_RTRPCS_RAC | IXGBE_RTRPCS_ARBDIS;
 	IXGBE_WRITE_REG(hw, IXGBE_RTRPCS, reg);
 
-	/* Map all traffic classes to their UP */
+	/*
+	 * map all UPs to TCs. up_to_tc_bitmap for each TC has corresponding
+	 * bits sets for the UPs that needs to be mappped to that TC.
+	 * e.g if priorities 6 and 7 are to be mapped to a TC then the
+	 * up_to_tc_bitmap value for that TC will be 11000000 in binary.
+	 */
 	reg = 0;
-	for (i = 0; i < MAX_USER_PRIORITY; i++)
-		reg |= (prio_tc[i] << (i * IXGBE_RTRUP2TC_UP_SHIFT));
+	for (i = 0; i < IXGBE_DCB_MAX_USER_PRIORITY; i++)
+		reg |= (map[i] << (i * IXGBE_RTRUP2TC_UP_SHIFT));
+
 	IXGBE_WRITE_REG(hw, IXGBE_RTRUP2TC, reg);
 
 	/* Configure traffic class credits and priority */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		credit_refill = refill[i];
-		credit_max    = max[i];
+		credit_max = max[i];
 		reg = credit_refill | (credit_max << IXGBE_RTRPT4C_MCL_SHIFT);
 
 		reg |= (u32)(bwg_id[i]) << IXGBE_RTRPT4C_BWG_SHIFT;
 
-		if (prio_type[i] == prio_link)
+		if (tsa[i] == ixgbe_dcb_tsa_strict)
 			reg |= IXGBE_RTRPT4C_LSP;
 
 		IXGBE_WRITE_REG(hw, IXGBE_RTRPT4C(i), reg);
@@ -87,27 +153,21 @@ s32 ixgbe_dcb_config_rx_arbiter_82599(struct ixgbe_hw *hw,
 	reg = IXGBE_RTRPCS_RRM | IXGBE_RTRPCS_RAC;
 	IXGBE_WRITE_REG(hw, IXGBE_RTRPCS, reg);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
  * ixgbe_dcb_config_tx_desc_arbiter_82599 - Config Tx Desc. arbiter
  * @hw: pointer to hardware structure
- * @refill: refill credits index by traffic class
- * @max: max credits index by traffic class
- * @bwg_id: bandwidth grouping indexed by traffic class
- * @prio_type: priority type indexed by traffic class
+ * @dcb_config: pointer to ixgbe_dcb_config structure
  *
  * Configure Tx Descriptor Arbiter and credits for each traffic class.
  */
-s32 ixgbe_dcb_config_tx_desc_arbiter_82599(struct ixgbe_hw *hw,
-					   u16 *refill,
-					   u16 *max,
-					   u8 *bwg_id,
-					   u8 *prio_type)
+s32 ixgbe_dcb_config_tx_desc_arbiter_82599(struct ixgbe_hw *hw, u16 *refill,
+					   u16 *max, u8 *bwg_id, u8 *tsa)
 {
-	u32    reg, max_credits;
-	u8     i;
+	u32 reg, max_credits;
+	u8  i;
 
 	/* Clear the per-Tx queue credits; we use per-TC instead */
 	for (i = 0; i < 128; i++) {
@@ -116,16 +176,16 @@ s32 ixgbe_dcb_config_tx_desc_arbiter_82599(struct ixgbe_hw *hw,
 	}
 
 	/* Configure traffic class credits and priority */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		max_credits = max[i];
 		reg = max_credits << IXGBE_RTTDT2C_MCL_SHIFT;
 		reg |= refill[i];
 		reg |= (u32)(bwg_id[i]) << IXGBE_RTTDT2C_BWG_SHIFT;
 
-		if (prio_type[i] == prio_group)
+		if (tsa[i] == ixgbe_dcb_tsa_group_strict_cee)
 			reg |= IXGBE_RTTDT2C_GSP;
 
-		if (prio_type[i] == prio_link)
+		if (tsa[i] == ixgbe_dcb_tsa_strict)
 			reg |= IXGBE_RTTDT2C_LSP;
 
 		IXGBE_WRITE_REG(hw, IXGBE_RTTDT2C(i), reg);
@@ -138,25 +198,19 @@ s32 ixgbe_dcb_config_tx_desc_arbiter_82599(struct ixgbe_hw *hw,
 	reg = IXGBE_RTTDCS_TDPAC | IXGBE_RTTDCS_TDRM;
 	IXGBE_WRITE_REG(hw, IXGBE_RTTDCS, reg);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
  * ixgbe_dcb_config_tx_data_arbiter_82599 - Config Tx Data arbiter
  * @hw: pointer to hardware structure
- * @refill: refill credits index by traffic class
- * @max: max credits index by traffic class
- * @bwg_id: bandwidth grouping indexed by traffic class
- * @prio_type: priority type indexed by traffic class
+ * @dcb_config: pointer to ixgbe_dcb_config structure
  *
  * Configure Tx Packet Arbiter and credits for each traffic class.
  */
-s32 ixgbe_dcb_config_tx_data_arbiter_82599(struct ixgbe_hw *hw,
-					   u16 *refill,
-					   u16 *max,
-					   u8 *bwg_id,
-					   u8 *prio_type,
-					   u8 *prio_tc)
+s32 ixgbe_dcb_config_tx_data_arbiter_82599(struct ixgbe_hw *hw, u16 *refill,
+					   u16 *max, u8 *bwg_id, u8 *tsa,
+					   u8 *map)
 {
 	u32 reg;
 	u8 i;
@@ -170,22 +224,28 @@ s32 ixgbe_dcb_config_tx_data_arbiter_82599(struct ixgbe_hw *hw,
 	      IXGBE_RTTPCS_ARBDIS;
 	IXGBE_WRITE_REG(hw, IXGBE_RTTPCS, reg);
 
-	/* Map all traffic classes to their UP */
+	/*
+	 * map all UPs to TCs. up_to_tc_bitmap for each TC has corresponding
+	 * bits sets for the UPs that needs to be mappped to that TC.
+	 * e.g if priorities 6 and 7 are to be mapped to a TC then the
+	 * up_to_tc_bitmap value for that TC will be 11000000 in binary.
+	 */
 	reg = 0;
-	for (i = 0; i < MAX_USER_PRIORITY; i++)
-		reg |= (prio_tc[i] << (i * IXGBE_RTTUP2TC_UP_SHIFT));
+	for (i = 0; i < IXGBE_DCB_MAX_USER_PRIORITY; i++)
+		reg |= (map[i] << (i * IXGBE_RTTUP2TC_UP_SHIFT));
+
 	IXGBE_WRITE_REG(hw, IXGBE_RTTUP2TC, reg);
 
 	/* Configure traffic class credits and priority */
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		reg = refill[i];
 		reg |= (u32)(max[i]) << IXGBE_RTTPT2C_MCL_SHIFT;
 		reg |= (u32)(bwg_id[i]) << IXGBE_RTTPT2C_BWG_SHIFT;
 
-		if (prio_type[i] == prio_group)
+		if (tsa[i] == ixgbe_dcb_tsa_group_strict_cee)
 			reg |= IXGBE_RTTPT2C_GSP;
 
-		if (prio_type[i] == prio_link)
+		if (tsa[i] == ixgbe_dcb_tsa_strict)
 			reg |= IXGBE_RTTPT2C_LSP;
 
 		IXGBE_WRITE_REG(hw, IXGBE_RTTPT2C(i), reg);
@@ -199,18 +259,18 @@ s32 ixgbe_dcb_config_tx_data_arbiter_82599(struct ixgbe_hw *hw,
 	      (IXGBE_RTTPCS_ARBD_DCB << IXGBE_RTTPCS_ARBD_SHIFT);
 	IXGBE_WRITE_REG(hw, IXGBE_RTTPCS, reg);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
  * ixgbe_dcb_config_pfc_82599 - Configure priority flow control
  * @hw: pointer to hardware structure
  * @pfc_en: enabled pfc bitmask
- * @prio_tc: priority to tc assignments indexed by priority
+ * @map: priority to tc assignments indexed by priority
  *
  * Configure Priority Flow Control (PFC) for each traffic class.
  */
-s32 ixgbe_dcb_config_pfc_82599(struct ixgbe_hw *hw, u8 pfc_en, u8 *prio_tc)
+s32 ixgbe_dcb_config_pfc_82599(struct ixgbe_hw *hw, u8 pfc_en, u8 *map)
 {
 	u32 i, j, fcrtl, reg;
 	u8 max_tc = 0;
@@ -229,7 +289,7 @@ s32 ixgbe_dcb_config_pfc_82599(struct ixgbe_hw *hw, u8 pfc_en, u8 *prio_tc)
 	 */
 	reg &= ~(IXGBE_MFLCN_RPFCE_MASK | IXGBE_MFLCN_RFCE);
 
-	if (hw->mac.type == ixgbe_mac_X540)
+	if (hw->mac.type >= ixgbe_mac_X540)
 		reg |= pfc_en << IXGBE_MFLCN_RPFCE_SHIFT;
 
 	if (pfc_en)
@@ -237,9 +297,9 @@ s32 ixgbe_dcb_config_pfc_82599(struct ixgbe_hw *hw, u8 pfc_en, u8 *prio_tc)
 
 	IXGBE_WRITE_REG(hw, IXGBE_MFLCN, reg);
 
-	for (i = 0; i < MAX_USER_PRIORITY; i++) {
-		if (prio_tc[i] > max_tc)
-			max_tc = prio_tc[i];
+	for (i = 0; i < IXGBE_DCB_MAX_USER_PRIORITY; i++) {
+		if (map[i] > max_tc)
+			max_tc = map[i];
 	}
 
 
@@ -247,8 +307,8 @@ s32 ixgbe_dcb_config_pfc_82599(struct ixgbe_hw *hw, u8 pfc_en, u8 *prio_tc)
 	for (i = 0; i <= max_tc; i++) {
 		int enabled = 0;
 
-		for (j = 0; j < MAX_USER_PRIORITY; j++) {
-			if ((prio_tc[j] == i) && (pfc_en & (1 << j))) {
+		for (j = 0; j < IXGBE_DCB_MAX_USER_PRIORITY; j++) {
+			if ((map[j] == i) && (pfc_en & (1 << j))) {
 				enabled = 1;
 				break;
 			}
@@ -259,7 +319,8 @@ s32 ixgbe_dcb_config_pfc_82599(struct ixgbe_hw *hw, u8 pfc_en, u8 *prio_tc)
 			fcrtl = (hw->fc.low_water[i] << 10) | IXGBE_FCRTL_XONE;
 			IXGBE_WRITE_REG(hw, IXGBE_FCRTL_82599(i), fcrtl);
 		} else {
-			/* In order to prevent Tx hangs when the internal Tx
+			/*
+			 * In order to prevent Tx hangs when the internal Tx
 			 * switch is enabled we must set the high water mark
 			 * to the Rx packet buffer size - 24KB.  This allows
 			 * the Tx switch to function even under heavy Rx
@@ -272,20 +333,20 @@ s32 ixgbe_dcb_config_pfc_82599(struct ixgbe_hw *hw, u8 pfc_en, u8 *prio_tc)
 		IXGBE_WRITE_REG(hw, IXGBE_FCRTH_82599(i), reg);
 	}
 
-	for (; i < MAX_TRAFFIC_CLASS; i++) {
+	for (; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		IXGBE_WRITE_REG(hw, IXGBE_FCRTL_82599(i), 0);
 		IXGBE_WRITE_REG(hw, IXGBE_FCRTH_82599(i), 0);
 	}
 
 	/* Configure pause time (2 TCs per register) */
-	reg = hw->fc.pause_time * 0x00010001;
-	for (i = 0; i < (MAX_TRAFFIC_CLASS / 2); i++)
+	reg = hw->fc.pause_time | (hw->fc.pause_time << 16);
+	for (i = 0; i < (IXGBE_DCB_MAX_TRAFFIC_CLASS / 2); i++)
 		IXGBE_WRITE_REG(hw, IXGBE_FCTTV(i), reg);
 
 	/* Configure flow control refresh threshold value */
 	IXGBE_WRITE_REG(hw, IXGBE_FCRTV, hw->fc.pause_time / 2);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -295,75 +356,229 @@ s32 ixgbe_dcb_config_pfc_82599(struct ixgbe_hw *hw, u8 pfc_en, u8 *prio_tc)
  * Configure queue statistics registers, all queues belonging to same traffic
  * class uses a single set of queue statistics counters.
  */
-static s32 ixgbe_dcb_config_tc_stats_82599(struct ixgbe_hw *hw)
+s32 ixgbe_dcb_config_tc_stats_82599(struct ixgbe_hw *hw,
+				    struct ixgbe_dcb_config *dcb_config)
 {
 	u32 reg = 0;
 	u8  i   = 0;
+	u8 tc_count = 8;
+	bool vt_mode = false;
 
-	/*
-	 * Receive Queues stats setting
-	 * 32 RQSMR registers, each configuring 4 queues.
-	 * Set all 16 queues of each TC to the same stat
-	 * with TC 'n' going to stat 'n'.
-	 */
-	for (i = 0; i < 32; i++) {
-		reg = 0x01010101 * (i / 4);
-		IXGBE_WRITE_REG(hw, IXGBE_RQSMR(i), reg);
+	if (dcb_config != NULL) {
+		tc_count = dcb_config->num_tcs.pg_tcs;
+		vt_mode = dcb_config->vt_mode;
 	}
-	/*
-	 * Transmit Queues stats setting
-	 * 32 TQSM registers, each controlling 4 queues.
-	 * Set all queues of each TC to the same stat
-	 * with TC 'n' going to stat 'n'.
-	 * Tx queues are allocated non-uniformly to TCs:
-	 * 32, 32, 16, 16, 8, 8, 8, 8.
-	 */
-	for (i = 0; i < 32; i++) {
-		if (i < 8)
-			reg = 0x00000000;
-		else if (i < 16)
-			reg = 0x01010101;
-		else if (i < 20)
-			reg = 0x02020202;
-		else if (i < 24)
-			reg = 0x03030303;
-		else if (i < 26)
-			reg = 0x04040404;
-		else if (i < 28)
-			reg = 0x05050505;
-		else if (i < 30)
-			reg = 0x06060606;
+
+	if (!((tc_count == 8 && vt_mode == false) || tc_count == 4))
+		return IXGBE_ERR_PARAM;
+
+	if (tc_count == 8 && vt_mode == false) {
+		/*
+		 * Receive Queues stats setting
+		 * 32 RQSMR registers, each configuring 4 queues.
+		 *
+		 * Set all 16 queues of each TC to the same stat
+		 * with TC 'n' going to stat 'n'.
+		 */
+		for (i = 0; i < 32; i++) {
+			reg = 0x01010101 * (i / 4);
+			IXGBE_WRITE_REG(hw, IXGBE_RQSMR(i), reg);
+		}
+		/*
+		 * Transmit Queues stats setting
+		 * 32 TQSM registers, each controlling 4 queues.
+		 *
+		 * Set all queues of each TC to the same stat
+		 * with TC 'n' going to stat 'n'.
+		 * Tx queues are allocated non-uniformly to TCs:
+		 * 32, 32, 16, 16, 8, 8, 8, 8.
+		 */
+		for (i = 0; i < 32; i++) {
+			if (i < 8)
+				reg = 0x00000000;
+			else if (i < 16)
+				reg = 0x01010101;
+			else if (i < 20)
+				reg = 0x02020202;
+			else if (i < 24)
+				reg = 0x03030303;
+			else if (i < 26)
+				reg = 0x04040404;
+			else if (i < 28)
+				reg = 0x05050505;
+			else if (i < 30)
+				reg = 0x06060606;
+			else
+				reg = 0x07070707;
+			IXGBE_WRITE_REG(hw, IXGBE_TQSM(i), reg);
+		}
+	} else if (tc_count == 4 && vt_mode == false) {
+		/*
+		 * Receive Queues stats setting
+		 * 32 RQSMR registers, each configuring 4 queues.
+		 *
+		 * Set all 16 queues of each TC to the same stat
+		 * with TC 'n' going to stat 'n'.
+		 */
+		for (i = 0; i < 32; i++) {
+			if (i % 8 > 3)
+				/* In 4 TC mode, odd 16-queue ranges are
+				 *  not used.
+				*/
+				continue;
+			reg = 0x01010101 * (i / 8);
+			IXGBE_WRITE_REG(hw, IXGBE_RQSMR(i), reg);
+		}
+		/*
+		 * Transmit Queues stats setting
+		 * 32 TQSM registers, each controlling 4 queues.
+		 *
+		 * Set all queues of each TC to the same stat
+		 * with TC 'n' going to stat 'n'.
+		 * Tx queues are allocated non-uniformly to TCs:
+		 * 64, 32, 16, 16.
+		 */
+		for (i = 0; i < 32; i++) {
+			if (i < 16)
+				reg = 0x00000000;
+			else if (i < 24)
+				reg = 0x01010101;
+			else if (i < 28)
+				reg = 0x02020202;
+			else
+				reg = 0x03030303;
+			IXGBE_WRITE_REG(hw, IXGBE_TQSM(i), reg);
+		}
+	} else if (tc_count == 4 && vt_mode == true) {
+		/*
+		 * Receive Queues stats setting
+		 * 32 RQSMR registers, each configuring 4 queues.
+		 *
+		 * Queue Indexing in 32 VF with DCB mode maps 4 TC's to each
+		 * pool. Set all 32 queues of each TC across pools to the same
+		 * stat with TC 'n' going to stat 'n'.
+		 */
+		for (i = 0; i < 32; i++)
+			IXGBE_WRITE_REG(hw, IXGBE_RQSMR(i), 0x03020100);
+		/*
+		 * Transmit Queues stats setting
+		 * 32 TQSM registers, each controlling 4 queues.
+		 *
+		 * Queue Indexing in 32 VF with DCB mode maps 4 TC's to each
+		 * pool. Set all 32 queues of each TC across pools to the same
+		 * stat with TC 'n' going to stat 'n'.
+		 */
+		for (i = 0; i < 32; i++)
+			IXGBE_WRITE_REG(hw, IXGBE_TQSM(i), 0x03020100);
+	}
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ * ixgbe_dcb_config_82599 - Configure general DCB parameters
+ * @hw: pointer to hardware structure
+ * @dcb_config: pointer to ixgbe_dcb_config structure
+ *
+ * Configure general DCB parameters.
+ */
+s32 ixgbe_dcb_config_82599(struct ixgbe_hw *hw,
+			   struct ixgbe_dcb_config *dcb_config)
+{
+	u32 reg;
+	u32 q;
+
+	/* Disable the Tx desc arbiter so that MTQC can be changed */
+	reg = IXGBE_READ_REG(hw, IXGBE_RTTDCS);
+	reg |= IXGBE_RTTDCS_ARBDIS;
+	IXGBE_WRITE_REG(hw, IXGBE_RTTDCS, reg);
+
+	reg = IXGBE_READ_REG(hw, IXGBE_MRQC);
+	if (dcb_config->num_tcs.pg_tcs == 8) {
+		/* Enable DCB for Rx with 8 TCs */
+		switch (reg & IXGBE_MRQC_MRQE_MASK) {
+		case 0:
+		case IXGBE_MRQC_RT4TCEN:
+			/* RSS disabled cases */
+			reg = (reg & ~IXGBE_MRQC_MRQE_MASK) |
+			      IXGBE_MRQC_RT8TCEN;
+			break;
+		case IXGBE_MRQC_RSSEN:
+		case IXGBE_MRQC_RTRSS4TCEN:
+			/* RSS enabled cases */
+			reg = (reg & ~IXGBE_MRQC_MRQE_MASK) |
+			      IXGBE_MRQC_RTRSS8TCEN;
+			break;
+		default:
+			/*
+			 * Unsupported value, assume stale data,
+			 * overwrite no RSS
+			 */
+			ASSERT(0);
+			reg = (reg & ~IXGBE_MRQC_MRQE_MASK) |
+			      IXGBE_MRQC_RT8TCEN;
+		}
+	}
+	if (dcb_config->num_tcs.pg_tcs == 4) {
+		/* We support both VT-on and VT-off with 4 TCs. */
+		if (dcb_config->vt_mode)
+			reg = (reg & ~IXGBE_MRQC_MRQE_MASK) |
+			      IXGBE_MRQC_VMDQRT4TCEN;
 		else
-			reg = 0x07070707;
-		IXGBE_WRITE_REG(hw, IXGBE_TQSM(i), reg);
+			reg = (reg & ~IXGBE_MRQC_MRQE_MASK) |
+			      IXGBE_MRQC_RTRSS4TCEN;
+	}
+	IXGBE_WRITE_REG(hw, IXGBE_MRQC, reg);
+
+	/* Enable DCB for Tx with 8 TCs */
+	if (dcb_config->num_tcs.pg_tcs == 8)
+		reg = IXGBE_MTQC_RT_ENA | IXGBE_MTQC_8TC_8TQ;
+	else {
+		/* We support both VT-on and VT-off with 4 TCs. */
+		reg = IXGBE_MTQC_RT_ENA | IXGBE_MTQC_4TC_4TQ;
+		if (dcb_config->vt_mode)
+			reg |= IXGBE_MTQC_VT_ENA;
 	}
+	IXGBE_WRITE_REG(hw, IXGBE_MTQC, reg);
 
-	return 0;
+	/* Disable drop for all queues */
+	for (q = 0; q < 128; q++)
+		IXGBE_WRITE_REG(hw, IXGBE_QDE,
+				(IXGBE_QDE_WRITE | (q << IXGBE_QDE_IDX_SHIFT)));
+
+	/* Enable the Tx desc arbiter */
+	reg = IXGBE_READ_REG(hw, IXGBE_RTTDCS);
+	reg &= ~IXGBE_RTTDCS_ARBDIS;
+	IXGBE_WRITE_REG(hw, IXGBE_RTTDCS, reg);
+
+	/* Enable Security TX Buffer IFG for DCB */
+	reg = IXGBE_READ_REG(hw, IXGBE_SECTXMINIFG);
+	reg |= IXGBE_SECTX_DCB;
+	IXGBE_WRITE_REG(hw, IXGBE_SECTXMINIFG, reg);
+
+	return IXGBE_SUCCESS;
 }
 
 /**
  * ixgbe_dcb_hw_config_82599 - Configure and enable DCB
  * @hw: pointer to hardware structure
- * @refill: refill credits index by traffic class
- * @max: max credits index by traffic class
- * @bwg_id: bandwidth grouping indexed by traffic class
- * @prio_type: priority type indexed by traffic class
- * @pfc_en: enabled pfc bitmask
+ * @dcb_config: pointer to ixgbe_dcb_config structure
  *
  * Configure dcb settings and enable dcb mode.
  */
-s32 ixgbe_dcb_hw_config_82599(struct ixgbe_hw *hw, u8 pfc_en, u16 *refill,
-			      u16 *max, u8 *bwg_id, u8 *prio_type, u8 *prio_tc)
+s32 ixgbe_dcb_hw_config_82599(struct ixgbe_hw *hw, int link_speed,
+			      u16 *refill, u16 *max, u8 *bwg_id, u8 *tsa,
+			      u8 *map)
 {
-	ixgbe_dcb_config_rx_arbiter_82599(hw, refill, max, bwg_id,
-					  prio_type, prio_tc);
-	ixgbe_dcb_config_tx_desc_arbiter_82599(hw, refill, max,
-					       bwg_id, prio_type);
-	ixgbe_dcb_config_tx_data_arbiter_82599(hw, refill, max,
-					       bwg_id, prio_type, prio_tc);
-	ixgbe_dcb_config_pfc_82599(hw, pfc_en, prio_tc);
-	ixgbe_dcb_config_tc_stats_82599(hw);
-
-	return 0;
+	UNREFERENCED_1PARAMETER(link_speed);
+
+	ixgbe_dcb_config_rx_arbiter_82599(hw, refill, max, bwg_id, tsa,
+					  map);
+	ixgbe_dcb_config_tx_desc_arbiter_82599(hw, refill, max, bwg_id,
+					       tsa);
+	ixgbe_dcb_config_tx_data_arbiter_82599(hw, refill, max, bwg_id,
+					       tsa, map);
+
+	return IXGBE_SUCCESS;
 }
 
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82599.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82599.h
index 90c3702..24be906 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82599.h
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_82599.h
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,100 +22,97 @@
 
 *******************************************************************************/
 
-#ifndef _DCB_82599_CONFIG_H_
-#define _DCB_82599_CONFIG_H_
+#ifndef _IXGBE_DCB_82599_H_
+#define _IXGBE_DCB_82599_H_
 
 /* DCB register definitions */
-#define IXGBE_RTTDCS_TDPAC      0x00000001 /* 0 Round Robin,
+#define IXGBE_RTTDCS_TDPAC	0x00000001 /* 0 Round Robin,
 					    * 1 WSP - Weighted Strict Priority
 					    */
-#define IXGBE_RTTDCS_VMPAC      0x00000002 /* 0 Round Robin,
+#define IXGBE_RTTDCS_VMPAC	0x00000002 /* 0 Round Robin,
 					    * 1 WRR - Weighted Round Robin
 					    */
-#define IXGBE_RTTDCS_TDRM       0x00000010 /* Transmit Recycle Mode */
-#define IXGBE_RTTDCS_ARBDIS     0x00000040 /* DCB arbiter disable */
-#define IXGBE_RTTDCS_BDPM       0x00400000 /* Bypass Data Pipe - must clear! */
-#define IXGBE_RTTDCS_BPBFSM     0x00800000 /* Bypass PB Free Space - must
+#define IXGBE_RTTDCS_TDRM	0x00000010 /* Transmit Recycle Mode */
+#define IXGBE_RTTDCS_BDPM	0x00400000 /* Bypass Data Pipe - must clear! */
+#define IXGBE_RTTDCS_BPBFSM	0x00800000 /* Bypass PB Free Space - must
 					     * clear!
 					     */
-#define IXGBE_RTTDCS_SPEED_CHG  0x80000000 /* Link speed change */
+#define IXGBE_RTTDCS_SPEED_CHG	0x80000000 /* Link speed change */
 
 /* Receive UP2TC mapping */
-#define IXGBE_RTRUP2TC_UP_SHIFT 3
+#define IXGBE_RTRUP2TC_UP_SHIFT	3
 #define IXGBE_RTRUP2TC_UP_MASK	7
 /* Transmit UP2TC mapping */
-#define IXGBE_RTTUP2TC_UP_SHIFT 3
+#define IXGBE_RTTUP2TC_UP_SHIFT	3
 
-#define IXGBE_RTRPT4C_MCL_SHIFT 12 /* Offset to Max Credit Limit setting */
-#define IXGBE_RTRPT4C_BWG_SHIFT 9  /* Offset to BWG index */
-#define IXGBE_RTRPT4C_GSP       0x40000000 /* GSP enable bit */
-#define IXGBE_RTRPT4C_LSP       0x80000000 /* LSP enable bit */
+#define IXGBE_RTRPT4C_MCL_SHIFT	12 /* Offset to Max Credit Limit setting */
+#define IXGBE_RTRPT4C_BWG_SHIFT	9  /* Offset to BWG index */
+#define IXGBE_RTRPT4C_GSP	0x40000000 /* GSP enable bit */
+#define IXGBE_RTRPT4C_LSP	0x80000000 /* LSP enable bit */
 
-#define IXGBE_RDRXCTL_MPBEN     0x00000010 /* DMA config for multiple packet
+#define IXGBE_RDRXCTL_MPBEN	0x00000010 /* DMA config for multiple packet
 					    * buffers enable
 					    */
-#define IXGBE_RDRXCTL_MCEN      0x00000040 /* DMA config for multiple cores
+#define IXGBE_RDRXCTL_MCEN	0x00000040 /* DMA config for multiple cores
 					    * (RSS) enable
 					    */
 
 /* RTRPCS Bit Masks */
-#define IXGBE_RTRPCS_RRM        0x00000002 /* Receive Recycle Mode enable */
+#define IXGBE_RTRPCS_RRM	0x00000002 /* Receive Recycle Mode enable */
 /* Receive Arbitration Control: 0 Round Robin, 1 DFP */
-#define IXGBE_RTRPCS_RAC        0x00000004
-#define IXGBE_RTRPCS_ARBDIS     0x00000040 /* Arbitration disable bit */
+#define IXGBE_RTRPCS_RAC	0x00000004
+#define IXGBE_RTRPCS_ARBDIS	0x00000040 /* Arbitration disable bit */
 
 /* RTTDT2C Bit Masks */
-#define IXGBE_RTTDT2C_MCL_SHIFT 12
-#define IXGBE_RTTDT2C_BWG_SHIFT 9
-#define IXGBE_RTTDT2C_GSP       0x40000000
-#define IXGBE_RTTDT2C_LSP       0x80000000
+#define IXGBE_RTTDT2C_MCL_SHIFT	12
+#define IXGBE_RTTDT2C_BWG_SHIFT	9
+#define IXGBE_RTTDT2C_GSP	0x40000000
+#define IXGBE_RTTDT2C_LSP	0x80000000
 
-#define IXGBE_RTTPT2C_MCL_SHIFT 12
-#define IXGBE_RTTPT2C_BWG_SHIFT 9
-#define IXGBE_RTTPT2C_GSP       0x40000000
-#define IXGBE_RTTPT2C_LSP       0x80000000
+#define IXGBE_RTTPT2C_MCL_SHIFT	12
+#define IXGBE_RTTPT2C_BWG_SHIFT	9
+#define IXGBE_RTTPT2C_GSP	0x40000000
+#define IXGBE_RTTPT2C_LSP	0x80000000
 
 /* RTTPCS Bit Masks */
-#define IXGBE_RTTPCS_TPPAC      0x00000020 /* 0 Round Robin,
+#define IXGBE_RTTPCS_TPPAC	0x00000020 /* 0 Round Robin,
 					    * 1 SP - Strict Priority
 					    */
-#define IXGBE_RTTPCS_ARBDIS     0x00000040 /* Arbiter disable */
-#define IXGBE_RTTPCS_TPRM       0x00000100 /* Transmit Recycle Mode enable */
-#define IXGBE_RTTPCS_ARBD_SHIFT 22
-#define IXGBE_RTTPCS_ARBD_DCB   0x4        /* Arbitration delay in DCB mode */
-
-/* SECTXMINIFG DCB */
-#define IXGBE_SECTX_DCB		0x00001F00 /* DCB TX Buffer IFG */
-
-
-/* DCB hardware-specific driver APIs */
+#define IXGBE_RTTPCS_ARBDIS	0x00000040 /* Arbiter disable */
+#define IXGBE_RTTPCS_TPRM	0x00000100 /* Transmit Recycle Mode enable */
+#define IXGBE_RTTPCS_ARBD_SHIFT	22
+#define IXGBE_RTTPCS_ARBD_DCB	0x4 /* Arbitration delay in DCB mode */
 
-/* DCB PFC functions */
-s32 ixgbe_dcb_config_pfc_82599(struct ixgbe_hw *hw, u8 pfc_en, u8 *prio_tc);
+#define IXGBE_TXPBTHRESH_DCB	0xA /* THRESH value for DCB mode */
 
-/* DCB hw initialization */
-s32 ixgbe_dcb_config_rx_arbiter_82599(struct ixgbe_hw *hw,
-					u16 *refill,
-					u16 *max,
-					u8 *bwg_id,
-					u8 *prio_type,
-					u8 *prio_tc);
-
-s32 ixgbe_dcb_config_tx_desc_arbiter_82599(struct ixgbe_hw *hw,
-						u16 *refill,
-						u16 *max,
-						u8 *bwg_id,
-						u8 *prio_type);
-
-s32 ixgbe_dcb_config_tx_data_arbiter_82599(struct ixgbe_hw *hw,
-						u16 *refill,
-						u16 *max,
-						u8 *bwg_id,
-						u8 *prio_type,
-						u8 *prio_tc);
-
-s32 ixgbe_dcb_hw_config_82599(struct ixgbe_hw *hw, u8 pfc_en, u16 *refill,
-			      u16 *max, u8 *bwg_id, u8 *prio_type,
-			      u8 *prio_tc);
-
-#endif /* _DCB_82599_CONFIG_H */
+/* SECTXMINIFG DCB */
+#define IXGBE_SECTX_DCB		0x00001F00 /* DCB TX Buffer SEC IFG */
+
+/* DCB driver APIs */
+
+/* DCB PFC */
+s32 ixgbe_dcb_config_pfc_82599(struct ixgbe_hw *, u8, u8 *);
+
+/* DCB stats */
+s32 ixgbe_dcb_config_tc_stats_82599(struct ixgbe_hw *,
+				    struct ixgbe_dcb_config *);
+s32 ixgbe_dcb_get_tc_stats_82599(struct ixgbe_hw *,
+				 struct ixgbe_hw_stats *, u8);
+s32 ixgbe_dcb_get_pfc_stats_82599(struct ixgbe_hw *,
+				  struct ixgbe_hw_stats *, u8);
+
+/* DCB config arbiters */
+s32 ixgbe_dcb_config_tx_desc_arbiter_82599(struct ixgbe_hw *, u16 *, u16 *,
+					   u8 *, u8 *);
+s32 ixgbe_dcb_config_tx_data_arbiter_82599(struct ixgbe_hw *, u16 *, u16 *,
+					   u8 *, u8 *, u8 *);
+s32 ixgbe_dcb_config_rx_arbiter_82599(struct ixgbe_hw *, u16 *, u16 *, u8 *,
+				      u8 *, u8 *);
+
+/* DCB initialization */
+s32 ixgbe_dcb_config_82599(struct ixgbe_hw *,
+			   struct ixgbe_dcb_config *);
+
+s32 ixgbe_dcb_hw_config_82599(struct ixgbe_hw *, int, u16 *, u16 *, u8 *,
+			      u8 *, u8 *);
+#endif /* _IXGBE_DCB_82959_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_nl.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_nl.c
index 2707bda..20d9d05 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_nl.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_dcb_nl.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -27,10 +23,11 @@
 *******************************************************************************/
 
 #include "ixgbe.h"
+
+#if IS_ENABLED(CONFIG_DCB)
 #include <linux/dcbnl.h>
 #include "ixgbe_dcb_82598.h"
 #include "ixgbe_dcb_82599.h"
-#include "ixgbe_sriov.h"
 
 /* Callbacks for DCB netlink in the kernel */
 #define BIT_DCB_MODE	0x01
@@ -38,40 +35,36 @@
 #define BIT_PG_RX	0x04
 #define BIT_PG_TX	0x08
 #define BIT_APP_UPCHG	0x10
-#define BIT_LINKSPEED   0x80
+#define BIT_RESETLINK	0x40
+#define BIT_LINKSPEED	0x80
 
 /* Responses for the DCB_C_SET_ALL command */
-#define DCB_HW_CHG_RST  0  /* DCB configuration changed with reset */
-#define DCB_NO_HW_CHG   1  /* DCB configuration did not change */
-#define DCB_HW_CHG      2  /* DCB configuration changed, no reset */
+#define DCB_HW_CHG_RST	0  /* DCB configuration changed with reset */
+#define DCB_NO_HW_CHG	1  /* DCB configuration did not change */
+#define DCB_HW_CHG	2  /* DCB configuration changed, no reset */
 
-static int ixgbe_copy_dcb_cfg(struct ixgbe_adapter *adapter, int tc_max)
+int ixgbe_copy_dcb_cfg(struct ixgbe_adapter *adapter, int tc_max)
 {
 	struct ixgbe_dcb_config *scfg = &adapter->temp_dcb_cfg;
 	struct ixgbe_dcb_config *dcfg = &adapter->dcb_cfg;
-	struct tc_configuration *src = NULL;
-	struct tc_configuration *dst = NULL;
+	struct ixgbe_dcb_tc_config *src = NULL;
+	struct ixgbe_dcb_tc_config *dst = NULL;
 	int i, j;
-	int tx = DCB_TX_CONFIG;
-	int rx = DCB_RX_CONFIG;
+	int tx = IXGBE_DCB_TX_CONFIG;
+	int rx = IXGBE_DCB_RX_CONFIG;
 	int changes = 0;
-#ifdef IXGBE_FCOE
-	struct dcb_app app = {
-			      .selector = DCB_APP_IDTYPE_ETHTYPE,
-			      .protocol = ETH_P_FCOE,
-			     };
-	u8 up = dcb_getapp(adapter->netdev, &app);
 
-	if (up && !(up & (1 << adapter->fcoe.up)))
+#if IS_ENABLED(CONFIG_FCOE)
+	if (adapter->fcoe.up_set != adapter->fcoe.up)
 		changes |= BIT_APP_UPCHG;
-#endif
+#endif /* CONFIG_FCOE */
 
 	for (i = DCB_PG_ATTR_TC_0; i < tc_max + DCB_PG_ATTR_TC_0; i++) {
 		src = &scfg->tc_config[i - DCB_PG_ATTR_TC_0];
 		dst = &dcfg->tc_config[i - DCB_PG_ATTR_TC_0];
 
-		if (dst->path[tx].prio_type != src->path[tx].prio_type) {
-			dst->path[tx].prio_type = src->path[tx].prio_type;
+		if (dst->path[tx].tsa != src->path[tx].tsa) {
+			dst->path[tx].tsa = src->path[tx].tsa;
 			changes |= BIT_PG_TX;
 		}
 
@@ -86,14 +79,14 @@ static int ixgbe_copy_dcb_cfg(struct ixgbe_adapter *adapter, int tc_max)
 		}
 
 		if (dst->path[tx].up_to_tc_bitmap !=
-				src->path[tx].up_to_tc_bitmap) {
+		    src->path[tx].up_to_tc_bitmap) {
 			dst->path[tx].up_to_tc_bitmap =
 				src->path[tx].up_to_tc_bitmap;
 			changes |= (BIT_PG_TX | BIT_PFC | BIT_APP_UPCHG);
 		}
 
-		if (dst->path[rx].prio_type != src->path[rx].prio_type) {
-			dst->path[rx].prio_type = src->path[rx].prio_type;
+		if (dst->path[rx].tsa != src->path[rx].tsa) {
+			dst->path[rx].tsa = src->path[rx].tsa;
 			changes |= BIT_PG_RX;
 		}
 
@@ -108,7 +101,7 @@ static int ixgbe_copy_dcb_cfg(struct ixgbe_adapter *adapter, int tc_max)
 		}
 
 		if (dst->path[rx].up_to_tc_bitmap !=
-				src->path[rx].up_to_tc_bitmap) {
+		    src->path[rx].up_to_tc_bitmap) {
 			dst->path[rx].up_to_tc_bitmap =
 				src->path[rx].up_to_tc_bitmap;
 			changes |= (BIT_PG_RX | BIT_PFC | BIT_APP_UPCHG);
@@ -117,6 +110,7 @@ static int ixgbe_copy_dcb_cfg(struct ixgbe_adapter *adapter, int tc_max)
 
 	for (i = DCB_PG_ATTR_BW_ID_0; i < DCB_PG_ATTR_BW_ID_MAX; i++) {
 		j = i - DCB_PG_ATTR_BW_ID_0;
+
 		if (dcfg->bw_percentage[tx][j] != scfg->bw_percentage[tx][j]) {
 			dcfg->bw_percentage[tx][j] = scfg->bw_percentage[tx][j];
 			changes |= BIT_PG_TX;
@@ -129,8 +123,8 @@ static int ixgbe_copy_dcb_cfg(struct ixgbe_adapter *adapter, int tc_max)
 
 	for (i = DCB_PFC_UP_ATTR_0; i < DCB_PFC_UP_ATTR_MAX; i++) {
 		j = i - DCB_PFC_UP_ATTR_0;
-		if (dcfg->tc_config[j].dcb_pfc != scfg->tc_config[j].dcb_pfc) {
-			dcfg->tc_config[j].dcb_pfc = scfg->tc_config[j].dcb_pfc;
+		if (dcfg->tc_config[j].pfc != scfg->tc_config[j].pfc) {
+			dcfg->tc_config[j].pfc = scfg->tc_config[j].pfc;
 			changes |= BIT_PFC;
 		}
 	}
@@ -153,6 +147,7 @@ static u8 ixgbe_dcbnl_get_state(struct net_device *netdev)
 static u8 ixgbe_dcbnl_set_state(struct net_device *netdev, u8 state)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	int err = 0;
 
 	/* Fail command if not in CEE mode */
 	if (!(adapter->dcbx_cap & DCB_CAP_DCBX_VER_CEE))
@@ -160,10 +155,12 @@ static u8 ixgbe_dcbnl_set_state(struct net_device *netdev, u8 state)
 
 	/* verify there is something to do, if not then exit */
 	if (!state == !(adapter->flags & IXGBE_FLAG_DCB_ENABLED))
-		return 0;
+		goto out;
 
-	return !!ixgbe_setup_tc(netdev,
-				state ? adapter->dcb_cfg.num_tcs.pg_tcs : 0);
+	err = ixgbe_setup_tc(netdev,
+			     state ? adapter->dcb_cfg.num_tcs.pg_tcs : 0);
+out:
+	return !!err;
 }
 
 static void ixgbe_dcbnl_get_perm_hw_addr(struct net_device *netdev,
@@ -196,7 +193,7 @@ static void ixgbe_dcbnl_set_pg_tc_cfg_tx(struct net_device *netdev, int tc,
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 
 	if (prio != DCB_ATTR_VALUE_UNDEFINED)
-		adapter->temp_dcb_cfg.tc_config[tc].path[0].prio_type = prio;
+		adapter->temp_dcb_cfg.tc_config[tc].path[0].tsa = prio;
 	if (bwg_id != DCB_ATTR_VALUE_UNDEFINED)
 		adapter->temp_dcb_cfg.tc_config[tc].path[0].bwg_id = bwg_id;
 	if (bw_pct != DCB_ATTR_VALUE_UNDEFINED)
@@ -222,7 +219,7 @@ static void ixgbe_dcbnl_set_pg_tc_cfg_rx(struct net_device *netdev, int tc,
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 
 	if (prio != DCB_ATTR_VALUE_UNDEFINED)
-		adapter->temp_dcb_cfg.tc_config[tc].path[1].prio_type = prio;
+		adapter->temp_dcb_cfg.tc_config[tc].path[1].tsa = prio;
 	if (bwg_id != DCB_ATTR_VALUE_UNDEFINED)
 		adapter->temp_dcb_cfg.tc_config[tc].path[1].bwg_id = bwg_id;
 	if (bw_pct != DCB_ATTR_VALUE_UNDEFINED)
@@ -247,7 +244,7 @@ static void ixgbe_dcbnl_get_pg_tc_cfg_tx(struct net_device *netdev, int tc,
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 
-	*prio = adapter->dcb_cfg.tc_config[tc].path[0].prio_type;
+	*prio = adapter->dcb_cfg.tc_config[tc].path[0].tsa;
 	*bwg_id = adapter->dcb_cfg.tc_config[tc].path[0].bwg_id;
 	*bw_pct = adapter->dcb_cfg.tc_config[tc].path[0].bwg_percent;
 	*up_map = adapter->dcb_cfg.tc_config[tc].path[0].up_to_tc_bitmap;
@@ -267,7 +264,7 @@ static void ixgbe_dcbnl_get_pg_tc_cfg_rx(struct net_device *netdev, int tc,
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 
-	*prio = adapter->dcb_cfg.tc_config[tc].path[1].prio_type;
+	*prio = adapter->dcb_cfg.tc_config[tc].path[1].tsa;
 	*bwg_id = adapter->dcb_cfg.tc_config[tc].path[1].bwg_id;
 	*bw_pct = adapter->dcb_cfg.tc_config[tc].path[1].bwg_percent;
 	*up_map = adapter->dcb_cfg.tc_config[tc].path[1].up_to_tc_bitmap;
@@ -281,23 +278,22 @@ static void ixgbe_dcbnl_get_pg_bwg_cfg_rx(struct net_device *netdev, int bwg_id,
 	*bw_pct = adapter->dcb_cfg.bw_percentage[1][bwg_id];
 }
 
-static void ixgbe_dcbnl_set_pfc_cfg(struct net_device *netdev, int priority,
-				    u8 setting)
+static void ixgbe_dcbnl_set_pfc_cfg(struct net_device *netdev, int up, u8 pfc)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	u8 tc = ixgbe_dcb_get_tc_from_up(&adapter->temp_dcb_cfg, 0, up);
 
-	adapter->temp_dcb_cfg.tc_config[priority].dcb_pfc = setting;
-	if (adapter->temp_dcb_cfg.tc_config[priority].dcb_pfc !=
-	    adapter->dcb_cfg.tc_config[priority].dcb_pfc)
+	adapter->temp_dcb_cfg.tc_config[tc].pfc = pfc;
+	if (adapter->temp_dcb_cfg.tc_config[tc].pfc !=
+	    adapter->dcb_cfg.tc_config[tc].pfc)
 		adapter->temp_dcb_cfg.pfc_mode_enable = true;
 }
 
-static void ixgbe_dcbnl_get_pfc_cfg(struct net_device *netdev, int priority,
-				    u8 *setting)
+static void ixgbe_dcbnl_get_pfc_cfg(struct net_device *netdev, int up, u8 *pfc)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-
-	*setting = adapter->dcb_cfg.tc_config[priority].dcb_pfc;
+	u8 tc = ixgbe_dcb_get_tc_from_up(&adapter->dcb_cfg, 0, up);
+	*pfc = adapter->dcb_cfg.tc_config[tc].pfc;
 }
 
 static void ixgbe_dcbnl_devreset(struct net_device *dev)
@@ -308,13 +304,21 @@ static void ixgbe_dcbnl_devreset(struct net_device *dev)
 		usleep_range(1000, 2000);
 
 	if (netif_running(dev))
+#ifdef HAVE_NET_DEVICE_OPS
 		dev->netdev_ops->ndo_stop(dev);
+#else
+		dev->stop(dev);
+#endif
 
 	ixgbe_clear_interrupt_scheme(adapter);
 	ixgbe_init_interrupt_scheme(adapter);
 
 	if (netif_running(dev))
+#ifdef HAVE_NET_DEVICE_OPS
 		dev->netdev_ops->ndo_open(dev);
+#else
+		dev->open(dev);
+#endif
 
 	clear_bit(__IXGBE_RESETTING, &adapter->state);
 }
@@ -325,83 +329,80 @@ static u8 ixgbe_dcbnl_set_all(struct net_device *netdev)
 	struct ixgbe_dcb_config *dcb_cfg = &adapter->dcb_cfg;
 	struct ixgbe_hw *hw = &adapter->hw;
 	int ret = DCB_NO_HW_CHG;
-	int i;
+	u8 prio_tc[IXGBE_DCB_MAX_USER_PRIORITY] = { 0 };
 
 	/* Fail command if not in CEE mode */
 	if (!(adapter->dcbx_cap & DCB_CAP_DCBX_VER_CEE))
-		return DCB_NO_HW_CHG;
+		return ret;
 
 	adapter->dcb_set_bitmap |= ixgbe_copy_dcb_cfg(adapter,
-						      MAX_TRAFFIC_CLASS);
+						      IXGBE_DCB_MAX_TRAFFIC_CLASS);
 	if (!adapter->dcb_set_bitmap)
-		return DCB_NO_HW_CHG;
+		return ret;
+
+	ixgbe_dcb_unpack_map_cee(dcb_cfg, IXGBE_DCB_TX_CONFIG, prio_tc);
 
-	if (adapter->dcb_set_bitmap & (BIT_PG_TX|BIT_PG_RX)) {
-		u16 refill[MAX_TRAFFIC_CLASS], max[MAX_TRAFFIC_CLASS];
-		u8 bwg_id[MAX_TRAFFIC_CLASS], prio_type[MAX_TRAFFIC_CLASS];
+	if (adapter->dcb_set_bitmap & (BIT_PG_TX | BIT_PG_RX)) {
 		/* Priority to TC mapping in CEE case default to 1:1 */
-		u8 prio_tc[MAX_USER_PRIORITY];
 		int max_frame = adapter->netdev->mtu + ETH_HLEN + ETH_FCS_LEN;
+#ifdef HAVE_MQPRIO
+		int i;
+#endif
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 		if (adapter->netdev->features & NETIF_F_FCOE_MTU)
 			max_frame = max(max_frame, IXGBE_FCOE_JUMBO_FRAME_SIZE);
 #endif
 
-		ixgbe_dcb_calculate_tc_credits(hw, dcb_cfg, max_frame,
-					       DCB_TX_CONFIG);
-		ixgbe_dcb_calculate_tc_credits(hw, dcb_cfg, max_frame,
-					       DCB_RX_CONFIG);
+		ixgbe_dcb_calculate_tc_credits_cee(hw, dcb_cfg, max_frame,
+						   IXGBE_DCB_TX_CONFIG);
 
-		ixgbe_dcb_unpack_refill(dcb_cfg, DCB_TX_CONFIG, refill);
-		ixgbe_dcb_unpack_max(dcb_cfg, max);
-		ixgbe_dcb_unpack_bwgid(dcb_cfg, DCB_TX_CONFIG, bwg_id);
-		ixgbe_dcb_unpack_prio(dcb_cfg, DCB_TX_CONFIG, prio_type);
-		ixgbe_dcb_unpack_map(dcb_cfg, DCB_TX_CONFIG, prio_tc);
+		ixgbe_dcb_calculate_tc_credits_cee(hw, dcb_cfg, max_frame,
+						   IXGBE_DCB_RX_CONFIG);
 
-		ixgbe_dcb_hw_ets_config(hw, refill, max, bwg_id,
-					prio_type, prio_tc);
+		ixgbe_dcb_hw_config_cee(hw, dcb_cfg);
 
+#ifdef HAVE_MQPRIO
 		for (i = 0; i < IEEE_8021QAZ_MAX_TCS; i++)
 			netdev_set_prio_tc_map(netdev, i, prio_tc[i]);
-
+#endif /* HAVE_MQPRIO */
 		ret = DCB_HW_CHG_RST;
 	}
 
 	if (adapter->dcb_set_bitmap & BIT_PFC) {
 		if (dcb_cfg->pfc_mode_enable) {
 			u8 pfc_en;
-			u8 prio_tc[MAX_USER_PRIORITY];
-
-			ixgbe_dcb_unpack_map(dcb_cfg, DCB_TX_CONFIG, prio_tc);
-			ixgbe_dcb_unpack_pfc(dcb_cfg, &pfc_en);
-			ixgbe_dcb_hw_pfc_config(hw, pfc_en, prio_tc);
+			ixgbe_dcb_unpack_pfc_cee(dcb_cfg, prio_tc, &pfc_en);
+			ixgbe_dcb_config_pfc(hw, pfc_en, prio_tc);
 		} else {
 			hw->mac.ops.fc_enable(hw);
 		}
+		/* This is known driver so disable MDD before updating SRRCTL */
+		if ((adapter->num_vfs) && (hw->mac.ops.disable_mdd) &&
+		    (adapter->flags & IXGBE_FLAG_MDD_ENABLED))
+			hw->mac.ops.disable_mdd(hw);
 
 		ixgbe_set_rx_drop_en(adapter);
 
-		ret = DCB_HW_CHG;
+		if ((adapter->num_vfs) && (hw->mac.ops.enable_mdd) &&
+		    (adapter->flags & IXGBE_FLAG_MDD_ENABLED))
+			hw->mac.ops.enable_mdd(hw);
+
+		if (ret != DCB_HW_CHG_RST)
+			ret = DCB_HW_CHG;
 	}
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* Reprogam FCoE hardware offloads when the traffic class
 	 * FCoE is using changes. This happens if the APP info
 	 * changes or the up2tc mapping is updated.
 	 */
 	if (adapter->dcb_set_bitmap & BIT_APP_UPCHG) {
-		struct dcb_app app = {
-				      .selector = DCB_APP_IDTYPE_ETHTYPE,
-				      .protocol = ETH_P_FCOE,
-				     };
-		u8 up = dcb_getapp(netdev, &app);
-
-		adapter->fcoe.up = ffs(up) - 1;
+		adapter->fcoe.up_set = adapter->fcoe.up;
 		ixgbe_dcbnl_devreset(netdev);
 		ret = DCB_HW_CHG_RST;
 	}
-#endif
+#endif /* CONFIG_FCOE */
 
 	adapter->dcb_set_bitmap = 0x00;
 	return ret;
@@ -409,7 +410,9 @@ static u8 ixgbe_dcbnl_set_all(struct net_device *netdev)
 
 static u8 ixgbe_dcbnl_getcap(struct net_device *netdev, int capid, u8 *cap)
 {
+#ifdef HAVE_DCBNL_IEEE
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+#endif
 
 	switch (capid) {
 	case DCB_CAP_ATTR_PG:
@@ -433,9 +436,11 @@ static u8 ixgbe_dcbnl_getcap(struct net_device *netdev, int capid, u8 *cap)
 	case DCB_CAP_ATTR_BCN:
 		*cap = false;
 		break;
+#ifdef HAVE_DCBNL_IEEE
 	case DCB_CAP_ATTR_DCBX:
 		*cap = adapter->dcbx_cap;
 		break;
+#endif
 	default:
 		*cap = false;
 		break;
@@ -444,9 +449,14 @@ static u8 ixgbe_dcbnl_getcap(struct net_device *netdev, int capid, u8 *cap)
 	return 0;
 }
 
+#ifdef NUMTCS_RETURNS_U8
+static u8 ixgbe_dcbnl_getnumtcs(struct net_device *netdev, int tcid, u8 *num)
+#else
 static int ixgbe_dcbnl_getnumtcs(struct net_device *netdev, int tcid, u8 *num)
+#endif
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	u8 rval = 0;
 
 	if (adapter->flags & IXGBE_FLAG_DCB_ENABLED) {
 		switch (tcid) {
@@ -457,18 +467,42 @@ static int ixgbe_dcbnl_getnumtcs(struct net_device *netdev, int tcid, u8 *num)
 			*num = adapter->dcb_cfg.num_tcs.pfc_tcs;
 			break;
 		default:
-			return -EINVAL;
+			rval = -EINVAL;
+			break;
 		}
 	} else {
-		return -EINVAL;
+		rval = -EINVAL;
 	}
 
-	return 0;
+	return rval;
 }
 
+#ifdef NUMTCS_RETURNS_U8
+static u8 ixgbe_dcbnl_setnumtcs(struct net_device *netdev, int tcid, u8 num)
+#else
 static int ixgbe_dcbnl_setnumtcs(struct net_device *netdev, int tcid, u8 num)
+#endif
 {
-	return -EINVAL;
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	u8 rval = 0;
+
+	if (adapter->flags & IXGBE_FLAG_DCB_ENABLED) {
+		switch (tcid) {
+		case DCB_NUMTCS_ATTR_PG:
+			adapter->dcb_cfg.num_tcs.pg_tcs = num;
+			break;
+		case DCB_NUMTCS_ATTR_PFC:
+			adapter->dcb_cfg.num_tcs.pfc_tcs = num;
+			break;
+		default:
+			rval = -EINVAL;
+			break;
+		}
+	} else {
+		rval = -EINVAL;
+	}
+
+	return rval;
 }
 
 static u8 ixgbe_dcbnl_getpfcstate(struct net_device *netdev)
@@ -483,8 +517,10 @@ static void ixgbe_dcbnl_setpfcstate(struct net_device *netdev, u8 state)
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 
 	adapter->temp_dcb_cfg.pfc_mode_enable = state;
+	return;
 }
 
+#ifdef HAVE_DCBNL_OPS_GETAPP
 /**
  * ixgbe_dcbnl_getapp - retrieve the DCBX application user priority
  * @netdev : the corresponding netdev
@@ -492,35 +528,99 @@ static void ixgbe_dcbnl_setpfcstate(struct net_device *netdev, u8 state)
  * @id: id is either ether type or TCP/UDP port number
  *
  * Returns : on success, returns a non-zero 802.1p user priority bitmap
- * otherwise returns -EINVAL as the invalid user priority bitmap to indicate an
+ * otherwise returns 0 as the invalid user priority bitmap to indicate an
  * error.
  */
+#ifdef HAVE_DCBNL_OPS_SETAPP_RETURN_INT
 static int ixgbe_dcbnl_getapp(struct net_device *netdev, u8 idtype, u16 id)
+#else
+static u8 ixgbe_dcbnl_getapp(struct net_device *netdev, u8 idtype, u16 id)
+#endif
 {
-	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	u8 rval = 0;
+#ifdef HAVE_DCBNL_IEEE
 	struct dcb_app app = {
-				.selector = idtype,
-				.protocol = id,
-			     };
+		.selector = idtype,
+		.protocol = id,
+	};
 
-	if (!(adapter->dcbx_cap & DCB_CAP_DCBX_VER_CEE))
-		return -EINVAL;
+	rval = dcb_getapp(netdev, &app);
+#endif
+
+	switch (idtype) {
+	case DCB_APP_IDTYPE_ETHTYPE:
+#if IS_ENABLED(CONFIG_FCOE)
+		if (id == ETH_P_FCOE)
+			rval = ixgbe_fcoe_getapp(netdev);
+#endif
+		break;
+	case DCB_APP_IDTYPE_PORTNUM:
+		break;
+	default:
+		break;
+	}
+
+	return rval;
+}
+
+/**
+ * ixgbe_dcbnl_setapp - set the DCBX application user priority
+ * @netdev : the corresponding netdev
+ * @idtype : identifies the id as ether type or TCP/UDP port number
+ * @id: id is either ether type or TCP/UDP port number
+ * @up: the 802.1p user priority bitmap
+ *
+ * Returns : 0 on success or 1 on error
+ */
+#ifdef HAVE_DCBNL_OPS_SETAPP_RETURN_INT
+static int ixgbe_dcbnl_setapp(struct net_device *netdev,
+#else
+static u8 ixgbe_dcbnl_setapp(struct net_device *netdev,
+#endif
+			     u8 idtype, u16 id, u8 up)
+{
+	int err = 0;
+#ifdef HAVE_DCBNL_IEEE
+	struct dcb_app app;
+
+	app.selector = idtype;
+	app.protocol = id;
+	app.priority = up;
+	err = dcb_setapp(netdev, &app);
+#endif
+
+	switch (idtype) {
+	case DCB_APP_IDTYPE_ETHTYPE:
+#if IS_ENABLED(CONFIG_FCOE)
+		if (id == ETH_P_FCOE) {
+			struct ixgbe_adapter *adapter = netdev_priv(netdev);
+
+			adapter->fcoe.up = up ? ffs(up) - 1 : IXGBE_FCOE_DEFUP;
+		}
+#endif
+		break;
+	case DCB_APP_IDTYPE_PORTNUM:
+		break;
+	default:
+		break;
+	}
 
-	return dcb_getapp(netdev, &app);
+	return err;
 }
+#endif /* HAVE_DCBNL_OPS_GETAPP */
 
+#ifdef HAVE_DCBNL_IEEE
 static int ixgbe_dcbnl_ieee_getets(struct net_device *dev,
 				   struct ieee_ets *ets)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
 	struct ieee_ets *my_ets = adapter->ixgbe_ieee_ets;
 
-	ets->ets_cap = adapter->dcb_cfg.num_tcs.pg_tcs;
-
 	/* No IEEE PFC settings available */
 	if (!my_ets)
-		return 0;
+		return -EINVAL;
 
+	ets->ets_cap = adapter->dcb_cfg.num_tcs.pg_tcs;
 	ets->cbs = my_ets->cbs;
 	memcpy(ets->tc_tx_bw, my_ets->tc_tx_bw, sizeof(ets->tc_tx_bw));
 	memcpy(ets->tc_rx_bw, my_ets->tc_rx_bw, sizeof(ets->tc_rx_bw));
@@ -534,7 +634,7 @@ static int ixgbe_dcbnl_ieee_setets(struct net_device *dev,
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
 	int max_frame = dev->mtu + ETH_HLEN + ETH_FCS_LEN;
-	int i, err;
+	int i, err = 0;
 	__u8 max_tc = 0;
 	__u8 map_chg = 0;
 
@@ -546,13 +646,13 @@ static int ixgbe_dcbnl_ieee_setets(struct net_device *dev,
 						  GFP_KERNEL);
 		if (!adapter->ixgbe_ieee_ets)
 			return -ENOMEM;
-
 		/* initialize UP2TC mappings to invalid value */
 		for (i = 0; i < IEEE_8021QAZ_MAX_TCS; i++)
 			adapter->ixgbe_ieee_ets->prio_tc[i] =
 				IEEE_8021QAZ_MAX_TCS;
 		/* if possible update UP2TC mappings from HW */
-		ixgbe_dcb_read_rtrup2tc(&adapter->hw,
+		if (adapter->hw.mac.ops.get_rtrup2tc)
+			adapter->hw.mac.ops.get_rtrup2tc(&adapter->hw,
 					adapter->ixgbe_ieee_ets->prio_tc);
 	}
 
@@ -571,15 +671,17 @@ static int ixgbe_dcbnl_ieee_setets(struct net_device *dev,
 	if (max_tc > adapter->dcb_cfg.num_tcs.pg_tcs)
 		return -EINVAL;
 
-	if (max_tc != netdev_get_num_tc(dev)) {
+	if (max_tc != netdev_get_num_tc(dev))
 		err = ixgbe_setup_tc(dev, max_tc);
-		if (err)
-			return err;
-	} else if (map_chg) {
+	else if (map_chg)
 		ixgbe_dcbnl_devreset(dev);
-	}
 
-	return ixgbe_dcb_hw_ets(&adapter->hw, ets, max_frame);
+	if (err)
+		goto err_out;
+
+	err = ixgbe_dcb_hw_ets(&adapter->hw, ets, max_frame);
+err_out:
+	return err;
 }
 
 static int ixgbe_dcbnl_ieee_getpfc(struct net_device *dev,
@@ -589,17 +691,16 @@ static int ixgbe_dcbnl_ieee_getpfc(struct net_device *dev,
 	struct ieee_pfc *my_pfc = adapter->ixgbe_ieee_pfc;
 	int i;
 
-	pfc->pfc_cap = adapter->dcb_cfg.num_tcs.pfc_tcs;
-
 	/* No IEEE PFC settings available */
 	if (!my_pfc)
-		return 0;
+		return -EINVAL;
 
+	pfc->pfc_cap = adapter->dcb_cfg.num_tcs.pfc_tcs;
 	pfc->pfc_en = my_pfc->pfc_en;
 	pfc->mbc = my_pfc->mbc;
 	pfc->delay = my_pfc->delay;
 
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		pfc->requests[i] = adapter->stats.pxoffrxc[i];
 		pfc->indications[i] = adapter->stats.pxofftxc[i];
 	}
@@ -628,14 +729,24 @@ static int ixgbe_dcbnl_ieee_setpfc(struct net_device *dev,
 	prio_tc = adapter->ixgbe_ieee_ets->prio_tc;
 	memcpy(adapter->ixgbe_ieee_pfc, pfc, sizeof(*adapter->ixgbe_ieee_pfc));
 
+
 	/* Enable link flow control parameters if PFC is disabled */
 	if (pfc->pfc_en)
-		err = ixgbe_dcb_hw_pfc_config(hw, pfc->pfc_en, prio_tc);
+		err = ixgbe_dcb_config_pfc(hw, pfc->pfc_en, prio_tc);
 	else
 		err = hw->mac.ops.fc_enable(hw);
 
+	/* This is known driver so disable MDD before updating SRRCTL */
+	if ((adapter->num_vfs) && (hw->mac.ops.disable_mdd) &&
+	    (adapter->flags & IXGBE_FLAG_MDD_ENABLED))
+		hw->mac.ops.disable_mdd(hw);
+
 	ixgbe_set_rx_drop_en(adapter);
 
+	if ((adapter->num_vfs) && (hw->mac.ops.enable_mdd) &&
+	    (adapter->flags & IXGBE_FLAG_MDD_ENABLED))
+		hw->mac.ops.enable_mdd(hw);
+
 	return err;
 }
 
@@ -643,47 +754,30 @@ static int ixgbe_dcbnl_ieee_setapp(struct net_device *dev,
 				   struct dcb_app *app)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
-	int err;
+	int err = -EINVAL;
 
 	if (!(adapter->dcbx_cap & DCB_CAP_DCBX_VER_IEEE))
-		return -EINVAL;
+		return err;
 
 	err = dcb_ieee_setapp(dev, app);
-	if (err)
-		return err;
 
-#ifdef IXGBE_FCOE
-	if (app->selector == IEEE_8021QAZ_APP_SEL_ETHERTYPE &&
+#if IS_ENABLED(CONFIG_FCOE)
+	if (!err && app->selector == IEEE_8021QAZ_APP_SEL_ETHERTYPE &&
 	    app->protocol == ETH_P_FCOE) {
 		u8 app_mask = dcb_ieee_getapp_mask(dev, app);
 
 		if (app_mask & (1 << adapter->fcoe.up))
-			return 0;
+			return err;
 
 		adapter->fcoe.up = app->priority;
+		adapter->fcoe.up_set = adapter->fcoe.up;
 		ixgbe_dcbnl_devreset(dev);
 	}
 #endif
-
-	/* VF devices should use default UP when available */
-	if (app->selector == IEEE_8021QAZ_APP_SEL_ETHERTYPE &&
-	    app->protocol == 0) {
-		int vf;
-
-		adapter->default_up = app->priority;
-
-		for (vf = 0; vf < adapter->num_vfs; vf++) {
-			struct vf_data_storage *vfinfo = &adapter->vfinfo[vf];
-
-			if (!vfinfo->pf_qos)
-				ixgbe_set_vmvir(adapter, vfinfo->pf_vlan,
-						app->priority, vf);
-		}
-	}
-
 	return 0;
 }
 
+#ifdef HAVE_DCBNL_IEEE_DELAPP
 static int ixgbe_dcbnl_ieee_delapp(struct net_device *dev,
 				   struct dcb_app *app)
 {
@@ -695,39 +789,22 @@ static int ixgbe_dcbnl_ieee_delapp(struct net_device *dev,
 
 	err = dcb_ieee_delapp(dev, app);
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	if (!err && app->selector == IEEE_8021QAZ_APP_SEL_ETHERTYPE &&
 	    app->protocol == ETH_P_FCOE) {
 		u8 app_mask = dcb_ieee_getapp_mask(dev, app);
 
 		if (app_mask & (1 << adapter->fcoe.up))
-			return 0;
+			return err;
 
 		adapter->fcoe.up = app_mask ?
-				   ffs(app_mask) - 1 : IXGBE_FCOE_DEFTC;
+				   ffs(app_mask) - 1 : IXGBE_FCOE_DEFUP;
 		ixgbe_dcbnl_devreset(dev);
 	}
 #endif
-	/* IF default priority is being removed clear VF default UP */
-	if (app->selector == IEEE_8021QAZ_APP_SEL_ETHERTYPE &&
-	    app->protocol == 0 && adapter->default_up == app->priority) {
-		int vf;
-		long unsigned int app_mask = dcb_ieee_getapp_mask(dev, app);
-		int qos = app_mask ? find_first_bit(&app_mask, 8) : 0;
-
-		adapter->default_up = qos;
-
-		for (vf = 0; vf < adapter->num_vfs; vf++) {
-			struct vf_data_storage *vfinfo = &adapter->vfinfo[vf];
-
-			if (!vfinfo->pf_qos)
-				ixgbe_set_vmvir(adapter, vfinfo->pf_vlan,
-						qos, vf);
-		}
-	}
-
 	return err;
 }
+#endif /* HAVE_DCBNL_IEEE_DELAPP */
 
 static u8 ixgbe_dcbnl_getdcbx(struct net_device *dev)
 {
@@ -738,9 +815,8 @@ static u8 ixgbe_dcbnl_getdcbx(struct net_device *dev)
 static u8 ixgbe_dcbnl_setdcbx(struct net_device *dev, u8 mode)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
-	struct ieee_ets ets = {0};
-	struct ieee_pfc pfc = {0};
-	int err = 0;
+	struct ieee_ets ets = { .ets_cap = 0 };
+	struct ieee_pfc pfc = { .pfc_en = 0 };
 
 	/* no support for LLD_MANAGED modes or CEE+IEEE */
 	if ((mode & DCB_CAP_DCBX_LLD_MANAGED) ||
@@ -761,7 +837,7 @@ static u8 ixgbe_dcbnl_setdcbx(struct net_device *dev, u8 mode)
 		ixgbe_dcbnl_ieee_setets(dev, &ets);
 		ixgbe_dcbnl_ieee_setpfc(dev, &pfc);
 	} else if (mode & DCB_CAP_DCBX_VER_CEE) {
-		u8 mask = BIT_PFC | BIT_PG_TX | BIT_PG_RX | BIT_APP_UPCHG;
+		u8 mask = (BIT_PFC | BIT_PG_TX | BIT_PG_RX | BIT_APP_UPCHG);
 
 		adapter->dcb_set_bitmap |= mask;
 		ixgbe_dcbnl_set_all(dev);
@@ -771,19 +847,25 @@ static u8 ixgbe_dcbnl_setdcbx(struct net_device *dev, u8 mode)
 		 */
 		ixgbe_dcbnl_ieee_setets(dev, &ets);
 		ixgbe_dcbnl_ieee_setpfc(dev, &pfc);
-		err = ixgbe_setup_tc(dev, 0);
+		ixgbe_setup_tc(dev, 0);
 	}
 
-	return err ? 1 : 0;
+	return 0;
 }
 
-const struct dcbnl_rtnl_ops dcbnl_ops = {
+#endif
+
+struct dcbnl_rtnl_ops ixgbe_dcbnl_ops = {
+#ifdef HAVE_DCBNL_IEEE
 	.ieee_getets	= ixgbe_dcbnl_ieee_getets,
 	.ieee_setets	= ixgbe_dcbnl_ieee_setets,
 	.ieee_getpfc	= ixgbe_dcbnl_ieee_getpfc,
 	.ieee_setpfc	= ixgbe_dcbnl_ieee_setpfc,
 	.ieee_setapp	= ixgbe_dcbnl_ieee_setapp,
+#ifdef HAVE_DCBNL_IEEE_DELAPP
 	.ieee_delapp	= ixgbe_dcbnl_ieee_delapp,
+#endif
+#endif
 	.getstate	= ixgbe_dcbnl_get_state,
 	.setstate	= ixgbe_dcbnl_set_state,
 	.getpermhwaddr	= ixgbe_dcbnl_get_perm_hw_addr,
@@ -803,7 +885,14 @@ const struct dcbnl_rtnl_ops dcbnl_ops = {
 	.setnumtcs	= ixgbe_dcbnl_setnumtcs,
 	.getpfcstate	= ixgbe_dcbnl_getpfcstate,
 	.setpfcstate	= ixgbe_dcbnl_setpfcstate,
+#ifdef HAVE_DCBNL_OPS_GETAPP
 	.getapp		= ixgbe_dcbnl_getapp,
+	.setapp		= ixgbe_dcbnl_setapp,
+#endif
+#ifdef HAVE_DCBNL_IEEE
 	.getdcbx	= ixgbe_dcbnl_getdcbx,
 	.setdcbx	= ixgbe_dcbnl_setdcbx,
+#endif
 };
+
+#endif /* CONFIG_DCB */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_debugfs.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_debugfs.c
index 5e2c1e3..94073c6 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_debugfs.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_debugfs.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -25,11 +21,13 @@
   Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
 
 *******************************************************************************/
-#include <linux/debugfs.h>
-#include <linux/module.h>
 
 #include "ixgbe.h"
 
+#ifdef HAVE_IXGBE_DEBUG_FS
+#include <linux/debugfs.h>
+#include <linux/module.h>
+
 static struct dentry *ixgbe_dbg_root;
 
 static char ixgbe_dbg_reg_ops_buf[256] = "";
@@ -103,7 +101,8 @@ static ssize_t ixgbe_dbg_reg_ops_write(struct file *filp,
 		u32 reg, value;
 		int cnt;
 		cnt = sscanf(&ixgbe_dbg_reg_ops_buf[5], "%x %x", &reg, &value);
-		if (cnt == 2) {
+		/* check format and bounds check register access */
+		if (cnt == 2 && reg <= IXGBE_HFDR) {
 			IXGBE_WRITE_REG(&adapter->hw, reg, value);
 			value = IXGBE_READ_REG(&adapter->hw, reg);
 			e_dev_info("write: 0x%08x = 0x%08x\n", reg, value);
@@ -114,7 +113,8 @@ static ssize_t ixgbe_dbg_reg_ops_write(struct file *filp,
 		u32 reg, value;
 		int cnt;
 		cnt = sscanf(&ixgbe_dbg_reg_ops_buf[4], "%x", &reg);
-		if (cnt == 1) {
+		/* check format and bounds check register access */
+		if (cnt == 1 && reg <= IXGBE_HFDR) {
 			value = IXGBE_READ_REG(&adapter->hw, reg);
 			e_dev_info("read 0x%08x = 0x%08x\n", reg, value);
 		} else {
@@ -205,7 +205,11 @@ static ssize_t ixgbe_dbg_netdev_ops_write(struct file *filp,
 	ixgbe_dbg_netdev_ops_buf[len] = '\0';
 
 	if (strncmp(ixgbe_dbg_netdev_ops_buf, "tx_timeout", 10) == 0) {
+#ifdef HAVE_NET_DEVICE_OPS
 		adapter->netdev->netdev_ops->ndo_tx_timeout(adapter->netdev);
+#else
+		adapter->netdev->tx_timeout(adapter->netdev);
+#endif /* HAVE_NET_DEVICE_OPS */
 		e_dev_info("tx_timeout called\n");
 	} else {
 		e_dev_info("Unknown command: %s\n", ixgbe_dbg_netdev_ops_buf);
@@ -215,7 +219,7 @@ static ssize_t ixgbe_dbg_netdev_ops_write(struct file *filp,
 	return count;
 }
 
-static const struct file_operations ixgbe_dbg_netdev_ops_fops = {
+static struct file_operations ixgbe_dbg_netdev_ops_fops = {
 	.owner = THIS_MODULE,
 	.open = simple_open,
 	.read = ixgbe_dbg_netdev_ops_read,
@@ -253,7 +257,8 @@ void ixgbe_dbg_adapter_init(struct ixgbe_adapter *adapter)
  **/
 void ixgbe_dbg_adapter_exit(struct ixgbe_adapter *adapter)
 {
-	debugfs_remove_recursive(adapter->ixgbe_dbg_adapter);
+	if (adapter->ixgbe_dbg_adapter)
+		debugfs_remove_recursive(adapter->ixgbe_dbg_adapter);
 	adapter->ixgbe_dbg_adapter = NULL;
 }
 
@@ -274,3 +279,5 @@ void ixgbe_dbg_exit(void)
 {
 	debugfs_remove_recursive(ixgbe_dbg_root);
 }
+
+#endif /* HAVE_IXGBE_DEBUG_FS */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_ethtool.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_ethtool.c
index d681273..011f5d5 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_ethtool.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_ethtool.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -28,99 +24,122 @@
 
 /* ethtool support for ixgbe */
 
-#include <linux/interrupt.h>
 #include <linux/types.h>
 #include <linux/module.h>
-#include <linux/slab.h>
 #include <linux/pci.h>
 #include <linux/netdevice.h>
 #include <linux/ethtool.h>
 #include <linux/vmalloc.h>
 #include <linux/highmem.h>
-#include <linux/uaccess.h>
+
+#ifdef SIOCETHTOOL
+#include <asm/uaccess.h>
 
 #include "ixgbe.h"
+#ifdef ETHTOOL_GMODULEINFO
 #include "ixgbe_phy.h"
+#endif
+#ifdef HAVE_ETHTOOL_GET_TS_INFO
+#include <linux/net_tstamp.h>
+#endif
 
+#ifndef ETH_GSTRING_LEN
+#define ETH_GSTRING_LEN 32
+#endif
 
 #define IXGBE_ALL_RAR_ENTRIES 16
 
-enum {NETDEV_STATS, IXGBE_STATS};
-
+#ifdef ETHTOOL_OPS_COMPAT
+#include "kcompat_ethtool.c"
+#endif
+#ifdef ETHTOOL_GSTATS
 struct ixgbe_stats {
 	char stat_string[ETH_GSTRING_LEN];
-	int type;
 	int sizeof_stat;
 	int stat_offset;
 };
 
-#define IXGBE_STAT(m)		IXGBE_STATS, \
-				sizeof(((struct ixgbe_adapter *)0)->m), \
-				offsetof(struct ixgbe_adapter, m)
-#define IXGBE_NETDEV_STAT(m)	NETDEV_STATS, \
-				sizeof(((struct rtnl_link_stats64 *)0)->m), \
-				offsetof(struct rtnl_link_stats64, m)
-
-static const struct ixgbe_stats ixgbe_gstrings_stats[] = {
-	{"rx_packets", IXGBE_NETDEV_STAT(rx_packets)},
-	{"tx_packets", IXGBE_NETDEV_STAT(tx_packets)},
-	{"rx_bytes", IXGBE_NETDEV_STAT(rx_bytes)},
-	{"tx_bytes", IXGBE_NETDEV_STAT(tx_bytes)},
-	{"rx_pkts_nic", IXGBE_STAT(stats.gprc)},
-	{"tx_pkts_nic", IXGBE_STAT(stats.gptc)},
-	{"rx_bytes_nic", IXGBE_STAT(stats.gorc)},
-	{"tx_bytes_nic", IXGBE_STAT(stats.gotc)},
-	{"lsc_int", IXGBE_STAT(lsc_int)},
-	{"tx_busy", IXGBE_STAT(tx_busy)},
-	{"non_eop_descs", IXGBE_STAT(non_eop_descs)},
-	{"rx_errors", IXGBE_NETDEV_STAT(rx_errors)},
-	{"tx_errors", IXGBE_NETDEV_STAT(tx_errors)},
-	{"rx_dropped", IXGBE_NETDEV_STAT(rx_dropped)},
-	{"tx_dropped", IXGBE_NETDEV_STAT(tx_dropped)},
-	{"multicast", IXGBE_NETDEV_STAT(multicast)},
-	{"broadcast", IXGBE_STAT(stats.bprc)},
-	{"rx_no_buffer_count", IXGBE_STAT(stats.rnbc[0]) },
-	{"collisions", IXGBE_NETDEV_STAT(collisions)},
-	{"rx_over_errors", IXGBE_NETDEV_STAT(rx_over_errors)},
-	{"rx_crc_errors", IXGBE_NETDEV_STAT(rx_crc_errors)},
-	{"rx_frame_errors", IXGBE_NETDEV_STAT(rx_frame_errors)},
-	{"hw_rsc_aggregated", IXGBE_STAT(rsc_total_count)},
-	{"hw_rsc_flushed", IXGBE_STAT(rsc_total_flush)},
-	{"fdir_match", IXGBE_STAT(stats.fdirmatch)},
-	{"fdir_miss", IXGBE_STAT(stats.fdirmiss)},
-	{"fdir_overflow", IXGBE_STAT(fdir_overflow)},
-	{"rx_fifo_errors", IXGBE_NETDEV_STAT(rx_fifo_errors)},
-	{"rx_missed_errors", IXGBE_NETDEV_STAT(rx_missed_errors)},
-	{"tx_aborted_errors", IXGBE_NETDEV_STAT(tx_aborted_errors)},
-	{"tx_carrier_errors", IXGBE_NETDEV_STAT(tx_carrier_errors)},
-	{"tx_fifo_errors", IXGBE_NETDEV_STAT(tx_fifo_errors)},
-	{"tx_heartbeat_errors", IXGBE_NETDEV_STAT(tx_heartbeat_errors)},
-	{"tx_timeout_count", IXGBE_STAT(tx_timeout_count)},
-	{"tx_restart_queue", IXGBE_STAT(restart_queue)},
-	{"rx_long_length_errors", IXGBE_STAT(stats.roc)},
-	{"rx_short_length_errors", IXGBE_STAT(stats.ruc)},
-	{"tx_flow_control_xon", IXGBE_STAT(stats.lxontxc)},
-	{"rx_flow_control_xon", IXGBE_STAT(stats.lxonrxc)},
-	{"tx_flow_control_xoff", IXGBE_STAT(stats.lxofftxc)},
-	{"rx_flow_control_xoff", IXGBE_STAT(stats.lxoffrxc)},
-	{"rx_csum_offload_errors", IXGBE_STAT(hw_csum_rx_error)},
-	{"alloc_rx_page_failed", IXGBE_STAT(alloc_rx_page_failed)},
-	{"alloc_rx_buff_failed", IXGBE_STAT(alloc_rx_buff_failed)},
-	{"rx_no_dma_resources", IXGBE_STAT(hw_rx_no_dma_resources)},
-	{"os2bmc_rx_by_bmc", IXGBE_STAT(stats.o2bgptc)},
-	{"os2bmc_tx_by_bmc", IXGBE_STAT(stats.b2ospc)},
-	{"os2bmc_tx_by_host", IXGBE_STAT(stats.o2bspc)},
-	{"os2bmc_rx_by_host", IXGBE_STAT(stats.b2ogprc)},
-#ifdef IXGBE_FCOE
-	{"fcoe_bad_fccrc", IXGBE_STAT(stats.fccrc)},
-	{"rx_fcoe_dropped", IXGBE_STAT(stats.fcoerpdc)},
-	{"rx_fcoe_packets", IXGBE_STAT(stats.fcoeprc)},
-	{"rx_fcoe_dwords", IXGBE_STAT(stats.fcoedwrc)},
-	{"fcoe_noddp", IXGBE_STAT(stats.fcoe_noddp)},
-	{"fcoe_noddp_ext_buff", IXGBE_STAT(stats.fcoe_noddp_ext_buff)},
-	{"tx_fcoe_packets", IXGBE_STAT(stats.fcoeptc)},
-	{"tx_fcoe_dwords", IXGBE_STAT(stats.fcoedwtc)},
-#endif /* IXGBE_FCOE */
+#define IXGBE_NETDEV_STAT(_net_stat) { \
+	.stat_string = #_net_stat, \
+	.sizeof_stat = FIELD_SIZEOF(struct net_device_stats, _net_stat), \
+	.stat_offset = offsetof(struct net_device_stats, _net_stat) \
+}
+static const struct ixgbe_stats ixgbe_gstrings_net_stats[] = {
+	IXGBE_NETDEV_STAT(rx_packets),
+	IXGBE_NETDEV_STAT(tx_packets),
+	IXGBE_NETDEV_STAT(rx_bytes),
+	IXGBE_NETDEV_STAT(tx_bytes),
+	IXGBE_NETDEV_STAT(rx_errors),
+	IXGBE_NETDEV_STAT(tx_errors),
+	IXGBE_NETDEV_STAT(rx_dropped),
+	IXGBE_NETDEV_STAT(tx_dropped),
+	IXGBE_NETDEV_STAT(multicast),
+	IXGBE_NETDEV_STAT(collisions),
+	IXGBE_NETDEV_STAT(rx_over_errors),
+	IXGBE_NETDEV_STAT(rx_crc_errors),
+	IXGBE_NETDEV_STAT(rx_frame_errors),
+	IXGBE_NETDEV_STAT(rx_fifo_errors),
+	IXGBE_NETDEV_STAT(rx_missed_errors),
+	IXGBE_NETDEV_STAT(tx_aborted_errors),
+	IXGBE_NETDEV_STAT(tx_carrier_errors),
+	IXGBE_NETDEV_STAT(tx_fifo_errors),
+	IXGBE_NETDEV_STAT(tx_heartbeat_errors),
+};
+
+#define IXGBE_STAT(_name, _stat) { \
+	.stat_string = _name, \
+	.sizeof_stat = FIELD_SIZEOF(struct ixgbe_adapter, _stat), \
+	.stat_offset = offsetof(struct ixgbe_adapter, _stat) \
+}
+static struct ixgbe_stats ixgbe_gstrings_stats[] = {
+	IXGBE_STAT("rx_pkts_nic", stats.gprc),
+	IXGBE_STAT("tx_pkts_nic", stats.gptc),
+	IXGBE_STAT("rx_bytes_nic", stats.gorc),
+	IXGBE_STAT("tx_bytes_nic", stats.gotc),
+	IXGBE_STAT("lsc_int", lsc_int),
+	IXGBE_STAT("tx_busy", tx_busy),
+	IXGBE_STAT("non_eop_descs", non_eop_descs),
+	IXGBE_STAT("broadcast", stats.bprc),
+	IXGBE_STAT("rx_no_buffer_count", stats.rnbc[0]) ,
+	IXGBE_STAT("tx_timeout_count", tx_timeout_count),
+	IXGBE_STAT("tx_restart_queue", restart_queue),
+	IXGBE_STAT("rx_long_length_errors", stats.roc),
+	IXGBE_STAT("rx_short_length_errors", stats.ruc),
+	IXGBE_STAT("tx_flow_control_xon", stats.lxontxc),
+	IXGBE_STAT("rx_flow_control_xon", stats.lxonrxc),
+	IXGBE_STAT("tx_flow_control_xoff", stats.lxofftxc),
+	IXGBE_STAT("rx_flow_control_xoff", stats.lxoffrxc),
+	IXGBE_STAT("rx_csum_offload_errors", hw_csum_rx_error),
+	IXGBE_STAT("alloc_rx_page_failed", alloc_rx_page_failed),
+	IXGBE_STAT("alloc_rx_buff_failed", alloc_rx_buff_failed),
+	IXGBE_STAT("rx_no_dma_resources", hw_rx_no_dma_resources),
+	IXGBE_STAT("hw_rsc_aggregated", rsc_total_count),
+	IXGBE_STAT("hw_rsc_flushed", rsc_total_flush),
+#ifdef HAVE_TX_MQ
+	IXGBE_STAT("fdir_match", stats.fdirmatch),
+	IXGBE_STAT("fdir_miss", stats.fdirmiss),
+	IXGBE_STAT("fdir_overflow", fdir_overflow),
+#endif /* HAVE_TX_MQ */
+#if IS_ENABLED(CONFIG_FCOE)
+	IXGBE_STAT("fcoe_bad_fccrc", stats.fccrc),
+	IXGBE_STAT("fcoe_last_errors", stats.fclast),
+	IXGBE_STAT("rx_fcoe_dropped", stats.fcoerpdc),
+	IXGBE_STAT("rx_fcoe_packets", stats.fcoeprc),
+	IXGBE_STAT("rx_fcoe_dwords", stats.fcoedwrc),
+	IXGBE_STAT("fcoe_noddp", stats.fcoe_noddp),
+	IXGBE_STAT("fcoe_noddp_ext_buff", stats.fcoe_noddp_ext_buff),
+	IXGBE_STAT("tx_fcoe_packets", stats.fcoeptc),
+	IXGBE_STAT("tx_fcoe_dwords", stats.fcoedwtc),
+#endif /* CONFIG_FCOE */
+	IXGBE_STAT("os2bmc_rx_by_bmc", stats.o2bgptc),
+	IXGBE_STAT("os2bmc_tx_by_bmc", stats.b2ospc),
+	IXGBE_STAT("os2bmc_tx_by_host", stats.o2bspc),
+	IXGBE_STAT("os2bmc_rx_by_host", stats.b2ogprc),
+#ifdef HAVE_PTP_1588_CLOCK
+	IXGBE_STAT("tx_hwtstamp_timeouts", tx_hwtstamp_timeouts),
+	IXGBE_STAT("tx_hwtstamp_skipped", tx_hwtstamp_skipped),
+	IXGBE_STAT("rx_hwtstamp_cleared", rx_hwtstamp_cleared),
+#endif /* HAVE_PTP_1588_CLOCK */
 };
 
 /* ixgbe allocates num_tx_queues and num_rx_queues symmetrically so
@@ -128,70 +147,335 @@ static const struct ixgbe_stats ixgbe_gstrings_stats[] = {
  * used because we do not have a good way to get the max number of
  * rx queues with CONFIG_RPS disabled.
  */
+#ifdef HAVE_TX_MQ
+#ifdef HAVE_NETDEV_SELECT_QUEUE
 #define IXGBE_NUM_RX_QUEUES netdev->num_tx_queues
+#define IXGBE_NUM_TX_QUEUES netdev->num_tx_queues
+#else
+#define IXGBE_NUM_RX_QUEUES adapter->indices
+#define IXGBE_NUM_TX_QUEUES adapter->indices
+#endif /* HAVE_NETDEV_SELECT_QUEUE */
+#else /* HAVE_TX_MQ */
+#define IXGBE_NUM_TX_QUEUES 1
+#define IXGBE_NUM_RX_QUEUES ( \
+		((struct ixgbe_adapter *)netdev_priv(netdev))->num_rx_queues)
+#endif /* HAVE_TX_MQ */
 
 #define IXGBE_QUEUE_STATS_LEN ( \
-	(netdev->num_tx_queues + IXGBE_NUM_RX_QUEUES) * \
-	(sizeof(struct ixgbe_queue_stats) / sizeof(u64)))
-#define IXGBE_GLOBAL_STATS_LEN ARRAY_SIZE(ixgbe_gstrings_stats)
+		(IXGBE_NUM_TX_QUEUES + IXGBE_NUM_RX_QUEUES) * \
+		(sizeof(struct ixgbe_queue_stats) / sizeof(u64)))
+#define IXGBE_GLOBAL_STATS_LEN	ARRAY_SIZE(ixgbe_gstrings_stats)
+#define IXGBE_NETDEV_STATS_LEN	ARRAY_SIZE(ixgbe_gstrings_net_stats)
 #define IXGBE_PB_STATS_LEN ( \
-			(sizeof(((struct ixgbe_adapter *)0)->stats.pxonrxc) + \
-			 sizeof(((struct ixgbe_adapter *)0)->stats.pxontxc) + \
-			 sizeof(((struct ixgbe_adapter *)0)->stats.pxoffrxc) + \
-			 sizeof(((struct ixgbe_adapter *)0)->stats.pxofftxc)) \
-			/ sizeof(u64))
+		(sizeof(((struct ixgbe_adapter *)0)->stats.pxonrxc) + \
+		 sizeof(((struct ixgbe_adapter *)0)->stats.pxontxc) + \
+		 sizeof(((struct ixgbe_adapter *)0)->stats.pxoffrxc) + \
+		 sizeof(((struct ixgbe_adapter *)0)->stats.pxofftxc)) \
+		/ sizeof(u64))
+#define IXGBE_VF_STATS_LEN \
+	((((struct ixgbe_adapter *)netdev_priv(netdev))->num_vfs) * \
+	  (sizeof(struct vf_stats) / sizeof(u64)))
 #define IXGBE_STATS_LEN (IXGBE_GLOBAL_STATS_LEN + \
+			 IXGBE_NETDEV_STATS_LEN + \
 			 IXGBE_PB_STATS_LEN + \
-			 IXGBE_QUEUE_STATS_LEN)
+			 IXGBE_QUEUE_STATS_LEN + \
+			 IXGBE_VF_STATS_LEN)
 
+#endif /* ETHTOOL_GSTATS */
+#ifdef ETHTOOL_TEST
 static const char ixgbe_gstrings_test[][ETH_GSTRING_LEN] = {
 	"Register test  (offline)", "Eeprom test    (offline)",
 	"Interrupt test (offline)", "Loopback test  (offline)",
 	"Link test   (on/offline)"
 };
-#define IXGBE_TEST_LEN sizeof(ixgbe_gstrings_test) / ETH_GSTRING_LEN
+#define IXGBE_TEST_LEN	(sizeof(ixgbe_gstrings_test) / ETH_GSTRING_LEN)
+#endif /* ETHTOOL_TEST */
+
+#ifdef HAVE_ETHTOOL_GET_SSET_COUNT
+static const char ixgbe_priv_flags_strings[][ETH_GSTRING_LEN] = {
+#define IXGBE_PRIV_FLAGS_FD_ATR		BIT(0)
+	"flow-director-atr",
+#ifdef HAVE_SWIOTLB_SKIP_CPU_SYNC
+#define IXGBE_PRIV_FLAGS_LEGACY_RX	BIT(1)
+	"legacy-rx",
+#endif
+};
+
+#define IXGBE_PRIV_FLAGS_STR_LEN ARRAY_SIZE(ixgbe_priv_flags_strings)
+
+#endif /* HAVE_ETHTOOL_GET_SSET_COUNT */
+/* currently supported speeds for 10G */
+#define ADVERTISED_MASK_10G (SUPPORTED_10000baseT_Full | SUPPORTED_10000baseKX4_Full | SUPPORTED_10000baseKR_Full)
+
+#define ixgbe_isbackplane(type)  ((type == ixgbe_media_type_backplane)? true : false)
+
+static __u32 ixgbe_backplane_type(struct ixgbe_hw *hw)
+{
+	__u32 mode = 0x00;
+	switch(hw->device_id)
+	{
+		case IXGBE_DEV_ID_82598:
+		case IXGBE_DEV_ID_82599_KX4:
+		case IXGBE_DEV_ID_82599_KX4_MEZZ:
+		case IXGBE_DEV_ID_X550EM_X_KX4:
+			mode = SUPPORTED_10000baseKX4_Full;
+			break;
+		case IXGBE_DEV_ID_82598_BX:
+		case IXGBE_DEV_ID_82599_KR:
+		case IXGBE_DEV_ID_X550EM_X_KR:
+		case IXGBE_DEV_ID_X550EM_X_XFI:
+			mode = SUPPORTED_10000baseKR_Full;
+			break;
+		default:
+			mode = (SUPPORTED_10000baseKX4_Full | SUPPORTED_10000baseKR_Full);
+			break;
+	}
+	return mode;
+}
+
+#ifdef HAVE_ETHTOOL_CONVERT_U32_AND_LINK_MODE
+static int ixgbe_get_link_ksettings(struct net_device *netdev,
+				    struct ethtool_link_ksettings *cmd)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	struct ixgbe_hw *hw = &adapter->hw;
+	ixgbe_link_speed supported_link;
+	bool autoneg = false;
+	u32 supported, advertising;
+
+	ethtool_convert_link_mode_to_legacy_u32(&supported,
+						cmd->link_modes.supported);
+
+	hw->mac.ops.get_link_capabilities(hw, &supported_link, &autoneg);
+
+	/* set the supported link speeds */
+	if (supported_link & IXGBE_LINK_SPEED_10GB_FULL)
+		supported |= (ixgbe_isbackplane(hw->phy.media_type)) ?
+			      ixgbe_backplane_type(hw) :
+			      SUPPORTED_10000baseT_Full;
+	if (supported_link & IXGBE_LINK_SPEED_1GB_FULL)
+		supported |= (ixgbe_isbackplane(hw->phy.media_type)) ?
+			      SUPPORTED_1000baseKX_Full :
+			      SUPPORTED_1000baseT_Full;
+	if (supported_link & IXGBE_LINK_SPEED_100_FULL)
+		supported |= SUPPORTED_100baseT_Full;
+	if (supported_link & IXGBE_LINK_SPEED_10_FULL)
+		supported |= SUPPORTED_10baseT_Full;
+
+	/* default advertised speed if phy.autoneg_advertised isn't set */
+	advertising = supported;
+
+	/* set the advertised speeds */
+	if (hw->phy.autoneg_advertised)	{
+		advertising = 0;
+		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_10_FULL)
+			advertising |= ADVERTISED_10baseT_Full;
+		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_100_FULL)
+			advertising |= ADVERTISED_100baseT_Full;
+		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_10GB_FULL)
+			advertising |= supported & ADVERTISED_MASK_10G;
+		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_1GB_FULL) {
+			if (supported & SUPPORTED_1000baseKX_Full)
+				advertising |= ADVERTISED_1000baseKX_Full;
+			else
+				advertising |= ADVERTISED_1000baseT_Full;
+		}
+	} else {
+		if (hw->phy.multispeed_fiber && !autoneg) {
+			if (supported_link & IXGBE_LINK_SPEED_10GB_FULL)
+				advertising = ADVERTISED_10000baseT_Full;
+		}
+	}
+
+	if (autoneg) {
+		supported |= SUPPORTED_Autoneg;
+		advertising |= ADVERTISED_Autoneg;
+		cmd->base.autoneg = AUTONEG_ENABLE;
+	} else {
+		cmd->base.autoneg = AUTONEG_DISABLE;
+	}
+
+	/* Determine the remaining settings based on the PHY type. */
+	switch (adapter->hw.phy.type) {
+	case ixgbe_phy_tn:
+	case ixgbe_phy_aq:
+	case ixgbe_phy_x550em_ext_t:
+	case ixgbe_phy_fw:
+	case ixgbe_phy_cu_unknown:
+		supported |= SUPPORTED_TP;
+		advertising |= ADVERTISED_TP;
+		cmd->base.port = PORT_TP;
+		break;
+	case ixgbe_phy_qt:
+		supported |= SUPPORTED_FIBRE;
+		advertising |= ADVERTISED_FIBRE;
+		cmd->base.port = PORT_FIBRE;
+		break;
+	case ixgbe_phy_nl:
+	case ixgbe_phy_sfp_passive_tyco:
+	case ixgbe_phy_sfp_passive_unknown:
+	case ixgbe_phy_sfp_ftl:
+	case ixgbe_phy_sfp_avago:
+	case ixgbe_phy_sfp_intel:
+	case ixgbe_phy_sfp_unknown:
+	case ixgbe_phy_qsfp_passive_unknown:
+	case ixgbe_phy_qsfp_active_unknown:
+	case ixgbe_phy_qsfp_intel:
+	case ixgbe_phy_qsfp_unknown:
+		switch (adapter->hw.phy.sfp_type) {
+			/* SFP+ devices, further checking needed */
+		case ixgbe_sfp_type_da_cu:
+		case ixgbe_sfp_type_da_cu_core0:
+		case ixgbe_sfp_type_da_cu_core1:
+			supported |= SUPPORTED_FIBRE;
+			advertising |= ADVERTISED_FIBRE;
+			cmd->base.port = PORT_DA;
+			break;
+		case ixgbe_sfp_type_sr:
+		case ixgbe_sfp_type_lr:
+		case ixgbe_sfp_type_srlr_core0:
+		case ixgbe_sfp_type_srlr_core1:
+		case ixgbe_sfp_type_1g_sx_core0:
+		case ixgbe_sfp_type_1g_sx_core1:
+		case ixgbe_sfp_type_1g_lx_core0:
+		case ixgbe_sfp_type_1g_lx_core1:
+			supported |= SUPPORTED_FIBRE;
+			advertising |= ADVERTISED_FIBRE;
+			cmd->base.port = PORT_FIBRE;
+			break;
+		case ixgbe_sfp_type_not_present:
+			supported |= SUPPORTED_FIBRE;
+			advertising |= ADVERTISED_FIBRE;
+			cmd->base.port = PORT_NONE;
+			break;
+		case ixgbe_sfp_type_1g_cu_core0:
+		case ixgbe_sfp_type_1g_cu_core1:
+			supported |= SUPPORTED_TP;
+			advertising |= ADVERTISED_TP;
+			cmd->base.port = PORT_TP;
+			break;
+		case ixgbe_sfp_type_unknown:
+		default:
+			supported |= SUPPORTED_FIBRE;
+			advertising |= ADVERTISED_FIBRE;
+			cmd->base.port = PORT_OTHER;
+			break;
+		}
+		break;
+	case ixgbe_phy_xaui:
+		supported |= SUPPORTED_FIBRE;
+		advertising |= ADVERTISED_FIBRE;
+		cmd->base.port = PORT_NONE;
+		break;
+	case ixgbe_phy_unknown:
+	case ixgbe_phy_generic:
+	case ixgbe_phy_sfp_unsupported:
+	default:
+		supported |= SUPPORTED_FIBRE;
+		advertising |= ADVERTISED_FIBRE;
+		cmd->base.port = PORT_OTHER;
+		break;
+	}
+
+	/* Indicate pause support */
+	supported |= SUPPORTED_Pause;
+
+	switch (hw->fc.requested_mode) {
+	case ixgbe_fc_full:
+		advertising |= ADVERTISED_Pause;
+		break;
+	case ixgbe_fc_rx_pause:
+		advertising |= ADVERTISED_Pause | ADVERTISED_Asym_Pause;
+		break;
+	case ixgbe_fc_tx_pause:
+		advertising |= ADVERTISED_Asym_Pause;
+		break;
+	default:
+		advertising &= ~(ADVERTISED_Pause | ADVERTISED_Asym_Pause);
+	}
+
+	if (netif_carrier_ok(netdev)) {
+		switch (adapter->link_speed) {
+		case IXGBE_LINK_SPEED_10GB_FULL:
+			cmd->base.speed = SPEED_10000;
+			break;
+		case IXGBE_LINK_SPEED_5GB_FULL:
+			cmd->base.speed = SPEED_5000;
+			break;
+#ifdef SUPPORTED_2500baseX_Full
+		case IXGBE_LINK_SPEED_2_5GB_FULL:
+			cmd->base.speed = SPEED_2500;
+			break;
+#endif /* SUPPORTED_2500baseX_Full */
+		case IXGBE_LINK_SPEED_1GB_FULL:
+			cmd->base.speed = SPEED_1000;
+			break;
+		case IXGBE_LINK_SPEED_100_FULL:
+			cmd->base.speed = SPEED_100;
+			break;
+		case IXGBE_LINK_SPEED_10_FULL:
+			cmd->base.speed = SPEED_10;
+			break;
+		default:
+			break;
+		}
+		cmd->base.duplex = DUPLEX_FULL;
+	} else {
+		cmd->base.speed = SPEED_UNKNOWN;
+		cmd->base.duplex = DUPLEX_UNKNOWN;
+	}
+
+	ethtool_convert_legacy_u32_to_link_mode(cmd->link_modes.supported,
+						supported);
+	ethtool_convert_legacy_u32_to_link_mode(cmd->link_modes.advertising,
+						supported);
 
+	return 0;
+}
+#else /* !HAVE_ETHTOOL_CONVERT_U32_AND_LINK_MODE */
 static int ixgbe_get_settings(struct net_device *netdev,
 			      struct ethtool_cmd *ecmd)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	struct ixgbe_hw *hw = &adapter->hw;
 	ixgbe_link_speed supported_link;
-	u32 link_speed = 0;
 	bool autoneg = false;
-	bool link_up;
 
 	hw->mac.ops.get_link_capabilities(hw, &supported_link, &autoneg);
 
 	/* set the supported link speeds */
 	if (supported_link & IXGBE_LINK_SPEED_10GB_FULL)
-		ecmd->supported |= SUPPORTED_10000baseT_Full;
-	if (supported_link & IXGBE_LINK_SPEED_2_5GB_FULL)
-		ecmd->supported |= SUPPORTED_2500baseX_Full;
+		ecmd->supported |= (ixgbe_isbackplane(hw->phy.media_type)) ?
+				    ixgbe_backplane_type(hw) :
+				    SUPPORTED_10000baseT_Full;
 	if (supported_link & IXGBE_LINK_SPEED_1GB_FULL)
-		ecmd->supported |= SUPPORTED_1000baseT_Full;
+		ecmd->supported |= (ixgbe_isbackplane(hw->phy.media_type)) ?
+				    SUPPORTED_1000baseKX_Full :
+				    SUPPORTED_1000baseT_Full;
 	if (supported_link & IXGBE_LINK_SPEED_100_FULL)
 		ecmd->supported |= SUPPORTED_100baseT_Full;
+	if (supported_link & IXGBE_LINK_SPEED_10_FULL)
+		ecmd->supported |= SUPPORTED_10baseT_Full;
+
+	/* default advertised speed if phy.autoneg_advertised isn't set */
+	ecmd->advertising = ecmd->supported;
 
 	/* set the advertised speeds */
 	if (hw->phy.autoneg_advertised) {
+		ecmd->advertising = 0;
+		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_10_FULL)
+			ecmd->advertising |= ADVERTISED_10baseT_Full;
 		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_100_FULL)
 			ecmd->advertising |= ADVERTISED_100baseT_Full;
 		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_10GB_FULL)
-			ecmd->advertising |= ADVERTISED_10000baseT_Full;
-		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_2_5GB_FULL)
-			ecmd->advertising |= ADVERTISED_2500baseX_Full;
-		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_1GB_FULL)
-			ecmd->advertising |= ADVERTISED_1000baseT_Full;
+			ecmd->advertising |= (ecmd->supported & ADVERTISED_MASK_10G);
+		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_1GB_FULL) {
+			if (ecmd->supported & SUPPORTED_1000baseKX_Full)
+				ecmd->advertising |= ADVERTISED_1000baseKX_Full;
+			else
+				ecmd->advertising |= ADVERTISED_1000baseT_Full;
+		}
 	} else {
-		/* default modes in case phy.autoneg_advertised isn't set */
-		if (supported_link & IXGBE_LINK_SPEED_10GB_FULL)
-			ecmd->advertising |= ADVERTISED_10000baseT_Full;
-		if (supported_link & IXGBE_LINK_SPEED_1GB_FULL)
-			ecmd->advertising |= ADVERTISED_1000baseT_Full;
-		if (supported_link & IXGBE_LINK_SPEED_100_FULL)
-			ecmd->advertising |= ADVERTISED_100baseT_Full;
-
 		if (hw->phy.multispeed_fiber && !autoneg) {
 			if (supported_link & IXGBE_LINK_SPEED_10GB_FULL)
 				ecmd->advertising = ADVERTISED_10000baseT_Full;
@@ -202,8 +486,9 @@ static int ixgbe_get_settings(struct net_device *netdev,
 		ecmd->supported |= SUPPORTED_Autoneg;
 		ecmd->advertising |= ADVERTISED_Autoneg;
 		ecmd->autoneg = AUTONEG_ENABLE;
-	} else
+	} else {
 		ecmd->autoneg = AUTONEG_DISABLE;
+	}
 
 	ecmd->transceiver = XCVR_EXTERNAL;
 
@@ -212,6 +497,7 @@ static int ixgbe_get_settings(struct net_device *netdev,
 	case ixgbe_phy_tn:
 	case ixgbe_phy_aq:
 	case ixgbe_phy_x550em_ext_t:
+	case ixgbe_phy_fw:
 	case ixgbe_phy_cu_unknown:
 		ecmd->supported |= SUPPORTED_TP;
 		ecmd->advertising |= ADVERTISED_TP;
@@ -229,8 +515,12 @@ static int ixgbe_get_settings(struct net_device *netdev,
 	case ixgbe_phy_sfp_avago:
 	case ixgbe_phy_sfp_intel:
 	case ixgbe_phy_sfp_unknown:
-		/* SFP+ devices, further checking needed */
+	case ixgbe_phy_qsfp_passive_unknown:
+	case ixgbe_phy_qsfp_active_unknown:
+	case ixgbe_phy_qsfp_intel:
+	case ixgbe_phy_qsfp_unknown:
 		switch (adapter->hw.phy.sfp_type) {
+			/* SFP+ devices, further checking needed */
 		case ixgbe_sfp_type_da_cu:
 		case ixgbe_sfp_type_da_cu_core0:
 		case ixgbe_sfp_type_da_cu_core1:
@@ -284,21 +574,47 @@ static int ixgbe_get_settings(struct net_device *netdev,
 		break;
 	}
 
-	hw->mac.ops.check_link(hw, &link_speed, &link_up, false);
-	if (link_up) {
-		switch (link_speed) {
+	/* Indicate pause support */
+	ecmd->supported |= SUPPORTED_Pause;
+
+	switch (hw->fc.requested_mode) {
+	case ixgbe_fc_full:
+		ecmd->advertising |= ADVERTISED_Pause;
+		break;
+	case ixgbe_fc_rx_pause:
+		ecmd->advertising |= ADVERTISED_Pause |
+				     ADVERTISED_Asym_Pause;
+		break;
+	case ixgbe_fc_tx_pause:
+		ecmd->advertising |= ADVERTISED_Asym_Pause;
+		break;
+	default:
+		ecmd->advertising &= ~(ADVERTISED_Pause |
+				       ADVERTISED_Asym_Pause);
+	}
+
+	if (netif_carrier_ok(netdev)) {
+		switch (adapter->link_speed) {
 		case IXGBE_LINK_SPEED_10GB_FULL:
 			ethtool_cmd_speed_set(ecmd, SPEED_10000);
 			break;
+		case IXGBE_LINK_SPEED_5GB_FULL:
+			ethtool_cmd_speed_set(ecmd, SPEED_5000);
+			break;
+#ifdef SUPPORTED_2500baseX_Full
 		case IXGBE_LINK_SPEED_2_5GB_FULL:
 			ethtool_cmd_speed_set(ecmd, SPEED_2500);
 			break;
+#endif /* SUPPORTED_2500baseX_Full */
 		case IXGBE_LINK_SPEED_1GB_FULL:
 			ethtool_cmd_speed_set(ecmd, SPEED_1000);
 			break;
 		case IXGBE_LINK_SPEED_100_FULL:
 			ethtool_cmd_speed_set(ecmd, SPEED_100);
 			break;
+		case IXGBE_LINK_SPEED_10_FULL:
+			ethtool_cmd_speed_set(ecmd, SPEED_10);
+			break;
 		default:
 			break;
 		}
@@ -310,7 +626,80 @@ static int ixgbe_get_settings(struct net_device *netdev,
 
 	return 0;
 }
+#endif /* !HAVE_ETHTOOL_CONVERT_U32_AND_LINK_MODE */
+
+#ifdef HAVE_ETHTOOL_CONVERT_U32_AND_LINK_MODE
+static int ixgbe_set_link_ksettings(struct net_device *netdev,
+				    const struct ethtool_link_ksettings *cmd)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	struct ixgbe_hw *hw = &adapter->hw;
+	u32 advertised, old;
+	s32 err = 0;
+	u32 supported, advertising;
+
+	ethtool_convert_link_mode_to_legacy_u32(&supported,
+						cmd->link_modes.supported);
+	ethtool_convert_link_mode_to_legacy_u32(&advertising,
+						cmd->link_modes.advertising);
+
+	if ((hw->phy.media_type == ixgbe_media_type_copper) ||
+	    (hw->phy.multispeed_fiber)) {
+		/*
+		 * this function does not support duplex forcing, but can
+		 * limit the advertising of the adapter to the specified speed
+		 */
+		if (advertising & ~supported)
+			return -EINVAL;
+
+		/* only allow one speed at a time if no autoneg */
+		if (!cmd->base.autoneg && hw->phy.multispeed_fiber) {
+			if (advertising ==
+			    (ADVERTISED_10000baseT_Full |
+			     ADVERTISED_1000baseT_Full))
+				return -EINVAL;
+		}
+
+		old = hw->phy.autoneg_advertised;
+		advertised = 0;
+		if (advertising & ADVERTISED_10000baseT_Full)
+			advertised |= IXGBE_LINK_SPEED_10GB_FULL;
+
+		if (advertising & ADVERTISED_1000baseT_Full)
+			advertised |= IXGBE_LINK_SPEED_1GB_FULL;
+
+		if (advertising & ADVERTISED_100baseT_Full)
+			advertised |= IXGBE_LINK_SPEED_100_FULL;
+
+		if (advertising & ADVERTISED_10baseT_Full)
+			advertised |= IXGBE_LINK_SPEED_10_FULL;
+
+		if (old == advertised)
+			return err;
+		/* this sets the link speed and restarts auto-neg */
+		while (test_and_set_bit(__IXGBE_IN_SFP_INIT, &adapter->state))
+			usleep_range(1000, 2000);
+
+		hw->mac.autotry_restart = true;
+		err = hw->mac.ops.setup_link(hw, advertised, true);
+		if (err) {
+			e_info(probe, "setup link failed with code %d\n", err);
+			hw->mac.ops.setup_link(hw, old, true);
+		}
+		clear_bit(__IXGBE_IN_SFP_INIT, &adapter->state);
+	} else {
+		/* in this case we currently only support 10Gb/FULL */
+		u32 speed = cmd->base.speed;
+
+		if ((cmd->base.autoneg == AUTONEG_ENABLE) ||
+		    (advertising != ADVERTISED_10000baseT_Full) ||
+		    (speed + cmd->base.duplex != SPEED_10000 + DUPLEX_FULL))
+			return -EINVAL;
+	}
 
+	return err;
+}
+#else /* !HAVE_ETHTOOL_CONVERT_U32_AND_LINK_MODE */
 static int ixgbe_set_settings(struct net_device *netdev,
 			      struct ethtool_cmd *ecmd)
 {
@@ -347,6 +736,9 @@ static int ixgbe_set_settings(struct net_device *netdev,
 		if (ecmd->advertising & ADVERTISED_100baseT_Full)
 			advertised |= IXGBE_LINK_SPEED_100_FULL;
 
+		if (ecmd->advertising & ADVERTISED_10baseT_Full)
+			advertised |= IXGBE_LINK_SPEED_10_FULL;
+
 		if (old == advertised)
 			return err;
 		/* this sets the link speed and restarts auto-neg */
@@ -360,9 +752,11 @@ static int ixgbe_set_settings(struct net_device *netdev,
 			hw->mac.ops.setup_link(hw, old, true);
 		}
 		clear_bit(__IXGBE_IN_SFP_INIT, &adapter->state);
-	} else {
+	}
+	else {
 		/* in this case we currently only support 10Gb/FULL */
 		u32 speed = ethtool_cmd_speed(ecmd);
+
 		if ((ecmd->autoneg == AUTONEG_ENABLE) ||
 		    (ecmd->advertising != ADVERTISED_10000baseT_Full) ||
 		    (speed + ecmd->duplex != SPEED_10000 + DUPLEX_FULL))
@@ -371,6 +765,7 @@ static int ixgbe_set_settings(struct net_device *netdev,
 
 	return err;
 }
+#endif /* !HAVE_ETHTOOL_CONVERT_U32_AND_LINK_MODE */
 
 static void ixgbe_get_pauseparam(struct net_device *netdev,
 				 struct ethtool_pauseparam *pause)
@@ -406,18 +801,19 @@ static int ixgbe_set_pauseparam(struct net_device *netdev,
 	    (adapter->flags & IXGBE_FLAG_DCB_ENABLED))
 		return -EINVAL;
 
-	/* some devices do not support autoneg of link flow control */
+
+	/* some devices do not support autoneg of flow control */
 	if ((pause->autoneg == AUTONEG_ENABLE) &&
 	    !ixgbe_device_supports_autoneg_fc(hw))
-		return -EINVAL;
+	    return -EINVAL;
 
 	fc.disable_fc_autoneg = (pause->autoneg != AUTONEG_ENABLE);
 
 	if ((pause->rx_pause && pause->tx_pause) || pause->autoneg)
 		fc.requested_mode = ixgbe_fc_full;
-	else if (pause->rx_pause && !pause->tx_pause)
+	else if (pause->rx_pause)
 		fc.requested_mode = ixgbe_fc_rx_pause;
-	else if (!pause->rx_pause && pause->tx_pause)
+	else if (pause->tx_pause)
 		fc.requested_mode = ixgbe_fc_tx_pause;
 	else
 		fc.requested_mode = ixgbe_fc_none;
@@ -446,16 +842,16 @@ static void ixgbe_set_msglevel(struct net_device *netdev, u32 data)
 	adapter->msg_enable = data;
 }
 
-static int ixgbe_get_regs_len(struct net_device *netdev)
+static int ixgbe_get_regs_len(struct net_device __always_unused *netdev)
 {
-#define IXGBE_REGS_LEN  1139
+#define IXGBE_REGS_LEN  1129
 	return IXGBE_REGS_LEN * sizeof(u32);
 }
 
-#define IXGBE_GET_STAT(_A_, _R_) _A_->stats._R_
+#define IXGBE_GET_STAT(_A_, _R_)	(_A_->stats._R_)
 
-static void ixgbe_get_regs(struct net_device *netdev,
-			   struct ethtool_regs *regs, void *p)
+static void ixgbe_get_regs(struct net_device *netdev, struct ethtool_regs *regs,
+			   void *p)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	struct ixgbe_hw *hw = &adapter->hw;
@@ -468,197 +864,166 @@ static void ixgbe_get_regs(struct net_device *netdev,
 			hw->device_id;
 
 	/* General Registers */
-	regs_buff[0] = IXGBE_READ_REG(hw, IXGBE_CTRL);
-	regs_buff[1] = IXGBE_READ_REG(hw, IXGBE_STATUS);
-	regs_buff[2] = IXGBE_READ_REG(hw, IXGBE_CTRL_EXT);
-	regs_buff[3] = IXGBE_READ_REG(hw, IXGBE_ESDP);
-	regs_buff[4] = IXGBE_READ_REG(hw, IXGBE_EODSDP);
-	regs_buff[5] = IXGBE_READ_REG(hw, IXGBE_LEDCTL);
-	regs_buff[6] = IXGBE_READ_REG(hw, IXGBE_FRTIMER);
-	regs_buff[7] = IXGBE_READ_REG(hw, IXGBE_TCPTIMER);
+	regs_buff[0] = IXGBE_R32_Q(hw, IXGBE_CTRL);
+	regs_buff[1] = IXGBE_R32_Q(hw, IXGBE_STATUS);
+	regs_buff[2] = IXGBE_R32_Q(hw, IXGBE_CTRL_EXT);
+	regs_buff[3] = IXGBE_R32_Q(hw, IXGBE_ESDP);
+	regs_buff[4] = IXGBE_R32_Q(hw, IXGBE_EODSDP);
+	regs_buff[5] = IXGBE_R32_Q(hw, IXGBE_LEDCTL);
+	regs_buff[6] = IXGBE_R32_Q(hw, IXGBE_FRTIMER);
+	regs_buff[7] = IXGBE_R32_Q(hw, IXGBE_TCPTIMER);
 
 	/* NVM Register */
-	regs_buff[8] = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
-	regs_buff[9] = IXGBE_READ_REG(hw, IXGBE_EERD);
-	regs_buff[10] = IXGBE_READ_REG(hw, IXGBE_FLA(hw));
-	regs_buff[11] = IXGBE_READ_REG(hw, IXGBE_EEMNGCTL);
-	regs_buff[12] = IXGBE_READ_REG(hw, IXGBE_EEMNGDATA);
-	regs_buff[13] = IXGBE_READ_REG(hw, IXGBE_FLMNGCTL);
-	regs_buff[14] = IXGBE_READ_REG(hw, IXGBE_FLMNGDATA);
-	regs_buff[15] = IXGBE_READ_REG(hw, IXGBE_FLMNGCNT);
-	regs_buff[16] = IXGBE_READ_REG(hw, IXGBE_FLOP);
-	regs_buff[17] = IXGBE_READ_REG(hw, IXGBE_GRC(hw));
+	regs_buff[8] = IXGBE_R32_Q(hw, IXGBE_EEC);
+	regs_buff[9] = IXGBE_R32_Q(hw, IXGBE_EERD);
+	regs_buff[10] = IXGBE_R32_Q(hw, IXGBE_FLA);
+	regs_buff[11] = IXGBE_R32_Q(hw, IXGBE_EEMNGCTL);
+	regs_buff[12] = IXGBE_R32_Q(hw, IXGBE_EEMNGDATA);
+	regs_buff[13] = IXGBE_R32_Q(hw, IXGBE_FLMNGCTL);
+	regs_buff[14] = IXGBE_R32_Q(hw, IXGBE_FLMNGDATA);
+	regs_buff[15] = IXGBE_R32_Q(hw, IXGBE_FLMNGCNT);
+	regs_buff[16] = IXGBE_R32_Q(hw, IXGBE_FLOP);
+	regs_buff[17] = IXGBE_R32_Q(hw, IXGBE_GRC);
 
 	/* Interrupt */
 	/* don't read EICR because it can clear interrupt causes, instead
 	 * read EICS which is a shadow but doesn't clear EICR */
-	regs_buff[18] = IXGBE_READ_REG(hw, IXGBE_EICS);
-	regs_buff[19] = IXGBE_READ_REG(hw, IXGBE_EICS);
-	regs_buff[20] = IXGBE_READ_REG(hw, IXGBE_EIMS);
-	regs_buff[21] = IXGBE_READ_REG(hw, IXGBE_EIMC);
-	regs_buff[22] = IXGBE_READ_REG(hw, IXGBE_EIAC);
-	regs_buff[23] = IXGBE_READ_REG(hw, IXGBE_EIAM);
-	regs_buff[24] = IXGBE_READ_REG(hw, IXGBE_EITR(0));
-	regs_buff[25] = IXGBE_READ_REG(hw, IXGBE_IVAR(0));
-	regs_buff[26] = IXGBE_READ_REG(hw, IXGBE_MSIXT);
-	regs_buff[27] = IXGBE_READ_REG(hw, IXGBE_MSIXPBA);
-	regs_buff[28] = IXGBE_READ_REG(hw, IXGBE_PBACL(0));
-	regs_buff[29] = IXGBE_READ_REG(hw, IXGBE_GPIE);
+	regs_buff[18] = IXGBE_R32_Q(hw, IXGBE_EICS);
+	regs_buff[19] = IXGBE_R32_Q(hw, IXGBE_EICS);
+	regs_buff[20] = IXGBE_R32_Q(hw, IXGBE_EIMS);
+	regs_buff[21] = IXGBE_R32_Q(hw, IXGBE_EIMC);
+	regs_buff[22] = IXGBE_R32_Q(hw, IXGBE_EIAC);
+	regs_buff[23] = IXGBE_R32_Q(hw, IXGBE_EIAM);
+	regs_buff[24] = IXGBE_R32_Q(hw, IXGBE_EITR(0));
+	regs_buff[25] = IXGBE_R32_Q(hw, IXGBE_IVAR(0));
+	regs_buff[26] = IXGBE_R32_Q(hw, IXGBE_MSIXT);
+	regs_buff[27] = IXGBE_R32_Q(hw, IXGBE_MSIXPBA);
+	regs_buff[28] = IXGBE_R32_Q(hw, IXGBE_PBACL(0));
+	regs_buff[29] = IXGBE_R32_Q(hw, IXGBE_GPIE);
 
 	/* Flow Control */
-	regs_buff[30] = IXGBE_READ_REG(hw, IXGBE_PFCTOP);
-	regs_buff[31] = IXGBE_READ_REG(hw, IXGBE_FCTTV(0));
-	regs_buff[32] = IXGBE_READ_REG(hw, IXGBE_FCTTV(1));
-	regs_buff[33] = IXGBE_READ_REG(hw, IXGBE_FCTTV(2));
-	regs_buff[34] = IXGBE_READ_REG(hw, IXGBE_FCTTV(3));
+	regs_buff[30] = IXGBE_R32_Q(hw, IXGBE_PFCTOP);
+	regs_buff[31] = IXGBE_R32_Q(hw, IXGBE_FCTTV(0));
+	regs_buff[32] = IXGBE_R32_Q(hw, IXGBE_FCTTV(1));
+	regs_buff[33] = IXGBE_R32_Q(hw, IXGBE_FCTTV(2));
+	regs_buff[34] = IXGBE_R32_Q(hw, IXGBE_FCTTV(3));
 	for (i = 0; i < 8; i++) {
 		switch (hw->mac.type) {
 		case ixgbe_mac_82598EB:
-			regs_buff[35 + i] = IXGBE_READ_REG(hw, IXGBE_FCRTL(i));
-			regs_buff[43 + i] = IXGBE_READ_REG(hw, IXGBE_FCRTH(i));
+			regs_buff[35 + i] = IXGBE_R32_Q(hw, IXGBE_FCRTL(i));
+			regs_buff[43 + i] = IXGBE_R32_Q(hw, IXGBE_FCRTH(i));
 			break;
 		case ixgbe_mac_82599EB:
 		case ixgbe_mac_X540:
 		case ixgbe_mac_X550:
 		case ixgbe_mac_X550EM_x:
-			regs_buff[35 + i] = IXGBE_READ_REG(hw, IXGBE_FCRTL_82599(i));
-			regs_buff[43 + i] = IXGBE_READ_REG(hw, IXGBE_FCRTH_82599(i));
+			regs_buff[35 + i] = IXGBE_R32_Q(hw,
+							IXGBE_FCRTL_82599(i));
+			regs_buff[43 + i] = IXGBE_R32_Q(hw,
+							IXGBE_FCRTH_82599(i));
 			break;
 		default:
 			break;
 		}
 	}
-	regs_buff[51] = IXGBE_READ_REG(hw, IXGBE_FCRTV);
-	regs_buff[52] = IXGBE_READ_REG(hw, IXGBE_TFCS);
+	regs_buff[51] = IXGBE_R32_Q(hw, IXGBE_FCRTV);
+	regs_buff[52] = IXGBE_R32_Q(hw, IXGBE_TFCS);
 
 	/* Receive DMA */
 	for (i = 0; i < 64; i++)
-		regs_buff[53 + i] = IXGBE_READ_REG(hw, IXGBE_RDBAL(i));
+		regs_buff[53 + i] = IXGBE_R32_Q(hw, IXGBE_RDBAL(i));
 	for (i = 0; i < 64; i++)
-		regs_buff[117 + i] = IXGBE_READ_REG(hw, IXGBE_RDBAH(i));
+		regs_buff[117 + i] = IXGBE_R32_Q(hw, IXGBE_RDBAH(i));
 	for (i = 0; i < 64; i++)
-		regs_buff[181 + i] = IXGBE_READ_REG(hw, IXGBE_RDLEN(i));
+		regs_buff[181 + i] = IXGBE_R32_Q(hw, IXGBE_RDLEN(i));
 	for (i = 0; i < 64; i++)
-		regs_buff[245 + i] = IXGBE_READ_REG(hw, IXGBE_RDH(i));
+		regs_buff[245 + i] = IXGBE_R32_Q(hw, IXGBE_RDH(i));
 	for (i = 0; i < 64; i++)
-		regs_buff[309 + i] = IXGBE_READ_REG(hw, IXGBE_RDT(i));
+		regs_buff[309 + i] = IXGBE_R32_Q(hw, IXGBE_RDT(i));
 	for (i = 0; i < 64; i++)
-		regs_buff[373 + i] = IXGBE_READ_REG(hw, IXGBE_RXDCTL(i));
+		regs_buff[373 + i] = IXGBE_R32_Q(hw, IXGBE_RXDCTL(i));
 	for (i = 0; i < 16; i++)
-		regs_buff[437 + i] = IXGBE_READ_REG(hw, IXGBE_SRRCTL(i));
+		regs_buff[437 + i] = IXGBE_R32_Q(hw, IXGBE_SRRCTL(i));
 	for (i = 0; i < 16; i++)
-		regs_buff[453 + i] = IXGBE_READ_REG(hw, IXGBE_DCA_RXCTRL(i));
-	regs_buff[469] = IXGBE_READ_REG(hw, IXGBE_RDRXCTL);
+		regs_buff[453 + i] = IXGBE_R32_Q(hw, IXGBE_DCA_RXCTRL(i));
+	regs_buff[469] = IXGBE_R32_Q(hw, IXGBE_RDRXCTL);
 	for (i = 0; i < 8; i++)
-		regs_buff[470 + i] = IXGBE_READ_REG(hw, IXGBE_RXPBSIZE(i));
-	regs_buff[478] = IXGBE_READ_REG(hw, IXGBE_RXCTRL);
-	regs_buff[479] = IXGBE_READ_REG(hw, IXGBE_DROPEN);
+		regs_buff[470 + i] = IXGBE_R32_Q(hw, IXGBE_RXPBSIZE(i));
+	regs_buff[478] = IXGBE_R32_Q(hw, IXGBE_RXCTRL);
+	regs_buff[479] = IXGBE_R32_Q(hw, IXGBE_DROPEN);
 
 	/* Receive */
-	regs_buff[480] = IXGBE_READ_REG(hw, IXGBE_RXCSUM);
-	regs_buff[481] = IXGBE_READ_REG(hw, IXGBE_RFCTL);
+	regs_buff[480] = IXGBE_R32_Q(hw, IXGBE_RXCSUM);
+	regs_buff[481] = IXGBE_R32_Q(hw, IXGBE_RFCTL);
 	for (i = 0; i < 16; i++)
-		regs_buff[482 + i] = IXGBE_READ_REG(hw, IXGBE_RAL(i));
+		regs_buff[482 + i] = IXGBE_R32_Q(hw, IXGBE_RAL(i));
 	for (i = 0; i < 16; i++)
-		regs_buff[498 + i] = IXGBE_READ_REG(hw, IXGBE_RAH(i));
-	regs_buff[514] = IXGBE_READ_REG(hw, IXGBE_PSRTYPE(0));
-	regs_buff[515] = IXGBE_READ_REG(hw, IXGBE_FCTRL);
-	regs_buff[516] = IXGBE_READ_REG(hw, IXGBE_VLNCTRL);
-	regs_buff[517] = IXGBE_READ_REG(hw, IXGBE_MCSTCTRL);
-	regs_buff[518] = IXGBE_READ_REG(hw, IXGBE_MRQC);
-	regs_buff[519] = IXGBE_READ_REG(hw, IXGBE_VMD_CTL);
+		regs_buff[498 + i] = IXGBE_R32_Q(hw, IXGBE_RAH(i));
+	regs_buff[514] = IXGBE_R32_Q(hw, IXGBE_PSRTYPE(0));
+	regs_buff[515] = IXGBE_R32_Q(hw, IXGBE_FCTRL);
+	regs_buff[516] = IXGBE_R32_Q(hw, IXGBE_VLNCTRL);
+	regs_buff[517] = IXGBE_R32_Q(hw, IXGBE_MCSTCTRL);
+	regs_buff[518] = IXGBE_R32_Q(hw, IXGBE_MRQC);
+	regs_buff[519] = IXGBE_R32_Q(hw, IXGBE_VMD_CTL);
 	for (i = 0; i < 8; i++)
-		regs_buff[520 + i] = IXGBE_READ_REG(hw, IXGBE_IMIR(i));
+		regs_buff[520 + i] = IXGBE_R32_Q(hw, IXGBE_IMIR(i));
 	for (i = 0; i < 8; i++)
-		regs_buff[528 + i] = IXGBE_READ_REG(hw, IXGBE_IMIREXT(i));
-	regs_buff[536] = IXGBE_READ_REG(hw, IXGBE_IMIRVP);
+		regs_buff[528 + i] = IXGBE_R32_Q(hw, IXGBE_IMIREXT(i));
+	regs_buff[536] = IXGBE_R32_Q(hw, IXGBE_IMIRVP);
 
 	/* Transmit */
 	for (i = 0; i < 32; i++)
-		regs_buff[537 + i] = IXGBE_READ_REG(hw, IXGBE_TDBAL(i));
+		regs_buff[537 + i] = IXGBE_R32_Q(hw, IXGBE_TDBAL(i));
 	for (i = 0; i < 32; i++)
-		regs_buff[569 + i] = IXGBE_READ_REG(hw, IXGBE_TDBAH(i));
+		regs_buff[569 + i] = IXGBE_R32_Q(hw, IXGBE_TDBAH(i));
 	for (i = 0; i < 32; i++)
-		regs_buff[601 + i] = IXGBE_READ_REG(hw, IXGBE_TDLEN(i));
+		regs_buff[601 + i] = IXGBE_R32_Q(hw, IXGBE_TDLEN(i));
 	for (i = 0; i < 32; i++)
-		regs_buff[633 + i] = IXGBE_READ_REG(hw, IXGBE_TDH(i));
+		regs_buff[633 + i] = IXGBE_R32_Q(hw, IXGBE_TDH(i));
 	for (i = 0; i < 32; i++)
-		regs_buff[665 + i] = IXGBE_READ_REG(hw, IXGBE_TDT(i));
+		regs_buff[665 + i] = IXGBE_R32_Q(hw, IXGBE_TDT(i));
 	for (i = 0; i < 32; i++)
-		regs_buff[697 + i] = IXGBE_READ_REG(hw, IXGBE_TXDCTL(i));
+		regs_buff[697 + i] = IXGBE_R32_Q(hw, IXGBE_TXDCTL(i));
 	for (i = 0; i < 32; i++)
-		regs_buff[729 + i] = IXGBE_READ_REG(hw, IXGBE_TDWBAL(i));
+		regs_buff[729 + i] = IXGBE_R32_Q(hw, IXGBE_TDWBAL(i));
 	for (i = 0; i < 32; i++)
-		regs_buff[761 + i] = IXGBE_READ_REG(hw, IXGBE_TDWBAH(i));
-	regs_buff[793] = IXGBE_READ_REG(hw, IXGBE_DTXCTL);
+		regs_buff[761 + i] = IXGBE_R32_Q(hw, IXGBE_TDWBAH(i));
+	regs_buff[793] = IXGBE_R32_Q(hw, IXGBE_DTXCTL);
 	for (i = 0; i < 16; i++)
-		regs_buff[794 + i] = IXGBE_READ_REG(hw, IXGBE_DCA_TXCTRL(i));
-	regs_buff[810] = IXGBE_READ_REG(hw, IXGBE_TIPG);
+		regs_buff[794 + i] = IXGBE_R32_Q(hw, IXGBE_DCA_TXCTRL(i));
+	regs_buff[810] = IXGBE_R32_Q(hw, IXGBE_TIPG);
 	for (i = 0; i < 8; i++)
-		regs_buff[811 + i] = IXGBE_READ_REG(hw, IXGBE_TXPBSIZE(i));
-	regs_buff[819] = IXGBE_READ_REG(hw, IXGBE_MNGTXMAP);
+		regs_buff[811 + i] = IXGBE_R32_Q(hw, IXGBE_TXPBSIZE(i));
+	regs_buff[819] = IXGBE_R32_Q(hw, IXGBE_MNGTXMAP);
 
 	/* Wake Up */
-	regs_buff[820] = IXGBE_READ_REG(hw, IXGBE_WUC);
-	regs_buff[821] = IXGBE_READ_REG(hw, IXGBE_WUFC);
-	regs_buff[822] = IXGBE_READ_REG(hw, IXGBE_WUS);
-	regs_buff[823] = IXGBE_READ_REG(hw, IXGBE_IPAV);
-	regs_buff[824] = IXGBE_READ_REG(hw, IXGBE_IP4AT);
-	regs_buff[825] = IXGBE_READ_REG(hw, IXGBE_IP6AT);
-	regs_buff[826] = IXGBE_READ_REG(hw, IXGBE_WUPL);
-	regs_buff[827] = IXGBE_READ_REG(hw, IXGBE_WUPM);
-	regs_buff[828] = IXGBE_READ_REG(hw, IXGBE_FHFT(0));
+	regs_buff[820] = IXGBE_R32_Q(hw, IXGBE_WUC);
+	regs_buff[821] = IXGBE_R32_Q(hw, IXGBE_WUFC);
+	regs_buff[822] = IXGBE_R32_Q(hw, IXGBE_WUS);
+	regs_buff[823] = IXGBE_R32_Q(hw, IXGBE_IPAV);
+	regs_buff[824] = IXGBE_R32_Q(hw, IXGBE_IP4AT);
+	regs_buff[825] = IXGBE_R32_Q(hw, IXGBE_IP6AT);
+	regs_buff[826] = IXGBE_R32_Q(hw, IXGBE_WUPL);
+	regs_buff[827] = IXGBE_R32_Q(hw, IXGBE_WUPM);
+	regs_buff[828] = IXGBE_R32_Q(hw, IXGBE_FHFT(0));
 
 	/* DCB */
-	regs_buff[829] = IXGBE_READ_REG(hw, IXGBE_RMCS);   /* same as FCCFG  */
-	regs_buff[831] = IXGBE_READ_REG(hw, IXGBE_PDPMCS); /* same as RTTPCS */
-
-	switch (hw->mac.type) {
-	case ixgbe_mac_82598EB:
-		regs_buff[830] = IXGBE_READ_REG(hw, IXGBE_DPMCS);
-		regs_buff[832] = IXGBE_READ_REG(hw, IXGBE_RUPPBMR);
-		for (i = 0; i < 8; i++)
-			regs_buff[833 + i] =
-				IXGBE_READ_REG(hw, IXGBE_RT2CR(i));
-		for (i = 0; i < 8; i++)
-			regs_buff[841 + i] =
-				IXGBE_READ_REG(hw, IXGBE_RT2SR(i));
-		for (i = 0; i < 8; i++)
-			regs_buff[849 + i] =
-				IXGBE_READ_REG(hw, IXGBE_TDTQ2TCCR(i));
-		for (i = 0; i < 8; i++)
-			regs_buff[857 + i] =
-				IXGBE_READ_REG(hw, IXGBE_TDTQ2TCSR(i));
-		break;
-	case ixgbe_mac_82599EB:
-	case ixgbe_mac_X540:
-	case ixgbe_mac_X550:
-	case ixgbe_mac_X550EM_x:
-		regs_buff[830] = IXGBE_READ_REG(hw, IXGBE_RTTDCS);
-		regs_buff[832] = IXGBE_READ_REG(hw, IXGBE_RTRPCS);
-		for (i = 0; i < 8; i++)
-			regs_buff[833 + i] =
-				IXGBE_READ_REG(hw, IXGBE_RTRPT4C(i));
-		for (i = 0; i < 8; i++)
-			regs_buff[841 + i] =
-				IXGBE_READ_REG(hw, IXGBE_RTRPT4S(i));
-		for (i = 0; i < 8; i++)
-			regs_buff[849 + i] =
-				IXGBE_READ_REG(hw, IXGBE_RTTDT2C(i));
-		for (i = 0; i < 8; i++)
-			regs_buff[857 + i] =
-				IXGBE_READ_REG(hw, IXGBE_RTTDT2S(i));
-		break;
-	default:
-		break;
-	}
-
+	regs_buff[829] = IXGBE_R32_Q(hw, IXGBE_RMCS);
+	regs_buff[830] = IXGBE_R32_Q(hw, IXGBE_DPMCS);
+	regs_buff[831] = IXGBE_R32_Q(hw, IXGBE_PDPMCS);
+	regs_buff[832] = IXGBE_R32_Q(hw, IXGBE_RUPPBMR);
+	for (i = 0; i < 8; i++)
+		regs_buff[833 + i] = IXGBE_R32_Q(hw, IXGBE_RT2CR(i));
 	for (i = 0; i < 8; i++)
-		regs_buff[865 + i] =
-		IXGBE_READ_REG(hw, IXGBE_TDPT2TCCR(i)); /* same as RTTPT2C */
+		regs_buff[841 + i] = IXGBE_R32_Q(hw, IXGBE_RT2SR(i));
 	for (i = 0; i < 8; i++)
-		regs_buff[873 + i] =
-		IXGBE_READ_REG(hw, IXGBE_TDPT2TCSR(i)); /* same as RTTPT2S */
+		regs_buff[849 + i] = IXGBE_R32_Q(hw, IXGBE_TDTQ2TCCR(i));
+	for (i = 0; i < 8; i++)
+		regs_buff[857 + i] = IXGBE_R32_Q(hw, IXGBE_TDTQ2TCSR(i));
+	for (i = 0; i < 8; i++)
+		regs_buff[865 + i] = IXGBE_R32_Q(hw, IXGBE_TDPT2TCCR(i));
+	for (i = 0; i < 8; i++)
+		regs_buff[873 + i] = IXGBE_R32_Q(hw, IXGBE_TDPT2TCSR(i));
 
 	/* Statistics */
 	regs_buff[881] = IXGBE_GET_STAT(adapter, crcerrs);
@@ -725,93 +1090,77 @@ static void ixgbe_get_regs(struct net_device *netdev,
 		regs_buff[1022 + i] = IXGBE_GET_STAT(adapter, qbtc[i]);
 
 	/* MAC */
-	regs_buff[1038] = IXGBE_READ_REG(hw, IXGBE_PCS1GCFIG);
-	regs_buff[1039] = IXGBE_READ_REG(hw, IXGBE_PCS1GLCTL);
-	regs_buff[1040] = IXGBE_READ_REG(hw, IXGBE_PCS1GLSTA);
-	regs_buff[1041] = IXGBE_READ_REG(hw, IXGBE_PCS1GDBG0);
-	regs_buff[1042] = IXGBE_READ_REG(hw, IXGBE_PCS1GDBG1);
-	regs_buff[1043] = IXGBE_READ_REG(hw, IXGBE_PCS1GANA);
-	regs_buff[1044] = IXGBE_READ_REG(hw, IXGBE_PCS1GANLP);
-	regs_buff[1045] = IXGBE_READ_REG(hw, IXGBE_PCS1GANNP);
-	regs_buff[1046] = IXGBE_READ_REG(hw, IXGBE_PCS1GANLPNP);
-	regs_buff[1047] = IXGBE_READ_REG(hw, IXGBE_HLREG0);
-	regs_buff[1048] = IXGBE_READ_REG(hw, IXGBE_HLREG1);
-	regs_buff[1049] = IXGBE_READ_REG(hw, IXGBE_PAP);
-	regs_buff[1050] = IXGBE_READ_REG(hw, IXGBE_MACA);
-	regs_buff[1051] = IXGBE_READ_REG(hw, IXGBE_APAE);
-	regs_buff[1052] = IXGBE_READ_REG(hw, IXGBE_ARD);
-	regs_buff[1053] = IXGBE_READ_REG(hw, IXGBE_AIS);
-	regs_buff[1054] = IXGBE_READ_REG(hw, IXGBE_MSCA);
-	regs_buff[1055] = IXGBE_READ_REG(hw, IXGBE_MSRWD);
-	regs_buff[1056] = IXGBE_READ_REG(hw, IXGBE_MLADD);
-	regs_buff[1057] = IXGBE_READ_REG(hw, IXGBE_MHADD);
-	regs_buff[1058] = IXGBE_READ_REG(hw, IXGBE_TREG);
-	regs_buff[1059] = IXGBE_READ_REG(hw, IXGBE_PCSS1);
-	regs_buff[1060] = IXGBE_READ_REG(hw, IXGBE_PCSS2);
-	regs_buff[1061] = IXGBE_READ_REG(hw, IXGBE_XPCSS);
-	regs_buff[1062] = IXGBE_READ_REG(hw, IXGBE_SERDESC);
-	regs_buff[1063] = IXGBE_READ_REG(hw, IXGBE_MACS);
-	regs_buff[1064] = IXGBE_READ_REG(hw, IXGBE_AUTOC);
-	regs_buff[1065] = IXGBE_READ_REG(hw, IXGBE_LINKS);
-	regs_buff[1066] = IXGBE_READ_REG(hw, IXGBE_AUTOC2);
-	regs_buff[1067] = IXGBE_READ_REG(hw, IXGBE_AUTOC3);
-	regs_buff[1068] = IXGBE_READ_REG(hw, IXGBE_ANLP1);
-	regs_buff[1069] = IXGBE_READ_REG(hw, IXGBE_ANLP2);
-	regs_buff[1070] = IXGBE_READ_REG(hw, IXGBE_ATLASCTL);
+	regs_buff[1038] = IXGBE_R32_Q(hw, IXGBE_PCS1GCFIG);
+	regs_buff[1039] = IXGBE_R32_Q(hw, IXGBE_PCS1GLCTL);
+	regs_buff[1040] = IXGBE_R32_Q(hw, IXGBE_PCS1GLSTA);
+	regs_buff[1041] = IXGBE_R32_Q(hw, IXGBE_PCS1GDBG0);
+	regs_buff[1042] = IXGBE_R32_Q(hw, IXGBE_PCS1GDBG1);
+	regs_buff[1043] = IXGBE_R32_Q(hw, IXGBE_PCS1GANA);
+	regs_buff[1044] = IXGBE_R32_Q(hw, IXGBE_PCS1GANLP);
+	regs_buff[1045] = IXGBE_R32_Q(hw, IXGBE_PCS1GANNP);
+	regs_buff[1046] = IXGBE_R32_Q(hw, IXGBE_PCS1GANLPNP);
+	regs_buff[1047] = IXGBE_R32_Q(hw, IXGBE_HLREG0);
+	regs_buff[1048] = IXGBE_R32_Q(hw, IXGBE_HLREG1);
+	regs_buff[1049] = IXGBE_R32_Q(hw, IXGBE_PAP);
+	regs_buff[1050] = IXGBE_R32_Q(hw, IXGBE_MACA);
+	regs_buff[1051] = IXGBE_R32_Q(hw, IXGBE_APAE);
+	regs_buff[1052] = IXGBE_R32_Q(hw, IXGBE_ARD);
+	regs_buff[1053] = IXGBE_R32_Q(hw, IXGBE_AIS);
+	regs_buff[1054] = IXGBE_R32_Q(hw, IXGBE_MSCA);
+	regs_buff[1055] = IXGBE_R32_Q(hw, IXGBE_MSRWD);
+	regs_buff[1056] = IXGBE_R32_Q(hw, IXGBE_MLADD);
+	regs_buff[1057] = IXGBE_R32_Q(hw, IXGBE_MHADD);
+	regs_buff[1058] = IXGBE_R32_Q(hw, IXGBE_TREG);
+	regs_buff[1059] = IXGBE_R32_Q(hw, IXGBE_PCSS1);
+	regs_buff[1060] = IXGBE_R32_Q(hw, IXGBE_PCSS2);
+	regs_buff[1061] = IXGBE_R32_Q(hw, IXGBE_XPCSS);
+	regs_buff[1062] = IXGBE_R32_Q(hw, IXGBE_SERDESC);
+	regs_buff[1063] = IXGBE_R32_Q(hw, IXGBE_MACS);
+	regs_buff[1064] = IXGBE_R32_Q(hw, IXGBE_AUTOC);
+	regs_buff[1065] = IXGBE_R32_Q(hw, IXGBE_LINKS);
+	regs_buff[1066] = IXGBE_R32_Q(hw, IXGBE_AUTOC2);
+	regs_buff[1067] = IXGBE_R32_Q(hw, IXGBE_AUTOC3);
+	regs_buff[1068] = IXGBE_R32_Q(hw, IXGBE_ANLP1);
+	regs_buff[1069] = IXGBE_R32_Q(hw, IXGBE_ANLP2);
+	regs_buff[1070] = IXGBE_R32_Q(hw, IXGBE_ATLASCTL);
 
 	/* Diagnostic */
-	regs_buff[1071] = IXGBE_READ_REG(hw, IXGBE_RDSTATCTL);
+	regs_buff[1071] = IXGBE_R32_Q(hw, IXGBE_RDSTATCTL);
 	for (i = 0; i < 8; i++)
-		regs_buff[1072 + i] = IXGBE_READ_REG(hw, IXGBE_RDSTAT(i));
-	regs_buff[1080] = IXGBE_READ_REG(hw, IXGBE_RDHMPN);
+		regs_buff[1072 + i] = IXGBE_R32_Q(hw, IXGBE_RDSTAT(i));
+	regs_buff[1080] = IXGBE_R32_Q(hw, IXGBE_RDHMPN);
 	for (i = 0; i < 4; i++)
-		regs_buff[1081 + i] = IXGBE_READ_REG(hw, IXGBE_RIC_DW(i));
-	regs_buff[1085] = IXGBE_READ_REG(hw, IXGBE_RDPROBE);
-	regs_buff[1086] = IXGBE_READ_REG(hw, IXGBE_TDSTATCTL);
-	for (i = 0; i < 8; i++)
-		regs_buff[1087 + i] = IXGBE_READ_REG(hw, IXGBE_TDSTAT(i));
-	regs_buff[1095] = IXGBE_READ_REG(hw, IXGBE_TDHMPN);
+		regs_buff[1081 + i] = IXGBE_R32_Q(hw, IXGBE_RIC_DW(i));
+	regs_buff[1085] = IXGBE_R32_Q(hw, IXGBE_RDPROBE);
+	regs_buff[1095] = IXGBE_R32_Q(hw, IXGBE_TDHMPN);
 	for (i = 0; i < 4; i++)
-		regs_buff[1096 + i] = IXGBE_READ_REG(hw, IXGBE_TIC_DW(i));
-	regs_buff[1100] = IXGBE_READ_REG(hw, IXGBE_TDPROBE);
-	regs_buff[1101] = IXGBE_READ_REG(hw, IXGBE_TXBUFCTRL);
-	regs_buff[1102] = IXGBE_READ_REG(hw, IXGBE_TXBUFDATA0);
-	regs_buff[1103] = IXGBE_READ_REG(hw, IXGBE_TXBUFDATA1);
-	regs_buff[1104] = IXGBE_READ_REG(hw, IXGBE_TXBUFDATA2);
-	regs_buff[1105] = IXGBE_READ_REG(hw, IXGBE_TXBUFDATA3);
-	regs_buff[1106] = IXGBE_READ_REG(hw, IXGBE_RXBUFCTRL);
-	regs_buff[1107] = IXGBE_READ_REG(hw, IXGBE_RXBUFDATA0);
-	regs_buff[1108] = IXGBE_READ_REG(hw, IXGBE_RXBUFDATA1);
-	regs_buff[1109] = IXGBE_READ_REG(hw, IXGBE_RXBUFDATA2);
-	regs_buff[1110] = IXGBE_READ_REG(hw, IXGBE_RXBUFDATA3);
+		regs_buff[1096 + i] = IXGBE_R32_Q(hw, IXGBE_TIC_DW(i));
+	regs_buff[1100] = IXGBE_R32_Q(hw, IXGBE_TDPROBE);
+	regs_buff[1101] = IXGBE_R32_Q(hw, IXGBE_TXBUFCTRL);
+	regs_buff[1102] = IXGBE_R32_Q(hw, IXGBE_TXBUFDATA0);
+	regs_buff[1103] = IXGBE_R32_Q(hw, IXGBE_TXBUFDATA1);
+	regs_buff[1104] = IXGBE_R32_Q(hw, IXGBE_TXBUFDATA2);
+	regs_buff[1105] = IXGBE_R32_Q(hw, IXGBE_TXBUFDATA3);
+	regs_buff[1106] = IXGBE_R32_Q(hw, IXGBE_RXBUFCTRL);
+	regs_buff[1107] = IXGBE_R32_Q(hw, IXGBE_RXBUFDATA0);
+	regs_buff[1108] = IXGBE_R32_Q(hw, IXGBE_RXBUFDATA1);
+	regs_buff[1109] = IXGBE_R32_Q(hw, IXGBE_RXBUFDATA2);
+	regs_buff[1110] = IXGBE_R32_Q(hw, IXGBE_RXBUFDATA3);
 	for (i = 0; i < 8; i++)
-		regs_buff[1111 + i] = IXGBE_READ_REG(hw, IXGBE_PCIE_DIAG(i));
-	regs_buff[1119] = IXGBE_READ_REG(hw, IXGBE_RFVAL);
-	regs_buff[1120] = IXGBE_READ_REG(hw, IXGBE_MDFTC1);
-	regs_buff[1121] = IXGBE_READ_REG(hw, IXGBE_MDFTC2);
-	regs_buff[1122] = IXGBE_READ_REG(hw, IXGBE_MDFTFIFO1);
-	regs_buff[1123] = IXGBE_READ_REG(hw, IXGBE_MDFTFIFO2);
-	regs_buff[1124] = IXGBE_READ_REG(hw, IXGBE_MDFTS);
-	regs_buff[1125] = IXGBE_READ_REG(hw, IXGBE_PCIEECCCTL);
-	regs_buff[1126] = IXGBE_READ_REG(hw, IXGBE_PBTXECC);
-	regs_buff[1127] = IXGBE_READ_REG(hw, IXGBE_PBRXECC);
+		regs_buff[1111 + i] = IXGBE_R32_Q(hw, IXGBE_PCIE_DIAG(i));
+	regs_buff[1119] = IXGBE_R32_Q(hw, IXGBE_RFVAL);
+	regs_buff[1120] = IXGBE_R32_Q(hw, IXGBE_MDFTC1);
+	regs_buff[1121] = IXGBE_R32_Q(hw, IXGBE_MDFTC2);
+	regs_buff[1122] = IXGBE_R32_Q(hw, IXGBE_MDFTFIFO1);
+	regs_buff[1123] = IXGBE_R32_Q(hw, IXGBE_MDFTFIFO2);
+	regs_buff[1124] = IXGBE_R32_Q(hw, IXGBE_MDFTS);
+	regs_buff[1125] = IXGBE_R32_Q(hw, IXGBE_PCIEECCCTL);
+	regs_buff[1126] = IXGBE_R32_Q(hw, IXGBE_PBTXECC);
+	regs_buff[1127] = IXGBE_R32_Q(hw, IXGBE_PBRXECC);
 
 	/* 82599 X540 specific registers  */
-	regs_buff[1128] = IXGBE_READ_REG(hw, IXGBE_MFLCN);
+	regs_buff[1128] = IXGBE_R32_Q(hw, IXGBE_MFLCN);
 
-	/* 82599 X540 specific DCB registers  */
-	regs_buff[1129] = IXGBE_READ_REG(hw, IXGBE_RTRUP2TC);
-	regs_buff[1130] = IXGBE_READ_REG(hw, IXGBE_RTTUP2TC);
-	for (i = 0; i < 4; i++)
-		regs_buff[1131 + i] = IXGBE_READ_REG(hw, IXGBE_TXLLQ(i));
-	regs_buff[1135] = IXGBE_READ_REG(hw, IXGBE_RTTBCNRM);
-					/* same as RTTQCNRM */
-	regs_buff[1136] = IXGBE_READ_REG(hw, IXGBE_RTTBCNRD);
-					/* same as RTTQCNRR */
-
-	/* X540 specific DCB registers  */
-	regs_buff[1137] = IXGBE_READ_REG(hw, IXGBE_RTTQCNCR);
-	regs_buff[1138] = IXGBE_READ_REG(hw, IXGBE_RTTQCNTG);
 }
 
 static int ixgbe_get_eeprom_len(struct net_device *netdev)
@@ -844,7 +1193,7 @@ static int ixgbe_get_eeprom(struct net_device *netdev,
 		return -ENOMEM;
 
 	ret_val = hw->eeprom.ops.read_buffer(hw, first_word, eeprom_len,
-					     eeprom_buff);
+					   eeprom_buff);
 
 	/* Device's eeprom is always little-endian, word addressable */
 	for (i = 0; i < eeprom_len; i++)
@@ -861,10 +1210,9 @@ static int ixgbe_set_eeprom(struct net_device *netdev,
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	struct ixgbe_hw *hw = &adapter->hw;
-	u16 *eeprom_buff;
-	void *ptr;
 	int max_len, first_word, last_word, ret_val = 0;
-	u16 i;
+	u16 *eeprom_buff, i;
+	void *ptr;
 
 	if (eeprom->len == 0)
 		return -EINVAL;
@@ -893,7 +1241,7 @@ static int ixgbe_set_eeprom(struct net_device *netdev,
 
 		ptr++;
 	}
-	if ((eeprom->offset + eeprom->len) & 1) {
+	if (((eeprom->offset + eeprom->len) & 1) && (ret_val == 0)) {
 		/*
 		 * need read/modify/write of last changed EEPROM word
 		 * only the first byte of the word is being modified
@@ -914,8 +1262,8 @@ static int ixgbe_set_eeprom(struct net_device *netdev,
 		cpu_to_le16s(&eeprom_buff[i]);
 
 	ret_val = hw->eeprom.ops.write_buffer(hw, first_word,
-					      last_word - first_word + 1,
-					      eeprom_buff);
+					    last_word - first_word + 1,
+					    eeprom_buff);
 
 	/* Update the checksum */
 	if (ret_val == 0)
@@ -930,32 +1278,35 @@ static void ixgbe_get_drvinfo(struct net_device *netdev,
 			      struct ethtool_drvinfo *drvinfo)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	u32 nvm_track_id;
 
-	strlcpy(drvinfo->driver, ixgbe_driver_name, sizeof(drvinfo->driver));
-	strlcpy(drvinfo->version, ixgbe_driver_version,
-		sizeof(drvinfo->version));
+	strncpy(drvinfo->driver, ixgbe_driver_name,
+		sizeof(drvinfo->driver) - 1);
+	strncpy(drvinfo->version, ixgbe_driver_version,
+		sizeof(drvinfo->version) - 1);
 
-	nvm_track_id = (adapter->eeprom_verh << 16) |
-			adapter->eeprom_verl;
-	snprintf(drvinfo->fw_version, sizeof(drvinfo->fw_version), "0x%08x",
-		 nvm_track_id);
+	strncpy(drvinfo->fw_version, adapter->eeprom_id,
+		sizeof(drvinfo->fw_version) - 1);
+	strncpy(drvinfo->bus_info, pci_name(adapter->pdev),
+		sizeof(drvinfo->bus_info) - 1);
+#ifdef HAVE_ETHTOOL_GET_SSET_COUNT
 
-	strlcpy(drvinfo->bus_info, pci_name(adapter->pdev),
-		sizeof(drvinfo->bus_info));
+	drvinfo->n_priv_flags = IXGBE_PRIV_FLAGS_STR_LEN;
+#endif
 }
 
 static void ixgbe_get_ringparam(struct net_device *netdev,
 				struct ethtool_ringparam *ring)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	struct ixgbe_ring *tx_ring = adapter->tx_ring[0];
-	struct ixgbe_ring *rx_ring = adapter->rx_ring[0];
 
 	ring->rx_max_pending = IXGBE_MAX_RXD;
 	ring->tx_max_pending = IXGBE_MAX_TXD;
-	ring->rx_pending = rx_ring->count;
-	ring->tx_pending = tx_ring->count;
+	ring->rx_mini_max_pending = 0;
+	ring->rx_jumbo_max_pending = 0;
+	ring->rx_pending = adapter->rx_ring_count;
+	ring->tx_pending = adapter->tx_ring_count;
+	ring->rx_mini_pending = 0;
+	ring->rx_jumbo_pending = 0;
 }
 
 static int ixgbe_set_ringparam(struct net_device *netdev,
@@ -1054,9 +1405,9 @@ static int ixgbe_set_ringparam(struct net_device *netdev,
 				}
 				goto err_setup;
 			}
-
 		}
 
+
 		for (i = 0; i < adapter->num_rx_queues; i++) {
 			ixgbe_free_rx_resources(adapter->rx_ring[i]);
 
@@ -1075,69 +1426,86 @@ clear_reset:
 	return err;
 }
 
+#ifndef HAVE_ETHTOOL_GET_SSET_COUNT
+static int ixgbe_get_stats_count(struct net_device *netdev)
+{
+	return IXGBE_STATS_LEN;
+}
+
+#else /* HAVE_ETHTOOL_GET_SSET_COUNT */
 static int ixgbe_get_sset_count(struct net_device *netdev, int sset)
 {
+#ifdef HAVE_TX_MQ
+#ifndef HAVE_NETDEV_SELECT_QUEUE
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+#endif
+#endif
+
 	switch (sset) {
 	case ETH_SS_TEST:
 		return IXGBE_TEST_LEN;
 	case ETH_SS_STATS:
 		return IXGBE_STATS_LEN;
+	case ETH_SS_PRIV_FLAGS:
+		return IXGBE_PRIV_FLAGS_STR_LEN;
 	default:
 		return -EOPNOTSUPP;
 	}
 }
 
+#endif /* HAVE_ETHTOOL_GET_SSET_COUNT */
 static void ixgbe_get_ethtool_stats(struct net_device *netdev,
-				    struct ethtool_stats *stats, u64 *data)
+				    struct ethtool_stats __always_unused *stats, u64 *data)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	struct rtnl_link_stats64 temp;
-	const struct rtnl_link_stats64 *net_stats;
+#ifdef HAVE_NETDEV_STATS_IN_NETDEV
+	struct net_device_stats *net_stats = &netdev->stats;
+#else
+	struct net_device_stats *net_stats = &adapter->net_stats;
+#endif
+	u64 *queue_stat;
+	int stat_count, k;
+#ifdef HAVE_NDO_GET_STATS64
 	unsigned int start;
+#endif
 	struct ixgbe_ring *ring;
 	int i, j;
-	char *p = NULL;
+	char *p;
 
 	ixgbe_update_stats(adapter);
-	net_stats = dev_get_stats(netdev, &temp);
-	for (i = 0; i < IXGBE_GLOBAL_STATS_LEN; i++) {
-		switch (ixgbe_gstrings_stats[i].type) {
-		case NETDEV_STATS:
-			p = (char *) net_stats +
-					ixgbe_gstrings_stats[i].stat_offset;
-			break;
-		case IXGBE_STATS:
-			p = (char *) adapter +
-					ixgbe_gstrings_stats[i].stat_offset;
-			break;
-		default:
-			data[i] = 0;
-			continue;
-		}
 
-		data[i] = (ixgbe_gstrings_stats[i].sizeof_stat ==
+	for (i = 0; i < IXGBE_NETDEV_STATS_LEN; i++) {
+		p = (char *)net_stats + ixgbe_gstrings_net_stats[i].stat_offset;
+		data[i] = (ixgbe_gstrings_net_stats[i].sizeof_stat ==
+			sizeof(u64)) ? *(u64 *)p : *(u32 *)p;
+	}
+	for (j = 0; j < IXGBE_GLOBAL_STATS_LEN; j++, i++) {
+		p = (char *)adapter + ixgbe_gstrings_stats[j].stat_offset;
+		data[i] = (ixgbe_gstrings_stats[j].sizeof_stat ==
 			   sizeof(u64)) ? *(u64 *)p : *(u32 *)p;
 	}
-	for (j = 0; j < netdev->num_tx_queues; j++) {
+	for (j = 0; j < IXGBE_NUM_TX_QUEUES; j++) {
 		ring = adapter->tx_ring[j];
 		if (!ring) {
-			data[i] = 0;
-			data[i+1] = 0;
-			i += 2;
+			data[i++] = 0;
+			data[i++] = 0;
 #ifdef BP_EXTENDED_STATS
-			data[i] = 0;
-			data[i+1] = 0;
-			data[i+2] = 0;
-			i += 3;
+			data[i++] = 0;
+			data[i++] = 0;
+			data[i++] = 0;
 #endif
 			continue;
 		}
 
+#ifdef HAVE_NDO_GET_STATS64
 		do {
 			start = u64_stats_fetch_begin_irq(&ring->syncp);
+#endif
 			data[i]   = ring->stats.packets;
 			data[i+1] = ring->stats.bytes;
+#ifdef HAVE_NDO_GET_STATS64
 		} while (u64_stats_fetch_retry_irq(&ring->syncp, start));
+#endif
 		i += 2;
 #ifdef BP_EXTENDED_STATS
 		data[i] = ring->stats.yields;
@@ -1149,23 +1517,25 @@ static void ixgbe_get_ethtool_stats(struct net_device *netdev,
 	for (j = 0; j < IXGBE_NUM_RX_QUEUES; j++) {
 		ring = adapter->rx_ring[j];
 		if (!ring) {
-			data[i] = 0;
-			data[i+1] = 0;
-			i += 2;
+			data[i++] = 0;
+			data[i++] = 0;
 #ifdef BP_EXTENDED_STATS
-			data[i] = 0;
-			data[i+1] = 0;
-			data[i+2] = 0;
-			i += 3;
+			data[i++] = 0;
+			data[i++] = 0;
+			data[i++] = 0;
 #endif
 			continue;
 		}
 
+#ifdef HAVE_NDO_GET_STATS64
 		do {
 			start = u64_stats_fetch_begin_irq(&ring->syncp);
+#endif
 			data[i]   = ring->stats.packets;
 			data[i+1] = ring->stats.bytes;
+#ifdef HAVE_NDO_GET_STATS64
 		} while (u64_stats_fetch_retry_irq(&ring->syncp, start));
+#endif
 		i += 2;
 #ifdef BP_EXTENDED_STATS
 		data[i] = ring->stats.yields;
@@ -1174,7 +1544,6 @@ static void ixgbe_get_ethtool_stats(struct net_device *netdev,
 		i += 3;
 #endif
 	}
-
 	for (j = 0; j < IXGBE_MAX_PACKET_BUFFERS; j++) {
 		data[i++] = adapter->stats.pxontxc[j];
 		data[i++] = adapter->stats.pxofftxc[j];
@@ -1183,28 +1552,42 @@ static void ixgbe_get_ethtool_stats(struct net_device *netdev,
 		data[i++] = adapter->stats.pxonrxc[j];
 		data[i++] = adapter->stats.pxoffrxc[j];
 	}
+	stat_count = sizeof(struct vf_stats) / sizeof(u64);
+	for (j = 0; j < adapter->num_vfs; j++) {
+		queue_stat = (u64 *)&adapter->vfinfo[j].vfstats;
+		for (k = 0; k < stat_count; k++)
+			data[i + k] = queue_stat[k];
+		queue_stat = (u64 *)&adapter->vfinfo[j].saved_rst_vfstats;
+		for (k = 0; k < stat_count; k++)
+			data[i + k] += queue_stat[k];
+		i += k;
+	}
 }
 
 static void ixgbe_get_strings(struct net_device *netdev, u32 stringset,
 			      u8 *data)
 {
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	char *p = (char *)data;
-	int i;
+	unsigned int i;
 
 	switch (stringset) {
 	case ETH_SS_TEST:
-		for (i = 0; i < IXGBE_TEST_LEN; i++) {
-			memcpy(data, ixgbe_gstrings_test[i], ETH_GSTRING_LEN);
-			data += ETH_GSTRING_LEN;
-		}
+		memcpy(data, *ixgbe_gstrings_test,
+		       IXGBE_TEST_LEN * ETH_GSTRING_LEN);
 		break;
 	case ETH_SS_STATS:
+		for (i = 0; i < IXGBE_NETDEV_STATS_LEN; i++) {
+			memcpy(p, ixgbe_gstrings_net_stats[i].stat_string,
+			       ETH_GSTRING_LEN);
+			p += ETH_GSTRING_LEN;
+		}
 		for (i = 0; i < IXGBE_GLOBAL_STATS_LEN; i++) {
 			memcpy(p, ixgbe_gstrings_stats[i].stat_string,
 			       ETH_GSTRING_LEN);
 			p += ETH_GSTRING_LEN;
 		}
-		for (i = 0; i < netdev->num_tx_queues; i++) {
+		for (i = 0; i < IXGBE_NUM_TX_QUEUES; i++) {
 			sprintf(p, "tx_queue_%u_packets", i);
 			p += ETH_GSTRING_LEN;
 			sprintf(p, "tx_queue_%u_bytes", i);
@@ -1244,8 +1627,26 @@ static void ixgbe_get_strings(struct net_device *netdev, u32 stringset,
 			sprintf(p, "rx_pb_%u_pxoff", i);
 			p += ETH_GSTRING_LEN;
 		}
+		for (i = 0; i < adapter->num_vfs; i++) {
+			sprintf(p, "VF %u Rx Packets", i);
+			p += ETH_GSTRING_LEN;
+			sprintf(p, "VF %u Rx Bytes", i);
+			p += ETH_GSTRING_LEN;
+			sprintf(p, "VF %u Tx Packets", i);
+			p += ETH_GSTRING_LEN;
+			sprintf(p, "VF %u Tx Bytes", i);
+			p += ETH_GSTRING_LEN;
+			sprintf(p, "VF %u MC Packets", i);
+			p += ETH_GSTRING_LEN;
+		}
 		/* BUG_ON(p - data != IXGBE_STATS_LEN * ETH_GSTRING_LEN); */
 		break;
+#ifdef HAVE_ETHTOOL_GET_SSET_COUNT
+	case ETH_SS_PRIV_FLAGS:
+		memcpy(data, ixgbe_priv_flags_strings,
+		       IXGBE_PRIV_FLAGS_STR_LEN * ETH_GSTRING_LEN);
+		break;
+#endif /* HAVE_ETHTOOL_GET_SSET_COUNT */
 	}
 }
 
@@ -1255,13 +1656,12 @@ static int ixgbe_link_test(struct ixgbe_adapter *adapter, u64 *data)
 	bool link_up;
 	u32 link_speed = 0;
 
-	if (ixgbe_removed(hw->hw_addr)) {
+	if (IXGBE_REMOVED(hw->hw_addr)) {
 		*data = 1;
 		return 1;
 	}
 	*data = 0;
-
-	hw->mac.ops.check_link(hw, &link_speed, &link_up, true);
+       hw->mac.ops.check_link(hw, &link_speed, &link_up, true);
 	if (link_up)
 		return *data;
 	else
@@ -1296,7 +1696,7 @@ struct ixgbe_reg_test {
 #define TABLE64_TEST_HI	6
 
 /* default 82599 register test */
-static const struct ixgbe_reg_test reg_test_82599[] = {
+static struct ixgbe_reg_test reg_test_82599[] = {
 	{ IXGBE_FCRTL_82599(0), 1, PATTERN_TEST, 0x8007FFF0, 0x8007FFF0 },
 	{ IXGBE_FCRTH_82599(0), 1, PATTERN_TEST, 0x8007FFF0, 0x8007FFF0 },
 	{ IXGBE_PFCTOP, 1, PATTERN_TEST, 0xFFFFFFFF, 0xFFFFFFFF },
@@ -1320,7 +1720,7 @@ static const struct ixgbe_reg_test reg_test_82599[] = {
 };
 
 /* default 82598 register test */
-static const struct ixgbe_reg_test reg_test_82598[] = {
+static struct ixgbe_reg_test reg_test_82598[] = {
 	{ IXGBE_FCRTL(0), 1, PATTERN_TEST, 0x8007FFF0, 0x8007FFF0 },
 	{ IXGBE_FCRTH(0), 1, PATTERN_TEST, 0x8007FFF0, 0x8007FFF0 },
 	{ IXGBE_PFCTOP, 1, PATTERN_TEST, 0xFFFFFFFF, 0xFFFFFFFF },
@@ -1347,29 +1747,32 @@ static const struct ixgbe_reg_test reg_test_82598[] = {
 	{ .reg = 0 }
 };
 
+
 static bool reg_pattern_test(struct ixgbe_adapter *adapter, u64 *data, int reg,
 			     u32 mask, u32 write)
 {
 	u32 pat, val, before;
 	static const u32 test_pattern[] = {
-		0x5A5A5A5A, 0xA5A5A5A5, 0x00000000, 0xFFFFFFFF};
+		0x5A5A5A5A, 0xA5A5A5A5, 0x00000000, 0xFFFFFFFF
+	};
 
-	if (ixgbe_removed(adapter->hw.hw_addr)) {
+	if (IXGBE_REMOVED(adapter->hw.hw_addr)) {
 		*data = 1;
 		return true;
 	}
 	for (pat = 0; pat < ARRAY_SIZE(test_pattern); pat++) {
-		before = ixgbe_read_reg(&adapter->hw, reg);
-		ixgbe_write_reg(&adapter->hw, reg, test_pattern[pat] & write);
-		val = ixgbe_read_reg(&adapter->hw, reg);
+		before = IXGBE_READ_REG(&adapter->hw, reg);
+		IXGBE_WRITE_REG(&adapter->hw, reg, test_pattern[pat] & write);
+		val = IXGBE_READ_REG(&adapter->hw, reg);
 		if (val != (test_pattern[pat] & write & mask)) {
-			e_err(drv, "pattern test reg %04X failed: got 0x%08X expected 0x%08X\n",
-			      reg, val, (test_pattern[pat] & write & mask));
+			e_err(drv,
+			      "pattern test reg %04X failed: got 0x%08X expected 0x%08X\n",
+			      reg, val, test_pattern[pat] & write & mask);
 			*data = reg;
-			ixgbe_write_reg(&adapter->hw, reg, before);
+			IXGBE_WRITE_REG(&adapter->hw, reg, before);
 			return true;
 		}
-		ixgbe_write_reg(&adapter->hw, reg, before);
+		IXGBE_WRITE_REG(&adapter->hw, reg, before);
 	}
 	return false;
 }
@@ -1379,36 +1782,38 @@ static bool reg_set_and_check(struct ixgbe_adapter *adapter, u64 *data, int reg,
 {
 	u32 val, before;
 
-	if (ixgbe_removed(adapter->hw.hw_addr)) {
+	if (IXGBE_REMOVED(adapter->hw.hw_addr)) {
 		*data = 1;
 		return true;
 	}
-	before = ixgbe_read_reg(&adapter->hw, reg);
-	ixgbe_write_reg(&adapter->hw, reg, write & mask);
-	val = ixgbe_read_reg(&adapter->hw, reg);
+	before = IXGBE_READ_REG(&adapter->hw, reg);
+	IXGBE_WRITE_REG(&adapter->hw, reg, write & mask);
+	val = IXGBE_READ_REG(&adapter->hw, reg);
 	if ((write & mask) != (val & mask)) {
-		e_err(drv, "set/check reg %04X test failed: got 0x%08X expected 0x%08X\n",
+		e_err(drv,
+		      "set/check reg %04X test failed: got 0x%08X expected 0x%08X\n",
 		      reg, (val & mask), (write & mask));
 		*data = reg;
-		ixgbe_write_reg(&adapter->hw, reg, before);
+		IXGBE_WRITE_REG(&adapter->hw, reg, before);
 		return true;
 	}
-	ixgbe_write_reg(&adapter->hw, reg, before);
+	IXGBE_WRITE_REG(&adapter->hw, reg, before);
 	return false;
 }
 
-static int ixgbe_reg_test(struct ixgbe_adapter *adapter, u64 *data)
+static bool ixgbe_reg_test(struct ixgbe_adapter *adapter, u64 *data)
 {
-	const struct ixgbe_reg_test *test;
+	struct ixgbe_reg_test *test;
+	struct ixgbe_hw *hw = &adapter->hw;
 	u32 value, before, after;
 	u32 i, toggle;
 
-	if (ixgbe_removed(adapter->hw.hw_addr)) {
+	if (IXGBE_REMOVED(hw->hw_addr)) {
 		e_err(drv, "Adapter removed - register test blocked\n");
 		*data = 1;
-		return 1;
+		return true;
 	}
-	switch (adapter->hw.mac.type) {
+	switch (hw->mac.type) {
 	case ixgbe_mac_82598EB:
 		toggle = 0x7FFFF3FF;
 		test = reg_test_82598;
@@ -1417,12 +1822,13 @@ static int ixgbe_reg_test(struct ixgbe_adapter *adapter, u64 *data)
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		toggle = 0x7FFFF30F;
 		test = reg_test_82599;
 		break;
 	default:
 		*data = 1;
-		return 1;
+		return true;
 	}
 
 	/*
@@ -1431,18 +1837,19 @@ static int ixgbe_reg_test(struct ixgbe_adapter *adapter, u64 *data)
 	 * tests.  Some bits are read-only, some toggle, and some
 	 * are writeable on newer MACs.
 	 */
-	before = ixgbe_read_reg(&adapter->hw, IXGBE_STATUS);
-	value = (ixgbe_read_reg(&adapter->hw, IXGBE_STATUS) & toggle);
-	ixgbe_write_reg(&adapter->hw, IXGBE_STATUS, toggle);
-	after = ixgbe_read_reg(&adapter->hw, IXGBE_STATUS) & toggle;
+	before = IXGBE_READ_REG(hw, IXGBE_STATUS);
+	value = IXGBE_READ_REG(hw, IXGBE_STATUS) & toggle;
+	IXGBE_WRITE_REG(hw, IXGBE_STATUS, toggle);
+	after = IXGBE_READ_REG(hw, IXGBE_STATUS) & toggle;
 	if (value != after) {
-		e_err(drv, "failed STATUS register test got: 0x%08X expected: 0x%08X\n",
+		e_err(drv,
+		      "failed STATUS register test got: 0x%08X expected: 0x%08X\n",
 		      after, value);
 		*data = 1;
-		return 1;
+		return true;
 	}
 	/* restore previous status */
-	ixgbe_write_reg(&adapter->hw, IXGBE_STATUS, before);
+	IXGBE_WRITE_REG(hw, IXGBE_STATUS, before);
 
 	/*
 	 * Perform the remainder of the register test, looping through
@@ -1455,61 +1862,63 @@ static int ixgbe_reg_test(struct ixgbe_adapter *adapter, u64 *data)
 			switch (test->test_type) {
 			case PATTERN_TEST:
 				b = reg_pattern_test(adapter, data,
-						     test->reg + (i * 0x40),
-						     test->mask,
-						     test->write);
-				break;
-			case SET_READ_TEST:
-				b = reg_set_and_check(adapter, data,
 						      test->reg + (i * 0x40),
 						      test->mask,
 						      test->write);
 				break;
+			case SET_READ_TEST:
+				b = reg_set_and_check(adapter, data,
+						       test->reg + (i * 0x40),
+						       test->mask,
+						       test->write);
+				break;
 			case WRITE_NO_TEST:
-				ixgbe_write_reg(&adapter->hw,
-						test->reg + (i * 0x40),
+				IXGBE_WRITE_REG(hw, test->reg + (i * 0x40),
 						test->write);
 				break;
 			case TABLE32_TEST:
 				b = reg_pattern_test(adapter, data,
-						     test->reg + (i * 4),
-						     test->mask,
-						     test->write);
+						      test->reg + (i * 4),
+						      test->mask,
+						      test->write);
 				break;
 			case TABLE64_TEST_LO:
 				b = reg_pattern_test(adapter, data,
-						     test->reg + (i * 8),
-						     test->mask,
-						     test->write);
+						      test->reg + (i * 8),
+						      test->mask,
+						      test->write);
 				break;
 			case TABLE64_TEST_HI:
 				b = reg_pattern_test(adapter, data,
-						     (test->reg + 4) + (i * 8),
-						     test->mask,
-						     test->write);
+						      (test->reg + 4) + (i * 8),
+						      test->mask,
+						      test->write);
 				break;
 			}
 			if (b)
-				return 1;
+				return true;
 		}
 		test++;
 	}
 
 	*data = 0;
-	return 0;
+	return false;
 }
 
-static int ixgbe_eeprom_test(struct ixgbe_adapter *adapter, u64 *data)
+static bool ixgbe_eeprom_test(struct ixgbe_adapter *adapter, u64 *data)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
-	if (hw->eeprom.ops.validate_checksum(hw, NULL))
+
+	if (hw->eeprom.ops.validate_checksum(hw, NULL)) {
 		*data = 1;
-	else
+		return true;
+	} else {
 		*data = 0;
-	return *data;
+		return false;
+	}
 }
 
-static irqreturn_t ixgbe_test_intr(int irq, void *data)
+static irqreturn_t ixgbe_test_intr(int __always_unused irq, void *data)
 {
 	struct net_device *netdev = (struct net_device *) data;
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
@@ -1525,6 +1934,10 @@ static int ixgbe_intr_test(struct ixgbe_adapter *adapter, u64 *data)
 	u32 mask, i = 0, shared_int = true;
 	u32 irq = adapter->pdev->irq;
 
+	if (IXGBE_REMOVED(adapter->hw.hw_addr)) {
+		*data = 1;
+		return -1;
+	}
 	*data = 0;
 
 	/* Hook up test interrupt handler just for this test */
@@ -1533,21 +1946,21 @@ static int ixgbe_intr_test(struct ixgbe_adapter *adapter, u64 *data)
 		return 0;
 	} else if (adapter->flags & IXGBE_FLAG_MSI_ENABLED) {
 		shared_int = false;
-		if (request_irq(irq, ixgbe_test_intr, 0, netdev->name,
+		if (request_irq(irq, &ixgbe_test_intr, 0, netdev->name,
 				netdev)) {
 			*data = 1;
 			return -1;
 		}
-	} else if (!request_irq(irq, ixgbe_test_intr, IRQF_PROBE_SHARED,
+	} else if (!request_irq(irq, &ixgbe_test_intr, IRQF_PROBE_SHARED,
 				netdev->name, netdev)) {
 		shared_int = false;
-	} else if (request_irq(irq, ixgbe_test_intr, IRQF_SHARED,
+	} else if (request_irq(irq, &ixgbe_test_intr, IRQF_SHARED,
 			       netdev->name, netdev)) {
 		*data = 1;
 		return -1;
 	}
-	e_info(hw, "testing %s interrupt\n", shared_int ?
-	       "shared" : "unshared");
+	e_info(hw, "testing %s interrupt\n",
+	       (shared_int ? "shared" : "unshared"));
 
 	/* Disable all the interrupts */
 	IXGBE_WRITE_REG(&adapter->hw, IXGBE_EIMC, 0xFFFFFFFF);
@@ -1642,19 +2055,18 @@ static void ixgbe_free_desc_rings(struct ixgbe_adapter *adapter)
 	/* shut down the DMA engines now so they can be reinitialized later */
 
 	/* first Rx */
-	hw->mac.ops.disable_rx(hw);
+	ixgbe_disable_rx(hw);
 	ixgbe_disable_rx_queue(adapter, rx_ring);
 
 	/* now Tx */
-	reg_ctl = IXGBE_READ_REG(hw, IXGBE_TXDCTL(tx_ring->reg_idx));
-	reg_ctl &= ~IXGBE_TXDCTL_ENABLE;
-	IXGBE_WRITE_REG(hw, IXGBE_TXDCTL(tx_ring->reg_idx), reg_ctl);
+	IXGBE_WRITE_REG(hw, IXGBE_TXDCTL(tx_ring->reg_idx), 0);
 
 	switch (hw->mac.type) {
 	case ixgbe_mac_82599EB:
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		reg_ctl = IXGBE_READ_REG(hw, IXGBE_DMATXCTL);
 		reg_ctl &= ~IXGBE_DMATXCTL_TE;
 		IXGBE_WRITE_REG(hw, IXGBE_DMATXCTL, reg_ctl);
@@ -1673,7 +2085,6 @@ static int ixgbe_setup_desc_rings(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_ring *tx_ring = &adapter->test_tx_ring;
 	struct ixgbe_ring *rx_ring = &adapter->test_rx_ring;
-	struct ixgbe_hw *hw = &adapter->hw;
 	u32 rctl, reg_data;
 	int ret_val;
 	int err;
@@ -1681,7 +2092,7 @@ static int ixgbe_setup_desc_rings(struct ixgbe_adapter *adapter)
 	/* Setup Tx descriptor ring and Tx buffers */
 	tx_ring->count = IXGBE_DEFAULT_TXD;
 	tx_ring->queue_index = 0;
-	tx_ring->dev = &adapter->pdev->dev;
+	tx_ring->dev = pci_dev_to_dev(adapter->pdev);
 	tx_ring->netdev = adapter->netdev;
 	tx_ring->reg_idx = adapter->tx_ring[0]->reg_idx;
 
@@ -1694,6 +2105,7 @@ static int ixgbe_setup_desc_rings(struct ixgbe_adapter *adapter)
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		reg_data = IXGBE_READ_REG(&adapter->hw, IXGBE_DMATXCTL);
 		reg_data |= IXGBE_DMATXCTL_TE;
 		IXGBE_WRITE_REG(&adapter->hw, IXGBE_DMATXCTL, reg_data);
@@ -1707,9 +2119,12 @@ static int ixgbe_setup_desc_rings(struct ixgbe_adapter *adapter)
 	/* Setup Rx Descriptor ring and Rx buffers */
 	rx_ring->count = IXGBE_DEFAULT_RXD;
 	rx_ring->queue_index = 0;
-	rx_ring->dev = &adapter->pdev->dev;
+	rx_ring->dev = pci_dev_to_dev(adapter->pdev);
 	rx_ring->netdev = adapter->netdev;
 	rx_ring->reg_idx = adapter->rx_ring[0]->reg_idx;
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	rx_ring->rx_buf_len = IXGBE_RXBUFFER_2K;
+#endif
 
 	err = ixgbe_setup_rx_resources(rx_ring);
 	if (err) {
@@ -1717,15 +2132,14 @@ static int ixgbe_setup_desc_rings(struct ixgbe_adapter *adapter)
 		goto err_nomem;
 	}
 
-	hw->mac.ops.disable_rx(hw);
+	ixgbe_disable_rx(&adapter->hw);
 
 	ixgbe_configure_rx_ring(adapter, rx_ring);
 
-	rctl = IXGBE_READ_REG(&adapter->hw, IXGBE_RXCTRL);
+	rctl = IXGBE_READ_REG(&adapter->hw, IXGBE_RXCTRL); 
 	rctl |= IXGBE_RXCTRL_DMBYPS;
 	IXGBE_WRITE_REG(&adapter->hw, IXGBE_RXCTRL, rctl);
-
-	hw->mac.ops.enable_rx(hw);
+	ixgbe_enable_rx(&adapter->hw);
 
 	return 0;
 
@@ -1749,11 +2163,12 @@ static int ixgbe_setup_loopback_test(struct ixgbe_adapter *adapter)
 	reg_data |= IXGBE_FCTRL_BAM | IXGBE_FCTRL_SBP | IXGBE_FCTRL_MPE;
 	IXGBE_WRITE_REG(hw, IXGBE_FCTRL, reg_data);
 
-	/* X540 and X550 needs to set the MACC.FLU bit to force link up */
+	/* X540 needs to set the MACC.FLU bit to force link up */
 	switch (adapter->hw.mac.type) {
-	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+	case ixgbe_mac_X540:
 		reg_data = IXGBE_READ_REG(hw, IXGBE_MACC);
 		reg_data |= IXGBE_MACC_FLU;
 		IXGBE_WRITE_REG(hw, IXGBE_MACC, reg_data);
@@ -1820,15 +2235,21 @@ static bool ixgbe_check_lbtest_frame(struct ixgbe_rx_buffer *rx_buffer,
 
 	frame_size >>= 1;
 
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	data = rx_buffer->skb->data;
+#else
 	data = kmap(rx_buffer->page) + rx_buffer->page_offset;
+#endif
 
 	if (data[3] != 0xFF ||
 	    data[frame_size + 10] != 0xBE ||
 	    data[frame_size + 12] != 0xAF)
 		match = false;
 
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
 	kunmap(rx_buffer->page);
 
+#endif
 	return match;
 }
 
@@ -1837,8 +2258,11 @@ static u16 ixgbe_clean_test_rings(struct ixgbe_ring *rx_ring,
 				  unsigned int size)
 {
 	union ixgbe_adv_rx_desc *rx_desc;
-	struct ixgbe_rx_buffer *rx_buffer;
-	struct ixgbe_tx_buffer *tx_buffer;
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	const int bufsz = rx_ring->rx_buf_len;
+#else
+	const int bufsz = ixgbe_rx_bufsz(rx_ring);
+#endif
 	u16 rx_ntc, tx_ntc, count = 0;
 
 	/* initialize next to clean and descriptor values */
@@ -1846,44 +2270,68 @@ static u16 ixgbe_clean_test_rings(struct ixgbe_ring *rx_ring,
 	tx_ntc = tx_ring->next_to_clean;
 	rx_desc = IXGBE_RX_DESC(rx_ring, rx_ntc);
 
-	while (ixgbe_test_staterr(rx_desc, IXGBE_RXD_STAT_DD)) {
+	while (tx_ntc != tx_ring->next_to_use) {
+		union ixgbe_adv_tx_desc *tx_desc;
+		struct ixgbe_tx_buffer *tx_buffer;
+
+		tx_desc = IXGBE_TX_DESC(tx_ring, tx_ntc);
+
+		/* if DD is not set transmit has not completed */
+		if (!(tx_desc->wb.status & cpu_to_le32(IXGBE_TXD_STAT_DD)))
+			return count;
+
+		/* unmap buffer on Tx side */
+		tx_buffer = &tx_ring->tx_buffer_info[tx_ntc];
+
+		/* Free all the Tx ring sk_buffs */
+		dev_kfree_skb_any(tx_buffer->skb);
+
+		/* unmap skb header data */
+		dma_unmap_single(tx_ring->dev,
+				 dma_unmap_addr(tx_buffer, dma),
+				 dma_unmap_len(tx_buffer, len),
+				 DMA_TO_DEVICE);
+		dma_unmap_len_set(tx_buffer, len, 0);
+
+		/* increment Tx next to clean counter */
+		tx_ntc++;
+		if (tx_ntc == tx_ring->count)
+			tx_ntc = 0;
+	}
+
+	while (rx_desc->wb.upper.length) {
+		struct ixgbe_rx_buffer *rx_buffer;
+
 		/* check Rx buffer */
 		rx_buffer = &rx_ring->rx_buffer_info[rx_ntc];
 
 		/* sync Rx buffer for CPU read */
 		dma_sync_single_for_cpu(rx_ring->dev,
 					rx_buffer->dma,
-					ixgbe_rx_bufsz(rx_ring),
+					bufsz,
 					DMA_FROM_DEVICE);
 
 		/* verify contents of skb */
 		if (ixgbe_check_lbtest_frame(rx_buffer, size))
 			count++;
+		else
+			break;
 
 		/* sync Rx buffer for device write */
 		dma_sync_single_for_device(rx_ring->dev,
 					   rx_buffer->dma,
-					   ixgbe_rx_bufsz(rx_ring),
+					   bufsz,
 					   DMA_FROM_DEVICE);
 
-		/* unmap buffer on Tx side */
-		tx_buffer = &tx_ring->tx_buffer_info[tx_ntc];
-		ixgbe_unmap_and_free_tx_resource(tx_ring, tx_buffer);
-
-		/* increment Rx/Tx next to clean counters */
+		/* increment Rx next to clean counter */
 		rx_ntc++;
 		if (rx_ntc == rx_ring->count)
 			rx_ntc = 0;
-		tx_ntc++;
-		if (tx_ntc == tx_ring->count)
-			tx_ntc = 0;
 
 		/* fetch next descriptor */
 		rx_desc = IXGBE_RX_DESC(rx_ring, rx_ntc);
 	}
 
-	netdev_tx_reset_queue(txring_txq(tx_ring));
-
 	/* re-map buffers to ring, store next to clean values */
 	ixgbe_alloc_rx_buffers(rx_ring, count);
 	rx_ring->next_to_clean = rx_ntc;
@@ -1896,7 +2344,7 @@ static int ixgbe_run_loopback_test(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_ring *tx_ring = &adapter->test_tx_ring;
 	struct ixgbe_ring *rx_ring = &adapter->test_rx_ring;
-	int i, j, lc, good_cnt, ret_val = 0;
+	int i, j, lc, ret_val = 0;
 	unsigned int size = 1024;
 	netdev_tx_t tx_ret_val;
 	struct sk_buff *skb;
@@ -1926,6 +2374,8 @@ static int ixgbe_run_loopback_test(struct ixgbe_adapter *adapter)
 		lc = ((rx_ring->count / 64) * 2) + 1;
 
 	for (j = 0; j <= lc; j++) {
+		unsigned int good_cnt;
+
 		/* reset count of good packets */
 		good_cnt = 0;
 
@@ -1978,13 +2428,21 @@ out:
 	return *data;
 }
 
+#ifndef HAVE_ETHTOOL_GET_SSET_COUNT
+static int ixgbe_diag_test_count(struct net_device __always_unused *netdev)
+{
+	return IXGBE_TEST_LEN;
+}
+
+#endif /* HAVE_ETHTOOL_GET_SSET_COUNT */
 static void ixgbe_diag_test(struct net_device *netdev,
 			    struct ethtool_test *eth_test, u64 *data)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	bool if_running = netif_running(netdev);
+	struct ixgbe_hw *hw = &adapter->hw;
 
-	if (ixgbe_removed(adapter->hw.hw_addr)) {
+	if (IXGBE_REMOVED(hw->hw_addr)) {
 		e_err(hw, "Adapter removed - test blocked\n");
 		data[0] = 1;
 		data[1] = 1;
@@ -1996,13 +2454,14 @@ static void ixgbe_diag_test(struct net_device *netdev,
 	}
 	set_bit(__IXGBE_TESTING, &adapter->state);
 	if (eth_test->flags == ETH_TEST_FL_OFFLINE) {
-		struct ixgbe_hw *hw = &adapter->hw;
-
 		if (adapter->flags & IXGBE_FLAG_SRIOV_ENABLED) {
 			int i;
 			for (i = 0; i < adapter->num_vfs; i++) {
 				if (adapter->vfinfo[i].clear_to_send) {
-					netdev_warn(netdev, "offline diagnostic is not supported when VFs are present\n");
+					e_warn(drv, "Please take active VFS "
+					       "offline and restart the "
+					       "adapter before running NIC "
+					       "diagnostics\n");
 					data[0] = 1;
 					data[1] = 1;
 					data[2] = 1;
@@ -2020,8 +2479,7 @@ static void ixgbe_diag_test(struct net_device *netdev,
 		e_info(hw, "offline testing starting\n");
 
 		/* Link test performed before hardware reset so autoneg doesn't
-		 * interfere with test result
-		 */
+		 * interfere with test result */
 		if (ixgbe_link_test(adapter, &data[4]))
 			eth_test->flags |= ETH_TEST_FL_FAILED;
 
@@ -2049,7 +2507,7 @@ static void ixgbe_diag_test(struct net_device *netdev,
 		 * loopback diagnostic. */
 		if (adapter->flags & (IXGBE_FLAG_SRIOV_ENABLED |
 				      IXGBE_FLAG_VMDQ_ENABLED)) {
-			e_info(hw, "Skip MAC loopback diagnostic in VT mode\n");
+			e_info(hw, "skip MAC loopback diagnostic in VT mode\n");
 			data[3] = 0;
 			goto skip_loopback;
 		}
@@ -2114,7 +2572,7 @@ static void ixgbe_get_wol(struct net_device *netdev,
 	wol->wolopts = 0;
 
 	if (ixgbe_wol_exclusion(adapter, wol) ||
-	    !device_can_wakeup(&adapter->pdev->dev))
+	    !device_can_wakeup(pci_dev_to_dev(adapter->pdev)))
 		return;
 
 	if (adapter->wol & IXGBE_WUFC_EX)
@@ -2130,6 +2588,7 @@ static void ixgbe_get_wol(struct net_device *netdev,
 static int ixgbe_set_wol(struct net_device *netdev, struct ethtool_wolinfo *wol)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	struct ixgbe_hw *hw = &adapter->hw;
 
 	if (wol->wolopts & (WAKE_PHY | WAKE_ARP | WAKE_MAGICSECURE))
 		return -EOPNOTSUPP;
@@ -2148,7 +2607,9 @@ static int ixgbe_set_wol(struct net_device *netdev, struct ethtool_wolinfo *wol)
 	if (wol->wolopts & WAKE_MAGIC)
 		adapter->wol |= IXGBE_WUFC_MAG;
 
-	device_set_wakeup_enable(&adapter->pdev->dev, adapter->wol);
+	hw->wol_enabled = !!(adapter->wol);
+
+	device_set_wakeup_enable(pci_dev_to_dev(adapter->pdev), adapter->wol);
 
 	return 0;
 }
@@ -2163,23 +2624,29 @@ static int ixgbe_nway_reset(struct net_device *netdev)
 	return 0;
 }
 
+#ifdef HAVE_ETHTOOL_SET_PHYS_ID
 static int ixgbe_set_phys_id(struct net_device *netdev,
 			     enum ethtool_phys_id_state state)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	struct ixgbe_hw *hw = &adapter->hw;
 
+	if (!hw->mac.ops.led_on || !hw->mac.ops.led_off)
+		return -EOPNOTSUPP;
+
 	switch (state) {
 	case ETHTOOL_ID_ACTIVE:
 		adapter->led_reg = IXGBE_READ_REG(hw, IXGBE_LEDCTL);
 		return 2;
 
 	case ETHTOOL_ID_ON:
-		hw->mac.ops.led_on(hw, IXGBE_LED_ON);
+		if (hw->mac.ops.led_on(hw, hw->mac.led_link_act))
+			return -EINVAL;
 		break;
 
 	case ETHTOOL_ID_OFF:
-		hw->mac.ops.led_off(hw, IXGBE_LED_ON);
+		if (hw->mac.ops.led_off(hw, hw->mac.led_link_act))
+			return -EINVAL;
 		break;
 
 	case ETHTOOL_ID_INACTIVE:
@@ -2190,12 +2657,42 @@ static int ixgbe_set_phys_id(struct net_device *netdev,
 
 	return 0;
 }
+#else
+static int ixgbe_phys_id(struct net_device *netdev, u32 data)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	struct ixgbe_hw *hw = &adapter->hw;
+	u32 led_reg = IXGBE_READ_REG(hw, IXGBE_LEDCTL);
+	u32 i;
+
+	if (!hw->mac.ops.led_on || !hw->mac.ops.led_off)
+		return -EOPNOTSUPP;
+
+	if (!data || data > 300)
+		data = 300;
+
+	for (i = 0; i < (data * 1000); i += 400) {
+		if (hw->mac.ops.led_on(hw, hw->mac.led_link_act))
+			return -EINVAL;
+		msleep_interruptible(200);
+		if (hw->mac.ops.led_off(hw, hw->mac.led_link_act))
+			return -EINVAL;
+		msleep_interruptible(200);
+	}
+
+	/* Restore LED settings */
+	IXGBE_WRITE_REG(hw, IXGBE_LEDCTL, led_reg);
+
+	return IXGBE_SUCCESS;
+}
+#endif /* HAVE_ETHTOOL_SET_PHYS_ID */
 
 static int ixgbe_get_coalesce(struct net_device *netdev,
 			      struct ethtool_coalesce *ec)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 
+	ec->tx_max_coalesced_frames_irq = adapter->tx_work_limit;
 	/* only valid if in constant ITR mode */
 	if (adapter->rx_itr_setting <= 1)
 		ec->rx_coalesce_usecs = adapter->rx_itr_setting;
@@ -2233,7 +2730,8 @@ static bool ixgbe_update_rsc(struct ixgbe_adapter *adapter)
 	    adapter->rx_itr_setting > IXGBE_MIN_RSC_ITR) {
 		if (!(adapter->flags2 & IXGBE_FLAG2_RSC_ENABLED)) {
 			adapter->flags2 |= IXGBE_FLAG2_RSC_ENABLED;
-			e_info(probe, "rx-usecs value high enough to re-enable RSC\n");
+			e_info(probe, "rx-usecs value high enough "
+				      "to re-enable RSC\n");
 			return true;
 		}
 	/* if interrupt rate is too high then disable RSC */
@@ -2249,9 +2747,9 @@ static int ixgbe_set_coalesce(struct net_device *netdev,
 			      struct ethtool_coalesce *ec)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	struct ixgbe_q_vector *q_vector;
 	int i;
-	u16 tx_itr_param, rx_itr_param, tx_itr_prev;
+	u16 tx_itr_param, rx_itr_param;
+	u16  tx_itr_prev;
 	bool need_reset = false;
 
 	if (adapter->q_vector[0]->tx.count && adapter->q_vector[0]->rx.count) {
@@ -2263,6 +2761,9 @@ static int ixgbe_set_coalesce(struct net_device *netdev,
 		tx_itr_prev = adapter->tx_itr_setting;
 	}
 
+	if (ec->tx_max_coalesced_frames_irq)
+		adapter->tx_work_limit = ec->tx_max_coalesced_frames_irq;
+
 	if ((ec->rx_coalesce_usecs > (IXGBE_MAX_EITR >> 2)) ||
 	    (ec->tx_coalesce_usecs > (IXGBE_MAX_EITR >> 2)))
 		return -EINVAL;
@@ -2306,8 +2807,19 @@ static int ixgbe_set_coalesce(struct net_device *netdev,
 	/* check the old value and enable RSC if necessary */
 	need_reset |= ixgbe_update_rsc(adapter);
 
+	if (adapter->hw.mac.dmac_config.watchdog_timer &&
+	    (!adapter->rx_itr_setting && !adapter->tx_itr_setting)) {
+		e_info(probe,
+		       "Disabling DMA coalescing because interrupt throttling is disabled\n");
+		adapter->hw.mac.dmac_config.watchdog_timer = 0;
+		ixgbe_dmac_config(&adapter->hw);
+	}
+
 	for (i = 0; i < adapter->num_q_vectors; i++) {
-		q_vector = adapter->q_vector[i];
+		struct ixgbe_q_vector *q_vector = adapter->q_vector[i];
+
+		q_vector->tx.work_limit = adapter->tx_work_limit;
+		q_vector->rx.work_limit = adapter->rx_work_limit;
 		if (q_vector->tx.count && !q_vector->rx.count)
 			/* tx only */
 			q_vector->itr = tx_itr_param;
@@ -2328,6 +2840,253 @@ static int ixgbe_set_coalesce(struct net_device *netdev,
 	return 0;
 }
 
+#ifndef HAVE_NDO_SET_FEATURES
+static u32 ixgbe_get_rx_csum(struct net_device *netdev)
+{
+	return !!(netdev->features & NETIF_F_RXCSUM);
+}
+
+static int ixgbe_set_rx_csum(struct net_device *netdev, u32 data)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	bool need_reset = false;
+
+	if (data)
+		netdev->features |= NETIF_F_RXCSUM;
+	else
+		netdev->features &= ~NETIF_F_RXCSUM;
+
+	/* LRO and RSC both depend on RX checksum to function */
+	if (!data && (netdev->features & NETIF_F_LRO)) {
+		netdev->features &= ~NETIF_F_LRO;
+
+		if (adapter->flags2 & IXGBE_FLAG2_RSC_ENABLED) {
+			adapter->flags2 &= ~IXGBE_FLAG2_RSC_ENABLED;
+			need_reset = true;
+		}
+	}
+
+#ifdef HAVE_VXLAN_RX_OFFLOAD
+	if (adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE && data) {
+		netdev->hw_enc_features |= NETIF_F_RXCSUM |
+					   NETIF_F_IP_CSUM |
+					   NETIF_F_IPV6_CSUM;
+		if (!need_reset)
+			adapter->flags2 |= IXGBE_FLAG2_VXLAN_REREG_NEEDED;
+	} else {
+		netdev->hw_enc_features &= ~(NETIF_F_RXCSUM |
+					     NETIF_F_IP_CSUM |
+					     NETIF_F_IPV6_CSUM);
+		ixgbe_clear_udp_tunnel_port(adapter,
+					    IXGBE_VXLANCTRL_ALL_UDPPORT_MASK);
+	}
+#endif /* HAVE_VXLAN_RX_OFFLOAD */
+
+	if (need_reset)
+		ixgbe_do_reset(netdev);
+
+	return 0;
+}
+
+static int ixgbe_set_tx_csum(struct net_device *netdev, u32 data)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+#ifdef NETIF_F_IPV6_CSUM
+	u32 feature_list = NETIF_F_IP_CSUM | NETIF_F_IPV6_CSUM;
+#else
+	u32 feature_list = NETIF_F_IP_CSUM;
+#endif
+
+	switch (adapter->hw.mac.type) {
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+#ifdef HAVE_ENCAP_TSO_OFFLOAD
+		if (data)
+			netdev->hw_enc_features |= NETIF_F_GSO_UDP_TUNNEL;
+		else
+			netdev->hw_enc_features &= ~NETIF_F_GSO_UDP_TUNNEL;
+		feature_list |= NETIF_F_GSO_UDP_TUNNEL;
+#endif /* HAVE_ENCAP_TSO_OFFLOAD */
+		feature_list |= NETIF_F_SCTP_CSUM;
+		break;
+	default:
+		break;
+	}
+
+	if (data)
+		netdev->features |= feature_list;
+	else
+		netdev->features &= ~feature_list;
+
+	return 0;
+}
+
+#ifdef NETIF_F_TSO
+static int ixgbe_set_tso(struct net_device *netdev, u32 data)
+{
+#ifdef NETIF_F_TSO6
+	u32 feature_list = NETIF_F_TSO | NETIF_F_TSO6;
+#else
+	u32 feature_list = NETIF_F_TSO;
+#endif
+
+	if (data)
+		netdev->features |= feature_list;
+	else
+		netdev->features &= ~feature_list;
+
+#ifndef HAVE_NETDEV_VLAN_FEATURES
+	if (!data) {
+		struct ixgbe_adapter *adapter = netdev_priv(netdev);
+		struct net_device *v_netdev;
+		int i;
+
+		/* disable TSO on all VLANs if they're present */
+		if (!adapter->vlgrp)
+			goto tso_out;
+
+		for (i = 0; i < VLAN_GROUP_ARRAY_LEN; i++) {
+			v_netdev = vlan_group_get_device(adapter->vlgrp, i);
+			if (!v_netdev)
+				continue;
+
+			v_netdev->features &= ~feature_list;
+			vlan_group_set_device(adapter->vlgrp, i, v_netdev);
+		}
+	}
+
+tso_out:
+
+#endif /* HAVE_NETDEV_VLAN_FEATURES */
+	return 0;
+}
+
+#endif /* NETIF_F_TSO */
+#ifdef ETHTOOL_GFLAGS
+static int ixgbe_set_flags(struct net_device *netdev, u32 data)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	u32 supported_flags = ETH_FLAG_RXVLAN | ETH_FLAG_TXVLAN;
+	u32 changed = netdev->features ^ data;
+	bool need_reset = false;
+	int rc;
+
+#ifndef HAVE_VLAN_RX_REGISTER
+	if ((adapter->flags & IXGBE_FLAG_DCB_ENABLED) &&
+	    !(data & ETH_FLAG_RXVLAN))
+		return -EINVAL;
+
+#endif
+	if (adapter->flags2 & IXGBE_FLAG2_RSC_CAPABLE)
+		supported_flags |= ETH_FLAG_LRO;
+
+#ifdef ETHTOOL_GRXRINGS
+	switch (adapter->hw.mac.type) {
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_82599EB:
+		supported_flags |= ETH_FLAG_NTUPLE;
+	default:
+		break;
+	}
+
+#endif
+#ifdef NETIF_F_RXHASH
+	supported_flags |= ETH_FLAG_RXHASH;
+
+#endif
+	rc = ethtool_op_set_flags(netdev, data, supported_flags);
+	if (rc)
+		return rc;
+
+#ifndef HAVE_VLAN_RX_REGISTER
+	if (changed & ETH_FLAG_RXVLAN)
+		ixgbe_vlan_mode(netdev, netdev->features);
+#endif
+
+#ifdef HAVE_VXLAN_RX_OFFLOAD
+	if (adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE &&
+	    netdev->features & NETIF_F_RXCSUM) {
+		vxlan_get_rx_port(netdev);
+	else
+		ixgbe_clear_udp_tunnel_port(adapter,
+					    IXGBE_VXLANCTRL_ALL_UDPPORT_MASK);
+	}
+#endif /* HAVE_VXLAN_RX_OFFLOAD */
+
+	/* if state changes we need to update adapter->flags and reset */
+	if (!(netdev->features & NETIF_F_LRO)) {
+		if (adapter->flags2 & IXGBE_FLAG2_RSC_ENABLED)
+			need_reset = true;
+		adapter->flags2 &= ~IXGBE_FLAG2_RSC_ENABLED;
+	} else if ((adapter->flags2 & IXGBE_FLAG2_RSC_CAPABLE) &&
+		   !(adapter->flags2 & IXGBE_FLAG2_RSC_ENABLED)) {
+		if (adapter->rx_itr_setting == 1 ||
+		    adapter->rx_itr_setting > IXGBE_MIN_RSC_ITR) {
+			adapter->flags2 |= IXGBE_FLAG2_RSC_ENABLED;
+			need_reset = true;
+		} else if (changed & ETH_FLAG_LRO) {
+			e_info(probe, "rx-usecs set too low, "
+			       "disabling RSC\n");
+		}
+	}
+
+#ifdef ETHTOOL_GRXRINGS
+	/*
+	 * Check if Flow Director n-tuple support was enabled or disabled.  If
+	 * the state changed, we need to reset.
+	 */
+	switch (netdev->features & NETIF_F_NTUPLE) {
+	case NETIF_F_NTUPLE:
+		/* turn off ATR, enable perfect filters and reset */
+		if (!(adapter->flags & IXGBE_FLAG_FDIR_PERFECT_CAPABLE))
+			need_reset = true;
+
+		adapter->flags &= ~IXGBE_FLAG_FDIR_HASH_CAPABLE;
+		adapter->flags |= IXGBE_FLAG_FDIR_PERFECT_CAPABLE;
+		break;
+	default:
+		/* turn off perfect filters, enable ATR and reset */
+		if (adapter->flags & IXGBE_FLAG_FDIR_PERFECT_CAPABLE)
+			need_reset = true;
+
+		adapter->flags &= ~IXGBE_FLAG_FDIR_PERFECT_CAPABLE;
+
+		/* We cannot enable ATR if VMDq is enabled */
+		if (adapter->flags & IXGBE_FLAG_VMDQ_ENABLED)
+			break;
+
+		/* We cannot enable ATR if we have 2 or more traffic classes */
+		if (netdev_get_num_tc(netdev) > 1)
+			break;
+
+		/* We cannot enable ATR if RSS is disabled */
+		if (adapter->ring_feature[RING_F_RSS].limit <= 1)
+			break;
+
+		/* A sample rate of 0 indicates ATR disabled */
+		if (!adapter->atr_sample_rate)
+			break;
+
+		adapter->flags |= IXGBE_FLAG_FDIR_HASH_CAPABLE;
+		break;
+	}
+
+#endif /* ETHTOOL_GRXRINGS */
+	if (need_reset)
+		ixgbe_do_reset(netdev);
+
+	return 0;
+}
+
+#endif /* ETHTOOL_GFLAGS */
+#endif /* HAVE_NDO_SET_FEATURES */
+#ifdef ETHTOOL_GRXRINGS
 static int ixgbe_get_ethtool_fdir_entry(struct ixgbe_adapter *adapter,
 					struct ethtool_rxnfc *cmd)
 {
@@ -2430,11 +3189,11 @@ static int ixgbe_get_rss_hash_opts(struct ixgbe_adapter *adapter,
 	switch (cmd->flow_type) {
 	case TCP_V4_FLOW:
 		cmd->data |= RXH_L4_B_0_1 | RXH_L4_B_2_3;
-		/* fallthrough */
+		/* fall through */
 	case UDP_V4_FLOW:
 		if (adapter->flags2 & IXGBE_FLAG2_RSS_FIELD_IPV4_UDP)
 			cmd->data |= RXH_L4_B_0_1 | RXH_L4_B_2_3;
-		/* fallthrough */
+		/* fall through */
 	case SCTP_V4_FLOW:
 	case AH_ESP_V4_FLOW:
 	case AH_V4_FLOW:
@@ -2444,11 +3203,11 @@ static int ixgbe_get_rss_hash_opts(struct ixgbe_adapter *adapter,
 		break;
 	case TCP_V6_FLOW:
 		cmd->data |= RXH_L4_B_0_1 | RXH_L4_B_2_3;
-		/* fallthrough */
+		/* fall through */
 	case UDP_V6_FLOW:
 		if (adapter->flags2 & IXGBE_FLAG2_RSS_FIELD_IPV6_UDP)
 			cmd->data |= RXH_L4_B_0_1 | RXH_L4_B_2_3;
-		/* fallthrough */
+		/* fall through */
 	case SCTP_V6_FLOW:
 	case AH_ESP_V6_FLOW:
 	case AH_V6_FLOW:
@@ -2464,7 +3223,11 @@ static int ixgbe_get_rss_hash_opts(struct ixgbe_adapter *adapter,
 }
 
 static int ixgbe_get_rxnfc(struct net_device *dev, struct ethtool_rxnfc *cmd,
+#ifdef HAVE_ETHTOOL_GET_RXNFC_VOID_RULE_LOCS
+			   void *rule_locs)
+#else
 			   u32 *rule_locs)
+#endif
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
 	int ret = -EOPNOTSUPP;
@@ -2482,7 +3245,8 @@ static int ixgbe_get_rxnfc(struct net_device *dev, struct ethtool_rxnfc *cmd,
 		ret = ixgbe_get_ethtool_fdir_entry(adapter, cmd);
 		break;
 	case ETHTOOL_GRXCLSRLALL:
-		ret = ixgbe_get_ethtool_fdir_all(adapter, cmd, rule_locs);
+		ret = ixgbe_get_ethtool_fdir_all(adapter, cmd,
+						 (u32 *)rule_locs);
 		break;
 	case ETHTOOL_GRXFH:
 		ret = ixgbe_get_rss_hash_opts(adapter, cmd);
@@ -2501,7 +3265,8 @@ static int ixgbe_update_ethtool_fdir_entry(struct ixgbe_adapter *adapter,
 	struct ixgbe_hw *hw = &adapter->hw;
 	struct hlist_node *node2;
 	struct ixgbe_fdir_filter *rule, *parent;
-	int err = -EINVAL;
+	bool deleted = false;
+	s32 err;
 
 	parent = NULL;
 	rule = NULL;
@@ -2516,24 +3281,32 @@ static int ixgbe_update_ethtool_fdir_entry(struct ixgbe_adapter *adapter,
 
 	/* if there is an old rule occupying our place remove it */
 	if (rule && (rule->sw_idx == sw_idx)) {
-		if (!input || (rule->filter.formatted.bkt_hash !=
-			       input->filter.formatted.bkt_hash)) {
+		/* hardware filters are only configured when interface is up,
+		 * and we should not issue filter commands while the interface
+		 * is down
+		 */
+		if (netif_running(adapter->netdev) &&
+		    (!input || (rule->filter.formatted.bkt_hash !=
+				input->filter.formatted.bkt_hash))) {
 			err = ixgbe_fdir_erase_perfect_filter_82599(hw,
 								&rule->filter,
 								sw_idx);
+			if (err)
+				return -EINVAL;
 		}
 
 		hlist_del(&rule->fdir_node);
 		kfree(rule);
 		adapter->fdir_filter_count--;
+		deleted = true;
 	}
 
-	/*
-	 * If no input this was a delete, err should be 0 if a rule was
-	 * successfully found and removed from the list else -EINVAL
+	/* If we weren't given an input, then this was a request to delete a
+	 * filter. We should return -EINVAL if the filter wasn't found, but
+	 * return 0 if the rule was successfully deleted.
 	 */
 	if (!input)
-		return err;
+		return deleted ? 0 : -EINVAL;
 
 	/* initialize node and set software index */
 	INIT_HLIST_NODE(&input->fdir_node);
@@ -2580,6 +3353,7 @@ static int ixgbe_flowspec_to_flow_type(struct ethtool_rx_flow_spec *fsp,
 				*flow_type = IXGBE_ATR_FLOW_TYPE_IPV4;
 				break;
 			}
+			/* fall through */
 		default:
 			return 0;
 		}
@@ -2599,35 +3373,18 @@ static int ixgbe_add_ethtool_fdir_entry(struct ixgbe_adapter *adapter,
 	struct ixgbe_hw *hw = &adapter->hw;
 	struct ixgbe_fdir_filter *input;
 	union ixgbe_atr_input mask;
-	u8 queue;
 	int err;
 
 	if (!(adapter->flags & IXGBE_FLAG_FDIR_PERFECT_CAPABLE))
 		return -EOPNOTSUPP;
 
-	/* ring_cookie is a masked into a set of queues and ixgbe pools or
-	 * we use the drop index.
+	/*
+	 * Don't allow programming if the action is a queue greater than
+	 * the number of online Rx queues.
 	 */
-	if (fsp->ring_cookie == RX_CLS_FLOW_DISC) {
-		queue = IXGBE_FDIR_DROP_QUEUE;
-	} else {
-		u32 ring = ethtool_get_flow_spec_ring(fsp->ring_cookie);
-		u8 vf = ethtool_get_flow_spec_ring_vf(fsp->ring_cookie);
-
-		if (!vf && (ring >= adapter->num_rx_queues))
-			return -EINVAL;
-		else if (vf &&
-			 ((vf > adapter->num_vfs) ||
-			   ring >= adapter->num_rx_queues_per_pool))
-			return -EINVAL;
-
-		/* Map the ring onto the absolute queue index */
-		if (!vf)
-			queue = adapter->rx_ring[ring]->reg_idx;
-		else
-			queue = ((vf - 1) *
-				adapter->num_rx_queues_per_pool) + ring;
-	}
+	if ((fsp->ring_cookie != RX_CLS_FLOW_DISC) &&
+	    (fsp->ring_cookie >= adapter->num_rx_queues))
+		return -EINVAL;
 
 	/* Don't allow indexes to exist outside of available space */
 	if (fsp->location >= ((1024 << adapter->fdir_pballoc) - 2)) {
@@ -2690,30 +3447,39 @@ static int ixgbe_add_ethtool_fdir_entry(struct ixgbe_adapter *adapter,
 	if (hlist_empty(&adapter->fdir_filter_list)) {
 		/* save mask and program input mask into HW */
 		memcpy(&adapter->fdir_mask, &mask, sizeof(mask));
-		err = ixgbe_fdir_set_input_mask_82599(hw, &mask);
+		err = ixgbe_fdir_set_input_mask_82599(hw, &mask, adapter->cloud_mode);
 		if (err) {
 			e_err(drv, "Error writing mask\n");
 			goto err_out_w_lock;
 		}
 	} else if (memcmp(&adapter->fdir_mask, &mask, sizeof(mask))) {
-		e_err(drv, "Only one mask supported per port\n");
+		e_err(drv, "Hardware only supports one mask per port. To change the mask you must first delete all the rules.\n");
 		goto err_out_w_lock;
 	}
 
 	/* apply mask and compute/store hash */
 	ixgbe_atr_compute_perfect_hash_82599(&input->filter, &mask);
 
-	/* program filters to filter memory */
-	err = ixgbe_fdir_write_perfect_filter_82599(hw,
-				&input->filter, input->sw_idx, queue);
-	if (err)
-		goto err_out_w_lock;
+	/* only program filters to hardware if the net device is running, as
+	 * we store the filters in the Rx buffer which is not allocated when
+	 * the device is down
+	 */
+	if (netif_running(adapter->netdev)) {
+		err = ixgbe_fdir_write_perfect_filter_82599(hw,
+					&input->filter, input->sw_idx,
+					(input->action == IXGBE_FDIR_DROP_QUEUE) ?
+					IXGBE_FDIR_DROP_QUEUE :
+					adapter->rx_ring[input->action]->reg_idx,
+					adapter->cloud_mode);
+		if (err)
+			goto err_out_w_lock;
+	}
 
 	ixgbe_update_ethtool_fdir_entry(adapter, input, input->sw_idx);
 
 	spin_unlock(&adapter->fdir_perfect_lock);
 
-	return err;
+	return 0;
 err_out_w_lock:
 	spin_unlock(&adapter->fdir_perfect_lock);
 err_out:
@@ -2735,6 +3501,19 @@ static int ixgbe_del_ethtool_fdir_entry(struct ixgbe_adapter *adapter,
 	return err;
 }
 
+#ifdef ETHTOOL_SRXNTUPLE
+/*
+ * We need to keep this around for kernels 2.6.33 - 2.6.39 in order to avoid
+ * a null pointer dereference as it was assumend if the NETIF_F_NTUPLE flag
+ * was defined that this function was present.
+ */
+static int ixgbe_set_rx_ntuple(struct net_device __always_unused *dev,
+			       struct ethtool_rx_ntuple __always_unused *cmd)
+{
+	return -EOPNOTSUPP;
+}
+
+#endif
 #define UDP_RSS_FLAGS (IXGBE_FLAG2_RSS_FIELD_IPV4_UDP | \
 		       IXGBE_FLAG2_RSS_FIELD_IPV6_UDP)
 static int ixgbe_set_rss_hash_opt(struct ixgbe_adapter *adapter,
@@ -2821,7 +3600,8 @@ static int ixgbe_set_rss_hash_opt(struct ixgbe_adapter *adapter,
 
 		if ((flags2 & UDP_RSS_FLAGS) &&
 		    !(adapter->flags2 & UDP_RSS_FLAGS))
-			e_warn(drv, "enabling UDP RSS: fragmented packets may arrive out of order to the stack above\n");
+			e_warn(drv, "enabling UDP RSS: fragmented packets"
+			       " may arrive out of order to the stack above\n");
 
 		adapter->flags2 = flags2;
 
@@ -2872,6 +3652,7 @@ static int ixgbe_set_rxnfc(struct net_device *dev, struct ethtool_rxnfc *cmd)
 	return ret;
 }
 
+#if defined(ETHTOOL_GRSSH) && defined(ETHTOOL_SRSSH)
 static int ixgbe_rss_indir_tbl_max(struct ixgbe_adapter *adapter)
 {
 	if (adapter->hw.mac.type < ixgbe_mac_X550)
@@ -2882,9 +3663,7 @@ static int ixgbe_rss_indir_tbl_max(struct ixgbe_adapter *adapter)
 
 static u32 ixgbe_get_rxfh_key_size(struct net_device *netdev)
 {
-	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-
-	return sizeof(adapter->rss_key);
+	return IXGBE_RSS_KEY_SIZE;
 }
 
 static u32 ixgbe_rss_indir_size(struct net_device *netdev)
@@ -2897,18 +3676,28 @@ static u32 ixgbe_rss_indir_size(struct net_device *netdev)
 static void ixgbe_get_reta(struct ixgbe_adapter *adapter, u32 *indir)
 {
 	int i, reta_size = ixgbe_rss_indir_tbl_entries(adapter);
+	u16 rss_m = adapter->ring_feature[RING_F_RSS].mask;
+
+	if (adapter->flags & IXGBE_FLAG_SRIOV_ENABLED)
+		rss_m = adapter->ring_feature[RING_F_RSS].indices - 1;
 
 	for (i = 0; i < reta_size; i++)
-		indir[i] = adapter->rss_indir_tbl[i];
+		indir[i] = adapter->rss_indir_tbl[i] & rss_m;
 }
 
+#ifdef HAVE_RXFH_HASHFUNC
 static int ixgbe_get_rxfh(struct net_device *netdev, u32 *indir, u8 *key,
 			  u8 *hfunc)
+#else
+static int ixgbe_get_rxfh(struct net_device *netdev, u32 *indir, u8 *key)
+#endif
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 
+#ifdef HAVE_RXFH_HASHFUNC
 	if (hfunc)
 		*hfunc = ETH_RSS_HASH_TOP;
+#endif
 
 	if (indir)
 		ixgbe_get_reta(adapter, indir);
@@ -2919,15 +3708,26 @@ static int ixgbe_get_rxfh(struct net_device *netdev, u32 *indir, u8 *key,
 	return 0;
 }
 
+#ifdef HAVE_RXFH_HASHFUNC
 static int ixgbe_set_rxfh(struct net_device *netdev, const u32 *indir,
 			  const u8 *key, const u8 hfunc)
+#else
+#ifdef HAVE_RXFH_NONCONST
+static int ixgbe_set_rxfh(struct net_device *netdev, u32 *indir, u8 *key)
+#else
+static int ixgbe_set_rxfh(struct net_device *netdev, const u32 *indir,
+			  const u8 *key)
+#endif /* HAVE_RXFH_NONCONST */
+#endif /* HAVE_RXFH_HASHFUNC */
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	int i;
 	u32 reta_entries = ixgbe_rss_indir_tbl_entries(adapter);
 
+#ifdef HAVE_RXFH_HASHFUNC
 	if (hfunc)
 		return -EINVAL;
+#endif
 
 	/* Fill out the redirection table */
 	if (indir) {
@@ -2949,22 +3749,33 @@ static int ixgbe_set_rxfh(struct net_device *netdev, const u32 *indir,
 	}
 
 	/* Fill out the rss hash key */
-	if (key)
+	if (key) {
 		memcpy(adapter->rss_key, key, ixgbe_get_rxfh_key_size(netdev));
+		ixgbe_store_key(adapter);
+	}
 
 	ixgbe_store_reta(adapter);
 
 	return 0;
 }
+#endif /* ETHTOOL_GRSSH && ETHTOOL_SRSSH */
 
+#ifdef HAVE_ETHTOOL_GET_TS_INFO
 static int ixgbe_get_ts_info(struct net_device *dev,
 			     struct ethtool_ts_info *info)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
 
+	/* we always support timestamping disabled */
+	info->rx_filters = 1 << HWTSTAMP_FILTER_NONE;
+
 	switch (adapter->hw.mac.type) {
+#ifdef HAVE_PTP_1588_CLOCK
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		info->rx_filters |= 1 << HWTSTAMP_FILTER_ALL;
+		/* fallthrough */
 	case ixgbe_mac_X540:
 	case ixgbe_mac_82599EB:
 		info->so_timestamping =
@@ -2984,18 +3795,30 @@ static int ixgbe_get_ts_info(struct net_device *dev,
 			(1 << HWTSTAMP_TX_OFF) |
 			(1 << HWTSTAMP_TX_ON);
 
-		info->rx_filters =
-			(1 << HWTSTAMP_FILTER_NONE) |
+		info->rx_filters |=
 			(1 << HWTSTAMP_FILTER_PTP_V1_L4_SYNC) |
 			(1 << HWTSTAMP_FILTER_PTP_V1_L4_DELAY_REQ) |
+			(1 << HWTSTAMP_FILTER_PTP_V2_L2_EVENT) |
+			(1 << HWTSTAMP_FILTER_PTP_V2_L4_EVENT) |
+			(1 << HWTSTAMP_FILTER_PTP_V2_SYNC) |
+			(1 << HWTSTAMP_FILTER_PTP_V2_L2_SYNC) |
+			(1 << HWTSTAMP_FILTER_PTP_V2_L4_SYNC) |
+			(1 << HWTSTAMP_FILTER_PTP_V2_DELAY_REQ) |
+			(1 << HWTSTAMP_FILTER_PTP_V2_L2_DELAY_REQ) |
+			(1 << HWTSTAMP_FILTER_PTP_V2_L4_DELAY_REQ) |
 			(1 << HWTSTAMP_FILTER_PTP_V2_EVENT);
 		break;
+#endif /* HAVE_PTP_1588_CLOCK */
 	default:
 		return ethtool_op_get_ts_info(dev, info);
+		break;
 	}
 	return 0;
 }
+#endif /* HAVE_ETHTOOL_GET_TS_INFO */
 
+#endif /* ETHTOOL_GRXRINGS */
+#ifdef ETHTOOL_SCHANNELS
 static unsigned int ixgbe_max_channels(struct ixgbe_adapter *adapter)
 {
 	unsigned int max_combined;
@@ -3005,8 +3828,8 @@ static unsigned int ixgbe_max_channels(struct ixgbe_adapter *adapter)
 		/* We only support one q_vector without MSI-X */
 		max_combined = 1;
 	} else if (adapter->flags & IXGBE_FLAG_SRIOV_ENABLED) {
-		/* SR-IOV currently only allows one queue on the PF */
-		max_combined = 1;
+		/* Limit value based on the queue mask */
+		max_combined = adapter->ring_feature[RING_F_RSS].mask + 1;
 	} else if (tcs > 1) {
 		/* For DCB report channels per traffic class */
 		if (adapter->hw.mac.type == ixgbe_mac_82598EB) {
@@ -3023,7 +3846,7 @@ static unsigned int ixgbe_max_channels(struct ixgbe_adapter *adapter)
 		/* support up to 64 queues with ATR */
 		max_combined = IXGBE_MAX_FDIR_INDICES;
 	} else {
-		/* support up to 16 queues with RSS */
+		/* support up to max allowed queues with RSS */
 		max_combined = ixgbe_max_rss_indices(adapter);
 	}
 
@@ -3094,23 +3917,25 @@ static int ixgbe_set_channels(struct net_device *dev,
 		count = max_rss_indices;
 	adapter->ring_feature[RING_F_RSS].limit = count;
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* cap FCoE limit at 8 */
 	if (count > IXGBE_FCRETA_SIZE)
 		count = IXGBE_FCRETA_SIZE;
 	adapter->ring_feature[RING_F_FCOE].limit = count;
+#endif /* CONFIG_FCOE */
 
-#endif
 	/* use setup TC to update any traffic class queue mapping */
 	return ixgbe_setup_tc(dev, netdev_get_num_tc(dev));
 }
+#endif /* ETHTOOL_SCHANNELS */
 
+#ifdef ETHTOOL_GMODULEINFO
 static int ixgbe_get_module_info(struct net_device *dev,
 				       struct ethtool_modinfo *modinfo)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
 	struct ixgbe_hw *hw = &adapter->hw;
-	s32 status;
+	u32 status;
 	u8 sff8472_rev, addr_mode;
 	bool page_swap = false;
 
@@ -3118,14 +3943,14 @@ static int ixgbe_get_module_info(struct net_device *dev,
 	status = hw->phy.ops.read_i2c_eeprom(hw,
 					     IXGBE_SFF_SFF_8472_COMP,
 					     &sff8472_rev);
-	if (status)
+	if (status != 0)
 		return -EIO;
 
 	/* addressing mode is not supported */
 	status = hw->phy.ops.read_i2c_eeprom(hw,
 					     IXGBE_SFF_SFF_8472_SWAP,
 					     &addr_mode);
-	if (status)
+	if (status != 0)
 		return -EIO;
 
 	if (addr_mode & IXGBE_SFF_ADDRESSING_MODE) {
@@ -3152,7 +3977,7 @@ static int ixgbe_get_module_eeprom(struct net_device *dev,
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
 	struct ixgbe_hw *hw = &adapter->hw;
-	s32 status = IXGBE_ERR_PHY_ADDR_INVALID;
+	u32 status = IXGBE_ERR_PHY_ADDR_INVALID;
 	u8 databyte = 0xFF;
 	int i = 0;
 
@@ -3169,7 +3994,7 @@ static int ixgbe_get_module_eeprom(struct net_device *dev,
 		else
 			status = hw->phy.ops.read_i2c_sff8472(hw, i, &databyte);
 
-		if (status)
+		if (status != 0)
 			return -EIO;
 
 		data[i - ee->offset] = databyte;
@@ -3177,47 +4002,368 @@ static int ixgbe_get_module_eeprom(struct net_device *dev,
 
 	return 0;
 }
+#endif /* ETHTOOL_GMODULEINFO */
+
+#ifdef ETHTOOL_GEEE
+
+static const struct {
+	ixgbe_link_speed mac_speed;
+	u32 supported;
+} ixgbe_ls_map[] = {
+	{ IXGBE_LINK_SPEED_10_FULL, SUPPORTED_10baseT_Full },
+	{ IXGBE_LINK_SPEED_100_FULL, SUPPORTED_100baseT_Full },
+	{ IXGBE_LINK_SPEED_1GB_FULL, SUPPORTED_1000baseT_Full },
+	{ IXGBE_LINK_SPEED_2_5GB_FULL, SUPPORTED_2500baseX_Full },
+	{ IXGBE_LINK_SPEED_10GB_FULL, SUPPORTED_10000baseT_Full },
+};
+
+static const struct {
+	u32 lp_advertised;
+	u32 mac_speed;
+} ixgbe_lp_map[] = {
+	{ FW_PHY_ACT_UD_2_100M_TX_EEE, SUPPORTED_100baseT_Full },
+	{ FW_PHY_ACT_UD_2_1G_T_EEE, SUPPORTED_1000baseT_Full },
+	{ FW_PHY_ACT_UD_2_10G_T_EEE, SUPPORTED_10000baseT_Full },
+	{ FW_PHY_ACT_UD_2_1G_KX_EEE, SUPPORTED_1000baseKX_Full },
+	{ FW_PHY_ACT_UD_2_10G_KX4_EEE, SUPPORTED_10000baseKX4_Full },
+	{ FW_PHY_ACT_UD_2_10G_KR_EEE, SUPPORTED_10000baseKR_Full},
+};
+
+static int
+ixgbe_get_eee_fw(struct ixgbe_adapter *adapter, struct ethtool_eee *edata)
+{
+	u32 info[FW_PHY_ACT_DATA_COUNT] = { 0 };
+	struct ixgbe_hw *hw = &adapter->hw;
+	s32 rc;
+	u16 i;
+
+	rc = ixgbe_fw_phy_activity(hw, FW_PHY_ACT_UD_2, &info);
+	if (rc)
+		return rc;
+
+	edata->lp_advertised = 0;
+	for (i = 0; i < ARRAY_SIZE(ixgbe_lp_map); ++i) {
+		if (info[0] & ixgbe_lp_map[i].lp_advertised)
+			edata->lp_advertised |= ixgbe_lp_map[i].mac_speed;
+	}
+
+	edata->supported = 0;
+	for (i = 0; i < ARRAY_SIZE(ixgbe_ls_map); ++i) {
+		if (hw->phy.eee_speeds_supported & ixgbe_ls_map[i].mac_speed)
+			edata->supported |= ixgbe_ls_map[i].supported;
+	}
+
+	edata->advertised = 0;
+	for (i = 0; i < ARRAY_SIZE(ixgbe_ls_map); ++i) {
+		if (hw->phy.eee_speeds_advertised & ixgbe_ls_map[i].mac_speed)
+			edata->advertised |= ixgbe_ls_map[i].supported;
+	}
+
+	edata->eee_enabled = !!edata->advertised;
+	edata->tx_lpi_enabled = edata->eee_enabled;
+	if (edata->advertised & edata->lp_advertised)
+		edata->eee_active = true;
+
+	return 0;
+}
+
+static int ixgbe_get_eee(struct net_device *netdev, struct ethtool_eee *edata)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	struct ixgbe_hw *hw = &adapter->hw;
+
+	if (!hw->mac.ops.setup_eee)
+		return -EOPNOTSUPP;
 
-static const struct ethtool_ops ixgbe_ethtool_ops = {
-	.get_settings           = ixgbe_get_settings,
-	.set_settings           = ixgbe_set_settings,
-	.get_drvinfo            = ixgbe_get_drvinfo,
-	.get_regs_len           = ixgbe_get_regs_len,
-	.get_regs               = ixgbe_get_regs,
-	.get_wol                = ixgbe_get_wol,
-	.set_wol                = ixgbe_set_wol,
-	.nway_reset             = ixgbe_nway_reset,
-	.get_link               = ethtool_op_get_link,
-	.get_eeprom_len         = ixgbe_get_eeprom_len,
-	.get_eeprom             = ixgbe_get_eeprom,
-	.set_eeprom             = ixgbe_set_eeprom,
-	.get_ringparam          = ixgbe_get_ringparam,
-	.set_ringparam          = ixgbe_set_ringparam,
-	.get_pauseparam         = ixgbe_get_pauseparam,
-	.set_pauseparam         = ixgbe_set_pauseparam,
-	.get_msglevel           = ixgbe_get_msglevel,
-	.set_msglevel           = ixgbe_set_msglevel,
-	.self_test              = ixgbe_diag_test,
-	.get_strings            = ixgbe_get_strings,
-	.set_phys_id            = ixgbe_set_phys_id,
-	.get_sset_count         = ixgbe_get_sset_count,
+	if (!(adapter->flags2 & IXGBE_FLAG2_EEE_CAPABLE))
+		return -EOPNOTSUPP;
+
+	if (hw->phy.eee_speeds_supported && hw->phy.type == ixgbe_phy_fw)
+		return ixgbe_get_eee_fw(adapter, edata);
+
+	return -EOPNOTSUPP;
+}
+#endif /* ETHTOOL_GEEE */
+
+#ifdef ETHTOOL_SEEE
+static int ixgbe_set_eee(struct net_device *netdev, struct ethtool_eee *edata)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	struct ixgbe_hw *hw = &adapter->hw;
+	struct ethtool_eee eee_data;
+	s32 ret_val;
+
+	if (!(hw->mac.ops.setup_eee &&
+	    (adapter->flags2 & IXGBE_FLAG2_EEE_CAPABLE)))
+		return -EOPNOTSUPP;
+
+	memset(&eee_data, 0, sizeof(struct ethtool_eee));
+
+	ret_val = ixgbe_get_eee(netdev, &eee_data);
+	if (ret_val)
+		return ret_val;
+
+	if (eee_data.tx_lpi_enabled != edata->tx_lpi_enabled) {
+		e_dev_err("Setting EEE tx-lpi is not supported\n");
+		return -EINVAL;
+	}
+
+	if (eee_data.tx_lpi_timer != edata->tx_lpi_timer) {
+		e_dev_err("Setting EEE Tx LPI timer is not supported\n");
+		return -EINVAL;
+	}
+
+	if (eee_data.advertised != edata->advertised) {
+		e_dev_err("Setting EEE advertised speeds is not supported\n");
+		return -EINVAL;
+	}
+
+	if (eee_data.eee_enabled != edata->eee_enabled) {
+
+		if (edata->eee_enabled) {
+			adapter->flags2 |= IXGBE_FLAG2_EEE_ENABLED;
+			hw->phy.eee_speeds_advertised =
+						   hw->phy.eee_speeds_supported;
+		} else {
+			adapter->flags2 &= ~IXGBE_FLAG2_EEE_ENABLED;
+			hw->phy.eee_speeds_advertised = 0;
+		}
+
+		/* reset link */
+		if (netif_running(netdev))
+			ixgbe_reinit_locked(adapter);
+		else
+			ixgbe_reset(adapter);
+	}
+
+	return 0;
+}
+#endif /* ETHTOOL_SEEE */
+
+#ifdef HAVE_ETHTOOL_GET_SSET_COUNT
+/**
+ * ixgbe_get_priv_flags - report device private flags
+ * @netdev: network interface device structure
+ *
+ * The get string set count and the string set should be matched for each
+ * flag returned.  Add new strings for each flag to the ixgbe_priv_flags_strings
+ * array.
+ *
+ * Returns a u32 bitmap of flags.
+ **/
+static u32 ixgbe_get_priv_flags(struct net_device *netdev)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	u32 priv_flags = 0;
+
+	if (adapter->flags & IXGBE_FLAG_FDIR_HASH_CAPABLE)
+		priv_flags |= IXGBE_PRIV_FLAGS_FD_ATR;
+#ifdef HAVE_SWIOTLB_SKIP_CPU_SYNC
+
+	if (adapter->flags2 & IXGBE_FLAG2_RX_LEGACY)
+		priv_flags |= IXGBE_PRIV_FLAGS_LEGACY_RX;
+#endif
+
+	return priv_flags;
+}
+
+/**
+ * ixgbe_set_priv_flags - set private flags
+ * @netdev: network interface device structure
+ * @flags: bit flags to be set
+ **/
+static int ixgbe_set_priv_flags(struct net_device *netdev, u32 priv_flags)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+#ifdef HAVE_SWIOTLB_SKIP_CPU_SYNC
+	unsigned int flags2 = adapter->flags2;
+#endif
+	unsigned int flags = adapter->flags;
+
+	/* allow the user to control the state of the Flow
+	 * Director ATR (Application Targeted Routing) feature
+	 * of the driver
+	 */
+	flags &= ~IXGBE_FLAG_FDIR_HASH_CAPABLE;
+	if (priv_flags & IXGBE_PRIV_FLAGS_FD_ATR) {
+		/* We cannot enable ATR if VMDq is enabled */
+		if (flags & IXGBE_FLAG_VMDQ_ENABLED)
+			return -EINVAL;
+		/* We cannot enable ATR if we have 2 or more traffic classes */
+		if (netdev_get_num_tc(netdev) > 1)
+			return -EINVAL;
+		/* We cannot enable ATR if RSS is disabled */
+		if (adapter->ring_feature[RING_F_RSS].limit <= 1)
+			return -EINVAL;
+		/* A sample rate of 0 indicates ATR disabled */
+		if (!adapter->atr_sample_rate)
+			return -EINVAL;
+		flags |= IXGBE_FLAG_FDIR_HASH_CAPABLE;
+	}
+#ifdef HAVE_SWIOTLB_SKIP_CPU_SYNC
+
+	flags2 &= ~IXGBE_FLAG2_RX_LEGACY;
+	if (priv_flags & IXGBE_PRIV_FLAGS_LEGACY_RX)
+		flags2 |= IXGBE_FLAG2_RX_LEGACY;
+#endif
+
+	if (flags != adapter->flags) {
+		adapter->flags = flags;
+
+		/* ATR state change requires a reset */
+		ixgbe_do_reset(netdev);
+#ifndef HAVE_SWIOTLB_SKIP_CPU_SYNC
+	}
+#else
+	} else if (flags2 != adapter->flags2) {
+		adapter->flags2 = flags2;
+
+		/* reset interface to repopulate queues */
+		if (netif_running(netdev))
+			ixgbe_reinit_locked(adapter);
+	}
+#endif
+
+	return 0;
+}
+
+#endif /* HAVE_ETHTOOL_GET_SSET_COUNT */
+static struct ethtool_ops ixgbe_ethtool_ops = {
+#ifdef HAVE_ETHTOOL_CONVERT_U32_AND_LINK_MODE
+	.get_link_ksettings	= ixgbe_get_link_ksettings,
+	.set_link_ksettings	= ixgbe_set_link_ksettings,
+#else
+	.get_settings		= ixgbe_get_settings,
+	.set_settings		= ixgbe_set_settings,
+#endif
+	.get_drvinfo		= ixgbe_get_drvinfo,
+	.get_regs_len		= ixgbe_get_regs_len,
+	.get_regs		= ixgbe_get_regs,
+	.get_wol		= ixgbe_get_wol,
+	.set_wol		= ixgbe_set_wol,
+	.nway_reset		= ixgbe_nway_reset,
+	.get_link		= ethtool_op_get_link,
+	.get_eeprom_len		= ixgbe_get_eeprom_len,
+	.get_eeprom		= ixgbe_get_eeprom,
+	.set_eeprom		= ixgbe_set_eeprom,
+	.get_ringparam		= ixgbe_get_ringparam,
+	.set_ringparam		= ixgbe_set_ringparam,
+	.get_pauseparam		= ixgbe_get_pauseparam,
+	.set_pauseparam		= ixgbe_set_pauseparam,
+	.get_msglevel		= ixgbe_get_msglevel,
+	.set_msglevel		= ixgbe_set_msglevel,
+#ifndef HAVE_ETHTOOL_GET_SSET_COUNT
+	.self_test_count	= ixgbe_diag_test_count,
+#endif /* HAVE_ETHTOOL_GET_SSET_COUNT */
+	.self_test		= ixgbe_diag_test,
+	.get_strings		= ixgbe_get_strings,
+#ifndef HAVE_RHEL6_ETHTOOL_OPS_EXT_STRUCT
+#ifdef HAVE_ETHTOOL_SET_PHYS_ID
+	.set_phys_id		= ixgbe_set_phys_id,
+#else
+	.phys_id		= ixgbe_phys_id,
+#endif /* HAVE_ETHTOOL_SET_PHYS_ID */
+#endif /* HAVE_RHEL6_ETHTOOL_OPS_EXT_STRUCT */
+#ifndef HAVE_ETHTOOL_GET_SSET_COUNT
+	.get_stats_count	= ixgbe_get_stats_count,
+#else /* HAVE_ETHTOOL_GET_SSET_COUNT */
+	.get_sset_count		= ixgbe_get_sset_count,
+	.get_priv_flags		= ixgbe_get_priv_flags,
+	.set_priv_flags		= ixgbe_set_priv_flags,
+#endif /* HAVE_ETHTOOL_GET_SSET_COUNT */
 	.get_ethtool_stats      = ixgbe_get_ethtool_stats,
-	.get_coalesce           = ixgbe_get_coalesce,
-	.set_coalesce           = ixgbe_set_coalesce,
+#ifdef HAVE_ETHTOOL_GET_PERM_ADDR
+	.get_perm_addr		= ethtool_op_get_perm_addr,
+#endif
+	.get_coalesce		= ixgbe_get_coalesce,
+	.set_coalesce		= ixgbe_set_coalesce,
+#ifndef HAVE_NDO_SET_FEATURES
+	.get_rx_csum		= ixgbe_get_rx_csum,
+	.set_rx_csum		= ixgbe_set_rx_csum,
+	.get_tx_csum		= ethtool_op_get_tx_csum,
+	.set_tx_csum		= ixgbe_set_tx_csum,
+	.get_sg			= ethtool_op_get_sg,
+	.set_sg			= ethtool_op_set_sg,
+#ifdef NETIF_F_TSO
+	.get_tso		= ethtool_op_get_tso,
+	.set_tso		= ixgbe_set_tso,
+#endif
+#ifdef ETHTOOL_GFLAGS
+	.get_flags		= ethtool_op_get_flags,
+	.set_flags		= ixgbe_set_flags,
+#endif
+#endif /* HAVE_NDO_SET_FEATURES */
+#ifdef ETHTOOL_GRXRINGS
 	.get_rxnfc		= ixgbe_get_rxnfc,
 	.set_rxnfc		= ixgbe_set_rxnfc,
+#ifdef ETHTOOL_SRXNTUPLE
+	.set_rx_ntuple		= ixgbe_set_rx_ntuple,
+#endif
+#endif /* ETHTOOL_GRXRINGS */
+#ifndef HAVE_RHEL6_ETHTOOL_OPS_EXT_STRUCT
+#ifdef ETHTOOL_GEEE
+	.get_eee		= ixgbe_get_eee,
+#endif /* ETHTOOL_GEEE */
+#ifdef ETHTOOL_SEEE
+	.set_eee		= ixgbe_set_eee,
+#endif /* ETHTOOL_SEEE */
+#ifdef ETHTOOL_SCHANNELS
+	.get_channels		= ixgbe_get_channels,
+	.set_channels		= ixgbe_set_channels,
+#endif
+#ifdef ETHTOOL_GMODULEINFO
+	.get_module_info	= ixgbe_get_module_info,
+	.get_module_eeprom	= ixgbe_get_module_eeprom,
+#endif
+#ifdef HAVE_ETHTOOL_GET_TS_INFO
+	.get_ts_info		= ixgbe_get_ts_info,
+#endif
+#if defined(ETHTOOL_GRSSH) && defined(ETHTOOL_SRSSH)
 	.get_rxfh_indir_size	= ixgbe_rss_indir_size,
 	.get_rxfh_key_size	= ixgbe_get_rxfh_key_size,
 	.get_rxfh		= ixgbe_get_rxfh,
 	.set_rxfh		= ixgbe_set_rxfh,
+#endif /* ETHTOOL_GRSSH && ETHTOOL_SRSSH */
+#endif /* HAVE_RHEL6_ETHTOOL_OPS_EXT_STRUCT */
+};
+
+#ifdef HAVE_RHEL6_ETHTOOL_OPS_EXT_STRUCT
+static const struct ethtool_ops_ext ixgbe_ethtool_ops_ext = {
+	.size			= sizeof(struct ethtool_ops_ext),
+	.get_ts_info		= ixgbe_get_ts_info,
+	.set_phys_id		= ixgbe_set_phys_id,
 	.get_channels		= ixgbe_get_channels,
 	.set_channels		= ixgbe_set_channels,
-	.get_ts_info		= ixgbe_get_ts_info,
+#ifdef ETHTOOL_GMODULEINFO
 	.get_module_info	= ixgbe_get_module_info,
 	.get_module_eeprom	= ixgbe_get_module_eeprom,
+#endif
+#if defined(ETHTOOL_GRSSH) && defined(ETHTOOL_SRSSH)
+	.get_rxfh_indir_size	= ixgbe_rss_indir_size,
+	.get_rxfh_key_size	= ixgbe_get_rxfh_key_size,
+	.get_rxfh		= ixgbe_get_rxfh,
+	.set_rxfh		= ixgbe_set_rxfh,
+#endif /* ETHTOOL_GRSSH && ETHTOOL_SRSSH */
+#ifdef ETHTOOL_GEEE
+	.get_eee		= ixgbe_get_eee,
+#endif /* ETHTOOL_GEEE */
+#ifdef ETHTOOL_SEEE
+	.set_eee		= ixgbe_set_eee,
+#endif /* ETHTOOL_SEEE */
 };
 
+#endif /* HAVE_RHEL6_ETHTOOL_OPS_EXT_STRUCT */
 void ixgbe_set_ethtool_ops(struct net_device *netdev)
 {
+#ifndef ETHTOOL_OPS_COMPAT
 	netdev->ethtool_ops = &ixgbe_ethtool_ops;
+#else
+	SET_ETHTOOL_OPS(netdev, &ixgbe_ethtool_ops);
+#endif
+
+#ifdef HAVE_RHEL6_ETHTOOL_OPS_EXT_STRUCT
+	set_ethtool_ops_ext(netdev, &ixgbe_ethtool_ops_ext);
+#endif /* HAVE_RHEL6_ETHTOOL_OPS_EXT_STRUCT */
 }
+#endif /* SIOCETHTOOL */
+
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_fcoe.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_fcoe.c
index 631c603..e3fe87c 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_fcoe.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_fcoe.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -27,9 +23,12 @@
 *******************************************************************************/
 
 #include "ixgbe.h"
+
+#if IS_ENABLED(CONFIG_FCOE)
+#if IS_ENABLED(CONFIG_DCB)
+#include "ixgbe_dcb_82599.h"
+#endif /* CONFIG_DCB */
 #include <linux/if_ether.h>
-#include <linux/gfp.h>
-#include <linux/if_vlan.h>
 #include <scsi/scsi_cmnd.h>
 #include <scsi/scsi_device.h>
 #include <scsi/fc/fc_fs.h>
@@ -39,7 +38,7 @@
 
 /**
  * ixgbe_fcoe_clear_ddp - clear the given ddp context
- * @ddp: ptr to the ixgbe_fcoe_ddp
+ * @ddp - ptr to the ixgbe_fcoe_ddp
  *
  * Returns : none
  *
@@ -67,72 +66,76 @@ static inline void ixgbe_fcoe_clear_ddp(struct ixgbe_fcoe_ddp *ddp)
  */
 int ixgbe_fcoe_ddp_put(struct net_device *netdev, u16 xid)
 {
-	int len;
+	int len = 0;
 	struct ixgbe_fcoe *fcoe;
 	struct ixgbe_adapter *adapter;
-	struct ixgbe_fcoe_ddp *ddp;
 	struct ixgbe_hw *hw;
+	struct ixgbe_fcoe_ddp *ddp;
 	u32 fcbuff;
 
 	if (!netdev)
-		return 0;
+		goto out_ddp_put;
 
-	if (xid >= IXGBE_FCOE_DDP_MAX)
-		return 0;
+	if (xid > netdev->fcoe_ddp_xid)
+		goto out_ddp_put;
 
 	adapter = netdev_priv(netdev);
+	hw = &adapter->hw;
 	fcoe = &adapter->fcoe;
 	ddp = &fcoe->ddp[xid];
 	if (!ddp->udl)
-		return 0;
+		goto out_ddp_put;
 
-	hw = &adapter->hw;
 	len = ddp->len;
-	/* if no error then skip ddp context invalidation */
-	if (!ddp->err)
-		goto skip_ddpinv;
-
-	if (hw->mac.type == ixgbe_mac_X550) {
-		/* X550 does not require DDP FCoE lock */
-
-		IXGBE_WRITE_REG(hw, IXGBE_FCDFC(0, xid), 0);
-		IXGBE_WRITE_REG(hw, IXGBE_FCDFC(3, xid),
-				(xid | IXGBE_FCFLTRW_WE));
-
-		/* program FCBUFF */
-		IXGBE_WRITE_REG(hw, IXGBE_FCDDC(2, xid), 0);
-
-		/* program FCDMARW */
-		IXGBE_WRITE_REG(hw, IXGBE_FCDDC(3, xid),
-				(xid | IXGBE_FCDMARW_WE));
-
-		/* read FCBUFF to check context invalidated */
-		IXGBE_WRITE_REG(hw, IXGBE_FCDDC(3, xid),
-				(xid | IXGBE_FCDMARW_RE));
-		fcbuff = IXGBE_READ_REG(hw, IXGBE_FCDDC(2, xid));
-	} else {
-		/* other hardware requires DDP FCoE lock */
-		spin_lock_bh(&fcoe->lock);
-		IXGBE_WRITE_REG(hw, IXGBE_FCFLT, 0);
-		IXGBE_WRITE_REG(hw, IXGBE_FCFLTRW,
-				(xid | IXGBE_FCFLTRW_WE));
-		IXGBE_WRITE_REG(hw, IXGBE_FCBUFF, 0);
-		IXGBE_WRITE_REG(hw, IXGBE_FCDMARW,
-				(xid | IXGBE_FCDMARW_WE));
-
-		/* guaranteed to be invalidated after 100us */
-		IXGBE_WRITE_REG(hw, IXGBE_FCDMARW,
-				(xid | IXGBE_FCDMARW_RE));
-		fcbuff = IXGBE_READ_REG(hw, IXGBE_FCBUFF);
-		spin_unlock_bh(&fcoe->lock);
+	/* if there an error, force to invalidate ddp context */
+	if (ddp->err) {
+		switch (hw->mac.type) {
+		case ixgbe_mac_X550:
+			/* X550 does not require DDP FCoE lock */
+
+			IXGBE_WRITE_REG(hw, IXGBE_FCDFC(0, xid), 0);
+			IXGBE_WRITE_REG(hw, IXGBE_FCDFC(3, xid),
+					(xid | IXGBE_FCFLTRW_WE));
+
+			/* program FCBUFF */
+			IXGBE_WRITE_REG(hw, IXGBE_FCDDC(2, xid), 0);
+
+			/* program FCDMARW */
+			IXGBE_WRITE_REG(hw, IXGBE_FCDDC(3, xid),
+					(xid | IXGBE_FCDMARW_WE));
+
+			/* read FCBUFF to check context invalidated */
+			IXGBE_WRITE_REG(hw, IXGBE_FCDDC(3, xid),
+					(xid | IXGBE_FCDMARW_RE));
+			fcbuff = IXGBE_READ_REG(hw,
+						 IXGBE_FCDDC(2, xid));
+			break;
+		default:
+			/* other hardware requires DDP FCoE lock */
+			spin_lock_bh(&fcoe->lock);
+
+			IXGBE_WRITE_REG(hw, IXGBE_FCFLT, 0);
+			IXGBE_WRITE_REG(hw, IXGBE_FCFLTRW,
+					(xid | IXGBE_FCFLTRW_WE));
+			IXGBE_WRITE_REG(hw, IXGBE_FCBUFF, 0);
+			IXGBE_WRITE_REG(hw, IXGBE_FCDMARW,
+					(xid | IXGBE_FCDMARW_WE));
+
+			/* read FCBUFF to check context invalidated */
+			IXGBE_WRITE_REG(hw, IXGBE_FCDMARW,
+					(xid | IXGBE_FCDMARW_RE));
+			fcbuff = IXGBE_READ_REG(hw, IXGBE_FCBUFF);
+
+			spin_unlock_bh(&fcoe->lock);
+			break;
 		}
 
-	if (fcbuff & IXGBE_FCBUFF_VALID)
-		usleep_range(100, 150);
-
-skip_ddpinv:
+		/* guaranteed to be invalidated after 100us */
+		if (fcbuff & IXGBE_FCBUFF_VALID)
+			udelay(100);
+	}
 	if (ddp->sgl)
-		dma_unmap_sg(&adapter->pdev->dev, ddp->sgl, ddp->sgc,
+		dma_unmap_sg(pci_dev_to_dev(adapter->pdev), ddp->sgl, ddp->sgc,
 			     DMA_FROM_DEVICE);
 	if (ddp->pool) {
 		dma_pool_free(ddp->pool, ddp->udl, ddp->udp);
@@ -141,6 +144,7 @@ skip_ddpinv:
 
 	ixgbe_fcoe_clear_ddp(ddp);
 
+out_ddp_put:
 	return len;
 }
 
@@ -173,11 +177,11 @@ static int ixgbe_fcoe_ddp_setup(struct net_device *netdev, u16 xid,
 	u32 fcbuff, fcdmarw, fcfltrw, fcrxctl;
 	dma_addr_t addr = 0;
 
-	if (!netdev || !sgl)
+	if (!netdev || !sgl || !sgc)
 		return 0;
 
 	adapter = netdev_priv(netdev);
-	if (xid >= IXGBE_FCOE_DDP_MAX) {
+	if (xid > netdev->fcoe_ddp_xid) {
 		e_warn(drv, "xid=0x%x out-of-range\n", xid);
 		return 0;
 	}
@@ -191,7 +195,7 @@ static int ixgbe_fcoe_ddp_setup(struct net_device *netdev, u16 xid,
 	ddp = &fcoe->ddp[xid];
 	if (ddp->sgl) {
 		e_err(drv, "xid 0x%x w/ non-null sgl=%p nents=%d\n",
-		      xid, ddp->sgl, ddp->sgc);
+			xid, ddp->sgl, ddp->sgc);
 		return 0;
 	}
 	ixgbe_fcoe_clear_ddp(ddp);
@@ -209,7 +213,7 @@ static int ixgbe_fcoe_ddp_setup(struct net_device *netdev, u16 xid,
 	}
 
 	/* setup dma from scsi command sgl */
-	dmacount = dma_map_sg(&adapter->pdev->dev, sgl, sgc, DMA_FROM_DEVICE);
+	dmacount = dma_map_sg(pci_dev_to_dev(adapter->pdev), sgl, sgc, DMA_FROM_DEVICE);
 	if (dmacount == 0) {
 		e_err(drv, "xid 0x%x DMA map error\n", xid);
 		goto out_noddp;
@@ -267,8 +271,9 @@ static int ixgbe_fcoe_ddp_setup(struct net_device *netdev, u16 xid,
 	lastsize = thisoff + thislen;
 
 	/*
-	 * lastsize can not be buffer len.
+	 * lastsize can not be bufflen.
 	 * If it is then adding another buffer with lastsize = 1.
+	 * Since lastsize is 1 there will be no HW access to this buffer.
 	 */
 	if (lastsize == bufflen) {
 		if (j >= IXGBE_BUFFCNT_MAX) {
@@ -309,7 +314,8 @@ static int ixgbe_fcoe_ddp_setup(struct net_device *netdev, u16 xid,
 		IXGBE_WRITE_REG(hw, IXGBE_FCRXCTRL, fcrxctl);
 	}
 
-	if (hw->mac.type == ixgbe_mac_X550) {
+	switch (hw->mac.type) {
+	case ixgbe_mac_X550:
 		/* X550 does not require DDP lock */
 
 		IXGBE_WRITE_REG(hw, IXGBE_FCDDC(0, xid),
@@ -321,8 +327,14 @@ static int ixgbe_fcoe_ddp_setup(struct net_device *netdev, u16 xid,
 		IXGBE_WRITE_REG(hw, IXGBE_FCDFC(0, xid), IXGBE_FCFLT_VALID);
 		IXGBE_WRITE_REG(hw, IXGBE_FCDFC(1, xid), 0);
 		IXGBE_WRITE_REG(hw, IXGBE_FCDFC(3, xid), fcfltrw);
-	} else {
-		/* DDP lock for indirect DDP context access */
+		/*
+		 * TBD: SMAC and FCID info not available with current
+		 * netdev APIs, add code to pull that from skb later
+		 * and then program that here before enabling DDP context.
+		 */
+		break;
+	default:
+		/* other devices require DDP lock with direct DDP context access */
 		spin_lock_bh(&fcoe->lock);
 
 		IXGBE_WRITE_REG(hw, IXGBE_FCPTRL, ddp->udp & DMA_BIT_MASK(32));
@@ -335,6 +347,7 @@ static int ixgbe_fcoe_ddp_setup(struct net_device *netdev, u16 xid,
 		IXGBE_WRITE_REG(hw, IXGBE_FCFLTRW, fcfltrw);
 
 		spin_unlock_bh(&fcoe->lock);
+		break;
 	}
 
 	return 1;
@@ -344,7 +357,7 @@ out_noddp_free:
 	ixgbe_fcoe_clear_ddp(ddp);
 
 out_noddp_unmap:
-	dma_unmap_sg(&adapter->pdev->dev, sgl, sgc, DMA_FROM_DEVICE);
+	dma_unmap_sg(pci_dev_to_dev(adapter->pdev), sgl, sgc, DMA_FROM_DEVICE);
 out_noddp:
 	put_cpu();
 	return 0;
@@ -370,6 +383,7 @@ int ixgbe_fcoe_ddp_get(struct net_device *netdev, u16 xid,
 	return ixgbe_fcoe_ddp_setup(netdev, xid, sgl, sgc, 0);
 }
 
+#ifdef HAVE_NETDEV_OPS_FCOE_DDP_TARGET
 /**
  * ixgbe_fcoe_ddp_target - called to set up ddp context in target mode
  * @netdev: the corresponding net_device
@@ -386,11 +400,12 @@ int ixgbe_fcoe_ddp_get(struct net_device *netdev, u16 xid,
  * Returns : 1 for success and 0 for no ddp
  */
 int ixgbe_fcoe_ddp_target(struct net_device *netdev, u16 xid,
-			    struct scatterlist *sgl, unsigned int sgc)
+			  struct scatterlist *sgl, unsigned int sgc)
 {
 	return ixgbe_fcoe_ddp_setup(netdev, xid, sgl, sgc, 1);
 }
 
+#endif /* HAVE_NETDEV_OPS_FCOE_DDP_TARGET */
 /**
  * ixgbe_fcoe_ddp - check ddp status and mark it done
  * @adapter: ixgbe adapter
@@ -399,7 +414,7 @@ int ixgbe_fcoe_ddp_target(struct net_device *netdev, u16 xid,
  *
  * This checks ddp status.
  *
- * Returns : < 0 indicates an error or not a FCiE ddp, 0 indicates
+ * Returns : < 0 indicates an error or not a FCoE ddp, 0 indicates
  * not passing the skb to ULD, > 0 indicates is the length of data
  * being ddped.
  */
@@ -407,14 +422,12 @@ int ixgbe_fcoe_ddp(struct ixgbe_adapter *adapter,
 		   union ixgbe_adv_rx_desc *rx_desc,
 		   struct sk_buff *skb)
 {
-	int rc = -EINVAL;
-	struct ixgbe_fcoe *fcoe;
+	struct ixgbe_fcoe *fcoe = &adapter->fcoe;
 	struct ixgbe_fcoe_ddp *ddp;
 	struct fc_frame_header *fh;
-	struct fcoe_crc_eof *crc;
+	int rc = -EINVAL, ddp_max;
 	__le32 fcerr = ixgbe_test_staterr(rx_desc, IXGBE_RXDADV_ERR_FCERR);
 	__le32 ddp_err;
-	int ddp_max;
 	u32 fctl;
 	u16 xid;
 
@@ -423,35 +436,36 @@ int ixgbe_fcoe_ddp(struct ixgbe_adapter *adapter,
 	else
 		skb->ip_summed = CHECKSUM_UNNECESSARY;
 
-	if (eth_hdr(skb)->h_proto == htons(ETH_P_8021Q))
-		fh = (struct fc_frame_header *)(skb->data +
-			sizeof(struct vlan_hdr) + sizeof(struct fcoe_hdr));
-	else
-		fh = (struct fc_frame_header *)(skb->data +
-			sizeof(struct fcoe_hdr));
+	/* verify header contains at least the FCOE header */
+	BUG_ON(skb_headlen(skb) < FCOE_HEADER_LEN);
+
+	fh = (struct fc_frame_header *)(skb->data + sizeof(struct fcoe_hdr));
+
+	if (skb->protocol == htons(ETH_P_8021Q))
+		fh = (struct fc_frame_header *)((char *)fh + VLAN_HLEN);
 
 	fctl = ntoh24(fh->fh_f_ctl);
 	if (fctl & FC_FC_EX_CTX)
-		xid =  be16_to_cpu(fh->fh_ox_id);
+		xid =  ntohs(fh->fh_ox_id);
 	else
-		xid =  be16_to_cpu(fh->fh_rx_id);
+		xid =  ntohs(fh->fh_rx_id);
 
 	ddp_max = IXGBE_FCOE_DDP_MAX;
 	/* X550 has different DDP Max limit */
 	if (adapter->hw.mac.type == ixgbe_mac_X550)
 		ddp_max = IXGBE_FCOE_DDP_MAX_X550;
+
 	if (xid >= ddp_max)
-		return -EINVAL;
+		goto ddp_out;
 
-	fcoe = &adapter->fcoe;
 	ddp = &fcoe->ddp[xid];
 	if (!ddp->udl)
-		return -EINVAL;
+		goto ddp_out;
 
 	ddp_err = ixgbe_test_staterr(rx_desc, IXGBE_RXDADV_ERR_FCEOFE |
 					      IXGBE_RXDADV_ERR_FCERR);
 	if (ddp_err)
-		return -EINVAL;
+		goto ddp_out;
 
 	switch (ixgbe_test_staterr(rx_desc, IXGBE_RXDADV_STAT_FCSTAT)) {
 	/* return 0 to bypass going to ULD for DDPed data */
@@ -462,7 +476,7 @@ int ixgbe_fcoe_ddp(struct ixgbe_adapter *adapter,
 		break;
 	/* unmap the sg list when FCPRSP is received */
 	case cpu_to_le32(IXGBE_RXDADV_STAT_FCSTAT_FCPRSP):
-		dma_unmap_sg(&adapter->pdev->dev, ddp->sgl,
+		dma_unmap_sg(pci_dev_to_dev(adapter->pdev), ddp->sgl,
 			     ddp->sgc, DMA_FROM_DEVICE);
 		ddp->err = ddp_err;
 		ddp->sgl = NULL;
@@ -490,11 +504,12 @@ int ixgbe_fcoe_ddp(struct ixgbe_adapter *adapter,
 	 */
 	if ((fh->fh_r_ctl == FC_RCTL_DD_SOL_DATA) &&
 	    (fctl & FC_FC_END_SEQ)) {
+		struct fcoe_crc_eof *crc;
 		skb_linearize(skb);
 		crc = (struct fcoe_crc_eof *)skb_put(skb, sizeof(*crc));
 		crc->fcoe_eof = FC_EOF_T;
 	}
-
+ddp_out:
 	return rc;
 }
 
@@ -518,13 +533,16 @@ int ixgbe_fso(struct ixgbe_ring *tx_ring,
 	u32 fcoe_sof_eof = 0;
 	u32 mss_l4len_idx;
 	u8 sof, eof;
+	u32 type_tucmd = IXGBE_ADVTXT_TUCMD_FCOE;
 
-	if (skb_is_gso(skb) && (skb_shinfo(skb)->gso_type != SKB_GSO_FCOE)) {
-		dev_err(tx_ring->dev, "Wrong gso type %d:expecting SKB_GSO_FCOE\n",
-			skb_shinfo(skb)->gso_type);
+#ifdef NETIF_F_FSO
+	if (skb_is_gso(skb) && skb_shinfo(skb)->gso_type != SKB_GSO_FCOE) {
+		dev_err(tx_ring->dev, "Wrong gso type %d:expecting "
+			"SKB_GSO_FCOE\n", skb_shinfo(skb)->gso_type);
 		return -EINVAL;
 	}
 
+#endif
 	/* resets the header to point fcoe/fc */
 	skb_set_network_header(skb, skb->mac_len);
 	skb_set_transport_header(skb, skb->mac_len +
@@ -593,6 +611,8 @@ int ixgbe_fso(struct ixgbe_ring *tx_ring,
 					       skb_shinfo(skb)->gso_size);
 		first->bytecount += (first->gso_segs - 1) * *hdr_len;
 		first->tx_flags |= IXGBE_TX_FLAGS_TSO;
+		/* Hardware expects L4T to be RSV for FCoE TSO */
+		type_tucmd |= IXGBE_ADVTXD_TUCMD_L4T_RSV;
 	}
 
 	/* set flag indicating FCOE to ixgbe_tx_map call */
@@ -610,7 +630,7 @@ int ixgbe_fso(struct ixgbe_ring *tx_ring,
 
 	/* write context desc */
 	ixgbe_tx_ctxtdesc(tx_ring, vlan_macip_lens, fcoe_sof_eof,
-			  IXGBE_ADVTXT_TUCMD_FCOE, mss_l4len_idx);
+			  type_tucmd, mss_l4len_idx);
 
 	return 0;
 }
@@ -620,8 +640,7 @@ static void ixgbe_fcoe_dma_pool_free(struct ixgbe_fcoe *fcoe, unsigned int cpu)
 	struct ixgbe_fcoe_ddp_pool *ddp_pool;
 
 	ddp_pool = per_cpu_ptr(fcoe->ddp_pool, cpu);
-	if (ddp_pool->pool)
-		dma_pool_destroy(ddp_pool->pool);
+	dma_pool_destroy(ddp_pool->pool);
 	ddp_pool->pool = NULL;
 }
 
@@ -633,7 +652,7 @@ static int ixgbe_fcoe_dma_pool_alloc(struct ixgbe_fcoe *fcoe,
 	struct dma_pool *pool;
 	char pool_name[32];
 
-	snprintf(pool_name, 32, "ixgbe_fcoe_ddp_%u", cpu);
+	snprintf(pool_name, 32, "ixgbe_fcoe_ddp_%d", cpu);
 
 	pool = dma_pool_create(pool_name, dev, IXGBE_FCPTR_MAX,
 			       IXGBE_FCPTR_ALIGN, PAGE_SIZE);
@@ -660,11 +679,12 @@ void ixgbe_configure_fcoe(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_ring_feature *fcoe = &adapter->ring_feature[RING_F_FCOE];
 	struct ixgbe_hw *hw = &adapter->hw;
-	int i, fcoe_q, fcoe_i, fcoe_q_h = 0;
-	int fcreta_size;
+	int i, fcoe_i;
+	u32 fcoe_q, fcoe_q_h = 0;
 	u32 etqf;
+	int fcreta_size;
 
-	/* Minimal functionality for FCoE requires at least CRC offloads */
+	/* Minimal funcionality for FCoE requires at least CRC offloads */
 	if (!(adapter->netdev->features & NETIF_F_FCOE_CRC))
 		return;
 
@@ -677,7 +697,7 @@ void ixgbe_configure_fcoe(struct ixgbe_adapter *adapter)
 	IXGBE_WRITE_REG(hw, IXGBE_ETQF(IXGBE_ETQF_FILTER_FCOE), etqf);
 	IXGBE_WRITE_REG(hw, IXGBE_ETQS(IXGBE_ETQF_FILTER_FCOE), 0);
 
-	/* leave registers un-configured if FCoE is disabled */
+	/* leave remaining registers unconfigued if FCoE is disabled */
 	if (!(adapter->flags & IXGBE_FLAG_FCOE_ENABLED))
 		return;
 
@@ -694,9 +714,9 @@ void ixgbe_configure_fcoe(struct ixgbe_adapter *adapter)
 			fcoe_q_h = (fcoe_q_h << IXGBE_FCRETA_ENTRY_HIGH_SHIFT) &
 				   IXGBE_FCRETA_ENTRY_HIGH_MASK;
 		}
-
 		fcoe_i = fcoe->offset + (i % fcoe->indices);
-		fcoe_i &= IXGBE_FCRETA_ENTRY_MASK;
+		if (fcoe_i >= MAX_RX_QUEUES)
+			fcoe_i = MAX_RX_QUEUES - 1;
 		fcoe_q = adapter->rx_ring[fcoe_i]->reg_idx;
 		fcoe_q |= fcoe_q_h;
 		IXGBE_WRITE_REG(hw, IXGBE_FCRETA(i), fcoe_q);
@@ -751,7 +771,7 @@ void ixgbe_free_fcoe_ddp_resources(struct ixgbe_adapter *adapter)
 	for_each_possible_cpu(cpu)
 		ixgbe_fcoe_dma_pool_free(fcoe, cpu);
 
-	dma_unmap_single(&adapter->pdev->dev,
+	dma_unmap_single(pci_dev_to_dev(adapter->pdev),
 			 fcoe->extra_ddp_buffer_dma,
 			 IXGBE_FCBUFF_MIN,
 			 DMA_FROM_DEVICE);
@@ -772,7 +792,7 @@ void ixgbe_free_fcoe_ddp_resources(struct ixgbe_adapter *adapter)
 int ixgbe_setup_fcoe_ddp_resources(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_fcoe *fcoe = &adapter->fcoe;
-	struct device *dev = &adapter->pdev->dev;
+	struct device *dev = pci_dev_to_dev(adapter->pdev);
 	void *buffer;
 	dma_addr_t dma;
 	unsigned int cpu;
@@ -783,8 +803,10 @@ int ixgbe_setup_fcoe_ddp_resources(struct ixgbe_adapter *adapter)
 
 	/* Extra buffer to be shared by all DDPs for HW work around */
 	buffer = kmalloc(IXGBE_FCBUFF_MIN, GFP_ATOMIC);
-	if (!buffer)
+	if (!buffer) {
+		e_err(drv, "failed to allocate extra DDP buffer\n");
 		return -ENOMEM;
+	}
 
 	dma = dma_map_single(dev, buffer, IXGBE_FCBUFF_MIN, DMA_FROM_DEVICE);
 	if (dma_mapping_error(dev, dma)) {
@@ -810,7 +832,11 @@ int ixgbe_setup_fcoe_ddp_resources(struct ixgbe_adapter *adapter)
 	return 0;
 }
 
+#ifndef HAVE_NETDEV_OPS_FCOE_ENABLE
+int ixgbe_fcoe_ddp_enable(struct ixgbe_adapter *adapter)
+#else
 static int ixgbe_fcoe_ddp_enable(struct ixgbe_adapter *adapter)
+#endif
 {
 	struct ixgbe_fcoe *fcoe = &adapter->fcoe;
 
@@ -825,6 +851,7 @@ static int ixgbe_fcoe_ddp_enable(struct ixgbe_adapter *adapter)
 	}
 
 	adapter->netdev->fcoe_ddp_xid = IXGBE_FCOE_DDP_MAX - 1;
+
 	/* X550 has different DDP Max limit */
 	if (adapter->hw.mac.type == ixgbe_mac_X550)
 		adapter->netdev->fcoe_ddp_xid = IXGBE_FCOE_DDP_MAX_X550 - 1;
@@ -832,7 +859,11 @@ static int ixgbe_fcoe_ddp_enable(struct ixgbe_adapter *adapter)
 	return 0;
 }
 
+#ifndef HAVE_NETDEV_OPS_FCOE_ENABLE
+void ixgbe_fcoe_ddp_disable(struct ixgbe_adapter *adapter)
+#else
 static void ixgbe_fcoe_ddp_disable(struct ixgbe_adapter *adapter)
+#endif
 {
 	struct ixgbe_fcoe *fcoe = &adapter->fcoe;
 
@@ -845,6 +876,7 @@ static void ixgbe_fcoe_ddp_disable(struct ixgbe_adapter *adapter)
 	fcoe->ddp_pool = NULL;
 }
 
+#ifdef HAVE_NETDEV_OPS_FCOE_ENABLE
 /**
  * ixgbe_fcoe_enable - turn on FCoE offload feature
  * @netdev: the corresponding netdev
@@ -932,7 +964,28 @@ int ixgbe_fcoe_disable(struct net_device *netdev)
 
 	return 0;
 }
+#endif /* HAVE_NETDEV_OPS_FCOE_ENABLE */
 
+#if IS_ENABLED(CONFIG_DCB)
+#ifdef HAVE_DCBNL_OPS_GETAPP
+/**
+ * ixgbe_fcoe_getapp - retrieves current user priority bitmap for FCoE
+ * @netdev: the corresponding net_device
+ *
+ * Finds out the corresponding user priority bitmap from the current
+ * traffic class that FCoE belongs to. Returns 0 as the invalid user
+ * priority bitmap to indicate an error.
+ *
+ * Returns : 802.1p user priority bitmap for FCoE
+ */
+u8 ixgbe_fcoe_getapp(struct net_device *netdev)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	return 1 << adapter->fcoe.up;
+}
+#endif /* HAVE_DCBNL_OPS_GETAPP */
+#endif /* CONFIG_DCB */
+#ifdef HAVE_NETDEV_OPS_FCOE_GETWWN
 /**
  * ixgbe_fcoe_get_wwn - get world wide name for the node or the port
  * @netdev : ixgbe adapter
@@ -947,6 +1000,7 @@ int ixgbe_fcoe_disable(struct net_device *netdev)
  */
 int ixgbe_fcoe_get_wwn(struct net_device *netdev, u64 *wwn, int type)
 {
+	int rc = -EINVAL;
 	u16 prefix = 0xffff;
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	struct ixgbe_mac_info *mac = &adapter->hw.mac;
@@ -971,94 +1025,12 @@ int ixgbe_fcoe_get_wwn(struct net_device *netdev, u64 *wwn, int type)
 		       ((u64) mac->san_addr[3] << 16) |
 		       ((u64) mac->san_addr[4] << 8)  |
 		       ((u64) mac->san_addr[5]);
-		return 0;
-	}
-	return -EINVAL;
-}
-
-/**
- * ixgbe_fcoe_get_hbainfo - get FCoE HBA information
- * @netdev : ixgbe adapter
- * @info : HBA information
- *
- * Returns ixgbe HBA information
- *
- * Returns : 0 on success
- */
-int ixgbe_fcoe_get_hbainfo(struct net_device *netdev,
-			   struct netdev_fcoe_hbainfo *info)
-{
-	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	struct ixgbe_hw *hw = &adapter->hw;
-	int i, pos;
-	u8 buf[8];
-
-	if (!info)
-		return -EINVAL;
-
-	/* Don't return information on unsupported devices */
-	if (hw->mac.type != ixgbe_mac_82599EB &&
-	    hw->mac.type != ixgbe_mac_X540)
-		return -EINVAL;
-
-	/* Manufacturer */
-	snprintf(info->manufacturer, sizeof(info->manufacturer),
-		 "Intel Corporation");
-
-	/* Serial Number */
-
-	/* Get the PCI-e Device Serial Number Capability */
-	pos = pci_find_ext_capability(adapter->pdev, PCI_EXT_CAP_ID_DSN);
-	if (pos) {
-		pos += 4;
-		for (i = 0; i < 8; i++)
-			pci_read_config_byte(adapter->pdev, pos + i, &buf[i]);
-
-		snprintf(info->serial_number, sizeof(info->serial_number),
-			 "%02X%02X%02X%02X%02X%02X%02X%02X",
-			 buf[7], buf[6], buf[5], buf[4],
-			 buf[3], buf[2], buf[1], buf[0]);
-	} else
-		snprintf(info->serial_number, sizeof(info->serial_number),
-			 "Unknown");
-
-	/* Hardware Version */
-	snprintf(info->hardware_version,
-		 sizeof(info->hardware_version),
-		 "Rev %d", hw->revision_id);
-	/* Driver Name/Version */
-	snprintf(info->driver_version,
-		 sizeof(info->driver_version),
-		 "%s v%s",
-		 ixgbe_driver_name,
-		 ixgbe_driver_version);
-	/* Firmware Version */
-	snprintf(info->firmware_version,
-		 sizeof(info->firmware_version),
-		 "0x%08x",
-		 (adapter->eeprom_verh << 16) |
-		  adapter->eeprom_verl);
-
-	/* Model */
-	if (hw->mac.type == ixgbe_mac_82599EB) {
-		snprintf(info->model,
-			 sizeof(info->model),
-			 "Intel 82599");
-	} else {
-		snprintf(info->model,
-			 sizeof(info->model),
-			 "Intel X540");
+		rc = 0;
 	}
-
-	/* Model Description */
-	snprintf(info->model_description,
-		 sizeof(info->model_description),
-		 "%s",
-		 ixgbe_default_device_descr);
-
-	return 0;
+	return rc;
 }
 
+#endif /* HAVE_NETDEV_OPS_FCOE_GETWWN */
 /**
  * ixgbe_fcoe_get_tc - get the current TC that fcoe is mapped to
  * @adapter - pointer to the device adapter structure
@@ -1067,9 +1039,6 @@ int ixgbe_fcoe_get_hbainfo(struct net_device *netdev,
  */
 u8 ixgbe_fcoe_get_tc(struct ixgbe_adapter *adapter)
 {
-#ifdef CONFIG_IXGBE_DCB
 	return netdev_get_prio_tc_map(adapter->netdev, adapter->fcoe.up);
-#else
-	return 0;
-#endif
 }
+#endif /* CONFIG_FCOE */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_fcoe.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_fcoe.h
index 3838587..08de8d3 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_fcoe.h
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_fcoe.h
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,8 +22,10 @@
 
 *******************************************************************************/
 
-#ifndef _IXGBE_FCOE_H
-#define _IXGBE_FCOE_H
+#ifndef _IXGBE_FCOE_H_
+#define _IXGBE_FCOE_H_
+
+#if IS_ENABLED(CONFIG_FCOE)
 
 #include <scsi/fc/fc_fs.h>
 #include <scsi/fc/fc_fcoe.h>
@@ -38,7 +36,7 @@
 /* ddp user buffer */
 #define IXGBE_BUFFCNT_MAX	256	/* 8 bits bufcnt */
 #define IXGBE_FCPTR_ALIGN	16
-#define IXGBE_FCPTR_MAX	(IXGBE_BUFFCNT_MAX * sizeof(dma_addr_t))
+#define IXGBE_FCPTR_MAX		(IXGBE_BUFFCNT_MAX * sizeof(dma_addr_t))
 #define IXGBE_FCBUFF_4KB	0x0
 #define IXGBE_FCBUFF_8KB	0x1
 #define IXGBE_FCBUFF_16KB	0x2
@@ -48,11 +46,16 @@
 #define IXGBE_FCOE_DDP_MAX	512	/* 9 bits xid */
 #define IXGBE_FCOE_DDP_MAX_X550	2048	/* 11 bits xid */
 
-/* Default traffic class to use for FCoE */
-#define IXGBE_FCOE_DEFTC	3
+/* Default user priority to use for FCoE */
+#define IXGBE_FCOE_DEFUP	3
 
 /* fcerr */
-#define IXGBE_FCERR_BADCRC       0x00100000
+#define IXGBE_FCERR_BADCRC	0x00100000
+#define IXGBE_FCERR_EOFSOF	0x00200000
+#define IXGBE_FCERR_NOFIRST	0x00300000
+#define IXGBE_FCERR_OOOSEQ	0x00400000
+#define IXGBE_FCERR_NODMA	0x00500000
+#define IXGBE_FCERR_PKTLOST	0x00600000
 
 /* FCoE DDP for target mode */
 #define __IXGBE_FCOE_TARGET	1
@@ -83,6 +86,8 @@ struct ixgbe_fcoe {
 	dma_addr_t extra_ddp_buffer_dma;
 	unsigned long mode;
 	u8 up;
+	u8 up_set;
 };
+#endif /* CONFIG_FCOE */
 
 #endif /* _IXGBE_FCOE_H */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_hv_vf.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_hv_vf.c
new file mode 100644
index 00000000..2786463
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_hv_vf.c
@@ -0,0 +1,210 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#include "ixgbe_hv_vf.h"
+
+/**
+ * Hyper-V variant - just a stub.
+ */
+s32 ixgbevf_hv_update_mc_addr_list_vf(struct ixgbe_hw *hw, u8 *mc_addr_list,
+				 u32 mc_addr_count, ixgbe_mc_addr_itr next,
+				 bool clear)
+{
+	UNREFERENCED_5PARAMETER(hw, mc_addr_list, mc_addr_count, next, clear);
+
+	return IXGBE_ERR_FEATURE_NOT_SUPPORTED;
+}
+
+/**
+ * Hyper-V variant - just a stub.
+ */
+s32 ixgbevf_hv_update_xcast_mode(struct ixgbe_hw *hw, int xcast_mode)
+{
+	UNREFERENCED_2PARAMETER(hw, xcast_mode);
+
+	return IXGBE_ERR_FEATURE_NOT_SUPPORTED;
+}
+
+/**
+ * Hyper-V variant - just a stub.
+ */
+s32 ixgbevf_hv_set_vfta_vf(struct ixgbe_hw *hw, u32 vlan, u32 vind,
+				  bool vlan_on, bool vlvf_bypass)
+{
+	UNREFERENCED_5PARAMETER(hw, vlan, vind, vlan_on, vlvf_bypass);
+
+	return IXGBE_ERR_FEATURE_NOT_SUPPORTED;
+}
+
+s32 ixgbevf_hv_set_uc_addr_vf(struct ixgbe_hw *hw, u32 index, u8 *addr)
+{
+	UNREFERENCED_3PARAMETER(hw, index, addr);
+
+	return IXGBE_ERR_FEATURE_NOT_SUPPORTED;
+}
+
+/**
+ * Hyper-V variant; there is no mailbox communication.
+ */
+s32 ixgbevf_hv_check_mac_link_vf(struct ixgbe_hw *hw,
+					ixgbe_link_speed *speed,
+					bool *link_up,
+					bool autoneg_wait_to_complete)
+{
+	struct ixgbe_mbx_info *mbx = &hw->mbx;
+	struct ixgbe_mac_info *mac = &hw->mac;
+	u32 links_reg;
+	UNREFERENCED_1PARAMETER(autoneg_wait_to_complete);
+
+	/* If we were hit with a reset drop the link */
+	if (!mbx->ops.check_for_rst(hw, 0) || !mbx->timeout)
+		mac->get_link_status = true;
+
+	if (!mac->get_link_status)
+		goto out;
+
+	/* if link status is down no point in checking to see if pf is up */
+	links_reg = IXGBE_READ_REG(hw, IXGBE_VFLINKS);
+	if (!(links_reg & IXGBE_LINKS_UP))
+		goto out;
+
+	/* for SFP+ modules and DA cables on 82599 it can take up to 500usecs
+	 * before the link status is correct
+	 */
+	if (mac->type == ixgbe_mac_82599_vf) {
+		int i;
+
+		for (i = 0; i < 5; i++) {
+			udelay(100);
+			links_reg = IXGBE_READ_REG(hw, IXGBE_VFLINKS);
+
+			if (!(links_reg & IXGBE_LINKS_UP))
+				goto out;
+		}
+	}
+
+	switch (links_reg & IXGBE_LINKS_SPEED_82599) {
+	case IXGBE_LINKS_SPEED_10G_82599:
+		*speed = IXGBE_LINK_SPEED_10GB_FULL;
+		if (hw->mac.type >= ixgbe_mac_X550) {
+			if (links_reg & IXGBE_LINKS_SPEED_NON_STD)
+				*speed = IXGBE_LINK_SPEED_2_5GB_FULL;
+		}
+		break;
+	case IXGBE_LINKS_SPEED_1G_82599:
+		*speed = IXGBE_LINK_SPEED_1GB_FULL;
+		break;
+	case IXGBE_LINKS_SPEED_100_82599:
+		*speed = IXGBE_LINK_SPEED_100_FULL;
+		if (hw->mac.type == ixgbe_mac_X550) {
+			if (links_reg & IXGBE_LINKS_SPEED_NON_STD)
+				*speed = IXGBE_LINK_SPEED_5GB_FULL;
+		}
+		break;
+	case IXGBE_LINKS_SPEED_10_X550EM_A:
+		*speed = IXGBE_LINK_SPEED_UNKNOWN;
+		/* Reserved for pre-x550 devices */
+		if (hw->mac.type >= ixgbe_mac_X550)
+			*speed = IXGBE_LINK_SPEED_10_FULL;
+		break;
+	default:
+		*speed = IXGBE_LINK_SPEED_UNKNOWN;
+	}
+
+	/* if we passed all the tests above then the link is up and we no
+	 * longer need to check for link
+	 */
+	mac->get_link_status = false;
+
+out:
+	*link_up = !mac->get_link_status;
+	return IXGBE_SUCCESS;
+}
+
+/**
+ * ixgbevf_hv_set_rlpml_vf - Set the maximum receive packet length
+ * @hw: pointer to the HW structure
+ * @max_size: value to assign to max frame size
+ * Hyper-V variant.
+ **/
+s32 ixgbevf_hv_set_rlpml_vf(struct ixgbe_hw *hw, u16 max_size)
+{
+	u32 reg;
+
+	/* If we are on Hyper-V, we implement this functionality
+	 * differently.
+	 */
+	reg =  IXGBE_READ_REG(hw, IXGBE_VFRXDCTL(0));
+	/* CRC == 4 */
+	reg |= ((max_size + 4) | IXGBE_RXDCTL_RLPML_EN);
+	IXGBE_WRITE_REG(hw, IXGBE_VFRXDCTL(0), reg);
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbevf_hv_negotiate_api_version_vf - Negotiate supported API version
+ *  @hw: pointer to the HW structure
+ *  @api: integer containing requested API version
+ *  Hyper-V version - only ixgbe_mbox_api_10 supported.
+ **/
+int ixgbevf_hv_negotiate_api_version_vf(struct ixgbe_hw *hw, int api)
+{
+	UNREFERENCED_1PARAMETER(hw);
+
+	/* Hyper-V only supports api version ixgbe_mbox_api_10 */
+	if (api != ixgbe_mbox_api_10)
+		return IXGBE_ERR_INVALID_ARGUMENT;
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbevf_hv_init_ops_vf - Initialize the pointers for vf
+ *  @hw: pointer to hardware structure
+ *
+ *  This will assign function pointers, adapter-specific functions can
+ *  override the assignment of generic function pointers by assigning
+ *  their own adapter-specific function pointers.
+ *  Does not touch the hardware.
+ **/
+s32 ixgbevf_hv_init_ops_vf(struct ixgbe_hw *hw)
+{
+	/* Set defaults for VF then override applicable Hyper-V
+	 * specific functions
+	 */
+	ixgbe_init_ops_vf(hw);
+
+	hw->mac.ops.reset_hw = ixgbevf_hv_reset_hw_vf;
+	hw->mac.ops.check_link = ixgbevf_hv_check_mac_link_vf;
+	hw->mac.ops.negotiate_api_version = ixgbevf_hv_negotiate_api_version_vf;
+	hw->mac.ops.set_rar = ixgbevf_hv_set_rar_vf;
+	hw->mac.ops.update_mc_addr_list = ixgbevf_hv_update_mc_addr_list_vf;
+	hw->mac.ops.update_xcast_mode = ixgbevf_hv_update_xcast_mode;
+	hw->mac.ops.set_uc_addr = ixgbevf_hv_set_uc_addr_vf;
+	hw->mac.ops.set_vfta = ixgbevf_hv_set_vfta_vf;
+	hw->mac.ops.set_rlpml = ixgbevf_hv_set_rlpml_vf;
+
+	return IXGBE_SUCCESS;
+}
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_hv_vf.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_hv_vf.h
new file mode 100644
index 00000000..387ed1f
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_hv_vf.h
@@ -0,0 +1,51 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#ifndef _IXGBE_HV_VF_H_
+#define _IXGBE_HV_VF_H_
+
+/* On Hyper-V, to reset, we need to read from this offset
+ * from the PCI config space. This is the mechanism used on
+ * Hyper-V to support PF/VF communication.
+ */
+#define IXGBE_HV_RESET_OFFSET           0x201
+
+#include "ixgbe_vf.h"
+
+s32 ixgbevf_hv_check_mac_link_vf(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
+				 bool *link_up, bool autoneg_wait_to_complete);
+s32 ixgbevf_hv_set_uc_addr_vf(struct ixgbe_hw *hw, u32 index, u8 *addr);
+s32 ixgbevf_hv_update_mc_addr_list_vf(struct ixgbe_hw *hw, u8 *mc_addr_list,
+				      u32 mc_addr_count, ixgbe_mc_addr_itr,
+				      bool clear);
+s32 ixgbevf_hv_update_xcast_mode(struct ixgbe_hw *hw, int xcast_mode);
+s32 ixgbevf_hv_set_vfta_vf(struct ixgbe_hw *hw, u32 vlan, u32 vind,
+			   bool vlan_on, bool vlvf_bypass);
+s32 ixgbevf_hv_set_rlpml_vf(struct ixgbe_hw *hw, u16 max_size);
+int ixgbevf_hv_negotiate_api_version_vf(struct ixgbe_hw *hw, int api);
+
+extern s32 ixgbevf_hv_reset_hw_vf(struct ixgbe_hw *hw);
+extern s32 ixgbevf_hv_set_rar_vf(struct ixgbe_hw *hw, u32 index, u8 *addr,
+				 u32 vmdq, u32 enable_addr);
+#endif /* _IXGBE_HV_VF_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_lib.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_lib.c
index f0de09d..2a0d91d 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_lib.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_lib.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -29,52 +25,79 @@
 #include "ixgbe.h"
 #include "ixgbe_sriov.h"
 
-#ifdef CONFIG_IXGBE_DCB
+#ifdef HAVE_TX_MQ
 /**
- * ixgbe_cache_ring_dcb_sriov - Descriptor ring to register mapping for SR-IOV
+ * ixgbe_cache_ring_dcb_vmdq - Descriptor ring to register mapping for VMDq
  * @adapter: board private structure to initialize
  *
- * Cache the descriptor ring offsets for SR-IOV to the assigned rings.  It
+ * Cache the descriptor ring offsets for VMDq to the assigned rings.  It
  * will also try to cache the proper offsets if RSS/FCoE are enabled along
  * with VMDq.
  *
  **/
-static bool ixgbe_cache_ring_dcb_sriov(struct ixgbe_adapter *adapter)
+static bool ixgbe_cache_ring_dcb_vmdq(struct ixgbe_adapter *adapter)
 {
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	struct ixgbe_ring_feature *fcoe = &adapter->ring_feature[RING_F_FCOE];
-#endif /* IXGBE_FCOE */
+#endif /* CONFIG_FCOE */
 	struct ixgbe_ring_feature *vmdq = &adapter->ring_feature[RING_F_VMDQ];
 	int i;
 	u16 reg_idx;
 	u8 tcs = netdev_get_num_tc(adapter->netdev);
 
-	/* verify we have DCB queueing enabled before proceeding */
+	/* verify we have DCB enabled before proceeding */
 	if (tcs <= 1)
 		return false;
 
 	/* verify we have VMDq enabled before proceeding */
-	if (!(adapter->flags & IXGBE_FLAG_SRIOV_ENABLED))
+	if (!(adapter->flags & IXGBE_FLAG_VMDQ_ENABLED))
 		return false;
 
-	/* start at VMDq register offset for SR-IOV enabled setups */
-	reg_idx = vmdq->offset * __ALIGN_MASK(1, ~vmdq->mask);
-	for (i = 0; i < adapter->num_rx_queues; i++, reg_idx++) {
-		/* If we are greater than indices move to next pool */
-		if ((reg_idx & ~vmdq->mask) >= tcs)
-			reg_idx = __ALIGN_MASK(reg_idx, ~vmdq->mask);
-		adapter->rx_ring[i]->reg_idx = reg_idx;
-	}
+	switch (adapter->hw.mac.type) {
+	case ixgbe_mac_82598EB:
+		/*
+		 * The bits on the 82598 are reversed compared to the other
+		 * adapters.  The DCB bits are the higher order bits and the
+		 * lower bits belong to the VMDq pool.  In order to sort
+		 * this out we have to swap the bits to get the correct layout
+		 */
+		for (i = 0; i < adapter->num_rx_queues; i++) {
+			reg_idx = ((i >> 3) | (i << 3)) & 0x3F;
+			adapter->rx_ring[i]->reg_idx = reg_idx;
+		}
+		for (i = 0; i < adapter->num_tx_queues; i++) {
+			reg_idx = ((i >> 4) | (i << 2)) & 0x1F;
+			adapter->tx_ring[i]->reg_idx = reg_idx;
+		}
+		break;
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		/* start at VMDq register offset for SR-IOV enabled setups */
+		reg_idx = vmdq->offset * __ALIGN_MASK(1, ~vmdq->mask);
+		for (i = 0; i < adapter->num_rx_queues; i++, reg_idx++) {
+			/* If we are greater than indices move to next pool */
+			if ((reg_idx & ~vmdq->mask) >= tcs)
+				reg_idx = __ALIGN_MASK(reg_idx, ~vmdq->mask);
+			adapter->rx_ring[i]->reg_idx = reg_idx;
+		}
 
-	reg_idx = vmdq->offset * __ALIGN_MASK(1, ~vmdq->mask);
-	for (i = 0; i < adapter->num_tx_queues; i++, reg_idx++) {
-		/* If we are greater than indices move to next pool */
-		if ((reg_idx & ~vmdq->mask) >= tcs)
-			reg_idx = __ALIGN_MASK(reg_idx, ~vmdq->mask);
-		adapter->tx_ring[i]->reg_idx = reg_idx;
+		reg_idx = vmdq->offset * __ALIGN_MASK(1, ~vmdq->mask);
+		for (i = 0; i < adapter->num_tx_queues; i++, reg_idx++) {
+			/* If we are greater than indices move to next pool */
+			if ((reg_idx & ~vmdq->mask) >= tcs)
+				reg_idx = __ALIGN_MASK(reg_idx, ~vmdq->mask);
+			adapter->tx_ring[i]->reg_idx = reg_idx;
+		}
+
+		break;
+	default:
+		break;
 	}
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* nothing to do if FCoE is disabled */
 	if (!(adapter->flags & IXGBE_FLAG_FCOE_ENABLED))
 		return true;
@@ -102,8 +125,8 @@ static bool ixgbe_cache_ring_dcb_sriov(struct ixgbe_adapter *adapter)
 			reg_idx++;
 		}
 	}
+#endif /* CONFIG_FCOE */
 
-#endif /* IXGBE_FCOE */
 	return true;
 }
 
@@ -111,8 +134,8 @@ static bool ixgbe_cache_ring_dcb_sriov(struct ixgbe_adapter *adapter)
 static void ixgbe_get_first_reg_idx(struct ixgbe_adapter *adapter, u8 tc,
 				    unsigned int *tx, unsigned int *rx)
 {
-	struct net_device *dev = adapter->netdev;
 	struct ixgbe_hw *hw = &adapter->hw;
+	struct net_device *dev = adapter->netdev;
 	u8 num_tcs = netdev_get_num_tc(dev);
 
 	*tx = 0;
@@ -128,6 +151,7 @@ static void ixgbe_get_first_reg_idx(struct ixgbe_adapter *adapter, u8 tc,
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+case ixgbe_mac_X550EM_a:
 		if (num_tcs > 4) {
 			/*
 			 * TCs    : TC0/1 TC2/3 TC4-7
@@ -167,12 +191,11 @@ static void ixgbe_get_first_reg_idx(struct ixgbe_adapter *adapter, u8 tc,
  **/
 static bool ixgbe_cache_ring_dcb(struct ixgbe_adapter *adapter)
 {
-	struct net_device *dev = adapter->netdev;
-	unsigned int tx_idx, rx_idx;
 	int tc, offset, rss_i, i;
+	unsigned int tx_idx, rx_idx;
+	struct net_device *dev = adapter->netdev;
 	u8 num_tcs = netdev_get_num_tc(dev);
 
-	/* verify we have DCB queueing enabled before proceeding */
 	if (num_tcs <= 1)
 		return false;
 
@@ -191,20 +214,21 @@ static bool ixgbe_cache_ring_dcb(struct ixgbe_adapter *adapter)
 	return true;
 }
 
-#endif
+#endif /* HAVE_TX_MQ */
 /**
- * ixgbe_cache_ring_sriov - Descriptor ring to register mapping for sriov
+ * ixgbe_cache_ring_vmdq - Descriptor ring to register mapping for VMDq
  * @adapter: board private structure to initialize
  *
- * SR-IOV doesn't use any descriptor rings but changes the default if
- * no other mapping is used.
+ * Cache the descriptor ring offsets for VMDq to the assigned rings.  It
+ * will also try to cache the proper offsets if RSS/FCoE/SRIOV are enabled along
+ * with VMDq.
  *
- */
-static bool ixgbe_cache_ring_sriov(struct ixgbe_adapter *adapter)
+ **/
+static bool ixgbe_cache_ring_vmdq(struct ixgbe_adapter *adapter)
 {
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	struct ixgbe_ring_feature *fcoe = &adapter->ring_feature[RING_F_FCOE];
-#endif /* IXGBE_FCOE */
+#endif /* CONFIG_FCOE */
 	struct ixgbe_ring_feature *vmdq = &adapter->ring_feature[RING_F_VMDQ];
 	struct ixgbe_ring_feature *rss = &adapter->ring_feature[RING_F_RSS];
 	int i;
@@ -217,26 +241,26 @@ static bool ixgbe_cache_ring_sriov(struct ixgbe_adapter *adapter)
 	/* start at VMDq register offset for SR-IOV enabled setups */
 	reg_idx = vmdq->offset * __ALIGN_MASK(1, ~vmdq->mask);
 	for (i = 0; i < adapter->num_rx_queues; i++, reg_idx++) {
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 		/* Allow first FCoE queue to be mapped as RSS */
 		if (fcoe->offset && (i > fcoe->offset))
 			break;
-#endif
+#endif /* CONFIG_FCOE */
 		/* If we are greater than indices move to next pool */
 		if ((reg_idx & ~vmdq->mask) >= rss->indices)
 			reg_idx = __ALIGN_MASK(reg_idx, ~vmdq->mask);
 		adapter->rx_ring[i]->reg_idx = reg_idx;
 	}
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* FCoE uses a linear block of queues so just assigning 1:1 */
 	for (; i < adapter->num_rx_queues; i++, reg_idx++)
 		adapter->rx_ring[i]->reg_idx = reg_idx;
+#endif /* CONFIG_FCOE */
 
-#endif
 	reg_idx = vmdq->offset * __ALIGN_MASK(1, ~vmdq->mask);
 	for (i = 0; i < adapter->num_tx_queues; i++, reg_idx++) {
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 		/* Allow first FCoE queue to be mapped as RSS */
 		if (fcoe->offset && (i > fcoe->offset))
 			break;
@@ -247,12 +271,11 @@ static bool ixgbe_cache_ring_sriov(struct ixgbe_adapter *adapter)
 		adapter->tx_ring[i]->reg_idx = reg_idx;
 	}
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* FCoE uses a linear block of queues so just assigning 1:1 */
 	for (; i < adapter->num_tx_queues; i++, reg_idx++)
 		adapter->tx_ring[i]->reg_idx = reg_idx;
-
-#endif
+#endif /* CONFIG_FCOE */
 
 	return true;
 }
@@ -261,7 +284,7 @@ static bool ixgbe_cache_ring_sriov(struct ixgbe_adapter *adapter)
  * ixgbe_cache_ring_rss - Descriptor ring to register mapping for RSS
  * @adapter: board private structure to initialize
  *
- * Cache the descriptor ring offsets for RSS to the assigned rings.
+ * Cache the descriptor ring offsets for RSS, ATR, FCoE, and SR-IOV.
  *
  **/
 static bool ixgbe_cache_ring_rss(struct ixgbe_adapter *adapter)
@@ -270,6 +293,7 @@ static bool ixgbe_cache_ring_rss(struct ixgbe_adapter *adapter)
 
 	for (i = 0; i < adapter->num_rx_queues; i++)
 		adapter->rx_ring[i]->reg_idx = i;
+
 	for (i = 0; i < adapter->num_tx_queues; i++)
 		adapter->tx_ring[i]->reg_idx = i;
 
@@ -289,19 +313,15 @@ static bool ixgbe_cache_ring_rss(struct ixgbe_adapter *adapter)
  **/
 static void ixgbe_cache_ring_register(struct ixgbe_adapter *adapter)
 {
-	/* start with default case */
-	adapter->rx_ring[0]->reg_idx = 0;
-	adapter->tx_ring[0]->reg_idx = 0;
-
-#ifdef CONFIG_IXGBE_DCB
-	if (ixgbe_cache_ring_dcb_sriov(adapter))
+#ifdef HAVE_TX_MQ
+	if (ixgbe_cache_ring_dcb_vmdq(adapter))
 		return;
 
 	if (ixgbe_cache_ring_dcb(adapter))
 		return;
 
 #endif
-	if (ixgbe_cache_ring_sriov(adapter))
+	if (ixgbe_cache_ring_vmdq(adapter))
 		return;
 
 	ixgbe_cache_ring_rss(adapter);
@@ -314,54 +334,73 @@ static void ixgbe_cache_ring_register(struct ixgbe_adapter *adapter)
 #define IXGBE_RSS_2Q_MASK	0x1
 #define IXGBE_RSS_DISABLED_MASK	0x0
 
-#ifdef CONFIG_IXGBE_DCB
+#ifdef HAVE_TX_MQ
 /**
- * ixgbe_set_dcb_sriov_queues: Allocate queues for SR-IOV devices w/ DCB
+ * ixgbe_set_dcb_vmdq_queues: Allocate queues for VMDq devices w/ DCB
  * @adapter: board private structure to initialize
  *
- * When SR-IOV (Single Root IO Virtualiztion) is enabled, allocate queues
+ * When VMDq (Virtual Machine Devices queue) is enabled, allocate queues
  * and VM pools where appropriate.  Also assign queues based on DCB
  * priorities and map accordingly..
  *
  **/
-static bool ixgbe_set_dcb_sriov_queues(struct ixgbe_adapter *adapter)
+static bool ixgbe_set_dcb_vmdq_queues(struct ixgbe_adapter *adapter)
 {
 	int i;
 	u16 vmdq_i = adapter->ring_feature[RING_F_VMDQ].limit;
 	u16 vmdq_m = 0;
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	u16 fcoe_i = 0;
 #endif
 	u8 tcs = netdev_get_num_tc(adapter->netdev);
 
-	/* verify we have DCB queueing enabled before proceeding */
+	/* verify we have DCB enabled before proceeding */
 	if (tcs <= 1)
 		return false;
 
 	/* verify we have VMDq enabled before proceeding */
-	if (!(adapter->flags & IXGBE_FLAG_SRIOV_ENABLED))
+	if (!(adapter->flags & IXGBE_FLAG_VMDQ_ENABLED))
 		return false;
 
-	/* Add starting offset to total pool count */
-	vmdq_i += adapter->ring_feature[RING_F_VMDQ].offset;
+	switch (adapter->hw.mac.type) {
+	case ixgbe_mac_82598EB:
+		/* 4 pools w/ 8TC per pool */
+		vmdq_i = min_t(u16, vmdq_i, 4);
+		vmdq_m = 0x7;
+		break;
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		/* Add starting offset to total pool count */
+		vmdq_i += adapter->ring_feature[RING_F_VMDQ].offset;
+
+		/* 16 pools w/ 8 TC per pool */
+		if (tcs > 4) {
+			vmdq_i = min_t(u16, vmdq_i, 16);
+			vmdq_m = IXGBE_82599_VMDQ_8Q_MASK;
+		/* 32 pools w/ 4 TC per pool */
+		} else {
+			vmdq_i = min_t(u16, vmdq_i, 32);
+			vmdq_m = IXGBE_82599_VMDQ_4Q_MASK;
+		}
 
-	/* 16 pools w/ 8 TC per pool */
-	if (tcs > 4) {
-		vmdq_i = min_t(u16, vmdq_i, 16);
-		vmdq_m = IXGBE_82599_VMDQ_8Q_MASK;
-	/* 32 pools w/ 4 TC per pool */
-	} else {
-		vmdq_i = min_t(u16, vmdq_i, 32);
-		vmdq_m = IXGBE_82599_VMDQ_4Q_MASK;
-	}
+#if IS_ENABLED(CONFIG_FCOE)
+		/* queues in the remaining pools are available for FCoE */
+		fcoe_i = (128 / __ALIGN_MASK(1, ~vmdq_m)) - vmdq_i;
+#endif /* CONFIG_FCOE */
 
-#ifdef IXGBE_FCOE
-	/* queues in the remaining pools are available for FCoE */
-	fcoe_i = (128 / __ALIGN_MASK(1, ~vmdq_m)) - vmdq_i;
+		/* remove the starting offset from the pool count */
+		vmdq_i -= adapter->ring_feature[RING_F_VMDQ].offset;
 
-#endif
-	/* remove the starting offset from the pool count */
-	vmdq_i -= adapter->ring_feature[RING_F_VMDQ].offset;
+		break;
+	default:
+		/* unknown hardware, only support one pool w/ one queue */
+		vmdq_i = 1;
+		tcs = 1;
+		break;
+	}
 
 	/* save features for later use */
 	adapter->ring_feature[RING_F_VMDQ].indices = vmdq_i;
@@ -374,16 +413,16 @@ static bool ixgbe_set_dcb_sriov_queues(struct ixgbe_adapter *adapter)
 	adapter->ring_feature[RING_F_RSS].indices = 1;
 	adapter->ring_feature[RING_F_RSS].mask = IXGBE_RSS_DISABLED_MASK;
 
-	/* disable ATR as it is not supported when VMDq is enabled */
-	adapter->flags &= ~IXGBE_FLAG_FDIR_HASH_CAPABLE;
-
 	adapter->num_rx_pools = vmdq_i;
 	adapter->num_rx_queues_per_pool = tcs;
 
 	adapter->num_tx_queues = vmdq_i * tcs;
 	adapter->num_rx_queues = vmdq_i * tcs;
 
-#ifdef IXGBE_FCOE
+	/* disable ATR as it is not supported when VMDq is enabled */
+	adapter->flags &= ~IXGBE_FLAG_FDIR_HASH_CAPABLE;
+
+#if IS_ENABLED(CONFIG_FCOE)
 	if (adapter->flags & IXGBE_FLAG_FCOE_ENABLED) {
 		struct ixgbe_ring_feature *fcoe;
 
@@ -411,8 +450,8 @@ static bool ixgbe_set_dcb_sriov_queues(struct ixgbe_adapter *adapter)
 			fcoe->offset = 0;
 		}
 	}
+#endif /* CONFIG_FCOE */
 
-#endif /* IXGBE_FCOE */
 	/* configure TC to queue mapping */
 	for (i = 0; i < tcs; i++)
 		netdev_set_tc_queue(adapter->netdev, i, 1, i);
@@ -420,6 +459,17 @@ static bool ixgbe_set_dcb_sriov_queues(struct ixgbe_adapter *adapter)
 	return true;
 }
 
+/**
+ * ixgbe_set_dcb_queues: Allocate queues for a DCB-enabled device
+ * @adapter: board private structure to initialize
+ *
+ * When DCB (Data Center Bridging) is enabled, allocate queues for
+ * each traffic class.  If multiqueue isn't available,then abort DCB
+ * initialization.
+ *
+ * This function handles all combinations of DCB, RSS, and FCoE.
+ *
+ **/
 static bool ixgbe_set_dcb_queues(struct ixgbe_adapter *adapter)
 {
 	struct net_device *dev = adapter->netdev;
@@ -430,12 +480,15 @@ static bool ixgbe_set_dcb_queues(struct ixgbe_adapter *adapter)
 	/* Map queue offset and counts onto allocated tx queues */
 	tcs = netdev_get_num_tc(dev);
 
-	/* verify we have DCB queueing enabled before proceeding */
 	if (tcs <= 1)
 		return false;
 
 	/* determine the upper limit for our current DCB mode */
+#ifndef HAVE_NETDEV_SELECT_QUEUE
+	rss_i = adapter->indices;
+#else
 	rss_i = dev->num_tx_queues / tcs;
+#endif
 	if (adapter->hw.mac.type == ixgbe_mac_82598EB) {
 		/* 8 TC w/ 4 queues per TC */
 		rss_i = min_t(u16, rss_i, 4);
@@ -452,16 +505,17 @@ static bool ixgbe_set_dcb_queues(struct ixgbe_adapter *adapter)
 
 	/* set RSS mask and indices */
 	f = &adapter->ring_feature[RING_F_RSS];
-	rss_i = min_t(int, rss_i, f->limit);
+	rss_i = min_t(u16, rss_i, f->limit);
 	f->indices = rss_i;
 	f->mask = rss_m;
 
-	/* disable ATR as it is not supported when multiple TCs are enabled */
+	/* disable ATR as it is not supported when DCB is enabled */
 	adapter->flags &= ~IXGBE_FLAG_FDIR_HASH_CAPABLE;
 
-#ifdef IXGBE_FCOE
-	/* FCoE enabled queues require special configuration indexed
-	 * by feature specific indices and offset. Here we map FCoE
+#if IS_ENABLED(CONFIG_FCOE)
+	/*
+	 * FCoE enabled queues require special configuration indexed
+	 * by feature specific indices and mask. Here we map FCoE
 	 * indices onto the DCB queue pairs allowing FCoE to own
 	 * configuration later.
 	 */
@@ -472,8 +526,8 @@ static bool ixgbe_set_dcb_queues(struct ixgbe_adapter *adapter)
 		f->indices = min_t(u16, rss_i, f->limit);
 		f->offset = rss_i * tc;
 	}
+#endif /* CONFIG_FCOE */
 
-#endif /* IXGBE_FCOE */
 	for (i = 0; i < tcs; i++)
 		netdev_set_tc_queue(dev, i, rss_i, rss_i * i);
 
@@ -485,54 +539,81 @@ static bool ixgbe_set_dcb_queues(struct ixgbe_adapter *adapter)
 
 #endif
 /**
- * ixgbe_set_sriov_queues - Allocate queues for SR-IOV devices
+ * ixgbe_set_vmdq_queues: Allocate queues for VMDq devices
  * @adapter: board private structure to initialize
  *
- * When SR-IOV (Single Root IO Virtualiztion) is enabled, allocate queues
+ * When VMDq (Virtual Machine Devices queue) is enabled, allocate queues
  * and VM pools where appropriate.  If RSS is available, then also try and
  * enable RSS and map accordingly.
  *
  **/
-static bool ixgbe_set_sriov_queues(struct ixgbe_adapter *adapter)
+static bool ixgbe_set_vmdq_queues(struct ixgbe_adapter *adapter)
 {
 	u16 vmdq_i = adapter->ring_feature[RING_F_VMDQ].limit;
 	u16 vmdq_m = 0;
 	u16 rss_i = adapter->ring_feature[RING_F_RSS].limit;
 	u16 rss_m = IXGBE_RSS_DISABLED_MASK;
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	u16 fcoe_i = 0;
 #endif
-	bool pools = (find_first_zero_bit(&adapter->fwd_bitmask, 32) > 1);
 
-	/* only proceed if SR-IOV is enabled */
-	if (!(adapter->flags & IXGBE_FLAG_SRIOV_ENABLED))
+	/* only proceed if VMDq is enabled */
+	if (!(adapter->flags & IXGBE_FLAG_VMDQ_ENABLED))
 		return false;
 
-	/* Add starting offset to total pool count */
-	vmdq_i += adapter->ring_feature[RING_F_VMDQ].offset;
-
-	/* double check we are limited to maximum pools */
-	vmdq_i = min_t(u16, IXGBE_MAX_VMDQ_INDICES, vmdq_i);
+	switch (adapter->hw.mac.type) {
+	case ixgbe_mac_82598EB:
+		vmdq_i = min_t(u16, vmdq_i, 16);
+		/* 16 pool mode with 1 queue per pool */
+		if ((vmdq_i > 4) || (rss_i == 1)) {
+			vmdq_m = 0x0F;
+			rss_i = 1;
+		/* 4 pool mode with 8 queue per pool */
+		} else {
+			vmdq_m = 0x18;
+			rss_m = IXGBE_RSS_8Q_MASK;
+			rss_i = min_t(u16, rss_i, 8);
+		}
+		break;
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		/* Add starting offset to total pool count */
+		vmdq_i += adapter->ring_feature[RING_F_VMDQ].offset;
+
+		/* double check we are limited to maximum pools */
+		vmdq_i = min_t(u16, IXGBE_MAX_VMDQ_INDICES, vmdq_i);
+
+		/* 64 pool mode with 2 queues per pool */
+		if (vmdq_i > 32) {
+			vmdq_m = IXGBE_82599_VMDQ_2Q_MASK;
+			rss_m = IXGBE_RSS_2Q_MASK;
+			rss_i = min_t(u16, rss_i, 2);
+		/* 32 pool mode with up to 4 queues per pool */
+		} else {
+			vmdq_m = IXGBE_82599_VMDQ_4Q_MASK;
+			rss_m = IXGBE_RSS_4Q_MASK;
+			/* We can support 4, 2, or 1 queues */
+			rss_i = (rss_i > 3) ? 4 : (rss_i > 1) ? 2 : 1;
+		}
 
-	/* 64 pool mode with 2 queues per pool */
-	if ((vmdq_i > 32) || (rss_i < 4) || (vmdq_i > 16 && pools)) {
-		vmdq_m = IXGBE_82599_VMDQ_2Q_MASK;
-		rss_m = IXGBE_RSS_2Q_MASK;
-		rss_i = min_t(u16, rss_i, 2);
-	/* 32 pool mode with 4 queues per pool */
-	} else {
-		vmdq_m = IXGBE_82599_VMDQ_4Q_MASK;
-		rss_m = IXGBE_RSS_4Q_MASK;
-		rss_i = 4;
-	}
+#if IS_ENABLED(CONFIG_FCOE)
+		/* queues in the remaining pools are available for FCoE */
+		fcoe_i = 128 - (vmdq_i * __ALIGN_MASK(1, ~vmdq_m));
+#endif
 
-#ifdef IXGBE_FCOE
-	/* queues in the remaining pools are available for FCoE */
-	fcoe_i = 128 - (vmdq_i * __ALIGN_MASK(1, ~vmdq_m));
+		/* remove the starting offset from the pool count */
+		vmdq_i -= adapter->ring_feature[RING_F_VMDQ].offset;
 
-#endif
-	/* remove the starting offset from the pool count */
-	vmdq_i -= adapter->ring_feature[RING_F_VMDQ].offset;
+		break;
+	default:
+		/* unknown hardware, support one pool w/ one queue */
+		vmdq_i = 1;
+		rss_i = 1;
+		break;
+	}
 
 	/* save features for later use */
 	adapter->ring_feature[RING_F_VMDQ].indices = vmdq_i;
@@ -546,12 +627,16 @@ static bool ixgbe_set_sriov_queues(struct ixgbe_adapter *adapter)
 	adapter->num_rx_queues_per_pool = rss_i;
 
 	adapter->num_rx_queues = vmdq_i * rss_i;
+#ifdef HAVE_TX_MQ
 	adapter->num_tx_queues = vmdq_i * rss_i;
+#else
+	adapter->num_tx_queues = vmdq_i;
+#endif /* HAVE_TX_MQ */
 
 	/* disable ATR as it is not supported when VMDq is enabled */
 	adapter->flags &= ~IXGBE_FLAG_FDIR_HASH_CAPABLE;
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/*
 	 * FCoE can use rings from adjacent buffers to allow RSS
 	 * like behavior.  To account for this we need to add the
@@ -580,7 +665,6 @@ static bool ixgbe_set_sriov_queues(struct ixgbe_adapter *adapter)
 			/* attempt to reserve some queues for just FCoE */
 			fcoe->indices = min_t(u16, fcoe_i, fcoe->limit);
 			fcoe->offset = fcoe_i - fcoe->indices;
-
 			fcoe_i -= rss_i;
 		}
 
@@ -588,13 +672,13 @@ static bool ixgbe_set_sriov_queues(struct ixgbe_adapter *adapter)
 		adapter->num_tx_queues += fcoe_i;
 		adapter->num_rx_queues += fcoe_i;
 	}
+#endif /* CONFIG_FCOE */
 
-#endif
 	return true;
 }
 
 /**
- * ixgbe_set_rss_queues - Allocate queues for RSS
+ * ixgbe_set_rss_queues: Allocate queues for RSS
  * @adapter: board private structure to initialize
  *
  * This is our "base" multiqueue mode.  RSS (Receive Side Scaling) will try
@@ -612,7 +696,6 @@ static bool ixgbe_set_rss_queues(struct ixgbe_adapter *adapter)
 	rss_i = f->limit;
 
 	f->indices = rss_i;
-
 	if (hw->mac.type < ixgbe_mac_X550)
 		f->mask = IXGBE_RSS_16Q_MASK;
 	else
@@ -635,7 +718,7 @@ static bool ixgbe_set_rss_queues(struct ixgbe_adapter *adapter)
 			adapter->flags |= IXGBE_FLAG_FDIR_HASH_CAPABLE;
 	}
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/*
 	 * FCoE can exist on the same rings as standard network traffic
 	 * however it is preferred to avoid that if possible.  In order
@@ -663,16 +746,18 @@ static bool ixgbe_set_rss_queues(struct ixgbe_adapter *adapter)
 		f->offset = fcoe_i - f->indices;
 		rss_i = max_t(u16, fcoe_i, rss_i);
 	}
+#endif /* CONFIG_FCOE */
 
-#endif /* IXGBE_FCOE */
 	adapter->num_rx_queues = rss_i;
+#ifdef HAVE_TX_MQ
 	adapter->num_tx_queues = rss_i;
+#endif
 
 	return true;
 }
 
-/**
- * ixgbe_set_num_queues - Allocate queues for device, feature dependent
+/*
+ * ixgbe_set_num_queues: Allocate queues for device, feature dependent
  * @adapter: board private structure to initialize
  *
  * This is the top level queue allocation routine.  The order here is very
@@ -690,15 +775,15 @@ static void ixgbe_set_num_queues(struct ixgbe_adapter *adapter)
 	adapter->num_rx_pools = adapter->num_rx_queues;
 	adapter->num_rx_queues_per_pool = 1;
 
-#ifdef CONFIG_IXGBE_DCB
-	if (ixgbe_set_dcb_sriov_queues(adapter))
+#ifdef HAVE_TX_MQ
+	if (ixgbe_set_dcb_vmdq_queues(adapter))
 		return;
 
 	if (ixgbe_set_dcb_queues(adapter))
 		return;
 
 #endif
-	if (ixgbe_set_sriov_queues(adapter))
+	if (ixgbe_set_vmdq_queues(adapter))
 		return;
 
 	ixgbe_set_rss_queues(adapter);
@@ -717,6 +802,9 @@ static int ixgbe_acquire_msix_vectors(struct ixgbe_adapter *adapter)
 	struct ixgbe_hw *hw = &adapter->hw;
 	int i, vectors, vector_threshold;
 
+	if (!(adapter->flags & IXGBE_FLAG_MSIX_CAPABLE))
+		return -EOPNOTSUPP;
+
 	/* We start by asking for one vector per queue pair */
 	vectors = max(adapter->num_rx_queues, adapter->num_tx_queues);
 
@@ -757,8 +845,7 @@ static int ixgbe_acquire_msix_vectors(struct ixgbe_adapter *adapter)
 
 	if (vectors < 0) {
 		/* A negative count of allocated vectors indicates an error in
-		 * acquiring within the specified range of MSI-X vectors
-		 */
+		 * acquiring within the specified range of MSI-X vectors */
 		e_dev_warn("Failed to allocate MSI-X interrupts. Err: %d\n",
 			   vectors);
 
@@ -783,6 +870,7 @@ static int ixgbe_acquire_msix_vectors(struct ixgbe_adapter *adapter)
 	return 0;
 }
 
+
 static void ixgbe_add_ring(struct ixgbe_ring *ring,
 			   struct ixgbe_ring_container *head)
 {
@@ -804,23 +892,27 @@ static void ixgbe_add_ring(struct ixgbe_ring *ring,
  * We allocate one q_vector.  If allocation fails we return -ENOMEM.
  **/
 static int ixgbe_alloc_q_vector(struct ixgbe_adapter *adapter,
-				int v_count, int v_idx,
-				int txr_count, int txr_idx,
-				int rxr_count, int rxr_idx)
+				unsigned int v_count, unsigned int v_idx,
+				unsigned int txr_count, unsigned int txr_idx,
+				unsigned int rxr_count, unsigned int rxr_idx)
 {
 	struct ixgbe_q_vector *q_vector;
 	struct ixgbe_ring *ring;
-	int node = NUMA_NO_NODE;
+	int node = -1;
+#ifdef HAVE_IRQ_AFFINITY_HINT
 	int cpu = -1;
-	int ring_count, size;
 	u8 tcs = netdev_get_num_tc(adapter->netdev);
+#endif
+	int ring_count, size;
 
+	/* note this will allocate space for the ring structure as well! */
 	ring_count = txr_count + rxr_count;
 	size = sizeof(struct ixgbe_q_vector) +
 	       (sizeof(struct ixgbe_ring) * ring_count);
 
+#ifdef HAVE_IRQ_AFFINITY_HINT
 	/* customize cpu for Flow Director mapping */
-	if ((tcs <= 1) && !(adapter->flags & IXGBE_FLAG_SRIOV_ENABLED)) {
+	if ((tcs <= 1) && !(adapter->flags & IXGBE_FLAG_VMDQ_ENABLED)) {
 		u16 rss_i = adapter->ring_feature[RING_F_RSS].indices;
 		if (rss_i > 1 && adapter->atr_sample_rate) {
 			if (cpu_online(v_idx)) {
@@ -830,6 +922,7 @@ static int ixgbe_alloc_q_vector(struct ixgbe_adapter *adapter,
 		}
 	}
 
+#endif
 	/* allocate q_vector and rings */
 	q_vector = kzalloc_node(size, GFP_KERNEL, node);
 	if (!q_vector)
@@ -838,21 +931,25 @@ static int ixgbe_alloc_q_vector(struct ixgbe_adapter *adapter,
 		return -ENOMEM;
 
 	/* setup affinity mask and node */
+#ifdef HAVE_IRQ_AFFINITY_HINT
 	if (cpu != -1)
 		cpumask_set_cpu(cpu, &q_vector->affinity_mask);
+#endif
 	q_vector->numa_node = node;
 
-#ifdef CONFIG_IXGBE_DCA
 	/* initialize CPU for DCA */
 	q_vector->cpu = -1;
 
-#endif
 	/* initialize NAPI */
 	netif_napi_add(adapter->netdev, &q_vector->napi,
 		       ixgbe_poll, 64);
+#ifndef HAVE_NETIF_NAPI_ADD_CALLS_NAPI_HASH_ADD
+#ifdef HAVE_NDO_BUSY_POLL
 	napi_hash_add(&q_vector->napi);
+#endif
+#endif
 
-#ifdef CONFIG_NET_RX_BUSY_POLL
+#ifdef HAVE_NDO_BUSY_POLL
 	/* initialize busy poll */
 	atomic_set(&q_vector->state, IXGBE_QV_STATE_DISABLE);
 
@@ -864,6 +961,7 @@ static int ixgbe_alloc_q_vector(struct ixgbe_adapter *adapter,
 
 	/* initialize work limits */
 	q_vector->tx.work_limit = adapter->tx_work_limit;
+	q_vector->rx.work_limit = adapter->rx_work_limit;
 
 	/* initialize pointer to rings */
 	ring = q_vector->ring;
@@ -885,7 +983,7 @@ static int ixgbe_alloc_q_vector(struct ixgbe_adapter *adapter,
 
 	while (txr_count) {
 		/* assign generic ring traits */
-		ring->dev = &adapter->pdev->dev;
+		ring->dev = pci_dev_to_dev(adapter->pdev);
 		ring->netdev = adapter->netdev;
 
 		/* configure backlink on ring */
@@ -896,11 +994,7 @@ static int ixgbe_alloc_q_vector(struct ixgbe_adapter *adapter,
 
 		/* apply Tx specific ring traits */
 		ring->count = adapter->tx_ring_count;
-		if (adapter->num_rx_pools > 1)
-			ring->queue_index =
-				txr_idx % adapter->num_rx_queues_per_pool;
-		else
-			ring->queue_index = txr_idx;
+		ring->queue_index = txr_idx;
 
 		/* assign ring to adapter */
 		adapter->tx_ring[txr_idx] = ring;
@@ -915,7 +1009,7 @@ static int ixgbe_alloc_q_vector(struct ixgbe_adapter *adapter,
 
 	while (rxr_count) {
 		/* assign generic ring traits */
-		ring->dev = &adapter->pdev->dev;
+		ring->dev = pci_dev_to_dev(adapter->pdev);
 		ring->netdev = adapter->netdev;
 
 		/* configure backlink on ring */
@@ -931,23 +1025,21 @@ static int ixgbe_alloc_q_vector(struct ixgbe_adapter *adapter,
 		if (adapter->hw.mac.type == ixgbe_mac_82599EB)
 			set_bit(__IXGBE_RX_CSUM_UDP_ZERO_ERR, &ring->state);
 
-#ifdef IXGBE_FCOE
-		if (adapter->netdev->features & NETIF_F_FCOE_MTU) {
+#if IS_ENABLED(CONFIG_FCOE)
+		if (adapter->flags & IXGBE_FLAG_FCOE_ENABLED) {
 			struct ixgbe_ring_feature *f;
 			f = &adapter->ring_feature[RING_F_FCOE];
+
 			if ((rxr_idx >= f->offset) &&
-			    (rxr_idx < f->offset + f->indices))
+			    (rxr_idx < f->offset + f->indices)) {
 				set_bit(__IXGBE_RX_FCOE, &ring->state);
+			}
 		}
+#endif /* CONFIG_FCOE */
 
-#endif /* IXGBE_FCOE */
 		/* apply Rx specific ring traits */
 		ring->count = adapter->rx_ring_count;
-		if (adapter->num_rx_pools > 1)
-			ring->queue_index =
-				rxr_idx % adapter->num_rx_queues_per_pool;
-		else
-			ring->queue_index = rxr_idx;
+		ring->queue_index = rxr_idx;
 
 		/* assign ring to adapter */
 		adapter->rx_ring[rxr_idx] = ring;
@@ -984,13 +1076,10 @@ static void ixgbe_free_q_vector(struct ixgbe_adapter *adapter, int v_idx)
 		adapter->rx_ring[ring->queue_index] = NULL;
 
 	adapter->q_vector[v_idx] = NULL;
+#ifdef HAVE_NDO_BUSY_POLL
 	napi_hash_del(&q_vector->napi);
+#endif
 	netif_napi_del(&q_vector->napi);
-
-	/*
-	 * ixgbe_get_stats64() might access the rings on this vector,
-	 * we must wait a grace period before freeing it.
-	 */
 	kfree_rcu(q_vector, rcu);
 }
 
@@ -1003,21 +1092,16 @@ static void ixgbe_free_q_vector(struct ixgbe_adapter *adapter, int v_idx)
  **/
 static int ixgbe_alloc_q_vectors(struct ixgbe_adapter *adapter)
 {
-	int q_vectors = adapter->num_q_vectors;
-	int rxr_remaining = adapter->num_rx_queues;
-	int txr_remaining = adapter->num_tx_queues;
-	int rxr_idx = 0, txr_idx = 0, v_idx = 0;
+	unsigned int q_vectors = adapter->num_q_vectors;
+	unsigned int rxr_remaining = adapter->num_rx_queues;
+	unsigned int txr_remaining = adapter->num_tx_queues;
+	unsigned int rxr_idx = 0, txr_idx = 0, v_idx = 0;
 	int err;
 
-	/* only one q_vector if MSI-X is disabled. */
-	if (!(adapter->flags & IXGBE_FLAG_MSIX_ENABLED))
-		q_vectors = 1;
-
 	if (q_vectors >= (rxr_remaining + txr_remaining)) {
 		for (; rxr_remaining; v_idx++) {
 			err = ixgbe_alloc_q_vector(adapter, q_vectors, v_idx,
 						   0, 0, 1, rxr_idx);
-
 			if (err)
 				goto err_out;
 
@@ -1044,7 +1128,7 @@ static int ixgbe_alloc_q_vectors(struct ixgbe_adapter *adapter)
 		txr_idx++;
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 
 err_out:
 	adapter->num_tx_queues = 0;
@@ -1077,7 +1161,7 @@ static void ixgbe_free_q_vectors(struct ixgbe_adapter *adapter)
 		ixgbe_free_q_vector(adapter, v_idx);
 }
 
-static void ixgbe_reset_interrupt_capability(struct ixgbe_adapter *adapter)
+void ixgbe_reset_interrupt_capability(struct ixgbe_adapter *adapter)
 {
 	if (adapter->flags & IXGBE_FLAG_MSIX_ENABLED) {
 		adapter->flags &= ~IXGBE_FLAG_MSIX_ENABLED;
@@ -1097,7 +1181,7 @@ static void ixgbe_reset_interrupt_capability(struct ixgbe_adapter *adapter)
  * Attempt to configure the interrupts using the best available
  * capabilities of the hardware and the kernel.
  **/
-static void ixgbe_set_interrupt_capability(struct ixgbe_adapter *adapter)
+void ixgbe_set_interrupt_capability(struct ixgbe_adapter *adapter)
 {
 	int err;
 
@@ -1126,9 +1210,15 @@ static void ixgbe_set_interrupt_capability(struct ixgbe_adapter *adapter)
 	adapter->dcb_cfg.num_tcs.pg_tcs = 1;
 	adapter->dcb_cfg.num_tcs.pfc_tcs = 1;
 
+	/* Disable VMDq support */
+	e_dev_warn("Disabling VMQd support\n");
+	adapter->flags &= ~IXGBE_FLAG_VMDQ_ENABLED;
+
+#ifdef CONFIG_PCI_IOV
 	/* Disable SR-IOV support */
 	e_dev_warn("Disabling SR-IOV support\n");
 	ixgbe_disable_sriov(adapter);
+#endif /* CONFIG_PCI_IOV */
 
 	/* Disable RSS */
 	e_dev_warn("Disabling RSS support\n");
@@ -1140,6 +1230,9 @@ static void ixgbe_set_interrupt_capability(struct ixgbe_adapter *adapter)
 	ixgbe_set_num_queues(adapter);
 	adapter->num_q_vectors = 1;
 
+	if (!(adapter->flags & IXGBE_FLAG_MSI_CAPABLE))
+		return;
+
 	err = pci_enable_msi(adapter->pdev);
 	if (err)
 		e_dev_warn("Failed to allocate MSI interrupt, falling back to legacy. Error: %d\n",
@@ -1168,25 +1261,19 @@ int ixgbe_init_interrupt_scheme(struct ixgbe_adapter *adapter)
 	/* Set interrupt mode */
 	ixgbe_set_interrupt_capability(adapter);
 
+	/* Allocate memory for queues */
 	err = ixgbe_alloc_q_vectors(adapter);
 	if (err) {
-		e_dev_err("Unable to allocate memory for queue vectors\n");
-		goto err_alloc_q_vectors;
+		e_err(probe, "Unable to allocate memory for queue vectors\n");
+		ixgbe_reset_interrupt_capability(adapter);
+		return err;
 	}
 
 	ixgbe_cache_ring_register(adapter);
 
-	e_dev_info("Multiqueue %s: Rx Queue count = %u, Tx Queue count = %u\n",
-		   (adapter->num_rx_queues > 1) ? "Enabled" : "Disabled",
-		   adapter->num_rx_queues, adapter->num_tx_queues);
-
 	set_bit(__IXGBE_DOWN, &adapter->state);
 
-	return 0;
-
-err_alloc_q_vectors:
-	ixgbe_reset_interrupt_capability(adapter);
-	return err;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -1198,9 +1285,6 @@ err_alloc_q_vectors:
  **/
 void ixgbe_clear_interrupt_scheme(struct ixgbe_adapter *adapter)
 {
-	adapter->num_tx_queues = 0;
-	adapter->num_rx_queues = 0;
-
 	ixgbe_free_q_vectors(adapter);
 	ixgbe_reset_interrupt_capability(adapter);
 }
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_main.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_main.c
index a5b4431..fde5663 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_main.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_main.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2015 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,73 +22,75 @@
 
 *******************************************************************************/
 
+/******************************************************************************
+ Copyright (c)2006 - 2007 Myricom, Inc. for some LRO specific code
+******************************************************************************/
 #include <linux/types.h>
 #include <linux/module.h>
 #include <linux/pci.h>
 #include <linux/netdevice.h>
 #include <linux/vmalloc.h>
+#include <linux/highmem.h>
 #include <linux/string.h>
 #include <linux/in.h>
-#include <linux/interrupt.h>
 #include <linux/ip.h>
 #include <linux/tcp.h>
-#include <linux/sctp.h>
 #include <linux/pkt_sched.h>
 #include <linux/ipv6.h>
-#include <linux/slab.h>
+#ifdef NETIF_F_TSO
 #include <net/checksum.h>
+#ifdef NETIF_F_TSO6
+#include <net/ipv6.h>
 #include <net/ip6_checksum.h>
-#include <linux/etherdevice.h>
+#endif /* NETIF_F_TSO6 */
+#endif /* NETIF_F_TSO */
+#ifdef SIOCETHTOOL
 #include <linux/ethtool.h>
-#include <linux/if.h>
-#include <linux/if_vlan.h>
-#include <linux/if_macvlan.h>
-#include <linux/if_bridge.h>
-#include <linux/prefetch.h>
-#include <scsi/fc/fc_fcoe.h>
-#include <net/vxlan.h>
-
-#ifdef CONFIG_OF
-#include <linux/of_net.h>
-#endif
-
-#ifdef CONFIG_SPARC
-#include <asm/idprom.h>
-#include <asm/prom.h>
 #endif
 
+#include <linux/if_bridge.h>
 #include "ixgbe.h"
-#include "ixgbe_common.h"
+#ifdef HAVE_UDP_ENC_RX_OFFLOAD
+#include <net/vxlan.h>
+#include <net/udp_tunnel.h>
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD */
+#ifdef HAVE_VXLAN_RX_OFFLOAD
+#include <net/vxlan.h>
+#endif /* HAVE_VXLAN_RX_OFFLOAD */
+
 #include "ixgbe_dcb_82599.h"
 #include "ixgbe_sriov.h"
-#ifdef CONFIG_IXGBE_VXLAN
-#include <net/vxlan.h>
-#endif
 
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+#include "buffalo/kernevnt.h"
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+
+#define DRV_HW_PERF
+
+#define FPGA
+
+#define DRIVERIOV
+
+#define BYPASS_TAG
+
+#define RELEASE_TAG
+
+#define DRV_VERSION	"5.3.4" \
+			DRIVERIOV DRV_HW_PERF FPGA \
+			BYPASS_TAG RELEASE_TAG
+#define DRV_SUMMARY	"Intel(R) 10GbE PCI Express Linux Network Driver"
+const char ixgbe_driver_version[] = DRV_VERSION;
+#ifdef HAVE_NON_CONST_PCI_DRIVER_NAME
 char ixgbe_driver_name[] = "ixgbe";
-static const char ixgbe_driver_string[] =
-			      "Intel(R) 10 Gigabit PCI Express Network Driver";
-#ifdef IXGBE_FCOE
-char ixgbe_default_device_descr[] =
-			      "Intel(R) 10 Gigabit Network Connection";
 #else
-static char ixgbe_default_device_descr[] =
-			      "Intel(R) 10 Gigabit Network Connection";
+const char ixgbe_driver_name[] = "ixgbe";
 #endif
-#define DRV_VERSION "4.2.1-k"
-const char ixgbe_driver_version[] = DRV_VERSION;
-static const char ixgbe_copyright[] =
-				"Copyright (c) 1999-2015 Intel Corporation.";
-
-static const char ixgbe_overheat_msg[] = "Network adapter has been stopped because it has over heated. Restart the computer. If the problem persists, power off the system and replace the adapter";
-
-static const struct ixgbe_info *ixgbe_info_tbl[] = {
-	[board_82598]		= &ixgbe_82598_info,
-	[board_82599]		= &ixgbe_82599_info,
-	[board_X540]		= &ixgbe_X540_info,
-	[board_X550]		= &ixgbe_X550_info,
-	[board_X550EM_x]	= &ixgbe_X550EM_x_info,
-};
+static const char ixgbe_driver_string[] = DRV_SUMMARY;
+static const char ixgbe_copyright[] = "Copyright(c) 1999 - 2017 Intel Corporation.";
+static const char ixgbe_overheat_msg[] =
+		"Network adapter has been stopped because it has over heated. "
+		"Restart the computer. If the problem persists, "
+		"power off the system and replace the adapter";
 
 /* ixgbe_pci_tbl - PCI Device ID Table
  *
@@ -103,107 +101,124 @@ static const struct ixgbe_info *ixgbe_info_tbl[] = {
  *   Class, Class Mask, private data (not used) }
  */
 static const struct pci_device_id ixgbe_pci_tbl[] = {
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598AF_DUAL_PORT), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598AF_SINGLE_PORT), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598AT), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598AT2), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598EB_CX4), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598_CX4_DUAL_PORT), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598_DA_DUAL_PORT), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598_SR_DUAL_PORT_EM), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598EB_XF_LR), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598EB_SFP_LOM), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598_BX), board_82598 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_KX4), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_XAUI_LOM), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_KR), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_SFP), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_SFP_EM), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_KX4_MEZZ), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_CX4), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_BACKPLANE_FCOE), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_SFP_FCOE), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_T3_LOM), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_COMBO_BACKPLANE), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X540T), board_X540 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_SFP_SF2), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_LS), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_QSFP_SF_QP), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599EN_SFP), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_SFP_SF_QP), board_82599 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X540T1), board_X540 },
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550T), board_X550},
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_X_KX4), board_X550EM_x},
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_X_KR), board_X550EM_x},
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_X_10G_T), board_X550EM_x},
-	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_X_SFP), board_X550EM_x},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598AF_DUAL_PORT), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598AF_SINGLE_PORT), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598AT), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598AT2), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598EB_CX4), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598_CX4_DUAL_PORT), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598_DA_DUAL_PORT), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598_SR_DUAL_PORT_EM), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598EB_XF_LR), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598EB_SFP_LOM), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82598_BX), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_KX4), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_XAUI_LOM), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_KR), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_SFP), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_SFP_EM), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_KX4_MEZZ), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_CX4), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_BACKPLANE_FCOE), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_SFP_FCOE), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_T3_LOM), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_COMBO_BACKPLANE), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X540T), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_SFP_SF2), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_LS), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599EN_SFP), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_SFP_SF_QP), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_82599_QSFP_SF_QP), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X540T1), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550T), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550T1), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_X_KX4), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_X_XFI), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_X_KR), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_X_SFP), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_X_10G_T), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_X_1G_T), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_A_KR), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_A_KR_L), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_A_SFP_N), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_A_SGMII), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_A_SGMII_L), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_A_10G_T), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_A_QSFP), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_A_QSFP_N), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_A_SFP), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_A_1G_T), 0},
+	{PCI_VDEVICE(INTEL, IXGBE_DEV_ID_X550EM_A_1G_T_L), 0},
 	/* required last entry */
-	{0, }
+	{ .device = 0 }
 };
 MODULE_DEVICE_TABLE(pci, ixgbe_pci_tbl);
 
-#ifdef CONFIG_IXGBE_DCA
+#if IS_ENABLED(CONFIG_DCA)
 static int ixgbe_notify_dca(struct notifier_block *, unsigned long event,
 			    void *p);
 static struct notifier_block dca_notifier = {
-	.notifier_call = ixgbe_notify_dca,
-	.next          = NULL,
-	.priority      = 0
+	.notifier_call	= ixgbe_notify_dca,
+	.next		= NULL,
+	.priority	= 0
 };
-#endif
-
-#ifdef CONFIG_PCI_IOV
-static unsigned int max_vfs;
-module_param(max_vfs, uint, 0);
-MODULE_PARM_DESC(max_vfs,
-		 "Maximum number of virtual functions to allocate per physical function - default is zero and maximum value is 63. (Deprecated)");
-#endif /* CONFIG_PCI_IOV */
-
-static unsigned int allow_unsupported_sfp;
-module_param(allow_unsupported_sfp, uint, 0);
-MODULE_PARM_DESC(allow_unsupported_sfp,
-		 "Allow unsupported and untested SFP+ modules on 82599-based adapters");
-
-#define DEFAULT_MSG_ENABLE (NETIF_MSG_DRV|NETIF_MSG_PROBE|NETIF_MSG_LINK)
-static int debug = -1;
-module_param(debug, int, 0);
-MODULE_PARM_DESC(debug, "Debug level (0=none,...,16=all)");
+#endif /* CONFIG_DCA */
+static void ixgbe_watchdog_link_is_down(struct ixgbe_adapter *);
 
 MODULE_AUTHOR("Intel Corporation, <linux.nics@intel.com>");
-MODULE_DESCRIPTION("Intel(R) 10 Gigabit PCI Express Network Driver");
+MODULE_DESCRIPTION(DRV_SUMMARY);
 MODULE_LICENSE("GPL");
 MODULE_VERSION(DRV_VERSION);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+int ixgbe_phy_deferred_linkdown = 1;
+module_param_named(deferred_linkdown, ixgbe_phy_deferred_linkdown, int, 0600);
+MODULE_PARM_DESC(deferred_linkdown, "Max linkdown count for lanact event");
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+
+#define DEFAULT_DEBUG_LEVEL_SHIFT 3
 
+static struct workqueue_struct *ixgbe_wq;
+
+static bool ixgbe_is_sfp(struct ixgbe_hw *hw);
 static bool ixgbe_check_cfg_remove(struct ixgbe_hw *hw, struct pci_dev *pdev);
 
-static int ixgbe_read_pci_cfg_word_parent(struct ixgbe_adapter *adapter,
+static int ixgbe_read_pci_cfg_word_parent(struct ixgbe_hw *hw,
 					  u32 reg, u16 *value)
 {
+	struct ixgbe_adapter *adapter = hw->back;
 	struct pci_dev *parent_dev;
 	struct pci_bus *parent_bus;
+	int pos;
 
 	parent_bus = adapter->pdev->bus->parent;
 	if (!parent_bus)
-		return -1;
+		return IXGBE_ERR_FEATURE_NOT_SUPPORTED;
 
 	parent_dev = parent_bus->self;
 	if (!parent_dev)
-		return -1;
+		return IXGBE_ERR_FEATURE_NOT_SUPPORTED;
 
-	if (!pci_is_pcie(parent_dev))
-		return -1;
+	pos = pci_find_capability(parent_dev, PCI_CAP_ID_EXP);
+	if (!pos)
+		return IXGBE_ERR_FEATURE_NOT_SUPPORTED;
 
-	pcie_capability_read_word(parent_dev, reg, value);
+	pci_read_config_word(parent_dev, pos + reg, value);
 	if (*value == IXGBE_FAILED_READ_CFG_WORD &&
-	    ixgbe_check_cfg_remove(&adapter->hw, parent_dev))
-		return -1;
-	return 0;
+	    ixgbe_check_cfg_remove(hw, parent_dev))
+		return IXGBE_ERR_FEATURE_NOT_SUPPORTED;
+	return IXGBE_SUCCESS;
 }
 
-static s32 ixgbe_get_parent_bus_info(struct ixgbe_adapter *adapter)
+/**
+ *  ixgbe_get_parent_bus_info - Set PCI bus info beyond switch
+ *  @hw: pointer to hardware structure
+ *
+ *  Sets the PCI bus info (speed, width, type) within the ixgbe_hw structure
+ *  when the device is behind a switch.
+ **/
+static s32 ixgbe_get_parent_bus_info(struct ixgbe_hw *hw)
 {
-	struct ixgbe_hw *hw = &adapter->hw;
 	u16 link_status = 0;
 	int err;
 
@@ -212,32 +227,30 @@ static s32 ixgbe_get_parent_bus_info(struct ixgbe_adapter *adapter)
 	/* Get the negotiated link width and speed from PCI config space of the
 	 * parent, as this device is behind a switch
 	 */
-	err = ixgbe_read_pci_cfg_word_parent(adapter, 18, &link_status);
+	err = ixgbe_read_pci_cfg_word_parent(hw, 18, &link_status);
 
-	/* assume caller will handle error case */
+	/* If the read fails, fallback to default */
 	if (err)
-		return err;
+		link_status = IXGBE_READ_PCIE_WORD(hw, IXGBE_PCI_LINK_STATUS);
 
-	hw->bus.width = ixgbe_convert_bus_width(link_status);
-	hw->bus.speed = ixgbe_convert_bus_speed(link_status);
+	ixgbe_set_pci_config_data_generic(hw, link_status);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
- * ixgbe_check_from_parent - Determine whether PCIe info should come from parent
+ * ixgbe_check_from_parent - determine whether to use parent for PCIe info
  * @hw: hw specific details
  *
- * This function is used by probe to determine whether a device's PCI-Express
- * bandwidth details should be gathered from the parent bus instead of from the
- * device. Used to ensure that various locations all have the correct device ID
- * checks.
+ * This function is used by probe to determine whether a device's PCIe info
+ * (speed, width, etc) should be obtained from the parent bus or directly. This
+ * is useful for specialized device configurations containing PCIe bridges.
  */
 static inline bool ixgbe_pcie_from_parent(struct ixgbe_hw *hw)
 {
 	switch (hw->device_id) {
-	case IXGBE_DEV_ID_82599_SFP_SF_QP:
 	case IXGBE_DEV_ID_82599_QSFP_SF_QP:
+	case IXGBE_DEV_ID_82599_SFP_SF_QP:
 		return true;
 	default:
 		return false;
@@ -282,7 +295,7 @@ static void ixgbe_check_minimum_link(struct ixgbe_adapter *adapter,
 		max_gts = 4 * width;
 		break;
 	case PCIE_SPEED_8_0GT:
-		/* 128b/130b encoding reduces throughput by less than 2% */
+		/* 128b/130b encoding has less than 2% impact on throughput */
 		max_gts = 8 * width;
 		break;
 	default:
@@ -297,7 +310,7 @@ static void ixgbe_check_minimum_link(struct ixgbe_adapter *adapter,
 		    speed == PCIE_SPEED_5_0GT ? "5.0GT/s" :
 		    speed == PCIE_SPEED_2_5GT ? "2.5GT/s" :
 		    "Unknown"),
-		   width,
+		   hw->bus.width,
 		   (speed == PCIE_SPEED_2_5GT ? "20%" :
 		    speed == PCIE_SPEED_5_0GT ? "20%" :
 		    speed == PCIE_SPEED_8_0GT ? "<2%" :
@@ -311,12 +324,66 @@ static void ixgbe_check_minimum_link(struct ixgbe_adapter *adapter,
 	}
 }
 
+/**
+ * ixgbe_enumerate_functions - Get the number of ports this device has
+ * @adapter: adapter structure
+ *
+ * This function enumerates the phsyical functions co-located on a single slot,
+ * in order to determine how many ports a device has. This is most useful in
+ * determining the required GT/s of PCIe bandwidth necessary for optimal
+ * performance.
+ **/
+static inline int ixgbe_enumerate_functions(struct ixgbe_adapter *adapter)
+{
+	struct pci_dev *entry, *pdev = adapter->pdev;
+	int physfns = 0;
+
+	/* Some cards can not use the generic count PCIe functions method,
+	 * because they are behind a parent switch, so we hardcode these to
+	 * correct number of ports.
+	 */
+	if (ixgbe_pcie_from_parent(&adapter->hw)) {
+		physfns = 4;
+	} else {
+		list_for_each_entry(entry, &pdev->bus->devices, bus_list) {
+#ifdef CONFIG_PCI_IOV
+			/* don't count virtual functions */
+			if (entry->is_virtfn)
+				continue;
+#endif
+
+			/* When the devices on the bus don't all match our device ID,
+			 * we can't reliably determine the correct number of
+			 * functions. This can occur if a function has been direct 
+			 * attached to a virtual machine using VT-d, for example. In
+			 * this case, simply return -1 to indicate this.
+			 */
+			if ((entry->vendor != pdev->vendor) ||
+			    (entry->device != pdev->device))
+				return -1;
+
+			physfns++;
+		}
+	}
+
+	return physfns;
+}
+
 static void ixgbe_service_event_schedule(struct ixgbe_adapter *adapter)
 {
 	if (!test_bit(__IXGBE_DOWN, &adapter->state) &&
-	    !test_bit(__IXGBE_REMOVING, &adapter->state) &&
+	    !test_bit(__IXGBE_REMOVE, &adapter->state) &&
 	    !test_and_set_bit(__IXGBE_SERVICE_SCHED, &adapter->state))
-		schedule_work(&adapter->service_task);
+		queue_work(ixgbe_wq, &adapter->service_task);
+}
+
+static void ixgbe_service_event_complete(struct ixgbe_adapter *adapter)
+{
+	BUG_ON(!test_bit(__IXGBE_SERVICE_SCHED, &adapter->state));
+
+	/* flush memory to make sure state is correct before next watchog */
+	smp_mb__before_atomic();
+	clear_bit(__IXGBE_SERVICE_SCHED, &adapter->state);
 }
 
 static void ixgbe_remove_adapter(struct ixgbe_hw *hw)
@@ -345,478 +412,72 @@ static void ixgbe_check_remove(struct ixgbe_hw *hw, u32 reg)
 		ixgbe_remove_adapter(hw);
 		return;
 	}
-	value = ixgbe_read_reg(hw, IXGBE_STATUS);
+	value = IXGBE_READ_REG(hw, IXGBE_STATUS);
 	if (value == IXGBE_FAILED_READ_REG)
 		ixgbe_remove_adapter(hw);
 }
 
-/**
- * ixgbe_read_reg - Read from device register
- * @hw: hw specific details
- * @reg: offset of register to read
- *
- * Returns : value read or IXGBE_FAILED_READ_REG if removed
- *
- * This function is used to read device registers. It checks for device
- * removal by confirming any read that returns all ones by checking the
- * status register value for all ones. This function avoids reading from
- * the hardware if a removal was previously detected in which case it
- * returns IXGBE_FAILED_READ_REG (all ones).
- */
-u32 ixgbe_read_reg(struct ixgbe_hw *hw, u32 reg)
+static u32
+ixgbe_validate_register_read(struct ixgbe_hw *_hw, u32 reg, bool quiet)
 {
-	u8 __iomem *reg_addr = ACCESS_ONCE(hw->hw_addr);
+	int i;
 	u32 value;
+	u8 __iomem *reg_addr;
+	struct ixgbe_adapter *adapter = _hw->back;
 
-	if (ixgbe_removed(reg_addr))
+	reg_addr = ACCESS_ONCE(_hw->hw_addr);
+	if (IXGBE_REMOVED(reg_addr))
 		return IXGBE_FAILED_READ_REG;
-	value = readl(reg_addr + reg);
-	if (unlikely(value == IXGBE_FAILED_READ_REG))
-		ixgbe_check_remove(hw, reg);
-	return value;
-}
-
-static bool ixgbe_check_cfg_remove(struct ixgbe_hw *hw, struct pci_dev *pdev)
-{
-	u16 value;
-
-	pci_read_config_word(pdev, PCI_VENDOR_ID, &value);
-	if (value == IXGBE_FAILED_READ_CFG_WORD) {
-		ixgbe_remove_adapter(hw);
-		return true;
+	for (i = 0; i < IXGBE_DEAD_READ_RETRIES; ++i) {
+		value = readl(reg_addr + reg);
+		if (value != IXGBE_DEAD_READ_REG)
+			break;
 	}
-	return false;
-}
-
-u16 ixgbe_read_pci_cfg_word(struct ixgbe_hw *hw, u32 reg)
-{
-	struct ixgbe_adapter *adapter = hw->back;
-	u16 value;
-
-	if (ixgbe_removed(hw->hw_addr))
-		return IXGBE_FAILED_READ_CFG_WORD;
-	pci_read_config_word(adapter->pdev, reg, &value);
-	if (value == IXGBE_FAILED_READ_CFG_WORD &&
-	    ixgbe_check_cfg_remove(hw, adapter->pdev))
-		return IXGBE_FAILED_READ_CFG_WORD;
+	if (quiet)
+		return value;
+	if (value == IXGBE_DEAD_READ_REG)
+		e_err(drv, "%s: register %x read unchanged\n", __func__, reg);
+	else
+		e_warn(hw, "%s: register %x read recovered after %d retries\n",
+			__func__, reg, i + 1);
 	return value;
 }
 
-#ifdef CONFIG_PCI_IOV
-static u32 ixgbe_read_pci_cfg_dword(struct ixgbe_hw *hw, u32 reg)
+u32 ixgbe_read_reg(struct ixgbe_hw *hw, u32 reg, bool quiet)
 {
-	struct ixgbe_adapter *adapter = hw->back;
 	u32 value;
+	u8 __iomem *reg_addr;
 
-	if (ixgbe_removed(hw->hw_addr))
-		return IXGBE_FAILED_READ_CFG_DWORD;
-	pci_read_config_dword(adapter->pdev, reg, &value);
-	if (value == IXGBE_FAILED_READ_CFG_DWORD &&
-	    ixgbe_check_cfg_remove(hw, adapter->pdev))
-		return IXGBE_FAILED_READ_CFG_DWORD;
-	return value;
-}
-#endif /* CONFIG_PCI_IOV */
-
-void ixgbe_write_pci_cfg_word(struct ixgbe_hw *hw, u32 reg, u16 value)
-{
-	struct ixgbe_adapter *adapter = hw->back;
-
-	if (ixgbe_removed(hw->hw_addr))
-		return;
-	pci_write_config_word(adapter->pdev, reg, value);
-}
-
-static void ixgbe_service_event_complete(struct ixgbe_adapter *adapter)
-{
-	BUG_ON(!test_bit(__IXGBE_SERVICE_SCHED, &adapter->state));
-
-	/* flush memory to make sure state is correct before next watchdog */
-	smp_mb__before_atomic();
-	clear_bit(__IXGBE_SERVICE_SCHED, &adapter->state);
-}
-
-struct ixgbe_reg_info {
-	u32 ofs;
-	char *name;
-};
-
-static const struct ixgbe_reg_info ixgbe_reg_info_tbl[] = {
-
-	/* General Registers */
-	{IXGBE_CTRL, "CTRL"},
-	{IXGBE_STATUS, "STATUS"},
-	{IXGBE_CTRL_EXT, "CTRL_EXT"},
-
-	/* Interrupt Registers */
-	{IXGBE_EICR, "EICR"},
-
-	/* RX Registers */
-	{IXGBE_SRRCTL(0), "SRRCTL"},
-	{IXGBE_DCA_RXCTRL(0), "DRXCTL"},
-	{IXGBE_RDLEN(0), "RDLEN"},
-	{IXGBE_RDH(0), "RDH"},
-	{IXGBE_RDT(0), "RDT"},
-	{IXGBE_RXDCTL(0), "RXDCTL"},
-	{IXGBE_RDBAL(0), "RDBAL"},
-	{IXGBE_RDBAH(0), "RDBAH"},
-
-	/* TX Registers */
-	{IXGBE_TDBAL(0), "TDBAL"},
-	{IXGBE_TDBAH(0), "TDBAH"},
-	{IXGBE_TDLEN(0), "TDLEN"},
-	{IXGBE_TDH(0), "TDH"},
-	{IXGBE_TDT(0), "TDT"},
-	{IXGBE_TXDCTL(0), "TXDCTL"},
-
-	/* List Terminator */
-	{ .name = NULL }
-};
-
-
-/*
- * ixgbe_regdump - register printout routine
- */
-static void ixgbe_regdump(struct ixgbe_hw *hw, struct ixgbe_reg_info *reginfo)
-{
-	int i = 0, j = 0;
-	char rname[16];
-	u32 regs[64];
-
-	switch (reginfo->ofs) {
-	case IXGBE_SRRCTL(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_SRRCTL(i));
-		break;
-	case IXGBE_DCA_RXCTRL(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_DCA_RXCTRL(i));
-		break;
-	case IXGBE_RDLEN(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_RDLEN(i));
-		break;
-	case IXGBE_RDH(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_RDH(i));
-		break;
-	case IXGBE_RDT(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_RDT(i));
-		break;
-	case IXGBE_RXDCTL(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_RXDCTL(i));
-		break;
-	case IXGBE_RDBAL(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_RDBAL(i));
-		break;
-	case IXGBE_RDBAH(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_RDBAH(i));
-		break;
-	case IXGBE_TDBAL(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_TDBAL(i));
-		break;
-	case IXGBE_TDBAH(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_TDBAH(i));
-		break;
-	case IXGBE_TDLEN(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_TDLEN(i));
-		break;
-	case IXGBE_TDH(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_TDH(i));
-		break;
-	case IXGBE_TDT(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_TDT(i));
-		break;
-	case IXGBE_TXDCTL(0):
-		for (i = 0; i < 64; i++)
-			regs[i] = IXGBE_READ_REG(hw, IXGBE_TXDCTL(i));
-		break;
-	default:
-		pr_info("%-15s %08x\n", reginfo->name,
-			IXGBE_READ_REG(hw, reginfo->ofs));
-		return;
-	}
-
-	for (i = 0; i < 8; i++) {
-		snprintf(rname, 16, "%s[%d-%d]", reginfo->name, i*8, i*8+7);
-		pr_err("%-15s", rname);
-		for (j = 0; j < 8; j++)
-			pr_cont(" %08x", regs[i*8+j]);
-		pr_cont("\n");
-	}
-
-}
-
-/*
- * ixgbe_dump - Print registers, tx-rings and rx-rings
- */
-static void ixgbe_dump(struct ixgbe_adapter *adapter)
-{
-	struct net_device *netdev = adapter->netdev;
-	struct ixgbe_hw *hw = &adapter->hw;
-	struct ixgbe_reg_info *reginfo;
-	int n = 0;
-	struct ixgbe_ring *tx_ring;
-	struct ixgbe_tx_buffer *tx_buffer;
-	union ixgbe_adv_tx_desc *tx_desc;
-	struct my_u0 { u64 a; u64 b; } *u0;
-	struct ixgbe_ring *rx_ring;
-	union ixgbe_adv_rx_desc *rx_desc;
-	struct ixgbe_rx_buffer *rx_buffer_info;
-	u32 staterr;
-	int i = 0;
-
-	if (!netif_msg_hw(adapter))
-		return;
-
-	/* Print netdevice Info */
-	if (netdev) {
-		dev_info(&adapter->pdev->dev, "Net device Info\n");
-		pr_info("Device Name     state            "
-			"trans_start      last_rx\n");
-		pr_info("%-15s %016lX %016lX %016lX\n",
-			netdev->name,
-			netdev->state,
-			netdev->trans_start,
-			netdev->last_rx);
-	}
-
-	/* Print Registers */
-	dev_info(&adapter->pdev->dev, "Register Dump\n");
-	pr_info(" Register Name   Value\n");
-	for (reginfo = (struct ixgbe_reg_info *)ixgbe_reg_info_tbl;
-	     reginfo->name; reginfo++) {
-		ixgbe_regdump(hw, reginfo);
-	}
-
-	/* Print TX Ring Summary */
-	if (!netdev || !netif_running(netdev))
-		return;
-
-	dev_info(&adapter->pdev->dev, "TX Rings Summary\n");
-	pr_info(" %s     %s              %s        %s\n",
-		"Queue [NTU] [NTC] [bi(ntc)->dma  ]",
-		"leng", "ntw", "timestamp");
-	for (n = 0; n < adapter->num_tx_queues; n++) {
-		tx_ring = adapter->tx_ring[n];
-		tx_buffer = &tx_ring->tx_buffer_info[tx_ring->next_to_clean];
-		pr_info(" %5d %5X %5X %016llX %08X %p %016llX\n",
-			   n, tx_ring->next_to_use, tx_ring->next_to_clean,
-			   (u64)dma_unmap_addr(tx_buffer, dma),
-			   dma_unmap_len(tx_buffer, len),
-			   tx_buffer->next_to_watch,
-			   (u64)tx_buffer->time_stamp);
-	}
-
-	/* Print TX Rings */
-	if (!netif_msg_tx_done(adapter))
-		goto rx_ring_summary;
-
-	dev_info(&adapter->pdev->dev, "TX Rings Dump\n");
-
-	/* Transmit Descriptor Formats
-	 *
-	 * 82598 Advanced Transmit Descriptor
-	 *   +--------------------------------------------------------------+
-	 * 0 |         Buffer Address [63:0]                                |
-	 *   +--------------------------------------------------------------+
-	 * 8 |  PAYLEN  | POPTS  | IDX | STA | DCMD  |DTYP |  RSV |  DTALEN |
-	 *   +--------------------------------------------------------------+
-	 *   63       46 45    40 39 36 35 32 31   24 23 20 19              0
-	 *
-	 * 82598 Advanced Transmit Descriptor (Write-Back Format)
-	 *   +--------------------------------------------------------------+
-	 * 0 |                          RSV [63:0]                          |
-	 *   +--------------------------------------------------------------+
-	 * 8 |            RSV           |  STA  |          NXTSEQ           |
-	 *   +--------------------------------------------------------------+
-	 *   63                       36 35   32 31                         0
-	 *
-	 * 82599+ Advanced Transmit Descriptor
-	 *   +--------------------------------------------------------------+
-	 * 0 |         Buffer Address [63:0]                                |
-	 *   +--------------------------------------------------------------+
-	 * 8 |PAYLEN  |POPTS|CC|IDX  |STA  |DCMD  |DTYP |MAC  |RSV  |DTALEN |
-	 *   +--------------------------------------------------------------+
-	 *   63     46 45 40 39 38 36 35 32 31  24 23 20 19 18 17 16 15     0
-	 *
-	 * 82599+ Advanced Transmit Descriptor (Write-Back Format)
-	 *   +--------------------------------------------------------------+
-	 * 0 |                          RSV [63:0]                          |
-	 *   +--------------------------------------------------------------+
-	 * 8 |            RSV           |  STA  |           RSV             |
-	 *   +--------------------------------------------------------------+
-	 *   63                       36 35   32 31                         0
-	 */
-
-	for (n = 0; n < adapter->num_tx_queues; n++) {
-		tx_ring = adapter->tx_ring[n];
-		pr_info("------------------------------------\n");
-		pr_info("TX QUEUE INDEX = %d\n", tx_ring->queue_index);
-		pr_info("------------------------------------\n");
-		pr_info("%s%s    %s              %s        %s          %s\n",
-			"T [desc]     [address 63:0  ] ",
-			"[PlPOIdStDDt Ln] [bi->dma       ] ",
-			"leng", "ntw", "timestamp", "bi->skb");
-
-		for (i = 0; tx_ring->desc && (i < tx_ring->count); i++) {
-			tx_desc = IXGBE_TX_DESC(tx_ring, i);
-			tx_buffer = &tx_ring->tx_buffer_info[i];
-			u0 = (struct my_u0 *)tx_desc;
-			if (dma_unmap_len(tx_buffer, len) > 0) {
-				pr_info("T [0x%03X]    %016llX %016llX %016llX %08X %p %016llX %p",
-					i,
-					le64_to_cpu(u0->a),
-					le64_to_cpu(u0->b),
-					(u64)dma_unmap_addr(tx_buffer, dma),
-					dma_unmap_len(tx_buffer, len),
-					tx_buffer->next_to_watch,
-					(u64)tx_buffer->time_stamp,
-					tx_buffer->skb);
-				if (i == tx_ring->next_to_use &&
-					i == tx_ring->next_to_clean)
-					pr_cont(" NTC/U\n");
-				else if (i == tx_ring->next_to_use)
-					pr_cont(" NTU\n");
-				else if (i == tx_ring->next_to_clean)
-					pr_cont(" NTC\n");
-				else
-					pr_cont("\n");
-
-				if (netif_msg_pktdata(adapter) &&
-				    tx_buffer->skb)
-					print_hex_dump(KERN_INFO, "",
-						DUMP_PREFIX_ADDRESS, 16, 1,
-						tx_buffer->skb->data,
-						dma_unmap_len(tx_buffer, len),
-						true);
+	reg_addr = ACCESS_ONCE(hw->hw_addr);
+	if (IXGBE_REMOVED(reg_addr))
+		return IXGBE_FAILED_READ_REG;
+	if (unlikely(hw->phy.nw_mng_if_sel &
+		     IXGBE_NW_MNG_IF_SEL_SGMII_ENABLE)) {
+		struct ixgbe_adapter *adapter;
+		int i;
+
+		for (i = 0; i < 200; ++i) {
+			value = readl(reg_addr + IXGBE_MAC_SGMII_BUSY);
+			if (likely(!value))
+				goto writes_completed;
+			if (value == IXGBE_FAILED_READ_REG) {
+				ixgbe_remove_adapter(hw);
+				return IXGBE_FAILED_READ_REG;
 			}
+			udelay(5);
 		}
-	}
 
-	/* Print RX Rings Summary */
-rx_ring_summary:
-	dev_info(&adapter->pdev->dev, "RX Rings Summary\n");
-	pr_info("Queue [NTU] [NTC]\n");
-	for (n = 0; n < adapter->num_rx_queues; n++) {
-		rx_ring = adapter->rx_ring[n];
-		pr_info("%5d %5X %5X\n",
-			n, rx_ring->next_to_use, rx_ring->next_to_clean);
+		adapter = hw->back;
+		e_warn(hw, "register writes incomplete %08x\n", value);
 	}
 
-	/* Print RX Rings */
-	if (!netif_msg_rx_status(adapter))
-		return;
-
-	dev_info(&adapter->pdev->dev, "RX Rings Dump\n");
-
-	/* Receive Descriptor Formats
-	 *
-	 * 82598 Advanced Receive Descriptor (Read) Format
-	 *    63                                           1        0
-	 *    +-----------------------------------------------------+
-	 *  0 |       Packet Buffer Address [63:1]           |A0/NSE|
-	 *    +----------------------------------------------+------+
-	 *  8 |       Header Buffer Address [63:1]           |  DD  |
-	 *    +-----------------------------------------------------+
-	 *
-	 *
-	 * 82598 Advanced Receive Descriptor (Write-Back) Format
-	 *
-	 *   63       48 47    32 31  30      21 20 16 15   4 3     0
-	 *   +------------------------------------------------------+
-	 * 0 |       RSS Hash /  |SPH| HDR_LEN  | RSV |Packet|  RSS |
-	 *   | Packet   | IP     |   |          |     | Type | Type |
-	 *   | Checksum | Ident  |   |          |     |      |      |
-	 *   +------------------------------------------------------+
-	 * 8 | VLAN Tag | Length | Extended Error | Extended Status |
-	 *   +------------------------------------------------------+
-	 *   63       48 47    32 31            20 19               0
-	 *
-	 * 82599+ Advanced Receive Descriptor (Read) Format
-	 *    63                                           1        0
-	 *    +-----------------------------------------------------+
-	 *  0 |       Packet Buffer Address [63:1]           |A0/NSE|
-	 *    +----------------------------------------------+------+
-	 *  8 |       Header Buffer Address [63:1]           |  DD  |
-	 *    +-----------------------------------------------------+
-	 *
-	 *
-	 * 82599+ Advanced Receive Descriptor (Write-Back) Format
-	 *
-	 *   63       48 47    32 31  30      21 20 17 16   4 3     0
-	 *   +------------------------------------------------------+
-	 * 0 |RSS / Frag Checksum|SPH| HDR_LEN  |RSC- |Packet|  RSS |
-	 *   |/ RTT / PCoE_PARAM |   |          | CNT | Type | Type |
-	 *   |/ Flow Dir Flt ID  |   |          |     |      |      |
-	 *   +------------------------------------------------------+
-	 * 8 | VLAN Tag | Length |Extended Error| Xtnd Status/NEXTP |
-	 *   +------------------------------------------------------+
-	 *   63       48 47    32 31          20 19                 0
-	 */
-
-	for (n = 0; n < adapter->num_rx_queues; n++) {
-		rx_ring = adapter->rx_ring[n];
-		pr_info("------------------------------------\n");
-		pr_info("RX QUEUE INDEX = %d\n", rx_ring->queue_index);
-		pr_info("------------------------------------\n");
-		pr_info("%s%s%s",
-			"R  [desc]      [ PktBuf     A0] ",
-			"[  HeadBuf   DD] [bi->dma       ] [bi->skb       ] ",
-			"<-- Adv Rx Read format\n");
-		pr_info("%s%s%s",
-			"RWB[desc]      [PcsmIpSHl PtRs] ",
-			"[vl er S cks ln] ---------------- [bi->skb       ] ",
-			"<-- Adv Rx Write-Back format\n");
-
-		for (i = 0; i < rx_ring->count; i++) {
-			rx_buffer_info = &rx_ring->rx_buffer_info[i];
-			rx_desc = IXGBE_RX_DESC(rx_ring, i);
-			u0 = (struct my_u0 *)rx_desc;
-			staterr = le32_to_cpu(rx_desc->wb.upper.status_error);
-			if (staterr & IXGBE_RXD_STAT_DD) {
-				/* Descriptor Done */
-				pr_info("RWB[0x%03X]     %016llX "
-					"%016llX ---------------- %p", i,
-					le64_to_cpu(u0->a),
-					le64_to_cpu(u0->b),
-					rx_buffer_info->skb);
-			} else {
-				pr_info("R  [0x%03X]     %016llX "
-					"%016llX %016llX %p", i,
-					le64_to_cpu(u0->a),
-					le64_to_cpu(u0->b),
-					(u64)rx_buffer_info->dma,
-					rx_buffer_info->skb);
-
-				if (netif_msg_pktdata(adapter) &&
-				    rx_buffer_info->dma) {
-					print_hex_dump(KERN_INFO, "",
-					   DUMP_PREFIX_ADDRESS, 16, 1,
-					   page_address(rx_buffer_info->page) +
-						    rx_buffer_info->page_offset,
-					   ixgbe_rx_bufsz(rx_ring), true);
-				}
-			}
-
-			if (i == rx_ring->next_to_use)
-				pr_cont(" NTU\n");
-			else if (i == rx_ring->next_to_clean)
-				pr_cont(" NTC\n");
-			else
-				pr_cont("\n");
-
-		}
-	}
+writes_completed:
+	value = readl(reg_addr + reg);
+	if (unlikely(value == IXGBE_FAILED_READ_REG))
+		ixgbe_check_remove(hw, reg);
+	if (unlikely(value == IXGBE_DEAD_READ_REG))
+		value = ixgbe_validate_register_read(hw, reg, quiet);
+	return value;
 }
 
 static void ixgbe_release_hw_control(struct ixgbe_adapter *adapter)
@@ -839,7 +500,7 @@ static void ixgbe_get_hw_control(struct ixgbe_adapter *adapter)
 			ctrl_ext | IXGBE_CTRL_EXT_DRV_LOAD);
 }
 
-/**
+/*
  * ixgbe_set_ivar - set the IVAR registers, mapping interrupt causes to vectors
  * @adapter: pointer to adapter struct
  * @direction: 0 for Rx, 1 for Tx, -1 for other causes
@@ -867,6 +528,7 @@ static void ixgbe_set_ivar(struct ixgbe_adapter *adapter, s8 direction,
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		if (direction == -1) {
 			/* other causes */
 			msix_vector |= IXGBE_IVAR_ALLOC_VAL;
@@ -905,6 +567,7 @@ static inline void ixgbe_irq_rearm_queues(struct ixgbe_adapter *adapter,
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		mask = (qmask & 0xFFFFFFFF);
 		IXGBE_WRITE_REG(&adapter->hw, IXGBE_EICS_EX(0), mask);
 		mask = (qmask >> 32);
@@ -915,28 +578,6 @@ static inline void ixgbe_irq_rearm_queues(struct ixgbe_adapter *adapter,
 	}
 }
 
-void ixgbe_unmap_and_free_tx_resource(struct ixgbe_ring *ring,
-				      struct ixgbe_tx_buffer *tx_buffer)
-{
-	if (tx_buffer->skb) {
-		dev_kfree_skb_any(tx_buffer->skb);
-		if (dma_unmap_len(tx_buffer, len))
-			dma_unmap_single(ring->dev,
-					 dma_unmap_addr(tx_buffer, dma),
-					 dma_unmap_len(tx_buffer, len),
-					 DMA_TO_DEVICE);
-	} else if (dma_unmap_len(tx_buffer, len)) {
-		dma_unmap_page(ring->dev,
-			       dma_unmap_addr(tx_buffer, dma),
-			       dma_unmap_len(tx_buffer, len),
-			       DMA_TO_DEVICE);
-	}
-	tx_buffer->next_to_watch = NULL;
-	tx_buffer->skb = NULL;
-	dma_unmap_len_set(tx_buffer, len, 0);
-	/* tx_buffer must be completely set up in the transmit path */
-}
-
 static void ixgbe_update_xoff_rx_lfc(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
@@ -971,13 +612,14 @@ static void ixgbe_update_xoff_received(struct ixgbe_adapter *adapter)
 	struct ixgbe_hw *hw = &adapter->hw;
 	struct ixgbe_hw_stats *hwstats = &adapter->stats;
 	u32 xoff[8] = {0};
-	u8 tc;
 	int i;
 	bool pfc_en = adapter->dcb_cfg.pfc_mode_enable;
 
+#ifdef HAVE_DCBNL_IEEE
 	if (adapter->ixgbe_ieee_pfc)
 		pfc_en |= !!(adapter->ixgbe_ieee_pfc->pfc_en);
 
+#endif
 	if (!(adapter->flags & IXGBE_FLAG_DCB_ENABLED) || !pfc_en) {
 		ixgbe_update_xoff_rx_lfc(adapter);
 		return;
@@ -985,27 +627,22 @@ static void ixgbe_update_xoff_received(struct ixgbe_adapter *adapter)
 
 	/* update stats for each tc, only valid with PFC enabled */
 	for (i = 0; i < MAX_TX_PACKET_BUFFERS; i++) {
-		u32 pxoffrxc;
-
 		switch (hw->mac.type) {
 		case ixgbe_mac_82598EB:
-			pxoffrxc = IXGBE_READ_REG(hw, IXGBE_PXOFFRXC(i));
+			xoff[i] = IXGBE_READ_REG(hw, IXGBE_PXOFFRXC(i));
 			break;
 		default:
-			pxoffrxc = IXGBE_READ_REG(hw, IXGBE_PXOFFRXCNT(i));
+			xoff[i] = IXGBE_READ_REG(hw, IXGBE_PXOFFRXCNT(i));
 		}
-		hwstats->pxoffrxc[i] += pxoffrxc;
-		/* Get the TC for given UP */
-		tc = netdev_get_prio_tc_map(adapter->netdev, i);
-		xoff[tc] += pxoffrxc;
+		hwstats->pxoffrxc[i] += xoff[i];
 	}
 
 	/* disarm tx queues that have received xoff frames */
 	for (i = 0; i < adapter->num_tx_queues; i++) {
 		struct ixgbe_ring *tx_ring = adapter->tx_ring[i];
+		u8 tc = tx_ring->dcb_tc;
 
-		tc = tx_ring->dcb_tc;
-		if (xoff[tc])
+		if ((tc <= 7) && (xoff[tc]))
 			clear_bit(__IXGBE_HANG_CHECK_ARMED, &tx_ring->state);
 	}
 }
@@ -1017,31 +654,23 @@ static u64 ixgbe_get_tx_completed(struct ixgbe_ring *ring)
 
 static u64 ixgbe_get_tx_pending(struct ixgbe_ring *ring)
 {
-	struct ixgbe_adapter *adapter;
+	struct ixgbe_adapter *adapter = ring->q_vector->adapter;
 	struct ixgbe_hw *hw;
 	u32 head, tail;
 
-	if (ring->l2_accel_priv)
-		adapter = ring->l2_accel_priv->real_adapter;
-	else
-		adapter = netdev_priv(ring->netdev);
-
 	hw = &adapter->hw;
 	head = IXGBE_READ_REG(hw, IXGBE_TDH(ring->reg_idx));
 	tail = IXGBE_READ_REG(hw, IXGBE_TDT(ring->reg_idx));
 
-	if (head != tail)
-		return (head < tail) ?
-			tail - head : (tail + ring->count - head);
-
-	return 0;
+	return ((head <= tail) ? tail : tail + ring->count) - head;
 }
 
-static inline bool ixgbe_check_tx_hang(struct ixgbe_ring *tx_ring)
+static bool ixgbe_check_tx_hang(struct ixgbe_ring *tx_ring)
 {
 	u32 tx_done = ixgbe_get_tx_completed(tx_ring);
 	u32 tx_done_old = tx_ring->tx_stats.tx_done_old;
 	u32 tx_pending = ixgbe_get_tx_pending(tx_ring);
+	bool ret = false;
 
 	clear_check_for_tx_hang(tx_ring);
 
@@ -1053,20 +682,22 @@ static inline bool ixgbe_check_tx_hang(struct ixgbe_ring *tx_ring)
 	 * bit is cleared if a pause frame is received to remove
 	 * false hang detection due to PFC or 802.3x frames. By
 	 * requiring this to fail twice we avoid races with
-	 * pfc clearing the ARMED bit and conditions where we
+	 * PFC clearing the ARMED bit and conditions where we
 	 * run the check_tx_hang logic with a transmit completion
 	 * pending but without time to complete it yet.
 	 */
-	if (tx_done_old == tx_done && tx_pending)
+	if ((tx_done_old == tx_done) && tx_pending) {
 		/* make sure it is true for two checks in a row */
-		return test_and_set_bit(__IXGBE_HANG_CHECK_ARMED,
-					&tx_ring->state);
-	/* update completed stats and continue */
-	tx_ring->tx_stats.tx_done_old = tx_done;
-	/* reset the countdown */
-	clear_bit(__IXGBE_HANG_CHECK_ARMED, &tx_ring->state);
+		ret = test_and_set_bit(__IXGBE_HANG_CHECK_ARMED,
+				       &tx_ring->state);
+	} else {
+		/* update completed stats and continue */
+		tx_ring->tx_stats.tx_done_old = tx_done;
+		/* reset the countdown */
+		clear_bit(__IXGBE_HANG_CHECK_ARMED, &tx_ring->state);
+	}
 
-	return false;
+	return ret;
 }
 
 /**
@@ -1078,19 +709,47 @@ static void ixgbe_tx_timeout_reset(struct ixgbe_adapter *adapter)
 
 	/* Do the reset outside of interrupt context */
 	if (!test_bit(__IXGBE_DOWN, &adapter->state)) {
-		adapter->flags2 |= IXGBE_FLAG2_RESET_REQUESTED;
-		e_warn(drv, "initiating reset due to tx timeout\n");
+		set_bit(__IXGBE_RESET_REQUESTED, &adapter->state);
 		ixgbe_service_event_schedule(adapter);
 	}
 }
 
 /**
- * ixgbe_clean_tx_irq - Reclaim resources after transmit completes
- * @q_vector: structure containing interrupt and ring information
- * @tx_ring: tx ring to clean
+ * ixgbe_tx_timeout - Respond to a Tx Hang
+ * @netdev: network interface device structure
  **/
-static bool ixgbe_clean_tx_irq(struct ixgbe_q_vector *q_vector,
-			       struct ixgbe_ring *tx_ring)
+static void ixgbe_tx_timeout(struct net_device *netdev)
+{
+struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	bool real_tx_hang = false;
+	int i;
+
+#define TX_TIMEO_LIMIT 16000
+	for (i = 0; i < adapter->num_tx_queues; i++) {
+		struct ixgbe_ring *tx_ring = adapter->tx_ring[i];
+		if (check_for_tx_hang(tx_ring) && ixgbe_check_tx_hang(tx_ring))
+			real_tx_hang = true;
+	}
+
+	if (real_tx_hang) {
+		ixgbe_tx_timeout_reset(adapter);
+	} else {
+		e_info(drv, "Fake Tx hang detected with timeout of %d "
+			"seconds\n", netdev->watchdog_timeo/HZ);
+
+		/* fake Tx hang - increase the kernel timeout */
+		if (netdev->watchdog_timeo < TX_TIMEO_LIMIT)
+			netdev->watchdog_timeo *= 2;
+	}
+}
+
+/**
+ * ixgbe_clean_tx_irq - Reclaim resources after transmit completes
+ * @q_vector: structure containing interrupt and ring information
+ * @tx_ring: tx ring to clean
+ **/
+static bool ixgbe_clean_tx_irq(struct ixgbe_q_vector *q_vector,
+			       struct ixgbe_ring *tx_ring)
 {
 	struct ixgbe_adapter *adapter = q_vector->adapter;
 	struct ixgbe_tx_buffer *tx_buffer;
@@ -1114,7 +773,7 @@ static bool ixgbe_clean_tx_irq(struct ixgbe_q_vector *q_vector,
 			break;
 
 		/* prevent any other reads prior to eop_desc */
-		smp_rmb();
+		read_barrier_depends();
 
 		/* if DD is not set pending work has not been completed */
 		if (!(eop_desc->wb.status & cpu_to_le32(IXGBE_TXD_STAT_DD)))
@@ -1128,7 +787,7 @@ static bool ixgbe_clean_tx_irq(struct ixgbe_q_vector *q_vector,
 		total_packets += tx_buffer->gso_segs;
 
 		/* free the skb */
-		dev_consume_skb_any(tx_buffer->skb);
+		dev_kfree_skb_any(tx_buffer->skb);
 
 		/* unmap skb header data */
 		dma_unmap_single(tx_ring->dev,
@@ -1137,7 +796,6 @@ static bool ixgbe_clean_tx_irq(struct ixgbe_q_vector *q_vector,
 				 DMA_TO_DEVICE);
 
 		/* clear tx_buffer data */
-		tx_buffer->skb = NULL;
 		dma_unmap_len_set(tx_buffer, len, 0);
 
 		/* unmap remaining buffers */
@@ -1194,23 +852,23 @@ static bool ixgbe_clean_tx_irq(struct ixgbe_q_vector *q_vector,
 			"  Tx Queue             <%d>\n"
 			"  TDH, TDT             <%x>, <%x>\n"
 			"  next_to_use          <%x>\n"
-			"  next_to_clean        <%x>\n"
-			"tx_buffer_info[next_to_clean]\n"
-			"  time_stamp           <%lx>\n"
-			"  jiffies              <%lx>\n",
+			"  next_to_clean        <%x>\n",
 			tx_ring->queue_index,
 			IXGBE_READ_REG(hw, IXGBE_TDH(tx_ring->reg_idx)),
 			IXGBE_READ_REG(hw, IXGBE_TDT(tx_ring->reg_idx)),
-			tx_ring->next_to_use, i,
+			tx_ring->next_to_use, i);
+		e_err(drv, "tx_buffer_info[next_to_clean]\n"
+			"  time_stamp           <%lx>\n"
+			"  jiffies              <%lx>\n",
 			tx_ring->tx_buffer_info[i].time_stamp, jiffies);
 
-		netif_stop_subqueue(tx_ring->netdev, tx_ring->queue_index);
+		netif_stop_subqueue(netdev_ring(tx_ring),
+				    ring_queue_index(tx_ring));
 
 		e_info(probe,
 		       "tx hang %d detected on queue %d, resetting adapter\n",
-			adapter->tx_timeout_count + 1, tx_ring->queue_index);
+		       adapter->tx_timeout_count + 1, tx_ring->queue_index);
 
-		/* schedule immediate reset if we believe we hung */
 		ixgbe_tx_timeout_reset(adapter);
 
 		/* the adapter is about to reset, no point in enabling stuff */
@@ -1221,25 +879,33 @@ static bool ixgbe_clean_tx_irq(struct ixgbe_q_vector *q_vector,
 				  total_packets, total_bytes);
 
 #define TX_WAKE_THRESHOLD (DESC_NEEDED * 2)
-	if (unlikely(total_packets && netif_carrier_ok(tx_ring->netdev) &&
+	if (unlikely(total_packets && netif_carrier_ok(netdev_ring(tx_ring)) &&
 		     (ixgbe_desc_unused(tx_ring) >= TX_WAKE_THRESHOLD))) {
 		/* Make sure that anybody stopping the queue after this
 		 * sees the new next_to_clean.
 		 */
 		smp_mb();
-		if (__netif_subqueue_stopped(tx_ring->netdev,
-					     tx_ring->queue_index)
-		    && !test_bit(__IXGBE_DOWN, &adapter->state)) {
-			netif_wake_subqueue(tx_ring->netdev,
-					    tx_ring->queue_index);
+#ifdef HAVE_TX_MQ
+		if (__netif_subqueue_stopped(netdev_ring(tx_ring),
+					     ring_queue_index(tx_ring))
+		    && !test_bit(__IXGBE_DOWN, &q_vector->adapter->state)) {
+			netif_wake_subqueue(netdev_ring(tx_ring),
+					    ring_queue_index(tx_ring));
+			++tx_ring->tx_stats.restart_queue;
+		}
+#else
+		if (netif_queue_stopped(netdev_ring(tx_ring)) &&
+		    !test_bit(__IXGBE_DOWN, &q_vector->adapter->state)) {
+			netif_wake_queue(netdev_ring(tx_ring));
 			++tx_ring->tx_stats.restart_queue;
 		}
+#endif
 	}
 
 	return !!budget;
 }
 
-#ifdef CONFIG_IXGBE_DCA
+#if IS_ENABLED(CONFIG_DCA)
 static void ixgbe_update_tx_dca(struct ixgbe_adapter *adapter,
 				struct ixgbe_ring *tx_ring,
 				int cpu)
@@ -1331,7 +997,7 @@ out_no_update:
 
 static void ixgbe_setup_dca(struct ixgbe_adapter *adapter)
 {
-	int i;
+	int v_idx;
 
 	/* always use CB2 mode, difference is masked in the CB driver */
 	if (adapter->flags & IXGBE_FLAG_DCA_ENABLED)
@@ -1341,9 +1007,9 @@ static void ixgbe_setup_dca(struct ixgbe_adapter *adapter)
 		IXGBE_WRITE_REG(&adapter->hw, IXGBE_DCA_CTRL,
 				IXGBE_DCA_CTRL_DCA_DISABLE);
 
-	for (i = 0; i < adapter->num_q_vectors; i++) {
-		adapter->q_vector[i]->cpu = -1;
-		ixgbe_update_dca(adapter->q_vector[i]);
+	for (v_idx = 0; v_idx < adapter->num_q_vectors; v_idx++) {
+		adapter->q_vector[v_idx]->cpu = -1;
+		ixgbe_update_dca(adapter->q_vector[v_idx]);
 	}
 }
 
@@ -1360,41 +1026,41 @@ static int __ixgbe_notify_dca(struct device *dev, void *data)
 		/* if we're already enabled, don't do it again */
 		if (adapter->flags & IXGBE_FLAG_DCA_ENABLED)
 			break;
-		if (dca_add_requester(dev) == 0) {
+		if (dca_add_requester(dev) == IXGBE_SUCCESS) {
 			adapter->flags |= IXGBE_FLAG_DCA_ENABLED;
-			IXGBE_WRITE_REG(&adapter->hw, IXGBE_DCA_CTRL,
-					IXGBE_DCA_CTRL_DCA_MODE_CB2);
+			IXGBE_WRITE_REG(&adapter->hw, IXGBE_DCA_CTRL, 2);
 			break;
 		}
-		/* Fall Through since DCA is disabled. */
+		/* fall through - DCA is disabled */
 	case DCA_PROVIDER_REMOVE:
 		if (adapter->flags & IXGBE_FLAG_DCA_ENABLED) {
 			dca_remove_requester(dev);
 			adapter->flags &= ~IXGBE_FLAG_DCA_ENABLED;
-			IXGBE_WRITE_REG(&adapter->hw, IXGBE_DCA_CTRL,
-					IXGBE_DCA_CTRL_DCA_DISABLE);
+			IXGBE_WRITE_REG(&adapter->hw, IXGBE_DCA_CTRL, 1);
 		}
 		break;
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
+#endif /* CONFIG_DCA */
 
-#endif /* CONFIG_IXGBE_DCA */
-
+#ifdef NETIF_F_RXHASH
 #define IXGBE_RSS_L4_TYPES_MASK \
 	((1ul << IXGBE_RXDADV_RSSTYPE_IPV4_TCP) | \
 	 (1ul << IXGBE_RXDADV_RSSTYPE_IPV4_UDP) | \
 	 (1ul << IXGBE_RXDADV_RSSTYPE_IPV6_TCP) | \
-	 (1ul << IXGBE_RXDADV_RSSTYPE_IPV6_UDP))
+	 (1ul << IXGBE_RXDADV_RSSTYPE_IPV6_UDP) | \
+	 (1ul << IXGBE_RXDADV_RSSTYPE_IPV6_TCP_EX) | \
+	 (1ul << IXGBE_RXDADV_RSSTYPE_IPV6_UDP_EX))
 
 static inline void ixgbe_rx_hash(struct ixgbe_ring *ring,
 				 union ixgbe_adv_rx_desc *rx_desc,
 				 struct sk_buff *skb)
 {
-	u16 rss_type;
+	u16 rss_type; 
 
-	if (!(ring->netdev->features & NETIF_F_RXHASH))
+	if (!(netdev_ring(ring)->features & NETIF_F_RXHASH))
 		return;
 
 	rss_type = le16_to_cpu(rx_desc->wb.lower.lo_dword.hs_rss.pkt_info) &
@@ -1407,8 +1073,9 @@ static inline void ixgbe_rx_hash(struct ixgbe_ring *ring,
 		     (IXGBE_RSS_L4_TYPES_MASK & (1ul << rss_type)) ?
 		     PKT_HASH_TYPE_L4 : PKT_HASH_TYPE_L3);
 }
+#endif /* NETIF_F_RXHASH */
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 /**
  * ixgbe_rx_is_fcoe - check the rx desc for incoming pkt type
  * @ring: structure containing ring specific data
@@ -1426,8 +1093,8 @@ static inline bool ixgbe_rx_is_fcoe(struct ixgbe_ring *ring,
 		(cpu_to_le16(IXGBE_ETQF_FILTER_FCOE <<
 			     IXGBE_RXDADV_PKTTYPE_ETQF_SHIFT)));
 }
+#endif /* CONFIG_FCOE */
 
-#endif /* IXGBE_FCOE */
 /**
  * ixgbe_rx_checksum - indicate in skb if hw indicated a good cksum
  * @ring: structure containing ring specific data
@@ -1439,19 +1106,21 @@ static inline void ixgbe_rx_checksum(struct ixgbe_ring *ring,
 				     struct sk_buff *skb)
 {
 	__le16 pkt_info = rx_desc->wb.lower.lo_dword.hs_rss.pkt_info;
-	__le16 hdr_info = rx_desc->wb.lower.lo_dword.hs_rss.hdr_info;
 	bool encap_pkt = false;
 
 	skb_checksum_none_assert(skb);
 
 	/* Rx csum disabled */
-	if (!(ring->netdev->features & NETIF_F_RXCSUM))
+	if (!(netdev_ring(ring)->features & NETIF_F_RXCSUM))
 		return;
 
-	if ((pkt_info & cpu_to_le16(IXGBE_RXDADV_PKTTYPE_VXLAN)) &&
-	    (hdr_info & cpu_to_le16(IXGBE_RXDADV_PKTTYPE_TUNNEL >> 16))) {
+	/* check for VXLAN or Geneve packet type */
+	if (pkt_info & cpu_to_le16(IXGBE_RXDADV_PKTTYPE_VXLAN)) {
 		encap_pkt = true;
+#if defined(HAVE_UDP_ENC_RX_OFFLOAD) || defined(HAVE_VXLAN_RX_OFFLOAD)
 		skb->encapsulation = 1;
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD || HAVE_VXLAN_RX_OFFLOAD */
+		skb->ip_summed = CHECKSUM_NONE;
 	}
 
 	/* if IP and error */
@@ -1465,6 +1134,7 @@ static inline void ixgbe_rx_checksum(struct ixgbe_ring *ring,
 		return;
 
 	if (ixgbe_test_staterr(rx_desc, IXGBE_RXDADV_ERR_TCPE)) {
+
 		/*
 		 * 82599 errata, UDP frames with a 0 checksum can be marked as
 		 * checksum errors.
@@ -1482,14 +1152,81 @@ static inline void ixgbe_rx_checksum(struct ixgbe_ring *ring,
 	if (encap_pkt) {
 		if (!ixgbe_test_staterr(rx_desc, IXGBE_RXD_STAT_OUTERIPCS))
 			return;
-
+		
 		if (ixgbe_test_staterr(rx_desc, IXGBE_RXDADV_ERR_OUTERIPER)) {
-			ring->rx_stats.csum_err++;
+			skb->ip_summed = CHECKSUM_NONE;
 			return;
 		}
+#ifdef HAVE_SKBUFF_CSUM_LEVEL
 		/* If we checked the outer header let the stack know */
 		skb->csum_level = 1;
+#endif /* HAVE_SKBUFF_CSUM_LEVEL */
+	}
+}
+
+static inline void ixgbe_release_rx_desc(struct ixgbe_ring *rx_ring, u32 val)
+{
+	rx_ring->next_to_use = val;
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+
+	/* update next to alloc since we have filled the ring */
+	rx_ring->next_to_alloc = val;
+#endif
+	/*
+	 * Force memory writes to complete before letting h/w
+	 * know there are new descriptors to fetch.  (Only
+	 * applicable for weak-ordered memory model archs,
+	 * such as IA-64).
+	 */
+	wmb();
+	writel(val, rx_ring->tail);
+}
+
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+static bool ixgbe_alloc_mapped_skb(struct ixgbe_ring *rx_ring,
+				   struct ixgbe_rx_buffer *bi)
+{
+	struct sk_buff *skb = bi->skb;
+	dma_addr_t dma = bi->dma;
+
+	if (unlikely(dma))
+		return true;
+
+	if (likely(!skb)) {
+		skb = netdev_alloc_skb_ip_align(netdev_ring(rx_ring),
+						rx_ring->rx_buf_len);
+		if (unlikely(!skb)) {
+			rx_ring->rx_stats.alloc_rx_buff_failed++;
+			return false;
+		}
+
+		bi->skb = skb;
+
+	}
+
+	dma = dma_map_single(rx_ring->dev, skb->data,
+			     rx_ring->rx_buf_len, DMA_FROM_DEVICE);
+
+	/*
+	 * if mapping failed free memory back to system since
+	 * there isn't much point in holding memory we can't use
+	 */
+	if (dma_mapping_error(rx_ring->dev, dma)) {
+		dev_kfree_skb_any(skb);
+		bi->skb = NULL;
+
+		rx_ring->rx_stats.alloc_rx_buff_failed++;
+		return false;
 	}
+
+	bi->dma = dma;
+	return true;
+}
+
+#else /* !CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
+static inline unsigned int ixgbe_rx_offset(struct ixgbe_ring *rx_ring)
+{
+	return ring_uses_build_skb(rx_ring) ? IXGBE_SKB_PAD : 0;
 }
 
 static bool ixgbe_alloc_mapped_page(struct ixgbe_ring *rx_ring,
@@ -1503,15 +1240,18 @@ static bool ixgbe_alloc_mapped_page(struct ixgbe_ring *rx_ring,
 		return true;
 
 	/* alloc new page for storage */
-	page = dev_alloc_pages(ixgbe_rx_pg_order(rx_ring));
+	page = alloc_pages(GFP_ATOMIC | __GFP_COLD | __GFP_COMP,
+			   ixgbe_rx_pg_order(rx_ring));
 	if (unlikely(!page)) {
 		rx_ring->rx_stats.alloc_rx_page_failed++;
 		return false;
 	}
 
 	/* map page for use */
-	dma = dma_map_page(rx_ring->dev, page, 0,
-			   ixgbe_rx_pg_size(rx_ring), DMA_FROM_DEVICE);
+	dma = dma_map_page_attrs(rx_ring->dev, page, 0,
+				 ixgbe_rx_pg_size(rx_ring),
+				 DMA_FROM_DEVICE,
+				 IXGBE_RX_DMA_ATTR);
 
 	/*
 	 * if mapping failed free memory back to system since
@@ -1526,11 +1266,13 @@ static bool ixgbe_alloc_mapped_page(struct ixgbe_ring *rx_ring,
 
 	bi->dma = dma;
 	bi->page = page;
-	bi->page_offset = 0;
+	bi->page_offset = ixgbe_rx_offset(rx_ring);
+	bi->pagecnt_bias = 1;
 
 	return true;
 }
 
+#endif /* !CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
 /**
  * ixgbe_alloc_rx_buffers - Replace used receive buffers
  * @rx_ring: ring to place buffers on
@@ -1541,6 +1283,9 @@ void ixgbe_alloc_rx_buffers(struct ixgbe_ring *rx_ring, u16 cleaned_count)
 	union ixgbe_adv_rx_desc *rx_desc;
 	struct ixgbe_rx_buffer *bi;
 	u16 i = rx_ring->next_to_use;
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	u16 bufsz;
+#endif
 
 	/* nothing to do */
 	if (!cleaned_count)
@@ -1549,16 +1294,34 @@ void ixgbe_alloc_rx_buffers(struct ixgbe_ring *rx_ring, u16 cleaned_count)
 	rx_desc = IXGBE_RX_DESC(rx_ring, i);
 	bi = &rx_ring->rx_buffer_info[i];
 	i -= rx_ring->count;
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+
+	bufsz = ixgbe_rx_bufsz(rx_ring);
+#endif
 
 	do {
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+		if (!ixgbe_alloc_mapped_skb(rx_ring, bi))
+			break;
+#else
 		if (!ixgbe_alloc_mapped_page(rx_ring, bi))
 			break;
 
+		/* sync the buffer for use by the device */
+		dma_sync_single_range_for_device(rx_ring->dev, bi->dma,
+						 bi->page_offset, bufsz,
+						 DMA_FROM_DEVICE);
+#endif
+
 		/*
 		 * Refresh the desc even if buffer_addrs didn't change
 		 * because each write-back erases this info.
 		 */
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+		rx_desc->read.pkt_addr = cpu_to_le64(bi->dma);
+#else
 		rx_desc->read.pkt_addr = cpu_to_le64(bi->dma + bi->page_offset);
+#endif
 
 		rx_desc++;
 		bi++;
@@ -1569,34 +1332,129 @@ void ixgbe_alloc_rx_buffers(struct ixgbe_ring *rx_ring, u16 cleaned_count)
 			i -= rx_ring->count;
 		}
 
-		/* clear the status bits for the next_to_use descriptor */
-		rx_desc->wb.upper.status_error = 0;
+		/* clear the length for the next_to_use descriptor */
+		rx_desc->wb.upper.length = 0;
 
 		cleaned_count--;
 	} while (cleaned_count);
 
 	i += rx_ring->count;
 
-	if (rx_ring->next_to_use != i) {
-		rx_ring->next_to_use = i;
+	if (rx_ring->next_to_use != i)
+		ixgbe_release_rx_desc(rx_ring, i);
+}
+
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+/**
+ * ixgbe_merge_active_tail - merge active tail into lro skb
+ * @tail: pointer to active tail in frag_list
+ *
+ * This function merges the length and data of an active tail into the
+ * skb containing the frag_list.  It resets the tail's pointer to the head,
+ * but it leaves the heads pointer to tail intact.
+ **/
+static inline struct sk_buff *ixgbe_merge_active_tail(struct sk_buff *tail)
+{
+	struct sk_buff *head = IXGBE_CB(tail)->head;
 
-		/* update next to alloc since we have filled the ring */
-		rx_ring->next_to_alloc = i;
+	if (!head)
+		return tail;
 
-		/* Force memory writes to complete before letting h/w
-		 * know there are new descriptors to fetch.  (Only
-		 * applicable for weak-ordered memory model archs,
-		 * such as IA-64).
-		 */
-		wmb();
-		writel(i, rx_ring->tail);
+	head->len += tail->len;
+	head->data_len += tail->len;
+	head->truesize += tail->truesize;
+
+	IXGBE_CB(tail)->head = NULL;
+
+	return head;
+}
+
+/**
+ * ixgbe_add_active_tail - adds an active tail into the skb frag_list
+ * @head: pointer to the start of the skb
+ * @tail: pointer to active tail to add to frag_list
+ *
+ * This function adds an active tail to the end of the frag list.  This tail
+ * will still be receiving data so we cannot yet ad it's stats to the main
+ * skb.  That is done via ixgbe_merge_active_tail.
+ **/
+static inline void ixgbe_add_active_tail(struct sk_buff *head,
+					 struct sk_buff *tail)
+{
+	struct sk_buff *old_tail = IXGBE_CB(head)->tail;
+
+	if (old_tail) {
+		ixgbe_merge_active_tail(old_tail);
+		old_tail->next = tail;
+	} else {
+		skb_shinfo(head)->frag_list = tail;
+	}
+
+	IXGBE_CB(tail)->head = head;
+	IXGBE_CB(head)->tail = tail;
+}
+
+/**
+ * ixgbe_close_active_frag_list - cleanup pointers on a frag_list skb
+ * @head: pointer to head of an active frag list
+ *
+ * This function will clear the frag_tail_tracker pointer on an active
+ * frag_list and returns true if the pointer was actually set
+ **/
+static inline bool ixgbe_close_active_frag_list(struct sk_buff *head)
+{
+	struct sk_buff *tail = IXGBE_CB(head)->tail;
+
+	if (!tail)
+		return false;
+
+	ixgbe_merge_active_tail(tail);
+
+	IXGBE_CB(head)->tail = NULL;
+
+	return true;
+}
+
+#endif
+#ifdef HAVE_VLAN_RX_REGISTER
+/**
+ * ixgbe_receive_skb - Send a completed packet up the stack
+ * @q_vector: structure containing interrupt and ring information
+ * @skb: packet to send up
+ **/
+static void ixgbe_receive_skb(struct ixgbe_q_vector *q_vector,
+			      struct sk_buff *skb)
+{
+	u16 vlan_tag = IXGBE_CB(skb)->vid;
+
+#if defined(NETIF_F_HW_VLAN_TX) || defined(NETIF_F_HW_VLAN_CTAG_TX)
+	if (vlan_tag & VLAN_VID_MASK) {
+		/* by placing vlgrp at start of structure we can alias it */
+		struct vlan_group **vlgrp = netdev_priv(skb->dev);
+		if (!*vlgrp)
+			dev_kfree_skb_any(skb);
+		else if (q_vector->netpoll_rx)
+			vlan_hwaccel_rx(skb, *vlgrp, vlan_tag);
+		else
+			vlan_gro_receive(&q_vector->napi,
+					 *vlgrp, vlan_tag, skb);
+	} else {
+#endif /* NETIF_F_HW_VLAN_TX || NETIF_F_HW_VLAN_CTAG_TX */
+		if (q_vector->netpoll_rx)
+			netif_rx(skb);
+		else
+			napi_gro_receive(&q_vector->napi, skb);
+#if defined(NETIF_F_HW_VLAN_TX) || defined(NETIF_F_HW_VLAN_CTAG_TX)
 	}
+#endif /* NETIF_F_HW_VLAN_TX || NETIF_F_HW_VLAN_CTAG_TX */
 }
 
-static void ixgbe_set_rsc_gso_size(struct ixgbe_ring *ring,
+#endif /* HAVE_VLAN_RX_REGISTER */
+#ifdef NETIF_F_GSO
+static void ixgbe_set_rsc_gso_size(struct ixgbe_ring __maybe_unused *ring,
 				   struct sk_buff *skb)
 {
-	u16 hdr_len = skb_headlen(skb);
+	u16 hdr_len = eth_get_headlen(skb->data, skb_headlen(skb));
 
 	/* set gso_size to avoid messing up TCP MSS */
 	skb_shinfo(skb)->gso_size = DIV_ROUND_UP((skb->len - hdr_len),
@@ -1604,6 +1462,7 @@ static void ixgbe_set_rsc_gso_size(struct ixgbe_ring *ring,
 	skb_shinfo(skb)->gso_type = SKB_GSO_TCPV4;
 }
 
+#endif /* NETIF_F_GSO */
 static void ixgbe_update_rsc_stats(struct ixgbe_ring *rx_ring,
 				   struct sk_buff *skb)
 {
@@ -1614,12 +1473,35 @@ static void ixgbe_update_rsc_stats(struct ixgbe_ring *rx_ring,
 	rx_ring->rx_stats.rsc_count += IXGBE_CB(skb)->append_cnt;
 	rx_ring->rx_stats.rsc_flush++;
 
+#ifdef NETIF_F_GSO
 	ixgbe_set_rsc_gso_size(rx_ring, skb);
 
+#endif
 	/* gso_size is computed using append_cnt so always clear it last */
 	IXGBE_CB(skb)->append_cnt = 0;
 }
 
+static void ixgbe_rx_vlan(struct ixgbe_ring *ring,
+			  union ixgbe_adv_rx_desc *rx_desc,
+			  struct sk_buff *skb)
+{
+#ifdef NETIF_F_HW_VLAN_CTAG_RX
+	if ((netdev_ring(ring)->features & NETIF_F_HW_VLAN_CTAG_RX) &&
+#else
+	if ((netdev_ring(ring)->features & NETIF_F_HW_VLAN_RX) &&
+#endif
+	    ixgbe_test_staterr(rx_desc, IXGBE_RXD_STAT_VP))
+#ifndef HAVE_VLAN_RX_REGISTER
+		__vlan_hwaccel_put_tag(skb,
+				       htons(ETH_P_8021Q),
+				       le16_to_cpu(rx_desc->wb.upper.vlan));
+#else
+		IXGBE_CB(skb)->vid = le16_to_cpu(rx_desc->wb.upper.vlan);
+	else
+		IXGBE_CB(skb)->vid = 0;
+#endif
+}
+
 /**
  * ixgbe_process_skb_fields - Populate skb header fields from Rx descriptor
  * @rx_ring: rx descriptor ring packet is being transacted on
@@ -1634,35 +1516,53 @@ static void ixgbe_process_skb_fields(struct ixgbe_ring *rx_ring,
 				     union ixgbe_adv_rx_desc *rx_desc,
 				     struct sk_buff *skb)
 {
-	struct net_device *dev = rx_ring->netdev;
+#ifdef HAVE_PTP_1588_CLOCK
+	u32 flags = rx_ring->q_vector->adapter->flags;
 
+#endif
 	ixgbe_update_rsc_stats(rx_ring, skb);
 
+#ifdef NETIF_F_RXHASH
 	ixgbe_rx_hash(rx_ring, rx_desc, skb);
 
+#endif /* NETIF_F_RXHASH */
 	ixgbe_rx_checksum(rx_ring, rx_desc, skb);
+#ifdef HAVE_PTP_1588_CLOCK
+	if (unlikely(flags & IXGBE_FLAG_RX_HWTSTAMP_ENABLED))
+		ixgbe_ptp_rx_hwtstamp(rx_ring, rx_desc, skb);
 
-	if (unlikely(ixgbe_test_staterr(rx_desc, IXGBE_RXDADV_STAT_TS)))
-		ixgbe_ptp_rx_hwtstamp(rx_ring->q_vector->adapter, skb);
-
-	if ((dev->features & NETIF_F_HW_VLAN_CTAG_RX) &&
-	    ixgbe_test_staterr(rx_desc, IXGBE_RXD_STAT_VP)) {
-		u16 vid = le16_to_cpu(rx_desc->wb.upper.vlan);
-		__vlan_hwaccel_put_tag(skb, htons(ETH_P_8021Q), vid);
-	}
+#endif
+	ixgbe_rx_vlan(rx_ring, rx_desc, skb);
 
-	skb_record_rx_queue(skb, rx_ring->queue_index);
+	skb_record_rx_queue(skb, ring_queue_index(rx_ring));
 
-	skb->protocol = eth_type_trans(skb, dev);
+	skb->protocol = eth_type_trans(skb, netdev_ring(rx_ring));
 }
 
 static void ixgbe_rx_skb(struct ixgbe_q_vector *q_vector,
+			 struct ixgbe_ring *rx_ring,
+			 union ixgbe_adv_rx_desc *rx_desc,
 			 struct sk_buff *skb)
 {
-	if (ixgbe_qv_busy_polling(q_vector))
+#ifdef HAVE_NDO_BUSY_POLL
+	skb_mark_napi_id(skb, &q_vector->napi);
+
+	if (ixgbe_qv_busy_polling(q_vector) || q_vector->netpoll_rx) {
 		netif_receive_skb(skb);
-	else
+		/* exit early if we busy polled */
+		return;
+	}
+#endif
+
+#ifdef HAVE_VLAN_RX_REGISTER
+		ixgbe_receive_skb(q_vector, skb);
+#else
 		napi_gro_receive(&q_vector->napi, skb);
+#endif
+#ifndef NETIF_F_GRO
+
+	netdev_ring(rx_ring)->last_rx = jiffies;
+#endif
 }
 
 /**
@@ -1680,6 +1580,9 @@ static bool ixgbe_is_non_eop(struct ixgbe_ring *rx_ring,
 			     union ixgbe_adv_rx_desc *rx_desc,
 			     struct sk_buff *skb)
 {
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	struct sk_buff *next_skb;
+#endif
 	u32 ntc = rx_ring->next_to_clean + 1;
 
 	/* fetch, update, and store next to clean */
@@ -1711,15 +1614,22 @@ static bool ixgbe_is_non_eop(struct ixgbe_ring *rx_ring,
 		return false;
 
 	/* place skb in next buffer to be received */
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	next_skb = rx_ring->rx_buffer_info[ntc].skb;
+
+	ixgbe_add_active_tail(skb, next_skb);
+	IXGBE_CB(next_skb)->head = skb;
+#else
 	rx_ring->rx_buffer_info[ntc].skb = skb;
+#endif
 	rx_ring->rx_stats.non_eop_descs++;
 
 	return true;
 }
 
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
 /**
  * ixgbe_pull_tail - ixgbe specific version of skb_pull_tail
- * @rx_ring: rx descriptor ring packet is being transacted on
  * @skb: pointer to current skb being adjusted
  *
  * This function is an ixgbe specific version of __pskb_pull_tail.  The
@@ -1729,8 +1639,7 @@ static bool ixgbe_is_non_eop(struct ixgbe_ring *rx_ring,
  * As a result we can do things like drop a frag and maintain an accurate
  * truesize for the skb.
  */
-static void ixgbe_pull_tail(struct ixgbe_ring *rx_ring,
-			    struct sk_buff *skb)
+static void ixgbe_pull_tail(struct sk_buff *skb)
 {
 	struct skb_frag_struct *frag = &skb_shinfo(skb)->frags[0];
 	unsigned char *va;
@@ -1774,19 +1683,19 @@ static void ixgbe_dma_sync_frag(struct ixgbe_ring *rx_ring,
 {
 	/* if the page was released unmap it, else just sync our portion */
 	if (unlikely(IXGBE_CB(skb)->page_released)) {
-		dma_unmap_page(rx_ring->dev, IXGBE_CB(skb)->dma,
-			       ixgbe_rx_pg_size(rx_ring), DMA_FROM_DEVICE);
-		IXGBE_CB(skb)->page_released = false;
+		dma_unmap_page_attrs(rx_ring->dev, IXGBE_CB(skb)->dma,
+				     ixgbe_rx_pg_size(rx_ring),
+				     DMA_FROM_DEVICE,
+				     IXGBE_RX_DMA_ATTR);
 	} else {
 		struct skb_frag_struct *frag = &skb_shinfo(skb)->frags[0];
 
 		dma_sync_single_range_for_cpu(rx_ring->dev,
 					      IXGBE_CB(skb)->dma,
 					      frag->page_offset,
-					      ixgbe_rx_bufsz(rx_ring),
+					      skb_frag_size(frag),
 					      DMA_FROM_DEVICE);
 	}
-	IXGBE_CB(skb)->dma = 0;
 }
 
 /**
@@ -1807,30 +1716,27 @@ static void ixgbe_dma_sync_frag(struct ixgbe_ring *rx_ring,
  *
  * Returns true if an error was encountered and skb was freed.
  **/
-static bool ixgbe_cleanup_headers(struct ixgbe_ring *rx_ring,
+static bool ixgbe_cleanup_headers(struct ixgbe_ring __maybe_unused *rx_ring,
 				  union ixgbe_adv_rx_desc *rx_desc,
 				  struct sk_buff *skb)
 {
-	struct net_device *netdev = rx_ring->netdev;
-
 	/* verify that the packet does not have any known errors */
 	if (unlikely(ixgbe_test_staterr(rx_desc,
-					IXGBE_RXDADV_ERR_FRAME_ERR_MASK) &&
-	    !(netdev->features & NETIF_F_RXALL))) {
+					IXGBE_RXDADV_ERR_FRAME_ERR_MASK))) {
 		dev_kfree_skb_any(skb);
 		return true;
 	}
 
 	/* place header in linear portion of buffer */
-	if (skb_is_nonlinear(skb))
-		ixgbe_pull_tail(rx_ring, skb);
+	if (!skb_headlen(skb))
+		ixgbe_pull_tail(skb);
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* do not attempt to pad FCoE Frames as this will disrupt DDP */
 	if (ixgbe_rx_is_fcoe(rx_ring, rx_desc))
 		return false;
-
 #endif
+
 	/* if eth_skb_pad returns an error the skb was freed */
 	if (eth_skb_pad(skb))
 		return true;
@@ -1857,14 +1763,14 @@ static void ixgbe_reuse_rx_page(struct ixgbe_ring *rx_ring,
 	nta++;
 	rx_ring->next_to_alloc = (nta < rx_ring->count) ? nta : 0;
 
-	/* transfer page from old buffer to new buffer */
-	*new_buff = *old_buff;
-
-	/* sync the buffer for use by the device */
-	dma_sync_single_range_for_device(rx_ring->dev, new_buff->dma,
-					 new_buff->page_offset,
-					 ixgbe_rx_bufsz(rx_ring),
-					 DMA_FROM_DEVICE);
+	/* Transfer page from old buffer to new buffer.
+	 * Move each member individually to avoid possible store
+	 * forwarding stalls and unnecessary copy of skb.
+	 */
+	new_buff->dma		= old_buff->dma;
+	new_buff->page		= old_buff->page;
+	new_buff->page_offset	= old_buff->page_offset;
+	new_buff->pagecnt_bias	= old_buff->pagecnt_bias;
 }
 
 static inline bool ixgbe_page_is_reserved(struct page *page)
@@ -1872,6 +1778,57 @@ static inline bool ixgbe_page_is_reserved(struct page *page)
 	return (page_to_nid(page) != numa_mem_id()) || page_is_pfmemalloc(page);
 }
 
+static bool ixgbe_can_reuse_rx_page(struct ixgbe_rx_buffer *rx_buffer)
+{
+	unsigned int pagecnt_bias = rx_buffer->pagecnt_bias;
+	struct page *page = rx_buffer->page;
+
+	/* avoid re-using remote pages */
+	if (unlikely(ixgbe_page_is_reserved(page)))
+		return false;
+
+#if (PAGE_SIZE < 8192)
+	/* if we are only owner of page we can reuse it */
+#ifdef HAVE_PAGE_COUNT_BULK_UPDATE
+	if (unlikely((page_ref_count(page) - pagecnt_bias) > 1))
+#else
+	if (unlikely((page_count(page) - pagecnt_bias) > 1))
+#endif
+		return false;
+#else
+	/* The last offset is a bit aggressive in that we assume the
+	 * worst case of FCoE being enabled and using a 3K buffer.
+	 * However this should have minimal impact as the 1K extra is
+	 * still less than one buffer in size.
+	 */
+#define IXGBE_LAST_OFFSET \
+	(SKB_WITH_OVERHEAD(PAGE_SIZE) - IXGBE_RXBUFFER_3K)
+	if (rx_buffer->page_offset > IXGBE_LAST_OFFSET)
+		return false;
+#endif
+
+#ifdef HAVE_PAGE_COUNT_BULK_UPDATE
+	/* If we have drained the page fragment pool we need to update
+	 * the pagecnt_bias and page count so that we fully restock the
+	 * number of references the driver holds.
+	 */
+	if (unlikely(!pagecnt_bias)) {
+		page_ref_add(page, USHRT_MAX);
+		rx_buffer->pagecnt_bias = USHRT_MAX;
+	}
+#else
+	/* Even if we own the page, we are not allowed to use atomic_set()
+	 * This would break get_page_unless_zero() users.
+	 */
+	if (likely(!pagecnt_bias)) {
+		page_ref_inc(page);
+		rx_buffer->pagecnt_bias = 1;
+	}
+#endif
+
+	return true;
+}
+
 /**
  * ixgbe_add_rx_frag - Add contents of Rx buffer to sk_buff
  * @rx_ring: rx descriptor ring to transact packets on
@@ -1887,150 +1844,182 @@ static inline bool ixgbe_page_is_reserved(struct page *page)
  * The function will then update the page offset if necessary and return
  * true if the buffer can be reused by the adapter.
  **/
-static bool ixgbe_add_rx_frag(struct ixgbe_ring *rx_ring,
+static void ixgbe_add_rx_frag(struct ixgbe_ring *rx_ring,
 			      struct ixgbe_rx_buffer *rx_buffer,
-			      union ixgbe_adv_rx_desc *rx_desc,
-			      struct sk_buff *skb)
+			      struct sk_buff *skb,
+			      unsigned int size)
 {
-	struct page *page = rx_buffer->page;
-	unsigned int size = le16_to_cpu(rx_desc->wb.upper.length);
 #if (PAGE_SIZE < 8192)
-	unsigned int truesize = ixgbe_rx_bufsz(rx_ring);
+	unsigned int truesize = ixgbe_rx_pg_size(rx_ring) / 2;
 #else
-	unsigned int truesize = ALIGN(size, L1_CACHE_BYTES);
-	unsigned int last_offset = ixgbe_rx_pg_size(rx_ring) -
-				   ixgbe_rx_bufsz(rx_ring);
+	unsigned int truesize = ring_uses_build_skb(rx_ring) ?
+				SKB_DATA_ALIGN(IXGBE_SKB_PAD + size) :
+				SKB_DATA_ALIGN(size);
 #endif
 
-	if ((size <= IXGBE_RX_HDR_SIZE) && !skb_is_nonlinear(skb)) {
-		unsigned char *va = page_address(page) + rx_buffer->page_offset;
-
-		memcpy(__skb_put(skb, size), va, ALIGN(size, sizeof(long)));
-
-		/* page is not reserved, we can reuse buffer as-is */
-		if (likely(!ixgbe_page_is_reserved(page)))
-			return true;
-
-		/* this page cannot be reused so discard it */
-		__free_pages(page, ixgbe_rx_pg_order(rx_ring));
-		return false;
-	}
-
-	skb_add_rx_frag(skb, skb_shinfo(skb)->nr_frags, page,
+	skb_add_rx_frag(skb, skb_shinfo(skb)->nr_frags, rx_buffer->page,
 			rx_buffer->page_offset, size, truesize);
 
-	/* avoid re-using remote pages */
-	if (unlikely(ixgbe_page_is_reserved(page)))
-		return false;
-
 #if (PAGE_SIZE < 8192)
-	/* if we are only owner of page we can reuse it */
-	if (unlikely(page_count(page) != 1))
-		return false;
-
-	/* flip page offset to other buffer */
 	rx_buffer->page_offset ^= truesize;
 #else
-	/* move offset up to the next cache line */
 	rx_buffer->page_offset += truesize;
-
-	if (rx_buffer->page_offset > last_offset)
-		return false;
 #endif
-
-	/* Even if we own the page, we are not allowed to use atomic_set()
-	 * This would break get_page_unless_zero() users.
-	 */
-	atomic_inc(&page->_count);
-
-	return true;
 }
 
-static struct sk_buff *ixgbe_fetch_rx_buffer(struct ixgbe_ring *rx_ring,
-					     union ixgbe_adv_rx_desc *rx_desc)
+static struct ixgbe_rx_buffer *
+ixgbe_get_rx_buffer(struct ixgbe_ring *rx_ring,
+		    union ixgbe_adv_rx_desc *rx_desc, struct sk_buff **skb,
+		    const unsigned int size)
 {
 	struct ixgbe_rx_buffer *rx_buffer;
-	struct sk_buff *skb;
-	struct page *page;
 
 	rx_buffer = &rx_ring->rx_buffer_info[rx_ring->next_to_clean];
-	page = rx_buffer->page;
-	prefetchw(page);
-
-	skb = rx_buffer->skb;
-
-	if (likely(!skb)) {
-		void *page_addr = page_address(page) +
-				  rx_buffer->page_offset;
-
-		/* prefetch first cache line of first page */
-		prefetch(page_addr);
-#if L1_CACHE_BYTES < 128
-		prefetch(page_addr + L1_CACHE_BYTES);
-#endif
-
-		/* allocate a skb to store the frags */
-		skb = napi_alloc_skb(&rx_ring->q_vector->napi,
-				     IXGBE_RX_HDR_SIZE);
-		if (unlikely(!skb)) {
-			rx_ring->rx_stats.alloc_rx_buff_failed++;
-			return NULL;
-		}
-
-		/*
-		 * we will be copying header into skb->data in
-		 * pskb_may_pull so it is in our interest to prefetch
-		 * it now to avoid a possible cache miss
-		 */
-		prefetchw(skb->data);
-
-		/*
-		 * Delay unmapping of the first packet. It carries the
-		 * header information, HW may still access the header
-		 * after the writeback.  Only unmap it when EOP is
-		 * reached
-		 */
-		if (likely(ixgbe_test_staterr(rx_desc, IXGBE_RXD_STAT_EOP)))
-			goto dma_sync;
+	prefetchw(rx_buffer->page);
+	*skb = rx_buffer->skb;
 
-		IXGBE_CB(skb)->dma = rx_buffer->dma;
+	/* Delay unmapping of the first packet. It carries the header
+	 * information, HW may still access the header after the writeback.
+	 * Only unmap it when EOP is reached
+	 */
+	if (!ixgbe_test_staterr(rx_desc, IXGBE_RXD_STAT_EOP)) {
+		if (!*skb)
+			goto skip_sync;
 	} else {
-		if (ixgbe_test_staterr(rx_desc, IXGBE_RXD_STAT_EOP))
-			ixgbe_dma_sync_frag(rx_ring, skb);
+		if (*skb)
+			ixgbe_dma_sync_frag(rx_ring, *skb);
+	}
 
-dma_sync:
-		/* we are reusing so sync this buffer for CPU use */
-		dma_sync_single_range_for_cpu(rx_ring->dev,
-					      rx_buffer->dma,
-					      rx_buffer->page_offset,
-					      ixgbe_rx_bufsz(rx_ring),
-					      DMA_FROM_DEVICE);
+	/* we are reusing so sync this buffer for CPU use */
+	dma_sync_single_range_for_cpu(rx_ring->dev,
+				      rx_buffer->dma,
+				      rx_buffer->page_offset,
+				      size,
+				      DMA_FROM_DEVICE);
+skip_sync:
+	rx_buffer->pagecnt_bias--;
 
-		rx_buffer->skb = NULL;
-	}
+	return rx_buffer;
+}
 
-	/* pull page into skb */
-	if (ixgbe_add_rx_frag(rx_ring, rx_buffer, rx_desc, skb)) {
+static void ixgbe_put_rx_buffer(struct ixgbe_ring *rx_ring,
+				struct ixgbe_rx_buffer *rx_buffer,
+				struct sk_buff *skb)
+{
+	if (ixgbe_can_reuse_rx_page(rx_buffer)) {
 		/* hand second half of page back to the ring */
 		ixgbe_reuse_rx_page(rx_ring, rx_buffer);
-	} else if (IXGBE_CB(skb)->dma == rx_buffer->dma) {
-		/* the page has been released from the ring */
-		IXGBE_CB(skb)->page_released = true;
 	} else {
-		/* we are not reusing the buffer so unmap it */
-		dma_unmap_page(rx_ring->dev, rx_buffer->dma,
-			       ixgbe_rx_pg_size(rx_ring),
-			       DMA_FROM_DEVICE);
+		if (IXGBE_CB(skb)->dma == rx_buffer->dma) {
+			/* the page has been released from the ring */
+			IXGBE_CB(skb)->page_released = true;
+		} else {
+			/* we are not reusing the buffer so unmap it */
+			dma_unmap_page_attrs(rx_ring->dev, rx_buffer->dma,
+					     ixgbe_rx_pg_size(rx_ring),
+					     DMA_FROM_DEVICE,
+					     IXGBE_RX_DMA_ATTR);
+		}
+		__page_frag_cache_drain(rx_buffer->page,
+					rx_buffer->pagecnt_bias);
 	}
 
-	/* clear contents of buffer_info */
+	/* clear contents of rx_buffer */
 	rx_buffer->page = NULL;
-
-	return skb;
+	rx_buffer->skb = NULL;
 }
 
-/**
- * ixgbe_clean_rx_irq - Clean completed descriptors from Rx ring - bounce buf
+static struct sk_buff *ixgbe_construct_skb(struct ixgbe_ring *rx_ring,
+					   struct ixgbe_rx_buffer *rx_buffer,
+					   union ixgbe_adv_rx_desc *rx_desc,
+					   unsigned int size)
+{
+	void *va = page_address(rx_buffer->page) + rx_buffer->page_offset;
+#if (PAGE_SIZE < 8192)
+	unsigned int truesize = ixgbe_rx_pg_size(rx_ring) / 2;
+#else
+	unsigned int truesize = SKB_DATA_ALIGN(size);
+#endif
+	struct sk_buff *skb;
+
+	/* prefetch first cache line of first page */
+	prefetch(va);
+#if L1_CACHE_BYTES < 128
+	prefetch(va + L1_CACHE_BYTES);
+#endif
+
+	/* allocate a skb to store the frags */
+	skb = napi_alloc_skb(&rx_ring->q_vector->napi, IXGBE_RX_HDR_SIZE);
+	if (unlikely(!skb))
+		return NULL;
+
+	if (size > IXGBE_RX_HDR_SIZE) {
+		if (!ixgbe_test_staterr(rx_desc, IXGBE_RXD_STAT_EOP))
+			IXGBE_CB(skb)->dma = rx_buffer->dma;
+
+		skb_add_rx_frag(skb, 0, rx_buffer->page,
+				rx_buffer->page_offset,
+				size, truesize);
+#if (PAGE_SIZE < 8192)
+		rx_buffer->page_offset ^= truesize;
+#else
+		rx_buffer->page_offset += truesize;
+#endif
+	} else {
+		memcpy(__skb_put(skb, size), va, ALIGN(size, sizeof(long)));
+		rx_buffer->pagecnt_bias++;
+	}
+
+	return skb;
+}
+
+#ifdef HAVE_SWIOTLB_SKIP_CPU_SYNC
+static struct sk_buff *ixgbe_build_skb(struct ixgbe_ring *rx_ring,
+				       struct ixgbe_rx_buffer *rx_buffer,
+				       union ixgbe_adv_rx_desc *rx_desc,
+				       unsigned int size)
+{
+	void *va = page_address(rx_buffer->page) + rx_buffer->page_offset;
+#if (PAGE_SIZE < 8192)
+	unsigned int truesize = ixgbe_rx_pg_size(rx_ring) / 2;
+#else
+	unsigned int truesize = SKB_DATA_ALIGN(sizeof(struct skb_shared_info)) +
+				SKB_DATA_ALIGN(IXGBE_SKB_PAD + size);
+#endif
+	struct sk_buff *skb;
+
+	/* prefetch first cache line of first page */
+	prefetch(va);
+#if L1_CACHE_BYTES < 128
+	prefetch(va + L1_CACHE_BYTES);
+#endif
+
+	/* build an skb around the page buffer */
+	skb = build_skb(va - IXGBE_SKB_PAD, truesize);
+	if (unlikely(!skb))
+		return NULL;
+
+	/* update pointers within the skb to store the data */
+	skb_reserve(skb, IXGBE_SKB_PAD);
+	__skb_put(skb, size);
+
+	/* record DMA address if this is the start of a chain of buffers */
+	if (!ixgbe_test_staterr(rx_desc, IXGBE_RXD_STAT_EOP))
+		IXGBE_CB(skb)->dma = rx_buffer->dma;
+
+	/* update buffer offset */
+#if (PAGE_SIZE < 8192)
+	rx_buffer->page_offset ^= truesize;
+#else
+	rx_buffer->page_offset += truesize;
+#endif
+
+	return skb;
+}
+
+#endif  /* HAVE_SWIOTLB_SKIP_CPU_SYNC */
+/**
+ * ixgbe_clean_rx_irq - Clean completed descriptors from Rx ring - bounce buf
  * @q_vector: structure containing interrupt and ring information
  * @rx_ring: rx descriptor ring to transact packets on
  * @budget: Total limit on number of packets to process
@@ -2040,23 +2029,24 @@ dma_sync:
  * expensive overhead for IOMMU access this provides a means of avoiding
  * it by maintaining the mapping of the page to the syste.
  *
- * Returns amount of work completed
+ * Returns amount of work completed.
  **/
 static int ixgbe_clean_rx_irq(struct ixgbe_q_vector *q_vector,
 			       struct ixgbe_ring *rx_ring,
-			       const int budget)
+			       int budget)
 {
 	unsigned int total_rx_bytes = 0, total_rx_packets = 0;
-#ifdef IXGBE_FCOE
-	struct ixgbe_adapter *adapter = q_vector->adapter;
+#if IS_ENABLED(CONFIG_FCOE)
 	int ddp_bytes;
 	unsigned int mss = 0;
-#endif /* IXGBE_FCOE */
+#endif /* CONFIG_FCOE */
 	u16 cleaned_count = ixgbe_desc_unused(rx_ring);
 
 	while (likely(total_rx_packets < budget)) {
 		union ixgbe_adv_rx_desc *rx_desc;
+		struct ixgbe_rx_buffer *rx_buffer;
 		struct sk_buff *skb;
+		unsigned int size;
 
 		/* return some buffers to hardware, one at a time is too slow */
 		if (cleaned_count >= IXGBE_RX_BUFFER_WRITE) {
@@ -2065,8 +2055,8 @@ static int ixgbe_clean_rx_irq(struct ixgbe_q_vector *q_vector,
 		}
 
 		rx_desc = IXGBE_RX_DESC(rx_ring, rx_ring->next_to_clean);
-
-		if (!rx_desc->wb.upper.status_error)
+		size = le16_to_cpu(rx_desc->wb.upper.length);
+		if (!size)
 			break;
 
 		/* This memory barrier is needed to keep us from reading
@@ -2075,13 +2065,28 @@ static int ixgbe_clean_rx_irq(struct ixgbe_q_vector *q_vector,
 		 */
 		dma_rmb();
 
+		rx_buffer = ixgbe_get_rx_buffer(rx_ring, rx_desc, &skb, size);
+
 		/* retrieve a buffer from the ring */
-		skb = ixgbe_fetch_rx_buffer(rx_ring, rx_desc);
+		if (skb)
+			ixgbe_add_rx_frag(rx_ring, rx_buffer, skb, size);
+#ifdef HAVE_SWIOTLB_SKIP_CPU_SYNC
+		else if (ring_uses_build_skb(rx_ring))
+			skb = ixgbe_build_skb(rx_ring, rx_buffer,
+					      rx_desc, size);
+#endif
+		else
+			skb = ixgbe_construct_skb(rx_ring, rx_buffer, rx_desc,
+						  size);
 
 		/* exit if we failed to retrieve a buffer */
-		if (!skb)
+		if (!skb) {
+			rx_ring->rx_stats.alloc_rx_buff_failed++;
+			rx_buffer->pagecnt_bias++;
 			break;
+		}
 
+		ixgbe_put_rx_buffer(rx_ring, rx_buffer, skb);
 		cleaned_count++;
 
 		/* place incomplete frames back on ring for completion */
@@ -2098,14 +2103,15 @@ static int ixgbe_clean_rx_irq(struct ixgbe_q_vector *q_vector,
 		/* populate checksum, timestamp, VLAN, and protocol */
 		ixgbe_process_skb_fields(rx_ring, rx_desc, skb);
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 		/* if ddp, not passing to ULD unless for FCP_RSP or error */
 		if (ixgbe_rx_is_fcoe(rx_ring, rx_desc)) {
-			ddp_bytes = ixgbe_fcoe_ddp(adapter, rx_desc, skb);
+			ddp_bytes = ixgbe_fcoe_ddp(q_vector->adapter,
+						   rx_desc, skb);
 			/* include DDPed FCoE data */
 			if (ddp_bytes > 0) {
 				if (!mss) {
-					mss = rx_ring->netdev->mtu -
+					mss = netdev_ring(rx_ring)->mtu -
 						sizeof(struct fcoe_hdr) -
 						sizeof(struct fc_frame_header) -
 						sizeof(struct fcoe_crc_eof);
@@ -2118,13 +2124,15 @@ static int ixgbe_clean_rx_irq(struct ixgbe_q_vector *q_vector,
 			}
 			if (!ddp_bytes) {
 				dev_kfree_skb_any(skb);
+#ifndef NETIF_F_GRO
+				netdev_ring(rx_ring)->last_rx = jiffies;
+#endif
 				continue;
 			}
 		}
+#endif /* CONFIG_FCOE */
 
-#endif /* IXGBE_FCOE */
-		skb_mark_napi_id(skb, &q_vector->napi);
-		ixgbe_rx_skb(q_vector, skb);
+		ixgbe_rx_skb(q_vector, rx_ring, rx_desc, skb);
 
 		/* update budget accounting */
 		total_rx_packets++;
@@ -2140,9 +2148,165 @@ static int ixgbe_clean_rx_irq(struct ixgbe_q_vector *q_vector,
 	return total_rx_packets;
 }
 
-#ifdef CONFIG_NET_RX_BUSY_POLL
+#else /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
+/**
+ * ixgbe_clean_rx_irq - Clean completed descriptors from Rx ring - legacy
+ * @q_vector: structure containing interrupt and ring information
+ * @rx_ring: rx descriptor ring to transact packets on
+ * @budget: Total limit on number of packets to process
+ *
+ * This function provides a legacy approach to Rx interrupt
+ * handling.  This version will perform better on systems with a low cost
+ * dma mapping API.
+ *
+ * Returns amount of work completed.
+ **/
+static int ixgbe_clean_rx_irq(struct ixgbe_q_vector *q_vector,
+			       struct ixgbe_ring *rx_ring,
+			       int budget)
+{
+	unsigned int total_rx_bytes = 0, total_rx_packets = 0;
+#if IS_ENABLED(CONFIG_FCOE)
+	int ddp_bytes;
+	unsigned int mss = 0;
+#endif /* CONFIG_FCOE */
+	u16 len = 0;
+	u16 cleaned_count = ixgbe_desc_unused(rx_ring);
+
+	while (likely(total_rx_packets < budget)) {
+		struct ixgbe_rx_buffer *rx_buffer;
+		union ixgbe_adv_rx_desc *rx_desc;
+		struct sk_buff *skb;
+		u16 ntc;
+
+		/* return some buffers to hardware, one at a time is too slow */
+		if (cleaned_count >= IXGBE_RX_BUFFER_WRITE) {
+			ixgbe_alloc_rx_buffers(rx_ring, cleaned_count);
+			cleaned_count = 0;
+		}
+
+		ntc = rx_ring->next_to_clean;
+		rx_desc = IXGBE_RX_DESC(rx_ring, ntc);
+		rx_buffer = &rx_ring->rx_buffer_info[ntc];
+
+		if (!rx_desc->wb.upper.length)
+			break;
+
+		/* This memory barrier is needed to keep us from reading
+		 * any other fields out of the rx_desc until we know the
+		 * descriptor has been written back
+		 */
+		dma_rmb();
+
+		skb = rx_buffer->skb;
+
+		prefetch(skb->data);
+
+		len = le16_to_cpu(rx_desc->wb.upper.length);
+		/* pull the header of the skb in */
+		__skb_put(skb, len);
+
+		/*
+		 * Delay unmapping of the first packet. It carries the
+		 * header information, HW may still access the header after
+		 * the writeback.  Only unmap it when EOP is reached
+		 */
+		if (!IXGBE_CB(skb)->head) {
+			IXGBE_CB(skb)->dma = rx_buffer->dma;
+		} else {
+			skb = ixgbe_merge_active_tail(skb);
+			dma_unmap_single(rx_ring->dev,
+					 rx_buffer->dma,
+					 rx_ring->rx_buf_len,
+					 DMA_FROM_DEVICE);
+		}
+
+		/* clear skb reference in buffer info structure */
+		rx_buffer->skb = NULL;
+		rx_buffer->dma = 0;
+
+		cleaned_count++;
+
+		if (ixgbe_is_non_eop(rx_ring, rx_desc, skb))
+			continue;
+
+		dma_unmap_single(rx_ring->dev,
+				 IXGBE_CB(skb)->dma,
+				 rx_ring->rx_buf_len,
+				 DMA_FROM_DEVICE);
+
+		IXGBE_CB(skb)->dma = 0;
+
+		if (ixgbe_close_active_frag_list(skb) &&
+		    !IXGBE_CB(skb)->append_cnt) {
+			/* if we got here without RSC the packet is invalid */
+			dev_kfree_skb_any(skb);
+			continue;
+		}
+
+		/* ERR_MASK will only have valid bits if EOP set */
+		if (unlikely(ixgbe_test_staterr(rx_desc,
+					   IXGBE_RXDADV_ERR_FRAME_ERR_MASK))) {
+			dev_kfree_skb_any(skb);
+			continue;
+		}
+
+		/* probably a little skewed due to removing CRC */
+		total_rx_bytes += skb->len;
+
+		/* populate checksum, timestamp, VLAN, and protocol */
+		ixgbe_process_skb_fields(rx_ring, rx_desc, skb);
+
+#if IS_ENABLED(CONFIG_FCOE)
+		/* if ddp, not passing to ULD unless for FCP_RSP or error */
+		if (ixgbe_rx_is_fcoe(rx_ring, rx_desc)) {
+			ddp_bytes = ixgbe_fcoe_ddp(q_vector->adapter,
+						   rx_desc, skb);
+			/* include DDPed FCoE data */
+			if (ddp_bytes > 0) {
+				if (!mss) {
+					mss = netdev_ring(rx_ring)->mtu -
+						sizeof(struct fcoe_hdr) -
+						sizeof(struct fc_frame_header) -
+						sizeof(struct fcoe_crc_eof);
+					if (mss > 512)
+						mss &= ~511;
+				}
+				total_rx_bytes += ddp_bytes;
+				total_rx_packets += DIV_ROUND_UP(ddp_bytes,
+								 mss);
+			}
+			if (!ddp_bytes) {
+				dev_kfree_skb_any(skb);
+#ifndef NETIF_F_GRO
+				netdev_ring(rx_ring)->last_rx = jiffies;
+#endif
+				continue;
+			}
+		}
+
+#endif /* CONFIG_FCOE */
+		ixgbe_rx_skb(q_vector, rx_ring, rx_desc, skb);
+
+		/* update budget accounting */
+		total_rx_packets++;
+	}
+
+	rx_ring->stats.packets += total_rx_packets;
+	rx_ring->stats.bytes += total_rx_bytes;
+	q_vector->rx.total_packets += total_rx_packets;
+	q_vector->rx.total_bytes += total_rx_bytes;
+
+	if (cleaned_count)
+		ixgbe_alloc_rx_buffers(rx_ring, cleaned_count);
+
+	return total_rx_packets;
+}
+
+#endif /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
+#ifdef HAVE_NDO_BUSY_POLL
 /* must be called with local_bh_disable()d */
-static int ixgbe_low_latency_recv(struct napi_struct *napi)
+static int ixgbe_busy_poll_recv(struct napi_struct *napi)
 {
 	struct ixgbe_q_vector *q_vector =
 			container_of(napi, struct ixgbe_q_vector, napi);
@@ -2172,8 +2336,8 @@ static int ixgbe_low_latency_recv(struct napi_struct *napi)
 
 	return found;
 }
-#endif	/* CONFIG_NET_RX_BUSY_POLL */
 
+#endif /* HAVE_NDO_BUSY_POLL */
 /**
  * ixgbe_configure_msix - Configure MSI-X hardware
  * @adapter: board private structure
@@ -2183,12 +2347,11 @@ static int ixgbe_low_latency_recv(struct napi_struct *napi)
  **/
 static void ixgbe_configure_msix(struct ixgbe_adapter *adapter)
 {
-	struct ixgbe_q_vector *q_vector;
 	int v_idx;
 	u32 mask;
 
 	/* Populate MSIX to EITR Select */
-	if (adapter->num_vfs > 32) {
+	if (adapter->num_vfs >= 32) {
 		u32 eitrsel = (1 << (adapter->num_vfs - 32)) - 1;
 		IXGBE_WRITE_REG(&adapter->hw, IXGBE_EITRSEL, eitrsel);
 	}
@@ -2198,8 +2361,8 @@ static void ixgbe_configure_msix(struct ixgbe_adapter *adapter)
 	 * corresponding register.
 	 */
 	for (v_idx = 0; v_idx < adapter->num_q_vectors; v_idx++) {
+		struct ixgbe_q_vector *q_vector = adapter->q_vector[v_idx];
 		struct ixgbe_ring *ring;
-		q_vector = adapter->q_vector[v_idx];
 
 		ixgbe_for_each_ring(ring, q_vector->rx)
 			ixgbe_set_ivar(adapter, 0, ring->reg_idx, v_idx);
@@ -2219,6 +2382,7 @@ static void ixgbe_configure_msix(struct ixgbe_adapter *adapter)
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		ixgbe_set_ivar(adapter, -1, 1, v_idx);
 		break;
 	default:
@@ -2278,23 +2442,25 @@ static void ixgbe_update_itr(struct ixgbe_q_vector *q_vector,
 	timepassed_us = q_vector->itr >> 2;
 	if (timepassed_us == 0)
 		return;
-
 	bytes_perint = bytes / timepassed_us; /* bytes/usec */
 
 	switch (itr_setting) {
 	case lowest_latency:
-		if (bytes_perint > 10)
+		if (bytes_perint > 10) {
 			itr_setting = low_latency;
+		}
 		break;
 	case low_latency:
-		if (bytes_perint > 20)
+		if (bytes_perint > 20) {
 			itr_setting = bulk_latency;
-		else if (bytes_perint <= 10)
+		} else if (bytes_perint <= 10) {
 			itr_setting = lowest_latency;
+		}
 		break;
 	case bulk_latency:
-		if (bytes_perint <= 20)
+		if (bytes_perint <= 20) {
 			itr_setting = low_latency;
+		}
 		break;
 	}
 
@@ -2330,6 +2496,7 @@ void ixgbe_write_eitr(struct ixgbe_q_vector *q_vector)
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		/*
 		 * set the WDIS bit to not clear the timer bits and cause an
 		 * immediate assertion of the interrupt
@@ -2387,12 +2554,12 @@ static void ixgbe_check_overtemp_subtask(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	u32 eicr = adapter->interrupt_event;
+	s32 rc;
 
 	if (test_bit(__IXGBE_DOWN, &adapter->state))
 		return;
 
-	if (!(adapter->flags2 & IXGBE_FLAG2_TEMP_SENSOR_CAPABLE) &&
-	    !(adapter->flags2 & IXGBE_FLAG2_TEMP_SENSOR_EVENT))
+	if (!(adapter->flags2 & IXGBE_FLAG2_TEMP_SENSOR_EVENT))
 		return;
 
 	adapter->flags2 &= ~IXGBE_FLAG2_TEMP_SENSOR_EVENT;
@@ -2406,7 +2573,7 @@ static void ixgbe_check_overtemp_subtask(struct ixgbe_adapter *adapter)
 		 *  - We may have missed the interrupt so always have to
 		 *    check if we  got a LSC
 		 */
-		if (!(eicr & IXGBE_EICR_GPI_SDP0_8259X) &&
+		if (!(eicr & IXGBE_EICR_GPI_SDP0) &&
 		    !(eicr & IXGBE_EICR_LSC))
 			return;
 
@@ -2425,10 +2592,16 @@ static void ixgbe_check_overtemp_subtask(struct ixgbe_adapter *adapter)
 			return;
 
 		break;
+	case IXGBE_DEV_ID_X550EM_A_1G_T:
+	case IXGBE_DEV_ID_X550EM_A_1G_T_L:
+		rc = hw->phy.ops.check_overtemp(hw);
+		if (rc != IXGBE_ERR_OVERTEMP)
+			return;
+		break;
 	default:
 		if (adapter->hw.mac.type >= ixgbe_mac_X540)
 			return;
-		if (!(eicr & IXGBE_EICR_GPI_SDP0(hw)))
+		if (!(eicr & IXGBE_EICR_GPI_SDP0_BY_MAC(hw)))
 			return;
 		break;
 	}
@@ -2442,17 +2615,15 @@ static void ixgbe_check_fan_failure(struct ixgbe_adapter *adapter, u32 eicr)
 	struct ixgbe_hw *hw = &adapter->hw;
 
 	if ((adapter->flags & IXGBE_FLAG_FAN_FAIL_CAPABLE) &&
-	    (eicr & IXGBE_EICR_GPI_SDP1(hw))) {
+	    (eicr & IXGBE_EICR_GPI_SDP1)) {
 		e_crit(probe, "Fan has stopped, replace the adapter\n");
 		/* write to clear the interrupt */
-		IXGBE_WRITE_REG(hw, IXGBE_EICR, IXGBE_EICR_GPI_SDP1(hw));
+		IXGBE_WRITE_REG(hw, IXGBE_EICR, IXGBE_EICR_GPI_SDP1);
 	}
 }
 
 static void ixgbe_check_overtemp_event(struct ixgbe_adapter *adapter, u32 eicr)
 {
-	struct ixgbe_hw *hw = &adapter->hw;
-
 	if (!(adapter->flags2 & IXGBE_FLAG2_TEMP_SENSOR_CAPABLE))
 		return;
 
@@ -2462,8 +2633,7 @@ static void ixgbe_check_overtemp_event(struct ixgbe_adapter *adapter, u32 eicr)
 		 * Need to check link state so complete overtemp check
 		 * on service task
 		 */
-		if (((eicr & IXGBE_EICR_GPI_SDP0(hw)) ||
-		     (eicr & IXGBE_EICR_LSC)) &&
+		if (((eicr & IXGBE_EICR_GPI_SDP0) || (eicr & IXGBE_EICR_LSC)) &&
 		    (!test_bit(__IXGBE_DOWN, &adapter->state))) {
 			adapter->interrupt_event = eicr;
 			adapter->flags2 |= IXGBE_FLAG2_TEMP_SENSOR_EVENT;
@@ -2471,6 +2641,18 @@ static void ixgbe_check_overtemp_event(struct ixgbe_adapter *adapter, u32 eicr)
 			return;
 		}
 		return;
+	case ixgbe_mac_X550EM_a:
+		if (eicr & IXGBE_EICR_GPI_SDP0_X550EM_a) {
+			adapter->interrupt_event = eicr;
+			adapter->flags2 |= IXGBE_FLAG2_TEMP_SENSOR_EVENT;
+			ixgbe_service_event_schedule(adapter);
+			IXGBE_WRITE_REG(&adapter->hw, IXGBE_EIMC,
+					IXGBE_EICR_GPI_SDP0_X550EM_a);
+			IXGBE_WRITE_REG(&adapter->hw, IXGBE_EICR,
+					IXGBE_EICR_GPI_SDP0_X550EM_a);
+		}
+		return;
+	case ixgbe_mac_X550:
 	case ixgbe_mac_X540:
 		if (!(eicr & IXGBE_EICR_TS))
 			return;
@@ -2482,36 +2664,13 @@ static void ixgbe_check_overtemp_event(struct ixgbe_adapter *adapter, u32 eicr)
 	e_crit(drv, "%s\n", ixgbe_overheat_msg);
 }
 
-static inline bool ixgbe_is_sfp(struct ixgbe_hw *hw)
-{
-	switch (hw->mac.type) {
-	case ixgbe_mac_82598EB:
-		if (hw->phy.type == ixgbe_phy_nl)
-			return true;
-		return false;
-	case ixgbe_mac_82599EB:
-	case ixgbe_mac_X550EM_x:
-		switch (hw->mac.ops.get_media_type(hw)) {
-		case ixgbe_media_type_fiber:
-		case ixgbe_media_type_fiber_qsfp:
-			return true;
-		default:
-			return false;
-		}
-	default:
-		return false;
-	}
-}
-
 static void ixgbe_check_sfp_event(struct ixgbe_adapter *adapter, u32 eicr)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
-	u32 eicr_mask = IXGBE_EICR_GPI_SDP2(hw);
+	u32 eicr_mask = IXGBE_EICR_GPI_SDP2_BY_MAC(hw);
 
 	if (!ixgbe_is_sfp(hw))
 		return;
-
-	/* Later MAC's use different SDP */
 	if (hw->mac.type >= ixgbe_mac_X540)
 		eicr_mask = IXGBE_EICR_GPI_SDP0_X540;
 
@@ -2526,9 +2685,9 @@ static void ixgbe_check_sfp_event(struct ixgbe_adapter *adapter, u32 eicr)
 	}
 
 	if (adapter->hw.mac.type == ixgbe_mac_82599EB &&
-	    (eicr & IXGBE_EICR_GPI_SDP1(hw))) {
+	    (eicr & IXGBE_EICR_GPI_SDP1_BY_MAC(hw))) {
 		/* Clear the interrupt */
-		IXGBE_WRITE_REG(hw, IXGBE_EICR, IXGBE_EICR_GPI_SDP1(hw));
+		IXGBE_WRITE_REG(hw, IXGBE_EICR, IXGBE_EICR_GPI_SDP1_BY_MAC(hw));
 		if (!test_bit(__IXGBE_DOWN, &adapter->state)) {
 			adapter->flags |= IXGBE_FLAG_NEED_LINK_CONFIG;
 			ixgbe_service_event_schedule(adapter);
@@ -2550,8 +2709,7 @@ static void ixgbe_check_lsc(struct ixgbe_adapter *adapter)
 	}
 }
 
-static inline void ixgbe_irq_enable_queues(struct ixgbe_adapter *adapter,
-					   u64 qmask)
+static void ixgbe_irq_enable_queues(struct ixgbe_adapter *adapter, u64 qmask)
 {
 	u32 mask;
 	struct ixgbe_hw *hw = &adapter->hw;
@@ -2565,6 +2723,7 @@ static inline void ixgbe_irq_enable_queues(struct ixgbe_adapter *adapter,
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		mask = (qmask & 0xFFFFFFFF);
 		if (mask)
 			IXGBE_WRITE_REG(hw, IXGBE_EIMS_EX(0), mask);
@@ -2578,34 +2737,6 @@ static inline void ixgbe_irq_enable_queues(struct ixgbe_adapter *adapter,
 	/* skip the flush */
 }
 
-static inline void ixgbe_irq_disable_queues(struct ixgbe_adapter *adapter,
-					    u64 qmask)
-{
-	u32 mask;
-	struct ixgbe_hw *hw = &adapter->hw;
-
-	switch (hw->mac.type) {
-	case ixgbe_mac_82598EB:
-		mask = (IXGBE_EIMS_RTX_QUEUE & qmask);
-		IXGBE_WRITE_REG(hw, IXGBE_EIMC, mask);
-		break;
-	case ixgbe_mac_82599EB:
-	case ixgbe_mac_X540:
-	case ixgbe_mac_X550:
-	case ixgbe_mac_X550EM_x:
-		mask = (qmask & 0xFFFFFFFF);
-		if (mask)
-			IXGBE_WRITE_REG(hw, IXGBE_EIMC_EX(0), mask);
-		mask = (qmask >> 32);
-		if (mask)
-			IXGBE_WRITE_REG(hw, IXGBE_EIMC_EX(1), mask);
-		break;
-	default:
-		break;
-	}
-	/* skip the flush */
-}
-
 /**
  * ixgbe_irq_enable - Enable default interrupt generation settings
  * @adapter: board private structure
@@ -2613,7 +2744,6 @@ static inline void ixgbe_irq_disable_queues(struct ixgbe_adapter *adapter,
 static inline void ixgbe_irq_enable(struct ixgbe_adapter *adapter, bool queues,
 				    bool flush)
 {
-	struct ixgbe_hw *hw = &adapter->hw;
 	u32 mask = (IXGBE_EIMS_ENABLE_MASK & ~IXGBE_EIMS_RTX_QUEUE);
 
 	/* don't reenable LSC while waiting for link */
@@ -2623,32 +2753,39 @@ static inline void ixgbe_irq_enable(struct ixgbe_adapter *adapter, bool queues,
 	if (adapter->flags2 & IXGBE_FLAG2_TEMP_SENSOR_CAPABLE)
 		switch (adapter->hw.mac.type) {
 		case ixgbe_mac_82599EB:
-			mask |= IXGBE_EIMS_GPI_SDP0(hw);
+		case ixgbe_mac_X550EM_a:
+			mask |= IXGBE_EIMS_GPI_SDP0_BY_MAC(&adapter->hw);
 			break;
 		case ixgbe_mac_X540:
 		case ixgbe_mac_X550:
-		case ixgbe_mac_X550EM_x:
 			mask |= IXGBE_EIMS_TS;
 			break;
 		default:
 			break;
 		}
 	if (adapter->flags & IXGBE_FLAG_FAN_FAIL_CAPABLE)
-		mask |= IXGBE_EIMS_GPI_SDP1(hw);
+		mask |= IXGBE_EIMS_GPI_SDP1;
 	switch (adapter->hw.mac.type) {
 	case ixgbe_mac_82599EB:
-		mask |= IXGBE_EIMS_GPI_SDP1(hw);
-		mask |= IXGBE_EIMS_GPI_SDP2(hw);
+		mask |= IXGBE_EIMS_GPI_SDP1;
+		mask |= IXGBE_EIMS_GPI_SDP2;
 		/* fall through */
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
-		if (adapter->hw.device_id == IXGBE_DEV_ID_X550EM_X_SFP)
-			mask |= IXGBE_EIMS_GPI_SDP0(&adapter->hw);
+	case ixgbe_mac_X550EM_a:
+		if (adapter->hw.device_id == IXGBE_DEV_ID_X550EM_X_SFP ||
+		    adapter->hw.device_id == IXGBE_DEV_ID_X550EM_A_SFP ||
+		    adapter->hw.device_id == IXGBE_DEV_ID_X550EM_A_SFP_N)
+			mask |= IXGBE_EIMS_GPI_SDP0_BY_MAC(&adapter->hw);
 		if (adapter->hw.phy.type == ixgbe_phy_x550em_ext_t)
 			mask |= IXGBE_EICR_GPI_SDP0_X540;
 		mask |= IXGBE_EIMS_ECC;
 		mask |= IXGBE_EIMS_MAILBOX;
+#ifdef HAVE_PTP_1588_CLOCK
+		mask |= IXGBE_EIMS_TIMESYNC;
+#endif
+
 		break;
 	default:
 		break;
@@ -2665,22 +2802,22 @@ static inline void ixgbe_irq_enable(struct ixgbe_adapter *adapter, bool queues,
 		IXGBE_WRITE_FLUSH(&adapter->hw);
 }
 
-static irqreturn_t ixgbe_msix_other(int irq, void *data)
+static irqreturn_t ixgbe_msix_other(int __always_unused irq, void *data)
 {
 	struct ixgbe_adapter *adapter = data;
 	struct ixgbe_hw *hw = &adapter->hw;
 	u32 eicr;
 
 	/*
-	 * Workaround for Silicon errata.  Use clear-by-write instead
-	 * of clear-by-read.  Reading with EICS will return the
+	 * Workaround for Silicon errata #26 on 82598.  Use clear-by-write
+	 * instead of clear-by-read.  Reading with EICS will return the
 	 * interrupt causes without clearing, which later be done
 	 * with the write to EICR.
 	 */
 	eicr = IXGBE_READ_REG(hw, IXGBE_EICS);
 
 	/* The lower 16bits of the EICR register are for the queue interrupts
-	 * which should be masked here in order to not accidentally clear them if
+	 * which should be masked here in order to not accidently clear them if
 	 * the bits are high when ixgbe_msix_other is called. There is a race
 	 * condition otherwise which results in possible performance loss
 	 * especially if the ixgbe_msix_other interrupt is triggering
@@ -2701,6 +2838,7 @@ static irqreturn_t ixgbe_msix_other(int irq, void *data)
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		if (hw->phy.type == ixgbe_phy_x550em_ext_t &&
 		    (eicr & IXGBE_EICR_GPI_SDP0_X540)) {
 			adapter->flags2 |= IXGBE_FLAG2_PHY_INTERRUPT;
@@ -2709,28 +2847,36 @@ static irqreturn_t ixgbe_msix_other(int irq, void *data)
 					IXGBE_EICR_GPI_SDP0_X540);
 		}
 		if (eicr & IXGBE_EICR_ECC) {
-			e_info(link, "Received ECC Err, initiating reset\n");
-			adapter->flags2 |= IXGBE_FLAG2_RESET_REQUESTED;
+			e_info(link, "Received unrecoverable ECC Err,"
+			       "initiating reset.\n");
+			set_bit(__IXGBE_RESET_REQUESTED, &adapter->state);
 			ixgbe_service_event_schedule(adapter);
 			IXGBE_WRITE_REG(hw, IXGBE_EICR, IXGBE_EICR_ECC);
 		}
+#ifdef HAVE_TX_MQ
 		/* Handle Flow Director Full threshold interrupt */
 		if (eicr & IXGBE_EICR_FLOW_DIR) {
 			int reinit_count = 0;
 			int i;
 			for (i = 0; i < adapter->num_tx_queues; i++) {
 				struct ixgbe_ring *ring = adapter->tx_ring[i];
-				if (test_and_clear_bit(__IXGBE_TX_FDIR_INIT_DONE,
-						       &ring->state))
+				if (test_and_clear_bit(
+						      __IXGBE_TX_FDIR_INIT_DONE,
+						      &ring->state))
 					reinit_count++;
 			}
 			if (reinit_count) {
-				/* no more flow director interrupts until after init */
-				IXGBE_WRITE_REG(hw, IXGBE_EIMC, IXGBE_EIMC_FLOW_DIR);
-				adapter->flags2 |= IXGBE_FLAG2_FDIR_REQUIRES_REINIT;
+				/* no more flow director interrupts until
+				 * after init
+				 */
+				IXGBE_WRITE_REG(hw, IXGBE_EIMC,
+						IXGBE_EIMC_FLOW_DIR);
+				adapter->flags2 |=
+					IXGBE_FLAG2_FDIR_REQUIRES_REINIT;
 				ixgbe_service_event_schedule(adapter);
 			}
 		}
+#endif
 		ixgbe_check_sfp_event(adapter, eicr);
 		ixgbe_check_overtemp_event(adapter, eicr);
 		break;
@@ -2740,8 +2886,10 @@ static irqreturn_t ixgbe_msix_other(int irq, void *data)
 
 	ixgbe_check_fan_failure(adapter, eicr);
 
+#ifdef HAVE_PTP_1588_CLOCK
 	if (unlikely(eicr & IXGBE_EICR_TIMESYNC))
-		ixgbe_ptp_check_pps_event(adapter, eicr);
+	    ixgbe_ptp_check_pps_event(adapter);
+#endif
 
 	/* re-enable the original interrupt state, no lsc, no queues */
 	if (!test_bit(__IXGBE_DOWN, &adapter->state))
@@ -2750,45 +2898,54 @@ static irqreturn_t ixgbe_msix_other(int irq, void *data)
 	return IRQ_HANDLED;
 }
 
-static irqreturn_t ixgbe_msix_clean_rings(int irq, void *data)
+static irqreturn_t ixgbe_msix_clean_rings(int __always_unused irq, void *data)
 {
 	struct ixgbe_q_vector *q_vector = data;
 
 	/* EIAM disabled interrupts (on this vector) for us */
 
 	if (q_vector->rx.ring || q_vector->tx.ring)
-		napi_schedule(&q_vector->napi);
+		napi_schedule_irqoff(&q_vector->napi);
 
 	return IRQ_HANDLED;
 }
 
 /**
- * ixgbe_poll - NAPI Rx polling callback
- * @napi: structure for representing this polling device
- * @budget: how many packets driver is allowed to clean
+ * ixgbe_poll - NAPI polling RX/TX cleanup routine
+ * @napi: napi struct with our devices info in it
+ * @budget: amount of work driver is allowed to do this pass, in packets
  *
- * This function is used for legacy and MSI, NAPI mode
+ * This function will clean all queues associated with a q_vector.
  **/
 int ixgbe_poll(struct napi_struct *napi, int budget)
 {
 	struct ixgbe_q_vector *q_vector =
-				container_of(napi, struct ixgbe_q_vector, napi);
+			       container_of(napi, struct ixgbe_q_vector, napi);
 	struct ixgbe_adapter *adapter = q_vector->adapter;
 	struct ixgbe_ring *ring;
 	int per_ring_budget, work_done = 0;
 	bool clean_complete = true;
 
-#ifdef CONFIG_IXGBE_DCA
+#if IS_ENABLED(CONFIG_DCA)
 	if (adapter->flags & IXGBE_FLAG_DCA_ENABLED)
 		ixgbe_update_dca(q_vector);
-#endif
+#endif /* CONFIG_DCA */
 
 	ixgbe_for_each_ring(ring, q_vector->tx)
-		clean_complete &= !!ixgbe_clean_tx_irq(q_vector, ring);
+		clean_complete &= ixgbe_clean_tx_irq(q_vector, ring);
+
+#ifdef HAVE_NDO_BUSY_POLL
+	if (test_bit(NAPI_STATE_NPSVC, &napi->state))
+		return budget;
 
 	/* Exit if we are called by netpoll or busy polling is active */
 	if ((budget <= 0) || !ixgbe_qv_lock_napi(q_vector))
 		return budget;
+#else
+	/* Exit if we are called by netpoll */
+	if (budget <= 0)
+		return budget;
+#endif
 
 	/* attempt to distribute budget to each queue fairly, but don't allow
 	 * the budget to go below 1 because we'll exit polling */
@@ -2800,24 +2957,31 @@ int ixgbe_poll(struct napi_struct *napi, int budget)
 	ixgbe_for_each_ring(ring, q_vector->rx) {
 		int cleaned = ixgbe_clean_rx_irq(q_vector, ring,
 						 per_ring_budget);
-
 		work_done += cleaned;
 		clean_complete &= (cleaned < per_ring_budget);
 	}
 
+#ifdef HAVE_NDO_BUSY_POLL
 	ixgbe_qv_unlock_napi(q_vector);
+#endif
+
+#ifndef HAVE_NETDEV_NAPI_LIST
+	if (!netif_running(adapter->netdev))
+		clean_complete = true;
+
+#endif
 	/* If all work not completed, return budget and keep polling */
 	if (!clean_complete)
 		return budget;
 
 	/* all work done, exit the polling mode */
 	napi_complete_done(napi, work_done);
-	if (adapter->rx_itr_setting & 1)
+	if (adapter->rx_itr_setting == 1)
 		ixgbe_set_itr(q_vector);
 	if (!test_bit(__IXGBE_DOWN, &adapter->state))
 		ixgbe_irq_enable_queues(adapter, ((u64)1 << q_vector->v_idx));
 
-	return 0;
+	return min(work_done, budget - 1);
 }
 
 /**
@@ -2830,23 +2994,23 @@ int ixgbe_poll(struct napi_struct *napi, int budget)
 static int ixgbe_request_msix_irqs(struct ixgbe_adapter *adapter)
 {
 	struct net_device *netdev = adapter->netdev;
+	unsigned int ri = 0, ti = 0;
 	int vector, err;
-	int ri = 0, ti = 0;
 
 	for (vector = 0; vector < adapter->num_q_vectors; vector++) {
 		struct ixgbe_q_vector *q_vector = adapter->q_vector[vector];
 		struct msix_entry *entry = &adapter->msix_entries[vector];
 
 		if (q_vector->tx.ring && q_vector->rx.ring) {
-			snprintf(q_vector->name, sizeof(q_vector->name) - 1,
-				 "%s-%s-%d", netdev->name, "TxRx", ri++);
+			snprintf(q_vector->name, sizeof(q_vector->name),
+				 "%s-TxRx-%u", netdev->name, ri++);
 			ti++;
 		} else if (q_vector->rx.ring) {
-			snprintf(q_vector->name, sizeof(q_vector->name) - 1,
-				 "%s-%s-%d", netdev->name, "rx", ri++);
+			snprintf(q_vector->name, sizeof(q_vector->name),
+				 "%s-rx-%u", netdev->name, ri++);
 		} else if (q_vector->tx.ring) {
-			snprintf(q_vector->name, sizeof(q_vector->name) - 1,
-				 "%s-%s-%d", netdev->name, "tx", ti++);
+			snprintf(q_vector->name, sizeof(q_vector->name),
+				 "%s-tx-%u", netdev->name, ti++);
 		} else {
 			/* skip this unused q_vector */
 			continue;
@@ -2854,16 +3018,18 @@ static int ixgbe_request_msix_irqs(struct ixgbe_adapter *adapter)
 		err = request_irq(entry->vector, &ixgbe_msix_clean_rings, 0,
 				  q_vector->name, q_vector);
 		if (err) {
-			e_err(probe, "request_irq failed for MSIX interrupt "
-			      "Error: %d\n", err);
+			e_err(probe, "request_irq failed for MSIX interrupt '%s' "
+			      "Error: %d\n", q_vector->name, err);
 			goto free_queue_irqs;
 		}
+#ifdef HAVE_IRQ_AFFINITY_HINT
 		/* If Flow Director is enabled, set interrupt affinity */
 		if (adapter->flags & IXGBE_FLAG_FDIR_HASH_CAPABLE) {
 			/* assign the mask for this irq */
 			irq_set_affinity_hint(entry->vector,
 					      &q_vector->affinity_mask);
 		}
+#endif /* HAVE_IRQ_AFFINITY_HINT */
 	}
 
 	err = request_irq(adapter->msix_entries[vector].vector,
@@ -2873,13 +3039,15 @@ static int ixgbe_request_msix_irqs(struct ixgbe_adapter *adapter)
 		goto free_queue_irqs;
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 
 free_queue_irqs:
 	while (vector) {
 		vector--;
+#ifdef HAVE_IRQ_AFFINITY_HINT
 		irq_set_affinity_hint(adapter->msix_entries[vector].vector,
 				      NULL);
+#endif
 		free_irq(adapter->msix_entries[vector].vector,
 			 adapter->q_vector[vector]);
 	}
@@ -2895,7 +3063,7 @@ free_queue_irqs:
  * @irq: interrupt number
  * @data: pointer to a network interface device structure
  **/
-static irqreturn_t ixgbe_intr(int irq, void *data)
+static irqreturn_t ixgbe_intr(int __always_unused irq, void *data)
 {
 	struct ixgbe_adapter *adapter = data;
 	struct ixgbe_hw *hw = &adapter->hw;
@@ -2929,17 +3097,19 @@ static irqreturn_t ixgbe_intr(int irq, void *data)
 
 	switch (hw->mac.type) {
 	case ixgbe_mac_82599EB:
-		ixgbe_check_sfp_event(adapter, eicr);
-		/* Fall through */
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+
 		if (eicr & IXGBE_EICR_ECC) {
-			e_info(link, "Received ECC Err, initiating reset\n");
-			adapter->flags2 |= IXGBE_FLAG2_RESET_REQUESTED;
+			e_info(link, "Received unrecoverable ECC Err,"
+			       "initiating reset.\n");
+			set_bit(__IXGBE_RESET_REQUESTED, &adapter->state);
 			ixgbe_service_event_schedule(adapter);
 			IXGBE_WRITE_REG(hw, IXGBE_EICR, IXGBE_EICR_ECC);
 		}
+		ixgbe_check_sfp_event(adapter, eicr);
 		ixgbe_check_overtemp_event(adapter, eicr);
 		break;
 	default:
@@ -2947,11 +3117,13 @@ static irqreturn_t ixgbe_intr(int irq, void *data)
 	}
 
 	ixgbe_check_fan_failure(adapter, eicr);
+#ifdef HAVE_PTP_1588_CLOCK
 	if (unlikely(eicr & IXGBE_EICR_TIMESYNC))
-		ixgbe_ptp_check_pps_event(adapter, eicr);
+	    ixgbe_ptp_check_pps_event(adapter);
+#endif
 
 	/* would disable interrupts here but EIAM disabled it */
-	napi_schedule(&q_vector->napi);
+	napi_schedule_irqoff(&q_vector->napi);
 
 	/*
 	 * re-enable link(maybe) and non-queue interrupts, no flush.
@@ -2978,10 +3150,10 @@ static int ixgbe_request_irq(struct ixgbe_adapter *adapter)
 	if (adapter->flags & IXGBE_FLAG_MSIX_ENABLED)
 		err = ixgbe_request_msix_irqs(adapter);
 	else if (adapter->flags & IXGBE_FLAG_MSI_ENABLED)
-		err = request_irq(adapter->pdev->irq, ixgbe_intr, 0,
+		err = request_irq(adapter->pdev->irq, &ixgbe_intr, 0,
 				  netdev->name, adapter);
 	else
-		err = request_irq(adapter->pdev->irq, ixgbe_intr, IRQF_SHARED,
+		err = request_irq(adapter->pdev->irq, &ixgbe_intr, IRQF_SHARED,
 				  netdev->name, adapter);
 
 	if (err)
@@ -2999,6 +3171,9 @@ static void ixgbe_free_irq(struct ixgbe_adapter *adapter)
 		return;
 	}
 
+	if (!adapter->msix_entries)
+		return;
+
 	for (vector = 0; vector < adapter->num_q_vectors; vector++) {
 		struct ixgbe_q_vector *q_vector = adapter->q_vector[vector];
 		struct msix_entry *entry = &adapter->msix_entries[vector];
@@ -3007,13 +3182,15 @@ static void ixgbe_free_irq(struct ixgbe_adapter *adapter)
 		if (!q_vector->rx.ring && !q_vector->tx.ring)
 			continue;
 
+#ifdef HAVE_IRQ_AFFINITY_HINT
 		/* clear the affinity_mask in the IRQ descriptor */
 		irq_set_affinity_hint(entry->vector, NULL);
 
+#endif
 		free_irq(entry->vector, q_vector);
 	}
 
-	free_irq(adapter->msix_entries[vector++].vector, adapter);
+	free_irq(adapter->msix_entries[vector].vector, adapter);
 }
 
 /**
@@ -3030,6 +3207,7 @@ static inline void ixgbe_irq_disable(struct ixgbe_adapter *adapter)
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		IXGBE_WRITE_REG(&adapter->hw, IXGBE_EIMC, 0xFFFF0000);
 		IXGBE_WRITE_REG(&adapter->hw, IXGBE_EIMC_EX(0), ~0);
 		IXGBE_WRITE_REG(&adapter->hw, IXGBE_EIMC_EX(1), ~0);
@@ -3083,18 +3261,27 @@ void ixgbe_configure_tx_ring(struct ixgbe_adapter *adapter,
 	u8 reg_idx = ring->reg_idx;
 
 	/* disable queue to avoid issues while updating state */
-	IXGBE_WRITE_REG(hw, IXGBE_TXDCTL(reg_idx), 0);
+	IXGBE_WRITE_REG(hw, IXGBE_TXDCTL(reg_idx), IXGBE_TXDCTL_SWFLSH);
 	IXGBE_WRITE_FLUSH(hw);
 
-	IXGBE_WRITE_REG(hw, IXGBE_TDBAL(reg_idx),
-			(tdba & DMA_BIT_MASK(32)));
-	IXGBE_WRITE_REG(hw, IXGBE_TDBAH(reg_idx), (tdba >> 32));
+	IXGBE_WRITE_REG(hw, IXGBE_TDBAL(reg_idx), tdba & DMA_BIT_MASK(32));
+	IXGBE_WRITE_REG(hw, IXGBE_TDBAH(reg_idx), tdba >> 32);
 	IXGBE_WRITE_REG(hw, IXGBE_TDLEN(reg_idx),
 			ring->count * sizeof(union ixgbe_adv_tx_desc));
+
+	/* disable head writeback */
+	IXGBE_WRITE_REG(hw, IXGBE_TDWBAH(reg_idx), 0);
+	IXGBE_WRITE_REG(hw, IXGBE_TDWBAL(reg_idx), 0);
+
+	/* reset head and tail pointers */
 	IXGBE_WRITE_REG(hw, IXGBE_TDH(reg_idx), 0);
 	IXGBE_WRITE_REG(hw, IXGBE_TDT(reg_idx), 0);
 	ring->tail = adapter->io_addr + IXGBE_TDT(reg_idx);
 
+	/* reset ntu and ntc to place SW in sync with hardwdare */
+	ring->next_to_clean = 0;
+	ring->next_to_use = 0;
+
 	/*
 	 * set WTHRESH to encourage burst writeback, it should not be set
 	 * higher than 1 when:
@@ -3131,13 +3318,17 @@ void ixgbe_configure_tx_ring(struct ixgbe_adapter *adapter,
 		struct ixgbe_q_vector *q_vector = ring->q_vector;
 
 		if (q_vector)
-			netif_set_xps_queue(ring->netdev,
+			netif_set_xps_queue(adapter->netdev,
 					    &q_vector->affinity_mask,
 					    ring->queue_index);
 	}
 
 	clear_bit(__IXGBE_HANG_CHECK_ARMED, &ring->state);
 
+	/* reinitialize tx_buffer_info */
+	memset(ring->tx_buffer_info, 0,
+	       sizeof(struct ixgbe_tx_buffer) * ring->count);
+
 	/* enable queue */
 	IXGBE_WRITE_REG(hw, IXGBE_TXDCTL(reg_idx), txdctl);
 
@@ -3148,11 +3339,11 @@ void ixgbe_configure_tx_ring(struct ixgbe_adapter *adapter,
 
 	/* poll to verify queue is enabled */
 	do {
-		usleep_range(1000, 2000);
+		msleep(1);
 		txdctl = IXGBE_READ_REG(hw, IXGBE_TXDCTL(reg_idx));
 	} while (--wait_loop && !(txdctl & IXGBE_TXDCTL_ENABLE));
 	if (!wait_loop)
-		e_err(drv, "Could not enable Tx Queue %d\n", reg_idx);
+		hw_dbg(hw, "Could not enable Tx Queue %d\n", reg_idx);
 }
 
 static void ixgbe_setup_mtqc(struct ixgbe_adapter *adapter)
@@ -3170,13 +3361,14 @@ static void ixgbe_setup_mtqc(struct ixgbe_adapter *adapter)
 	IXGBE_WRITE_REG(hw, IXGBE_RTTDCS, rttdcs);
 
 	/* set transmit pool layout */
-	if (adapter->flags & IXGBE_FLAG_SRIOV_ENABLED) {
+	if (adapter->flags & IXGBE_FLAG_VMDQ_ENABLED) {
 		mtqc = IXGBE_MTQC_VT_ENA;
 		if (tcs > 4)
 			mtqc |= IXGBE_MTQC_RT_ENA | IXGBE_MTQC_8TC_8TQ;
 		else if (tcs > 1)
 			mtqc |= IXGBE_MTQC_RT_ENA | IXGBE_MTQC_4TC_4TQ;
-		else if (adapter->ring_feature[RING_F_RSS].indices == 4)
+		else if (adapter->ring_feature[RING_F_VMDQ].mask ==
+			 IXGBE_82599_VMDQ_4Q_MASK)
 			mtqc |= IXGBE_MTQC_32VF;
 		else
 			mtqc |= IXGBE_MTQC_64VF;
@@ -3215,6 +3407,13 @@ static void ixgbe_configure_tx(struct ixgbe_adapter *adapter)
 	u32 dmatxctl;
 	u32 i;
 
+#ifdef CONFIG_NETDEVICES_MULTIQUEUE
+	if (adapter->num_tx_queues > 1)
+		adapter->netdev->features |= NETIF_F_MULTI_QUEUE;
+	else
+		adapter->netdev->features &= ~NETIF_F_MULTI_QUEUE;
+
+#endif
 	ixgbe_setup_mtqc(adapter);
 
 	if (hw->mac.type != ixgbe_mac_82598EB) {
@@ -3253,18 +3452,16 @@ static void ixgbe_disable_rx_drop(struct ixgbe_adapter *adapter,
 	IXGBE_WRITE_REG(hw, IXGBE_SRRCTL(reg_idx), srrctl);
 }
 
-#ifdef CONFIG_IXGBE_DCB
 void ixgbe_set_rx_drop_en(struct ixgbe_adapter *adapter)
-#else
-static void ixgbe_set_rx_drop_en(struct ixgbe_adapter *adapter)
-#endif
 {
 	int i;
 	bool pfc_en = adapter->dcb_cfg.pfc_mode_enable;
 
+#ifdef HAVE_DCBNL_IEEE
 	if (adapter->ixgbe_ieee_pfc)
 		pfc_en |= !!(adapter->ixgbe_ieee_pfc->pfc_en);
 
+#endif
 	/*
 	 * We should set the drop enable bit if:
 	 *  SR-IOV is enabled
@@ -3284,8 +3481,6 @@ static void ixgbe_set_rx_drop_en(struct ixgbe_adapter *adapter)
 	}
 }
 
-#define IXGBE_SRRCTL_BSIZEHDRSIZE_SHIFT 2
-
 static void ixgbe_configure_srrctl(struct ixgbe_adapter *adapter,
 				   struct ixgbe_ring *rx_ring)
 {
@@ -3296,19 +3491,35 @@ static void ixgbe_configure_srrctl(struct ixgbe_adapter *adapter,
 	if (hw->mac.type == ixgbe_mac_82598EB) {
 		u16 mask = adapter->ring_feature[RING_F_RSS].mask;
 
+		/* program one srrctl register per VMDq index */
+		if (adapter->flags & IXGBE_FLAG_VMDQ_ENABLED)
+			mask = adapter->ring_feature[RING_F_VMDQ].mask;
+
 		/*
 		 * if VMDq is not active we must program one srrctl register
 		 * per RSS queue since we have enabled RDRXCTL.MVMEN
 		 */
 		reg_idx &= mask;
+
+		/* divide by the first bit of the mask to get the indices */
+		if (reg_idx)
+			reg_idx /= ((~mask) + 1) & mask;
 	}
 
 	/* configure header buffer length, needed for RSC */
 	srrctl = IXGBE_RX_HDR_SIZE << IXGBE_SRRCTL_BSIZEHDRSIZE_SHIFT;
 
 	/* configure the packet buffer length */
-	srrctl |= ixgbe_rx_bufsz(rx_ring) >> IXGBE_SRRCTL_BSIZEPKT_SHIFT;
-
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	srrctl |= ALIGN(rx_ring->rx_buf_len, 1024) >>
+		  IXGBE_SRRCTL_BSIZEPKT_SHIFT;
+#else
+	if (test_bit(__IXGBE_RX_3K_BUFFER, &rx_ring->state))
+		srrctl |= IXGBE_RXBUFFER_3K >> IXGBE_SRRCTL_BSIZEPKT_SHIFT;
+	else
+		srrctl |= IXGBE_RXBUFFER_2K >> IXGBE_SRRCTL_BSIZEPKT_SHIFT;
+#endif
+
 	/* configure descriptor type */
 	srrctl |= IXGBE_SRRCTL_DESCTYPE_ADV_ONEBUF;
 
@@ -3316,8 +3527,7 @@ static void ixgbe_configure_srrctl(struct ixgbe_adapter *adapter,
 }
 
 /**
- * Return a number of entries in the RSS indirection table
- *
+ * ixgbe_rss_indir_tbl_entries - Return RSS indirection table entries
  * @adapter: device handle
  *
  *  - 82598/82599/X540:     128
@@ -3335,8 +3545,44 @@ u32 ixgbe_rss_indir_tbl_entries(struct ixgbe_adapter *adapter)
 }
 
 /**
- * Write the RETA table to HW
+ * ixgbe_store_key - Write the RSS key to HW
+ * @adapter: device handle
+ *
+ * Write the RSS key stored in adapter.rss_key to HW.
+ */
+void ixgbe_store_key(struct ixgbe_adapter *adapter)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	int i;
+
+	for (i = 0; i < 10; i++)
+		IXGBE_WRITE_REG(hw, IXGBE_RSSRK(i), adapter->rss_key[i]);
+}
+
+/**
+ * ixgbe_init_rss_key - Initialize adapter RSS key
+ * @adapter: device handle
  *
+ * Allocates and initializes the RSS key if it is not allocated.
+ **/
+static inline int ixgbe_init_rss_key(struct ixgbe_adapter *adapter)
+{
+	u32 *rss_key;
+
+	if (!adapter->rss_key) {
+		rss_key = kzalloc(IXGBE_RSS_KEY_SIZE, GFP_KERNEL);
+		if (unlikely(!rss_key))
+			return -ENOMEM;
+
+		netdev_rss_key_fill(rss_key, IXGBE_RSS_KEY_SIZE);
+		adapter->rss_key = rss_key;
+	}
+
+	return 0;
+}
+
+/**
+ * ixgbe_store_reta - Write the RETA table to HW
  * @adapter: device handle
  *
  * Write the RSS redirection table stored in adapter.rss_indir_tbl[] to HW.
@@ -3375,8 +3621,7 @@ void ixgbe_store_reta(struct ixgbe_adapter *adapter)
 }
 
 /**
- * Write the RETA table to HW (for x550 devices in SRIOV mode)
- *
+ * ixgbe_store_vfreta - Write the RETA table to HW (x550 devices in SRIOV mode)
  * @adapter: device handle
  *
  * Write the RSS redirection table stored in adapter.rss_indir_tbl[] to HW.
@@ -3401,21 +3646,19 @@ static void ixgbe_store_vfreta(struct ixgbe_adapter *adapter)
 
 static void ixgbe_setup_reta(struct ixgbe_adapter *adapter)
 {
-	struct ixgbe_hw *hw = &adapter->hw;
 	u32 i, j;
 	u32 reta_entries = ixgbe_rss_indir_tbl_entries(adapter);
 	u16 rss_i = adapter->ring_feature[RING_F_RSS].indices;
 
-	/* Program table for at least 2 queues w/ SR-IOV so that VFs can
+	/* Program table for at least 4 queues w/ SR-IOV so that VFs can
 	 * make full use of any rings they may have.  We will use the
 	 * PSRTYPE register to control how many rings we use within the PF.
 	 */
-	if ((adapter->flags & IXGBE_FLAG_SRIOV_ENABLED) && (rss_i < 2))
-		rss_i = 2;
+	if ((adapter->flags & IXGBE_FLAG_SRIOV_ENABLED) && (rss_i < 4))
+		rss_i = 4;
 
 	/* Fill out hash function seeds */
-	for (i = 0; i < 10; i++)
-		IXGBE_WRITE_REG(hw, IXGBE_RSSRK(i), adapter->rss_key[i]);
+	ixgbe_store_key(adapter);
 
 	/* Fill out redirection table */
 	memset(adapter->rss_indir_tbl, 0, sizeof(adapter->rss_indir_tbl));
@@ -3440,7 +3683,7 @@ static void ixgbe_setup_vfreta(struct ixgbe_adapter *adapter)
 	/* Fill out hash function seeds */
 	for (i = 0; i < 10; i++)
 		IXGBE_WRITE_REG(hw, IXGBE_PFVFRSSRK(i, pf_pool),
-				adapter->rss_key[i]);
+				*(adapter->rss_key + i));
 
 	/* Fill out the redirection table */
 	for (i = 0, j = 0; i < 64; i++, j++) {
@@ -3453,11 +3696,13 @@ static void ixgbe_setup_vfreta(struct ixgbe_adapter *adapter)
 	ixgbe_store_vfreta(adapter);
 }
 
+
 static void ixgbe_setup_mrqc(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
-	u32 mrqc = 0, rss_field = 0, vfmrqc = 0;
 	u32 rxcsum;
+	u32 mrqc = 0, rss_field = 0;
+	u32 vfmrqc = 0;
 
 	/* Disable indicating checksum in descriptor, enables RSS hash */
 	rxcsum = IXGBE_READ_REG(hw, IXGBE_RXCSUM);
@@ -3470,12 +3715,13 @@ static void ixgbe_setup_mrqc(struct ixgbe_adapter *adapter)
 	} else {
 		u8 tcs = netdev_get_num_tc(adapter->netdev);
 
-		if (adapter->flags & IXGBE_FLAG_SRIOV_ENABLED) {
+		if (adapter->flags & IXGBE_FLAG_VMDQ_ENABLED) {
 			if (tcs > 4)
 				mrqc = IXGBE_MRQC_VMDQRT8TCEN;	/* 8 TCs */
 			else if (tcs > 1)
 				mrqc = IXGBE_MRQC_VMDQRT4TCEN;	/* 4 TCs */
-			else if (adapter->ring_feature[RING_F_RSS].indices == 4)
+			else if (adapter->ring_feature[RING_F_VMDQ].mask ==
+				 IXGBE_82599_VMDQ_4Q_MASK)
 				mrqc = IXGBE_MRQC_VMDQRSS32EN;
 			else
 				mrqc = IXGBE_MRQC_VMDQRSS64EN;
@@ -3487,10 +3733,13 @@ static void ixgbe_setup_mrqc(struct ixgbe_adapter *adapter)
 			else
 				mrqc = IXGBE_MRQC_RSSEN;
 		}
+
+		/* Enable L3/L4 for Tx Switched packets */
+		mrqc |= IXGBE_MRQC_L3L4TXSWEN;
 	}
 
 	/* Perform hash on these packet types */
-	rss_field |= IXGBE_MRQC_RSS_FIELD_IPV4 |
+	rss_field = IXGBE_MRQC_RSS_FIELD_IPV4 |
 		     IXGBE_MRQC_RSS_FIELD_IPV4_TCP |
 		     IXGBE_MRQC_RSS_FIELD_IPV6 |
 		     IXGBE_MRQC_RSS_FIELD_IPV6_TCP;
@@ -3500,7 +3749,6 @@ static void ixgbe_setup_mrqc(struct ixgbe_adapter *adapter)
 	if (adapter->flags2 & IXGBE_FLAG2_RSS_FIELD_IPV6_UDP)
 		rss_field |= IXGBE_MRQC_RSS_FIELD_IPV6_UDP;
 
-	netdev_rss_key_fill(adapter->rss_key, sizeof(adapter->rss_key));
 	if ((hw->mac.type >= ixgbe_mac_X550) &&
 	    (adapter->flags & IXGBE_FLAG_SRIOV_ENABLED)) {
 		unsigned int pf_pool = adapter->num_vfs;
@@ -3522,12 +3770,31 @@ static void ixgbe_setup_mrqc(struct ixgbe_adapter *adapter)
 }
 
 /**
+ * ixgbe_clear_rscctl - disable RSC for the indicated ring
+ * @adapter: address of board private structure
+ * @ring: structure containing ring specific data
+ **/
+void ixgbe_clear_rscctl(struct ixgbe_adapter *adapter,
+			struct ixgbe_ring *ring)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	u32 rscctrl;
+	u8 reg_idx = ring->reg_idx;
+
+	rscctrl = IXGBE_READ_REG(hw, IXGBE_RSCCTL(reg_idx));
+	rscctrl &= ~IXGBE_RSCCTL_RSCEN;
+	IXGBE_WRITE_REG(hw, IXGBE_RSCCTL(reg_idx), rscctrl);
+
+	clear_ring_rsc_enabled(ring);
+}
+
+/**
  * ixgbe_configure_rscctl - enable RSC for the indicated ring
  * @adapter:    address of board private structure
- * @index:      index of ring to set
+ * @ring: structure containing ring specific data
  **/
-static void ixgbe_configure_rscctl(struct ixgbe_adapter *adapter,
-				   struct ixgbe_ring *ring)
+void ixgbe_configure_rscctl(struct ixgbe_adapter *adapter,
+			    struct ixgbe_ring *ring)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	u32 rscctrl;
@@ -3543,11 +3810,27 @@ static void ixgbe_configure_rscctl(struct ixgbe_adapter *adapter,
 	 * total size of max desc * buf_len is not greater
 	 * than 65536
 	 */
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+#if (MAX_SKB_FRAGS >= 16)
 	rscctrl |= IXGBE_RSCCTL_MAXDESC_16;
+#elif (MAX_SKB_FRAGS >= 8)
+	rscctrl |= IXGBE_RSCCTL_MAXDESC_8;
+#elif (MAX_SKB_FRAGS >= 4)
+	rscctrl |= IXGBE_RSCCTL_MAXDESC_4;
+#else
+	rscctrl |= IXGBE_RSCCTL_MAXDESC_1;
+#endif
+#else /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
+	if (ring->rx_buf_len <= IXGBE_RXBUFFER_4K)
+		rscctrl |= IXGBE_RSCCTL_MAXDESC_16;
+	else if (ring->rx_buf_len <= IXGBE_RXBUFFER_8K)
+		rscctrl |= IXGBE_RSCCTL_MAXDESC_8;
+	else
+		rscctrl |= IXGBE_RSCCTL_MAXDESC_4;
+#endif /* !CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
 	IXGBE_WRITE_REG(hw, IXGBE_RSCCTL(reg_idx), rscctrl);
 }
 
-#define IXGBE_MAX_RX_DESC_POLL 10
 static void ixgbe_rx_desc_queue_enable(struct ixgbe_adapter *adapter,
 				       struct ixgbe_ring *ring)
 {
@@ -3556,7 +3839,7 @@ static void ixgbe_rx_desc_queue_enable(struct ixgbe_adapter *adapter,
 	u32 rxdctl;
 	u8 reg_idx = ring->reg_idx;
 
-	if (ixgbe_removed(hw->hw_addr))
+	if (IXGBE_REMOVED(hw->hw_addr))
 		return;
 	/* RXDCTL.EN will return 0 on 82598 if link is down, so skip it */
 	if (hw->mac.type == ixgbe_mac_82598EB &&
@@ -3564,13 +3847,13 @@ static void ixgbe_rx_desc_queue_enable(struct ixgbe_adapter *adapter,
 		return;
 
 	do {
-		usleep_range(1000, 2000);
+		msleep(1);
 		rxdctl = IXGBE_READ_REG(hw, IXGBE_RXDCTL(reg_idx));
 	} while (--wait_loop && !(rxdctl & IXGBE_RXDCTL_ENABLE));
 
 	if (!wait_loop) {
-		e_err(drv, "RXDCTL.ENABLE on Rx queue %d not set within "
-		      "the polling period\n", reg_idx);
+		e_err(drv, "RXDCTL.ENABLE on Rx queue %d "
+		      "not set within the polling period\n", reg_idx);
 	}
 }
 
@@ -3582,7 +3865,7 @@ void ixgbe_disable_rx_queue(struct ixgbe_adapter *adapter,
 	u32 rxdctl;
 	u8 reg_idx = ring->reg_idx;
 
-	if (ixgbe_removed(hw->hw_addr))
+	if (IXGBE_REMOVED(hw->hw_addr))
 		return;
 	rxdctl = IXGBE_READ_REG(hw, IXGBE_RXDCTL(reg_idx));
 	rxdctl &= ~IXGBE_RXDCTL_ENABLE;
@@ -3610,6 +3893,7 @@ void ixgbe_configure_rx_ring(struct ixgbe_adapter *adapter,
 			     struct ixgbe_ring *ring)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
+	union ixgbe_adv_rx_desc *rx_desc;
 	u64 rdba = ring->dma;
 	u32 rxdctl;
 	u8 reg_idx = ring->reg_idx;
@@ -3618,18 +3902,31 @@ void ixgbe_configure_rx_ring(struct ixgbe_adapter *adapter,
 	rxdctl = IXGBE_READ_REG(hw, IXGBE_RXDCTL(reg_idx));
 	ixgbe_disable_rx_queue(adapter, ring);
 
-	IXGBE_WRITE_REG(hw, IXGBE_RDBAL(reg_idx), (rdba & DMA_BIT_MASK(32)));
-	IXGBE_WRITE_REG(hw, IXGBE_RDBAH(reg_idx), (rdba >> 32));
+	IXGBE_WRITE_REG(hw, IXGBE_RDBAL(reg_idx), rdba & DMA_BIT_MASK(32));
+	IXGBE_WRITE_REG(hw, IXGBE_RDBAH(reg_idx), rdba >> 32);
 	IXGBE_WRITE_REG(hw, IXGBE_RDLEN(reg_idx),
 			ring->count * sizeof(union ixgbe_adv_rx_desc));
+	/* Force flushing of IXGBE_RDLEN to prevent MDD */
+	IXGBE_WRITE_FLUSH(hw);
+
+	/* reset head and tail pointers */
 	IXGBE_WRITE_REG(hw, IXGBE_RDH(reg_idx), 0);
 	IXGBE_WRITE_REG(hw, IXGBE_RDT(reg_idx), 0);
 	ring->tail = adapter->io_addr + IXGBE_RDT(reg_idx);
 
+	/* reset ntu and ntc to place SW in sync with hardwdare */
+	ring->next_to_clean = 0;
+	ring->next_to_use = 0;
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	ring->next_to_alloc = 0;
+#endif
+
 	ixgbe_configure_srrctl(adapter, ring);
+        /* In ESX, RSCCTL configuration is done by on demand */
 	ixgbe_configure_rscctl(adapter, ring);
 
-	if (hw->mac.type == ixgbe_mac_82598EB) {
+	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
 		/*
 		 * enable cache line friendly hardware writes:
 		 * PTHRESH=32 descriptors (half the internal cache),
@@ -3639,8 +3936,41 @@ void ixgbe_configure_rx_ring(struct ixgbe_adapter *adapter,
 		 */
 		rxdctl &= ~0x3FFFFF;
 		rxdctl |=  0x080420;
+		break;
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+#if (PAGE_SIZE < 8192)
+		rxdctl &= ~(IXGBE_RXDCTL_RLPMLMASK |
+			    IXGBE_RXDCTL_RLPML_EN);
+
+		/* Limit the maximum frame size so we don't overrun the skb */
+		if (ring_uses_build_skb(ring) &&
+		    !test_bit(__IXGBE_RX_3K_BUFFER, &ring->state))
+			rxdctl |= IXGBE_MAX_2K_FRAME_BUILD_SKB |
+				  IXGBE_RXDCTL_RLPML_EN;
+#endif
+#else /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
+		/* If operating in IOV mode set RLPML */
+		if (!(adapter->flags & IXGBE_FLAG_SRIOV_ENABLED))
+			break;
+		rxdctl |= ring->rx_buf_len | IXGBE_RXDCTL_RLPML_EN;
+#endif /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
+		break;
+	default:
+		break;
 	}
 
+	/* initialize rx_buffer_info */
+	memset(ring->rx_buffer_info, 0,
+	       sizeof(struct ixgbe_rx_buffer) * ring->count);
+
+	/* initialize Rx descriptor 0 */
+	rx_desc = IXGBE_RX_DESC(ring, 0);
+	rx_desc->wb.upper.length = 0;
+
 	/* enable receive descriptor ring */
 	rxdctl |= IXGBE_RXDCTL_ENABLE;
 	IXGBE_WRITE_REG(hw, IXGBE_RXDCTL(reg_idx), rxdctl);
@@ -3653,7 +3983,7 @@ static void ixgbe_setup_psrtype(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	int rss_i = adapter->ring_feature[RING_F_RSS].indices;
-	u16 pool;
+	int p;
 
 	/* PSRTYPE must be initialized in non 82598 adapters */
 	u32 psrtype = IXGBE_PSRTYPE_TCPHDR |
@@ -3666,12 +3996,71 @@ static void ixgbe_setup_psrtype(struct ixgbe_adapter *adapter)
 		return;
 
 	if (rss_i > 3)
-		psrtype |= 2 << 29;
+		psrtype |= 2u << 29;
 	else if (rss_i > 1)
-		psrtype |= 1 << 29;
+		psrtype |= 1u << 29;
+
+	for (p = 0; p < adapter->num_rx_pools; p++)
+		IXGBE_WRITE_REG(hw, IXGBE_PSRTYPE(VMDQ_P(p)), psrtype);
+}
+
+/**
+ * ixgbe_configure_bridge_mode - common settings for configuring bridge mode
+ * @adapter - the private structure
+ *
+ * This function's purpose is to remove code duplication and configure some
+ * settings require to switch bridge modes.
+ **/
+static void ixgbe_configure_bridge_mode(struct ixgbe_adapter *adapter)
+{
+	struct ixgbe_hw * hw = &adapter->hw;
+	unsigned int p;
+	u32 vmdctl;
+
+	if (adapter->flags & IXGBE_FLAG_SRIOV_VEPA_BRIDGE_MODE) {
+		/* disable Tx loopback, rely on switch hairpin mode */
+		IXGBE_WRITE_REG(hw, IXGBE_PFDTXGSWC, 0);
+
+		/* must enable Rx switching replication to allow multicast
+		 * packet reception on all VFs, and to enable source address
+		 * pruning.
+		 */
+		vmdctl = IXGBE_READ_REG(hw, IXGBE_VMD_CTL);
+		vmdctl |= IXGBE_VT_CTL_REPLEN;
+		IXGBE_WRITE_REG(hw, IXGBE_VMD_CTL, vmdctl);
+
+		/* enable Rx source address pruning. Note, this requires
+		 * replication to be enabled or else it does nothing.
+		 */
+		for (p = 0; p < (adapter->num_vfs + adapter->num_rx_pools); p++) {
+			if (hw->mac.ops.set_source_address_pruning)
+				hw->mac.ops.set_source_address_pruning(hw,
+								       true,
+								       p);
+		}
+	} else {
+		/* enable Tx loopback for internal VF/PF communication */
+		IXGBE_WRITE_REG(hw, IXGBE_PFDTXGSWC, IXGBE_PFDTXGSWC_VT_LBEN);
+
+		/* disable Rx switching replication unless we have SR-IOV
+		 * virtual functions
+		 */
+		vmdctl = IXGBE_READ_REG(hw, IXGBE_VMD_CTL);
+		if (!adapter->num_vfs)
+			vmdctl &= ~IXGBE_VT_CTL_REPLEN;
+		IXGBE_WRITE_REG(hw, IXGBE_VMD_CTL, vmdctl);
+
+		/* disable Rx source address pruning, since we don't expect to
+		 * be receiving external loopback of our transmitted frames.
+		 */
+		for (p = 0; p < (adapter->num_vfs + adapter->num_rx_pools); p++) {
+			if (hw->mac.ops.set_source_address_pruning)
+				hw->mac.ops.set_source_address_pruning(hw,
+								       false,
+								       p);
+		}
+	}
 
-	for_each_set_bit(pool, &adapter->fwd_bitmask, 32)
-		IXGBE_WRITE_REG(hw, IXGBE_PSRTYPE(VMDQ_P(pool)), psrtype);
 }
 
 static void ixgbe_configure_virtualization(struct ixgbe_adapter *adapter)
@@ -3681,29 +4070,60 @@ static void ixgbe_configure_virtualization(struct ixgbe_adapter *adapter)
 	u32 gcr_ext, vmdctl;
 	int i;
 
-	if (!(adapter->flags & IXGBE_FLAG_SRIOV_ENABLED))
+	if (!(adapter->flags & IXGBE_FLAG_VMDQ_ENABLED))
 		return;
 
-	vmdctl = IXGBE_READ_REG(hw, IXGBE_VT_CTL);
-	vmdctl |= IXGBE_VMD_CTL_VMDQ_EN;
-	vmdctl &= ~IXGBE_VT_CTL_POOL_MASK;
-	vmdctl |= VMDQ_P(0) << IXGBE_VT_CTL_POOL_SHIFT;
-	vmdctl |= IXGBE_VT_CTL_REPLEN;
-	IXGBE_WRITE_REG(hw, IXGBE_VT_CTL, vmdctl);
-
-	vf_shift = VMDQ_P(0) % 32;
-	reg_offset = (VMDQ_P(0) >= 32) ? 1 : 0;
-
-	/* Enable only the PF's pool for Tx/Rx */
-	IXGBE_WRITE_REG(hw, IXGBE_VFRE(reg_offset), (~0) << vf_shift);
-	IXGBE_WRITE_REG(hw, IXGBE_VFRE(reg_offset ^ 1), reg_offset - 1);
-	IXGBE_WRITE_REG(hw, IXGBE_VFTE(reg_offset), (~0) << vf_shift);
-	IXGBE_WRITE_REG(hw, IXGBE_VFTE(reg_offset ^ 1), reg_offset - 1);
-	if (adapter->bridge_mode == BRIDGE_MODE_VEB)
-		IXGBE_WRITE_REG(hw, IXGBE_PFDTXGSWC, IXGBE_PFDTXGSWC_VT_LBEN);
+	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		vmdctl = IXGBE_READ_REG(hw, IXGBE_VMD_CTL);
+		vmdctl |= IXGBE_VMD_CTL_VMDQ_EN;
+		IXGBE_WRITE_REG(hw, IXGBE_VMD_CTL, vmdctl);
+		break;
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540:
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		vmdctl = IXGBE_READ_REG(hw, IXGBE_VT_CTL);
+		vmdctl |= IXGBE_VT_CTL_VT_ENABLE;
+		vmdctl &= ~IXGBE_VT_CTL_POOL_MASK;
+		vmdctl |= VMDQ_P(0) << IXGBE_VT_CTL_POOL_SHIFT;
+		if (adapter->num_vfs)
+			vmdctl |= IXGBE_VT_CTL_REPLEN;
+		IXGBE_WRITE_REG(hw, IXGBE_VT_CTL, vmdctl);
+
+		for (i = 1; i < adapter->num_rx_pools; i++) {
+			u32 vmolr;
+			int pool = VMDQ_P(i);
+
+			/* accept untagged packets until a vlan tag is
+			 * specifically set for the VMDQ queue/pool
+			 */
+			vmolr = IXGBE_READ_REG(hw, IXGBE_VMOLR(pool));
+			vmolr |= IXGBE_VMOLR_AUPE;
+			IXGBE_WRITE_REG(hw, IXGBE_VMOLR(pool), vmolr);
+		}
+
+		vf_shift = VMDQ_P(0) % 32;
+		reg_offset = (VMDQ_P(0) >= 32) ? 1 : 0;
+
+		/* Enable only the PF pools for Tx/Rx */
+		IXGBE_WRITE_REG(hw, IXGBE_VFRE(reg_offset), (~0) << vf_shift);
+		IXGBE_WRITE_REG(hw, IXGBE_VFRE(reg_offset ^ 1), reg_offset - 1);
+		IXGBE_WRITE_REG(hw, IXGBE_VFTE(reg_offset), (~0) << vf_shift);
+		IXGBE_WRITE_REG(hw, IXGBE_VFTE(reg_offset ^ 1), reg_offset - 1);
+
+		/* clear VLAN promisc flag so VFTA
+		 * will be updated if necessary
+		 */
+		adapter->flags2 &= ~IXGBE_FLAG2_VLAN_PROMISC;
+		break;
+	default:
+		break;
+	}
 
-	/* Map PF MAC address in RAR Entry 0 to first pool following VFs */
-	hw->mac.ops.set_vmdq(hw, 0, VMDQ_P(0));
+	if (!(adapter->flags & IXGBE_FLAG_SRIOV_ENABLED))
+		return;
 
 	/*
 	 * Set up VF register offsets for selected VT Mode,
@@ -3723,39 +4143,21 @@ static void ixgbe_configure_virtualization(struct ixgbe_adapter *adapter)
 
 	IXGBE_WRITE_REG(hw, IXGBE_GCR_EXT, gcr_ext);
 
-
-	/* Enable MAC Anti-Spoofing */
-	hw->mac.ops.set_mac_anti_spoofing(hw, (adapter->num_vfs != 0),
-					  adapter->num_vfs);
-
-	/* Ensure LLDP and FC is set for Ethertype Antispoofing if we will be
-	 * calling set_ethertype_anti_spoofing for each VF in loop below
-	 */
-	if (hw->mac.ops.set_ethertype_anti_spoofing) {
-		IXGBE_WRITE_REG(hw, IXGBE_ETQF(IXGBE_ETQF_FILTER_LLDP),
-				(IXGBE_ETQF_FILTER_EN    |
-				 IXGBE_ETQF_TX_ANTISPOOF |
-				 IXGBE_ETH_P_LLDP));
-
-		IXGBE_WRITE_REG(hw, IXGBE_ETQF(IXGBE_ETQF_FILTER_FC),
-				(IXGBE_ETQF_FILTER_EN |
-				 IXGBE_ETQF_TX_ANTISPOOF |
-				 ETH_P_PAUSE));
-	}
-
-	/* For VFs that have spoof checking turned off */
+	/* configure default bridge settings */
+	ixgbe_configure_bridge_mode(adapter);
+#if IS_ENABLED(CONFIG_PCI_IOV)
 	for (i = 0; i < adapter->num_vfs; i++) {
-		if (!adapter->vfinfo[i].spoofchk_enabled)
-			ixgbe_ndo_set_vf_spoofchk(adapter->netdev, i, false);
-
-		/* enable ethertype anti spoofing if hw supports it */
-		if (hw->mac.ops.set_ethertype_anti_spoofing)
-			hw->mac.ops.set_ethertype_anti_spoofing(hw, true, i);
+		/* configure spoof checking */
+		ixgbe_ndo_set_vf_spoofchk(adapter->netdev, i,
+					  adapter->vfinfo[i].spoofchk_enabled);
 
+#ifdef HAVE_NDO_SET_VF_RSS_QUERY_EN
 		/* Enable/Disable RSS query feature  */
 		ixgbe_ndo_set_vf_rss_query_en(adapter->netdev, i,
-					  adapter->vfinfo[i].rss_query_enabled);
+					adapter->vfinfo[i].rss_query_enabled);
+#endif /* HAVE_NDO_SET_VF_RSS_QUERY_EN */
 	}
+#endif /* CONFIG_PCI_IOV */
 }
 
 static void ixgbe_set_rx_buffer_len(struct ixgbe_adapter *adapter)
@@ -3766,14 +4168,25 @@ static void ixgbe_set_rx_buffer_len(struct ixgbe_adapter *adapter)
 	struct ixgbe_ring *rx_ring;
 	int i;
 	u32 mhadd, hlreg0;
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	int rx_buf_len;
+#endif
+
+	switch (hw->mac.type) {
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		max_frame += IXGBE_TS_HDR_LEN;
+	default:
+		break;
+	}
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* adjust max frame to be able to do baby jumbo for FCoE */
 	if ((adapter->flags & IXGBE_FLAG_FCOE_ENABLED) &&
 	    (max_frame < IXGBE_FCOE_JUMBO_FRAME_SIZE))
 		max_frame = IXGBE_FCOE_JUMBO_FRAME_SIZE;
-
-#endif /* IXGBE_FCOE */
+#endif /* CONFIG_FCOE */
 
 	/* adjust max frame to be at least the size of a standard frame */
 	if (max_frame < (ETH_FRAME_LEN + ETH_FCS_LEN))
@@ -3787,8 +4200,32 @@ static void ixgbe_set_rx_buffer_len(struct ixgbe_adapter *adapter)
 		IXGBE_WRITE_REG(hw, IXGBE_MHADD, mhadd);
 	}
 
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+		/* MHADD will allow an extra 4 bytes past for vlan tagged frames */
+		max_frame += VLAN_HLEN;
+
+	if (!(adapter->flags2 & IXGBE_FLAG2_RSC_ENABLED) &&
+	    (max_frame <= MAXIMUM_ETHERNET_VLAN_SIZE)) {
+		rx_buf_len = MAXIMUM_ETHERNET_VLAN_SIZE;
+	/*
+	 * Make best use of allocation by using all but 1K of a
+	 * power of 2 allocation that will be used for skb->head.
+	 */
+	} else if (max_frame <= IXGBE_RXBUFFER_3K) {
+		rx_buf_len = IXGBE_RXBUFFER_3K;
+	} else if (max_frame <= IXGBE_RXBUFFER_7K) {
+		rx_buf_len = IXGBE_RXBUFFER_7K;
+	} else if (max_frame <= IXGBE_RXBUFFER_15K) {
+		rx_buf_len = IXGBE_RXBUFFER_15K;
+	} else {
+		rx_buf_len = IXGBE_MAX_RXBUFFER;
+	}
+
+#endif /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
 	hlreg0 = IXGBE_READ_REG(hw, IXGBE_HLREG0);
-	/* set jumbo enable since MHADD.MFS is keeping size locked at max_frame */
+	/* set jumbo enable since MHADD.MFS is keeping size locked at
+	 * max_frame
+	 */
 	hlreg0 |= IXGBE_HLREG0_JUMBOEN;
 	IXGBE_WRITE_REG(hw, IXGBE_HLREG0, hlreg0);
 
@@ -3798,10 +4235,48 @@ static void ixgbe_set_rx_buffer_len(struct ixgbe_adapter *adapter)
 	 */
 	for (i = 0; i < adapter->num_rx_queues; i++) {
 		rx_ring = adapter->rx_ring[i];
+
+		clear_ring_rsc_enabled(rx_ring);
 		if (adapter->flags2 & IXGBE_FLAG2_RSC_ENABLED)
 			set_ring_rsc_enabled(rx_ring);
-		else
-			clear_ring_rsc_enabled(rx_ring);
+
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+		clear_bit(__IXGBE_RX_3K_BUFFER, &rx_ring->state);
+		clear_bit(__IXGBE_RX_BUILD_SKB_ENABLED, &rx_ring->state);
+#if IS_ENABLED(CONFIG_FCOE)
+
+		if (test_bit(__IXGBE_RX_FCOE, &rx_ring->state))
+			set_bit(__IXGBE_RX_3K_BUFFER, &rx_ring->state);
+#endif
+#ifdef HAVE_SWIOTLB_SKIP_CPU_SYNC
+
+		if (adapter->flags2 & IXGBE_FLAG2_RX_LEGACY)
+			continue;
+
+		set_bit(__IXGBE_RX_BUILD_SKB_ENABLED, &rx_ring->state);
+
+#if (PAGE_SIZE < 8192)
+		if (adapter->flags2 & IXGBE_FLAG2_RSC_ENABLED)
+			set_bit(__IXGBE_RX_3K_BUFFER, &rx_ring->state);
+
+		if (IXGBE_2K_TOO_SMALL_WITH_PADDING ||
+		    (max_frame > (ETH_FRAME_LEN + ETH_FCS_LEN)))
+			set_bit(__IXGBE_RX_3K_BUFFER, &rx_ring->state);
+#endif
+#else /* !HAVE_SWIOTLB_SKIP_CPU_SYNC */
+
+		adapter->flags2 |= IXGBE_FLAG2_RX_LEGACY;
+#endif /* !HAVE_SWIOTLB_SKIP_CPU_SYNC */
+#else /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
+
+		rx_ring->rx_buf_len = rx_buf_len;
+#if IS_ENABLED(CONFIG_FCOE)
+
+		if (test_bit(__IXGBE_RX_FCOE, &rx_ring->state) &&
+		    (rx_buf_len < IXGBE_FCOE_JUMBO_FRAME_SIZE))
+			rx_ring->rx_buf_len = IXGBE_FCOE_JUMBO_FRAME_SIZE;
+#endif /* CONFIG_FCOE */
+#endif /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
 	}
 }
 
@@ -3811,24 +4286,12 @@ static void ixgbe_setup_rdrxctl(struct ixgbe_adapter *adapter)
 	u32 rdrxctl = IXGBE_READ_REG(hw, IXGBE_RDRXCTL);
 
 	switch (hw->mac.type) {
-	case ixgbe_mac_82598EB:
-		/*
-		 * For VMDq support of different descriptor types or
-		 * buffer sizes through the use of multiple SRRCTL
-		 * registers, RDRXCTL.MVMEN must be set to 1
-		 *
-		 * also, the manual doesn't mention it clearly but DCA hints
-		 * will only use queue 0's tags unless this bit is set.  Side
-		 * effects of setting this bit are only that SRRCTL must be
-		 * fully programmed [0..15]
-		 */
-		rdrxctl |= IXGBE_RDRXCTL_MVMEN;
-		break;
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		if (adapter->num_vfs)
 			rdrxctl |= IXGBE_RDRXCTL_PSP;
-		/* fall through for older HW */
+		/* fall through */
 	case ixgbe_mac_82599EB:
 	case ixgbe_mac_X540:
 		/* Disable RSC for ACK packets */
@@ -3839,6 +4302,19 @@ static void ixgbe_setup_rdrxctl(struct ixgbe_adapter *adapter)
 		rdrxctl |= (IXGBE_RDRXCTL_RSCACKC | IXGBE_RDRXCTL_FCOE_WRFIX);
 		rdrxctl |= IXGBE_RDRXCTL_CRCSTRIP;
 		break;
+	case ixgbe_mac_82598EB:
+		/*
+		 * For VMDq support of different descriptor types or
+		 * buffer sizes through the use of multiple SRRCTL
+		 * registers, RDRXCTL.MVMEN must be set to 1
+		 *
+		 * also, the manual doesn't mention it clearly but DCA hints
+		 * will only use queue 0's tags unless this bit is set.  Side
+		 * effects of setting this bit are only that SRRCTL must be
+		 * fully programmed [0..15]
+		 */
+		rdrxctl |= IXGBE_RDRXCTL_MVMEN;
+		break;
 	default:
 		/* We should do nothing since we don't know this hardware */
 		return;
@@ -3860,7 +4336,7 @@ static void ixgbe_configure_rx(struct ixgbe_adapter *adapter)
 	u32 rxctrl, rfctl;
 
 	/* disable receives while setting up the descriptors */
-	hw->mac.ops.disable_rx(hw);
+	ixgbe_disable_rx(hw);
 
 	ixgbe_setup_psrtype(adapter);
 	ixgbe_setup_rdrxctl(adapter);
@@ -3870,6 +4346,9 @@ static void ixgbe_configure_rx(struct ixgbe_adapter *adapter)
 	rfctl &= ~IXGBE_RFCTL_RSC_DIS;
 	if (!(adapter->flags2 & IXGBE_FLAG2_RSC_ENABLED))
 		rfctl |= IXGBE_RFCTL_RSC_DIS;
+
+	/* disable NFS filtering */
+	rfctl |= (IXGBE_RFCTL_NFSW_DIS | IXGBE_RFCTL_NFSR_DIS);
 	IXGBE_WRITE_REG(hw, IXGBE_RFCTL, rfctl);
 
 	/* Program registers for the distribution of queues */
@@ -3895,57 +4374,202 @@ static void ixgbe_configure_rx(struct ixgbe_adapter *adapter)
 	hw->mac.ops.enable_rx_dma(hw, rxctrl);
 }
 
+#if defined(NETIF_F_HW_VLAN_TX) || defined(NETIF_F_HW_VLAN_CTAG_TX)
+#ifdef HAVE_INT_NDO_VLAN_RX_ADD_VID
+#ifdef NETIF_F_HW_VLAN_CTAG_TX
 static int ixgbe_vlan_rx_add_vid(struct net_device *netdev,
-				 __be16 proto, u16 vid)
+				 __always_unused __be16 proto, u16 vid)
+#else /* !NETIF_F_HW_VLAN_CTAG_TX */
+static int ixgbe_vlan_rx_add_vid(struct net_device *netdev, u16 vid)
+#endif /* NETIF_F_HW_VLAN_CTAG_TX */
+#else /* !HAVE_INT_NDO_VLAN_RX_ADD_VID */
+static void ixgbe_vlan_rx_add_vid(struct net_device *netdev, u16 vid)
+#endif /* HAVE_INT_NDO_VLAN_RX_ADD_VID */
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	struct ixgbe_hw *hw = &adapter->hw;
+	int pool_ndx = VMDQ_P(0);
 
 	/* add VID to filter table */
-	hw->mac.ops.set_vfta(&adapter->hw, vid, VMDQ_P(0), true);
-	set_bit(vid, adapter->active_vlans);
+	if (hw->mac.ops.set_vfta) {
+#ifndef HAVE_VLAN_RX_REGISTER
+		if (vid < VLAN_N_VID)
+			set_bit(vid, adapter->active_vlans);
+#endif
+
+		if (!vid || !(adapter->flags2 & IXGBE_FLAG2_VLAN_PROMISC))
+			hw->mac.ops.set_vfta(hw, vid, pool_ndx, true, !!vid);
+
+		if (adapter->flags & IXGBE_FLAG_VMDQ_ENABLED &&
+		    adapter->hw.mac.type != ixgbe_mac_82598EB) {
+			int i;
+
+			/* enable vlan id for all pools */
+			for (i = 1; i < adapter->num_rx_pools; i++)
+				hw->mac.ops.set_vfta(hw, vid, VMDQ_P(i), true,
+#ifdef HAVE_VLAN_RX_REGISTER
+						     false);
+#else
+						     true);
+#endif
+		}
+	}
+#ifndef HAVE_NETDEV_VLAN_FEATURES
 
+	/*
+	 * Copy feature flags from netdev to the vlan netdev for this vid.
+	 * This allows things like TSO to bubble down to our vlan device.
+	 * Some vlans, such as VLAN 0 for DCB will not have a v_netdev so
+	 * we will not have a netdev that needs updating.
+	 */
+	if (adapter->vlgrp) {
+		struct vlan_group *vlgrp = adapter->vlgrp;
+		struct net_device *v_netdev = vlan_group_get_device(vlgrp, vid);
+		if (v_netdev) {
+			v_netdev->features |= netdev->features;
+			vlan_group_set_device(vlgrp, vid, v_netdev);
+		}
+	}
+#endif /* HAVE_NETDEV_VLAN_FEATURES */
+#ifdef HAVE_INT_NDO_VLAN_RX_ADD_VID
 	return 0;
+#endif
 }
 
-static int ixgbe_vlan_rx_kill_vid(struct net_device *netdev,
-				  __be16 proto, u16 vid)
+#if defined(HAVE_VLAN_RX_REGISTER) && defined(CONFIG_PCI_IOV)
+int ixgbe_find_vlvf_entry(struct ixgbe_hw *hw, u32 vlan)
+#else
+static int ixgbe_find_vlvf_entry(struct ixgbe_hw *hw, u32 vlan)
+#endif
 {
-	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	struct ixgbe_hw *hw = &adapter->hw;
+	u32 vlvf;
+	int idx;
 
-	/* remove VID from filter table */
-	hw->mac.ops.set_vfta(&adapter->hw, vid, VMDQ_P(0), false);
-	clear_bit(vid, adapter->active_vlans);
+	/* short cut the special case */
+	if (vlan == 0)
+		return 0;
 
-	return 0;
+	/* Search for the vlan id in the VLVF entries */
+	for (idx = IXGBE_VLVF_ENTRIES; --idx;) {
+		vlvf = IXGBE_READ_REG(hw, IXGBE_VLVF(idx));
+		if ((vlvf & VLAN_VID_MASK) == vlan)
+			break;
+	}
+
+	return idx;
 }
 
-/**
- * ixgbe_vlan_strip_disable - helper to disable hw vlan stripping
- * @adapter: driver data
- */
-static void ixgbe_vlan_strip_disable(struct ixgbe_adapter *adapter)
+void ixgbe_update_pf_promisc_vlvf(struct ixgbe_adapter *adapter, u32 vid)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
-	u32 vlnctrl;
-	int i, j;
+	u32 bits, word;
+	int idx;
 
-	switch (hw->mac.type) {
-	case ixgbe_mac_82598EB:
-		vlnctrl = IXGBE_READ_REG(hw, IXGBE_VLNCTRL);
-		vlnctrl &= ~IXGBE_VLNCTRL_VME;
-		IXGBE_WRITE_REG(hw, IXGBE_VLNCTRL, vlnctrl);
-		break;
-	case ixgbe_mac_82599EB:
+	idx = ixgbe_find_vlvf_entry(hw, vid);
+	if (!idx)
+		return;
+
+	/* See if any other pools are set for this VLAN filter
+	 * entry other than the PF.
+	 */
+	word = idx * 2 + (VMDQ_P(0) / 32);
+	bits = ~(1 << (VMDQ_P(0)) % 32);
+	bits &= IXGBE_READ_REG(hw, IXGBE_VLVFB(word));
+
+	/* Disable the filter so this falls into the default pool. */
+	if (!bits && !IXGBE_READ_REG(hw, IXGBE_VLVFB(word ^ 1))) {
+		if (!(adapter->flags2 & IXGBE_FLAG2_VLAN_PROMISC))
+			IXGBE_WRITE_REG(hw, IXGBE_VLVFB(word), 0);
+		IXGBE_WRITE_REG(hw, IXGBE_VLVF(idx), 0);
+	}
+}
+
+#ifdef HAVE_INT_NDO_VLAN_RX_ADD_VID
+#ifdef NETIF_F_HW_VLAN_CTAG_RX
+static int ixgbe_vlan_rx_kill_vid(struct net_device *netdev,
+				  __always_unused __be16 proto, u16 vid)
+#else /* !NETIF_F_HW_VLAN_CTAG_RX */
+static int ixgbe_vlan_rx_kill_vid(struct net_device *netdev, u16 vid)
+#endif /* NETIF_F_HW_VLAN_CTAG_RX */
+#else
+static void ixgbe_vlan_rx_kill_vid(struct net_device *netdev, u16 vid)
+#endif
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	struct ixgbe_hw *hw = &adapter->hw;
+	int pool_ndx = VMDQ_P(0);
+
+	/* User is not allowed to remove vlan ID 0 */
+	if (!vid)
+#ifdef HAVE_INT_NDO_VLAN_RX_ADD_VID
+		return 0;
+#else
+		return;
+#endif
+
+#ifdef HAVE_VLAN_RX_REGISTER
+	if (!test_bit(__IXGBE_DOWN, &adapter->state))
+		ixgbe_irq_disable(adapter);
+
+	vlan_group_set_device(adapter->vlgrp, vid, NULL);
+
+	if (!test_bit(__IXGBE_DOWN, &adapter->state))
+		ixgbe_irq_enable(adapter, true, true);
+
+#endif /* HAVE_VLAN_RX_REGISTER */
+	/* remove VID from filter table */
+	if (hw->mac.ops.set_vfta) {
+		if (vid && !(adapter->flags2 & IXGBE_FLAG2_VLAN_PROMISC))
+			hw->mac.ops.set_vfta(hw, vid, pool_ndx, false, true);
+
+		if (adapter->flags & IXGBE_FLAG_VMDQ_ENABLED &&
+		    adapter->hw.mac.type != ixgbe_mac_82598EB) {
+			int i;
+
+			/* remove vlan id from all pools */
+			for (i = 1; i < adapter->num_rx_pools; i++)
+				hw->mac.ops.set_vfta(hw, vid, VMDQ_P(i), false,
+						     true);
+		}
+	}
+#ifndef HAVE_VLAN_RX_REGISTER
+
+	clear_bit(vid, adapter->active_vlans);
+#endif
+#ifdef HAVE_INT_NDO_VLAN_RX_ADD_VID
+	return 0;
+#endif
+}
+
+#ifdef HAVE_8021P_SUPPORT
+/**
+ * ixgbe_vlan_strip_disable - helper to disable vlan tag stripping
+ * @adapter: driver data
+ */
+void ixgbe_vlan_strip_disable(struct ixgbe_adapter *adapter)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	u32 vlnctrl;
+	int i, j;
+
+	/* leave vlan tag stripping enabled for DCB */
+	if (adapter->flags & IXGBE_FLAG_DCB_ENABLED)
+		return;
+
+	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		vlnctrl = IXGBE_READ_REG(hw, IXGBE_VLNCTRL);
+		vlnctrl &= ~IXGBE_VLNCTRL_VME;
+		IXGBE_WRITE_REG(hw, IXGBE_VLNCTRL, vlnctrl);
+		break;
+	case ixgbe_mac_82599EB:
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		for (i = 0; i < adapter->num_rx_queues; i++) {
 			struct ixgbe_ring *ring = adapter->rx_ring[i];
 
-			if (ring->l2_accel_priv)
-				continue;
 			j = ring->reg_idx;
 			vlnctrl = IXGBE_READ_REG(hw, IXGBE_RXDCTL(j));
 			vlnctrl &= ~IXGBE_RXDCTL_VME;
@@ -3957,11 +4581,12 @@ static void ixgbe_vlan_strip_disable(struct ixgbe_adapter *adapter)
 	}
 }
 
+#endif /* HAVE_8021P_SUPPORT */
 /**
- * ixgbe_vlan_strip_enable - helper to enable hw vlan stripping
+ * ixgbe_vlan_strip_enable - helper to enable vlan tag stripping
  * @adapter: driver data
  */
-static void ixgbe_vlan_strip_enable(struct ixgbe_adapter *adapter)
+void ixgbe_vlan_strip_enable(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	u32 vlnctrl;
@@ -3977,11 +4602,10 @@ static void ixgbe_vlan_strip_enable(struct ixgbe_adapter *adapter)
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		for (i = 0; i < adapter->num_rx_queues; i++) {
 			struct ixgbe_ring *ring = adapter->rx_ring[i];
 
-			if (ring->l2_accel_priv)
-				continue;
 			j = ring->reg_idx;
 			vlnctrl = IXGBE_READ_REG(hw, IXGBE_RXDCTL(j));
 			vlnctrl |= IXGBE_RXDCTL_VME;
@@ -3993,14 +4617,249 @@ static void ixgbe_vlan_strip_enable(struct ixgbe_adapter *adapter)
 	}
 }
 
+#ifndef HAVE_VLAN_RX_REGISTER
+static void ixgbe_vlan_promisc_enable(struct ixgbe_adapter *adapter)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	u32 vlnctrl, i;
+
+	vlnctrl = IXGBE_READ_REG(hw, IXGBE_VLNCTRL);
+
+	if (adapter->flags & IXGBE_FLAG_VMDQ_ENABLED) {
+	/* we need to keep the VLAN filter on in SRIOV */
+		vlnctrl |= IXGBE_VLNCTRL_VFE;
+		IXGBE_WRITE_REG(hw, IXGBE_VLNCTRL, vlnctrl);
+	} else {
+		vlnctrl &= ~IXGBE_VLNCTRL_VFE;
+		IXGBE_WRITE_REG(hw, IXGBE_VLNCTRL, vlnctrl);
+		return;
+	}
+
+	/* Nothing to do for 82598 */
+	if (hw->mac.type == ixgbe_mac_82598EB)
+		return;
+
+	/* We are already in VLAN promisc, nothing to do */
+	if (adapter->flags2 & IXGBE_FLAG2_VLAN_PROMISC)
+		return;
+
+	/* Set flag so we don't redo unnecessary work */
+	adapter->flags2 |= IXGBE_FLAG2_VLAN_PROMISC;
+
+	/* Add PF to all active pools */
+	for (i = IXGBE_VLVF_ENTRIES; --i;) {
+		u32 reg_offset = IXGBE_VLVFB(i * 2 + VMDQ_P(0) / 32);
+		u32 vlvfb = IXGBE_READ_REG(hw, reg_offset);
+
+		vlvfb |= 1 << (VMDQ_P(0) % 32);
+		IXGBE_WRITE_REG(hw, reg_offset, vlvfb);
+	}
+
+	/* Set all bits in the VLAN filter table array */
+	for (i = hw->mac.vft_size; i--;)
+		IXGBE_WRITE_REG(hw, IXGBE_VFTA(i), ~0U);
+}
+
+#define VFTA_BLOCK_SIZE 8
+static void ixgbe_scrub_vfta(struct ixgbe_adapter *adapter, u32 vfta_offset)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	u32 vfta[VFTA_BLOCK_SIZE] = { 0 };
+	u32 vid_start = vfta_offset * 32;
+	u32 vid_end = vid_start + (VFTA_BLOCK_SIZE * 32);
+	u32 i, vid, word, bits;
+
+	for (i = IXGBE_VLVF_ENTRIES; --i;) {
+		u32 vlvf = IXGBE_READ_REG(hw, IXGBE_VLVF(i));
+
+		/* pull VLAN ID from VLVF */
+		vid = vlvf & VLAN_VID_MASK;
+
+		/* only concern outselves with a certain range */
+		if (vid < vid_start || vid >= vid_end)
+			continue;
+
+		if (vlvf) {
+			/* record VLAN ID in VFTA */
+			vfta[(vid - vid_start) / 32] |= 1 << (vid % 32);
+
+			/* if PF is part of this then continue */
+			if (test_bit(vid, adapter->active_vlans))
+				continue;
+		}
+
+		/* remove PF from the pool */
+		word = i * 2 + VMDQ_P(0) / 32;
+		bits = ~(1 << (VMDQ_P(0) % 32));
+		bits &= IXGBE_READ_REG(hw, IXGBE_VLVFB(word));
+		IXGBE_WRITE_REG(hw, IXGBE_VLVFB(word), bits);
+	}
+
+	/* extract values from active_vlans and write back to VFTA */
+	for (i = VFTA_BLOCK_SIZE; i--;) {
+		vid = (vfta_offset + i) * 32;
+		word = vid / BITS_PER_LONG;
+		bits = vid % BITS_PER_LONG;
+
+		vfta[i] |= adapter->active_vlans[word] >> bits;
+
+		IXGBE_WRITE_REG(hw, IXGBE_VFTA(vfta_offset + i), vfta[i]);
+	}
+}
+
+static void ixgbe_vlan_promisc_disable(struct ixgbe_adapter *adapter)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	u32 vlnctrl, i;
+
+	/* configure vlan filtering */
+	vlnctrl = IXGBE_READ_REG(hw, IXGBE_VLNCTRL);
+	vlnctrl |= IXGBE_VLNCTRL_VFE;
+	IXGBE_WRITE_REG(hw, IXGBE_VLNCTRL, vlnctrl);
+
+	if (!(adapter->flags & IXGBE_FLAG_VMDQ_ENABLED) ||
+	    hw->mac.type == ixgbe_mac_82598EB)
+		return;
+
+	/* We are not in VLAN promisc, nothing to do */
+	if (!(adapter->flags2 & IXGBE_FLAG2_VLAN_PROMISC))
+		return;
+
+	/* Set flag so we don't redo unnecessary work */
+	adapter->flags2 &= ~IXGBE_FLAG2_VLAN_PROMISC;
+
+	for (i = 0; i < hw->mac.vft_size; i += VFTA_BLOCK_SIZE)
+		ixgbe_scrub_vfta(adapter, i);
+}
+#endif /* HAVE_VLAN_RX_REGISTER */
+
+#ifdef HAVE_VLAN_RX_REGISTER
+static void ixgbe_vlan_mode(struct net_device *netdev, struct vlan_group *grp)
+#else
+void ixgbe_vlan_mode(struct net_device *netdev, u32 features)
+#endif
+{
+#if defined(HAVE_VLAN_RX_REGISTER) || defined(HAVE_8021P_SUPPORT)
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+#endif
+#ifdef HAVE_8021P_SUPPORT
+	bool enable;
+#endif
+
+#ifdef HAVE_VLAN_RX_REGISTER
+	if (!test_bit(__IXGBE_DOWN, &adapter->state))
+		ixgbe_irq_disable(adapter);
+
+	adapter->vlgrp = grp;
+
+	if (!test_bit(__IXGBE_DOWN, &adapter->state))
+		ixgbe_irq_enable(adapter, true, true);
+#endif
+#ifdef HAVE_8021P_SUPPORT
+#ifdef HAVE_VLAN_RX_REGISTER
+	enable = (grp || (adapter->flags & IXGBE_FLAG_DCB_ENABLED));
+#else
+#ifdef NETIF_F_HW_VLAN_CTAG_RX
+	enable = !!(features & NETIF_F_HW_VLAN_CTAG_RX);
+#else
+	enable = !!(features & NETIF_F_HW_VLAN_RX);
+#endif /* NETIF_F_HW_VLAN_CTAG_RX */
+#endif /* HAVE_VLAN_RX_REGISTER */
+	if (enable)
+		/* enable VLAN tag insert/strip */
+		ixgbe_vlan_strip_enable(adapter);
+	else
+		/* disable VLAN tag insert/strip */
+		ixgbe_vlan_strip_disable(adapter);
+
+#endif /* HAVE_8021P_SUPPORT */
+}
+
 static void ixgbe_restore_vlan(struct ixgbe_adapter *adapter)
 {
-	u16 vid;
+	u16 vid = 1;
+#ifdef HAVE_VLAN_RX_REGISTER
+
+	ixgbe_vlan_mode(adapter->netdev, adapter->vlgrp);
+
+	/*
+	 * add vlan ID 0 and enable vlan tag stripping so we
+	 * always accept priority-tagged traffic
+	 */
+#ifdef NETIF_F_HW_VLAN_CTAG_RX
+	ixgbe_vlan_rx_add_vid(adapter->netdev, htons(ETH_P_8021Q), 0);
+#else
+	ixgbe_vlan_rx_add_vid(adapter->netdev, 0);
+#endif
+#ifndef HAVE_8021P_SUPPORT
+	ixgbe_vlan_strip_enable(adapter);
+#endif
 
+	if (adapter->vlgrp) {
+		for (; vid < VLAN_N_VID; vid++) {
+			if (!vlan_group_get_device(adapter->vlgrp, vid))
+				continue;
+#ifdef NETIF_F_HW_VLAN_CTAG_RX
+			ixgbe_vlan_rx_add_vid(adapter->netdev,
+					      htons(ETH_P_8021Q), vid);
+#else
+			ixgbe_vlan_rx_add_vid(adapter->netdev, vid);
+#endif
+		}
+	}
+#else /* !HAVE_VLAN_RX_REGISTER */
+
+#ifdef NETIF_F_HW_VLAN_CTAG_RX
 	ixgbe_vlan_rx_add_vid(adapter->netdev, htons(ETH_P_8021Q), 0);
+#else
+	ixgbe_vlan_rx_add_vid(adapter->netdev, 0);
+#endif
 
-	for_each_set_bit(vid, adapter->active_vlans, VLAN_N_VID)
+	for_each_set_bit_from(vid, adapter->active_vlans, VLAN_N_VID)
+#ifdef NETIF_F_HW_VLAN_CTAG_RX
 		ixgbe_vlan_rx_add_vid(adapter->netdev, htons(ETH_P_8021Q), vid);
+#else
+		ixgbe_vlan_rx_add_vid(adapter->netdev, vid);
+#endif
+#endif /* HAVE_VLAN_RX_REGISTER */
+}
+
+#endif
+static u8 *ixgbe_addr_list_itr(struct ixgbe_hw __maybe_unused *hw, u8 **mc_addr_ptr, u32 *vmdq)
+{
+#ifdef NETDEV_HW_ADDR_T_MULTICAST
+	struct netdev_hw_addr *mc_ptr;
+#else
+	struct dev_mc_list *mc_ptr;
+#endif
+#ifdef CONFIG_PCI_IOV
+	struct ixgbe_adapter *adapter = hw->back;
+#endif /* CONFIG_PCI_IOV */
+	u8 *addr = *mc_addr_ptr;
+
+	/* VMDQ_P implicitely uses the adapter struct when CONFIG_PCI_IOV is
+	 * defined, so we have to wrap the pointer above correctly to prevent
+	 * a warning.
+	 */
+	*vmdq = VMDQ_P(0);
+
+#ifdef NETDEV_HW_ADDR_T_MULTICAST
+	mc_ptr = container_of(addr, struct netdev_hw_addr, addr[0]);
+	if (mc_ptr->list.next) {
+		struct netdev_hw_addr *ha;
+
+		ha = list_entry(mc_ptr->list.next, struct netdev_hw_addr, list);
+		*mc_addr_ptr = ha->addr;
+	}
+#else
+	mc_ptr = container_of(addr, struct dev_mc_list, dmi_addr[0]);
+	if (mc_ptr->next)
+		*mc_addr_ptr = mc_ptr->next->dmi_addr;
+#endif
+	else
+		*mc_addr_ptr = NULL;
+
+	return addr;
 }
 
 /**
@@ -4012,149 +4871,204 @@ static void ixgbe_restore_vlan(struct ixgbe_adapter *adapter)
  *                0 on no addresses written
  *                X on writing X addresses to MTA
  **/
-static int ixgbe_write_mc_addr_list(struct net_device *netdev)
+int ixgbe_write_mc_addr_list(struct net_device *netdev)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	struct ixgbe_hw *hw = &adapter->hw;
+#ifdef NETDEV_HW_ADDR_T_MULTICAST
+	struct netdev_hw_addr *ha;
+#endif
+	u8  *addr_list = NULL;
+	int addr_count = 0;
+
+	if (!hw->mac.ops.update_mc_addr_list)
+		return -ENOMEM;
 
 	if (!netif_running(netdev))
 		return 0;
 
-	if (hw->mac.ops.update_mc_addr_list)
-		hw->mac.ops.update_mc_addr_list(hw, netdev);
-	else
-		return -ENOMEM;
+
+	if (netdev_mc_empty(netdev)) {
+		hw->mac.ops.update_mc_addr_list(hw, NULL, 0,
+						ixgbe_addr_list_itr, true);
+	} else {
+#ifdef NETDEV_HW_ADDR_T_MULTICAST
+		ha = list_first_entry(&netdev->mc.list,
+				      struct netdev_hw_addr, list);
+		addr_list = ha->addr;
+#else
+		addr_list = netdev->mc_list->dmi_addr;
+#endif
+		addr_count = netdev_mc_count(netdev);
+
+		hw->mac.ops.update_mc_addr_list(hw, addr_list, addr_count,
+						ixgbe_addr_list_itr, true);
+	}
 
 #ifdef CONFIG_PCI_IOV
 	ixgbe_restore_vf_multicasts(adapter);
 #endif
-
-	return netdev_mc_count(netdev);
+	return addr_count;
 }
 
 #ifdef CONFIG_PCI_IOV
 void ixgbe_full_sync_mac_table(struct ixgbe_adapter *adapter)
 {
+	struct ixgbe_mac_addr *mac_table = &adapter->mac_table[0];
 	struct ixgbe_hw *hw = &adapter->hw;
 	int i;
-	for (i = 0; i < hw->mac.num_rar_entries; i++) {
-		if (adapter->mac_table[i].state & IXGBE_MAC_STATE_IN_USE)
-			hw->mac.ops.set_rar(hw, i, adapter->mac_table[i].addr,
-					    adapter->mac_table[i].queue,
+
+	for (i = 0; i < hw->mac.num_rar_entries; i++, mac_table++) {
+		mac_table->state &= ~IXGBE_MAC_STATE_MODIFIED;
+
+		if (mac_table->state & IXGBE_MAC_STATE_IN_USE)
+			hw->mac.ops.set_rar(hw, i,
+					    mac_table->addr,
+					    mac_table->pool,
 					    IXGBE_RAH_AV);
 		else
 			hw->mac.ops.clear_rar(hw, i);
-
-		adapter->mac_table[i].state &= ~(IXGBE_MAC_STATE_MODIFIED);
 	}
 }
 #endif
 
 static void ixgbe_sync_mac_table(struct ixgbe_adapter *adapter)
 {
+	struct ixgbe_mac_addr *mac_table = &adapter->mac_table[0];
 	struct ixgbe_hw *hw = &adapter->hw;
 	int i;
-	for (i = 0; i < hw->mac.num_rar_entries; i++) {
-		if (adapter->mac_table[i].state & IXGBE_MAC_STATE_MODIFIED) {
-			if (adapter->mac_table[i].state &
-			    IXGBE_MAC_STATE_IN_USE)
-				hw->mac.ops.set_rar(hw, i,
-						adapter->mac_table[i].addr,
-						adapter->mac_table[i].queue,
-						IXGBE_RAH_AV);
-			else
-				hw->mac.ops.clear_rar(hw, i);
 
-			adapter->mac_table[i].state &=
-						~(IXGBE_MAC_STATE_MODIFIED);
-		}
-	}
-}
+	for (i = 0; i < hw->mac.num_rar_entries; i++, mac_table++) {
+		if (!(mac_table->state & IXGBE_MAC_STATE_MODIFIED))
+			continue;
 
-static void ixgbe_flush_sw_mac_table(struct ixgbe_adapter *adapter)
-{
-	int i;
-	struct ixgbe_hw *hw = &adapter->hw;
+		mac_table->state &= ~IXGBE_MAC_STATE_MODIFIED;
 
-	for (i = 0; i < hw->mac.num_rar_entries; i++) {
-		adapter->mac_table[i].state |= IXGBE_MAC_STATE_MODIFIED;
-		adapter->mac_table[i].state &= ~IXGBE_MAC_STATE_IN_USE;
-		eth_zero_addr(adapter->mac_table[i].addr);
-		adapter->mac_table[i].queue = 0;
+		if (mac_table->state & IXGBE_MAC_STATE_IN_USE)
+			hw->mac.ops.set_rar(hw, i,
+					    mac_table->addr,
+					    mac_table->pool,
+					    IXGBE_RAH_AV);
+		else
+			hw->mac.ops.clear_rar(hw, i);
 	}
-	ixgbe_sync_mac_table(adapter);
 }
 
-static int ixgbe_available_rars(struct ixgbe_adapter *adapter)
+int ixgbe_available_rars(struct ixgbe_adapter *adapter, u16 pool)
 {
+	struct ixgbe_mac_addr *mac_table = &adapter->mac_table[0];
 	struct ixgbe_hw *hw = &adapter->hw;
 	int i, count = 0;
 
-	for (i = 0; i < hw->mac.num_rar_entries; i++) {
-		if (adapter->mac_table[i].state == 0)
-			count++;
+	for (i = 0; i < hw->mac.num_rar_entries; i++, mac_table++) {
+		/* do not count default RAR as available */
+		if (mac_table->state & IXGBE_MAC_STATE_DEFAULT)
+			continue;
+
+		/* only count unused and addresses that belong to us */
+		if (mac_table->state & IXGBE_MAC_STATE_IN_USE) {
+			if (mac_table->pool != pool)
+				continue;
+		}
+
+		count++;
 	}
+
 	return count;
 }
 
 /* this function destroys the first RAR entry */
-static void ixgbe_mac_set_default_filter(struct ixgbe_adapter *adapter,
-					 u8 *addr)
+static void ixgbe_mac_set_default_filter(struct ixgbe_adapter *adapter)
 {
+	struct ixgbe_mac_addr *mac_table = &adapter->mac_table[0];
 	struct ixgbe_hw *hw = &adapter->hw;
 
-	memcpy(&adapter->mac_table[0].addr, addr, ETH_ALEN);
-	adapter->mac_table[0].queue = VMDQ_P(0);
-	adapter->mac_table[0].state = (IXGBE_MAC_STATE_DEFAULT |
-				       IXGBE_MAC_STATE_IN_USE);
-	hw->mac.ops.set_rar(hw, 0, adapter->mac_table[0].addr,
-			    adapter->mac_table[0].queue,
+	ether_addr_copy(mac_table->addr, hw->mac.addr);
+	mac_table->pool = VMDQ_P(0);
+
+	mac_table->state = IXGBE_MAC_STATE_DEFAULT | IXGBE_MAC_STATE_IN_USE;
+
+	hw->mac.ops.set_rar(hw, 0, mac_table->addr, mac_table->pool,
 			    IXGBE_RAH_AV);
 }
 
-int ixgbe_add_mac_filter(struct ixgbe_adapter *adapter, u8 *addr, u16 queue)
+int ixgbe_add_mac_filter(struct ixgbe_adapter *adapter,
+			 const u8 *addr, u16 pool)
 {
+	struct ixgbe_mac_addr *mac_table = &adapter->mac_table[0];
 	struct ixgbe_hw *hw = &adapter->hw;
 	int i;
 
 	if (is_zero_ether_addr(addr))
 		return -EINVAL;
 
-	for (i = 0; i < hw->mac.num_rar_entries; i++) {
-		if (adapter->mac_table[i].state & IXGBE_MAC_STATE_IN_USE)
+	for (i = 0; i < hw->mac.num_rar_entries; i++, mac_table++) {
+		if (mac_table->state & IXGBE_MAC_STATE_IN_USE) {
 			continue;
-		adapter->mac_table[i].state |= (IXGBE_MAC_STATE_MODIFIED |
-						IXGBE_MAC_STATE_IN_USE);
-		ether_addr_copy(adapter->mac_table[i].addr, addr);
-		adapter->mac_table[i].queue = queue;
+		}
+
+		ether_addr_copy(mac_table->addr, addr);
+		mac_table->pool = pool;
+
+		mac_table->state |= IXGBE_MAC_STATE_MODIFIED |
+				    IXGBE_MAC_STATE_IN_USE;
+
 		ixgbe_sync_mac_table(adapter);
+
 		return i;
 	}
+
 	return -ENOMEM;
 }
 
-int ixgbe_del_mac_filter(struct ixgbe_adapter *adapter, u8 *addr, u16 queue)
+static void ixgbe_flush_sw_mac_table(struct ixgbe_adapter *adapter)
 {
-	/* search table for addr, if found, set to 0 and sync */
+	struct ixgbe_mac_addr *mac_table = &adapter->mac_table[0];
+	struct ixgbe_hw *hw = &adapter->hw;
 	int i;
+
+	for (i = 0; i < hw->mac.num_rar_entries; i++, mac_table++) {
+		mac_table->state |= IXGBE_MAC_STATE_MODIFIED;
+		mac_table->state &= ~IXGBE_MAC_STATE_IN_USE;
+	}
+
+	ixgbe_sync_mac_table(adapter);
+}
+
+int ixgbe_del_mac_filter(struct ixgbe_adapter *adapter,
+			 const u8 *addr, u16 pool)
+{
+	struct ixgbe_mac_addr *mac_table = &adapter->mac_table[0];
 	struct ixgbe_hw *hw = &adapter->hw;
+	int i;
 
 	if (is_zero_ether_addr(addr))
 		return -EINVAL;
 
-	for (i = 0; i < hw->mac.num_rar_entries; i++) {
-		if (ether_addr_equal(addr, adapter->mac_table[i].addr) &&
-		    adapter->mac_table[i].queue == queue) {
-			adapter->mac_table[i].state |= IXGBE_MAC_STATE_MODIFIED;
-			adapter->mac_table[i].state &= ~IXGBE_MAC_STATE_IN_USE;
-			eth_zero_addr(adapter->mac_table[i].addr);
-			adapter->mac_table[i].queue = 0;
-			ixgbe_sync_mac_table(adapter);
-			return 0;
-		}
+	/* search table for addr, if found clear IN USE flag and sync */
+	for (i = 0; i < hw->mac.num_rar_entries; i++, mac_table++) {
+		/* we can only delete an entry if it is in use */
+		if (!(mac_table->state & IXGBE_MAC_STATE_IN_USE))
+			continue;
+		/* we only care about entries that belong to the given pool */
+		if (mac_table->pool != pool)
+			continue;
+		/* we only care about a specific MAC address */
+		if (!ether_addr_equal(addr, mac_table->addr))
+			continue;
+
+		mac_table->state |= IXGBE_MAC_STATE_MODIFIED;
+		mac_table->state &= ~IXGBE_MAC_STATE_IN_USE;
+
+		ixgbe_sync_mac_table(adapter);
+
+		return 0;
 	}
+
 	return -ENOMEM;
 }
+
+#ifdef HAVE_SET_RX_MODE
 /**
  * ixgbe_write_uc_addr_list - write unicast addresses to RAR table
  * @netdev: network interface device structure
@@ -4164,26 +5078,55 @@ int ixgbe_del_mac_filter(struct ixgbe_adapter *adapter, u8 *addr, u16 queue)
  *                0 on no addresses written
  *                X on writing X addresses to the RAR table
  **/
-static int ixgbe_write_uc_addr_list(struct net_device *netdev, int vfn)
+int ixgbe_write_uc_addr_list(struct net_device *netdev, int vfn)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	int count = 0;
 
 	/* return ENOMEM indicating insufficient memory for addresses */
-	if (netdev_uc_count(netdev) > ixgbe_available_rars(adapter))
+	if (netdev_uc_count(netdev) > ixgbe_available_rars(adapter, vfn))
 		return -ENOMEM;
 
 	if (!netdev_uc_empty(netdev)) {
+#ifdef NETDEV_HW_ADDR_T_UNICAST
 		struct netdev_hw_addr *ha;
+#else
+		struct dev_mc_list *ha;
+#endif
 		netdev_for_each_uc_addr(ha, netdev) {
+#ifdef NETDEV_HW_ADDR_T_UNICAST
 			ixgbe_del_mac_filter(adapter, ha->addr, vfn);
 			ixgbe_add_mac_filter(adapter, ha->addr, vfn);
+#else
+			ixgbe_del_mac_filter(adapter, ha->da_addr, vfn);
+			ixgbe_add_mac_filter(adapter, ha->da_addr, vfn);
+#endif
 			count++;
 		}
 	}
 	return count;
 }
 
+static int ixgbe_uc_sync(struct net_device *netdev, const unsigned char *addr)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	int ret;
+
+	ret = ixgbe_add_mac_filter(adapter, addr, VMDQ_P(0));
+
+	return min_t(int, ret, 0);
+}
+
+static int ixgbe_uc_unsync(struct net_device *netdev, const unsigned char *addr)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+
+	ixgbe_del_mac_filter(adapter, addr, VMDQ_P(0));
+
+	return 0;
+}
+
+#endif
 /**
  * ixgbe_set_rx_mode - Unicast, Multicast and Promiscuous mode set
  * @netdev: network interface device structure
@@ -4198,54 +5141,75 @@ void ixgbe_set_rx_mode(struct net_device *netdev)
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	struct ixgbe_hw *hw = &adapter->hw;
 	u32 fctrl, vmolr = IXGBE_VMOLR_BAM | IXGBE_VMOLR_AUPE;
+#if defined(HAVE_VLAN_RX_REGISTER) || defined(ESX55)
 	u32 vlnctrl;
+#endif
+#if defined(NETIF_F_HW_VLAN_CTAG_FILTER) || defined(NETIF_F_HW_VLAN_FILTER)
+	netdev_features_t features = netdev->features;
+#endif
 	int count;
 
 	/* Check for Promiscuous and All Multicast modes */
 	fctrl = IXGBE_READ_REG(hw, IXGBE_FCTRL);
+#if defined(HAVE_VLAN_RX_REGISTER) || defined(ESX55)
 	vlnctrl = IXGBE_READ_REG(hw, IXGBE_VLNCTRL);
+#endif
 
 	/* set all bits that we expect to always be set */
-	fctrl &= ~IXGBE_FCTRL_SBP; /* disable store-bad-packets */
 	fctrl |= IXGBE_FCTRL_BAM;
 	fctrl |= IXGBE_FCTRL_DPF; /* discard pause frames when FC enabled */
 	fctrl |= IXGBE_FCTRL_PMCF;
 
 	/* clear the bits we are changing the status of */
 	fctrl &= ~(IXGBE_FCTRL_UPE | IXGBE_FCTRL_MPE);
-	vlnctrl &= ~(IXGBE_VLNCTRL_VFE | IXGBE_VLNCTRL_CFIEN);
+#if defined(HAVE_VLAN_RX_REGISTER) || defined(ESX55)
+	vlnctrl  &= ~(IXGBE_VLNCTRL_VFE | IXGBE_VLNCTRL_CFIEN);
+#endif
 	if (netdev->flags & IFF_PROMISC) {
 		hw->addr_ctrl.user_set_promisc = true;
 		fctrl |= (IXGBE_FCTRL_UPE | IXGBE_FCTRL_MPE);
 		vmolr |= IXGBE_VMOLR_MPE;
+#ifdef HAVE_VLAN_RX_REGISTER
 		/* Only disable hardware filter vlans in promiscuous mode
 		 * if SR-IOV and VMDQ are disabled - otherwise ensure
 		 * that hardware VLAN filters remain enabled.
 		 */
-		if (adapter->flags & (IXGBE_FLAG_VMDQ_ENABLED |
-				      IXGBE_FLAG_SRIOV_ENABLED))
+		if ((adapter->flags & (IXGBE_FLAG_VMDQ_ENABLED |
+				       IXGBE_FLAG_SRIOV_ENABLED)))
 			vlnctrl |= (IXGBE_VLNCTRL_VFE | IXGBE_VLNCTRL_CFIEN);
+#endif
+#ifdef NETIF_F_HW_VLAN_CTAG_FILTER
+		features &= ~NETIF_F_HW_VLAN_CTAG_FILTER;
+#endif
+#ifdef NETIF_F_HW_VLAN_FILTER
+		features &= ~NETIF_F_HW_VLAN_FILTER;
+#endif
 	} else {
 		if (netdev->flags & IFF_ALLMULTI) {
 			fctrl |= IXGBE_FCTRL_MPE;
 			vmolr |= IXGBE_VMOLR_MPE;
 		}
-		vlnctrl |= IXGBE_VLNCTRL_VFE;
 		hw->addr_ctrl.user_set_promisc = false;
+#if defined(HAVE_VLAN_RX_REGISTER) || defined(ESX55)
+		/* enable hardware vlan filtering */
+		vlnctrl |= IXGBE_VLNCTRL_VFE;
+#endif
 	}
 
+#ifdef HAVE_SET_RX_MODE
 	/*
 	 * Write addresses to available RAR registers, if there is not
 	 * sufficient space to store all the addresses then enable
 	 * unicast promiscuous mode
 	 */
-	count = ixgbe_write_uc_addr_list(netdev, VMDQ_P(0));
-	if (count < 0) {
+	if (__dev_uc_sync(netdev, ixgbe_uc_sync, ixgbe_uc_unsync)) {
 		fctrl |= IXGBE_FCTRL_UPE;
 		vmolr |= IXGBE_VMOLR_ROPE;
 	}
 
-	/* Write addresses to the MTA, if the attempt fails
+#endif
+	/*
+	 * Write addresses to the MTA, if the attempt fails
 	 * then we should just turn on promiscuous mode so
 	 * that we can at least receive multicast traffic
 	 */
@@ -4264,107 +5228,236 @@ void ixgbe_set_rx_mode(struct net_device *netdev)
 		IXGBE_WRITE_REG(hw, IXGBE_VMOLR(VMDQ_P(0)), vmolr);
 	}
 
-	/* This is useful for sniffing bad packets. */
-	if (adapter->netdev->features & NETIF_F_RXALL) {
-		/* UPE and MPE will be handled by normal PROMISC logic
-		 * in e1000e_set_rx_mode */
-		fctrl |= (IXGBE_FCTRL_SBP | /* Receive bad packets */
-			  IXGBE_FCTRL_BAM | /* RX All Bcast Pkts */
-			  IXGBE_FCTRL_PMCF); /* RX All MAC Ctrl Pkts */
-
-		fctrl &= ~(IXGBE_FCTRL_DPF);
-		/* NOTE:  VLAN filtering is disabled by setting PROMISC */
-	}
-
-	IXGBE_WRITE_REG(hw, IXGBE_VLNCTRL, vlnctrl);
 	IXGBE_WRITE_REG(hw, IXGBE_FCTRL, fctrl);
 
-	if (netdev->features & NETIF_F_HW_VLAN_CTAG_RX)
+#ifdef HAVE_8021P_SUPPORT
+#ifdef NETIF_F_HW_VLAN_CTAG_RX
+	if (features & NETIF_F_HW_VLAN_CTAG_RX)
+#else
+	if (features & NETIF_F_HW_VLAN_RX)
+#endif
 		ixgbe_vlan_strip_enable(adapter);
 	else
 		ixgbe_vlan_strip_disable(adapter);
+#endif /* HAVE_8021P_SUPPORT */
+
+#if defined(NETIF_F_HW_VLAN_CTAG_FILTER)
+	if (features & NETIF_F_HW_VLAN_CTAG_FILTER)
+		ixgbe_vlan_promisc_disable(adapter);
+	else
+		ixgbe_vlan_promisc_enable(adapter);
+#elif defined(NETIF_F_HW_VLAN_FILTER) && !defined(HAVE_VLAN_RX_REGISTER)
+	if (features & NETIF_F_HW_VLAN_FILTER)
+		ixgbe_vlan_promisc_disable(adapter);
+	else
+		ixgbe_vlan_promisc_enable(adapter);
+#elif defined(HAVE_VLAN_RX_REGISTER) || defined(ESX55)
+	IXGBE_WRITE_REG(hw, IXGBE_VLNCTRL, vlnctrl);
+#endif /* NETIF_F_HW_VLAN_CTAG_FILTER */
 }
 
 static void ixgbe_napi_enable_all(struct ixgbe_adapter *adapter)
 {
+	struct ixgbe_q_vector *q_vector;
 	int q_idx;
 
 	for (q_idx = 0; q_idx < adapter->num_q_vectors; q_idx++) {
+		q_vector = adapter->q_vector[q_idx];
+#ifdef HAVE_NDO_BUSY_POLL
 		ixgbe_qv_init_lock(adapter->q_vector[q_idx]);
-		napi_enable(&adapter->q_vector[q_idx]->napi);
+#endif
+		napi_enable(&q_vector->napi);
 	}
 }
 
 static void ixgbe_napi_disable_all(struct ixgbe_adapter *adapter)
 {
+	struct ixgbe_q_vector *q_vector;
 	int q_idx;
 
 	for (q_idx = 0; q_idx < adapter->num_q_vectors; q_idx++) {
-		napi_disable(&adapter->q_vector[q_idx]->napi);
-		while (!ixgbe_qv_disable(adapter->q_vector[q_idx])) {
+		q_vector = adapter->q_vector[q_idx];
+		napi_disable(&q_vector->napi);
+#ifdef HAVE_NDO_BUSY_POLL
+		while(!ixgbe_qv_disable(adapter->q_vector[q_idx])) {
 			pr_info("QV %d locked\n", q_idx);
 			usleep_range(1000, 20000);
 		}
+#endif
 	}
 }
 
-static void ixgbe_clear_vxlan_port(struct ixgbe_adapter *adapter)
+#ifdef HAVE_DCBNL_IEEE
+s32 ixgbe_dcb_hw_ets(struct ixgbe_hw *hw, struct ieee_ets *ets, int max_frame)
 {
-	switch (adapter->hw.mac.type) {
-	case ixgbe_mac_X550:
-	case ixgbe_mac_X550EM_x:
-		IXGBE_WRITE_REG(&adapter->hw, IXGBE_VXLANCTRL, 0);
-#ifdef CONFIG_IXGBE_VXLAN
+	__u16 refill[IEEE_8021QAZ_MAX_TCS], max[IEEE_8021QAZ_MAX_TCS];
+	__u8 prio_type[IEEE_8021QAZ_MAX_TCS];
+	int i;
+
+	/* naively give each TC a bwg to map onto CEE hardware */
+	__u8 bwg_id[IEEE_8021QAZ_MAX_TCS] = {0, 1, 2, 3, 4, 5, 6, 7};
+
+	/* Map TSA onto CEE prio type */
+	for (i = 0; i < IEEE_8021QAZ_MAX_TCS; i++) {
+		switch (ets->tc_tsa[i]) {
+		case IEEE_8021QAZ_TSA_STRICT:
+			prio_type[i] = 2;
+			break;
+		case IEEE_8021QAZ_TSA_ETS:
+			prio_type[i] = 0;
+			break;
+		default:
+			/* Hardware only supports priority strict or
+			 * ETS transmission selection algorithms if
+			 * we receive some other value from dcbnl
+			 * throw an error
+			 */
+			return -EINVAL;
+		}
+	}
+
+	ixgbe_dcb_calculate_tc_credits(ets->tc_tx_bw, refill, max, max_frame);
+	return ixgbe_dcb_hw_config(hw, refill, max,
+				   bwg_id, prio_type, ets->prio_tc);
+}
+#endif /* HAVE_DCBNL_IEEE */
+
+#if defined(HAVE_UDP_ENC_RX_OFFLOAD) || defined(HAVE_VXLAN_RX_OFFLOAD)
+void ixgbe_clear_udp_tunnel_port(struct ixgbe_adapter *adapter, u32 mask)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	u32 vxlanctrl;
+
+	if (!(adapter->flags & (IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE |
+				IXGBE_FLAG_GENEVE_OFFLOAD_CAPABLE)))
+		return;
+
+	vxlanctrl = IXGBE_READ_REG(hw, IXGBE_VXLANCTRL) & ~mask;
+	IXGBE_WRITE_REG(hw, IXGBE_VXLANCTRL, vxlanctrl);
+
+	if (mask & IXGBE_VXLANCTRL_VXLAN_UDPPORT_MASK)
 		adapter->vxlan_port = 0;
+#ifdef HAVE_UDP_ENC_RX_OFFLOAD
+	if (mask & IXGBE_VXLANCTRL_GENEVE_UDPPORT_MASK)
+		adapter->geneve_port = 0;
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD */
+}
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD || HAVE_VXLAN_RX_OFFLOAD */
+
+#ifdef NETIF_F_GSO_PARTIAL
+/* NETIF_F_GSO_IPXIP4/6 may not be defined in all distributions */
+#ifndef NETIF_F_GSO_IPXIP4
+#define NETIF_F_GSO_IPXIP4 0
 #endif
-		break;
-	default:
-		break;
-	}
+#ifndef NETIF_F_GSO_IPXIP6
+#define NETIF_F_GSO_IPXIP6 0
+#endif
+#define IXGBE_GSO_PARTIAL_FEATURES (NETIF_F_GSO_GRE | \
+				    NETIF_F_GSO_GRE_CSUM | \
+				    NETIF_F_GSO_IPXIP4 | \
+				    NETIF_F_GSO_IPXIP6 | \
+				    NETIF_F_GSO_UDP_TUNNEL | \
+				    NETIF_F_GSO_UDP_TUNNEL_CSUM)
+#endif /* NETIF_F_GSO_PARTIAL */
+
+static inline unsigned long ixgbe_tso_features(void)
+{
+	unsigned long features = 0;
+
+#ifdef NETIF_F_TSO
+	features |= NETIF_F_TSO;
+#endif /* NETIF_F_TSO */
+#ifdef NETIF_F_TSO6
+	features |= NETIF_F_TSO6;
+#endif /* NETIF_F_TSO6 */
+#ifdef NETIF_F_GSO_PARTIAL
+	features |= NETIF_F_GSO_PARTIAL | IXGBE_GSO_PARTIAL_FEATURES;
+#endif
+
+	return features;
 }
 
-#ifdef CONFIG_IXGBE_DCB
-/**
- * ixgbe_configure_dcb - Configure DCB hardware
+/*
+ * ixgbe_configure_dcb - Configure DCB hardware support
  * @adapter: ixgbe adapter struct
  *
- * This is called by the driver on open to configure the DCB hardware.
- * This is also called by the gennetlink interface when reconfiguring
- * the DCB state.
+ * Called when the driver opens or needs to reconfigure DCB related bits.
  */
 static void ixgbe_configure_dcb(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
-	int max_frame = adapter->netdev->mtu + ETH_HLEN + ETH_FCS_LEN;
+	struct net_device *netdev = adapter->netdev;
+
+	int max_frame = netdev->mtu + ETH_HLEN + ETH_FCS_LEN;
 
+	/* The following workaround for 82598EB was originaly hidden inside a
+	 * kcompat definition of netif_set_gso_max_size. This workaround is
+	 * necessary as the 82598EB hardware does not support TSO and DCB
+	 * unless the stack TSO maximum segment size can be reduced. Older
+	 * kernels do not support the requisite interface, and thus need TSO
+	 * disabled if we want to support DCB.
+	 */
 	if (!(adapter->flags & IXGBE_FLAG_DCB_ENABLED)) {
-		if (hw->mac.type == ixgbe_mac_82598EB)
-			netif_set_gso_max_size(adapter->netdev, 65536);
+		if (hw->mac.type == ixgbe_mac_82598EB) {
+#ifdef NETDEV_CAN_SET_GSO_MAX_SIZE
+			netif_set_gso_max_size(netdev, 65536);
+#else
+			/* We previously disabled TSO, so we should enable it
+			 * now. */
+			netdev->features |= ixgbe_tso_features();
+#ifdef NETIF_F_GSO_PARTIAL
+			netdev->gso_partial_features =
+						     IXGBE_GSO_PARTIAL_FEATURES;
+#endif
+#endif /* NETDEV_CAN_SET_GSO_MAX_SIZE */
+		}
 		return;
 	}
 
-	if (hw->mac.type == ixgbe_mac_82598EB)
-		netif_set_gso_max_size(adapter->netdev, 32768);
-
-#ifdef IXGBE_FCOE
-	if (adapter->netdev->features & NETIF_F_FCOE_MTU)
-		max_frame = max(max_frame, IXGBE_FCOE_JUMBO_FRAME_SIZE);
+	if (hw->mac.type == ixgbe_mac_82598EB) {
+#ifdef NETDEV_CAN_SET_GSO_MAX_SIZE
+		netif_set_gso_max_size(netdev, 32768);
+#else
+		/* Simply disable TSO since we cannot change the maximum
+		 * segment size. */
+		netdev->features &= ~ixgbe_tso_features();
+#ifdef NETIF_F_GSO_PARTIAL
+		netdev->gso_partial_features = 0;
 #endif
+#endif /* NETDEV_CAN_SET_GSO_MAX_SIZE */
+	}
+
+#if IS_ENABLED(CONFIG_FCOE)
+	if (netdev->features & NETIF_F_FCOE_MTU)
+		max_frame = max_t(int, max_frame,
+				  IXGBE_FCOE_JUMBO_FRAME_SIZE);
+#endif /* CONFIG_FCOE */
 
-	/* reconfigure the hardware */
-	if (adapter->dcbx_cap & DCB_CAP_DCBX_VER_CEE) {
-		ixgbe_dcb_calculate_tc_credits(hw, &adapter->dcb_cfg, max_frame,
-						DCB_TX_CONFIG);
-		ixgbe_dcb_calculate_tc_credits(hw, &adapter->dcb_cfg, max_frame,
-						DCB_RX_CONFIG);
-		ixgbe_dcb_hw_config(hw, &adapter->dcb_cfg);
-	} else if (adapter->ixgbe_ieee_ets && adapter->ixgbe_ieee_pfc) {
-		ixgbe_dcb_hw_ets(&adapter->hw,
-				 adapter->ixgbe_ieee_ets,
-				 max_frame);
-		ixgbe_dcb_hw_pfc_config(&adapter->hw,
-					adapter->ixgbe_ieee_pfc->pfc_en,
-					adapter->ixgbe_ieee_ets->prio_tc);
+#ifdef HAVE_DCBNL_IEEE
+	if (adapter->dcbx_cap & DCB_CAP_DCBX_VER_IEEE) {
+		if (adapter->ixgbe_ieee_ets)
+			ixgbe_dcb_hw_ets(&adapter->hw,
+					 adapter->ixgbe_ieee_ets,
+					 max_frame);
+
+		if (adapter->ixgbe_ieee_pfc && adapter->ixgbe_ieee_ets) {
+			struct ieee_pfc *pfc = adapter->ixgbe_ieee_pfc;
+			u8 *tc = adapter->ixgbe_ieee_ets->prio_tc;
+
+			ixgbe_dcb_config_pfc(&adapter->hw, pfc->pfc_en, tc);
+		}
+	} else
+#endif /* HAVE_DCBNL_IEEE */
+	{
+		ixgbe_dcb_calculate_tc_credits_cee(hw,
+						   &adapter->dcb_cfg,
+						   max_frame,
+						   IXGBE_DCB_TX_CONFIG);
+		ixgbe_dcb_calculate_tc_credits_cee(hw,
+						   &adapter->dcb_cfg,
+						   max_frame,
+						   IXGBE_DCB_RX_CONFIG);
+		ixgbe_dcb_hw_config_cee(hw, &adapter->dcb_cfg);
 	}
 
 	/* Enable RSS Hash per TC */
@@ -4381,16 +5474,149 @@ static void ixgbe_configure_dcb(struct ixgbe_adapter *adapter)
 		IXGBE_WRITE_REG(hw, IXGBE_RQTC, msb * 0x11111111);
 	}
 }
-#endif
 
+#ifndef IXGBE_NO_LLI
+static void ixgbe_configure_lli_82599(struct ixgbe_adapter *adapter)
+{
+	u16 port;
+
+	if (adapter->lli_etype) {
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_L34T_IMIR(0),
+				(IXGBE_IMIR_LLI_EN_82599 |
+				 IXGBE_IMIR_SIZE_BP_82599 |
+				 IXGBE_IMIR_CTRL_BP_82599));
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_ETQS(0), IXGBE_ETQS_LLI);
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_ETQF(0),
+				(adapter->lli_etype | IXGBE_ETQF_FILTER_EN));
+	}
+
+	if (adapter->lli_port) {
+		port = swab16(adapter->lli_port);
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_L34T_IMIR(0),
+				(IXGBE_IMIR_LLI_EN_82599 |
+				 IXGBE_IMIR_SIZE_BP_82599 |
+				 IXGBE_IMIR_CTRL_BP_82599));
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_FTQF(0),
+				(IXGBE_FTQF_POOL_MASK_EN |
+				 (IXGBE_FTQF_PRIORITY_MASK <<
+				  IXGBE_FTQF_PRIORITY_SHIFT) |
+				 (IXGBE_FTQF_DEST_PORT_MASK <<
+				  IXGBE_FTQF_5TUPLE_MASK_SHIFT)));
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_SDPQF(0), (port << 16));
+	}
+
+	if (adapter->flags & IXGBE_FLAG_LLI_PUSH) {
+		switch (adapter->hw.mac.type) {
+		case ixgbe_mac_82599EB:
+			IXGBE_WRITE_REG(&adapter->hw, IXGBE_L34T_IMIR(0),
+					(IXGBE_IMIR_LLI_EN_82599 |
+					 IXGBE_IMIR_SIZE_BP_82599 |
+					 IXGBE_IMIR_CTRL_PSH_82599 |
+					 IXGBE_IMIR_CTRL_SYN_82599 |
+					 IXGBE_IMIR_CTRL_URG_82599 |
+					 IXGBE_IMIR_CTRL_ACK_82599 |
+					 IXGBE_IMIR_CTRL_RST_82599 |
+					 IXGBE_IMIR_CTRL_FIN_82599));
+			IXGBE_WRITE_REG(&adapter->hw, IXGBE_LLITHRESH,
+					0xfc000000);
+			break;
+		case ixgbe_mac_X540:
+			IXGBE_WRITE_REG(&adapter->hw, IXGBE_L34T_IMIR(0),
+					(IXGBE_IMIR_LLI_EN_82599 |
+					 IXGBE_IMIR_SIZE_BP_82599 |
+					 IXGBE_IMIR_CTRL_PSH_82599));
+			break;
+		default:
+			break;
+		}
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_FTQF(0),
+				(IXGBE_FTQF_POOL_MASK_EN |
+				 (IXGBE_FTQF_PRIORITY_MASK <<
+				  IXGBE_FTQF_PRIORITY_SHIFT) |
+				 (IXGBE_FTQF_5TUPLE_MASK_MASK <<
+				  IXGBE_FTQF_5TUPLE_MASK_SHIFT)));
+
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_SYNQF, 0x80000100);
+	}
+
+	if (adapter->lli_size) {
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_L34T_IMIR(0),
+				(IXGBE_IMIR_LLI_EN_82599 |
+				 IXGBE_IMIR_CTRL_BP_82599));
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_LLITHRESH,
+				adapter->lli_size);
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_FTQF(0),
+				(IXGBE_FTQF_POOL_MASK_EN |
+				 (IXGBE_FTQF_PRIORITY_MASK <<
+				  IXGBE_FTQF_PRIORITY_SHIFT) |
+				 (IXGBE_FTQF_5TUPLE_MASK_MASK <<
+				  IXGBE_FTQF_5TUPLE_MASK_SHIFT)));
+	}
+
+	if (adapter->lli_vlan_pri) {
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_IMIRVP,
+				(IXGBE_IMIRVP_PRIORITY_EN |
+				 adapter->lli_vlan_pri));
+	}
+}
+
+static void ixgbe_configure_lli(struct ixgbe_adapter *adapter)
+{
+	u16 port;
+
+	/* lli should only be enabled with MSI-X and MSI */
+	if (!(adapter->flags & IXGBE_FLAG_MSI_ENABLED) &&
+	    !(adapter->flags & IXGBE_FLAG_MSIX_ENABLED))
+		return;
+	/* LLI not supported on X550 and X550EM_x*/
+	if ((adapter->hw.mac.type == ixgbe_mac_X550) ||
+	    (adapter->hw.mac.type == ixgbe_mac_X550EM_x))
+		return;
+	/* LLI not supported on X550EM_a */
+	if (adapter->hw.mac.type == ixgbe_mac_X550EM_a)
+		return;
+	if (adapter->hw.mac.type != ixgbe_mac_82598EB) {
+		ixgbe_configure_lli_82599(adapter);
+		return;
+	}
+
+	if (adapter->lli_port) {
+		/* use filter 0 for port */
+		port = swab16(adapter->lli_port);
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_IMIR(0),
+				(port | IXGBE_IMIR_PORT_IM_EN));
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_IMIREXT(0),
+				(IXGBE_IMIREXT_SIZE_BP |
+				 IXGBE_IMIREXT_CTRL_BP));
+	}
+
+	if (adapter->flags & IXGBE_FLAG_LLI_PUSH) {
+		/* use filter 1 for push flag */
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_IMIR(1),
+				(IXGBE_IMIR_PORT_BP | IXGBE_IMIR_PORT_IM_EN));
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_IMIREXT(1),
+				(IXGBE_IMIREXT_SIZE_BP |
+				 IXGBE_IMIREXT_CTRL_PSH));
+	}
+
+	if (adapter->lli_size) {
+		/* use filter 2 for size */
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_IMIR(2),
+				(IXGBE_IMIR_PORT_BP | IXGBE_IMIR_PORT_IM_EN));
+		IXGBE_WRITE_REG(&adapter->hw, IXGBE_IMIREXT(2),
+				(adapter->lli_size | IXGBE_IMIREXT_CTRL_BP));
+	}
+}
+
+#endif /* IXGBE_NO_LLI */
 /* Additional bittime to account for IXGBE framing */
 #define IXGBE_ETH_FRAMING 20
 
-/**
+/*
  * ixgbe_hpbthresh - calculate high water mark for flow control
  *
  * @adapter: board private structure to calculate for
- * @pb: packet buffer to calculate
+ * @pb - packet buffer to calculate
  */
 static int ixgbe_hpbthresh(struct ixgbe_adapter *adapter, int pb)
 {
@@ -4402,19 +5628,20 @@ static int ixgbe_hpbthresh(struct ixgbe_adapter *adapter, int pb)
 	/* Calculate max LAN frame size */
 	tc = link = dev->mtu + ETH_HLEN + ETH_FCS_LEN + IXGBE_ETH_FRAMING;
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* FCoE traffic class uses FCOE jumbo frames */
 	if ((dev->features & NETIF_F_FCOE_MTU) &&
 	    (tc < IXGBE_FCOE_JUMBO_FRAME_SIZE) &&
-	    (pb == ixgbe_fcoe_get_tc(adapter)))
+	    (pb == netdev_get_prio_tc_map(dev, adapter->fcoe.up)))
 		tc = IXGBE_FCOE_JUMBO_FRAME_SIZE;
-#endif
+#endif /* CONFIG_FCOE */
 
 	/* Calculate delay value for device */
 	switch (hw->mac.type) {
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		dv_id = IXGBE_DV_X540(link, tc);
 		break;
 	default:
@@ -4438,7 +5665,7 @@ static int ixgbe_hpbthresh(struct ixgbe_adapter *adapter, int pb)
 	 */
 	if (marker < 0) {
 		e_warn(drv, "Packet Buffer(%i) can not provide enough"
-			    "headroom to support flow control."
+			    "headroom to suppport flow control."
 			    "Decrease MTU or number of traffic classes\n", pb);
 		marker = tc + 1;
 	}
@@ -4446,13 +5673,13 @@ static int ixgbe_hpbthresh(struct ixgbe_adapter *adapter, int pb)
 	return marker;
 }
 
-/**
+/*
  * ixgbe_lpbthresh - calculate low water mark for for flow control
  *
  * @adapter: board private structure to calculate for
- * @pb: packet buffer to calculate
+ * @pb - packet buffer to calculate
  */
-static int ixgbe_lpbthresh(struct ixgbe_adapter *adapter, int pb)
+static int ixgbe_lpbthresh(struct ixgbe_adapter *adapter, int __maybe_unused pb)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	struct net_device *dev = adapter->netdev;
@@ -4462,19 +5689,20 @@ static int ixgbe_lpbthresh(struct ixgbe_adapter *adapter, int pb)
 	/* Calculate max LAN frame size */
 	tc = dev->mtu + ETH_HLEN + ETH_FCS_LEN;
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* FCoE traffic class uses FCOE jumbo frames */
 	if ((dev->features & NETIF_F_FCOE_MTU) &&
 	    (tc < IXGBE_FCOE_JUMBO_FRAME_SIZE) &&
 	    (pb == netdev_get_prio_tc_map(dev, adapter->fcoe.up)))
 		tc = IXGBE_FCOE_JUMBO_FRAME_SIZE;
-#endif
+#endif /* CONFIG_FCOE */
 
 	/* Calculate delay value for device */
 	switch (hw->mac.type) {
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		dv_id = IXGBE_LOW_DV_X540(tc);
 		break;
 	default:
@@ -4498,6 +5726,7 @@ static void ixgbe_pbthresh_setup(struct ixgbe_adapter *adapter)
 	if (!num_tc)
 		num_tc = 1;
 
+
 	for (i = 0; i < num_tc; i++) {
 		hw->fc.high_water[i] = ixgbe_hpbthresh(adapter, i);
 		hw->fc.low_water[i] = ixgbe_lpbthresh(adapter, i);
@@ -4507,7 +5736,7 @@ static void ixgbe_pbthresh_setup(struct ixgbe_adapter *adapter)
 			hw->fc.low_water[i] = 0;
 	}
 
-	for (; i < MAX_TRAFFIC_CLASS; i++)
+	for (; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++)
 		hw->fc.high_water[i] = 0;
 }
 
@@ -4523,7 +5752,7 @@ static void ixgbe_configure_pb(struct ixgbe_adapter *adapter)
 	else
 		hdrm = 0;
 
-	hw->mac.ops.set_rxpba(hw, tc, hdrm, PBA_STRATEGY_EQUAL);
+	hw->mac.ops.setup_rxpba(hw, tc, hdrm, PBA_STRATEGY_EQUAL);
 	ixgbe_pbthresh_setup(adapter);
 }
 
@@ -4536,7 +5765,8 @@ static void ixgbe_fdir_filter_restore(struct ixgbe_adapter *adapter)
 	spin_lock(&adapter->fdir_perfect_lock);
 
 	if (!hlist_empty(&adapter->fdir_filter_list))
-		ixgbe_fdir_set_input_mask_82599(hw, &adapter->fdir_mask);
+		ixgbe_fdir_set_input_mask_82599(hw, &adapter->fdir_mask, 
+				adapter->cloud_mode);
 
 	hlist_for_each_entry_safe(filter, node2,
 				  &adapter->fdir_filter_list, fdir_node) {
@@ -4545,219 +5775,91 @@ static void ixgbe_fdir_filter_restore(struct ixgbe_adapter *adapter)
 				filter->sw_idx,
 				(filter->action == IXGBE_FDIR_DROP_QUEUE) ?
 				IXGBE_FDIR_DROP_QUEUE :
-				adapter->rx_ring[filter->action]->reg_idx);
+				adapter->rx_ring[filter->action]->reg_idx,
+				adapter->cloud_mode);
 	}
 
 	spin_unlock(&adapter->fdir_perfect_lock);
 }
 
-static void ixgbe_macvlan_set_rx_mode(struct net_device *dev, unsigned int pool,
-				      struct ixgbe_adapter *adapter)
-{
-	struct ixgbe_hw *hw = &adapter->hw;
-	u32 vmolr;
-
-	/* No unicast promiscuous support for VMDQ devices. */
-	vmolr = IXGBE_READ_REG(hw, IXGBE_VMOLR(pool));
-	vmolr |= (IXGBE_VMOLR_ROMPE | IXGBE_VMOLR_BAM | IXGBE_VMOLR_AUPE);
-
-	/* clear the affected bit */
-	vmolr &= ~IXGBE_VMOLR_MPE;
-
-	if (dev->flags & IFF_ALLMULTI) {
-		vmolr |= IXGBE_VMOLR_MPE;
-	} else {
-		vmolr |= IXGBE_VMOLR_ROMPE;
-		hw->mac.ops.update_mc_addr_list(hw, dev);
-	}
-	ixgbe_write_uc_addr_list(adapter->netdev, pool);
-	IXGBE_WRITE_REG(hw, IXGBE_VMOLR(pool), vmolr);
-}
-
-static void ixgbe_fwd_psrtype(struct ixgbe_fwd_adapter *vadapter)
-{
-	struct ixgbe_adapter *adapter = vadapter->real_adapter;
-	int rss_i = adapter->num_rx_queues_per_pool;
-	struct ixgbe_hw *hw = &adapter->hw;
-	u16 pool = vadapter->pool;
-	u32 psrtype = IXGBE_PSRTYPE_TCPHDR |
-		      IXGBE_PSRTYPE_UDPHDR |
-		      IXGBE_PSRTYPE_IPV4HDR |
-		      IXGBE_PSRTYPE_L2HDR |
-		      IXGBE_PSRTYPE_IPV6HDR;
-
-	if (hw->mac.type == ixgbe_mac_82598EB)
-		return;
-
-	if (rss_i > 3)
-		psrtype |= 2 << 29;
-	else if (rss_i > 1)
-		psrtype |= 1 << 29;
-
-	IXGBE_WRITE_REG(hw, IXGBE_PSRTYPE(VMDQ_P(pool)), psrtype);
-}
-
 /**
  * ixgbe_clean_rx_ring - Free Rx Buffers per Queue
  * @rx_ring: ring to free buffers from
  **/
 static void ixgbe_clean_rx_ring(struct ixgbe_ring *rx_ring)
 {
-	struct device *dev = rx_ring->dev;
-	unsigned long size;
-	u16 i;
-
-	/* ring already cleared, nothing to do */
-	if (!rx_ring->rx_buffer_info)
-		return;
+	u16 i = rx_ring->next_to_clean;
+	struct ixgbe_rx_buffer *rx_buffer = &rx_ring->rx_buffer_info[i];
 
 	/* Free all the Rx ring sk_buffs */
-	for (i = 0; i < rx_ring->count; i++) {
-		struct ixgbe_rx_buffer *rx_buffer = &rx_ring->rx_buffer_info[i];
-
+#ifdef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+	while (i != rx_ring->next_to_use) {
+#else
+	while (i != rx_ring->next_to_alloc) {
+#endif
 		if (rx_buffer->skb) {
 			struct sk_buff *skb = rx_buffer->skb;
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
 			if (IXGBE_CB(skb)->page_released)
-				dma_unmap_page(dev,
-					       IXGBE_CB(skb)->dma,
-					       ixgbe_rx_bufsz(rx_ring),
-					       DMA_FROM_DEVICE);
+				dma_unmap_page_attrs(rx_ring->dev,
+						     IXGBE_CB(skb)->dma,
+						     ixgbe_rx_pg_size(rx_ring),
+						     DMA_FROM_DEVICE,
+						     IXGBE_RX_DMA_ATTR);
+#else
+			/* We need to clean up RSC frag lists */
+			skb = ixgbe_merge_active_tail(skb);
+			if (ixgbe_close_active_frag_list(skb))
+				dma_unmap_single(rx_ring->dev,
+						 IXGBE_CB(skb)->dma,
+						 rx_ring->rx_buf_len,
+						 DMA_FROM_DEVICE);
+			IXGBE_CB(skb)->dma = 0;
+#endif /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
 			dev_kfree_skb(skb);
 			rx_buffer->skb = NULL;
 		}
 
-		if (!rx_buffer->page)
-			continue;
-
-		dma_unmap_page(dev, rx_buffer->dma,
-			       ixgbe_rx_pg_size(rx_ring), DMA_FROM_DEVICE);
-		__free_pages(rx_buffer->page, ixgbe_rx_pg_order(rx_ring));
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+		/* Invalidate cache lines that may have been written to by
+		 * device so that we avoid corrupting memory.
+		 */
+		dma_sync_single_range_for_cpu(rx_ring->dev,
+					      rx_buffer->dma,
+					      rx_buffer->page_offset,
+					      ixgbe_rx_bufsz(rx_ring),
+					      DMA_FROM_DEVICE);
 
-		rx_buffer->page = NULL;
+		/* free resources associated with mapping */
+		dma_unmap_page_attrs(rx_ring->dev, rx_buffer->dma,
+				     ixgbe_rx_pg_size(rx_ring),
+				     DMA_FROM_DEVICE,
+				     IXGBE_RX_DMA_ATTR);
+
+		__page_frag_cache_drain(rx_buffer->page,
+					rx_buffer->pagecnt_bias);
+#else /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
+		if (rx_buffer->dma) {
+			dma_unmap_single(rx_ring->dev,
+					 rx_buffer->dma,
+					 rx_ring->rx_buf_len,
+					 DMA_FROM_DEVICE);
+			rx_buffer->dma = 0;
+		}
+#endif /* CONFIG_IXGBE_DISABLE_PACKET_SPLIT */
+		i++;
+		rx_buffer++;
+		if (i == rx_ring->count) {
+			i = 0;
+			rx_buffer = rx_ring->rx_buffer_info;
+		}
 	}
-
-	size = sizeof(struct ixgbe_rx_buffer) * rx_ring->count;
-	memset(rx_ring->rx_buffer_info, 0, size);
-
-	/* Zero out the descriptor ring */
-	memset(rx_ring->desc, 0, rx_ring->size);
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
 
 	rx_ring->next_to_alloc = 0;
 	rx_ring->next_to_clean = 0;
 	rx_ring->next_to_use = 0;
-}
-
-static void ixgbe_disable_fwd_ring(struct ixgbe_fwd_adapter *vadapter,
-				   struct ixgbe_ring *rx_ring)
-{
-	struct ixgbe_adapter *adapter = vadapter->real_adapter;
-	int index = rx_ring->queue_index + vadapter->rx_base_queue;
-
-	/* shutdown specific queue receive and wait for dma to settle */
-	ixgbe_disable_rx_queue(adapter, rx_ring);
-	usleep_range(10000, 20000);
-	ixgbe_irq_disable_queues(adapter, ((u64)1 << index));
-	ixgbe_clean_rx_ring(rx_ring);
-	rx_ring->l2_accel_priv = NULL;
-}
-
-static int ixgbe_fwd_ring_down(struct net_device *vdev,
-			       struct ixgbe_fwd_adapter *accel)
-{
-	struct ixgbe_adapter *adapter = accel->real_adapter;
-	unsigned int rxbase = accel->rx_base_queue;
-	unsigned int txbase = accel->tx_base_queue;
-	int i;
-
-	netif_tx_stop_all_queues(vdev);
-
-	for (i = 0; i < adapter->num_rx_queues_per_pool; i++) {
-		ixgbe_disable_fwd_ring(accel, adapter->rx_ring[rxbase + i]);
-		adapter->rx_ring[rxbase + i]->netdev = adapter->netdev;
-	}
-
-	for (i = 0; i < adapter->num_rx_queues_per_pool; i++) {
-		adapter->tx_ring[txbase + i]->l2_accel_priv = NULL;
-		adapter->tx_ring[txbase + i]->netdev = adapter->netdev;
-	}
-
-
-	return 0;
-}
-
-static int ixgbe_fwd_ring_up(struct net_device *vdev,
-			     struct ixgbe_fwd_adapter *accel)
-{
-	struct ixgbe_adapter *adapter = accel->real_adapter;
-	unsigned int rxbase, txbase, queues;
-	int i, baseq, err = 0;
-
-	if (!test_bit(accel->pool, &adapter->fwd_bitmask))
-		return 0;
-
-	baseq = accel->pool * adapter->num_rx_queues_per_pool;
-	netdev_dbg(vdev, "pool %i:%i queues %i:%i VSI bitmask %lx\n",
-		   accel->pool, adapter->num_rx_pools,
-		   baseq, baseq + adapter->num_rx_queues_per_pool,
-		   adapter->fwd_bitmask);
-
-	accel->netdev = vdev;
-	accel->rx_base_queue = rxbase = baseq;
-	accel->tx_base_queue = txbase = baseq;
-
-	for (i = 0; i < adapter->num_rx_queues_per_pool; i++)
-		ixgbe_disable_fwd_ring(accel, adapter->rx_ring[rxbase + i]);
-
-	for (i = 0; i < adapter->num_rx_queues_per_pool; i++) {
-		adapter->rx_ring[rxbase + i]->netdev = vdev;
-		adapter->rx_ring[rxbase + i]->l2_accel_priv = accel;
-		ixgbe_configure_rx_ring(adapter, adapter->rx_ring[rxbase + i]);
-	}
-
-	for (i = 0; i < adapter->num_rx_queues_per_pool; i++) {
-		adapter->tx_ring[txbase + i]->netdev = vdev;
-		adapter->tx_ring[txbase + i]->l2_accel_priv = accel;
-	}
-
-	queues = min_t(unsigned int,
-		       adapter->num_rx_queues_per_pool, vdev->num_tx_queues);
-	err = netif_set_real_num_tx_queues(vdev, queues);
-	if (err)
-		goto fwd_queue_err;
-
-	err = netif_set_real_num_rx_queues(vdev, queues);
-	if (err)
-		goto fwd_queue_err;
-
-	if (is_valid_ether_addr(vdev->dev_addr))
-		ixgbe_add_mac_filter(adapter, vdev->dev_addr, accel->pool);
-
-	ixgbe_fwd_psrtype(accel);
-	ixgbe_macvlan_set_rx_mode(vdev, accel->pool, adapter);
-	return err;
-fwd_queue_err:
-	ixgbe_fwd_ring_down(vdev, accel);
-	return err;
-}
-
-static void ixgbe_configure_dfwd(struct ixgbe_adapter *adapter)
-{
-	struct net_device *upper;
-	struct list_head *iter;
-	int err;
-
-	netdev_for_each_all_upper_dev_rcu(adapter->netdev, upper, iter) {
-		if (netif_is_macvlan(upper)) {
-			struct macvlan_dev *dfwd = netdev_priv(upper);
-			struct ixgbe_fwd_adapter *vadapter = dfwd->fwd_priv;
-
-			if (dfwd->fwd_priv) {
-				err = ixgbe_fwd_ring_up(upper, vadapter);
-				if (err)
-					continue;
-			}
-		}
-	}
+#endif
 }
 
 static void ixgbe_configure(struct ixgbe_adapter *adapter)
@@ -4765,9 +5867,8 @@ static void ixgbe_configure(struct ixgbe_adapter *adapter)
 	struct ixgbe_hw *hw = &adapter->hw;
 
 	ixgbe_configure_pb(adapter);
-#ifdef CONFIG_IXGBE_DCB
 	ixgbe_configure_dcb(adapter);
-#endif
+
 	/*
 	 * We must restore virtualization before VLANs or else
 	 * the VLVF registers will not be populated
@@ -4775,49 +5876,73 @@ static void ixgbe_configure(struct ixgbe_adapter *adapter)
 	ixgbe_configure_virtualization(adapter);
 
 	ixgbe_set_rx_mode(adapter->netdev);
+#if defined(NETIF_F_HW_VLAN_TX) || defined(NETIF_F_HW_VLAN_CTAG_TX)
 	ixgbe_restore_vlan(adapter);
+#endif
 
-	switch (hw->mac.type) {
-	case ixgbe_mac_82599EB:
-	case ixgbe_mac_X540:
-		hw->mac.ops.disable_rx_buff(hw);
-		break;
-	default:
-		break;
-	}
+	if (adapter->hw.mac.type == ixgbe_mac_82599EB ||
+	    adapter->hw.mac.type == ixgbe_mac_X540)
+		hw->mac.ops.disable_sec_rx_path(hw);
 
 	if (adapter->flags & IXGBE_FLAG_FDIR_HASH_CAPABLE) {
 		ixgbe_init_fdir_signature_82599(&adapter->hw,
 						adapter->fdir_pballoc);
 	} else if (adapter->flags & IXGBE_FLAG_FDIR_PERFECT_CAPABLE) {
 		ixgbe_init_fdir_perfect_82599(&adapter->hw,
-					      adapter->fdir_pballoc);
+					      adapter->fdir_pballoc, adapter->cloud_mode);
 		ixgbe_fdir_filter_restore(adapter);
 	}
 
-	switch (hw->mac.type) {
-	case ixgbe_mac_82599EB:
-	case ixgbe_mac_X540:
-		hw->mac.ops.enable_rx_buff(hw);
-		break;
-	default:
-		break;
+	if (adapter->hw.mac.type == ixgbe_mac_82599EB ||
+	    adapter->hw.mac.type == ixgbe_mac_X540)
+		hw->mac.ops.enable_sec_rx_path(hw);
+
+	/* Enable EEE only when supported and enabled */
+	if (hw->mac.ops.setup_eee &&
+	    (adapter->flags2 & IXGBE_FLAG2_EEE_CAPABLE)) {
+		bool eee_enable = !!(adapter->flags2 & IXGBE_FLAG2_EEE_ENABLED);
+
+		hw->mac.ops.setup_eee(hw, eee_enable);
 	}
 
-#ifdef CONFIG_IXGBE_DCA
+#if IS_ENABLED(CONFIG_DCA)
 	/* configure DCA */
 	if (adapter->flags & IXGBE_FLAG_DCA_CAPABLE)
 		ixgbe_setup_dca(adapter);
-#endif /* CONFIG_IXGBE_DCA */
+#endif
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* configure FCoE L2 filters, redirection table, and Rx control */
 	ixgbe_configure_fcoe(adapter);
+#endif /* CONFIG_FCOE */
 
-#endif /* IXGBE_FCOE */
 	ixgbe_configure_tx(adapter);
 	ixgbe_configure_rx(adapter);
-	ixgbe_configure_dfwd(adapter);
+}
+
+static bool ixgbe_is_sfp(struct ixgbe_hw *hw)
+{
+	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		if (hw->phy.type == ixgbe_phy_nl)
+			return true;
+		return false;
+	case ixgbe_mac_82599EB:
+		switch (hw->mac.ops.get_media_type(hw)) {
+		case ixgbe_media_type_fiber:
+		case ixgbe_media_type_fiber_qsfp:
+			return true;
+		default:
+			return false;
+		}
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		if (hw->mac.ops.get_media_type(hw) == ixgbe_media_type_fiber)
+			return true;
+		return false;
+	default:
+		return false;
+	}
 }
 
 /**
@@ -4827,7 +5952,7 @@ static void ixgbe_configure(struct ixgbe_adapter *adapter)
 static void ixgbe_sfp_link_config(struct ixgbe_adapter *adapter)
 {
 	/*
-	 * We are assuming the worst case scenario here, and that
+	 * We are assuming the worst case scenerio here, and that
 	 * is that an SFP was inserted/removed after the reset
 	 * but before SFP detection was enabled.  As such the best
 	 * solution is to just start searching as soon as we start
@@ -4849,27 +5974,68 @@ static int ixgbe_non_sfp_link_config(struct ixgbe_hw *hw)
 {
 	u32 speed;
 	bool autoneg, link_up = false;
-	int ret = IXGBE_ERR_LINK_SETUP;
+	u32 ret = IXGBE_ERR_LINK_SETUP;
 
 	if (hw->mac.ops.check_link)
 		ret = hw->mac.ops.check_link(hw, &speed, &link_up, false);
 
 	if (ret)
-		return ret;
+		goto link_cfg_out;
 
 	speed = hw->phy.autoneg_advertised;
 	if ((!speed) && (hw->mac.ops.get_link_capabilities))
 		ret = hw->mac.ops.get_link_capabilities(hw, &speed,
 							&autoneg);
 	if (ret)
-		return ret;
+		goto link_cfg_out;
 
 	if (hw->mac.ops.setup_link)
 		ret = hw->mac.ops.setup_link(hw, speed, link_up);
-
+link_cfg_out:
 	return ret;
 }
 
+/**
+ * ixgbe_clear_vf_stats_counters - Clear out VF stats after reset
+ * @adapter: board private structure
+ *
+ * On a reset we need to clear out the VF stats or accounting gets
+ * messed up because they're not clear on read.
+ **/
+static void ixgbe_clear_vf_stats_counters(struct ixgbe_adapter *adapter)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	int i;
+
+	for (i = 0; i < adapter->num_vfs; i++) {
+		adapter->vfinfo[i].last_vfstats.gprc =
+			IXGBE_READ_REG(hw, IXGBE_PVFGPRC(i));
+		adapter->vfinfo[i].saved_rst_vfstats.gprc +=
+			adapter->vfinfo[i].vfstats.gprc;
+		adapter->vfinfo[i].vfstats.gprc = 0;
+		adapter->vfinfo[i].last_vfstats.gptc =
+			IXGBE_READ_REG(hw, IXGBE_PVFGPTC(i));
+		adapter->vfinfo[i].saved_rst_vfstats.gptc +=
+			adapter->vfinfo[i].vfstats.gptc;
+		adapter->vfinfo[i].vfstats.gptc = 0;
+		adapter->vfinfo[i].last_vfstats.gorc =
+			IXGBE_READ_REG(hw, IXGBE_PVFGORC_LSB(i));
+		adapter->vfinfo[i].saved_rst_vfstats.gorc +=
+			adapter->vfinfo[i].vfstats.gorc;
+		adapter->vfinfo[i].vfstats.gorc = 0;
+		adapter->vfinfo[i].last_vfstats.gotc =
+			IXGBE_READ_REG(hw, IXGBE_PVFGOTC_LSB(i));
+		adapter->vfinfo[i].saved_rst_vfstats.gotc +=
+			adapter->vfinfo[i].vfstats.gotc;
+		adapter->vfinfo[i].vfstats.gotc = 0;
+		adapter->vfinfo[i].last_vfstats.mprc =
+			IXGBE_READ_REG(hw, IXGBE_PVFMPRC(i));
+		adapter->vfinfo[i].saved_rst_vfstats.mprc +=
+			adapter->vfinfo[i].vfstats.mprc;
+		adapter->vfinfo[i].vfstats.mprc = 0;
+	}
+}
+
 static void ixgbe_setup_gpie(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
@@ -4891,6 +6057,7 @@ static void ixgbe_setup_gpie(struct ixgbe_adapter *adapter)
 		case ixgbe_mac_X540:
 		case ixgbe_mac_X550:
 		case ixgbe_mac_X550EM_x:
+		case ixgbe_mac_X550EM_a:
 		default:
 			IXGBE_WRITE_REG(hw, IXGBE_EIAM_EX(0), 0xFFFFFFFF);
 			IXGBE_WRITE_REG(hw, IXGBE_EIAM_EX(1), 0xFFFFFFFF);
@@ -4902,9 +6069,6 @@ static void ixgbe_setup_gpie(struct ixgbe_adapter *adapter)
 		IXGBE_WRITE_REG(hw, IXGBE_EIAM, IXGBE_EICS_RTX_QUEUE);
 	}
 
-	/* XXX: to interrupt immediately for EICS writes, enable this */
-	/* gpie |= IXGBE_GPIE_EIMEN; */
-
 	if (adapter->flags & IXGBE_FLAG_SRIOV_ENABLED) {
 		gpie &= ~IXGBE_GPIE_VTMODE_MASK;
 
@@ -4922,25 +6086,25 @@ static void ixgbe_setup_gpie(struct ixgbe_adapter *adapter)
 	}
 
 	/* Enable Thermal over heat sensor interrupt */
-	if (adapter->flags2 & IXGBE_FLAG2_TEMP_SENSOR_CAPABLE) {
+	if (adapter->flags2 & IXGBE_FLAG2_TEMP_SENSOR_CAPABLE)
 		switch (adapter->hw.mac.type) {
 		case ixgbe_mac_82599EB:
-			gpie |= IXGBE_SDP0_GPIEN_8259X;
+			gpie |= IXGBE_SDP0_GPIEN;
 			break;
 		default:
 			break;
 		}
-	}
 
 	/* Enable fan failure interrupt */
 	if (adapter->flags & IXGBE_FLAG_FAN_FAIL_CAPABLE)
-		gpie |= IXGBE_SDP1_GPIEN(hw);
+		gpie |= IXGBE_SDP1_GPIEN;
 
 	switch (hw->mac.type) {
 	case ixgbe_mac_82599EB:
-		gpie |= IXGBE_SDP1_GPIEN_8259X | IXGBE_SDP2_GPIEN_8259X;
+		gpie |= IXGBE_SDP1_GPIEN | IXGBE_SDP2_GPIEN;
 		break;
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		gpie |= IXGBE_SDP0_GPIEN_X540;
 		break;
 	default:
@@ -4967,17 +6131,18 @@ static void ixgbe_up_complete(struct ixgbe_adapter *adapter)
 	/* enable the optics for 82599 SFP+ fiber */
 	if (hw->mac.ops.enable_tx_laser)
 		hw->mac.ops.enable_tx_laser(hw);
-
-	if (hw->phy.ops.set_phy_power)
-		hw->phy.ops.set_phy_power(hw, true);
+	ixgbe_set_phy_power(hw, true);
 
 	smp_mb__before_atomic();
 	clear_bit(__IXGBE_DOWN, &adapter->state);
 	ixgbe_napi_enable_all(adapter);
+#ifndef IXGBE_NO_LLI
+	ixgbe_configure_lli(adapter);
+#endif
 
 	if (ixgbe_is_sfp(hw)) {
 		ixgbe_sfp_link_config(adapter);
-	} else {
+	} else if (!hw->phy.reset_disable) {
 		err = ixgbe_non_sfp_link_config(hw);
 		if (err)
 			e_err(probe, "link_config FAILED %d\n", err);
@@ -4997,12 +6162,16 @@ static void ixgbe_up_complete(struct ixgbe_adapter *adapter)
 			e_crit(drv, "Fan has stopped, replace the adapter\n");
 	}
 
+	/* enable transmits */
+	netif_tx_start_all_queues(adapter->netdev);
+
 	/* bring the link up in the watchdog, this could race with our first
 	 * link up interrupt but shouldn't be a problem */
 	adapter->flags |= IXGBE_FLAG_NEED_LINK_UPDATE;
 	adapter->link_check_timeout = jiffies;
 	mod_timer(&adapter->service_timer, jiffies);
 
+	ixgbe_clear_vf_stats_counters(adapter);
 	/* Set PF Reset Done bit so PF/VF Mail Ops can work */
 	ctrl_ext = IXGBE_READ_REG(hw, IXGBE_CTRL_EXT);
 	ctrl_ext |= IXGBE_CTRL_EXT_PFRSTD;
@@ -5013,10 +6182,16 @@ void ixgbe_reinit_locked(struct ixgbe_adapter *adapter)
 {
 	WARN_ON(in_interrupt());
 	/* put off any impending NetWatchDogTimeout */
+#ifdef HAVE_NETIF_TRANS_UPDATE
+	netif_trans_update(adapter->netdev);
+#else
 	adapter->netdev->trans_start = jiffies;
+#endif
 
 	while (test_and_set_bit(__IXGBE_RESETTING, &adapter->state))
 		usleep_range(1000, 2000);
+	if (adapter->hw.phy.type == ixgbe_phy_fw)
+		ixgbe_watchdog_link_is_down(adapter);
 	ixgbe_down(adapter);
 	/*
 	 * If SR-IOV enabled then wait a bit before bringing the adapter
@@ -5041,11 +6216,12 @@ void ixgbe_up(struct ixgbe_adapter *adapter)
 void ixgbe_reset(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
+#ifdef HAVE_SET_RX_MODE
 	struct net_device *netdev = adapter->netdev;
+#endif
 	int err;
-	u8 old_addr[ETH_ALEN];
 
-	if (ixgbe_removed(hw->hw_addr))
+	if (IXGBE_REMOVED(hw->hw_addr))
 		return;
 	/* lock SFP init bit to prevent race conditions with the watchdog */
 	while (test_and_set_bit(__IXGBE_IN_SFP_INIT, &adapter->state))
@@ -5058,7 +6234,7 @@ void ixgbe_reset(struct ixgbe_adapter *adapter)
 
 	err = hw->mac.ops.init_hw(hw);
 	switch (err) {
-	case 0:
+	case IXGBE_SUCCESS:
 	case IXGBE_ERR_SFP_NOT_PRESENT:
 	case IXGBE_ERR_SFP_NOT_SUPPORTED:
 		break;
@@ -5068,35 +6244,49 @@ void ixgbe_reset(struct ixgbe_adapter *adapter)
 	case IXGBE_ERR_EEPROM_VERSION:
 		/* We are running on a pre-production device, log a warning */
 		e_dev_warn("This device is a pre-production adapter/LOM. "
-			   "Please be aware there may be issues associated with "
-			   "your hardware.  If you are experiencing problems "
-			   "please contact your Intel or hardware "
+			   "Please be aware there may be issues associated "
+			   "with your hardware.  If you are experiencing "
+			   "problems please contact your Intel or hardware "
 			   "representative who provided you with this "
 			   "hardware.\n");
 		break;
+	case IXGBE_ERR_OVERTEMP:
+		e_crit(drv, "%s\n", ixgbe_overheat_msg);
+		break;
 	default:
 		e_dev_err("Hardware Error: %d\n", err);
 	}
 
 	clear_bit(__IXGBE_IN_SFP_INIT, &adapter->state);
-	/* do not flush user set addresses */
-	memcpy(old_addr, &adapter->mac_table[0].addr, netdev->addr_len);
+
+	/* flush entries out of MAC table */
 	ixgbe_flush_sw_mac_table(adapter);
-	ixgbe_mac_set_default_filter(adapter, old_addr);
+#ifdef HAVE_SET_RX_MODE
+	__dev_uc_unsync(netdev, NULL);
+#endif
+
+	/* do not flush user set addresses */
+	ixgbe_mac_set_default_filter(adapter);
 
 	/* update SAN MAC vmdq pool selection */
 	if (hw->mac.san_mac_rar_index)
 		hw->mac.ops.set_vmdq_san_mac(hw, VMDQ_P(0));
 
+	/* Clear saved DMA coalescing values except for watchdog_timer */
+	hw->mac.dmac_config.fcoe_en = false;
+	hw->mac.dmac_config.link_speed = 0;
+	hw->mac.dmac_config.fcoe_tc = 0;
+	hw->mac.dmac_config.num_tcs = 0;
+
+#ifdef HAVE_PTP_1588_CLOCK
 	if (test_bit(__IXGBE_PTP_RUNNING, &adapter->state))
 		ixgbe_ptp_reset(adapter);
+#endif
 
-	if (hw->phy.ops.set_phy_power) {
-		if (!netif_running(adapter->netdev) && !adapter->wol)
-			hw->phy.ops.set_phy_power(hw, false);
-		else
-			hw->phy.ops.set_phy_power(hw, true);
-	}
+	if (!netif_running(adapter->netdev) && !adapter->wol)
+		ixgbe_set_phy_power(hw, false);
+	else
+		ixgbe_set_phy_power(hw, true);
 }
 
 /**
@@ -5105,28 +6295,57 @@ void ixgbe_reset(struct ixgbe_adapter *adapter)
  **/
 static void ixgbe_clean_tx_ring(struct ixgbe_ring *tx_ring)
 {
-	struct ixgbe_tx_buffer *tx_buffer_info;
-	unsigned long size;
-	u16 i;
+	u16 i = tx_ring->next_to_clean;
+	struct ixgbe_tx_buffer *tx_buffer = &tx_ring->tx_buffer_info[i];
 
-	/* ring already cleared, nothing to do */
-	if (!tx_ring->tx_buffer_info)
-		return;
+	while (i != tx_ring->next_to_use) {
+		union ixgbe_adv_tx_desc *eop_desc, *tx_desc;
 
-	/* Free all the Tx ring sk_buffs */
-	for (i = 0; i < tx_ring->count; i++) {
-		tx_buffer_info = &tx_ring->tx_buffer_info[i];
-		ixgbe_unmap_and_free_tx_resource(tx_ring, tx_buffer_info);
-	}
+		/* Free all the Tx ring sk_buffs */
+		dev_kfree_skb_any(tx_buffer->skb);
 
-	netdev_tx_reset_queue(txring_txq(tx_ring));
+		/* unmap skb header data */
+		dma_unmap_single(tx_ring->dev,
+				 dma_unmap_addr(tx_buffer, dma),
+				 dma_unmap_len(tx_buffer, len),
+				 DMA_TO_DEVICE);
 
-	size = sizeof(struct ixgbe_tx_buffer) * tx_ring->count;
-	memset(tx_ring->tx_buffer_info, 0, size);
+		/* check for eop_desc to determine the end of the packet */
+		eop_desc = tx_buffer->next_to_watch;
+		tx_desc = IXGBE_TX_DESC(tx_ring, i);
+
+		/* unmap remaining buffers */
+		while (tx_desc != eop_desc) {
+			tx_buffer++;
+			tx_desc++;
+			i++;
+			if (unlikely(i == tx_ring->count)) {
+				i = 0;
+				tx_buffer = tx_ring->tx_buffer_info;
+				tx_desc = IXGBE_TX_DESC(tx_ring, 0);
+			}
+
+			/* unmap any remaining paged data */
+			if (dma_unmap_len(tx_buffer, len))
+				dma_unmap_page(tx_ring->dev,
+					       dma_unmap_addr(tx_buffer, dma),
+					       dma_unmap_len(tx_buffer, len),
+					       DMA_TO_DEVICE);
+		}
+
+		/* move us one more past the eop_desc for start of next pkt */
+		tx_buffer++;
+		i++;
+		if (unlikely(i == tx_ring->count)) {
+			i = 0;
+			tx_buffer = tx_ring->tx_buffer_info;
+		}
+	}
 
-	/* Zero out the descriptor ring */
-	memset(tx_ring->desc, 0, tx_ring->size);
+	/* reset BQL for queue */
+	netdev_tx_reset_queue(txring_txq(tx_ring));
 
+	/* reset next_to_use and next_to_clean */
 	tx_ring->next_to_use = 0;
 	tx_ring->next_to_clean = 0;
 }
@@ -5176,8 +6395,6 @@ void ixgbe_down(struct ixgbe_adapter *adapter)
 {
 	struct net_device *netdev = adapter->netdev;
 	struct ixgbe_hw *hw = &adapter->hw;
-	struct net_device *upper;
-	struct list_head *iter;
 	int i;
 
 	/* signal that we are down to the interrupt handler */
@@ -5185,7 +6402,7 @@ void ixgbe_down(struct ixgbe_adapter *adapter)
 		return; /* do nothing if already down */
 
 	/* disable receives */
-	hw->mac.ops.disable_rx(hw);
+	ixgbe_disable_rx(hw);
 
 	/* disable all enabled rx queues */
 	for (i = 0; i < adapter->num_rx_queues; i++)
@@ -5200,25 +6417,12 @@ void ixgbe_down(struct ixgbe_adapter *adapter)
 	netif_carrier_off(netdev);
 	netif_tx_disable(netdev);
 
-	/* disable any upper devices */
-	netdev_for_each_all_upper_dev_rcu(adapter->netdev, upper, iter) {
-		if (netif_is_macvlan(upper)) {
-			struct macvlan_dev *vlan = netdev_priv(upper);
-
-			if (vlan->fwd_priv) {
-				netif_tx_stop_all_queues(upper);
-				netif_carrier_off(upper);
-				netif_tx_disable(upper);
-			}
-		}
-	}
-
 	ixgbe_irq_disable(adapter);
 
 	ixgbe_napi_disable_all(adapter);
 
-	adapter->flags2 &= ~(IXGBE_FLAG2_FDIR_REQUIRES_REINIT |
-			     IXGBE_FLAG2_RESET_REQUESTED);
+	adapter->flags2 &= ~(IXGBE_FLAG2_FDIR_REQUIRES_REINIT);
+	clear_bit(__IXGBE_RESET_REQUESTED, &adapter->state);
 	adapter->flags &= ~IXGBE_FLAG_NEED_LINK_UPDATE;
 
 	del_timer_sync(&adapter->service_timer);
@@ -5229,7 +6433,7 @@ void ixgbe_down(struct ixgbe_adapter *adapter)
 
 		/* Mark all the VFs as inactive */
 		for (i = 0 ; i < adapter->num_vfs; i++)
-			adapter->vfinfo[i].clear_to_send = false;
+			adapter->vfinfo[i].clear_to_send = 0;
 
 		/* ping all the active vfs to let them know we are going down */
 		ixgbe_ping_all_vfs(adapter);
@@ -5244,12 +6448,13 @@ void ixgbe_down(struct ixgbe_adapter *adapter)
 		IXGBE_WRITE_REG(hw, IXGBE_TXDCTL(reg_idx), IXGBE_TXDCTL_SWFLSH);
 	}
 
-	/* Disable the Tx DMA engine on 82599 and later MAC */
+	/* Disable the Tx DMA engine on 82599 and X540 */
 	switch (hw->mac.type) {
 	case ixgbe_mac_82599EB:
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		IXGBE_WRITE_REG(hw, IXGBE_DMATXCTL,
 				(IXGBE_READ_REG(hw, IXGBE_DMATXCTL) &
 				 ~IXGBE_DMATXCTL_TE));
@@ -5258,28 +6463,85 @@ void ixgbe_down(struct ixgbe_adapter *adapter)
 		break;
 	}
 
+#ifdef HAVE_PCI_ERS
 	if (!pci_channel_offline(adapter->pdev))
+#endif
 		ixgbe_reset(adapter);
 
 	/* power down the optics for 82599 SFP+ fiber */
 	if (hw->mac.ops.disable_tx_laser)
 		hw->mac.ops.disable_tx_laser(hw);
 
-	ixgbe_clean_all_tx_rings(adapter);
-	ixgbe_clean_all_rx_rings(adapter);
-}
+	ixgbe_clean_all_tx_rings(adapter);
+	ixgbe_clean_all_rx_rings(adapter);
+}
+
+/**
+ * ixgbe_eee_capable - helper function to determine EEE support on X550
+ *
+ **/
+static inline void ixgbe_set_eee_capable(struct ixgbe_adapter *adapter)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+
+	switch (hw->device_id) {
+	case IXGBE_DEV_ID_X550EM_A_1G_T:
+	case IXGBE_DEV_ID_X550EM_A_1G_T_L:
+		if (!hw->phy.eee_speeds_supported)
+			break;
+		adapter->flags2 |= IXGBE_FLAG2_EEE_CAPABLE;
+		if (!hw->phy.eee_speeds_advertised)
+			break;
+		adapter->flags2 |= IXGBE_FLAG2_EEE_ENABLED;
+		break;
+	default:
+		adapter->flags2 &= ~IXGBE_FLAG2_EEE_CAPABLE;
+		adapter->flags2 &= ~IXGBE_FLAG2_EEE_ENABLED;
+		break;
+	}
+}
+
+#if IS_ENABLED(CONFIG_DCB)
+static void ixgbe_init_dcb(struct ixgbe_adapter *adapter)
+{
+	struct ixgbe_dcb_tc_config *tc;
+	int j, bwg_pct;
+
+	/* Configure DCB traffic classes */
+	bwg_pct = 100 / adapter->dcb_cfg.num_tcs.pg_tcs;
+	for (j = 0; j < adapter->dcb_cfg.num_tcs.pg_tcs; j++) {
+		tc = &adapter->dcb_cfg.tc_config[j];
+		tc->path[IXGBE_DCB_TX_CONFIG].bwg_id = 0;
+		tc->path[IXGBE_DCB_TX_CONFIG].bwg_percent = bwg_pct;
+		tc->path[IXGBE_DCB_RX_CONFIG].bwg_id = 0;
+		tc->path[IXGBE_DCB_RX_CONFIG].bwg_percent = bwg_pct;
+		tc->pfc = ixgbe_dcb_pfc_disabled;
+	}
+
+	/* reset back to TC 0 */
+	tc = &adapter->dcb_cfg.tc_config[0];
 
-/**
- * ixgbe_tx_timeout - Respond to a Tx Hang
- * @netdev: network interface device structure
- **/
-static void ixgbe_tx_timeout(struct net_device *netdev)
-{
-	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	/* total of all TCs bandwidth needs to be 100 */
+	bwg_pct += 100 % adapter->dcb_cfg.num_tcs.pg_tcs;
+	tc->path[IXGBE_DCB_TX_CONFIG].bwg_percent = bwg_pct;
+	tc->path[IXGBE_DCB_RX_CONFIG].bwg_percent = bwg_pct;
 
-	/* Do the reset outside of interrupt context */
-	ixgbe_tx_timeout_reset(adapter);
+	/* Initialize default user to priority mapping, UPx->TC0 */
+	tc->path[IXGBE_DCB_TX_CONFIG].up_to_tc_bitmap = 0xFF;
+	tc->path[IXGBE_DCB_RX_CONFIG].up_to_tc_bitmap = 0xFF;
+
+	adapter->dcb_cfg.bw_percentage[IXGBE_DCB_TX_CONFIG][0] = 100;
+	adapter->dcb_cfg.bw_percentage[IXGBE_DCB_RX_CONFIG][0] = 100;
+	adapter->dcb_cfg.rx_pba_cfg = ixgbe_dcb_pba_equal;
+	adapter->dcb_cfg.pfc_mode_enable = false;
+	adapter->dcb_cfg.round_robin_enable = false;
+	adapter->dcb_set_bitmap = 0x00;
+	if (adapter->flags & IXGBE_FLAG_DCB_CAPABLE)
+		adapter->dcbx_cap = DCB_CAP_DCBX_HOST | DCB_CAP_DCBX_VER_CEE;
+	memcpy(&adapter->temp_dcb_cfg, &adapter->dcb_cfg,
+	       sizeof(adapter->temp_dcb_cfg));
 }
+#endif /*CONFIG_DCB*/
 
 /**
  * ixgbe_sw_init - Initialize general software structures (struct ixgbe_adapter)
@@ -5289,165 +6551,188 @@ static void ixgbe_tx_timeout(struct net_device *netdev)
  * Fields are initialized based on PCI device information and
  * OS network device settings (MTU size).
  **/
-static int ixgbe_sw_init(struct ixgbe_adapter *adapter)
+static int __devinit ixgbe_sw_init(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	struct pci_dev *pdev = adapter->pdev;
-	unsigned int rss, fdir;
+	int err;
+	unsigned int fdir;
 	u32 fwsm;
-#ifdef CONFIG_IXGBE_DCB
-	int j;
-	struct tc_configuration *tc;
-#endif
+	u16 device_caps;
 
 	/* PCI config space info */
 
 	hw->vendor_id = pdev->vendor;
 	hw->device_id = pdev->device;
-	hw->revision_id = pdev->revision;
+	pci_read_config_byte(pdev, PCI_REVISION_ID, &hw->revision_id);
+	if (hw->revision_id == IXGBE_FAILED_READ_CFG_BYTE &&
+	    ixgbe_check_cfg_remove(hw, pdev)) {
+		e_err(probe, "read of revision id failed\n");
+		err = -ENODEV;
+		goto out;
+	}
 	hw->subsystem_vendor_id = pdev->subsystem_vendor;
 	hw->subsystem_device_id = pdev->subsystem_device;
 
+	err = ixgbe_init_shared_code(hw);
+	if (err) {
+		e_err(probe, "init_shared_code failed: %d\n", err);
+		goto out;
+	}
+	adapter->mac_table = kzalloc(sizeof(struct ixgbe_mac_addr) *
+				     hw->mac.num_rar_entries,
+				     GFP_ATOMIC);
+	if (!adapter->mac_table) {
+		err = IXGBE_ERR_OUT_OF_MEM;
+		e_err(probe, "mac_table allocation failed: %d\n", err);
+		goto out;
+	}
+
+	if (ixgbe_init_rss_key(adapter)) {
+		err = IXGBE_ERR_OUT_OF_MEM;
+		e_err(probe, "rss_key allocation failed: %d\n", err);
+		goto out;
+	}
+
 	/* Set common capability flags and settings */
-	rss = min_t(int, ixgbe_max_rss_indices(adapter), num_online_cpus());
-	adapter->ring_feature[RING_F_RSS].limit = rss;
-	adapter->flags2 |= IXGBE_FLAG2_RSC_CAPABLE;
-	adapter->max_q_vectors = MAX_Q_VECTORS_82599;
-	adapter->atr_sample_rate = 20;
-	fdir = min_t(int, IXGBE_MAX_FDIR_INDICES, num_online_cpus());
-	adapter->ring_feature[RING_F_FDIR].limit = fdir;
-	adapter->fdir_pballoc = IXGBE_FDIR_PBALLOC_64K;
-#ifdef CONFIG_IXGBE_DCA
+#if IS_ENABLED(CONFIG_DCA)
 	adapter->flags |= IXGBE_FLAG_DCA_CAPABLE;
 #endif
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_DCB)
+	adapter->flags |= IXGBE_FLAG_DCB_CAPABLE;
+	adapter->flags &= ~IXGBE_FLAG_DCB_ENABLED;
+#endif
+#if IS_ENABLED(CONFIG_FCOE)
 	adapter->flags |= IXGBE_FLAG_FCOE_CAPABLE;
 	adapter->flags &= ~IXGBE_FLAG_FCOE_ENABLED;
-#ifdef CONFIG_IXGBE_DCB
+#if IS_ENABLED(CONFIG_DCB)
 	/* Default traffic class to use for FCoE */
-	adapter->fcoe.up = IXGBE_FCOE_DEFTC;
-#endif /* CONFIG_IXGBE_DCB */
-#endif /* IXGBE_FCOE */
-
-	adapter->mac_table = kzalloc(sizeof(struct ixgbe_mac_addr) *
-				     hw->mac.num_rar_entries,
-				     GFP_ATOMIC);
+	adapter->fcoe.up = IXGBE_FCOE_DEFUP;
+	adapter->fcoe.up_set = IXGBE_FCOE_DEFUP;
+#endif /* CONFIG_DCB */
+#endif /* CONFIG_FCOE */
+	adapter->flags2 |= IXGBE_FLAG2_RSC_CAPABLE;
+	fdir = min_t(int, IXGBE_MAX_FDIR_INDICES, num_online_cpus());
+	adapter->ring_feature[RING_F_FDIR].limit = fdir;
+	adapter->max_q_vectors = IXGBE_MAX_MSIX_Q_VECTORS_82599;
 
 	/* Set MAC specific capability flags and exceptions */
 	switch (hw->mac.type) {
 	case ixgbe_mac_82598EB:
+		adapter->flags |= IXGBE_FLAGS_82598_INIT;
 		adapter->flags2 &= ~IXGBE_FLAG2_RSC_CAPABLE;
 
 		if (hw->device_id == IXGBE_DEV_ID_82598AT)
 			adapter->flags |= IXGBE_FLAG_FAN_FAIL_CAPABLE;
 
-		adapter->max_q_vectors = MAX_Q_VECTORS_82598;
+		adapter->max_q_vectors = IXGBE_MAX_MSIX_Q_VECTORS_82598;
 		adapter->ring_feature[RING_F_FDIR].limit = 0;
-		adapter->atr_sample_rate = 0;
-		adapter->fdir_pballoc = 0;
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 		adapter->flags &= ~IXGBE_FLAG_FCOE_CAPABLE;
-		adapter->flags &= ~IXGBE_FLAG_FCOE_ENABLED;
-#ifdef CONFIG_IXGBE_DCB
+#if IS_ENABLED(CONFIG_DCB)
 		adapter->fcoe.up = 0;
+		adapter->fcoe.up_set = 0;
 #endif /* IXGBE_DCB */
-#endif /* IXGBE_FCOE */
+#endif /* CONFIG_FCOE */
 		break;
 	case ixgbe_mac_82599EB:
+		adapter->flags |= IXGBE_FLAGS_82599_INIT;
 		if (hw->device_id == IXGBE_DEV_ID_82599_T3_LOM)
 			adapter->flags2 |= IXGBE_FLAG2_TEMP_SENSOR_CAPABLE;
+#ifndef IXGBE_NO_SMART_SPEED
+		hw->phy.smart_speed = ixgbe_smart_speed_on;
+#else
+		hw->phy.smart_speed = ixgbe_smart_speed_off;
+#endif
 		break;
 	case ixgbe_mac_X540:
-		fwsm = IXGBE_READ_REG(hw, IXGBE_FWSM(hw));
+		adapter->flags |= IXGBE_FLAGS_X540_INIT;
+		fwsm = IXGBE_READ_REG(hw, IXGBE_FWSM);
 		if (fwsm & IXGBE_FWSM_TS_ENABLED)
 			adapter->flags2 |= IXGBE_FLAG2_TEMP_SENSOR_CAPABLE;
 		break;
+	case ixgbe_mac_X550EM_a:
+		adapter->flags |= IXGBE_FLAG_GENEVE_OFFLOAD_CAPABLE;
+		switch (hw->device_id) {
+		case IXGBE_DEV_ID_X550EM_A_1G_T:
+		case IXGBE_DEV_ID_X550EM_A_1G_T_L:
+			adapter->flags2 |= IXGBE_FLAG2_TEMP_SENSOR_CAPABLE;
+			break;
+		default:
+			break;
+		}
+		/* fall through */
 	case ixgbe_mac_X550EM_x:
+#if IS_ENABLED(CONFIG_DCB)
+		adapter->flags &= ~IXGBE_FLAG_DCB_CAPABLE;
+#endif
+#if IS_ENABLED(CONFIG_FCOE)
+		adapter->flags &= ~IXGBE_FLAG_FCOE_CAPABLE;
+#if IS_ENABLED(CONFIG_DCB)
+		adapter->fcoe.up = 0;
+		adapter->fcoe.up_set = 0;
+#endif /* CONFIG_DCB */
+#endif /* CONFIG_FCOE */
+	/* fall through */
 	case ixgbe_mac_X550:
-#ifdef CONFIG_IXGBE_DCA
+		if (hw->mac.type == ixgbe_mac_X550)
+			adapter->flags2 |= IXGBE_FLAG2_TEMP_SENSOR_CAPABLE;
+		ixgbe_set_eee_capable(adapter);
+		adapter->flags |= IXGBE_FLAGS_X550_INIT;
+#if IS_ENABLED(CONFIG_DCA)
 		adapter->flags &= ~IXGBE_FLAG_DCA_CAPABLE;
-#endif
-#ifdef CONFIG_IXGBE_VXLAN
-		adapter->flags |= IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE;
-#endif
-		break;
+#endif /* CONFIG_DCA */
 	default:
 		break;
 	}
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* FCoE support exists, always init the FCoE lock */
 	spin_lock_init(&adapter->fcoe.lock);
+#endif /* CONFIG_FCOE */
 
-#endif
 	/* n-tuple support exists, always init our spinlock */
 	spin_lock_init(&adapter->fdir_perfect_lock);
 
-#ifdef CONFIG_IXGBE_DCB
+#if IS_ENABLED(CONFIG_DCB)
 	switch (hw->mac.type) {
+	case ixgbe_mac_82598EB:
+	case ixgbe_mac_82599EB:
+		adapter->dcb_cfg.num_tcs.pg_tcs = 8;
+		adapter->dcb_cfg.num_tcs.pfc_tcs = 8;
+		break;
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
-	case ixgbe_mac_X550EM_x:
-		adapter->dcb_cfg.num_tcs.pg_tcs = X540_TRAFFIC_CLASS;
-		adapter->dcb_cfg.num_tcs.pfc_tcs = X540_TRAFFIC_CLASS;
+		adapter->dcb_cfg.num_tcs.pg_tcs = 4;
+		adapter->dcb_cfg.num_tcs.pfc_tcs = 4;
 		break;
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 	default:
-		adapter->dcb_cfg.num_tcs.pg_tcs = MAX_TRAFFIC_CLASS;
-		adapter->dcb_cfg.num_tcs.pfc_tcs = MAX_TRAFFIC_CLASS;
+		adapter->dcb_cfg.num_tcs.pg_tcs = 1;
+		adapter->dcb_cfg.num_tcs.pfc_tcs = 1;
 		break;
 	}
+	ixgbe_init_dcb(adapter);
 
-	/* Configure DCB traffic classes */
-	for (j = 0; j < MAX_TRAFFIC_CLASS; j++) {
-		tc = &adapter->dcb_cfg.tc_config[j];
-		tc->path[DCB_TX_CONFIG].bwg_id = 0;
-		tc->path[DCB_TX_CONFIG].bwg_percent = 12 + (j & 1);
-		tc->path[DCB_RX_CONFIG].bwg_id = 0;
-		tc->path[DCB_RX_CONFIG].bwg_percent = 12 + (j & 1);
-		tc->dcb_pfc = pfc_disabled;
-	}
-
-	/* Initialize default user to priority mapping, UPx->TC0 */
-	tc = &adapter->dcb_cfg.tc_config[0];
-	tc->path[DCB_TX_CONFIG].up_to_tc_bitmap = 0xFF;
-	tc->path[DCB_RX_CONFIG].up_to_tc_bitmap = 0xFF;
-
-	adapter->dcb_cfg.bw_percentage[DCB_TX_CONFIG][0] = 100;
-	adapter->dcb_cfg.bw_percentage[DCB_RX_CONFIG][0] = 100;
-	adapter->dcb_cfg.pfc_mode_enable = false;
-	adapter->dcb_set_bitmap = 0x00;
-	adapter->dcbx_cap = DCB_CAP_DCBX_HOST | DCB_CAP_DCBX_VER_CEE;
-	memcpy(&adapter->temp_dcb_cfg, &adapter->dcb_cfg,
-	       sizeof(adapter->temp_dcb_cfg));
+#endif /* CONFIG_DCB */
 
-#endif
+	if (hw->mac.type == ixgbe_mac_82599EB ||
+	    hw->mac.type == ixgbe_mac_X550 ||
+	    hw->mac.type == ixgbe_mac_X550EM_x ||
+	    hw->mac.type == ixgbe_mac_X550EM_a ||
+	    hw->mac.type == ixgbe_mac_X540)
+		hw->mbx.ops.init_params(hw);
 
 	/* default flow control settings */
 	hw->fc.requested_mode = ixgbe_fc_full;
 	hw->fc.current_mode = ixgbe_fc_full;	/* init for ethtool output */
+
+	adapter->last_lfc_mode = hw->fc.current_mode;
 	ixgbe_pbthresh_setup(adapter);
 	hw->fc.pause_time = IXGBE_DEFAULT_FCPAUSE;
 	hw->fc.send_xon = true;
-	hw->fc.disable_fc_autoneg = ixgbe_device_supports_autoneg_fc(hw);
-
-#ifdef CONFIG_PCI_IOV
-	if (max_vfs > 0)
-		e_dev_warn("Enabling SR-IOV VFs using the max_vfs module parameter is deprecated - please use the pci sysfs interface instead.\n");
-
-	/* assign number of SR-IOV VFs */
-	if (hw->mac.type != ixgbe_mac_82598EB) {
-		if (max_vfs > IXGBE_MAX_VFS_DRV_LIMIT) {
-			adapter->num_vfs = 0;
-			e_dev_warn("max_vfs parameter out of range. Not assigning any SR-IOV VFs\n");
-		} else {
-			adapter->num_vfs = max_vfs;
-		}
-	}
-#endif /* CONFIG_PCI_IOV */
-
-	/* enable itr by default in dynamic mode */
-	adapter->rx_itr_setting = 1;
-	adapter->tx_itr_setting = 1;
+	hw->fc.disable_fc_autoneg = false;
 
 	/* set default ring sizes */
 	adapter->tx_ring_count = IXGBE_DEFAULT_TXD;
@@ -5455,18 +6740,26 @@ static int ixgbe_sw_init(struct ixgbe_adapter *adapter)
 
 	/* set default work limits */
 	adapter->tx_work_limit = IXGBE_DEFAULT_TX_WORK;
+	adapter->rx_work_limit = IXGBE_DEFAULT_RX_WORK;
 
-	/* initialize eeprom parameters */
-	if (ixgbe_init_eeprom_params_generic(hw)) {
-		e_dev_err("EEPROM initialization failed\n");
-		return -EIO;
+	/* Cache bit indicating need for crosstalk fix */
+	switch (hw->mac.type) {
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		hw->mac.ops.get_device_caps(hw, &device_caps);
+		if (device_caps & IXGBE_DEVICE_CAPS_NO_CROSSTALK_WR)
+			adapter->need_crosstalk_fix = false;
+		else
+			adapter->need_crosstalk_fix = true;
+		break;
+	default:
+		adapter->need_crosstalk_fix = false;
+		break;
 	}
-
-	/* PF holds first pool slot */
-	set_bit(0, &adapter->fwd_bitmask);
 	set_bit(__IXGBE_DOWN, &adapter->state);
-
-	return 0;
+out:
+	return err;
 }
 
 /**
@@ -5479,27 +6772,25 @@ int ixgbe_setup_tx_resources(struct ixgbe_ring *tx_ring)
 {
 	struct device *dev = tx_ring->dev;
 	int orig_node = dev_to_node(dev);
-	int ring_node = -1;
+	int numa_node = -1;
 	int size;
 
 	size = sizeof(struct ixgbe_tx_buffer) * tx_ring->count;
 
 	if (tx_ring->q_vector)
-		ring_node = tx_ring->q_vector->numa_node;
+		numa_node = tx_ring->q_vector->numa_node;
 
-	tx_ring->tx_buffer_info = vzalloc_node(size, ring_node);
+	tx_ring->tx_buffer_info = vmalloc_node(size, numa_node);
 	if (!tx_ring->tx_buffer_info)
-		tx_ring->tx_buffer_info = vzalloc(size);
+		tx_ring->tx_buffer_info = vmalloc(size);
 	if (!tx_ring->tx_buffer_info)
 		goto err;
 
-	u64_stats_init(&tx_ring->syncp);
-
 	/* round up to nearest 4K */
 	tx_ring->size = tx_ring->count * sizeof(union ixgbe_adv_tx_desc);
 	tx_ring->size = ALIGN(tx_ring->size, 4096);
 
-	set_dev_node(dev, ring_node);
+	set_dev_node(dev, numa_node);
 	tx_ring->desc = dma_alloc_coherent(dev,
 					   tx_ring->size,
 					   &tx_ring->dma,
@@ -5511,8 +6802,6 @@ int ixgbe_setup_tx_resources(struct ixgbe_ring *tx_ring)
 	if (!tx_ring->desc)
 		goto err;
 
-	tx_ring->next_to_use = 0;
-	tx_ring->next_to_clean = 0;
 	return 0;
 
 err:
@@ -5537,6 +6826,7 @@ static int ixgbe_setup_all_tx_resources(struct ixgbe_adapter *adapter)
 	int i, err = 0;
 
 	for (i = 0; i < adapter->num_tx_queues; i++) {
+
 		err = ixgbe_setup_tx_resources(adapter->tx_ring[i]);
 		if (!err)
 			continue;
@@ -5563,27 +6853,25 @@ int ixgbe_setup_rx_resources(struct ixgbe_ring *rx_ring)
 {
 	struct device *dev = rx_ring->dev;
 	int orig_node = dev_to_node(dev);
-	int ring_node = -1;
+	int numa_node = -1;
 	int size;
 
 	size = sizeof(struct ixgbe_rx_buffer) * rx_ring->count;
 
 	if (rx_ring->q_vector)
-		ring_node = rx_ring->q_vector->numa_node;
+		numa_node = rx_ring->q_vector->numa_node;
 
-	rx_ring->rx_buffer_info = vzalloc_node(size, ring_node);
+	rx_ring->rx_buffer_info = vmalloc_node(size, numa_node);
 	if (!rx_ring->rx_buffer_info)
-		rx_ring->rx_buffer_info = vzalloc(size);
+		rx_ring->rx_buffer_info = vmalloc(size);
 	if (!rx_ring->rx_buffer_info)
 		goto err;
 
-	u64_stats_init(&rx_ring->syncp);
-
 	/* Round up to nearest 4K */
 	rx_ring->size = rx_ring->count * sizeof(union ixgbe_adv_rx_desc);
 	rx_ring->size = ALIGN(rx_ring->size, 4096);
 
-	set_dev_node(dev, ring_node);
+	set_dev_node(dev, numa_node);
 	rx_ring->desc = dma_alloc_coherent(dev,
 					   rx_ring->size,
 					   &rx_ring->dma,
@@ -5595,9 +6883,6 @@ int ixgbe_setup_rx_resources(struct ixgbe_ring *rx_ring)
 	if (!rx_ring->desc)
 		goto err;
 
-	rx_ring->next_to_clean = 0;
-	rx_ring->next_to_use = 0;
-
 	return 0;
 err:
 	vfree(rx_ring->rx_buffer_info);
@@ -5622,14 +6907,15 @@ static int ixgbe_setup_all_rx_resources(struct ixgbe_adapter *adapter)
 
 	for (i = 0; i < adapter->num_rx_queues; i++) {
 		err = ixgbe_setup_rx_resources(adapter->rx_ring[i]);
-		if (!err)
+		if (!err) {
 			continue;
+		}
 
 		e_err(probe, "Allocation for Rx Queue %u failed\n", i);
 		goto err_setup_rx;
 	}
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	err = ixgbe_setup_fcoe_ddp_resources(adapter);
 	if (!err)
 #endif
@@ -5660,7 +6946,6 @@ void ixgbe_free_tx_resources(struct ixgbe_ring *tx_ring)
 
 	dma_free_coherent(tx_ring->dev, tx_ring->size,
 			  tx_ring->desc, tx_ring->dma);
-
 	tx_ring->desc = NULL;
 }
 
@@ -5675,8 +6960,7 @@ static void ixgbe_free_all_tx_resources(struct ixgbe_adapter *adapter)
 	int i;
 
 	for (i = 0; i < adapter->num_tx_queues; i++)
-		if (adapter->tx_ring[i]->desc)
-			ixgbe_free_tx_resources(adapter->tx_ring[i]);
+		ixgbe_free_tx_resources(adapter->tx_ring[i]);
 }
 
 /**
@@ -5712,13 +6996,12 @@ static void ixgbe_free_all_rx_resources(struct ixgbe_adapter *adapter)
 {
 	int i;
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	ixgbe_free_fcoe_ddp_resources(adapter);
-
 #endif
+
 	for (i = 0; i < adapter->num_rx_queues; i++)
-		if (adapter->rx_ring[i]->desc)
-			ixgbe_free_rx_resources(adapter->rx_ring[i]);
+		ixgbe_free_rx_resources(adapter->rx_ring[i]);
 }
 
 /**
@@ -5731,12 +7014,16 @@ static void ixgbe_free_all_rx_resources(struct ixgbe_adapter *adapter)
 static int ixgbe_change_mtu(struct net_device *netdev, int new_mtu)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+#ifndef HAVE_NETDEVICE_MIN_MAX_MTU
 	int max_frame = new_mtu + ETH_HLEN + ETH_FCS_LEN;
+#endif
 
+#ifndef HAVE_NETDEVICE_MIN_MAX_MTU
 	/* MTU < 68 is an error and causes problems on some kernels */
 	if ((new_mtu < 68) || (max_frame > IXGBE_MAX_JUMBO_FRAME_SIZE))
 		return -EINVAL;
 
+#endif
 	/*
 	 * For 82599EB we cannot allow legacy VFs to enable their receive
 	 * paths when MTU greater than 1500 is configured.  So display a
@@ -5744,7 +7031,11 @@ static int ixgbe_change_mtu(struct net_device *netdev, int new_mtu)
 	 */
 	if ((adapter->flags & IXGBE_FLAG_SRIOV_ENABLED) &&
 	    (adapter->hw.mac.type == ixgbe_mac_82599EB) &&
+#ifndef HAVE_NETDEVICE_MIN_MAX_MTU
 	    (max_frame > (ETH_FRAME_LEN + ETH_FCS_LEN)))
+#else
+	    (new_mtu > ETH_DATA_LEN))
+#endif
 		e_warn(probe, "Setting MTU > 1500 will disable legacy VFs\n");
 
 	e_info(probe, "changing MTU from %d to %d\n", netdev->mtu, new_mtu);
@@ -5773,8 +7064,7 @@ static int ixgbe_change_mtu(struct net_device *netdev, int new_mtu)
 static int ixgbe_open(struct net_device *netdev)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	struct ixgbe_hw *hw = &adapter->hw;
-	int err, queues;
+	int err;
 
 	/* disallow open during test */
 	if (test_bit(__IXGBE_TESTING, &adapter->state))
@@ -5799,41 +7089,40 @@ static int ixgbe_open(struct net_device *netdev)
 		goto err_req_irq;
 
 	/* Notify the stack of the actual queue counts. */
-	if (adapter->num_rx_pools > 1)
-		queues = adapter->num_rx_queues_per_pool;
-	else
-		queues = adapter->num_tx_queues;
-
-	err = netif_set_real_num_tx_queues(netdev, queues);
+	err = netif_set_real_num_tx_queues(netdev,
+					   adapter->num_rx_pools > 1 ? 1 :
+					   adapter->num_tx_queues);
 	if (err)
 		goto err_set_queues;
 
-	if (adapter->num_rx_pools > 1 &&
-	    adapter->num_rx_queues > IXGBE_MAX_L2A_QUEUES)
-		queues = IXGBE_MAX_L2A_QUEUES;
-	else
-		queues = adapter->num_rx_queues;
-	err = netif_set_real_num_rx_queues(netdev, queues);
+	err = netif_set_real_num_rx_queues(netdev,
+					   adapter->num_rx_pools > 1 ? 1 :
+					   adapter->num_rx_queues);
 	if (err)
 		goto err_set_queues;
 
+#ifdef HAVE_PTP_1588_CLOCK
 	ixgbe_ptp_init(adapter);
+#endif /* HAVE_PTP_1588_CLOCK*/
 
 	ixgbe_up_complete(adapter);
 
-	ixgbe_clear_vxlan_port(adapter);
-#ifdef CONFIG_IXGBE_VXLAN
-	vxlan_get_rx_port(netdev);
+#if defined(HAVE_UDP_ENC_RX_OFFLOAD) || defined(HAVE_VXLAN_RX_OFFLOAD)
+	ixgbe_clear_udp_tunnel_port(adapter, IXGBE_VXLANCTRL_ALL_UDPPORT_MASK);
 #endif
-
-	return 0;
+#ifdef HAVE_UDP_ENC_RX_OFFLOAD
+	udp_tunnel_get_rx_info(netdev);
+#elif defined(HAVE_VXLAN_RX_OFFLOAD)
+	vxlan_get_rx_port(netdev);
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD */
+	return IXGBE_SUCCESS;
 
 err_set_queues:
 	ixgbe_free_irq(adapter);
 err_req_irq:
 	ixgbe_free_all_rx_resources(adapter);
-	if (hw->phy.ops.set_phy_power && !adapter->wol)
-		hw->phy.ops.set_phy_power(&adapter->hw, false);
+	if (!adapter->wol)
+		ixgbe_set_phy_power(&adapter->hw, false);
 err_setup_rx:
 	ixgbe_free_all_tx_resources(adapter);
 err_setup_tx:
@@ -5842,23 +7131,31 @@ err_setup_tx:
 	return err;
 }
 
+/**
+ * ixgbe_close_suspend - actions necessary to both suspend and close flows
+ * @adapter: the private adapter struct
+ *
+ * This function should contain the necessary work common to both suspending
+ * and closing of the device.
+ */
 static void ixgbe_close_suspend(struct ixgbe_adapter *adapter)
 {
+#ifdef HAVE_PTP_1588_CLOCK
 	ixgbe_ptp_suspend(adapter);
+#endif
 
 	if (adapter->hw.phy.ops.enter_lplu) {
 		adapter->hw.phy.reset_disable = true;
 		ixgbe_down(adapter);
-		adapter->hw.phy.ops.enter_lplu(&adapter->hw);
+		ixgbe_enter_lplu(&adapter->hw);
 		adapter->hw.phy.reset_disable = false;
 	} else {
 		ixgbe_down(adapter);
 	}
-
 	ixgbe_free_irq(adapter);
 
-	ixgbe_free_all_tx_resources(adapter);
 	ixgbe_free_all_rx_resources(adapter);
+	ixgbe_free_all_tx_resources(adapter);
 }
 
 /**
@@ -5876,7 +7173,9 @@ static int ixgbe_close(struct net_device *netdev)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 
+#ifdef HAVE_PTP_1588_CLOCK
 	ixgbe_ptp_stop(adapter);
+#endif
 
 	if (netif_device_present(netdev))
 		ixgbe_close_suspend(adapter);
@@ -5889,12 +7188,21 @@ static int ixgbe_close(struct net_device *netdev)
 }
 
 #ifdef CONFIG_PM
+#ifndef USE_LEGACY_PM_SUPPORT
+static int ixgbe_resume(struct device *dev)
+#else
 static int ixgbe_resume(struct pci_dev *pdev)
+#endif /* USE_LEGACY_PM_SUPPORT */
 {
-	struct ixgbe_adapter *adapter = pci_get_drvdata(pdev);
-	struct net_device *netdev = adapter->netdev;
+	struct ixgbe_adapter *adapter;
+	struct net_device *netdev;
 	u32 err;
+#ifndef USE_LEGACY_PM_SUPPORT
+	struct pci_dev *pdev = to_pci_dev(dev);
+#endif
 
+	adapter = pci_get_drvdata(pdev);
+	netdev = adapter->netdev;
 	adapter->hw.hw_addr = adapter->io_addr;
 	pci_set_power_state(pdev, PCI_D0);
 	pci_restore_state(pdev);
@@ -5920,6 +7228,7 @@ static int ixgbe_resume(struct pci_dev *pdev)
 	IXGBE_WRITE_REG(&adapter->hw, IXGBE_WUS, ~0);
 
 	rtnl_lock();
+
 	err = ixgbe_init_interrupt_scheme(adapter);
 	if (!err && netif_running(netdev))
 		err = ixgbe_open(netdev);
@@ -5927,18 +7236,88 @@ static int ixgbe_resume(struct pci_dev *pdev)
 
 	if (!err)
 		netif_device_attach(netdev);
+
 	rtnl_unlock();
 
 	return err;
 }
+
+#ifndef USE_LEGACY_PM_SUPPORT
+/**
+ * ixgbe_freeze - quiesce the device (no IRQ's or DMA)
+ * @dev: The port's netdev
+ */
+static int ixgbe_freeze(struct device *dev)
+{
+	struct ixgbe_adapter *adapter = pci_get_drvdata(to_pci_dev(dev));
+	struct net_device *netdev = adapter->netdev;
+	bool lplu_enabled = !!adapter->hw.phy.ops.enter_lplu;
+
+	rtnl_lock();
+	netif_device_detach(netdev);
+
+	if (netif_running(netdev)) {
+		if (lplu_enabled) {
+			adapter->hw.phy.reset_disable = true;
+			ixgbe_down(adapter);
+			adapter->hw.phy.reset_disable = false;
+		} else {
+			ixgbe_down(adapter);
+		}
+		ixgbe_free_irq(adapter);
+	}
+
+	ixgbe_reset_interrupt_capability(adapter);
+	rtnl_unlock();
+
+	return 0;
+}
+
+/**
+ * ixgbe_thaw - un-quiesce the device
+ * @dev: The port's netdev
+ */
+static int ixgbe_thaw(struct device *dev)
+{
+	struct ixgbe_adapter *adapter = pci_get_drvdata(to_pci_dev(dev));
+	struct net_device *netdev = adapter->netdev;
+	bool lplu_enabled = !!adapter->hw.phy.ops.enter_lplu;
+
+	ixgbe_set_interrupt_capability(adapter);
+
+	if (netif_running(netdev)) {
+		u32 err = ixgbe_request_irq(adapter);
+		if (err)
+			return err;
+
+		if (lplu_enabled) {
+			adapter->hw.phy.reset_disable = true;
+			ixgbe_up(adapter);
+			adapter->hw.phy.reset_disable = false;
+		} else {
+			ixgbe_up(adapter);
+		}
+	}
+
+	netif_device_attach(netdev);
+
+	return 0;
+}
+#endif /* USE_LEGACY_PM_SUPPORT */
 #endif /* CONFIG_PM */
 
+/*
+ * __ixgbe_shutdown is not used when power management
+ * is disabled on older kernels (<2.6.12). causes a compile
+ * warning/error, because it is defined and not used.
+ */
+#if defined(CONFIG_PM) || !defined(USE_REBOOT_NOTIFIER)
 static int __ixgbe_shutdown(struct pci_dev *pdev, bool *enable_wake)
 {
 	struct ixgbe_adapter *adapter = pci_get_drvdata(pdev);
 	struct net_device *netdev = adapter->netdev;
 	struct ixgbe_hw *hw = &adapter->hw;
-	u32 ctrl, fctrl;
+	u32 ctrl;
 	u32 wufc = adapter->wol;
 #ifdef CONFIG_PM
 	int retval = 0;
@@ -5959,22 +7338,24 @@ static int __ixgbe_shutdown(struct pci_dev *pdev, bool *enable_wake)
 		return retval;
 
 #endif
-	if (hw->mac.ops.stop_link_on_d3)
-		hw->mac.ops.stop_link_on_d3(hw);
+
+	/* this won't stop link of managebility or WoL is enabled */
+	if (hw->mac.type == ixgbe_mac_82599EB)
+		ixgbe_stop_mac_link_on_d3_82599(hw);
 
 	if (wufc) {
+		u32 fctrl;
+
 		ixgbe_set_rx_mode(netdev);
 
 		/* enable the optics for 82599 SFP+ fiber as we can WoL */
 		if (hw->mac.ops.enable_tx_laser)
 			hw->mac.ops.enable_tx_laser(hw);
 
-		/* turn on all-multi mode if wake on multicast is enabled */
-		if (wufc & IXGBE_WUFC_MC) {
-			fctrl = IXGBE_READ_REG(hw, IXGBE_FCTRL);
-			fctrl |= IXGBE_FCTRL_MPE;
-			IXGBE_WRITE_REG(hw, IXGBE_FCTRL, fctrl);
-		}
+		/* enable the reception of multicast packets */
+		fctrl = IXGBE_READ_REG(hw, IXGBE_FCTRL);
+		fctrl |= IXGBE_FCTRL_MPE;
+		IXGBE_WRITE_REG(hw, IXGBE_FCTRL, fctrl);
 
 		ctrl = IXGBE_READ_REG(hw, IXGBE_CTRL);
 		ctrl |= IXGBE_CTRL_GIO_DIS;
@@ -5994,6 +7375,7 @@ static int __ixgbe_shutdown(struct pci_dev *pdev, bool *enable_wake)
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		pci_wake_from_d3(pdev, !!wufc);
 		break;
 	default:
@@ -6001,8 +7383,8 @@ static int __ixgbe_shutdown(struct pci_dev *pdev, bool *enable_wake)
 	}
 
 	*enable_wake = !!wufc;
-	if (hw->phy.ops.set_phy_power && !*enable_wake)
-		hw->phy.ops.set_phy_power(hw, false);
+	if (!*enable_wake)
+		ixgbe_set_phy_power(hw, false);
 
 	ixgbe_release_hw_control(adapter);
 
@@ -6011,12 +7393,21 @@ static int __ixgbe_shutdown(struct pci_dev *pdev, bool *enable_wake)
 
 	return 0;
 }
+#endif /* defined(CONFIG_PM) || !defined(USE_REBOOT_NOTIFIER) */
 
 #ifdef CONFIG_PM
-static int ixgbe_suspend(struct pci_dev *pdev, pm_message_t state)
+#ifndef USE_LEGACY_PM_SUPPORT
+static int ixgbe_suspend(struct device *dev)
+#else
+static int ixgbe_suspend(struct pci_dev *pdev,
+			 pm_message_t __always_unused state)
+#endif /* USE_LEGACY_PM_SUPPORT */
 {
 	int retval;
 	bool wake;
+#ifndef USE_LEGACY_PM_SUPPORT
+	struct pci_dev *pdev = to_pci_dev(dev);
+#endif
 
 	retval = __ixgbe_shutdown(pdev, &wake);
 	if (retval)
@@ -6031,27 +7422,120 @@ static int ixgbe_suspend(struct pci_dev *pdev, pm_message_t state)
 
 	return 0;
 }
-#endif /* CONFIG_PM */
-
-static void ixgbe_shutdown(struct pci_dev *pdev)
+#endif /* CONFIG_PM */
+
+#ifndef USE_REBOOT_NOTIFIER
+static void ixgbe_shutdown(struct pci_dev *pdev)
+{
+	bool wake;
+
+	__ixgbe_shutdown(pdev, &wake);
+
+	if (system_state == SYSTEM_POWER_OFF) {
+		pci_wake_from_d3(pdev, wake);
+		pci_set_power_state(pdev, PCI_D3hot);
+	}
+}
+
+#endif
+#ifdef HAVE_NDO_GET_STATS64
+/**
+ * ixgbe_get_stats64 - Get System Network Statistics
+ * @netdev: network interface device structure
+ * @stats: storage space for 64bit statistics
+ *
+ * Returns 64bit statistics, for use in the ndo_get_stats64 callback. This
+ * function replaces ixgbe_get_stats for kernels which support it.
+ */
+#ifdef HAVE_VOID_NDO_GET_STATS64
+static void ixgbe_get_stats64(struct net_device *netdev,
+			      struct rtnl_link_stats64 *stats)
+#else
+static struct rtnl_link_stats64 *ixgbe_get_stats64(struct net_device *netdev,
+						   struct rtnl_link_stats64 *stats)
+#endif
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	int i;
+
+	rcu_read_lock();
+	for (i = 0; i < adapter->num_rx_queues; i++) {
+		struct ixgbe_ring *ring = ACCESS_ONCE(adapter->rx_ring[i]);
+		u64 bytes, packets;
+		unsigned int start;
+
+		if (ring) {
+			do {
+				start = u64_stats_fetch_begin_irq(&ring->syncp);
+				packets = ring->stats.packets;
+				bytes   = ring->stats.bytes;
+			} while (u64_stats_fetch_retry_irq(&ring->syncp, start));
+			stats->rx_packets += packets;
+			stats->rx_bytes   += bytes;
+		}
+	}
+
+	for (i = 0; i < adapter->num_tx_queues; i++) {
+		struct ixgbe_ring *ring = ACCESS_ONCE(adapter->tx_ring[i]);
+		u64 bytes, packets;
+		unsigned int start;
+
+		if (ring) {
+			do {
+				start = u64_stats_fetch_begin_irq(&ring->syncp);
+				packets = ring->stats.packets;
+				bytes   = ring->stats.bytes;
+			} while (u64_stats_fetch_retry_irq(&ring->syncp, start));
+			stats->tx_packets += packets;
+			stats->tx_bytes   += bytes;
+		}
+	}
+	rcu_read_unlock();
+	/* following stats updated by ixgbe_watchdog_task() */
+	stats->multicast	= netdev->stats.multicast;
+	stats->rx_errors	= netdev->stats.rx_errors;
+	stats->rx_length_errors	= netdev->stats.rx_length_errors;
+	stats->rx_crc_errors	= netdev->stats.rx_crc_errors;
+	stats->rx_missed_errors	= netdev->stats.rx_missed_errors;
+#ifndef HAVE_VOID_NDO_GET_STATS64
+	return stats;
+#endif
+}
+#else
+/**
+ * ixgbe_get_stats - Get System Network Statistics
+ * @netdev: network interface device structure
+ *
+ * Returns the address of the device statistics structure.
+ * The statistics are actually updated from the timer callback.
+ **/
+static struct net_device_stats *ixgbe_get_stats(struct net_device *netdev)
 {
-	bool wake;
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 
-	__ixgbe_shutdown(pdev, &wake);
+	/* update the stats data */
+	ixgbe_update_stats(adapter);
 
-	if (system_state == SYSTEM_POWER_OFF) {
-		pci_wake_from_d3(pdev, wake);
-		pci_set_power_state(pdev, PCI_D3hot);
-	}
+#ifdef HAVE_NETDEV_STATS_IN_NETDEV
+	/* only return the current stats */
+	return &netdev->stats;
+#else
+	/* only return the current stats */
+	return &adapter->net_stats;
+#endif /* HAVE_NETDEV_STATS_IN_NETDEV */
 }
-
+#endif
 /**
  * ixgbe_update_stats - Update the board statistics counters.
  * @adapter: board private structure
  **/
 void ixgbe_update_stats(struct ixgbe_adapter *adapter)
 {
-	struct net_device *netdev = adapter->netdev;
+#ifdef HAVE_NETDEV_STATS_IN_NETDEV
+	struct net_device_stats *net_stats = &adapter->netdev->stats;
+#else
+	struct net_device_stats *net_stats = &adapter->net_stats;
+#endif /* HAVE_NETDEV_STATS_IN_NETDEV */
 	struct ixgbe_hw *hw = &adapter->hw;
 	struct ixgbe_hw_stats *hwstats = &adapter->stats;
 	u64 total_mpc = 0;
@@ -6083,13 +7567,14 @@ void ixgbe_update_stats(struct ixgbe_adapter *adapter)
 		hw_csum_rx_error += rx_ring->rx_stats.csum_err;
 		bytes += rx_ring->stats.bytes;
 		packets += rx_ring->stats.packets;
+
 	}
 	adapter->non_eop_descs = non_eop_descs;
 	adapter->alloc_rx_page_failed = alloc_rx_page_failed;
 	adapter->alloc_rx_buff_failed = alloc_rx_buff_failed;
 	adapter->hw_csum_rx_error = hw_csum_rx_error;
-	netdev->stats.rx_bytes = bytes;
-	netdev->stats.rx_packets = packets;
+	net_stats->rx_bytes = bytes;
+	net_stats->rx_packets = packets;
 
 	bytes = 0;
 	packets = 0;
@@ -6103,8 +7588,8 @@ void ixgbe_update_stats(struct ixgbe_adapter *adapter)
 	}
 	adapter->restart_queue = restart_queue;
 	adapter->tx_busy = tx_busy;
-	netdev->stats.tx_bytes = bytes;
-	netdev->stats.tx_packets = packets;
+	net_stats->tx_bytes = bytes;
+	net_stats->tx_packets = packets;
 
 	hwstats->crcerrs += IXGBE_READ_REG(hw, IXGBE_CRCERRS);
 
@@ -6129,6 +7614,7 @@ void ixgbe_update_stats(struct ixgbe_adapter *adapter)
 		case ixgbe_mac_X540:
 		case ixgbe_mac_X550:
 		case ixgbe_mac_X550EM_x:
+		case ixgbe_mac_X550EM_a:
 			hwstats->pxonrxc[i] +=
 				IXGBE_READ_REG(hw, IXGBE_PXONRXCNT(i));
 			break;
@@ -6142,9 +7628,10 @@ void ixgbe_update_stats(struct ixgbe_adapter *adapter)
 		hwstats->qptc[i] += IXGBE_READ_REG(hw, IXGBE_QPTC(i));
 		hwstats->qprc[i] += IXGBE_READ_REG(hw, IXGBE_QPRC(i));
 		if ((hw->mac.type == ixgbe_mac_82599EB) ||
-		    (hw->mac.type == ixgbe_mac_X540) ||
 		    (hw->mac.type == ixgbe_mac_X550) ||
-		    (hw->mac.type == ixgbe_mac_X550EM_x)) {
+		    (hw->mac.type == ixgbe_mac_X550EM_x) ||
+		    (hw->mac.type == ixgbe_mac_X550EM_a) ||
+		    (hw->mac.type == ixgbe_mac_X540)) {
 			hwstats->qbtc[i] += IXGBE_READ_REG(hw, IXGBE_QBTC_L(i));
 			IXGBE_READ_REG(hw, IXGBE_QBTC_H(i)); /* to clear */
 			hwstats->qbrc[i] += IXGBE_READ_REG(hw, IXGBE_QBRC_L(i));
@@ -6169,11 +7656,13 @@ void ixgbe_update_stats(struct ixgbe_adapter *adapter)
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
-		/* OS2BMC stats are X540 and later */
+	case ixgbe_mac_X550EM_a:
+		/* OS2BMC stats are X540 only*/
 		hwstats->o2bgptc += IXGBE_READ_REG(hw, IXGBE_O2BGPTC);
 		hwstats->o2bspc += IXGBE_READ_REG(hw, IXGBE_O2BSPC);
 		hwstats->b2ospc += IXGBE_READ_REG(hw, IXGBE_B2OSPC);
 		hwstats->b2ogprc += IXGBE_READ_REG(hw, IXGBE_B2OGPRC);
+		/* fall through */
 	case ixgbe_mac_82599EB:
 		for (i = 0; i < 16; i++)
 			adapter->hw_rx_no_dma_resources +=
@@ -6185,16 +7674,19 @@ void ixgbe_update_stats(struct ixgbe_adapter *adapter)
 		hwstats->tor += IXGBE_READ_REG(hw, IXGBE_TORL);
 		IXGBE_READ_REG(hw, IXGBE_TORH); /* to clear */
 		hwstats->lxonrxc += IXGBE_READ_REG(hw, IXGBE_LXONRXCNT);
+#ifdef HAVE_TX_MQ
 		hwstats->fdirmatch += IXGBE_READ_REG(hw, IXGBE_FDIRMATCH);
 		hwstats->fdirmiss += IXGBE_READ_REG(hw, IXGBE_FDIRMISS);
-#ifdef IXGBE_FCOE
+#endif /* HAVE_TX_MQ */
+#if IS_ENABLED(CONFIG_FCOE)
 		hwstats->fccrc += IXGBE_READ_REG(hw, IXGBE_FCCRC);
+		hwstats->fclast += IXGBE_READ_REG(hw, IXGBE_FCLAST);
 		hwstats->fcoerpdc += IXGBE_READ_REG(hw, IXGBE_FCOERPDC);
 		hwstats->fcoeprc += IXGBE_READ_REG(hw, IXGBE_FCOEPRC);
 		hwstats->fcoeptc += IXGBE_READ_REG(hw, IXGBE_FCOEPTC);
 		hwstats->fcoedwrc += IXGBE_READ_REG(hw, IXGBE_FCOEDWRC);
 		hwstats->fcoedwtc += IXGBE_READ_REG(hw, IXGBE_FCOEDWTC);
-		/* Add up per cpu counters for total ddp aloc fail */
+		/* Add up per cpu counters for total ddp alloc fail */
 		if (adapter->fcoe.ddp_pool) {
 			struct ixgbe_fcoe *fcoe = &adapter->fcoe;
 			struct ixgbe_fcoe_ddp_pool *ddp_pool;
@@ -6208,7 +7700,8 @@ void ixgbe_update_stats(struct ixgbe_adapter *adapter)
 			hwstats->fcoe_noddp = noddp;
 			hwstats->fcoe_noddp_ext_buff = noddp_ext_buff;
 		}
-#endif /* IXGBE_FCOE */
+
+#endif /* CONFIG_FCOE */
 		break;
 	default:
 		break;
@@ -6251,21 +7744,49 @@ void ixgbe_update_stats(struct ixgbe_adapter *adapter)
 	hwstats->ptc1023 += IXGBE_READ_REG(hw, IXGBE_PTC1023);
 	hwstats->ptc1522 += IXGBE_READ_REG(hw, IXGBE_PTC1522);
 	hwstats->bptc += IXGBE_READ_REG(hw, IXGBE_BPTC);
-
 	/* Fill out the OS statistics structure */
-	netdev->stats.multicast = hwstats->mprc;
+	net_stats->multicast = hwstats->mprc;
 
 	/* Rx Errors */
-	netdev->stats.rx_errors = hwstats->crcerrs + hwstats->rlec;
-	netdev->stats.rx_dropped = 0;
-	netdev->stats.rx_length_errors = hwstats->rlec;
-	netdev->stats.rx_crc_errors = hwstats->crcerrs;
-	netdev->stats.rx_missed_errors = total_mpc;
+	net_stats->rx_errors = hwstats->crcerrs +
+				       hwstats->rlec;
+	net_stats->rx_dropped = 0;
+	net_stats->rx_length_errors = hwstats->rlec;
+	net_stats->rx_crc_errors = hwstats->crcerrs;
+	net_stats->rx_missed_errors = total_mpc;
+
+	/*
+	 * VF Stats Collection - skip while resetting because these
+	 * are not clear on read and otherwise you'll sometimes get
+	 * crazy values.
+	 */
+	if (!test_bit(__IXGBE_RESETTING, &adapter->state)) {
+		for (i = 0; i < adapter->num_vfs; i++) {
+			UPDATE_VF_COUNTER_32bit(IXGBE_PVFGPRC(i),	      \
+					adapter->vfinfo[i].last_vfstats.gprc, \
+					adapter->vfinfo[i].vfstats.gprc);
+			UPDATE_VF_COUNTER_32bit(IXGBE_PVFGPTC(i),	      \
+					adapter->vfinfo[i].last_vfstats.gptc, \
+					adapter->vfinfo[i].vfstats.gptc);
+			UPDATE_VF_COUNTER_36bit(IXGBE_PVFGORC_LSB(i),	      \
+					IXGBE_PVFGORC_MSB(i),		      \
+					adapter->vfinfo[i].last_vfstats.gorc, \
+					adapter->vfinfo[i].vfstats.gorc);
+			UPDATE_VF_COUNTER_36bit(IXGBE_PVFGOTC_LSB(i),	      \
+					IXGBE_PVFGOTC_MSB(i),		      \
+					adapter->vfinfo[i].last_vfstats.gotc, \
+					adapter->vfinfo[i].vfstats.gotc);
+			UPDATE_VF_COUNTER_32bit(IXGBE_PVFMPRC(i),	      \
+					adapter->vfinfo[i].last_vfstats.mprc, \
+					adapter->vfinfo[i].vfstats.mprc);
+		}
+	}
 }
 
+#ifdef HAVE_TX_MQ
 /**
  * ixgbe_fdir_reinit_subtask - worker thread to reinit FDIR filter table
- * @adapter: pointer to the device adapter structure
+ * @adapter - pointer to the device adapter structure
  **/
 static void ixgbe_fdir_reinit_subtask(struct ixgbe_adapter *adapter)
 {
@@ -6287,7 +7808,7 @@ static void ixgbe_fdir_reinit_subtask(struct ixgbe_adapter *adapter)
 
 	adapter->fdir_overflow++;
 
-	if (ixgbe_reinit_fdir_tables_82599(hw) == 0) {
+	if (ixgbe_reinit_fdir_tables_82599(hw) == IXGBE_SUCCESS) {
 		for (i = 0; i < adapter->num_tx_queues; i++)
 			set_bit(__IXGBE_TX_FDIR_INIT_DONE,
 				&(adapter->tx_ring[i]->state));
@@ -6299,9 +7820,10 @@ static void ixgbe_fdir_reinit_subtask(struct ixgbe_adapter *adapter)
 	}
 }
 
+#endif /* HAVE_TX_MQ */
 /**
  * ixgbe_check_hang_subtask - check for hung queues and dropped interrupts
- * @adapter: pointer to the device adapter structure
+ * @adapter - pointer to the device adapter structure
  *
  * This function serves two purposes.  First it strobes the interrupt lines
  * in order to make certain interrupts are occurring.  Secondly it sets the
@@ -6314,9 +7836,9 @@ static void ixgbe_check_hang_subtask(struct ixgbe_adapter *adapter)
 	u64 eics = 0;
 	int i;
 
-	/* If we're down, removing or resetting, just bail */
+	/* If we're down or resetting, just bail */
 	if (test_bit(__IXGBE_DOWN, &adapter->state) ||
-	    test_bit(__IXGBE_REMOVING, &adapter->state) ||
+	    test_bit(__IXGBE_REMOVE, &adapter->state) ||
 	    test_bit(__IXGBE_RESETTING, &adapter->state))
 		return;
 
@@ -6349,8 +7871,8 @@ static void ixgbe_check_hang_subtask(struct ixgbe_adapter *adapter)
 
 /**
  * ixgbe_watchdog_update_link - update the link status
- * @adapter: pointer to the device adapter structure
- * @link_speed: pointer to a u32 to store the link_speed
+ * @adapter - pointer to the device adapter structure
+ * @link_speed - pointer to a u32 to store the link_speed
  **/
 static void ixgbe_watchdog_update_link(struct ixgbe_adapter *adapter)
 {
@@ -6370,9 +7892,37 @@ static void ixgbe_watchdog_update_link(struct ixgbe_adapter *adapter)
 		link_up = true;
 	}
 
+	/* If Crosstalk fix enabled do the sanity check of making sure
+	 * the SFP+ cage is empty.
+	 */
+	if (adapter->need_crosstalk_fix) {
+		u32 sfp_cage_full;
+
+		switch (hw->mac.type) {
+		case ixgbe_mac_82599EB:
+			sfp_cage_full = IXGBE_READ_REG(hw, IXGBE_ESDP) &
+					IXGBE_ESDP_SDP2;
+			break;
+		case ixgbe_mac_X550EM_x:
+		case ixgbe_mac_X550EM_a:
+			sfp_cage_full = IXGBE_READ_REG(hw, IXGBE_ESDP) &
+					IXGBE_ESDP_SDP0;
+			break;
+		default:
+			/* Non-SFP+ system - sanity check */
+			sfp_cage_full = false;
+			break;
+		}
+
+		if (ixgbe_is_sfp(hw) && link_up && !sfp_cage_full)
+			link_up = false;
+	}
+
+#ifdef HAVE_DCBNL_IEEE
 	if (adapter->ixgbe_ieee_pfc)
 		pfc_en |= !!(adapter->ixgbe_ieee_pfc->pfc_en);
 
+#endif
 	if (link_up && !((adapter->flags & IXGBE_FLAG_DCB_ENABLED) && pfc_en)) {
 		hw->mac.ops.fc_enable(hw);
 		ixgbe_set_rx_drop_en(adapter);
@@ -6388,39 +7938,66 @@ static void ixgbe_watchdog_update_link(struct ixgbe_adapter *adapter)
 
 	adapter->link_up = link_up;
 	adapter->link_speed = link_speed;
+	if (hw->mac.ops.dmac_config && hw->mac.dmac_config.watchdog_timer) {
+		u8 num_tcs = netdev_get_num_tc(adapter->netdev);
+#if IS_ENABLED(CONFIG_FCOE)
+		u8 fcoe_tc = ixgbe_fcoe_get_tc(adapter);
+		bool fcoe_en = !!(adapter->flags & IXGBE_FLAG_FCOE_ENABLED);
+#endif /* CONFIG_FCOE */
+
+		if (hw->mac.dmac_config.link_speed != link_speed ||
+#if IS_ENABLED(CONFIG_FCOE)
+		    hw->mac.dmac_config.fcoe_tc != fcoe_tc ||
+		    hw->mac.dmac_config.fcoe_en != fcoe_en ||
+#endif /* CONFIG_FCOE */
+		    hw->mac.dmac_config.num_tcs != num_tcs) {
+			hw->mac.dmac_config.link_speed = link_speed;
+			hw->mac.dmac_config.num_tcs = num_tcs;
+#if IS_ENABLED(CONFIG_FCOE)
+			hw->mac.dmac_config.fcoe_en = fcoe_en;
+			hw->mac.dmac_config.fcoe_tc = fcoe_tc;
+#endif /* CONFIG_FCOE */
+			hw->mac.ops.dmac_config(hw);
+		}
+	}
 }
 
 static void ixgbe_update_default_up(struct ixgbe_adapter *adapter)
 {
-#ifdef CONFIG_IXGBE_DCB
+	u8 up = 0;
+#ifdef HAVE_DCBNL_IEEE
 	struct net_device *netdev = adapter->netdev;
 	struct dcb_app app = {
-			      .selector = IEEE_8021QAZ_APP_SEL_ETHERTYPE,
+			      .selector = DCB_APP_IDTYPE_ETHTYPE,
 			      .protocol = 0,
 			     };
-	u8 up = 0;
-
-	if (adapter->dcbx_cap & DCB_CAP_DCBX_VER_IEEE)
-		up = dcb_ieee_getapp_mask(netdev, &app);
+	up = dcb_getapp(netdev, &app);
+#endif
 
+#if IS_ENABLED(CONFIG_FCOE)
 	adapter->default_up = (up > 1) ? (ffs(up) - 1) : 0;
+#else
+	adapter->default_up = up;
 #endif
 }
 
 /**
  * ixgbe_watchdog_link_is_up - update netif_carrier status and
  *                             print link up message
- * @adapter: pointer to the device adapter structure
+ * @adapter - pointer to the device adapter structure
  **/
 static void ixgbe_watchdog_link_is_up(struct ixgbe_adapter *adapter)
 {
 	struct net_device *netdev = adapter->netdev;
 	struct ixgbe_hw *hw = &adapter->hw;
-	struct net_device *upper;
-	struct list_head *iter;
 	u32 link_speed = adapter->link_speed;
 	const char *speed_str;
 	bool flow_rx, flow_tx;
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	int speed = 0;
+	int duplex = -1;
+	int new_state = 0;
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
 
 	/* only continue if link was previously down */
 	if (netif_carrier_ok(netdev))
@@ -6436,10 +8013,11 @@ static void ixgbe_watchdog_link_is_up(struct ixgbe_adapter *adapter)
 		flow_tx = !!(rmcs & IXGBE_RMCS_TFCE_802_3X);
 	}
 		break;
-	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
-	case ixgbe_mac_82599EB: {
+	case ixgbe_mac_X550EM_a:
+	case ixgbe_mac_82599EB:
+	case ixgbe_mac_X540: {
 		u32 mflcn = IXGBE_READ_REG(hw, IXGBE_MFLCN);
 		u32 fccfg = IXGBE_READ_REG(hw, IXGBE_FCCFG);
 		flow_rx = !!(mflcn & IXGBE_MFLCN_RFCE);
@@ -6452,15 +8030,20 @@ static void ixgbe_watchdog_link_is_up(struct ixgbe_adapter *adapter)
 		break;
 	}
 
+#ifdef HAVE_PTP_1588_CLOCK
 	adapter->last_rx_ptp_check = jiffies;
 
 	if (test_bit(__IXGBE_PTP_RUNNING, &adapter->state))
 		ixgbe_ptp_start_cyclecounter(adapter);
 
+#endif
 	switch (link_speed) {
 	case IXGBE_LINK_SPEED_10GB_FULL:
 		speed_str = "10 Gbps";
 		break;
+	case IXGBE_LINK_SPEED_5GB_FULL:
+		speed_str = "5 Gbps";
+		break;
 	case IXGBE_LINK_SPEED_2_5GB_FULL:
 		speed_str = "2.5 Gbps";
 		break;
@@ -6470,6 +8053,9 @@ static void ixgbe_watchdog_link_is_up(struct ixgbe_adapter *adapter)
 	case IXGBE_LINK_SPEED_100_FULL:
 		speed_str = "100 Mbps";
 		break;
+	case IXGBE_LINK_SPEED_10_FULL:
+		speed_str = "10 Mbps";
+		break;
 	default:
 		speed_str = "unknown speed";
 		break;
@@ -6480,59 +8066,133 @@ static void ixgbe_watchdog_link_is_up(struct ixgbe_adapter *adapter)
 	       (flow_tx ? "TX" : "None"))));
 
 	netif_carrier_on(netdev);
+#ifdef IFLA_VF_MAX
 	ixgbe_check_vf_rate_limit(adapter);
+#endif /* IFLA_VF_MAX */
+	/* Turn on malicious driver detection */
+	if ((adapter->num_vfs) && (hw->mac.ops.enable_mdd) &&
+		(adapter->flags & IXGBE_FLAG_MDD_ENABLED))
+		hw->mac.ops.enable_mdd(hw);
 
-	/* enable transmits */
-	netif_tx_wake_all_queues(adapter->netdev);
-
-	/* enable any upper devices */
-	rtnl_lock();
-	netdev_for_each_all_upper_dev_rcu(adapter->netdev, upper, iter) {
-		if (netif_is_macvlan(upper)) {
-			struct macvlan_dev *vlan = netdev_priv(upper);
-
-			if (vlan->fwd_priv)
-				netif_tx_wake_all_queues(upper);
-		}
-	}
-	rtnl_unlock();
+	netif_tx_wake_all_queues(netdev);
 
 	/* update the default user priority for VFs */
 	ixgbe_update_default_up(adapter);
 
 	/* ping all the active vfs to let them know link has changed */
 	ixgbe_ping_all_vfs(adapter);
+
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	switch (link_speed) {
+	case IXGBE_LINK_SPEED_10GB_FULL:
+		speed = 10000;
+		duplex = 1;
+		break;
+	case IXGBE_LINK_SPEED_5GB_FULL:
+		speed = 5000;
+		duplex = 1;
+		break;
+	case IXGBE_LINK_SPEED_2_5GB_FULL:
+		speed = 2500;
+		duplex = 1;
+		break;
+	case IXGBE_LINK_SPEED_1GB_FULL:
+		speed = 1000;
+		duplex = 1;
+		break;
+	case IXGBE_LINK_SPEED_100_FULL:
+		speed = 100;
+		duplex = 1;
+		break;
+	case IXGBE_LINK_SPEED_10_FULL:
+		speed = 10;
+		duplex = 1;
+		break;
+	default:
+		speed = 0;
+		duplex = 1;
+		break;
+	}
+	/* issue event when link-down count was expired */
+	new_state += (adapter->state_cache.link != 1);
+	new_state += (adapter->state_cache.speed != speed);
+	adapter->state_cache.link = 1;
+	adapter->state_cache.down_tv = 0;
+	adapter->state_cache.speed = speed;
+	if (new_state) {
+		kernevnt_LanAct_params(netdev->name, speed, duplex);
+	}
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
 }
 
 /**
  * ixgbe_watchdog_link_is_down - update netif_carrier status and
  *                               print link down message
- * @adapter: pointer to the adapter structure
+ * @adapter - pointer to the adapter structure
  **/
 static void ixgbe_watchdog_link_is_down(struct ixgbe_adapter *adapter)
 {
 	struct net_device *netdev = adapter->netdev;
 	struct ixgbe_hw *hw = &adapter->hw;
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	int new_state = 0;
+	unsigned int max_linkdown = max(ixgbe_phy_deferred_linkdown, 1);
+	struct timespec ts;
+	unsigned long now;
+
+	ktime_get_ts(&ts);
+	now = (unsigned long)ts.tv_sec;
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
 
 	adapter->link_up = false;
 	adapter->link_speed = 0;
 
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	/* prepare for called just after initialization */
+	if (adapter->state_cache.down_tv == ~0UL || max_linkdown <= 1) {
+		adapter->state_cache.down_tv = now - max_linkdown;
+	} else if (netif_carrier_ok(netdev)) {
+		adapter->state_cache.down_tv = now;
+	}
+
+	/* issue event only when link-down count was overflow */
+	if (now >= (adapter->state_cache.down_tv + max_linkdown)) {
+		new_state += (adapter->state_cache.link != 0);
+		adapter->state_cache.link = 0;
+	}
+	/* only continue if link was up previously */
+	if (!netif_carrier_ok(netdev)) {
+		if (new_state) {
+			kernevnt_LanAct_params(netdev->name, 0, 1);
+		}
+		return;
+	}
+#else /* CONFIG_BUFFALO_USE_KERNEVNT */
 	/* only continue if link was up previously */
 	if (!netif_carrier_ok(netdev))
 		return;
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
 
 	/* poll for SFP+ cable when link is down */
 	if (ixgbe_is_sfp(hw) && hw->mac.type == ixgbe_mac_82598EB)
 		adapter->flags2 |= IXGBE_FLAG2_SEARCH_FOR_SFP;
 
+#ifdef HAVE_PTP_1588_CLOCK
 	if (test_bit(__IXGBE_PTP_RUNNING, &adapter->state))
 		ixgbe_ptp_start_cyclecounter(adapter);
 
+#endif
 	e_info(drv, "NIC Link is Down\n");
 	netif_carrier_off(netdev);
+	netif_tx_stop_all_queues(netdev);
 
 	/* ping all the active vfs to let them know link has changed */
 	ixgbe_ping_all_vfs(adapter);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	if (new_state) {
+		kernevnt_LanAct_params(netdev->name, 0, 1);
+	}
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
 }
 
 static bool ixgbe_ring_tx_pending(struct ixgbe_adapter *adapter)
@@ -6560,16 +8220,15 @@ static bool ixgbe_vf_tx_pending(struct ixgbe_adapter *adapter)
 	if (!adapter->num_vfs)
 		return false;
 
-	/* resetting the PF is only needed for MAC before X550 */
+	/* resetting the PF is only needed for MACs < X550 */
 	if (hw->mac.type >= ixgbe_mac_X550)
 		return false;
-
 	for (i = 0; i < adapter->num_vfs; i++) {
 		for (j = 0; j < q_per_pool; j++) {
 			u32 h, t;
 
-			h = IXGBE_READ_REG(hw, IXGBE_PVFTDHN(q_per_pool, i, j));
-			t = IXGBE_READ_REG(hw, IXGBE_PVFTDTN(q_per_pool, i, j));
+			h = IXGBE_READ_REG(hw, IXGBE_PVFTDHn(q_per_pool, i, j));
+			t = IXGBE_READ_REG(hw, IXGBE_PVFTDTn(q_per_pool, i, j));
 
 			if (h != t)
 				return true;
@@ -6581,7 +8240,7 @@ static bool ixgbe_vf_tx_pending(struct ixgbe_adapter *adapter)
 
 /**
  * ixgbe_watchdog_flush_tx - flush queues on link down
- * @adapter: pointer to the device adapter structure
+ * @adapter - pointer to the device adapter structure
  **/
 static void ixgbe_watchdog_flush_tx(struct ixgbe_adapter *adapter)
 {
@@ -6593,8 +8252,8 @@ static void ixgbe_watchdog_flush_tx(struct ixgbe_adapter *adapter)
 			 * to get done, so reset controller to flush Tx.
 			 * (Do the reset outside of interrupt context).
 			 */
-			e_warn(drv, "initiating reset to clear Tx work after link loss\n");
-			adapter->flags2 |= IXGBE_FLAG2_RESET_REQUESTED;
+			e_warn(drv, "initiating reset due to lost link with pending Tx work\n");
+			set_bit(__IXGBE_RESET_REQUESTED, &adapter->state);
 		}
 	}
 }
@@ -6603,12 +8262,29 @@ static void ixgbe_watchdog_flush_tx(struct ixgbe_adapter *adapter)
 static inline void ixgbe_issue_vf_flr(struct ixgbe_adapter *adapter,
 				      struct pci_dev *vfdev)
 {
-	if (!pci_wait_for_pending_transaction(vfdev))
-		e_dev_warn("Issuing VFLR with pending transactions\n");
+	int pos, i;
+	u16 status;
 
-	e_dev_err("Issuing VFLR for VF %s\n", pci_name(vfdev));
-	pcie_capability_set_word(vfdev, PCI_EXP_DEVCTL, PCI_EXP_DEVCTL_BCR_FLR);
+	/* wait for pending transactions on the bus */
+	for (i = 0; i < 4; i++) {
+		if (i)
+			msleep((1 << (i - 1)) * 100);
+
+		pcie_capability_read_word(vfdev, PCI_EXP_DEVSTA, &status);
+		if (!(status & PCI_EXP_DEVSTA_TRPND))
+			goto clear;
+	}
+
+	e_dev_warn("Issuing VFLR with pending transactions\n");
 
+clear:
+	pos = pci_find_capability(vfdev, PCI_CAP_ID_EXP);
+	if (!pos)
+		return;
+
+	e_dev_err("Issuing VFLR for VF %s\n", pci_name(vfdev));
+	pci_write_config_word(vfdev, pos + PCI_EXP_DEVCTL,
+			      PCI_EXP_DEVCTL_BCR_FLR);
 	msleep(100);
 }
 
@@ -6616,10 +8292,8 @@ static void ixgbe_check_for_bad_vf(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	struct pci_dev *pdev = adapter->pdev;
-	struct pci_dev *vfdev;
+	unsigned int vf;
 	u32 gpc;
-	int pos;
-	unsigned short vf_id;
 
 	if (!(netif_carrier_ok(adapter->netdev)))
 		return;
@@ -6627,7 +8301,8 @@ static void ixgbe_check_for_bad_vf(struct ixgbe_adapter *adapter)
 	gpc = IXGBE_READ_REG(hw, IXGBE_TXDGPC);
 	if (gpc) /* If incrementing then no need for the check below */
 		return;
-	/* Check to see if a bad DMA write target from an errant or
+	/*
+	 * Check to see if a bad DMA write target from an errant or
 	 * malicious VF has caused a PCIe error.  If so then we can
 	 * issue a VFLR to the offending VF(s) and then resume without
 	 * requesting a full slot reset.
@@ -6636,26 +8311,17 @@ static void ixgbe_check_for_bad_vf(struct ixgbe_adapter *adapter)
 	if (!pdev)
 		return;
 
-	pos = pci_find_ext_capability(pdev, PCI_EXT_CAP_ID_SRIOV);
-	if (!pos)
-		return;
-
-	/* get the device ID for the VF */
-	pci_read_config_word(pdev, pos + PCI_SRIOV_VF_DID, &vf_id);
-
 	/* check status reg for all VFs owned by this PF */
-	vfdev = pci_get_device(pdev->vendor, vf_id, NULL);
-	while (vfdev) {
-		if (vfdev->is_virtfn && (vfdev->physfn == pdev)) {
-			u16 status_reg;
-
-			pci_read_config_word(vfdev, PCI_STATUS, &status_reg);
-			if (status_reg & PCI_STATUS_REC_MASTER_ABORT)
-				/* issue VFLR */
-				ixgbe_issue_vf_flr(adapter, vfdev);
-		}
+	for (vf = 0; vf < adapter->num_vfs; ++vf) {
+		struct pci_dev *vfdev = adapter->vfinfo[vf].vfdev;
+		u16 status_reg;
 
-		vfdev = pci_get_device(pdev->vendor, vf_id, vfdev);
+		if (!vfdev)
+			continue;
+		pci_read_config_word(vfdev, PCI_STATUS, &status_reg);
+		if (status_reg != IXGBE_FAILED_READ_CFG_WORD &&
+		    status_reg & PCI_STATUS_REC_MASTER_ABORT)
+			ixgbe_issue_vf_flr(adapter, vfdev);
 	}
 }
 
@@ -6677,29 +8343,20 @@ static void ixgbe_spoof_check(struct ixgbe_adapter *adapter)
 	if (!ssvpc)
 		return;
 
-	e_warn(drv, "%u Spoofed packets detected\n", ssvpc);
-}
-#else
-static void ixgbe_spoof_check(struct ixgbe_adapter __always_unused *adapter)
-{
+	e_warn(drv, "%d Spoofed packets detected\n", ssvpc);
 }
 
-static void
-ixgbe_check_for_bad_vf(struct ixgbe_adapter __always_unused *adapter)
-{
-}
 #endif /* CONFIG_PCI_IOV */
 
-
 /**
  * ixgbe_watchdog_subtask - check and bring link up
- * @adapter: pointer to the device adapter structure
+ * @adapter - pointer to the device adapter structure
  **/
 static void ixgbe_watchdog_subtask(struct ixgbe_adapter *adapter)
 {
-	/* if interface is down, removing or resetting, do nothing */
+	/* if interface is down do nothing */
 	if (test_bit(__IXGBE_DOWN, &adapter->state) ||
-	    test_bit(__IXGBE_REMOVING, &adapter->state) ||
+	    test_bit(__IXGBE_REMOVE, &adapter->state) ||
 	    test_bit(__IXGBE_RESETTING, &adapter->state))
 		return;
 
@@ -6709,9 +8366,10 @@ static void ixgbe_watchdog_subtask(struct ixgbe_adapter *adapter)
 		ixgbe_watchdog_link_is_up(adapter);
 	else
 		ixgbe_watchdog_link_is_down(adapter);
-
-	ixgbe_check_for_bad_vf(adapter);
+#ifdef CONFIG_PCI_IOV
 	ixgbe_spoof_check(adapter);
+	ixgbe_check_for_bad_vf(adapter);
+#endif /* CONFIG_PCI_IOV */
 	ixgbe_update_stats(adapter);
 
 	ixgbe_watchdog_flush_tx(adapter);
@@ -6719,13 +8377,36 @@ static void ixgbe_watchdog_subtask(struct ixgbe_adapter *adapter)
 
 /**
  * ixgbe_sfp_detection_subtask - poll for SFP+ cable
- * @adapter: the ixgbe adapter structure
+ * @adapter - the ixgbe adapter structure
  **/
 static void ixgbe_sfp_detection_subtask(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	s32 err;
 
+	/* If crosstalk fix enabled verify the SFP+ cage is full */
+	if (adapter->need_crosstalk_fix) {
+		u32 sfp_cage_full;
+
+		switch (hw->mac.type) {
+		case ixgbe_mac_82599EB:
+			sfp_cage_full = IXGBE_READ_REG(hw, IXGBE_ESDP) &
+					IXGBE_ESDP_SDP2;
+			break;
+		case ixgbe_mac_X550EM_x:
+		case ixgbe_mac_X550EM_a:
+			sfp_cage_full = IXGBE_READ_REG(hw, IXGBE_ESDP) &
+					IXGBE_ESDP_SDP0;
+			break;
+		default:
+			/* Non-SFP+ system - sanity check */
+			sfp_cage_full = false;
+			break;
+		}
+		if (!sfp_cage_full)
+			return;
+	}
+
 	/* not searching for SFP so there is nothing to do here */
 	if (!(adapter->flags2 & IXGBE_FLAG2_SEARCH_FOR_SFP) &&
 	    !(adapter->flags2 & IXGBE_FLAG2_SFP_NEEDS_RESET))
@@ -6733,7 +8414,7 @@ static void ixgbe_sfp_detection_subtask(struct ixgbe_adapter *adapter)
 
 	if (adapter->sfp_poll_time &&
 	    time_after(adapter->sfp_poll_time, jiffies))
-		return; /* If not yet time to poll for SFP */
+		return;	/* If not yet time to poll for SFP */
 
 	/* someone else is in init, wait until next service event */
 	if (test_and_set_bit(__IXGBE_IN_SFP_INIT, &adapter->state))
@@ -6781,23 +8462,25 @@ sfp_out:
 	clear_bit(__IXGBE_IN_SFP_INIT, &adapter->state);
 
 	if ((err == IXGBE_ERR_SFP_NOT_SUPPORTED) &&
-	    (adapter->netdev->reg_state == NETREG_REGISTERED)) {
+	    adapter->netdev_registered) {
 		e_dev_err("failed to initialize because an unsupported "
 			  "SFP+ module type was detected.\n");
 		e_dev_err("Reload the driver after installing a "
 			  "supported module.\n");
 		unregister_netdev(adapter->netdev);
+		adapter->netdev_registered = false;
 	}
 }
 
 /**
  * ixgbe_sfp_link_config_subtask - set up link SFP after module install
- * @adapter: the ixgbe adapter structure
+ * @adapter - the ixgbe adapter structure
  **/
 static void ixgbe_sfp_link_config_subtask(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
-	u32 speed;
+	u32 cap_speed;
+	u32 speed = 0;
 	bool autoneg = false;
 
 	if (!(adapter->flags & IXGBE_FLAG_NEED_LINK_CONFIG))
@@ -6809,15 +8492,16 @@ static void ixgbe_sfp_link_config_subtask(struct ixgbe_adapter *adapter)
 
 	adapter->flags &= ~IXGBE_FLAG_NEED_LINK_CONFIG;
 
-	speed = hw->phy.autoneg_advertised;
-	if ((!speed) && (hw->mac.ops.get_link_capabilities)) {
-		hw->mac.ops.get_link_capabilities(hw, &speed, &autoneg);
+	hw->mac.ops.get_link_capabilities(hw, &cap_speed, &autoneg);
 
-		/* setup the highest link when no autoneg */
-		if (!autoneg) {
-			if (speed & IXGBE_LINK_SPEED_10GB_FULL)
-				speed = IXGBE_LINK_SPEED_10GB_FULL;
-		}
+	/* Advertise highest capable link speed */
+	if (cap_speed & IXGBE_LINK_SPEED_10GB_FULL) {
+		if (!autoneg)
+			speed = IXGBE_LINK_SPEED_10GB_FULL;
+		else
+			speed = cap_speed;
+	} else if (cap_speed == IXGBE_LINK_SPEED_1GB_FULL) {
+		speed = IXGBE_LINK_SPEED_1GB_FULL;
 	}
 
 	if (hw->mac.ops.setup_link)
@@ -6851,38 +8535,28 @@ static void ixgbe_service_timer(unsigned long data)
 
 static void ixgbe_phy_interrupt_subtask(struct ixgbe_adapter *adapter)
 {
-	struct ixgbe_hw *hw = &adapter->hw;
 	u32 status;
 
 	if (!(adapter->flags2 & IXGBE_FLAG2_PHY_INTERRUPT))
 		return;
-
 	adapter->flags2 &= ~IXGBE_FLAG2_PHY_INTERRUPT;
-
-	if (!hw->phy.ops.handle_lasi)
-		return;
-
-	status = hw->phy.ops.handle_lasi(&adapter->hw);
+	status = ixgbe_handle_lasi(&adapter->hw);
 	if (status != IXGBE_ERR_OVERTEMP)
 		return;
-
 	e_crit(drv, "%s\n", ixgbe_overheat_msg);
 }
 
 static void ixgbe_reset_subtask(struct ixgbe_adapter *adapter)
 {
-	if (!(adapter->flags2 & IXGBE_FLAG2_RESET_REQUESTED))
+	if (!test_and_clear_bit(__IXGBE_RESET_REQUESTED, &adapter->state))
 		return;
 
-	adapter->flags2 &= ~IXGBE_FLAG2_RESET_REQUESTED;
-
-	/* If we're already down, removing or resetting, just bail */
+	/* If we're already down or resetting, just bail */
 	if (test_bit(__IXGBE_DOWN, &adapter->state) ||
-	    test_bit(__IXGBE_REMOVING, &adapter->state) ||
+	    test_bit(__IXGBE_REMOVE, &adapter->state) ||
 	    test_bit(__IXGBE_RESETTING, &adapter->state))
 		return;
 
-	ixgbe_dump(adapter);
 	netdev_err(adapter->netdev, "Reset adapter\n");
 	adapter->tx_timeout_count++;
 
@@ -6900,7 +8574,7 @@ static void ixgbe_service_task(struct work_struct *work)
 	struct ixgbe_adapter *adapter = container_of(work,
 						     struct ixgbe_adapter,
 						     service_task);
-	if (ixgbe_removed(adapter->hw.hw_addr)) {
+	if (IXGBE_REMOVED(adapter->hw.hw_addr)) {
 		if (!test_bit(__IXGBE_DOWN, &adapter->state)) {
 			rtnl_lock();
 			ixgbe_down(adapter);
@@ -6909,25 +8583,36 @@ static void ixgbe_service_task(struct work_struct *work)
 		ixgbe_service_event_complete(adapter);
 		return;
 	}
-#ifdef CONFIG_IXGBE_VXLAN
-	if (adapter->flags2 & IXGBE_FLAG2_VXLAN_REREG_NEEDED) {
-		adapter->flags2 &= ~IXGBE_FLAG2_VXLAN_REREG_NEEDED;
+#if defined(HAVE_UDP_ENC_RX_OFFLOAD) || defined(HAVE_VXLAN_RX_OFFLOAD)
+	if (adapter->flags2 & IXGBE_FLAG2_UDP_TUN_REREG_NEEDED) {
+		rtnl_lock();
+		adapter->flags2 &= ~IXGBE_FLAG2_UDP_TUN_REREG_NEEDED;
+#ifdef HAVE_UDP_ENC_RX_OFFLOAD
+		udp_tunnel_get_rx_info(adapter->netdev);
+#else
 		vxlan_get_rx_port(adapter->netdev);
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD */
+		rtnl_unlock();
 	}
-#endif /* CONFIG_IXGBE_VXLAN */
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD || HAVE_VXLAN_RX_OFFLOAD */
 	ixgbe_reset_subtask(adapter);
 	ixgbe_phy_interrupt_subtask(adapter);
 	ixgbe_sfp_detection_subtask(adapter);
 	ixgbe_sfp_link_config_subtask(adapter);
 	ixgbe_check_overtemp_subtask(adapter);
 	ixgbe_watchdog_subtask(adapter);
+#ifdef HAVE_TX_MQ
 	ixgbe_fdir_reinit_subtask(adapter);
+#endif
 	ixgbe_check_hang_subtask(adapter);
-
+#ifdef HAVE_PTP_1588_CLOCK
 	if (test_bit(__IXGBE_PTP_RUNNING, &adapter->state)) {
 		ixgbe_ptp_overflow_check(adapter);
-		ixgbe_ptp_rx_hang(adapter);
+		if (unlikely(adapter->flags & IXGBE_FLAG_RX_HWTSTAMP_IN_REGISTER))
+			ixgbe_ptp_rx_hang(adapter);
+		ixgbe_ptp_tx_hang(adapter);
 	}
+#endif /* HAVE_PTP_1588_CLOCK */
 
 	ixgbe_service_event_complete(adapter);
 }
@@ -6936,9 +8621,19 @@ static int ixgbe_tso(struct ixgbe_ring *tx_ring,
 		     struct ixgbe_tx_buffer *first,
 		     u8 *hdr_len)
 {
+#ifdef NETIF_F_TSO
+	u32 vlan_macip_lens, type_tucmd, mss_l4len_idx;
 	struct sk_buff *skb = first->skb;
-	u32 vlan_macip_lens, type_tucmd;
-	u32 mss_l4len_idx, l4len;
+	union {
+		struct iphdr *v4;
+		struct ipv6hdr *v6;
+		unsigned char *hdr;
+	} ip;
+	union {
+		struct tcphdr *tcp;
+		unsigned char *hdr;
+	} l4;
+	u32 paylen, l4_offset;
 	int err;
 
 	if (skb->ip_summed != CHECKSUM_PARTIAL)
@@ -6951,52 +8646,74 @@ static int ixgbe_tso(struct ixgbe_ring *tx_ring,
 	if (err < 0)
 		return err;
 
+	ip.hdr = skb_network_header(skb);
+	l4.hdr = skb_checksum_start(skb);
+
 	/* ADV DTYP TUCMD MKRLOC/ISCSIHEDLEN */
 	type_tucmd = IXGBE_ADVTXD_TUCMD_L4T_TCP;
 
-	if (first->protocol == htons(ETH_P_IP)) {
-		struct iphdr *iph = ip_hdr(skb);
-		iph->tot_len = 0;
-		iph->check = 0;
-		tcp_hdr(skb)->check = ~csum_tcpudp_magic(iph->saddr,
-							 iph->daddr, 0,
-							 IPPROTO_TCP,
-							 0);
+	/* initialize outer IP header fields */
+	if (ip.v4->version == 4) {
+		unsigned char *csum_start = skb_checksum_start(skb);
+		unsigned char *trans_start = ip.hdr + (ip.v4->ihl * 4);
+
+		/* IP header will have to cancel out any data that
+		 * is not a part of the outer IP header
+		 */
+		ip.v4->check = csum_fold(csum_partial(trans_start,
+						      csum_start - trans_start,
+						      0));
 		type_tucmd |= IXGBE_ADVTXD_TUCMD_IPV4;
+
+		ip.v4->tot_len = 0;
 		first->tx_flags |= IXGBE_TX_FLAGS_TSO |
 				   IXGBE_TX_FLAGS_CSUM |
 				   IXGBE_TX_FLAGS_IPV4;
-	} else if (skb_is_gso_v6(skb)) {
-		ipv6_hdr(skb)->payload_len = 0;
-		tcp_hdr(skb)->check =
-		    ~csum_ipv6_magic(&ipv6_hdr(skb)->saddr,
-				     &ipv6_hdr(skb)->daddr,
-				     0, IPPROTO_TCP, 0);
+	} else {
+		ip.v6->payload_len = 0;
 		first->tx_flags |= IXGBE_TX_FLAGS_TSO |
 				   IXGBE_TX_FLAGS_CSUM;
 	}
 
-	/* compute header lengths */
-	l4len = tcp_hdrlen(skb);
-	*hdr_len = skb_transport_offset(skb) + l4len;
+	/* determine offset of inner transport header */
+	l4_offset = l4.hdr - skb->data;
+
+	/* compute length of segmentation header */
+	*hdr_len = (l4.tcp->doff * 4) + l4_offset;
+
+	/* remove payload length from inner checksum */
+	paylen = skb->len - l4_offset;
+	csum_replace_by_diff(&l4.tcp->check, htonl(paylen));
 
 	/* update gso size and bytecount with header size */
 	first->gso_segs = skb_shinfo(skb)->gso_segs;
 	first->bytecount += (first->gso_segs - 1) * *hdr_len;
 
 	/* mss_l4len_id: use 0 as index for TSO */
-	mss_l4len_idx = l4len << IXGBE_ADVTXD_L4LEN_SHIFT;
+	mss_l4len_idx = (*hdr_len - l4_offset) << IXGBE_ADVTXD_L4LEN_SHIFT;
 	mss_l4len_idx |= skb_shinfo(skb)->gso_size << IXGBE_ADVTXD_MSS_SHIFT;
 
 	/* vlan_macip_lens: HEADLEN, MACLEN, VLAN tag */
-	vlan_macip_lens = skb_network_header_len(skb);
-	vlan_macip_lens |= skb_network_offset(skb) << IXGBE_ADVTXD_MACLEN_SHIFT;
+	vlan_macip_lens = l4.hdr - ip.hdr;
+	vlan_macip_lens |= (ip.hdr - skb->data) << IXGBE_ADVTXD_MACLEN_SHIFT;
 	vlan_macip_lens |= first->tx_flags & IXGBE_TX_FLAGS_VLAN_MASK;
 
 	ixgbe_tx_ctxtdesc(tx_ring, vlan_macip_lens, 0, type_tucmd,
 			  mss_l4len_idx);
 
 	return 1;
+#else
+	return 0;
+#endif /* NETIF_F_TSO */
+}
+
+static inline bool ixgbe_ipv6_csum_is_sctp(struct sk_buff *skb)
+{
+	unsigned int offset = 0;
+
+	ipv6_find_hdr(skb, &offset, IPPROTO_SCTP, NULL, NULL);
+
+	return offset == skb_checksum_start_offset(skb);
 }
 
 static void ixgbe_tx_csum(struct ixgbe_ring *tx_ring,
@@ -7004,91 +8721,47 @@ static void ixgbe_tx_csum(struct ixgbe_ring *tx_ring,
 {
 	struct sk_buff *skb = first->skb;
 	u32 vlan_macip_lens = 0;
-	u32 mss_l4len_idx = 0;
 	u32 type_tucmd = 0;
 
 	if (skb->ip_summed != CHECKSUM_PARTIAL) {
-		if (!(first->tx_flags & IXGBE_TX_FLAGS_HW_VLAN) &&
-		    !(first->tx_flags & IXGBE_TX_FLAGS_CC))
+csum_failed:
+		if (!(first->tx_flags & (IXGBE_TX_FLAGS_HW_VLAN |
+					 IXGBE_TX_FLAGS_CC)))
 			return;
-		vlan_macip_lens = skb_network_offset(skb) <<
-				  IXGBE_ADVTXD_MACLEN_SHIFT;
-	} else {
-		u8 l4_hdr = 0;
-		union {
-			struct iphdr *ipv4;
-			struct ipv6hdr *ipv6;
-			u8 *raw;
-		} network_hdr;
-		union {
-			struct tcphdr *tcphdr;
-			u8 *raw;
-		} transport_hdr;
-
-		if (skb->encapsulation) {
-			network_hdr.raw = skb_inner_network_header(skb);
-			transport_hdr.raw = skb_inner_transport_header(skb);
-			vlan_macip_lens = skb_inner_network_offset(skb) <<
-					  IXGBE_ADVTXD_MACLEN_SHIFT;
-		} else {
-			network_hdr.raw = skb_network_header(skb);
-			transport_hdr.raw = skb_transport_header(skb);
-			vlan_macip_lens = skb_network_offset(skb) <<
-					  IXGBE_ADVTXD_MACLEN_SHIFT;
-		}
-
-		/* use first 4 bits to determine IP version */
-		switch (network_hdr.ipv4->version) {
-		case IPVERSION:
-			vlan_macip_lens |= transport_hdr.raw - network_hdr.raw;
-			type_tucmd |= IXGBE_ADVTXD_TUCMD_IPV4;
-			l4_hdr = network_hdr.ipv4->protocol;
-			break;
-		case 6:
-			vlan_macip_lens |= transport_hdr.raw - network_hdr.raw;
-			l4_hdr = network_hdr.ipv6->nexthdr;
-			break;
-		default:
-			if (unlikely(net_ratelimit())) {
-				dev_warn(tx_ring->dev,
-					 "partial checksum but version=%d\n",
-					 network_hdr.ipv4->version);
-			}
-		}
+		goto no_csum;
+	}
 
-		switch (l4_hdr) {
-		case IPPROTO_TCP:
-			type_tucmd |= IXGBE_ADVTXD_TUCMD_L4T_TCP;
-			mss_l4len_idx = (transport_hdr.tcphdr->doff * 4) <<
-					IXGBE_ADVTXD_L4LEN_SHIFT;
-			break;
-		case IPPROTO_SCTP:
-			type_tucmd |= IXGBE_ADVTXD_TUCMD_L4T_SCTP;
-			mss_l4len_idx = sizeof(struct sctphdr) <<
-					IXGBE_ADVTXD_L4LEN_SHIFT;
-			break;
-		case IPPROTO_UDP:
-			mss_l4len_idx = sizeof(struct udphdr) <<
-					IXGBE_ADVTXD_L4LEN_SHIFT;
-			break;
-		default:
-			if (unlikely(net_ratelimit())) {
-				dev_warn(tx_ring->dev,
-				 "partial checksum but l4 proto=%x!\n",
-				 l4_hdr);
-			}
+	switch (skb->csum_offset) {
+	case offsetof(struct tcphdr, check):
+		type_tucmd = IXGBE_ADVTXD_TUCMD_L4T_TCP;
+		/* fall through */
+	case offsetof(struct udphdr, check):
+		break;
+	case offsetof(struct sctphdr, checksum):
+		/* validate that this is actually an SCTP request */
+		if (((first->protocol == htons(ETH_P_IP)) &&
+		     (ip_hdr(skb)->protocol == IPPROTO_SCTP)) ||
+		    ((first->protocol == htons(ETH_P_IPV6)) &&
+		     ixgbe_ipv6_csum_is_sctp(skb))) {
+			type_tucmd = IXGBE_ADVTXD_TUCMD_L4T_SCTP;
 			break;
 		}
-
-		/* update TX checksum flag */
-		first->tx_flags |= IXGBE_TX_FLAGS_CSUM;
+		/* fall through */
+	default:
+		skb_checksum_help(skb);
+		goto csum_failed;
 	}
 
+	/* update TX checksum flag */
+	first->tx_flags |= IXGBE_TX_FLAGS_CSUM;
+	vlan_macip_lens = skb_checksum_start_offset(skb) -
+			  skb_network_offset(skb);
+no_csum:
 	/* vlan_macip_lens: MACLEN, VLAN tag */
+	vlan_macip_lens |= skb_network_offset(skb) << IXGBE_ADVTXD_MACLEN_SHIFT;
 	vlan_macip_lens |= first->tx_flags & IXGBE_TX_FLAGS_VLAN_MASK;
 
-	ixgbe_tx_ctxtdesc(tx_ring, vlan_macip_lens, 0,
-			  type_tucmd, mss_l4len_idx);
+	ixgbe_tx_ctxtdesc(tx_ring, vlan_macip_lens, 0, type_tucmd, 0);
 }
 
 #define IXGBE_SET_FLAG(_input, _flag, _result) \
@@ -7096,7 +8769,7 @@ static void ixgbe_tx_csum(struct ixgbe_ring *tx_ring,
 	 ((u32)(_input & _flag) * (_result / _flag)) : \
 	 ((u32)(_input & _flag) / (_flag / _result)))
 
-static u32 ixgbe_tx_cmd_type(struct sk_buff *skb, u32 tx_flags)
+static u32 ixgbe_tx_cmd_type(u32 tx_flags)
 {
 	/* set type for advanced descriptor with frame checksum insertion */
 	u32 cmd_type = IXGBE_ADVTXD_DTYP_DATA |
@@ -7115,9 +8788,6 @@ static u32 ixgbe_tx_cmd_type(struct sk_buff *skb, u32 tx_flags)
 	cmd_type |= IXGBE_SET_FLAG(tx_flags, IXGBE_TX_FLAGS_TSTAMP,
 				   IXGBE_ADVTXD_MAC_TSTAMP);
 
-	/* insert frame checksum */
-	cmd_type ^= IXGBE_SET_FLAG(skb->no_fcs, 1, IXGBE_ADVTXD_DCMD_IFCS);
-
 	return cmd_type;
 }
 
@@ -7180,9 +8850,9 @@ static inline int ixgbe_maybe_stop_tx(struct ixgbe_ring *tx_ring, u16 size)
 #define IXGBE_TXD_CMD (IXGBE_TXD_CMD_EOP | \
 		       IXGBE_TXD_CMD_RS)
 
-static void ixgbe_tx_map(struct ixgbe_ring *tx_ring,
-			 struct ixgbe_tx_buffer *first,
-			 const u8 hdr_len)
+static int ixgbe_tx_map(struct ixgbe_ring *tx_ring,
+			struct ixgbe_tx_buffer *first,
+			const u8 hdr_len)
 {
 	struct sk_buff *skb = first->skb;
 	struct ixgbe_tx_buffer *tx_buffer;
@@ -7191,7 +8861,7 @@ static void ixgbe_tx_map(struct ixgbe_ring *tx_ring,
 	dma_addr_t dma;
 	unsigned int data_len, size;
 	u32 tx_flags = first->tx_flags;
-	u32 cmd_type = ixgbe_tx_cmd_type(skb, tx_flags);
+	u32 cmd_type = ixgbe_tx_cmd_type(tx_flags);
 	u16 i = tx_ring->next_to_use;
 
 	tx_desc = IXGBE_TX_DESC(tx_ring, i);
@@ -7201,7 +8871,7 @@ static void ixgbe_tx_map(struct ixgbe_ring *tx_ring,
 	size = skb_headlen(skb);
 	data_len = skb->data_len;
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	if (tx_flags & IXGBE_TX_FLAGS_FCOE) {
 		if (data_len < sizeof(struct fcoe_crc_eof)) {
 			size -= sizeof(struct fcoe_crc_eof) - data_len;
@@ -7210,8 +8880,8 @@ static void ixgbe_tx_map(struct ixgbe_ring *tx_ring,
 			data_len -= sizeof(struct fcoe_crc_eof);
 		}
 	}
+#endif /* CONFIG_FCOE */
 
-#endif
 	dma = dma_map_single(tx_ring->dev, skb->data, size, DMA_TO_DEVICE);
 
 	tx_buffer = first;
@@ -7257,7 +8927,7 @@ static void ixgbe_tx_map(struct ixgbe_ring *tx_ring,
 		}
 		tx_desc->read.olinfo_status = 0;
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 		size = min_t(unsigned int, data_len, skb_frag_size(frag));
 #else
 		size = skb_frag_size(frag);
@@ -7279,6 +8949,9 @@ static void ixgbe_tx_map(struct ixgbe_ring *tx_ring,
 	/* set the timestamp */
 	first->time_stamp = jiffies;
 
+#ifndef HAVE_TRANS_START_IN_QUEUE
+	netdev_ring(tx_ring)->trans_start = first->time_stamp;
+#endif
 	/*
 	 * Force memory writes to complete before letting h/w know there
 	 * are new descriptors to fetch.  (Only applicable for weak-ordered
@@ -7300,6 +8973,7 @@ static void ixgbe_tx_map(struct ixgbe_ring *tx_ring,
 
 	ixgbe_maybe_stop_tx(tx_ring, DESC_NEEDED);
 
+#ifdef HAVE_SKB_XMIT_MORE
 	if (netif_xmit_stopped(txring_txq(tx_ring)) || !skb->xmit_more) {
 		writel(i, tx_ring->tail);
 
@@ -7308,23 +8982,42 @@ static void ixgbe_tx_map(struct ixgbe_ring *tx_ring,
 		 */
 		mmiowb();
 	}
+#else
+	/* notify HW of packet */
+	writel(i, tx_ring->tail);
 
-	return;
+	/* we need this if more than one processor can write to our tail
+	 * at a time, it synchronizes IO on IA64/Altix systems
+	 */
+	mmiowb();
+#endif /* HAVE_SKB_XMIT_MORE */
+
+	return 0;
 dma_error:
 	dev_err(tx_ring->dev, "TX DMA map failed\n");
 
 	/* clear dma mappings for failed tx_buffer_info map */
 	for (;;) {
 		tx_buffer = &tx_ring->tx_buffer_info[i];
-		ixgbe_unmap_and_free_tx_resource(tx_ring, tx_buffer);
+		if (dma_unmap_len(tx_buffer, len))
+			dma_unmap_page(tx_ring->dev,
+				       dma_unmap_addr(tx_buffer, dma),
+				       dma_unmap_len(tx_buffer, len),
+				       DMA_TO_DEVICE);
+		dma_unmap_len_set(tx_buffer, len, 0);
 		if (tx_buffer == first)
 			break;
 		if (i == 0)
-			i = tx_ring->count;
+			i += tx_ring->count;
 		i--;
 	}
 
+	dev_kfree_skb_any(first->skb);
+	first->skb = NULL;
+
 	tx_ring->next_to_use = i;
+
+	return -1;
 }
 
 static void ixgbe_atr(struct ixgbe_ring *ring,
@@ -7340,10 +9033,9 @@ static void ixgbe_atr(struct ixgbe_ring *ring,
 	} hdr;
 	struct tcphdr *th;
 	struct sk_buff *skb;
-#ifdef CONFIG_IXGBE_VXLAN
-	u8 encap = false;
-#endif /* CONFIG_IXGBE_VXLAN */
+	unsigned int hlen;
 	__be16 vlan_id;
+	int l4_proto;
 
 	/* if ring doesn't have a interrupt vector, cannot perform ATR */
 	if (!q_vector)
@@ -7355,40 +9047,74 @@ static void ixgbe_atr(struct ixgbe_ring *ring,
 
 	ring->atr_count++;
 
+	/* currently only IPv4/IPv6 with TCP is supported */
+	if (first->protocol != htons(ETH_P_IP) &&
+	    first->protocol != htons(ETH_P_IPV6))
+		return;
+
 	/* snag network header to get L4 type and address */
 	skb = first->skb;
 	hdr.network = skb_network_header(skb);
-	if (skb->encapsulation) {
-#ifdef CONFIG_IXGBE_VXLAN
+
+#if defined(HAVE_UDP_ENC_RX_OFFLOAD) || defined(HAVE_VXLAN_RX_OFFLOAD)
+	if (unlikely(hdr.network <= skb->data))
+		return;
+
+	if (skb->encapsulation &&
+	    first->protocol == htons(ETH_P_IP) &&
+	    hdr.ipv4->protocol == IPPROTO_UDP) {
 		struct ixgbe_adapter *adapter = q_vector->adapter;
 
-		if (!adapter->vxlan_port)
-			return;
-		if (first->protocol != htons(ETH_P_IP) ||
-		    hdr.ipv4->version != IPVERSION ||
-		    hdr.ipv4->protocol != IPPROTO_UDP) {
+		if (unlikely(skb_tail_pointer(skb) < hdr.network +
+			     VXLAN_HEADROOM))
 			return;
-		}
-		if (ntohs(udp_hdr(skb)->dest) != adapter->vxlan_port)
-			return;
-		encap = true;
-		hdr.network = skb_inner_network_header(skb);
-		th = inner_tcp_hdr(skb);
-#else
+
+		/* verify the port is recognized as VXLAN or GENEVE*/
+		if (adapter->vxlan_port &&
+		    udp_hdr(skb)->dest == adapter->vxlan_port)
+			hdr.network = skb_inner_network_header(skb);
+
+#ifdef HAVE_UDP_ENC_RX_OFFLOAD
+		if (adapter->geneve_port &&
+		    udp_hdr(skb)->dest == adapter->geneve_port)
+			hdr.network = skb_inner_network_header(skb);
+#endif
+	}
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD || HAVE_VXLAN_RX_OFFLOAD */
+
+	/* Make sure we have at least [minimum IPv4 header + TCP]
+	 * or [IPv6 header] bytes
+	 */
+	if (unlikely(skb_tail_pointer(skb) < hdr.network + 40))
+		return;
+
+	/* Currently only IPv4/IPv6 with TCP is supported */
+	switch (hdr.ipv4->version) {
+	case IPVERSION:
+		/* access ihl as u8 to avoid unaligned access on ia64 */
+		hlen = (hdr.network[0] & 0x0F) << 2;
+		l4_proto = hdr.ipv4->protocol;
+		break;
+	case 6:
+		hlen = hdr.network - skb->data;
+		l4_proto = ipv6_find_hdr(skb, &hlen, IPPROTO_TCP, NULL, NULL);
+		hlen -= hdr.network - skb->data;
+		break;
+	default:
 		return;
-#endif /* CONFIG_IXGBE_VXLAN */
-	} else {
-		/* Currently only IPv4/IPv6 with TCP is supported */
-		if ((first->protocol != htons(ETH_P_IPV6) ||
-		     hdr.ipv6->nexthdr != IPPROTO_TCP) &&
-		    (first->protocol != htons(ETH_P_IP) ||
-		     hdr.ipv4->protocol != IPPROTO_TCP))
-			return;
-		th = tcp_hdr(skb);
 	}
 
-	/* skip this packet since it is invalid or the socket is closing */
-	if (!th || th->fin)
+	if (l4_proto != IPPROTO_TCP)
+		return;
+
+	if (unlikely(skb_tail_pointer(skb) < hdr.network +
+		     hlen + sizeof(struct tcphdr)))
+		return;
+
+	th = (struct tcphdr *)(hdr.network + hlen);
+
+	/* skip this packet since the socket is closing */
+	if (th->fin)
 		return;
 
 	/* sample on all syn packets or once every atr sample count */
@@ -7419,10 +9145,12 @@ static void ixgbe_atr(struct ixgbe_ring *ring,
 		common.port.src ^= th->dest ^ first->protocol;
 	common.port.dst ^= th->source;
 
-	if (first->protocol == htons(ETH_P_IP)) {
+	switch (hdr.ipv4->version) {
+	case IPVERSION:
 		input.formatted.flow_type = IXGBE_ATR_FLOW_TYPE_TCPV4;
 		common.ip ^= hdr.ipv4->saddr ^ hdr.ipv4->daddr;
-	} else {
+		break;
+	case 6:
 		input.formatted.flow_type = IXGBE_ATR_FLOW_TYPE_TCPV6;
 		common.ip ^= hdr.ipv6->saddr.s6_addr32[0] ^
 			     hdr.ipv6->saddr.s6_addr32[1] ^
@@ -7432,46 +9160,56 @@ static void ixgbe_atr(struct ixgbe_ring *ring,
 			     hdr.ipv6->daddr.s6_addr32[1] ^
 			     hdr.ipv6->daddr.s6_addr32[2] ^
 			     hdr.ipv6->daddr.s6_addr32[3];
+		break;
+	default:
+		break;
 	}
 
-#ifdef CONFIG_IXGBE_VXLAN
-	if (encap)
+#if defined(HAVE_UDP_ENC_RX_OFFLOAD) || defined(HAVE_VXLAN_RX_OFFLOAD)
+	if (hdr.network != skb_network_header(skb))
 		input.formatted.flow_type |= IXGBE_ATR_L4TYPE_TUNNEL_MASK;
-#endif /* CONFIG_IXGBE_VXLAN */
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD || HAVE_VXLAN_RX_OFFLOAD */
 
 	/* This assumes the Rx queue and Tx queue are bound to the same CPU */
 	ixgbe_fdir_add_signature_filter_82599(&q_vector->adapter->hw,
 					      input, common, ring->queue_index);
 }
+#ifdef HAVE_NETDEV_SELECT_QUEUE
+#if IS_ENABLED(CONFIG_FCOE)
 
+#if defined(HAVE_NDO_SELECT_QUEUE_ACCEL_FALLBACK)
 static u16 ixgbe_select_queue(struct net_device *dev, struct sk_buff *skb,
-			      void *accel_priv, select_queue_fallback_t fallback)
+			      __always_unused void *accel,
+			      select_queue_fallback_t fallback)
+#elif defined(HAVE_NDO_SELECT_QUEUE_ACCEL)
+static u16 ixgbe_select_queue(struct net_device *dev, struct sk_buff *skb,
+			      __always_unused void *accel)
+#else
+static u16 ixgbe_select_queue(struct net_device *dev, struct sk_buff *skb)
+#endif /* HAVE_NDO_SELECT_QUEUE_ACCEL_FALLBACK */
 {
-	struct ixgbe_fwd_adapter *fwd_adapter = accel_priv;
-#ifdef IXGBE_FCOE
-	struct ixgbe_adapter *adapter;
+	struct ixgbe_adapter *adapter = netdev_priv(dev);
 	struct ixgbe_ring_feature *f;
 	int txq;
-#endif
-
-	if (fwd_adapter)
-		return skb->queue_mapping + fwd_adapter->tx_base_queue;
-
-#ifdef IXGBE_FCOE
 
 	/*
 	 * only execute the code below if protocol is FCoE
 	 * or FIP and we have FCoE enabled on the adapter
 	 */
 	switch (vlan_get_protocol(skb)) {
-	case htons(ETH_P_FCOE):
-	case htons(ETH_P_FIP):
+	case __constant_htons(ETH_P_FCOE):
+	case __constant_htons(ETH_P_FIP):
 		adapter = netdev_priv(dev);
 
 		if (adapter->flags & IXGBE_FLAG_FCOE_ENABLED)
 			break;
+		/* fall through */
 	default:
+#ifdef HAVE_NDO_SELECT_QUEUE_ACCEL_FALLBACK
 		return fallback(dev, skb);
+#else
+		return __netdev_pick_tx(dev, skb);
+#endif
 	}
 
 	f = &adapter->ring_feature[RING_F_FCOE];
@@ -7483,14 +9221,13 @@ static u16 ixgbe_select_queue(struct net_device *dev, struct sk_buff *skb,
 		txq -= f->indices;
 
 	return txq + f->offset;
-#else
-	return fallback(dev, skb);
-#endif
 }
+#endif /* CONFIG_FCOE */
+#endif /* HAVE_NETDEV_SELECT_QUEUE */
 
 netdev_tx_t ixgbe_xmit_frame_ring(struct sk_buff *skb,
-			  struct ixgbe_adapter *adapter,
-			  struct ixgbe_ring *tx_ring)
+				  struct ixgbe_adapter __maybe_unused *adapter,
+				  struct ixgbe_ring *tx_ring)
 {
 	struct ixgbe_tx_buffer *first;
 	int tso;
@@ -7532,47 +9269,70 @@ netdev_tx_t ixgbe_xmit_frame_ring(struct sk_buff *skb,
 		if (!vhdr)
 			goto out_drop;
 
+		protocol = vhdr->h_vlan_encapsulated_proto;
 		tx_flags |= ntohs(vhdr->h_vlan_TCI) <<
 				  IXGBE_TX_FLAGS_VLAN_SHIFT;
 		tx_flags |= IXGBE_TX_FLAGS_SW_VLAN;
 	}
-	protocol = vlan_get_protocol(skb);
 
+	skb_tx_timestamp(skb);
+
+#ifdef HAVE_PTP_1588_CLOCK
+#ifdef SKB_SHARED_TX_IS_UNION
+	if (unlikely(skb_tx(skb)->hardware) &&
+	    adapter->ptp_clock) {
+		if (!test_and_set_bit_lock(__IXGBE_PTP_TX_IN_PROGRESS,
+					   &adapter->state)) {
+			skb_tx(skb)->in_progress = 1;
+#else
 	if (unlikely(skb_shinfo(skb)->tx_flags & SKBTX_HW_TSTAMP) &&
-	    adapter->ptp_clock &&
-	    !test_and_set_bit_lock(__IXGBE_PTP_TX_IN_PROGRESS,
+	    adapter->ptp_clock) {
+		if (!test_and_set_bit_lock(__IXGBE_PTP_TX_IN_PROGRESS,
 				   &adapter->state)) {
-		skb_shinfo(skb)->tx_flags |= SKBTX_IN_PROGRESS;
-		tx_flags |= IXGBE_TX_FLAGS_TSTAMP;
+			skb_shinfo(skb)->tx_flags |= SKBTX_IN_PROGRESS;
+#endif
+			tx_flags |= IXGBE_TX_FLAGS_TSTAMP;
 
-		/* schedule check for Tx timestamp */
-		adapter->ptp_tx_skb = skb_get(skb);
-		adapter->ptp_tx_start = jiffies;
-		schedule_work(&adapter->ptp_tx_work);
+			/* schedule check for Tx timestamp */
+			adapter->ptp_tx_skb = skb_get(skb);
+			adapter->ptp_tx_start = jiffies;
+			schedule_work(&adapter->ptp_tx_work);
+		} else {
+			adapter->tx_hwtstamp_skipped++;
+		}
 	}
 
-	skb_tx_timestamp(skb);
-
+#endif
 #ifdef CONFIG_PCI_IOV
 	/*
 	 * Use the l2switch_enable flag - would be false if the DMA
 	 * Tx switch had been disabled.
 	 */
-	if (adapter->flags & IXGBE_FLAG_SRIOV_ENABLED)
+	if (adapter->flags & IXGBE_FLAG_SRIOV_L2SWITCH_ENABLE)
 		tx_flags |= IXGBE_TX_FLAGS_CC;
 
 #endif
-	/* DCB maps skb priorities 0-7 onto 3 bit PCP of VLAN tag. */
+#ifdef HAVE_TX_MQ
 	if ((adapter->flags & IXGBE_FLAG_DCB_ENABLED) &&
 	    ((tx_flags & (IXGBE_TX_FLAGS_HW_VLAN | IXGBE_TX_FLAGS_SW_VLAN)) ||
 	     (skb->priority != TC_PRIO_CONTROL))) {
 		tx_flags &= ~IXGBE_TX_FLAGS_VLAN_PRIO_MASK;
-		tx_flags |= (skb->priority & 0x7) <<
-					IXGBE_TX_FLAGS_VLAN_PRIO_SHIFT;
+#if IS_ENABLED(CONFIG_FCOE)
+		/* for FCoE with DCB, we force the priority to what
+		 * was specified by the switch */
+		if ((adapter->flags & IXGBE_FLAG_FCOE_ENABLED) &&
+		    ((protocol == htons(ETH_P_FCOE)) ||
+		     (protocol == htons(ETH_P_FIP))))
+			tx_flags |= adapter->fcoe.up <<
+				    IXGBE_TX_FLAGS_VLAN_PRIO_SHIFT;
+		else
+#endif /* CONFIG_FCOE */
+			tx_flags |= skb->priority <<
+				    IXGBE_TX_FLAGS_VLAN_PRIO_SHIFT;
 		if (tx_flags & IXGBE_TX_FLAGS_SW_VLAN) {
 			struct vlan_ethhdr *vhdr;
-
-			if (skb_cow_head(skb, 0))
+			if (skb_header_cloned(skb) &&
+			    pskb_expand_head(skb, 0, 0, GFP_ATOMIC))
 				goto out_drop;
 			vhdr = (struct vlan_ethhdr *)skb->data;
 			vhdr->h_vlan_TCI = htons(tx_flags >>
@@ -7582,11 +9342,12 @@ netdev_tx_t ixgbe_xmit_frame_ring(struct sk_buff *skb,
 		}
 	}
 
+#endif /* HAVE_TX_MQ */
 	/* record initial flags and protocol */
 	first->tx_flags = tx_flags;
 	first->protocol = protocol;
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	/* setup tx offload for FCoE */
 	if ((protocol == htons(ETH_P_FCOE)) &&
 	    (tx_ring->netdev->features & (NETIF_F_FSO | NETIF_F_FCOE_CRC))) {
@@ -7595,9 +9356,25 @@ netdev_tx_t ixgbe_xmit_frame_ring(struct sk_buff *skb,
 			goto out_drop;
 
 		goto xmit_fcoe;
+	} else if (protocol ==  htons(ETH_P_FIP)) {
+		/* FCoE stack has a bug where it does not set the network
+		 * header offset for FIP frames sent resulting into MACLEN
+		 * being set to ZERO in the Tx context descriptor.
+		 * This will cause MDD events when trying to Tx such frames.
+		 */
+		if (!skb_network_offset(skb)) {
+			if (tx_flags & (IXGBE_TX_FLAGS_HW_VLAN |
+			    IXGBE_TX_FLAGS_SW_VLAN))
+				skb_set_network_header(skb,
+						sizeof(struct ethhdr) +
+						sizeof(struct vlan_hdr));
+			else
+				skb_set_network_header(skb,
+						sizeof(struct ethhdr));
+		}
 	}
+#endif /* CONFIG_FCOE */
 
-#endif /* IXGBE_FCOE */
 	tso = ixgbe_tso(tx_ring, first, &hdr_len);
 	if (tso < 0)
 		goto out_drop;
@@ -7608,26 +9385,48 @@ netdev_tx_t ixgbe_xmit_frame_ring(struct sk_buff *skb,
 	if (test_bit(__IXGBE_TX_FDIR_INIT_DONE, &tx_ring->state))
 		ixgbe_atr(tx_ring, first);
 
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 xmit_fcoe:
-#endif /* IXGBE_FCOE */
+#endif /* CONFIG_FCOE */
+#ifdef HAVE_PTP_1588_CLOCK
+	if (ixgbe_tx_map(tx_ring, first, hdr_len))
+		goto cleanup_tx_tstamp;
+#else
 	ixgbe_tx_map(tx_ring, first, hdr_len);
+#endif
 
 	return NETDEV_TX_OK;
 
 out_drop:
 	dev_kfree_skb_any(first->skb);
 	first->skb = NULL;
+#ifdef HAVE_PTP_1588_CLOCK
+cleanup_tx_tstamp:
+	if (unlikely(tx_flags & IXGBE_TX_FLAGS_TSTAMP)) {
+		dev_kfree_skb_any(adapter->ptp_tx_skb);
+		adapter->ptp_tx_skb = NULL;
+		cancel_work_sync(&adapter->ptp_tx_work);
+		clear_bit_unlock(__IXGBE_PTP_TX_IN_PROGRESS, &adapter->state);
+	}
+#endif
 
 	return NETDEV_TX_OK;
 }
 
 static netdev_tx_t __ixgbe_xmit_frame(struct sk_buff *skb,
 				      struct net_device *netdev,
-				      struct ixgbe_ring *ring)
+				      __always_unused struct ixgbe_ring *ring)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	struct ixgbe_ring *tx_ring;
+#ifdef HAVE_TX_MQ
+	unsigned int r_idx = skb->queue_mapping;
+#endif
+
+	if (!netif_carrier_ok(netdev)) {
+		dev_kfree_skb_any(skb);
+		return NETDEV_TX_OK;
+	}
 
 	/*
 	 * The minimum packet size for olinfo paylen is 17 so pad the skb
@@ -7636,8 +9435,13 @@ static netdev_tx_t __ixgbe_xmit_frame(struct sk_buff *skb,
 	if (skb_put_padto(skb, 17))
 		return NETDEV_TX_OK;
 
-	tx_ring = ring ? ring : adapter->tx_ring[skb->queue_mapping];
-
+#ifdef HAVE_TX_MQ
+	if (r_idx >= adapter->num_tx_queues)
+		r_idx = r_idx % adapter->num_tx_queues;
+	tx_ring = adapter->tx_ring[r_idx];
+#else
+	tx_ring = adapter->tx_ring[0];
+#endif
 	return ixgbe_xmit_frame_ring(skb, adapter, tx_ring);
 }
 
@@ -7659,76 +9463,36 @@ static int ixgbe_set_mac(struct net_device *netdev, void *p)
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	struct ixgbe_hw *hw = &adapter->hw;
 	struct sockaddr *addr = p;
-	int ret;
 
 	if (!is_valid_ether_addr(addr->sa_data))
 		return -EADDRNOTAVAIL;
 
-	ixgbe_del_mac_filter(adapter, hw->mac.addr, VMDQ_P(0));
 	memcpy(netdev->dev_addr, addr->sa_data, netdev->addr_len);
 	memcpy(hw->mac.addr, addr->sa_data, netdev->addr_len);
 
-	ret = ixgbe_add_mac_filter(adapter, hw->mac.addr, VMDQ_P(0));
-	return ret > 0 ? 0 : ret;
-}
-
-static int
-ixgbe_mdio_read(struct net_device *netdev, int prtad, int devad, u16 addr)
-{
-	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	struct ixgbe_hw *hw = &adapter->hw;
-	u16 value;
-	int rc;
-
-	if (prtad != hw->phy.mdio.prtad)
-		return -EINVAL;
-	rc = hw->phy.ops.read_reg(hw, addr, devad, &value);
-	if (!rc)
-		rc = value;
-	return rc;
-}
-
-static int ixgbe_mdio_write(struct net_device *netdev, int prtad, int devad,
-			    u16 addr, u16 value)
-{
-	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	struct ixgbe_hw *hw = &adapter->hw;
-
-	if (prtad != hw->phy.mdio.prtad)
-		return -EINVAL;
-	return hw->phy.ops.write_reg(hw, addr, devad, value);
-}
-
-static int ixgbe_ioctl(struct net_device *netdev, struct ifreq *req, int cmd)
-{
-	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	ixgbe_mac_set_default_filter(adapter);
 
-	switch (cmd) {
-	case SIOCSHWTSTAMP:
-		return ixgbe_ptp_set_ts_config(adapter, req);
-	case SIOCGHWTSTAMP:
-		return ixgbe_ptp_get_ts_config(adapter, req);
-	default:
-		return mdio_mii_ioctl(&adapter->hw.phy.mdio, if_mii(req), cmd);
-	}
+	return 0;
 }
 
+#if defined(HAVE_NETDEV_STORAGE_ADDRESS) && defined(NETDEV_HW_ADDR_T_SAN)
 /**
  * ixgbe_add_sanmac_netdev - Add the SAN MAC address to the corresponding
- * netdev->dev_addrs
+ * netdev->dev_addr_list
  * @netdev: network interface device structure
  *
  * Returns non-zero on failure
  **/
 static int ixgbe_add_sanmac_netdev(struct net_device *dev)
 {
-	int err = 0;
+	int err = IXGBE_SUCCESS;
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
 	struct ixgbe_hw *hw = &adapter->hw;
 
 	if (is_valid_ether_addr(hw->mac.san_addr)) {
 		rtnl_lock();
-		err = dev_addr_add(dev, hw->mac.san_addr, NETDEV_HW_ADDR_T_SAN);
+		err = dev_addr_add(dev, hw->mac.san_addr,
+				   NETDEV_HW_ADDR_T_SAN);
 		rtnl_unlock();
 
 		/* update SAN MAC vmdq pool selection */
@@ -7739,14 +9503,14 @@ static int ixgbe_add_sanmac_netdev(struct net_device *dev)
 
 /**
  * ixgbe_del_sanmac_netdev - Removes the SAN MAC address to the corresponding
- * netdev->dev_addrs
+ * netdev->dev_addr_list
  * @netdev: network interface device structure
  *
  * Returns non-zero on failure
  **/
 static int ixgbe_del_sanmac_netdev(struct net_device *dev)
 {
-	int err = 0;
+	int err = IXGBE_SUCCESS;
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
 	struct ixgbe_mac_info *mac = &adapter->hw.mac;
 
@@ -7758,6 +9522,92 @@ static int ixgbe_del_sanmac_netdev(struct net_device *dev)
 	return err;
 }
 
+#endif /* (HAVE_NETDEV_STORAGE_ADDRESS) && defined(NETDEV_HW_ADDR_T_SAN) */
+
+static int ixgbe_mdio_read(struct net_device *netdev, int prtad, int devad,
+			   u16 addr)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	struct ixgbe_hw *hw = &adapter->hw;
+	u16 value;
+	int rc;
+
+	if (prtad != hw->phy.addr)
+		return -EINVAL;
+
+	if (!hw->phy.ops.read_reg)
+		return -EOPNOTSUPP;
+
+	rc = hw->phy.ops.read_reg(hw, addr, devad, &value);
+	if (!rc)
+		rc = value;
+
+	return rc;
+}
+
+static int ixgbe_mdio_write(struct net_device *netdev, int prtad, int devad,
+			    u16 addr, u16 value)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+	struct ixgbe_hw *hw = &adapter->hw;
+
+	if (prtad != hw->phy.addr)
+		return -EINVAL;
+
+	if (!hw->phy.ops.write_reg)
+		return -EOPNOTSUPP;
+
+	return hw->phy.ops.write_reg(hw, addr, devad, value);
+}
+
+static int ixgbe_mii_ioctl(struct net_device *netdev, struct ifreq *ifr,
+			   int cmd)
+{
+	struct mii_ioctl_data *mii = (struct mii_ioctl_data *) &ifr->ifr_data;
+	int prtad, devad, ret;
+
+	prtad = (mii->phy_id & MDIO_PHY_ID_PRTAD) >> 5;
+	devad = (mii->phy_id & MDIO_PHY_ID_DEVAD);
+
+	if (cmd == SIOCGMIIREG) {
+		ret = ixgbe_mdio_read(netdev, prtad, devad, mii->reg_num);
+		if (ret < 0)
+			return ret;
+		mii->val_out = ret;
+		return 0;
+	} else {
+		return ixgbe_mdio_write(netdev, prtad, devad, mii->reg_num,
+					mii->val_in);
+	}
+}
+
+static int ixgbe_ioctl(struct net_device *netdev, struct ifreq *ifr, int cmd)
+{
+#ifdef HAVE_PTP_1588_CLOCK
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+
+#endif
+	switch (cmd) {
+#ifdef HAVE_PTP_1588_CLOCK
+#ifdef SIOCGHWTSTAMP
+	case SIOCGHWTSTAMP:
+		return ixgbe_ptp_get_ts_config(adapter, ifr);
+#endif
+	case SIOCSHWTSTAMP:
+		return ixgbe_ptp_set_ts_config(adapter, ifr);
+#endif
+#ifdef ETHTOOL_OPS_COMPAT
+	case SIOCETHTOOL:
+		return ethtool_ioctl(ifr);
+#endif
+	case SIOCGMIIREG:
+	case SIOCSMIIREG:
+		return ixgbe_mii_ioctl(netdev, ifr, cmd);
+	default:
+		return -EOPNOTSUPP;
+	}
+}
+
 #ifdef CONFIG_NET_POLL_CONTROLLER
 /*
  * Polling 'interrupt' - used by things like netconsole to send skbs
@@ -7767,69 +9617,25 @@ static int ixgbe_del_sanmac_netdev(struct net_device *dev)
 static void ixgbe_netpoll(struct net_device *netdev)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	int i;
 
 	/* if interface is down do nothing */
 	if (test_bit(__IXGBE_DOWN, &adapter->state))
 		return;
 
-	/* loop through and schedule all active queues */
-	for (i = 0; i < adapter->num_q_vectors; i++)
-		ixgbe_msix_clean_rings(0, adapter->q_vector[i]);
-}
-
-#endif
-static struct rtnl_link_stats64 *ixgbe_get_stats64(struct net_device *netdev,
-						   struct rtnl_link_stats64 *stats)
-{
-	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	int i;
-
-	rcu_read_lock();
-	for (i = 0; i < adapter->num_rx_queues; i++) {
-		struct ixgbe_ring *ring = ACCESS_ONCE(adapter->rx_ring[i]);
-		u64 bytes, packets;
-		unsigned int start;
-
-		if (ring) {
-			do {
-				start = u64_stats_fetch_begin_irq(&ring->syncp);
-				packets = ring->stats.packets;
-				bytes   = ring->stats.bytes;
-			} while (u64_stats_fetch_retry_irq(&ring->syncp, start));
-			stats->rx_packets += packets;
-			stats->rx_bytes   += bytes;
-		}
-	}
-
-	for (i = 0; i < adapter->num_tx_queues; i++) {
-		struct ixgbe_ring *ring = ACCESS_ONCE(adapter->tx_ring[i]);
-		u64 bytes, packets;
-		unsigned int start;
-
-		if (ring) {
-			do {
-				start = u64_stats_fetch_begin_irq(&ring->syncp);
-				packets = ring->stats.packets;
-				bytes   = ring->stats.bytes;
-			} while (u64_stats_fetch_retry_irq(&ring->syncp, start));
-			stats->tx_packets += packets;
-			stats->tx_bytes   += bytes;
+	if (adapter->flags & IXGBE_FLAG_MSIX_ENABLED) {
+		int i;
+		for (i = 0; i < adapter->num_q_vectors; i++) {
+			adapter->q_vector[i]->netpoll_rx = true;
+			ixgbe_msix_clean_rings(0, adapter->q_vector[i]);
+			adapter->q_vector[i]->netpoll_rx = false;
 		}
+	} else {
+		ixgbe_intr(0, adapter);
 	}
-	rcu_read_unlock();
-	/* following stats updated by ixgbe_watchdog_task() */
-	stats->multicast	= netdev->stats.multicast;
-	stats->rx_errors	= netdev->stats.rx_errors;
-	stats->rx_length_errors	= netdev->stats.rx_length_errors;
-	stats->rx_crc_errors	= netdev->stats.rx_crc_errors;
-	stats->rx_missed_errors	= netdev->stats.rx_missed_errors;
-	return stats;
 }
+#endif /* CONFIG_NET_POLL_CONTROLLER */
 
-#ifdef CONFIG_IXGBE_DCB
-/**
- * ixgbe_validate_rtr - verify 802.1Qp to Rx packet buffer mapping is valid.
+/* ixgbe_validate_rtr - verify 802.1Qp to Rx packet buffer mapping is valid.
  * @adapter: pointer to ixgbe_adapter
  * @tc: number of traffic classes currently enabled
  *
@@ -7851,7 +9657,7 @@ static void ixgbe_validate_rtr(struct ixgbe_adapter *adapter, u8 tc)
 	reg = IXGBE_READ_REG(hw, IXGBE_RTRUP2TC);
 	rsave = reg;
 
-	for (i = 0; i < MAX_TRAFFIC_CLASS; i++) {
+	for (i = 0; i < IXGBE_DCB_MAX_TRAFFIC_CLASS; i++) {
 		u8 up2tc = reg >> (i * IXGBE_RTRUP2TC_UP_SHIFT);
 
 		/* If up2tc is out of bounds default to zero */
@@ -7871,14 +9677,15 @@ static void ixgbe_validate_rtr(struct ixgbe_adapter *adapter, u8 tc)
  *
  * Populate the netdev user priority to tc map
  */
-static void ixgbe_set_prio_tc_map(struct ixgbe_adapter *adapter)
+static void ixgbe_set_prio_tc_map(struct ixgbe_adapter __maybe_unused *adapter)
 {
+#ifdef HAVE_DCBNL_IEEE
 	struct net_device *dev = adapter->netdev;
 	struct ixgbe_dcb_config *dcb_cfg = &adapter->dcb_cfg;
 	struct ieee_ets *ets = adapter->ixgbe_ieee_ets;
 	u8 prio;
 
-	for (prio = 0; prio < MAX_USER_PRIORITY; prio++) {
+	for (prio = 0; prio < IXGBE_DCB_MAX_USER_PRIORITY; prio++) {
 		u8 tc = 0;
 
 		if (adapter->dcbx_cap & DCB_CAP_DCBX_VER_CEE)
@@ -7888,11 +9695,61 @@ static void ixgbe_set_prio_tc_map(struct ixgbe_adapter *adapter)
 
 		netdev_set_prio_tc_map(dev, prio, tc);
 	}
+#endif
+}
+
+#ifdef NETIF_F_HW_TC
+#ifdef TC_MQPRIO_HW_OFFLOAD_MAX
+static int ixgbe_setup_tc_mqprio(struct net_device *dev,
+				 struct tc_mqprio_qopt *mqprio)
+{
+	mqprio->hw = TC_MQPRIO_HW_OFFLOAD_TCS;
+	return ixgbe_setup_tc(dev, mqprio->num_tc);
+}
+
+#endif
+#if defined(HAVE_NDO_SETUP_TC_REMOVE_TC_TO_NETDEV)
+static int
+__ixgbe_setup_tc(struct net_device *dev, enum tc_setup_type type,
+		 void *type_data)
+#elif defined(HAVE_NDO_SETUP_TC_CHAIN_INDEX)
+static int
+__ixgbe_setup_tc(struct net_device *dev, __always_unused u32 handle,
+		 u32 chain_index, __always_unused __be16 proto,
+		 struct tc_to_netdev *tc)
+#else
+static int
+__ixgbe_setup_tc(struct net_device *dev, __always_unused u32 handle,
+		 __always_unused __be16 proto, struct tc_to_netdev *tc)
+#endif
+{
+#ifndef HAVE_NDO_SETUP_TC_REMOVE_TC_TO_NETDEV
+	unsigned int type = tc->type;
+
+#ifdef HAVE_NDO_SETUP_TC_CHAIN_INDEX
+	if (chain_index)
+		return -EOPNOTSUPP;
+
+#endif
+#endif
+	switch (type) {
+	case TC_SETUP_MQPRIO:
+#if defined(HAVE_NDO_SETUP_TC_REMOVE_TC_TO_NETDEV)
+		return ixgbe_setup_tc_mqprio(dev, type_data);
+#elif defined(TC_MQPRIO_HW_OFFLOAD_MAX)
+		return ixgbe_setup_tc_mqprio(dev, tc->mqprio);
+#else
+		return ixgbe_setup_tc(dev, tc->tc);
+#endif
+	default:
+		return -EOPNOTSUPP;
+	}
 }
 
-#endif /* CONFIG_IXGBE_DCB */
+#endif /* NETIF_F_HW_TC */
 /**
- * ixgbe_setup_tc - configure net_device for multiple traffic classes
+ * ixgbe_setup_tc - routine to configure net_device for multiple traffic
+ * classes.
  *
  * @netdev: net device to configure
  * @tc: number of traffic classes to enable
@@ -7901,19 +9758,15 @@ int ixgbe_setup_tc(struct net_device *dev, u8 tc)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
 	struct ixgbe_hw *hw = &adapter->hw;
-	bool pools;
 
 	/* Hardware supports up to 8 traffic classes */
 	if (tc > adapter->dcb_cfg.num_tcs.pg_tcs)
 		return -EINVAL;
 
-	if (hw->mac.type == ixgbe_mac_82598EB && tc && tc < MAX_TRAFFIC_CLASS)
+	if (tc && hw->mac.type == ixgbe_mac_82598EB &&
+	    tc < IXGBE_DCB_MAX_TRAFFIC_CLASS)
 		return -EINVAL;
 
-	pools = (find_first_zero_bit(&adapter->fwd_bitmask, 32) > 1);
-	if (tc && pools && adapter->num_rx_pools > IXGBE_MAX_DCBMACVLANS)
-		return -EBUSY;
-
 	/* Hardware has to reinitialize queues and interrupts to
 	 * match packet buffer alignment. Unfortunately, the
 	 * hardware is not flexible enough to do this dynamically.
@@ -7925,7 +9778,6 @@ int ixgbe_setup_tc(struct net_device *dev, u8 tc)
 
 	ixgbe_clear_interrupt_scheme(adapter);
 
-#ifdef CONFIG_IXGBE_DCB
 	if (tc) {
 		netdev_set_num_tc(dev, tc);
 		ixgbe_set_prio_tc_map(adapter);
@@ -7950,11 +9802,9 @@ int ixgbe_setup_tc(struct net_device *dev, u8 tc)
 
 	ixgbe_validate_rtr(adapter, tc);
 
-#endif /* CONFIG_IXGBE_DCB */
 	ixgbe_init_interrupt_scheme(adapter);
-
 	if (netif_running(dev))
-		return ixgbe_open(dev);
+		ixgbe_open(dev);
 
 	return 0;
 }
@@ -7968,8 +9818,8 @@ void ixgbe_sriov_reinit(struct ixgbe_adapter *adapter)
 	ixgbe_setup_tc(netdev, netdev_get_num_tc(netdev));
 	rtnl_unlock();
 }
-
 #endif
+
 void ixgbe_do_reset(struct net_device *netdev)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
@@ -7980,11 +9830,25 @@ void ixgbe_do_reset(struct net_device *netdev)
 		ixgbe_reset(adapter);
 }
 
+#ifdef HAVE_NDO_SET_FEATURES
+#ifdef HAVE_RHEL6_NET_DEVICE_OPS_EXT
+static u32 ixgbe_fix_features(struct net_device *netdev, u32 features)
+#else
 static netdev_features_t ixgbe_fix_features(struct net_device *netdev,
 					    netdev_features_t features)
+#endif
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 
+#if IS_ENABLED(CONFIG_DCB)
+	if (adapter->flags & IXGBE_FLAG_DCB_ENABLED)
+#ifdef NETIF_F_HW_VLAN_CTAG_RX
+		features |= NETIF_F_HW_VLAN_CTAG_RX;
+#else
+		features |= NETIF_F_HW_VLAN_RX;
+#endif
+#endif /* CONFIG_DCB */
+
 	/* If Rx checksum is disabled, then RSC/LRO should also be disabled */
 	if (!(features & NETIF_F_RXCSUM))
 		features &= ~NETIF_F_LRO;
@@ -7996,12 +9860,16 @@ static netdev_features_t ixgbe_fix_features(struct net_device *netdev,
 	return features;
 }
 
+#ifdef HAVE_RHEL6_NET_DEVICE_OPS_EXT
+static int ixgbe_set_features(struct net_device *netdev, u32 features)
+#else
 static int ixgbe_set_features(struct net_device *netdev,
 			      netdev_features_t features)
+#endif
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	netdev_features_t changed = netdev->features ^ features;
 	bool need_reset = false;
+	netdev_features_t changed = netdev->features ^ features;
 
 	/* Make sure RSC matches LRO, reset if change */
 	if (!(features & NETIF_F_LRO)) {
@@ -8014,7 +9882,7 @@ static int ixgbe_set_features(struct net_device *netdev,
 		    adapter->rx_itr_setting > IXGBE_MIN_RSC_ITR) {
 			adapter->flags2 |= IXGBE_FLAG2_RSC_ENABLED;
 			need_reset = true;
-		} else if ((changed ^ features) & NETIF_F_LRO) {
+		} else if (changed & NETIF_F_LRO) {
 			e_info(probe, "rx-usecs set too low, "
 			       "disabling RSC\n");
 		}
@@ -8040,8 +9908,8 @@ static int ixgbe_set_features(struct net_device *netdev,
 
 		adapter->flags &= ~IXGBE_FLAG_FDIR_PERFECT_CAPABLE;
 
-		/* We cannot enable ATR if SR-IOV is enabled */
-		if (adapter->flags & IXGBE_FLAG_SRIOV_ENABLED)
+		/* We cannot enable ATR if VMDq is enabled */
+		if (adapter->flags & IXGBE_FLAG_VMDQ_ENABLED)
 			break;
 
 		/* We cannot enable ATR if we have 2 or more traffic classes */
@@ -8056,67 +9924,196 @@ static int ixgbe_set_features(struct net_device *netdev,
 		if (!adapter->atr_sample_rate)
 			break;
 
-		adapter->flags |= IXGBE_FLAG_FDIR_HASH_CAPABLE;
-		break;
-	}
+		adapter->flags |= IXGBE_FLAG_FDIR_HASH_CAPABLE;
+		break;
+	}
+
+	netdev->features = features;
+
+#if defined(HAVE_UDP_ENC_RX_OFFLOAD) || defined(HAVE_VXLAN_RX_OFFLOAD)
+	if (adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE &&
+	    features & NETIF_F_RXCSUM) {
+		if (!need_reset)
+			adapter->flags2 |= IXGBE_FLAG2_UDP_TUN_REREG_NEEDED;
+	} else {
+		u32 port_mask = IXGBE_VXLANCTRL_VXLAN_UDPPORT_MASK;
+
+		ixgbe_clear_udp_tunnel_port(adapter, port_mask);
+	}
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD || HAVE_VXLAN_RX_OFFLOAD */
+
+#ifdef HAVE_UDP_ENC_RX_OFFLOAD
+	if (adapter->flags & IXGBE_FLAG_GENEVE_OFFLOAD_CAPABLE &&
+	    features & NETIF_F_RXCSUM) {
+		if (!need_reset)
+			adapter->flags2 |= IXGBE_FLAG2_UDP_TUN_REREG_NEEDED;
+	} else {
+		u32 port_mask = IXGBE_VXLANCTRL_GENEVE_UDPPORT_MASK;
+
+		ixgbe_clear_udp_tunnel_port(adapter, port_mask);
+	}
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD */
+	if (need_reset)
+		ixgbe_do_reset(netdev);
+#ifdef NETIF_F_HW_VLAN_CTAG_FILTER
+	else if (changed & (NETIF_F_HW_VLAN_CTAG_RX |
+			    NETIF_F_HW_VLAN_CTAG_FILTER))
+		ixgbe_set_rx_mode(netdev);
+#endif
+#ifdef NETIF_F_HW_VLAN_FILTER
+	else if (changed & (NETIF_F_HW_VLAN_RX |
+			    NETIF_F_HW_VLAN_FILTER))
+		ixgbe_set_rx_mode(netdev);
+#endif
+	return 0;
+
+}
+#endif /* HAVE_NDO_SET_FEATURES */
+
+#ifdef HAVE_UDP_ENC_RX_OFFLOAD
+/**
+ * ixgbe_add_udp_tunnel_port - Get notifications about adding UDP tunnel ports
+ * @dev: The port's netdev
+ * @ti: Tunnel endpoint information
+ **/
+static void ixgbe_add_udp_tunnel_port(struct net_device *dev,
+				      struct udp_tunnel_info *ti)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(dev);
+	struct ixgbe_hw *hw = &adapter->hw;
+	__be16 port = ti->port;
+	u32 port_shift = 0;
+	u32 reg;
+
+	if (ti->sa_family != AF_INET)
+		return;
+
+	switch (ti->type) {
+	case UDP_TUNNEL_TYPE_VXLAN:
+		if (!(adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE))
+			return;
+
+		if (adapter->vxlan_port == port)
+			return;
+
+		if (adapter->vxlan_port) {
+			netdev_info(dev,
+				    "VXLAN port %d set, not adding port %d\n",
+				    ntohs(adapter->vxlan_port),
+				    ntohs(port));
+			return;
+		}
+
+		adapter->vxlan_port = port;
+		break;
+	case UDP_TUNNEL_TYPE_GENEVE:
+		if (!(adapter->flags & IXGBE_FLAG_GENEVE_OFFLOAD_CAPABLE))
+			return;
+
+		if (adapter->geneve_port == port)
+			return;
+
+		if (adapter->geneve_port) {
+			netdev_info(dev,
+				    "GENEVE port %d set, not adding port %d\n",
+				    ntohs(adapter->geneve_port),
+				    ntohs(port));
+			return;
+		}
+
+		port_shift = IXGBE_VXLANCTRL_GENEVE_UDPPORT_SHIFT;
+		adapter->geneve_port = port;
+		break;
+	default:
+		return;
+	}
+
+	reg = IXGBE_READ_REG(hw, IXGBE_VXLANCTRL) | ntohs(port) << port_shift;
+	IXGBE_WRITE_REG(hw, IXGBE_VXLANCTRL, reg);
+}
+
+/**
+ * ixgbe_del_udp_tunnel_port - Get notifications about removing UDP tunnel ports
+ * @dev: The port's netdev
+ * @ti: Tunnel endpoint information
+ **/
+static void ixgbe_del_udp_tunnel_port(struct net_device *dev,
+				      struct udp_tunnel_info *ti)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(dev);
+	u32 port_mask;
+
+	if (ti->type != UDP_TUNNEL_TYPE_VXLAN &&
+	    ti->type != UDP_TUNNEL_TYPE_GENEVE)
+		return;
+
+	if (ti->sa_family != AF_INET)
+		return;
 
-	if (features & NETIF_F_HW_VLAN_CTAG_RX)
-		ixgbe_vlan_strip_enable(adapter);
-	else
-		ixgbe_vlan_strip_disable(adapter);
+	switch (ti->type) {
+	case UDP_TUNNEL_TYPE_VXLAN:
+		if (!(adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE))
+			return;
 
-	if (changed & NETIF_F_RXALL)
-		need_reset = true;
+		if (adapter->vxlan_port != ti->port) {
+			netdev_info(dev, "VXLAN port %d not found\n",
+				    ntohs(ti->port));
+			return;
+		}
 
-	netdev->features = features;
+		port_mask = IXGBE_VXLANCTRL_VXLAN_UDPPORT_MASK;
+		break;
+	case UDP_TUNNEL_TYPE_GENEVE:
+		if (!(adapter->flags & IXGBE_FLAG_GENEVE_OFFLOAD_CAPABLE))
+			return;
 
-#ifdef CONFIG_IXGBE_VXLAN
-	if ((adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE)) {
-		if (features & NETIF_F_RXCSUM)
-			adapter->flags2 |= IXGBE_FLAG2_VXLAN_REREG_NEEDED;
-		else
-			ixgbe_clear_vxlan_port(adapter);
-	}
-#endif /* CONFIG_IXGBE_VXLAN */
+		if (adapter->geneve_port != ti->port) {
+			netdev_info(dev, "GENEVE port %d not found\n",
+				    ntohs(ti->port));
+			return;
+		}
 
-	if (need_reset)
-		ixgbe_do_reset(netdev);
+		port_mask = IXGBE_VXLANCTRL_GENEVE_UDPPORT_MASK;
+		break;
+	default:
+		return;
+	}
 
-	return 0;
+	ixgbe_clear_udp_tunnel_port(adapter, port_mask);
+	adapter->flags2 |= IXGBE_FLAG2_UDP_TUN_REREG_NEEDED;
 }
-
-#ifdef CONFIG_IXGBE_VXLAN
+#elif defined(HAVE_VXLAN_RX_OFFLOAD)
 /**
  * ixgbe_add_vxlan_port - Get notifications about VXLAN ports that come up
  * @dev: The port's netdev
  * @sa_family: Socket Family that VXLAN is notifiying us about
  * @port: New UDP port number that VXLAN started listening to
- **/
+ * @type: Enumerated type specifying UDP tunnel type
+ */
 static void ixgbe_add_vxlan_port(struct net_device *dev, sa_family_t sa_family,
 				 __be16 port)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
 	struct ixgbe_hw *hw = &adapter->hw;
-	u16 new_port = ntohs(port);
 
-	if (!(adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE))
+	if (sa_family != AF_INET)
 		return;
 
-	if (sa_family == AF_INET6)
+	if (!(adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_ENABLE))
 		return;
 
-	if (adapter->vxlan_port == new_port)
+	if (adapter->vxlan_port == port)
 		return;
 
 	if (adapter->vxlan_port) {
 		netdev_info(dev,
 			    "Hit Max num of VXLAN ports, not adding port %d\n",
-			    new_port);
+			    ntohs(port));
 		return;
 	}
 
-	adapter->vxlan_port = new_port;
-	IXGBE_WRITE_REG(hw, IXGBE_VXLANCTRL, new_port);
+	adapter->vxlan_port = port;
+	IXGBE_WRITE_REG(hw, IXGBE_VXLANCTRL, ntohs(port));
 }
 
 /**
@@ -8124,120 +10121,83 @@ static void ixgbe_add_vxlan_port(struct net_device *dev, sa_family_t sa_family,
  * @dev: The port's netdev
  * @sa_family: Socket Family that VXLAN is notifying us about
  * @port: UDP port number that VXLAN stopped listening to
- **/
+ * @type: Enumerated type specifying UDP tunnel type
+ */
 static void ixgbe_del_vxlan_port(struct net_device *dev, sa_family_t sa_family,
 				 __be16 port)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
-	u16 new_port = ntohs(port);
 
-	if (!(adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE))
+	if (!(adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_ENABLE))
 		return;
 
-	if (sa_family == AF_INET6)
+	if (sa_family != AF_INET)
 		return;
 
-	if (adapter->vxlan_port != new_port) {
+	if (adapter->vxlan_port != port) {
 		netdev_info(dev, "Port %d was not found, not deleting\n",
-			    new_port);
+			    ntohs(port));
 		return;
 	}
 
-	ixgbe_clear_vxlan_port(adapter);
-	adapter->flags2 |= IXGBE_FLAG2_VXLAN_REREG_NEEDED;
+	ixgbe_clear_udp_tunnel_port(adapter, IXGBE_VXLANCTRL_ALL_UDPPORT_MASK);
+	adapter->flags2 |= IXGBE_FLAG2_UDP_TUN_REREG_NEEDED;
+}
+#endif /* HAVE_VXLAN_RX_OFFLOAD */
+
+#ifdef HAVE_NDO_GSO_CHECK
+static bool
+ixgbe_gso_check(struct sk_buff *skb, __always_unused struct net_device *dev)
+{
+	return vxlan_gso_check(skb);
 }
-#endif /* CONFIG_IXGBE_VXLAN */
+#endif /* HAVE_NDO_GSO_CHECK */
 
+#ifdef HAVE_FDB_OPS
+#ifdef USE_CONST_DEV_UC_CHAR
 static int ixgbe_ndo_fdb_add(struct ndmsg *ndm, struct nlattr *tb[],
 			     struct net_device *dev,
-			     const unsigned char *addr, u16 vid,
+			     const unsigned char *addr,
+#ifdef HAVE_NDO_FDB_ADD_VID
+			     u16 vid,
+#endif
+			     u16 flags)
+#else
+static int ixgbe_ndo_fdb_add(struct ndmsg *ndm,
+			     struct net_device *dev,
+			     unsigned char *addr,
 			     u16 flags)
+#endif /* USE_CONST_DEV_UC_CHAR */
 {
 	/* guarantee we can provide a unique filter for the unicast address */
 	if (is_unicast_ether_addr(addr) || is_link_local_ether_addr(addr)) {
-		if (IXGBE_MAX_PF_MACVLANS <= netdev_uc_count(dev))
+		struct ixgbe_adapter *adapter = netdev_priv(dev);
+		u16 pool = VMDQ_P(0);
+
+		if (netdev_uc_count(dev) >= ixgbe_available_rars(adapter, pool))
 			return -ENOMEM;
 	}
 
+#ifdef USE_CONST_DEV_UC_CHAR
+#ifdef HAVE_NDO_FDB_ADD_VID
 	return ndo_dflt_fdb_add(ndm, tb, dev, addr, vid, flags);
+#else
+	return ndo_dflt_fdb_add(ndm, tb, dev, addr, flags);
+#endif /* HAVE_NDO_FDB_ADD_VID */
+#else
+	return ndo_dflt_fdb_add(ndm, dev, addr, flags);
+#endif /* USE_CONST_DEV_UC_CHAR */
 }
 
-/**
- * ixgbe_configure_bridge_mode - set various bridge modes
- * @adapter - the private structure
- * @mode - requested bridge mode
- *
- * Configure some settings require for various bridge modes.
- **/
-static int ixgbe_configure_bridge_mode(struct ixgbe_adapter *adapter,
-				       __u16 mode)
-{
-	struct ixgbe_hw *hw = &adapter->hw;
-	unsigned int p, num_pools;
-	u32 vmdctl;
-
-	switch (mode) {
-	case BRIDGE_MODE_VEPA:
-		/* disable Tx loopback, rely on switch hairpin mode */
-		IXGBE_WRITE_REG(&adapter->hw, IXGBE_PFDTXGSWC, 0);
-
-		/* must enable Rx switching replication to allow multicast
-		 * packet reception on all VFs, and to enable source address
-		 * pruning.
-		 */
-		vmdctl = IXGBE_READ_REG(hw, IXGBE_VMD_CTL);
-		vmdctl |= IXGBE_VT_CTL_REPLEN;
-		IXGBE_WRITE_REG(hw, IXGBE_VMD_CTL, vmdctl);
-
-		/* enable Rx source address pruning. Note, this requires
-		 * replication to be enabled or else it does nothing.
-		 */
-		num_pools = adapter->num_vfs + adapter->num_rx_pools;
-		for (p = 0; p < num_pools; p++) {
-			if (hw->mac.ops.set_source_address_pruning)
-				hw->mac.ops.set_source_address_pruning(hw,
-								       true,
-								       p);
-		}
-		break;
-	case BRIDGE_MODE_VEB:
-		/* enable Tx loopback for internal VF/PF communication */
-		IXGBE_WRITE_REG(&adapter->hw, IXGBE_PFDTXGSWC,
-				IXGBE_PFDTXGSWC_VT_LBEN);
-
-		/* disable Rx switching replication unless we have SR-IOV
-		 * virtual functions
-		 */
-		vmdctl = IXGBE_READ_REG(hw, IXGBE_VMD_CTL);
-		if (!adapter->num_vfs)
-			vmdctl &= ~IXGBE_VT_CTL_REPLEN;
-		IXGBE_WRITE_REG(hw, IXGBE_VMD_CTL, vmdctl);
-
-		/* disable Rx source address pruning, since we don't expect to
-		 * be receiving external loopback of our transmitted frames.
-		 */
-		num_pools = adapter->num_vfs + adapter->num_rx_pools;
-		for (p = 0; p < num_pools; p++) {
-			if (hw->mac.ops.set_source_address_pruning)
-				hw->mac.ops.set_source_address_pruning(hw,
-								       false,
-								       p);
-		}
-		break;
-	default:
-		return -EINVAL;
-	}
-
-	adapter->bridge_mode = mode;
-
-	e_info(drv, "enabling bridge mode: %s\n",
-	       mode == BRIDGE_MODE_VEPA ? "VEPA" : "VEB");
-
-	return 0;
-}
-
+#ifdef HAVE_BRIDGE_ATTRIBS
+#ifdef HAVE_NDO_BRIDGE_SET_DEL_LINK_FLAGS
 static int ixgbe_ndo_bridge_setlink(struct net_device *dev,
-				    struct nlmsghdr *nlh, u16 flags)
+				    struct nlmsghdr *nlh,
+				    __always_unused u16 flags)
+#else
+static int ixgbe_ndo_bridge_setlink(struct net_device *dev,
+				    struct nlmsghdr *nlh)
+#endif /* HAVE_NDO_BRIDGE_SET_DEL_LINK_FLAGS */
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
 	struct nlattr *attr, *br_spec;
@@ -8247,137 +10207,107 @@ static int ixgbe_ndo_bridge_setlink(struct net_device *dev,
 		return -EOPNOTSUPP;
 
 	br_spec = nlmsg_find_attr(nlh, sizeof(struct ifinfomsg), IFLA_AF_SPEC);
-	if (!br_spec)
-		return -EINVAL;
 
 	nla_for_each_nested(attr, br_spec, rem) {
-		int status;
 		__u16 mode;
 
 		if (nla_type(attr) != IFLA_BRIDGE_MODE)
 			continue;
 
-		if (nla_len(attr) < sizeof(mode))
+		mode = nla_get_u16(attr);
+		if (mode == BRIDGE_MODE_VEPA) {
+			adapter->flags |= IXGBE_FLAG_SRIOV_VEPA_BRIDGE_MODE;
+		} else if (mode == BRIDGE_MODE_VEB) {
+			adapter->flags &= ~IXGBE_FLAG_SRIOV_VEPA_BRIDGE_MODE;
+		} else {
 			return -EINVAL;
+		}
 
-		mode = nla_get_u16(attr);
-		status = ixgbe_configure_bridge_mode(adapter, mode);
-		if (status)
-			return status;
+		adapter->bridge_mode = mode;
 
-		break;
+		/* re-configure settings related to bridge mode */
+		ixgbe_configure_bridge_mode(adapter);
+
+		e_info(drv, "enabling bridge mode: %s\n",
+			mode == BRIDGE_MODE_VEPA ? "VEPA" : "VEB");
 	}
 
 	return 0;
 }
 
+#ifdef HAVE_NDO_BRIDGE_GETLINK_NLFLAGS
+static int ixgbe_ndo_bridge_getlink(struct sk_buff *skb, u32 pid, u32 seq,
+				    struct net_device *dev,
+				    u32 __maybe_unused filter_mask,
+				    int nlflags)
+#elif defined(HAVE_BRIDGE_FILTER)
 static int ixgbe_ndo_bridge_getlink(struct sk_buff *skb, u32 pid, u32 seq,
 				    struct net_device *dev,
-				    u32 filter_mask, int nlflags)
+				    u32 __always_unused filter_mask)
+#else
+static int ixgbe_ndo_bridge_getlink(struct sk_buff *skb, u32 pid, u32 seq,
+				    struct net_device *dev)
+#endif /* HAVE_NDO_BRIDGE_GETLINK_NLFLAGS */
 {
 	struct ixgbe_adapter *adapter = netdev_priv(dev);
+	u16 mode;
 
 	if (!(adapter->flags & IXGBE_FLAG_SRIOV_ENABLED))
 		return 0;
 
-	return ndo_dflt_bridge_getlink(skb, pid, seq, dev,
-				       adapter->bridge_mode, 0, 0, nlflags,
+	mode = adapter->bridge_mode;
+#ifdef HAVE_NDO_DFLT_BRIDGE_GETLINK_VLAN_SUPPORT
+	return ndo_dflt_bridge_getlink(skb, pid, seq, dev, mode, 0, 0, nlflags,
 				       filter_mask, NULL);
+#elif defined(HAVE_NDO_BRIDGE_GETLINK_NLFLAGS)
+	return ndo_dflt_bridge_getlink(skb, pid, seq, dev, mode, 0, 0, nlflags);
+#elif defined(HAVE_NDO_FDB_ADD_VID) || \
+      defined NDO_DFLT_BRIDGE_GETLINK_HAS_BRFLAGS
+	return ndo_dflt_bridge_getlink(skb, pid, seq, dev, mode, 0, 0);
+#else
+	return ndo_dflt_bridge_getlink(skb, pid, seq, dev, mode);
+#endif /* HAVE_NDO_BRIDGE_GETLINK_NLFLAGS */
 }
+#endif /* HAVE_BRIDGE_ATTRIBS */
+#endif /* HAVE_FDB_OPS */
 
-static void *ixgbe_fwd_add(struct net_device *pdev, struct net_device *vdev)
-{
-	struct ixgbe_fwd_adapter *fwd_adapter = NULL;
-	struct ixgbe_adapter *adapter = netdev_priv(pdev);
-	int used_pools = adapter->num_vfs + adapter->num_rx_pools;
-	unsigned int limit;
-	int pool, err;
+#ifdef HAVE_NDO_FEATURES_CHECK
+#define IXGBE_MAX_TUNNEL_HDR_LEN 80
+#ifdef NETIF_F_GSO_PARTIAL
+#define IXGBE_MAX_MAC_HDR_LEN		127
+#define IXGBE_MAX_NETWORK_HDR_LEN	511
 
-	/* Hardware has a limited number of available pools. Each VF, and the
-	 * PF require a pool. Check to ensure we don't attempt to use more
-	 * then the available number of pools.
+static netdev_features_t
+ixgbe_features_check(struct sk_buff *skb, struct net_device *dev,
+		     netdev_features_t features)
+{
+	unsigned int network_hdr_len, mac_hdr_len;
+
+	/* Make certain the headers can be described by a context descriptor */
+	mac_hdr_len = skb_network_header(skb) - skb->data;
+	if (unlikely(mac_hdr_len > IXGBE_MAX_MAC_HDR_LEN))
+		return features & ~(NETIF_F_HW_CSUM |
+				    NETIF_F_SCTP_CRC |
+				    NETIF_F_HW_VLAN_CTAG_TX |
+				    NETIF_F_TSO |
+				    NETIF_F_TSO6);
+
+	network_hdr_len = skb_checksum_start(skb) - skb_network_header(skb);
+	if (unlikely(network_hdr_len >  IXGBE_MAX_NETWORK_HDR_LEN))
+		return features & ~(NETIF_F_HW_CSUM |
+				    NETIF_F_SCTP_CRC |
+				    NETIF_F_TSO |
+				    NETIF_F_TSO6);
+
+	/* We can only support IPV4 TSO in tunnels if we can mangle the
+	 * inner IP ID field, so strip TSO if MANGLEID is not supported.
 	 */
-	if (used_pools >= IXGBE_MAX_VF_FUNCTIONS)
-		return ERR_PTR(-EINVAL);
-
-#ifdef CONFIG_RPS
-	if (vdev->num_rx_queues != vdev->num_tx_queues) {
-		netdev_info(pdev, "%s: Only supports a single queue count for TX and RX\n",
-			    vdev->name);
-		return ERR_PTR(-EINVAL);
-	}
-#endif
-	/* Check for hardware restriction on number of rx/tx queues */
-	if (vdev->num_tx_queues > IXGBE_MAX_L2A_QUEUES ||
-	    vdev->num_tx_queues == IXGBE_BAD_L2A_QUEUE) {
-		netdev_info(pdev,
-			    "%s: Supports RX/TX Queue counts 1,2, and 4\n",
-			    pdev->name);
-		return ERR_PTR(-EINVAL);
-	}
-
-	if (((adapter->flags & IXGBE_FLAG_DCB_ENABLED) &&
-	      adapter->num_rx_pools > IXGBE_MAX_DCBMACVLANS - 1) ||
-	    (adapter->num_rx_pools > IXGBE_MAX_MACVLANS))
-		return ERR_PTR(-EBUSY);
-
-	fwd_adapter = kzalloc(sizeof(*fwd_adapter), GFP_KERNEL);
-	if (!fwd_adapter)
-		return ERR_PTR(-ENOMEM);
-
-	pool = find_first_zero_bit(&adapter->fwd_bitmask, 32);
-	adapter->num_rx_pools++;
-	set_bit(pool, &adapter->fwd_bitmask);
-	limit = find_last_bit(&adapter->fwd_bitmask, 32);
-
-	/* Enable VMDq flag so device will be set in VM mode */
-	adapter->flags |= IXGBE_FLAG_VMDQ_ENABLED | IXGBE_FLAG_SRIOV_ENABLED;
-	adapter->ring_feature[RING_F_VMDQ].limit = limit + 1;
-	adapter->ring_feature[RING_F_RSS].limit = vdev->num_tx_queues;
-
-	/* Force reinit of ring allocation with VMDQ enabled */
-	err = ixgbe_setup_tc(pdev, netdev_get_num_tc(pdev));
-	if (err)
-		goto fwd_add_err;
-	fwd_adapter->pool = pool;
-	fwd_adapter->real_adapter = adapter;
-	err = ixgbe_fwd_ring_up(vdev, fwd_adapter);
-	if (err)
-		goto fwd_add_err;
-	netif_tx_start_all_queues(vdev);
-	return fwd_adapter;
-fwd_add_err:
-	/* unwind counter and free adapter struct */
-	netdev_info(pdev,
-		    "%s: dfwd hardware acceleration failed\n", vdev->name);
-	clear_bit(pool, &adapter->fwd_bitmask);
-	adapter->num_rx_pools--;
-	kfree(fwd_adapter);
-	return ERR_PTR(err);
-}
-
-static void ixgbe_fwd_del(struct net_device *pdev, void *priv)
-{
-	struct ixgbe_fwd_adapter *fwd_adapter = priv;
-	struct ixgbe_adapter *adapter = fwd_adapter->real_adapter;
-	unsigned int limit;
-
-	clear_bit(fwd_adapter->pool, &adapter->fwd_bitmask);
-	adapter->num_rx_pools--;
-
-	limit = find_last_bit(&adapter->fwd_bitmask, 32);
-	adapter->ring_feature[RING_F_VMDQ].limit = limit + 1;
-	ixgbe_fwd_ring_down(fwd_adapter->netdev, fwd_adapter);
-	ixgbe_setup_tc(pdev, netdev_get_num_tc(pdev));
-	netdev_dbg(pdev, "pool %i:%i queues %i:%i VSI bitmask %lx\n",
-		   fwd_adapter->pool, adapter->num_rx_pools,
-		   fwd_adapter->rx_base_queue,
-		   fwd_adapter->rx_base_queue + adapter->num_rx_queues_per_pool,
-		   adapter->fwd_bitmask);
-	kfree(fwd_adapter);
-}
+	if (skb->encapsulation && !(features & NETIF_F_TSO_MANGLEID))
+		features &= ~NETIF_F_TSO;
 
-#define IXGBE_MAX_TUNNEL_HDR_LEN 80
+	return features;
+}
+#else
 static netdev_features_t
 ixgbe_features_check(struct sk_buff *skb, struct net_device *dev,
 		     netdev_features_t features)
@@ -8387,109 +10317,204 @@ ixgbe_features_check(struct sk_buff *skb, struct net_device *dev,
 
 	if (unlikely(skb_inner_mac_header(skb) - skb_transport_header(skb) >
 		     IXGBE_MAX_TUNNEL_HDR_LEN))
-		return features & ~NETIF_F_ALL_CSUM;
+		return features & ~NETIF_F_CSUM_MASK;
 
 	return features;
 }
+#endif /* NETIF_F_GSO_PARTIAL */
+#endif /* HAVE_NDO_FEATURES_CHECK */
 
+#ifdef HAVE_NET_DEVICE_OPS
 static const struct net_device_ops ixgbe_netdev_ops = {
 	.ndo_open		= ixgbe_open,
 	.ndo_stop		= ixgbe_close,
 	.ndo_start_xmit		= ixgbe_xmit_frame,
+#ifdef HAVE_NETDEV_SELECT_QUEUE
+#if IS_ENABLED(CONFIG_FCOE)
 	.ndo_select_queue	= ixgbe_select_queue,
+#else
+#ifndef HAVE_MQPRIO
+	.ndo_select_queue	= __netdev_pick_tx,
+#endif
+#endif /* CONFIG_FCOE */
+#endif /* HAVE_NETDEV_SELECT_QUEUE */
 	.ndo_set_rx_mode	= ixgbe_set_rx_mode,
 	.ndo_validate_addr	= eth_validate_addr,
 	.ndo_set_mac_address	= ixgbe_set_mac,
 	.ndo_change_mtu		= ixgbe_change_mtu,
 	.ndo_tx_timeout		= ixgbe_tx_timeout,
+#if defined(NETIF_F_HW_VLAN_TX) || defined(NETIF_F_HW_VLAN_CTAG_TX)
 	.ndo_vlan_rx_add_vid	= ixgbe_vlan_rx_add_vid,
 	.ndo_vlan_rx_kill_vid	= ixgbe_vlan_rx_kill_vid,
+#endif
 	.ndo_do_ioctl		= ixgbe_ioctl,
+#ifdef HAVE_RHEL7_NET_DEVICE_OPS_EXT
+/* RHEL7 requires this to be defined to enable extended ops.  RHEL7 uses the
+ * function get_ndo_ext to retrieve offsets for extended fields from with the
+ * net_device_ops struct and ndo_size is checked to determine whether or not
+ * the offset is valid.
+ */
+	.ndo_size		= sizeof(const struct net_device_ops),
+#endif
+#ifdef IFLA_VF_MAX
 	.ndo_set_vf_mac		= ixgbe_ndo_set_vf_mac,
+#ifdef HAVE_RHEL7_NETDEV_OPS_EXT_NDO_SET_VF_VLAN
+	.extended.ndo_set_vf_vlan = ixgbe_ndo_set_vf_vlan,
+#else
 	.ndo_set_vf_vlan	= ixgbe_ndo_set_vf_vlan,
+#endif
+#ifdef HAVE_NDO_SET_VF_MIN_MAX_TX_RATE
 	.ndo_set_vf_rate	= ixgbe_ndo_set_vf_bw,
+#else
+	.ndo_set_vf_tx_rate	= ixgbe_ndo_set_vf_bw,
+#endif /* HAVE_NDO_SET_VF_MIN_MAX_TX_RATE */
+#if defined(HAVE_VF_SPOOFCHK_CONFIGURE) && IS_ENABLED(CONFIG_PCI_IOV)
 	.ndo_set_vf_spoofchk	= ixgbe_ndo_set_vf_spoofchk,
+#endif
+#ifdef HAVE_NDO_SET_VF_RSS_QUERY_EN
 	.ndo_set_vf_rss_query_en = ixgbe_ndo_set_vf_rss_query_en,
+#endif
+#ifdef HAVE_NDO_SET_VF_TRUST
+#ifdef HAVE_RHEL7_NET_DEVICE_OPS_EXT
+	.extended.ndo_set_vf_trust = ixgbe_ndo_set_vf_trust,
+#else
 	.ndo_set_vf_trust	= ixgbe_ndo_set_vf_trust,
+#endif /* HAVE_RHEL7_NET_DEVICE_OPS_EXT */
+#endif /* HAVE_NDO_SET_VF_TRUST */
 	.ndo_get_vf_config	= ixgbe_ndo_get_vf_config,
+#endif /* IFLA_VF_MAX */
+#ifdef HAVE_NDO_GET_STATS64
 	.ndo_get_stats64	= ixgbe_get_stats64,
-#ifdef CONFIG_IXGBE_DCB
+#else
+	.ndo_get_stats		= ixgbe_get_stats,
+#endif /* HAVE_NDO_GET_STATS64 */
+#ifdef HAVE_SETUP_TC
+#ifdef NETIF_F_HW_TC
+	.ndo_setup_tc		= __ixgbe_setup_tc,
+#else
 	.ndo_setup_tc		= ixgbe_setup_tc,
+#endif /* NETIF_F_HW_TC */
 #endif
 #ifdef CONFIG_NET_POLL_CONTROLLER
 	.ndo_poll_controller	= ixgbe_netpoll,
 #endif
-#ifdef CONFIG_NET_RX_BUSY_POLL
-	.ndo_busy_poll		= ixgbe_low_latency_recv,
-#endif
-#ifdef IXGBE_FCOE
+#ifndef HAVE_RHEL6_NET_DEVICE_EXTENDED
+#ifdef HAVE_NDO_BUSY_POLL
+	.ndo_busy_poll		= ixgbe_busy_poll_recv,
+#endif /* HAVE_NDO_BUSY_POLL */
+#endif /* !HAVE_RHEL6_NET_DEVICE_EXTENDED */
+#if IS_ENABLED(CONFIG_FCOE)
 	.ndo_fcoe_ddp_setup = ixgbe_fcoe_ddp_get,
+#ifdef HAVE_NETDEV_OPS_FCOE_DDP_TARGET
 	.ndo_fcoe_ddp_target = ixgbe_fcoe_ddp_target,
+#endif
 	.ndo_fcoe_ddp_done = ixgbe_fcoe_ddp_put,
+#ifdef HAVE_NETDEV_OPS_FCOE_ENABLE
 	.ndo_fcoe_enable = ixgbe_fcoe_enable,
 	.ndo_fcoe_disable = ixgbe_fcoe_disable,
+#endif
+#ifdef HAVE_NETDEV_OPS_FCOE_GETWWN
 	.ndo_fcoe_get_wwn = ixgbe_fcoe_get_wwn,
-	.ndo_fcoe_get_hbainfo = ixgbe_fcoe_get_hbainfo,
-#endif /* IXGBE_FCOE */
-	.ndo_set_features = ixgbe_set_features,
-	.ndo_fix_features = ixgbe_fix_features,
+#endif
+#endif /* CONFIG_FCOE */
+#ifdef HAVE_VLAN_RX_REGISTER
+	.ndo_vlan_rx_register	= &ixgbe_vlan_mode,
+#endif
+#ifdef HAVE_FDB_OPS
 	.ndo_fdb_add		= ixgbe_ndo_fdb_add,
+#ifndef USE_DEFAULT_FDB_DEL_DUMP
+	.ndo_fdb_del		= ndo_dflt_fdb_del,
+	.ndo_fdb_dump		= ndo_dflt_fdb_dump,
+#endif
+#ifdef HAVE_BRIDGE_ATTRIBS
 	.ndo_bridge_setlink	= ixgbe_ndo_bridge_setlink,
 	.ndo_bridge_getlink	= ixgbe_ndo_bridge_getlink,
-	.ndo_dfwd_add_station	= ixgbe_fwd_add,
-	.ndo_dfwd_del_station	= ixgbe_fwd_del,
-#ifdef CONFIG_IXGBE_VXLAN
+#endif /* HAVE_BRIDGE_ATTRIBS */
+#endif
+#ifdef HAVE_UDP_ENC_RX_OFFLOAD
+#ifdef HAVE_RHEL7_NETDEV_OPS_EXT_NDO_UDP_TUNNEL
+	.extended.ndo_udp_tunnel_add = ixgbe_add_udp_tunnel_port,
+	.extended.ndo_udp_tunnel_del = ixgbe_del_udp_tunnel_port,
+#else
+	.ndo_udp_tunnel_add	= ixgbe_add_udp_tunnel_port,
+	.ndo_udp_tunnel_del	= ixgbe_del_udp_tunnel_port,
+#endif
+#elif defined(HAVE_VXLAN_RX_OFFLOAD)
 	.ndo_add_vxlan_port	= ixgbe_add_vxlan_port,
 	.ndo_del_vxlan_port	= ixgbe_del_vxlan_port,
-#endif /* CONFIG_IXGBE_VXLAN */
+#endif /* HAVE_UDP_ENC_RX_OFFLOAD */
+#ifdef HAVE_NDO_GSO_CHECK
+	.ndo_gso_check		= ixgbe_gso_check,
+#endif /* HAVE_NDO_GSO_CHECK */
+#ifdef HAVE_NDO_FEATURES_CHECK
 	.ndo_features_check	= ixgbe_features_check,
+#endif /* HAVE_NDO_FEATURES_CHECK */
+#ifdef HAVE_RHEL6_NET_DEVICE_OPS_EXT
 };
 
-/**
- * ixgbe_enumerate_functions - Get the number of ports this device has
- * @adapter: adapter structure
- *
- * This function enumerates the phsyical functions co-located on a single slot,
- * in order to determine how many ports a device has. This is most useful in
- * determining the required GT/s of PCIe bandwidth necessary for optimal
- * performance.
- **/
-static inline int ixgbe_enumerate_functions(struct ixgbe_adapter *adapter)
-{
-	struct pci_dev *entry, *pdev = adapter->pdev;
-	int physfns = 0;
-
-	/* Some cards can not use the generic count PCIe functions method,
-	 * because they are behind a parent switch, so we hardcode these with
-	 * the correct number of functions.
-	 */
-	if (ixgbe_pcie_from_parent(&adapter->hw))
-		physfns = 4;
-
-	list_for_each_entry(entry, &adapter->pdev->bus->devices, bus_list) {
-		/* don't count virtual functions */
-		if (entry->is_virtfn)
-			continue;
-
-		/* When the devices on the bus don't all match our device ID,
-		 * we can't reliably determine the correct number of
-		 * functions. This can occur if a function has been direct
-		 * attached to a virtual machine using VT-d, for example. In
-		 * this case, simply return -1 to indicate this.
-		 */
-		if ((entry->vendor != pdev->vendor) ||
-		    (entry->device != pdev->device))
-			return -1;
+/* RHEL6 keeps these operations in a separate structure */
+static const struct net_device_ops_ext ixgbe_netdev_ops_ext = {
+	.size = sizeof(struct net_device_ops_ext),
+#endif /* HAVE_RHEL6_NET_DEVICE_OPS_EXT */
+#ifdef HAVE_NDO_SET_FEATURES
+	.ndo_set_features = ixgbe_set_features,
+	.ndo_fix_features = ixgbe_fix_features,
+#endif /* HAVE_NDO_SET_FEATURES */
+};
+#endif /* HAVE_NET_DEVICE_OPS */
+
+void ixgbe_assign_netdev_ops(struct net_device *dev)
+{
+#ifdef HAVE_NET_DEVICE_OPS
+	dev->netdev_ops = &ixgbe_netdev_ops;
+#ifdef HAVE_RHEL6_NET_DEVICE_OPS_EXT
+	set_netdev_ops_ext(dev, &ixgbe_netdev_ops_ext);
+#endif /* HAVE_RHEL6_NET_DEVICE_OPS_EXT */
+#else /* HAVE_NET_DEVICE_OPS */
+	dev->open = &ixgbe_open;
+	dev->stop = &ixgbe_close;
+	dev->hard_start_xmit = &ixgbe_xmit_frame;
+	dev->get_stats = &ixgbe_get_stats;
+#ifdef HAVE_SET_RX_MODE
+	dev->set_rx_mode = &ixgbe_set_rx_mode;
+#endif
+	dev->set_multicast_list = &ixgbe_set_rx_mode;
+	dev->set_mac_address = &ixgbe_set_mac;
+	dev->change_mtu = &ixgbe_change_mtu;
+	dev->do_ioctl = &ixgbe_ioctl;
+#ifdef HAVE_TX_TIMEOUT
+	dev->tx_timeout = &ixgbe_tx_timeout;
+#endif
+#if defined(NETIF_F_HW_VLAN_TX) || defined(NETIF_F_HW_VLAN_CTAG_TX)
+	dev->vlan_rx_register = &ixgbe_vlan_mode;
+	dev->vlan_rx_add_vid = &ixgbe_vlan_rx_add_vid;
+	dev->vlan_rx_kill_vid = &ixgbe_vlan_rx_kill_vid;
+#endif
+#ifdef CONFIG_NET_POLL_CONTROLLER
+	dev->poll_controller = &ixgbe_netpoll;
+#endif
+#ifdef HAVE_NETDEV_SELECT_QUEUE
+#if IS_ENABLED(CONFIG_FCOE)
+	dev->select_queue = &ixgbe_select_queue;
+#else
+	dev->select_queue = &__netdev_pick_tx;
+#endif
+#endif /* HAVE_NETDEV_SELECT_QUEUE */
+#endif /* HAVE_NET_DEVICE_OPS */
 
-		physfns++;
-	}
+#ifdef HAVE_RHEL6_NET_DEVICE_EXTENDED
+#ifdef HAVE_NDO_BUSY_POLL
+	netdev_extended(dev)->ndo_busy_poll		= ixgbe_busy_poll_recv;
+#endif /* HAVE_NDO_BUSY_POLL */
+#endif /* HAVE_RHEL6_NET_DEVICE_EXTENDED */
 
-	return physfns;
+	ixgbe_set_ethtool_ops(dev);
+	dev->watchdog_timeo = 5 * HZ;
 }
 
 /**
  * ixgbe_wol_supported - Check whether device supports WoL
- * @hw: hw specific details
+ * @adapter: the adapter private structure
  * @device_id: the device ID
  * @subdev_id: the subsystem device ID
  *
@@ -8497,86 +10522,144 @@ static inline int ixgbe_enumerate_functions(struct ixgbe_adapter *adapter)
  * which devices have WoL support
  *
  **/
-int ixgbe_wol_supported(struct ixgbe_adapter *adapter, u16 device_id,
-			u16 subdevice_id)
+bool ixgbe_wol_supported(struct ixgbe_adapter *adapter, u16 device_id,
+			 u16 subdevice_id)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	u16 wol_cap = adapter->eeprom_cap & IXGBE_DEVICE_CAPS_WOL_MASK;
-	int is_wol_supported = 0;
 
+	/* WOL not supported on 82598 */
+	if (hw->mac.type == ixgbe_mac_82598EB)
+		return false;
+
+	/* check eeprom to see if WOL is enabled for X540 and newer */
+	if (hw->mac.type >= ixgbe_mac_X540) {
+		if ((wol_cap == IXGBE_DEVICE_CAPS_WOL_PORT0_1) ||
+		    ((wol_cap == IXGBE_DEVICE_CAPS_WOL_PORT0) &&
+		     (hw->bus.func == 0)))
+			return true;
+	}
+
+	/* WOL is determined based on device IDs for 82599 MACs */
 	switch (device_id) {
 	case IXGBE_DEV_ID_82599_SFP:
 		/* Only these subdevices could supports WOL */
 		switch (subdevice_id) {
-		case IXGBE_SUBDEV_ID_82599_SFP_WOL0:
 		case IXGBE_SUBDEV_ID_82599_560FLR:
+		case IXGBE_SUBDEV_ID_82599_LOM_SNAP6:
+		case IXGBE_SUBDEV_ID_82599_SFP_WOL0:
+		case IXGBE_SUBDEV_ID_82599_SFP_2OCP:
 			/* only support first port */
 			if (hw->bus.func != 0)
 				break;
+			/* fall through */
 		case IXGBE_SUBDEV_ID_82599_SP_560FLR:
 		case IXGBE_SUBDEV_ID_82599_SFP:
 		case IXGBE_SUBDEV_ID_82599_RNDC:
 		case IXGBE_SUBDEV_ID_82599_ECNA_DP:
-		case IXGBE_SUBDEV_ID_82599_LOM_SFP:
-			is_wol_supported = 1;
-			break;
+		case IXGBE_SUBDEV_ID_82599_SFP_1OCP:
+		case IXGBE_SUBDEV_ID_82599_SFP_LOM_OEM1:
+		case IXGBE_SUBDEV_ID_82599_SFP_LOM_OEM2:
+			return true;
 		}
 		break;
 	case IXGBE_DEV_ID_82599EN_SFP:
-		/* Only this subdevice supports WOL */
+		/* Only these subdevices support WoL */
 		switch (subdevice_id) {
 		case IXGBE_SUBDEV_ID_82599EN_SFP_OCP1:
-			is_wol_supported = 1;
-			break;
+			return true;
 		}
 		break;
 	case IXGBE_DEV_ID_82599_COMBO_BACKPLANE:
 		/* All except this subdevice support WOL */
 		if (subdevice_id != IXGBE_SUBDEV_ID_82599_KX4_KR_MEZZ)
-			is_wol_supported = 1;
+			return true;
 		break;
 	case IXGBE_DEV_ID_82599_KX4:
-		is_wol_supported = 1;
-		break;
-	case IXGBE_DEV_ID_X540T:
-	case IXGBE_DEV_ID_X540T1:
-	case IXGBE_DEV_ID_X550T:
-	case IXGBE_DEV_ID_X550EM_X_KX4:
-	case IXGBE_DEV_ID_X550EM_X_KR:
-	case IXGBE_DEV_ID_X550EM_X_10G_T:
-		/* check eeprom to see if enabled wol */
-		if ((wol_cap == IXGBE_DEVICE_CAPS_WOL_PORT0_1) ||
-		    ((wol_cap == IXGBE_DEVICE_CAPS_WOL_PORT0) &&
-		     (hw->bus.func == 0))) {
-			is_wol_supported = 1;
-		}
+		return  true;
+	default:
 		break;
 	}
 
-	return is_wol_supported;
+	return false;
 }
 
 /**
- * ixgbe_get_platform_mac_addr - Look up MAC address in Open Firmware / IDPROM
- * @adapter: Pointer to adapter struct
- */
-static void ixgbe_get_platform_mac_addr(struct ixgbe_adapter *adapter)
+ * ixgbe_set_fw_version - Set FW version
+ * @adapter: the adapter private structure
+ *
+ * This function is used by probe and ethtool to determine the FW version to
+ * format to display. The FW version is taken from the EEPROM/NVM.
+ *
+ **/
+static void ixgbe_set_fw_version(struct ixgbe_adapter *adapter)
 {
-#ifdef CONFIG_OF
-	struct device_node *dp = pci_device_to_OF_node(adapter->pdev);
 	struct ixgbe_hw *hw = &adapter->hw;
-	const unsigned char *addr;
+	u16 eeprom_verh = 0, eeprom_verl = 0;
+	u16 offset = 0;
+	u32 etrack_id;
+
+	/* Check for OEM Product Version block format */
+	hw->eeprom.ops.read(hw, 0x1b, &offset);
+
+	/* Make sure offset to OEM Product Version block is valid */
+	if (!(offset == 0x0) && !(offset == 0xffff)) {
+		u16 mod_len = 0, cap = 0, prod_ver = 0, rel_num = 0;
+		u16 build, major, patch;
+
+		/* Read product version block */
+		hw->eeprom.ops.read(hw, offset, &mod_len);
+		hw->eeprom.ops.read(hw, offset + 0x1, &cap);
+		hw->eeprom.ops.read(hw, offset + 0x2, &prod_ver);
+		hw->eeprom.ops.read(hw, offset + 0x3, &rel_num);
+
+		/* Only display OEM product version if valid block */
+		if (mod_len == 0x3 && (cap & 0xf) == 0x0) {
+			major = prod_ver >> 8;
+			build = prod_ver & 0xff;
+			patch = rel_num;
+
+			snprintf(adapter->eeprom_id, sizeof(adapter->eeprom_id),
+				 "%x.%x.%x", major, build, patch);
+			return;
+		}
+	}
 
-	addr = of_get_mac_address(dp);
-	if (addr) {
-		ether_addr_copy(hw->mac.perm_addr, addr);
-		return;
+	/*
+	 * Save off EEPROM version number and Option Rom version which
+	 * together make a unique identify for the eeprom
+	 */
+	hw->eeprom.ops.read(hw, 0x2e, &eeprom_verh);
+	hw->eeprom.ops.read(hw, 0x2d, &eeprom_verl);
+	etrack_id = (eeprom_verh << 16) | eeprom_verl;
+
+	/* Check for SCSI block version format */
+	hw->eeprom.ops.read(hw, 0x17, &offset);
+
+	/* Make sure offset to SCSI block is valid */
+	if (!(offset == 0x0) && !(offset == 0xffff)) {
+		u16 eeprom_cfg_blkh = 0, eeprom_cfg_blkl = 0;
+		u16 build, major, patch;
+
+		hw->eeprom.ops.read(hw, offset + 0x84, &eeprom_cfg_blkh);
+		hw->eeprom.ops.read(hw, offset + 0x83, &eeprom_cfg_blkl);
+
+		/* Only display Option Rom if exist */
+		if (eeprom_cfg_blkl && eeprom_cfg_blkh) {
+			major = eeprom_cfg_blkl >> 8;
+			build = (eeprom_cfg_blkl << 8) | (eeprom_cfg_blkh >> 8);
+			patch = eeprom_cfg_blkh & 0x00ff;
+
+			snprintf(adapter->eeprom_id, sizeof(adapter->eeprom_id),
+				 "0x%08x, %d.%d.%d", etrack_id, major, build,
+				 patch);
+			return;
+		}
 	}
-#endif /* CONFIG_OF */
 
-#ifdef CONFIG_SPARC
-	ether_addr_copy(hw->mac.perm_addr, idprom->id_ethaddr);
-#endif /* CONFIG_SPARC */
+	/* Set ETrack ID format */
+	snprintf(adapter->eeprom_id, sizeof(adapter->eeprom_id),
+		 "0x%08x", etrack_id);
 }
 
 /**
@@ -8590,83 +10673,130 @@ static void ixgbe_get_platform_mac_addr(struct ixgbe_adapter *adapter)
  * The OS initialization, configuring of the adapter private structure,
  * and a hardware reset occur.
  **/
-static int ixgbe_probe(struct pci_dev *pdev, const struct pci_device_id *ent)
+static int __devinit ixgbe_probe(struct pci_dev *pdev,
+				 const struct pci_device_id __always_unused *ent)
 {
 	struct net_device *netdev;
 	struct ixgbe_adapter *adapter = NULL;
-	struct ixgbe_hw *hw;
-	const struct ixgbe_info *ii = ixgbe_info_tbl[ent->driver_data];
-	int i, err, pci_using_dac, expected_gts;
-	unsigned int indices = MAX_TX_QUEUES;
+	struct ixgbe_hw *hw = NULL;
+	static int cards_found;
+	int err, pci_using_dac, expected_gts;
+	char *info_string, *i_s_var;
 	u8 part_str[IXGBE_PBANUM_LENGTH];
+	enum ixgbe_mac_type mac_type = ixgbe_mac_unknown;
+#ifdef HAVE_TX_MQ
+	unsigned int indices = MAX_TX_QUEUES;
+#endif /* HAVE_TX_MQ */
 	bool disable_dev = false;
-#ifdef IXGBE_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 	u16 device_caps;
 #endif
-	u32 eec;
-
-	/* Catch broken hardware that put the wrong VF device ID in
-	 * the PCIe SR-IOV capability.
-	 */
-	if (pdev->is_virtfn) {
-		WARN(1, KERN_ERR "%s (%hx:%hx) should not be a VF!\n",
-		     pci_name(pdev), pdev->vendor, pdev->device);
-		return -EINVAL;
-	}
+#ifndef NETIF_F_GSO_PARTIAL
+#ifdef HAVE_NDO_SET_FEATURES
+#ifndef HAVE_RHEL6_NET_DEVICE_OPS_EXT
+	netdev_features_t hw_features;
+#else
+	u32 hw_features;
+#endif
+#endif
+#endif /* NETIF_F_GSO_PARTIAL */
 
 	err = pci_enable_device_mem(pdev);
 	if (err)
 		return err;
 
-	if (!dma_set_mask_and_coherent(&pdev->dev, DMA_BIT_MASK(64))) {
+	if (!dma_set_mask(pci_dev_to_dev(pdev), DMA_BIT_MASK(64)) &&
+	    !dma_set_coherent_mask(pci_dev_to_dev(pdev), DMA_BIT_MASK(64))) {
 		pci_using_dac = 1;
 	} else {
-		err = dma_set_mask_and_coherent(&pdev->dev, DMA_BIT_MASK(32));
+		err = dma_set_mask(pci_dev_to_dev(pdev), DMA_BIT_MASK(32));
 		if (err) {
-			dev_err(&pdev->dev,
-				"No usable DMA configuration, aborting\n");
-			goto err_dma;
+			err = dma_set_coherent_mask(pci_dev_to_dev(pdev),
+						    DMA_BIT_MASK(32));
+			if (err) {
+				dev_err(pci_dev_to_dev(pdev), "No usable DMA "
+					"configuration, aborting\n");
+				goto err_dma;
+			}
 		}
 		pci_using_dac = 0;
 	}
 
-	err = pci_request_selected_regions(pdev, pci_select_bars(pdev,
-					   IORESOURCE_MEM), ixgbe_driver_name);
+	err = pci_request_mem_regions(pdev, ixgbe_driver_name);
 	if (err) {
-		dev_err(&pdev->dev,
+		dev_err(pci_dev_to_dev(pdev),
 			"pci_request_selected_regions failed 0x%x\n", err);
 		goto err_pci_reg;
 	}
 
+	/*
+	 * The mac_type is needed before we have the adapter is  set up
+	 * so rather than maintain two devID -> MAC tables we dummy up
+	 * an ixgbe_hw stuct and use ixgbe_set_mac_type.
+	 */
+	hw = vmalloc(sizeof(struct ixgbe_hw));
+	if (!hw) {
+		pr_info("Unable to allocate memory for early mac "
+			"check\n");
+	} else {
+		hw->vendor_id = pdev->vendor;
+		hw->device_id = pdev->device;
+		ixgbe_set_mac_type(hw);
+		mac_type = hw->mac.type;
+		vfree(hw);
+	}
+
+	/*
+	 * Workaround of Silicon errata on 82598. Disable LOs in the PCI switch
+	 * port to which the 82598 is connected to prevent duplicate
+	 * completions caused by LOs.  We need the mac type so that we only
+	 * do this on 82598 devices, ixgbe_set_mac_type does this for us if
+	 * we set it's device ID.
+	 */
+	if (mac_type == ixgbe_mac_82598EB)
+		pci_disable_link_state(pdev, PCIE_LINK_STATE_L0S);
+
 	pci_enable_pcie_error_reporting(pdev);
 
 	pci_set_master(pdev);
-	pci_save_state(pdev);
 
-	if (ii->mac == ixgbe_mac_82598EB) {
-#ifdef CONFIG_IXGBE_DCB
-		/* 8 TC w/ 4 queues per TC */
-		indices = 4 * MAX_TRAFFIC_CLASS;
-#else
+#ifdef HAVE_TX_MQ
+	if (mac_type == ixgbe_mac_82598EB) {
+#if IS_ENABLED(CONFIG_DCB)
+		indices = IXGBE_MAX_DCB_INDICES * 4;
+#else /* CONFIG_DCB */
 		indices = IXGBE_MAX_RSS_INDICES;
-#endif
+#endif /* !CONFIG_DCB */
 	}
 
 	netdev = alloc_etherdev_mq(sizeof(struct ixgbe_adapter), indices);
+#else /* HAVE_TX_MQ */
+	netdev = alloc_etherdev(sizeof(struct ixgbe_adapter));
+#endif /* HAVE_TX_MQ */
 	if (!netdev) {
 		err = -ENOMEM;
 		goto err_alloc_etherdev;
 	}
 
-	SET_NETDEV_DEV(netdev, &pdev->dev);
+	SET_MODULE_OWNER(netdev);
+	SET_NETDEV_DEV(netdev, pci_dev_to_dev(pdev));
 
 	adapter = netdev_priv(netdev);
-
+#ifdef HAVE_TX_MQ
+#ifndef HAVE_NETDEV_SELECT_QUEUE
+	adapter->indices = indices;
+#endif
+#endif
 	adapter->netdev = netdev;
 	adapter->pdev = pdev;
 	hw = &adapter->hw;
 	hw->back = adapter;
-	adapter->msg_enable = netif_msg_init(debug, DEFAULT_MSG_ENABLE);
+	adapter->msg_enable = (1 << DEFAULT_DEBUG_LEVEL_SHIFT) - 1;
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	adapter->state_cache.speed = 0;
+	adapter->state_cache.link = 1;
+	adapter->state_cache.down_tv = ~0UL;
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
 
 	hw->hw_addr = ioremap(pci_resource_start(pdev, 0),
 			      pci_resource_len(pdev, 0));
@@ -8676,51 +10806,29 @@ static int ixgbe_probe(struct pci_dev *pdev, const struct pci_device_id *ent)
 		goto err_ioremap;
 	}
 
-	netdev->netdev_ops = &ixgbe_netdev_ops;
-	ixgbe_set_ethtool_ops(netdev);
-	netdev->watchdog_timeo = 5 * HZ;
-	strlcpy(netdev->name, pci_name(pdev), sizeof(netdev->name));
+	ixgbe_assign_netdev_ops(netdev);
 
-	/* Setup hw api */
-	memcpy(&hw->mac.ops, ii->mac_ops, sizeof(hw->mac.ops));
-	hw->mac.type  = ii->mac;
-	hw->mvals     = ii->mvals;
+	strncpy(netdev->name, pci_name(pdev), sizeof(netdev->name) - 1);
 
-	/* EEPROM */
-	memcpy(&hw->eeprom.ops, ii->eeprom_ops, sizeof(hw->eeprom.ops));
-	eec = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
-	if (ixgbe_removed(hw->hw_addr)) {
-		err = -EIO;
-		goto err_ioremap;
-	}
-	/* If EEPROM is valid (bit 8 = 1), use default otherwise use bit bang */
-	if (!(eec & (1 << 8)))
-		hw->eeprom.ops.read = &ixgbe_read_eeprom_bit_bang_generic;
-
-	/* PHY */
-	memcpy(&hw->phy.ops, ii->phy_ops, sizeof(hw->phy.ops));
-	hw->phy.sfp_type = ixgbe_sfp_type_unknown;
-	/* ixgbe_identify_phy_generic will set prtad and mmds properly */
-	hw->phy.mdio.prtad = MDIO_PRTAD_NONE;
-	hw->phy.mdio.mmds = 0;
-	hw->phy.mdio.mode_support = MDIO_SUPPORTS_C45 | MDIO_EMULATE_C22;
-	hw->phy.mdio.dev = netdev;
-	hw->phy.mdio.mdio_read = ixgbe_mdio_read;
-	hw->phy.mdio.mdio_write = ixgbe_mdio_write;
-
-	ii->get_invariants(hw);
+	adapter->bd_number = cards_found;
 
+	ixgbe_get_hw_control(adapter);
 	/* setup the private structure */
 	err = ixgbe_sw_init(adapter);
 	if (err)
 		goto err_sw_init;
 
+	/* Make sure the SWFW semaphore is in a valid state */
+	if (hw->mac.ops.init_swfw_sync)
+		hw->mac.ops.init_swfw_sync(hw);
+
 	/* Make it possible the adapter to be woken up via WOL */
 	switch (adapter->hw.mac.type) {
 	case ixgbe_mac_82599EB:
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		IXGBE_WRITE_REG(&adapter->hw, IXGBE_WUS, ~0);
 		break;
 	default:
@@ -8728,8 +10836,8 @@ static int ixgbe_probe(struct pci_dev *pdev, const struct pci_device_id *ent)
 	}
 
 	/*
-	 * If there is a fan on this device and it has failed log the
-	 * failure.
+	 * If we have a fan, this is as early we know, warn if we
+	 * have had a failure.
 	 */
 	if (adapter->flags & IXGBE_FLAG_FAN_FAIL_CAPABLE) {
 		u32 esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
@@ -8737,18 +10845,23 @@ static int ixgbe_probe(struct pci_dev *pdev, const struct pci_device_id *ent)
 			e_crit(probe, "Fan has stopped, replace the adapter\n");
 	}
 
-	if (allow_unsupported_sfp)
-		hw->allow_unsupported_sfp = allow_unsupported_sfp;
+	/*
+	 * check_options must be called before setup_link to set up
+	 * hw->fc completely
+	 */
+	ixgbe_check_options(adapter);
 
 	/* reset_hw fills in the perm_addr as well */
 	hw->phy.reset_if_overtemp = true;
 	err = hw->mac.ops.reset_hw(hw);
 	hw->phy.reset_if_overtemp = false;
 	if (err == IXGBE_ERR_SFP_NOT_PRESENT) {
-		err = 0;
+		err = IXGBE_SUCCESS;
 	} else if (err == IXGBE_ERR_SFP_NOT_SUPPORTED) {
-		e_dev_err("failed to load because an unsupported SFP+ or QSFP module type was detected.\n");
-		e_dev_err("Reload the driver after installing a supported module.\n");
+		e_dev_err("failed to load because an unsupported SFP+ or QSFP "
+			  "module type was detected.\n");
+		e_dev_err("Reload the driver after installing a supported "
+			  "module.\n");
 		goto err_sw_init;
 	} else if (err) {
 		e_dev_err("HW Init failed: %d\n", err);
@@ -8756,116 +10869,239 @@ static int ixgbe_probe(struct pci_dev *pdev, const struct pci_device_id *ent)
 	}
 
 #ifdef CONFIG_PCI_IOV
-	/* SR-IOV not supported on the 82598 */
-	if (adapter->hw.mac.type == ixgbe_mac_82598EB)
-		goto skip_sriov;
-	/* Mailbox */
-	ixgbe_init_mbx_params_pf(hw);
-	memcpy(&hw->mbx.ops, ii->mbx_ops, sizeof(hw->mbx.ops));
-	pci_sriov_set_totalvfs(pdev, IXGBE_MAX_VFS_DRV_LIMIT);
-	ixgbe_enable_sriov(adapter);
-skip_sriov:
+#if defined(HAVE_SRIOV_CONFIGURE) || defined(HAVE_RHEL6_SRIOV_CONFIGURE)
+	if (adapter->max_vfs > 0) {
+		e_dev_warn("Enabling SR-IOV VFs using the max_vfs module parameter is deprecated.\n");
+		e_dev_warn("Please use the pci sysfs interface instead. Ex:\n");
+		e_dev_warn("echo '%d' > /sys/bus/pci/devices/%04x:%02x:%02x.%1x/sriov_numvfs\n",
+			   adapter->max_vfs,
+			   pci_domain_nr(pdev->bus),
+			   pdev->bus->number,
+			   PCI_SLOT(pdev->devfn),
+			   PCI_FUNC(pdev->devfn)
+			   );
+	}
+
+#endif
+	if (adapter->flags & IXGBE_FLAG_SRIOV_CAPABLE) {
+		pci_sriov_set_totalvfs(pdev, IXGBE_MAX_VFS_DRV_LIMIT);
+		ixgbe_enable_sriov(adapter);
+	}
+
+#endif /* CONFIG_PCI_IOV */
 
-#endif
+#ifdef NETIF_F_GSO_PARTIAL
 	netdev->features = NETIF_F_SG |
-			   NETIF_F_IP_CSUM |
-			   NETIF_F_IPV6_CSUM |
-			   NETIF_F_HW_VLAN_CTAG_TX |
-			   NETIF_F_HW_VLAN_CTAG_RX |
 			   NETIF_F_TSO |
 			   NETIF_F_TSO6 |
 			   NETIF_F_RXHASH |
-			   NETIF_F_RXCSUM;
+			   NETIF_F_RXCSUM |
+			   NETIF_F_HW_CSUM;
+
+	netdev->gso_partial_features = IXGBE_GSO_PARTIAL_FEATURES;
+	netdev->features |= NETIF_F_GSO_PARTIAL |
+			    IXGBE_GSO_PARTIAL_FEATURES;
+
+	if (hw->mac.type >= ixgbe_mac_82599EB)
+		netdev->features |= NETIF_F_SCTP_CRC;
+
+	/* copy netdev features into list of user selectable features */
+	netdev->hw_features |= netdev->features |
+			       NETIF_F_HW_VLAN_CTAG_FILTER |
+			       NETIF_F_HW_VLAN_CTAG_RX |
+			       NETIF_F_HW_VLAN_CTAG_TX |
+			       NETIF_F_RXALL;
+
+	if (hw->mac.type >= ixgbe_mac_82599EB)
+		netdev->hw_features |= NETIF_F_NTUPLE |
+				       NETIF_F_HW_TC;
+
+	if (pci_using_dac)
+		netdev->features |= NETIF_F_HIGHDMA;
+
+	netdev->vlan_features |= netdev->features | NETIF_F_TSO_MANGLEID;
+	netdev->hw_enc_features |= netdev->vlan_features;
+	netdev->mpls_features |= NETIF_F_HW_CSUM;
+
+	/* set this bit last since it cannot be part of vlan_features */
+	netdev->features |= NETIF_F_HW_VLAN_CTAG_FILTER |
+			    NETIF_F_HW_VLAN_CTAG_RX |
+			    NETIF_F_HW_VLAN_CTAG_TX;
+
+	netdev->priv_flags |= IFF_UNICAST_FLT;
+	netdev->priv_flags |= IFF_SUPP_NOFCS;
+
+	/* give us the option of enabling RSC/LRO later */
+	if (adapter->flags2 & IXGBE_FLAG2_RSC_CAPABLE)
+		netdev->hw_features |= NETIF_F_LRO;
+
+#else	/* NETIF_F_GSO_PARTIAL */
+	netdev->features |= NETIF_F_SG |
+			    NETIF_F_IP_CSUM;
 
-	netdev->hw_features = netdev->features | NETIF_F_HW_L2FW_DOFFLOAD;
+#ifdef NETIF_F_IPV6_CSUM
+	netdev->features |= NETIF_F_IPV6_CSUM;
+#endif
+
+#ifdef NETIF_F_HW_VLAN_CTAG_TX
+	netdev->features |= NETIF_F_HW_VLAN_CTAG_TX |
+			    NETIF_F_HW_VLAN_CTAG_FILTER |
+			    NETIF_F_HW_VLAN_CTAG_RX;
+#endif
+
+#ifdef NETIF_F_HW_VLAN_TX
+	netdev->features |= NETIF_F_HW_VLAN_TX |
+			    NETIF_F_HW_VLAN_FILTER |
+			    NETIF_F_HW_VLAN_RX;
+#endif
+	netdev->features |= ixgbe_tso_features();
+#ifdef NETIF_F_RXHASH
+	netdev->features |= NETIF_F_RXHASH;
+#endif /* NETIF_F_RXHASH */
+	netdev->features |= NETIF_F_RXCSUM;
+
+#ifdef HAVE_NDO_SET_FEATURES
+	/* copy netdev features into list of user selectable features */
+#ifndef HAVE_RHEL6_NET_DEVICE_OPS_EXT
+	hw_features = netdev->hw_features;
+#else
+	hw_features = get_netdev_hw_features(netdev);
+#endif
+	hw_features |= netdev->features;
+
+	/* give us the option of enabling RSC/LRO later */
+	if (adapter->flags2 & IXGBE_FLAG2_RSC_CAPABLE)
+		hw_features |= NETIF_F_LRO;
+
+#else
+#ifdef NETIF_F_GRO
+
+	/* this is only needed on kernels prior to 2.6.39 */
+	netdev->features |= NETIF_F_GRO;
+#endif /* NETIF_F_GRO */
+#endif /* HAVE_NDO_SET_FEATURES */
 
 	switch (adapter->hw.mac.type) {
 	case ixgbe_mac_82599EB:
 	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		netdev->features |= NETIF_F_SCTP_CSUM;
-		netdev->hw_features |= NETIF_F_SCTP_CSUM |
+#ifdef HAVE_NDO_SET_FEATURES
+		hw_features |= NETIF_F_SCTP_CSUM |
 				       NETIF_F_NTUPLE;
+#endif
 		break;
 	default:
 		break;
 	}
+#ifdef HAVE_NDO_SET_FEATURES
+#ifdef HAVE_RHEL6_NET_DEVICE_OPS_EXT
+	set_netdev_hw_features(netdev, hw_features);
+#else
+	netdev->hw_features = hw_features;
+#endif
+#endif
 
-	netdev->hw_features |= NETIF_F_RXALL;
-	netdev->features |= NETIF_F_HW_VLAN_CTAG_FILTER;
-
-	netdev->vlan_features |= NETIF_F_TSO;
-	netdev->vlan_features |= NETIF_F_TSO6;
-	netdev->vlan_features |= NETIF_F_IP_CSUM;
-	netdev->vlan_features |= NETIF_F_IPV6_CSUM;
-	netdev->vlan_features |= NETIF_F_SG;
-
-	netdev->hw_enc_features |= NETIF_F_SG | NETIF_F_IP_CSUM |
-				   NETIF_F_IPV6_CSUM;
+#ifdef HAVE_NETDEV_VLAN_FEATURES
+	netdev->vlan_features |= NETIF_F_SG |
+				 NETIF_F_IP_CSUM |
+				 NETIF_F_IPV6_CSUM |
+				 NETIF_F_TSO |
+				 NETIF_F_TSO6;
+
+#endif /* HAVE_NETDEV_VLAN_FEATURES */
+#ifdef HAVE_ENCAP_CSUM_OFFLOAD
+	netdev->hw_enc_features |= NETIF_F_SG;
+#endif /* HAVE_ENCAP_CSUM_OFFLOAD */
+#ifdef HAVE_VXLAN_RX_OFFLOAD
+	if (adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE) {
+		netdev->hw_enc_features |= NETIF_F_IP_CSUM |
+					   NETIF_F_IPV6_CSUM;
+	}
+#endif /* NETIF_F_GSO_PARTIAL */
 
+#endif /* HAVE_VXLAN_RX_OFFLOAD */
+	if (netdev->features & NETIF_F_LRO) {
+		if ((adapter->flags2 & IXGBE_FLAG2_RSC_CAPABLE) &&
+		    ((adapter->rx_itr_setting == 1) ||
+		     (adapter->rx_itr_setting > IXGBE_MIN_RSC_ITR))) {
+			adapter->flags2 |= IXGBE_FLAG2_RSC_ENABLED;
+		} else if (adapter->flags2 & IXGBE_FLAG2_RSC_CAPABLE) {
+			e_dev_info("InterruptThrottleRate set too high, "
+				   "disabling RSC\n");
+		}
+	}
+#ifdef IFF_UNICAST_FLT
 	netdev->priv_flags |= IFF_UNICAST_FLT;
+#endif
+#ifdef IFF_SUPP_NOFCS
 	netdev->priv_flags |= IFF_SUPP_NOFCS;
+#endif
 
-#ifdef CONFIG_IXGBE_VXLAN
-	switch (adapter->hw.mac.type) {
-	case ixgbe_mac_X550:
-	case ixgbe_mac_X550EM_x:
-		netdev->hw_enc_features |= NETIF_F_RXCSUM |
-					   NETIF_F_IP_CSUM |
-					   NETIF_F_IPV6_CSUM;
-		break;
-	default:
-		break;
-	}
-#endif /* CONFIG_IXGBE_VXLAN */
+#ifdef HAVE_NETDEVICE_MIN_MAX_MTU
+	/* MTU range: 68 - 9710 */
+	netdev->min_mtu = ETH_MIN_MTU;
+	netdev->max_mtu = IXGBE_MAX_JUMBO_FRAME_SIZE - (ETH_HLEN + ETH_FCS_LEN);
 
-#ifdef CONFIG_IXGBE_DCB
-	netdev->dcbnl_ops = &dcbnl_ops;
 #endif
+#if IS_ENABLED(CONFIG_DCB)
+	if (adapter->flags & IXGBE_FLAG_DCB_CAPABLE)
+		netdev->dcbnl_ops = &ixgbe_dcbnl_ops;
 
-#ifdef IXGBE_FCOE
+#endif /* CONFIG_DCB */
+#if IS_ENABLED(CONFIG_FCOE)
+#ifdef NETIF_F_FSO
 	if (adapter->flags & IXGBE_FLAG_FCOE_CAPABLE) {
 		unsigned int fcoe_l;
 
-		if (hw->mac.ops.get_device_caps) {
-			hw->mac.ops.get_device_caps(hw, &device_caps);
-			if (device_caps & IXGBE_DEVICE_CAPS_FCOE_OFFLOADS)
-				adapter->flags &= ~IXGBE_FLAG_FCOE_CAPABLE;
+		hw->mac.ops.get_device_caps(hw, &device_caps);
+		if (device_caps & IXGBE_DEVICE_CAPS_FCOE_OFFLOADS) {
+			adapter->flags &= ~IXGBE_FLAG_FCOE_ENABLED;
+			adapter->flags &= ~IXGBE_FLAG_FCOE_CAPABLE;
+			e_dev_info("FCoE offload feature is not available. "
+				   "Disabling FCoE offload feature\n");
+		} else {
+			netdev->features |= NETIF_F_FSO |
+					    NETIF_F_FCOE_CRC;
+#ifndef HAVE_NETDEV_OPS_FCOE_ENABLE
+			ixgbe_fcoe_ddp_enable(adapter);
+			adapter->flags |= IXGBE_FLAG_FCOE_ENABLED;
+			netdev->features |= NETIF_F_FCOE_MTU;
+#endif /* HAVE_NETDEV_OPS_FCOE_ENABLE */
 		}
 
-
 		fcoe_l = min_t(int, IXGBE_FCRETA_SIZE, num_online_cpus());
 		adapter->ring_feature[RING_F_FCOE].limit = fcoe_l;
 
-		netdev->features |= NETIF_F_FSO |
-				    NETIF_F_FCOE_CRC;
-
+#ifdef HAVE_NETDEV_VLAN_FEATURES
 		netdev->vlan_features |= NETIF_F_FSO |
 					 NETIF_F_FCOE_CRC |
 					 NETIF_F_FCOE_MTU;
+#endif /* HAVE_NETDEV_VLAN_FEATURES */
 	}
-#endif /* IXGBE_FCOE */
+#endif /* NETIF_F_FSO */
+#endif /* CONFIG_FCOE */
 	if (pci_using_dac) {
 		netdev->features |= NETIF_F_HIGHDMA;
+#ifdef HAVE_NETDEV_VLAN_FEATURES
 		netdev->vlan_features |= NETIF_F_HIGHDMA;
+#endif /* HAVE_NETDEV_VLAN_FEATURES */
 	}
 
-	if (adapter->flags2 & IXGBE_FLAG2_RSC_CAPABLE)
-		netdev->hw_features |= NETIF_F_LRO;
-	if (adapter->flags2 & IXGBE_FLAG2_RSC_ENABLED)
-		netdev->features |= NETIF_F_LRO;
-
 	/* make sure the EEPROM is good */
-	if (hw->eeprom.ops.validate_checksum(hw, NULL) < 0) {
+	if (hw->eeprom.ops.validate_checksum &&
+	    (hw->eeprom.ops.validate_checksum(hw, NULL) < 0)) {
 		e_dev_err("The EEPROM Checksum Is Not Valid\n");
 		err = -EIO;
 		goto err_sw_init;
 	}
 
-	ixgbe_get_platform_mac_addr(adapter);
-
 	memcpy(netdev->dev_addr, hw->mac.perm_addr, netdev->addr_len);
+#ifdef ETHTOOL_GPERMADDR
+	memcpy(netdev->perm_addr, hw->mac.perm_addr, netdev->addr_len);
+#endif
 
 	if (!is_valid_ether_addr(netdev->dev_addr)) {
 		e_dev_err("invalid MAC address\n");
@@ -8873,12 +11109,14 @@ skip_sriov:
 		goto err_sw_init;
 	}
 
-	ixgbe_mac_set_default_filter(adapter, hw->mac.perm_addr);
+	/* Set hw->mac.addr to permanent MAC address */
+	ether_addr_copy(hw->mac.addr, hw->mac.perm_addr);
+	ixgbe_mac_set_default_filter(adapter);
 
 	setup_timer(&adapter->service_timer, &ixgbe_service_timer,
 		    (unsigned long) adapter);
 
-	if (ixgbe_removed(hw->hw_addr)) {
+	if (IXGBE_REMOVED(hw->hw_addr)) {
 		err = -EIO;
 		goto err_sw_init;
 	}
@@ -8893,53 +11131,14 @@ skip_sriov:
 	/* WOL not supported for all devices */
 	adapter->wol = 0;
 	hw->eeprom.ops.read(hw, 0x2c, &adapter->eeprom_cap);
-	hw->wol_enabled = ixgbe_wol_supported(adapter, pdev->device,
-						pdev->subsystem_device);
-	if (hw->wol_enabled)
+	if (ixgbe_wol_supported(adapter, pdev->device, pdev->subsystem_device))
 		adapter->wol = IXGBE_WUFC_MAG;
 
-	device_set_wakeup_enable(&adapter->pdev->dev, adapter->wol);
-
-	/* save off EEPROM version number */
-	hw->eeprom.ops.read(hw, 0x2e, &adapter->eeprom_verh);
-	hw->eeprom.ops.read(hw, 0x2d, &adapter->eeprom_verl);
-
-	/* pick up the PCI bus settings for reporting later */
-	if (ixgbe_pcie_from_parent(hw))
-		ixgbe_get_parent_bus_info(adapter);
-	else
-		 hw->mac.ops.get_bus_info(hw);
-
-	/* calculate the expected PCIe bandwidth required for optimal
-	 * performance. Note that some older parts will never have enough
-	 * bandwidth due to being older generation PCIe parts. We clamp these
-	 * parts to ensure no warning is displayed if it can't be fixed.
-	 */
-	switch (hw->mac.type) {
-	case ixgbe_mac_82598EB:
-		expected_gts = min(ixgbe_enumerate_functions(adapter) * 10, 16);
-		break;
-	default:
-		expected_gts = ixgbe_enumerate_functions(adapter) * 10;
-		break;
-	}
-
-	/* don't check link if we failed to enumerate functions */
-	if (expected_gts > 0)
-		ixgbe_check_minimum_link(adapter, expected_gts);
+	hw->wol_enabled = !!(adapter->wol);
 
-	err = ixgbe_read_pba_string_generic(hw, part_str, sizeof(part_str));
-	if (err)
-		strlcpy(part_str, "Unknown", sizeof(part_str));
-	if (ixgbe_is_sfp(hw) && hw->phy.sfp_type != ixgbe_sfp_type_not_present)
-		e_dev_info("MAC: %d, PHY: %d, SFP+: %d, PBA No: %s\n",
-			   hw->mac.type, hw->phy.type, hw->phy.sfp_type,
-			   part_str);
-	else
-		e_dev_info("MAC: %d, PHY: %d, PBA No: %s\n",
-			   hw->mac.type, hw->phy.type, part_str);
+	device_set_wakeup_enable(pci_dev_to_dev(adapter->pdev), adapter->wol);
 
-	e_dev_info("%pM\n", netdev->dev_addr);
+	ixgbe_set_fw_version(adapter);
 
 	/* reset the hardware with the new settings */
 	err = hw->mac.ops.start_hw(hw);
@@ -8951,13 +11150,36 @@ skip_sriov:
 			   "problems please contact your Intel or hardware "
 			   "representative who provided you with this "
 			   "hardware.\n");
+	} else if (err == IXGBE_ERR_OVERTEMP) {
+		e_crit(drv, "%s\n", ixgbe_overheat_msg);
+		goto err_register;
+	} else if (err) {
+		e_dev_err("HW init failed\n");
+		goto err_register;
 	}
+
+	/* pick up the PCI bus settings for reporting later */
+	if (ixgbe_pcie_from_parent(hw))
+		ixgbe_get_parent_bus_info(hw);
+	else
+		if (hw->mac.ops.get_bus_info)
+			hw->mac.ops.get_bus_info(hw);
+
 	strcpy(netdev->name, "eth%d");
 	err = register_netdev(netdev);
 	if (err)
 		goto err_register;
 
 	pci_set_drvdata(pdev, adapter);
+	adapter->netdev_registered = true;
+#ifdef HAVE_PCI_ERS
+	/*
+	 * call save state here in standalone driver because it relies on
+	 * adapter struct to exist, and needs to call netdev_priv
+	 */
+	pci_save_state(pdev);
+
+#endif
 
 	/* power down the optics for 82599 SFP+ fiber */
 	if (hw->mac.ops.disable_tx_laser)
@@ -8965,37 +11187,137 @@ skip_sriov:
 
 	/* carrier off reporting is important to ethtool even BEFORE open */
 	netif_carrier_off(netdev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	kernevnt_LanAct_params(netdev->name, 0, 1);
+#endif /* CONFIG_BUFFALO_USE_KERNEVNT */
+	/* keep stopping all the transmit queues for older kernels */
+	netif_tx_stop_all_queues(netdev);
 
-#ifdef CONFIG_IXGBE_DCA
-	if (dca_add_requester(&pdev->dev) == 0) {
-		adapter->flags |= IXGBE_FLAG_DCA_ENABLED;
-		ixgbe_setup_dca(adapter);
+#if IS_ENABLED(CONFIG_DCA)
+	if (adapter->flags & IXGBE_FLAG_DCA_CAPABLE) {
+		err = dca_add_requester(pci_dev_to_dev(pdev));
+		switch (err) {
+		case IXGBE_SUCCESS:
+			adapter->flags |= IXGBE_FLAG_DCA_ENABLED;
+			ixgbe_setup_dca(adapter);
+			break;
+		/* -19 is returned from the kernel when no provider is found */
+		case -19:
+			e_info(rx_err, "No DCA provider found. Please "
+			       "start ioatdma for DCA functionality.\n");
+			break;
+		default:
+			e_info(probe, "DCA registration failed: %d\n", err);
+			break;
+		}
+	}
+#endif
+
+	/* print all messages at the end so that we use our eth%d name */
+
+	/* calculate the expected PCIe bandwidth required for optimal
+	 * performance. Note that some older parts will never have enough
+	 * bandwidth due to being older generation PCIe parts. We clamp these
+	 * parts to ensure that no warning is displayed, as this could confuse
+	 * users otherwise. */
+	switch(hw->mac.type) {
+	case ixgbe_mac_82598EB:
+		expected_gts = min(ixgbe_enumerate_functions(adapter) * 10, 16);
+		break;
+	default:
+		expected_gts = ixgbe_enumerate_functions(adapter) * 10;
+		break;
 	}
+
+	/* don't check link if we failed to enumerate functions */
+	if (expected_gts > 0)
+		ixgbe_check_minimum_link(adapter, expected_gts);
+
+	/* First try to read PBA as a string */
+	err = ixgbe_read_pba_string(hw, part_str, IXGBE_PBANUM_LENGTH);
+	if (err)
+		strncpy(part_str, "Unknown", IXGBE_PBANUM_LENGTH);
+	if (ixgbe_is_sfp(hw) && hw->phy.sfp_type != ixgbe_sfp_type_not_present)
+		e_info(probe, "MAC: %d, PHY: %d, SFP+: %d, PBA No: %s\n",
+		       hw->mac.type, hw->phy.type, hw->phy.sfp_type, part_str);
+	else
+		e_info(probe, "MAC: %d, PHY: %d, PBA No: %s\n",
+		      hw->mac.type, hw->phy.type, part_str);
+
+	e_dev_info("%02x:%02x:%02x:%02x:%02x:%02x\n",
+		   netdev->dev_addr[0], netdev->dev_addr[1],
+		   netdev->dev_addr[2], netdev->dev_addr[3],
+		   netdev->dev_addr[4], netdev->dev_addr[5]);
+
+#define INFO_STRING_LEN 255
+	info_string = kzalloc(INFO_STRING_LEN, GFP_KERNEL);
+	if (!info_string) {
+		e_err(probe, "allocation for info string failed\n");
+		goto no_info_string;
+	}
+	i_s_var = info_string;
+	i_s_var += sprintf(info_string, "Enabled Features: ");
+	i_s_var += sprintf(i_s_var, "RxQ: %d TxQ: %d ",
+			   adapter->num_rx_queues, adapter->num_tx_queues);
+#if IS_ENABLED(CONFIG_FCOE)
+	if (adapter->flags & IXGBE_FLAG_FCOE_ENABLED)
+		i_s_var += sprintf(i_s_var, "FCoE ");
 #endif
+	if (adapter->flags & IXGBE_FLAG_FDIR_HASH_CAPABLE)
+		i_s_var += sprintf(i_s_var, "FdirHash ");
+	if (adapter->flags & IXGBE_FLAG_DCB_ENABLED)
+		i_s_var += sprintf(i_s_var, "DCB ");
+	if (adapter->flags & IXGBE_FLAG_DCA_ENABLED)
+		i_s_var += sprintf(i_s_var, "DCA ");
+	if (adapter->flags2 & IXGBE_FLAG2_RSC_ENABLED)
+		i_s_var += sprintf(i_s_var, "RSC ");
+	if (adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_ENABLE)
+		i_s_var += sprintf(i_s_var, "vxlan_rx ");
+
+	BUG_ON(i_s_var > (info_string + INFO_STRING_LEN));
+	/* end features printing */
+	e_info(probe, "%s\n", info_string);
+	kfree(info_string);
+no_info_string:
+#ifdef CONFIG_PCI_IOV
 	if (adapter->flags & IXGBE_FLAG_SRIOV_ENABLED) {
-		e_info(probe, "IOV is enabled with %d VFs\n", adapter->num_vfs);
+		int i;
 		for (i = 0; i < adapter->num_vfs; i++)
 			ixgbe_vf_configuration(pdev, (i | 0x10000000));
 	}
+#endif
 
-	/* firmware requires driver version to be 0xFFFFFFFF
-	 * since os does not support feature
-	 */
+	/* Initialize the LED link active for LED blink support */
+	if (hw->mac.ops.init_led_link_act)
+		hw->mac.ops.init_led_link_act(hw);
+
+	/* firmware requires blank numerical version */
 	if (hw->mac.ops.set_fw_drv_ver)
-		hw->mac.ops.set_fw_drv_ver(hw, 0xFF, 0xFF, 0xFF,
-					   0xFF);
+		hw->mac.ops.set_fw_drv_ver(hw, 0xFF, 0xFF, 0xFF, 0xFF,
+					   sizeof(ixgbe_driver_version) - 1,
+					   ixgbe_driver_version);
 
+#if defined(HAVE_NETDEV_STORAGE_ADDRESS) && defined(NETDEV_HW_ADDR_T_SAN)
 	/* add san mac addr to netdev */
 	ixgbe_add_sanmac_netdev(netdev);
 
-	e_dev_info("%s\n", ixgbe_default_device_descr);
+#endif /* (HAVE_NETDEV_STORAGE_ADDRESS) && (NETDEV_HW_ADDR_T_SAN) */
+	e_info(probe, "Intel(R) 10 Gigabit Network Connection\n");
+	cards_found++;
 
-#ifdef CONFIG_IXGBE_HWMON
+#ifdef IXGBE_SYSFS
 	if (ixgbe_sysfs_init(adapter))
 		e_err(probe, "failed to allocate sysfs resources\n");
-#endif /* CONFIG_IXGBE_HWMON */
+#else
+#ifdef IXGBE_PROCFS
+	if (ixgbe_procfs_init(adapter))
+		e_err(probe, "failed to allocate procfs resources\n");
+#endif /* IXGBE_PROCFS */
+#endif /* IXGBE_SYSFS */
+#ifdef HAVE_IXGBE_DEBUG_FS
 
 	ixgbe_dbg_adapter_init(adapter);
+#endif /* HAVE_IXGBE_DEBUG_FS */
 
 	/* setup link for SFP devices with MNG FW, else wait for IXGBE_UP */
 	if (ixgbe_mng_enabled(hw) && ixgbe_is_sfp(hw) && hw->mac.ops.setup_link)
@@ -9003,22 +11325,31 @@ skip_sriov:
 			IXGBE_LINK_SPEED_10GB_FULL | IXGBE_LINK_SPEED_1GB_FULL,
 			true);
 
+	if (hw->mac.ops.setup_eee &&
+	    (adapter->flags2 & IXGBE_FLAG2_EEE_CAPABLE)) {
+		bool eee_enable = !!(adapter->flags2 & IXGBE_FLAG2_EEE_ENABLED);
+
+		hw->mac.ops.setup_eee(hw, eee_enable);
+	}
+
 	return 0;
 
 err_register:
-	ixgbe_release_hw_control(adapter);
 	ixgbe_clear_interrupt_scheme(adapter);
 err_sw_init:
+	ixgbe_release_hw_control(adapter);
+#ifdef CONFIG_PCI_IOV
 	ixgbe_disable_sriov(adapter);
+#endif /* CONFIG_PCI_IOV */
 	adapter->flags2 &= ~IXGBE_FLAG2_SEARCH_FOR_SFP;
-	iounmap(adapter->io_addr);
 	kfree(adapter->mac_table);
+	kfree(adapter->rss_key);
+	iounmap(adapter->io_addr);
 err_ioremap:
 	disable_dev = !test_and_set_bit(__IXGBE_DISABLED, &adapter->state);
 	free_netdev(netdev);
 err_alloc_etherdev:
-	pci_release_selected_regions(pdev,
-				     pci_select_bars(pdev, IORESOURCE_MEM));
+	pci_release_mem_regions(pdev);
 err_pci_reg:
 err_dma:
 	if (!adapter || disable_dev)
@@ -9035,7 +11366,7 @@ err_dma:
  * Hot-Plug event, or because the driver is going to be removed from
  * memory.
  **/
-static void ixgbe_remove(struct pci_dev *pdev)
+static void __devexit ixgbe_remove(struct pci_dev *pdev)
 {
 	struct ixgbe_adapter *adapter = pci_get_drvdata(pdev);
 	struct net_device *netdev;
@@ -9045,51 +11376,63 @@ static void ixgbe_remove(struct pci_dev *pdev)
 	if (!adapter)
 		return;
 
-	netdev  = adapter->netdev;
+	netdev = adapter->netdev;
+#ifdef HAVE_IXGBE_DEBUG_FS
 	ixgbe_dbg_adapter_exit(adapter);
 
-	set_bit(__IXGBE_REMOVING, &adapter->state);
+#endif /*HAVE_IXGBE_DEBUG_FS */
+	set_bit(__IXGBE_REMOVE, &adapter->state);
 	cancel_work_sync(&adapter->service_task);
 
-
-#ifdef CONFIG_IXGBE_DCA
+#if IS_ENABLED(CONFIG_DCA)
 	if (adapter->flags & IXGBE_FLAG_DCA_ENABLED) {
 		adapter->flags &= ~IXGBE_FLAG_DCA_ENABLED;
-		dca_remove_requester(&pdev->dev);
+		dca_remove_requester(pci_dev_to_dev(pdev));
 		IXGBE_WRITE_REG(&adapter->hw, IXGBE_DCA_CTRL,
 				IXGBE_DCA_CTRL_DCA_DISABLE);
 	}
+#endif /* CONFIG_DCA */
 
-#endif
-#ifdef CONFIG_IXGBE_HWMON
+#ifdef IXGBE_SYSFS
 	ixgbe_sysfs_exit(adapter);
-#endif /* CONFIG_IXGBE_HWMON */
+#else
+#ifdef IXGBE_PROCFS
+	ixgbe_procfs_exit(adapter);
+#endif /* IXGBE_PROCFS */
+#endif /* IXGBE-SYSFS */
 
+#if defined(HAVE_NETDEV_STORAGE_ADDRESS) && defined(NETDEV_HW_ADDR_T_SAN)
 	/* remove the added san mac */
 	ixgbe_del_sanmac_netdev(netdev);
 
+#endif /* (HAVE_NETDEV_STORAGE_ADDRESS) && (NETDEV_HW_ADDR_T_SAN) */
+
 #ifdef CONFIG_PCI_IOV
 	ixgbe_disable_sriov(adapter);
-#endif
-	if (netdev->reg_state == NETREG_REGISTERED)
+#endif /* CONFIG_PCI_IOV */
+	if (adapter->netdev_registered) {
 		unregister_netdev(netdev);
+		adapter->netdev_registered = false;
+	}
 
+#if IS_ENABLED(CONFIG_FCOE)
+#ifndef HAVE_NETDEV_OPS_FCOE_ENABLE
+	ixgbe_fcoe_ddp_disable(adapter);
+#endif
+#endif /* CONFIG_FCOE */
 	ixgbe_clear_interrupt_scheme(adapter);
-
 	ixgbe_release_hw_control(adapter);
 
-#ifdef CONFIG_DCB
+#ifdef HAVE_DCBNL_IEEE
 	kfree(adapter->ixgbe_ieee_pfc);
 	kfree(adapter->ixgbe_ieee_ets);
 
 #endif
 	iounmap(adapter->io_addr);
-	pci_release_selected_regions(pdev, pci_select_bars(pdev,
-				     IORESOURCE_MEM));
-
-	e_dev_info("complete\n");
+	pci_release_mem_regions(pdev);
 
 	kfree(adapter->mac_table);
+	kfree(adapter->rss_key);
 	disable_dev = !test_and_set_bit(__IXGBE_DISABLED, &adapter->state);
 	free_netdev(netdev);
 
@@ -9097,8 +11440,70 @@ static void ixgbe_remove(struct pci_dev *pdev)
 
 	if (disable_dev)
 		pci_disable_device(pdev);
+
+}
+
+static bool ixgbe_check_cfg_remove(struct ixgbe_hw *hw, struct pci_dev *pdev)
+{
+	u16 value;
+
+	pci_read_config_word(pdev, PCI_VENDOR_ID, &value);
+	if (value == IXGBE_FAILED_READ_CFG_WORD) {
+		ixgbe_remove_adapter(hw);
+		return true;
+	}
+	return false;
+}
+
+u16 ixgbe_read_pci_cfg_word(struct ixgbe_hw *hw, u32 reg)
+{
+	struct ixgbe_adapter *adapter = hw->back;
+	u16 value;
+
+	if (IXGBE_REMOVED(hw->hw_addr))
+		return IXGBE_FAILED_READ_CFG_WORD;
+	pci_read_config_word(adapter->pdev, reg, &value);
+	if (value == IXGBE_FAILED_READ_CFG_WORD &&
+	    ixgbe_check_cfg_remove(hw, adapter->pdev))
+		return IXGBE_FAILED_READ_CFG_WORD;
+	return value;
+}
+
+#ifdef HAVE_PCI_ERS
+#ifdef CONFIG_PCI_IOV
+static u32 ixgbe_read_pci_cfg_dword(struct ixgbe_hw *hw, u32 reg)
+{
+	struct ixgbe_adapter *adapter = hw->back;
+	u32 value;
+
+	if (IXGBE_REMOVED(hw->hw_addr))
+		return IXGBE_FAILED_READ_CFG_DWORD;
+	pci_read_config_dword(adapter->pdev, reg, &value);
+	if (value == IXGBE_FAILED_READ_CFG_DWORD &&
+	    ixgbe_check_cfg_remove(hw, adapter->pdev))
+		return IXGBE_FAILED_READ_CFG_DWORD;
+	return value;
+}
+#endif /* CONFIG_PCI_IOV */
+#endif /* HAVE_PCI_ERS */
+
+void ixgbe_write_pci_cfg_word(struct ixgbe_hw *hw, u32 reg, u16 value)
+{
+	struct ixgbe_adapter *adapter = hw->back;
+
+	if (IXGBE_REMOVED(hw->hw_addr))
+		return;
+	pci_write_config_word(adapter->pdev, reg, value);
 }
 
+void ewarn(struct ixgbe_hw *hw, const char *st)
+{
+	struct ixgbe_adapter *adapter = hw->back;
+
+	netif_warn(adapter, drv, adapter->netdev,  "%s", st);
+}
+
+#ifdef HAVE_PCI_ERS
 /**
  * ixgbe_io_error_detected - called when PCI error is detected
  * @pdev: Pointer to PCI device
@@ -9139,7 +11544,7 @@ static pci_ers_result_t ixgbe_io_error_detected(struct pci_dev *pdev,
 	dw1 = ixgbe_read_pci_cfg_dword(hw, pos + PCI_ERR_HEADER_LOG + 4);
 	dw2 = ixgbe_read_pci_cfg_dword(hw, pos + PCI_ERR_HEADER_LOG + 8);
 	dw3 = ixgbe_read_pci_cfg_dword(hw, pos + PCI_ERR_HEADER_LOG + 12);
-	if (ixgbe_removed(hw->hw_addr))
+	if (IXGBE_REMOVED(hw->hw_addr))
 		goto skip_bad_vf_detection;
 
 	req_id = dw1 >> 16;
@@ -9158,10 +11563,10 @@ static pci_ers_result_t ixgbe_io_error_detected(struct pci_dev *pdev,
 		dw0, dw1, dw2, dw3);
 		switch (adapter->hw.mac.type) {
 		case ixgbe_mac_82599EB:
-			device_id = IXGBE_82599_VF_DEVICE_ID;
+			device_id = IXGBE_DEV_ID_82599_VF;
 			break;
 		case ixgbe_mac_X540:
-			device_id = IXGBE_X540_VF_DEVICE_ID;
+			device_id = IXGBE_DEV_ID_X540_VF;
 			break;
 		case ixgbe_mac_X550:
 			device_id = IXGBE_DEV_ID_X550_VF;
@@ -9169,6 +11574,9 @@ static pci_ers_result_t ixgbe_io_error_detected(struct pci_dev *pdev,
 		case ixgbe_mac_X550EM_x:
 			device_id = IXGBE_DEV_ID_X550EM_X_VF;
 			break;
+		case ixgbe_mac_X550EM_a:
+			device_id = IXGBE_DEV_ID_X550EM_A_VF;
+			break;
 		default:
 			device_id = 0;
 			break;
@@ -9211,6 +11619,9 @@ skip_bad_vf_detection:
 	if (!test_bit(__IXGBE_SERVICE_INITED, &adapter->state))
 		return PCI_ERS_RESULT_DISCONNECT;
 
+	if (!netif_device_present(netdev))
+		return PCI_ERS_RESULT_DISCONNECT;
+
 	rtnl_lock();
 	netif_device_detach(netdev);
 
@@ -9240,7 +11651,6 @@ static pci_ers_result_t ixgbe_io_slot_reset(struct pci_dev *pdev)
 {
 	struct ixgbe_adapter *adapter = pci_get_drvdata(pdev);
 	pci_ers_result_t result;
-	int err;
 
 	if (pci_enable_device_mem(pdev)) {
 		e_err(probe, "Cannot re-enable PCI device after reset.\n");
@@ -9251,21 +11661,22 @@ static pci_ers_result_t ixgbe_io_slot_reset(struct pci_dev *pdev)
 		adapter->hw.hw_addr = adapter->io_addr;
 		pci_set_master(pdev);
 		pci_restore_state(pdev);
+		/*
+		 * After second error pci->state_saved is false, this
+		 * resets it so EEH doesn't break.
+		 */
 		pci_save_state(pdev);
 
 		pci_wake_from_d3(pdev, false);
 
-		ixgbe_reset(adapter);
+		set_bit(__IXGBE_RESET_REQUESTED, &adapter->state);
+		ixgbe_service_event_schedule(adapter);
+
 		IXGBE_WRITE_REG(&adapter->hw, IXGBE_WUS, ~0);
 		result = PCI_ERS_RESULT_RECOVERED;
 	}
 
-	err = pci_cleanup_aer_uncorrect_error_status(pdev);
-	if (err) {
-		e_dev_err("pci_cleanup_aer_uncorrect_error_status "
-			  "failed 0x%0x\n", err);
-		/* non-fatal, continue */
-	}
+	pci_cleanup_aer_uncorrect_error_status(pdev);
 
 	return result;
 }
@@ -9298,26 +11709,83 @@ static void ixgbe_io_resume(struct pci_dev *pdev)
 	rtnl_unlock();
 }
 
+#ifdef HAVE_CONST_STRUCT_PCI_ERROR_HANDLERS
 static const struct pci_error_handlers ixgbe_err_handler = {
+#else
+static struct pci_error_handlers ixgbe_err_handler = {
+#endif
 	.error_detected = ixgbe_io_error_detected,
 	.slot_reset = ixgbe_io_slot_reset,
 	.resume = ixgbe_io_resume,
 };
+#endif /* HAVE_PCI_ERS */
+
+struct net_device *ixgbe_hw_to_netdev(const struct ixgbe_hw *hw)
+{
+	return ((struct ixgbe_adapter *)hw->back)->netdev;
+}
+struct ixgbe_msg *ixgbe_hw_to_msg(const struct ixgbe_hw *hw)
+{
+	struct ixgbe_adapter *adapter =
+		container_of(hw, struct ixgbe_adapter, hw);
+	return (struct ixgbe_msg *)&adapter->msg_enable;
+}
+
+#ifdef HAVE_RHEL6_SRIOV_CONFIGURE
+static struct pci_driver_rh ixgbe_driver_rh = {
+	.sriov_configure = ixgbe_pci_sriov_configure,
+};
+#endif
+
+#ifdef CONFIG_PM
+#ifndef USE_LEGACY_PM_SUPPORT
+static const struct dev_pm_ops ixgbe_pm_ops = {
+	.suspend        = ixgbe_suspend,
+	.resume         = ixgbe_resume,
+	.freeze         = ixgbe_freeze,
+	.thaw           = ixgbe_thaw,
+	.poweroff       = ixgbe_suspend,
+	.restore        = ixgbe_resume,
+};
+#endif /* USE_LEGACY_PM_SUPPORT */
+#endif
 
 static struct pci_driver ixgbe_driver = {
 	.name     = ixgbe_driver_name,
 	.id_table = ixgbe_pci_tbl,
 	.probe    = ixgbe_probe,
-	.remove   = ixgbe_remove,
+	.remove   = __devexit_p(ixgbe_remove),
 #ifdef CONFIG_PM
+#ifndef USE_LEGACY_PM_SUPPORT
+	.driver = {
+		.pm = &ixgbe_pm_ops,
+	},
+#else
 	.suspend  = ixgbe_suspend,
 	.resume   = ixgbe_resume,
+#endif /* USE_LEGACY_PM_SUPPORT */
 #endif
+#ifndef USE_REBOOT_NOTIFIER
 	.shutdown = ixgbe_shutdown,
+#endif
+#if defined(HAVE_SRIOV_CONFIGURE)
 	.sriov_configure = ixgbe_pci_sriov_configure,
+#elif defined(HAVE_RHEL6_SRIOV_CONFIGURE)
+	.rh_reserved = &ixgbe_driver_rh,
+#endif /* HAVE_SRIOV_CONFIGURE */
+#ifdef HAVE_PCI_ERS
 	.err_handler = &ixgbe_err_handler
+#endif
 };
 
+bool ixgbe_is_ixgbe(struct pci_dev *pcidev)
+{
+	if (pci_dev_driver(pcidev) != &ixgbe_driver)
+		return false;
+	else
+		return true;
+}
+
 /**
  * ixgbe_init_module - Driver Registration Routine
  *
@@ -9330,19 +11798,38 @@ static int __init ixgbe_init_module(void)
 	pr_info("%s - version %s\n", ixgbe_driver_string, ixgbe_driver_version);
 	pr_info("%s\n", ixgbe_copyright);
 
+	ixgbe_wq = create_singlethread_workqueue(ixgbe_driver_name);
+	if (!ixgbe_wq) {
+		pr_err("%s: Failed to create workqueue\n", ixgbe_driver_name);
+		return -ENOMEM;
+	}
+
+#ifdef IXGBE_PROCFS
+	if (ixgbe_procfs_topdir_init())
+		pr_info("Procfs failed to initialize topdir\n");
+#endif
+
+#ifdef HAVE_IXGBE_DEBUG_FS
 	ixgbe_dbg_init();
+#endif /* HAVE_IXGBE_DEBUG_FS */
 
 	ret = pci_register_driver(&ixgbe_driver);
 	if (ret) {
+		destroy_workqueue(ixgbe_wq);
+#ifdef HAVE_IXGBE_DEBUG_FS
 		ixgbe_dbg_exit();
+#endif /* HAVE_IXGBE_DEBUG_FS */
+#ifdef IXGBE_PROCFS
+		ixgbe_procfs_topdir_exit();
+#endif
 		return ret;
-	}
+}
+#if IS_ENABLED(CONFIG_DCA)
 
-#ifdef CONFIG_IXGBE_DCA
 	dca_register_notify(&dca_notifier);
 #endif
 
-	return 0;
+	return ret;
 }
 
 module_init(ixgbe_init_module);
@@ -9355,17 +11842,22 @@ module_init(ixgbe_init_module);
  **/
 static void __exit ixgbe_exit_module(void)
 {
-#ifdef CONFIG_IXGBE_DCA
+#if IS_ENABLED(CONFIG_DCA)
 	dca_unregister_notify(&dca_notifier);
 #endif
 	pci_unregister_driver(&ixgbe_driver);
-
+#ifdef IXGBE_PROCFS
+	ixgbe_procfs_topdir_exit();
+#endif
+	destroy_workqueue(ixgbe_wq);
+#ifdef HAVE_IXGBE_DEBUG_FS
 	ixgbe_dbg_exit();
+#endif /* HAVE_IXGBE_DEBUG_FS */
 }
 
-#ifdef CONFIG_IXGBE_DCA
-static int ixgbe_notify_dca(struct notifier_block *nb, unsigned long event,
-			    void *p)
+#if IS_ENABLED(CONFIG_DCA)
+static int ixgbe_notify_dca(struct notifier_block __always_unused *nb, unsigned long event,
+			    void __always_unused *p)
 {
 	int ret_val;
 
@@ -9374,9 +11866,8 @@ static int ixgbe_notify_dca(struct notifier_block *nb, unsigned long event,
 
 	return ret_val ? NOTIFY_BAD : NOTIFY_DONE;
 }
-
-#endif /* CONFIG_IXGBE_DCA */
-
+#endif
 module_exit(ixgbe_exit_module);
 
 /* ixgbe_main.c */
+
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_mbx.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_mbx.c
index 9993a47..ab3aa32 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_mbx.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_mbx.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,9 +22,7 @@
 
 *******************************************************************************/
 
-#include <linux/pci.h>
-#include <linux/delay.h>
-#include "ixgbe.h"
+#include "ixgbe_type.h"
 #include "ixgbe_mbx.h"
 
 /**
@@ -38,20 +32,23 @@
  *  @size: Length of buffer
  *  @mbx_id: id of mailbox to read
  *
- *  returns SUCCESS if it successfully read message from buffer
+ *  returns SUCCESS if it successfuly read message from buffer
  **/
 s32 ixgbe_read_mbx(struct ixgbe_hw *hw, u32 *msg, u16 size, u16 mbx_id)
 {
 	struct ixgbe_mbx_info *mbx = &hw->mbx;
+	s32 ret_val = IXGBE_ERR_MBX;
+
+	DEBUGFUNC("ixgbe_read_mbx");
 
 	/* limit read to size of mailbox */
 	if (size > mbx->size)
 		size = mbx->size;
 
-	if (!mbx->ops.read)
-		return IXGBE_ERR_MBX;
+	if (mbx->ops.read)
+		ret_val = mbx->ops.read(hw, msg, size, mbx_id);
 
-	return mbx->ops.read(hw, msg, size, mbx_id);
+	return ret_val;
 }
 
 /**
@@ -66,14 +63,18 @@ s32 ixgbe_read_mbx(struct ixgbe_hw *hw, u32 *msg, u16 size, u16 mbx_id)
 s32 ixgbe_write_mbx(struct ixgbe_hw *hw, u32 *msg, u16 size, u16 mbx_id)
 {
 	struct ixgbe_mbx_info *mbx = &hw->mbx;
+	s32 ret_val = IXGBE_SUCCESS;
 
-	if (size > mbx->size)
-		return IXGBE_ERR_MBX;
+	DEBUGFUNC("ixgbe_write_mbx");
 
-	if (!mbx->ops.write)
-		return IXGBE_ERR_MBX;
+	if (size > mbx->size) {
+		ret_val = IXGBE_ERR_MBX;
+		ERROR_REPORT2(IXGBE_ERROR_ARGUMENT,
+			     "Invalid mailbox message size %d", size);
+	} else if (mbx->ops.write)
+		ret_val = mbx->ops.write(hw, msg, size, mbx_id);
 
-	return mbx->ops.write(hw, msg, size, mbx_id);
+	return ret_val;
 }
 
 /**
@@ -86,11 +87,14 @@ s32 ixgbe_write_mbx(struct ixgbe_hw *hw, u32 *msg, u16 size, u16 mbx_id)
 s32 ixgbe_check_for_msg(struct ixgbe_hw *hw, u16 mbx_id)
 {
 	struct ixgbe_mbx_info *mbx = &hw->mbx;
+	s32 ret_val = IXGBE_ERR_MBX;
+
+	DEBUGFUNC("ixgbe_check_for_msg");
 
-	if (!mbx->ops.check_for_msg)
-		return IXGBE_ERR_MBX;
+	if (mbx->ops.check_for_msg)
+		ret_val = mbx->ops.check_for_msg(hw, mbx_id);
 
-	return mbx->ops.check_for_msg(hw, mbx_id);
+	return ret_val;
 }
 
 /**
@@ -103,11 +107,14 @@ s32 ixgbe_check_for_msg(struct ixgbe_hw *hw, u16 mbx_id)
 s32 ixgbe_check_for_ack(struct ixgbe_hw *hw, u16 mbx_id)
 {
 	struct ixgbe_mbx_info *mbx = &hw->mbx;
+	s32 ret_val = IXGBE_ERR_MBX;
+
+	DEBUGFUNC("ixgbe_check_for_ack");
 
-	if (!mbx->ops.check_for_ack)
-		return IXGBE_ERR_MBX;
+	if (mbx->ops.check_for_ack)
+		ret_val = mbx->ops.check_for_ack(hw, mbx_id);
 
-	return mbx->ops.check_for_ack(hw, mbx_id);
+	return ret_val;
 }
 
 /**
@@ -120,11 +127,14 @@ s32 ixgbe_check_for_ack(struct ixgbe_hw *hw, u16 mbx_id)
 s32 ixgbe_check_for_rst(struct ixgbe_hw *hw, u16 mbx_id)
 {
 	struct ixgbe_mbx_info *mbx = &hw->mbx;
+	s32 ret_val = IXGBE_ERR_MBX;
 
-	if (!mbx->ops.check_for_rst)
-		return IXGBE_ERR_MBX;
+	DEBUGFUNC("ixgbe_check_for_rst");
 
-	return mbx->ops.check_for_rst(hw, mbx_id);
+	if (mbx->ops.check_for_rst)
+		ret_val = mbx->ops.check_for_rst(hw, mbx_id);
+
+	return ret_val;
 }
 
 /**
@@ -134,22 +144,29 @@ s32 ixgbe_check_for_rst(struct ixgbe_hw *hw, u16 mbx_id)
  *
  *  returns SUCCESS if it successfully received a message notification
  **/
-static s32 ixgbe_poll_for_msg(struct ixgbe_hw *hw, u16 mbx_id)
+STATIC s32 ixgbe_poll_for_msg(struct ixgbe_hw *hw, u16 mbx_id)
 {
 	struct ixgbe_mbx_info *mbx = &hw->mbx;
 	int countdown = mbx->timeout;
 
+	DEBUGFUNC("ixgbe_poll_for_msg");
+
 	if (!countdown || !mbx->ops.check_for_msg)
-		return IXGBE_ERR_MBX;
+		goto out;
 
-	while (mbx->ops.check_for_msg(hw, mbx_id)) {
+	while (countdown && mbx->ops.check_for_msg(hw, mbx_id)) {
 		countdown--;
 		if (!countdown)
-			return IXGBE_ERR_MBX;
-		udelay(mbx->usec_delay);
+			break;
+		usec_delay(mbx->usec_delay);
 	}
 
-	return 0;
+	if (countdown == 0)
+		ERROR_REPORT2(IXGBE_ERROR_POLLING,
+			   "Polling for VF%d mailbox message timedout", mbx_id);
+
+out:
+	return countdown ? IXGBE_SUCCESS : IXGBE_ERR_MBX;
 }
 
 /**
@@ -159,22 +176,29 @@ static s32 ixgbe_poll_for_msg(struct ixgbe_hw *hw, u16 mbx_id)
  *
  *  returns SUCCESS if it successfully received a message acknowledgement
  **/
-static s32 ixgbe_poll_for_ack(struct ixgbe_hw *hw, u16 mbx_id)
+STATIC s32 ixgbe_poll_for_ack(struct ixgbe_hw *hw, u16 mbx_id)
 {
 	struct ixgbe_mbx_info *mbx = &hw->mbx;
 	int countdown = mbx->timeout;
 
+	DEBUGFUNC("ixgbe_poll_for_ack");
+
 	if (!countdown || !mbx->ops.check_for_ack)
-		return IXGBE_ERR_MBX;
+		goto out;
 
-	while (mbx->ops.check_for_ack(hw, mbx_id)) {
+	while (countdown && mbx->ops.check_for_ack(hw, mbx_id)) {
 		countdown--;
 		if (!countdown)
-			return IXGBE_ERR_MBX;
-		udelay(mbx->usec_delay);
+			break;
+		usec_delay(mbx->usec_delay);
 	}
 
-	return 0;
+	if (countdown == 0)
+		ERROR_REPORT2(IXGBE_ERROR_POLLING,
+			     "Polling for VF%d mailbox ack timedout", mbx_id);
+
+out:
+	return countdown ? IXGBE_SUCCESS : IXGBE_ERR_MBX;
 }
 
 /**
@@ -187,21 +211,23 @@ static s32 ixgbe_poll_for_ack(struct ixgbe_hw *hw, u16 mbx_id)
  *  returns SUCCESS if it successfully received a message notification and
  *  copied it into the receive buffer.
  **/
-static s32 ixgbe_read_posted_mbx(struct ixgbe_hw *hw, u32 *msg, u16 size,
-				 u16 mbx_id)
+s32 ixgbe_read_posted_mbx(struct ixgbe_hw *hw, u32 *msg, u16 size, u16 mbx_id)
 {
 	struct ixgbe_mbx_info *mbx = &hw->mbx;
-	s32 ret_val;
+	s32 ret_val = IXGBE_ERR_MBX;
+
+	DEBUGFUNC("ixgbe_read_posted_mbx");
 
 	if (!mbx->ops.read)
-		return IXGBE_ERR_MBX;
+		goto out;
 
 	ret_val = ixgbe_poll_for_msg(hw, mbx_id);
-	if (ret_val)
-		return ret_val;
 
-	/* if ack received read message */
-	return mbx->ops.read(hw, msg, size, mbx_id);
+	/* if ack received read message, otherwise we timed out */
+	if (!ret_val)
+		ret_val = mbx->ops.read(hw, msg, size, mbx_id);
+out:
+	return ret_val;
 }
 
 /**
@@ -214,35 +240,291 @@ static s32 ixgbe_read_posted_mbx(struct ixgbe_hw *hw, u32 *msg, u16 size,
  *  returns SUCCESS if it successfully copied message into the buffer and
  *  received an ack to that message within delay * timeout period
  **/
-static s32 ixgbe_write_posted_mbx(struct ixgbe_hw *hw, u32 *msg, u16 size,
+s32 ixgbe_write_posted_mbx(struct ixgbe_hw *hw, u32 *msg, u16 size,
 			   u16 mbx_id)
 {
 	struct ixgbe_mbx_info *mbx = &hw->mbx;
-	s32 ret_val;
+	s32 ret_val = IXGBE_ERR_MBX;
+
+	DEBUGFUNC("ixgbe_write_posted_mbx");
 
 	/* exit if either we can't write or there isn't a defined timeout */
 	if (!mbx->ops.write || !mbx->timeout)
-		return IXGBE_ERR_MBX;
+		goto out;
 
 	/* send msg */
 	ret_val = mbx->ops.write(hw, msg, size, mbx_id);
-	if (ret_val)
-		return ret_val;
 
 	/* if msg sent wait until we receive an ack */
-	return ixgbe_poll_for_ack(hw, mbx_id);
+	if (!ret_val)
+		ret_val = ixgbe_poll_for_ack(hw, mbx_id);
+out:
+	return ret_val;
+}
+
+/**
+ *  ixgbe_init_mbx_ops_generic - Initialize MB function pointers
+ *  @hw: pointer to the HW structure
+ *
+ *  Setups up the mailbox read and write message function pointers
+ **/
+void ixgbe_init_mbx_ops_generic(struct ixgbe_hw *hw)
+{
+	struct ixgbe_mbx_info *mbx = &hw->mbx;
+
+	mbx->ops.read_posted = ixgbe_read_posted_mbx;
+	mbx->ops.write_posted = ixgbe_write_posted_mbx;
+}
+
+/**
+ *  ixgbe_read_v2p_mailbox - read v2p mailbox
+ *  @hw: pointer to the HW structure
+ *
+ *  This function is used to read the v2p mailbox without losing the read to
+ *  clear status bits.
+ **/
+STATIC u32 ixgbe_read_v2p_mailbox(struct ixgbe_hw *hw)
+{
+	u32 v2p_mailbox = IXGBE_READ_REG(hw, IXGBE_VFMAILBOX);
+
+	v2p_mailbox |= hw->mbx.v2p_mailbox;
+	hw->mbx.v2p_mailbox |= v2p_mailbox & IXGBE_VFMAILBOX_R2C_BITS;
+
+	return v2p_mailbox;
+}
+
+/**
+ *  ixgbe_check_for_bit_vf - Determine if a status bit was set
+ *  @hw: pointer to the HW structure
+ *  @mask: bitmask for bits to be tested and cleared
+ *
+ *  This function is used to check for the read to clear bits within
+ *  the V2P mailbox.
+ **/
+STATIC s32 ixgbe_check_for_bit_vf(struct ixgbe_hw *hw, u32 mask)
+{
+	u32 v2p_mailbox = ixgbe_read_v2p_mailbox(hw);
+	s32 ret_val = IXGBE_ERR_MBX;
+
+	if (v2p_mailbox & mask)
+		ret_val = IXGBE_SUCCESS;
+
+	hw->mbx.v2p_mailbox &= ~mask;
+
+	return ret_val;
+}
+
+/**
+ *  ixgbe_check_for_msg_vf - checks to see if the PF has sent mail
+ *  @hw: pointer to the HW structure
+ *  @mbx_id: id of mailbox to check
+ *
+ *  returns SUCCESS if the PF has set the Status bit or else ERR_MBX
+ **/
+STATIC s32 ixgbe_check_for_msg_vf(struct ixgbe_hw *hw, u16 mbx_id)
+{
+	s32 ret_val = IXGBE_ERR_MBX;
+
+	UNREFERENCED_1PARAMETER(mbx_id);
+	DEBUGFUNC("ixgbe_check_for_msg_vf");
+
+	if (!ixgbe_check_for_bit_vf(hw, IXGBE_VFMAILBOX_PFSTS)) {
+		ret_val = IXGBE_SUCCESS;
+		hw->mbx.stats.reqs++;
+	}
+
+	return ret_val;
+}
+
+/**
+ *  ixgbe_check_for_ack_vf - checks to see if the PF has ACK'd
+ *  @hw: pointer to the HW structure
+ *  @mbx_id: id of mailbox to check
+ *
+ *  returns SUCCESS if the PF has set the ACK bit or else ERR_MBX
+ **/
+STATIC s32 ixgbe_check_for_ack_vf(struct ixgbe_hw *hw, u16 mbx_id)
+{
+	s32 ret_val = IXGBE_ERR_MBX;
+
+	UNREFERENCED_1PARAMETER(mbx_id);
+	DEBUGFUNC("ixgbe_check_for_ack_vf");
+
+	if (!ixgbe_check_for_bit_vf(hw, IXGBE_VFMAILBOX_PFACK)) {
+		ret_val = IXGBE_SUCCESS;
+		hw->mbx.stats.acks++;
+	}
+
+	return ret_val;
 }
 
-static s32 ixgbe_check_for_bit_pf(struct ixgbe_hw *hw, u32 mask, s32 index)
+/**
+ *  ixgbe_check_for_rst_vf - checks to see if the PF has reset
+ *  @hw: pointer to the HW structure
+ *  @mbx_id: id of mailbox to check
+ *
+ *  returns true if the PF has set the reset done bit or else false
+ **/
+STATIC s32 ixgbe_check_for_rst_vf(struct ixgbe_hw *hw, u16 mbx_id)
+{
+	s32 ret_val = IXGBE_ERR_MBX;
+
+	UNREFERENCED_1PARAMETER(mbx_id);
+	DEBUGFUNC("ixgbe_check_for_rst_vf");
+
+	if (!ixgbe_check_for_bit_vf(hw, (IXGBE_VFMAILBOX_RSTD |
+	    IXGBE_VFMAILBOX_RSTI))) {
+		ret_val = IXGBE_SUCCESS;
+		hw->mbx.stats.rsts++;
+	}
+
+	return ret_val;
+}
+
+/**
+ *  ixgbe_obtain_mbx_lock_vf - obtain mailbox lock
+ *  @hw: pointer to the HW structure
+ *
+ *  return SUCCESS if we obtained the mailbox lock
+ **/
+STATIC s32 ixgbe_obtain_mbx_lock_vf(struct ixgbe_hw *hw)
+{
+	s32 ret_val = IXGBE_ERR_MBX;
+
+	DEBUGFUNC("ixgbe_obtain_mbx_lock_vf");
+
+	/* Take ownership of the buffer */
+	IXGBE_WRITE_REG(hw, IXGBE_VFMAILBOX, IXGBE_VFMAILBOX_VFU);
+
+	/* reserve mailbox for vf use */
+	if (ixgbe_read_v2p_mailbox(hw) & IXGBE_VFMAILBOX_VFU)
+		ret_val = IXGBE_SUCCESS;
+
+	return ret_val;
+}
+
+/**
+ *  ixgbe_write_mbx_vf - Write a message to the mailbox
+ *  @hw: pointer to the HW structure
+ *  @msg: The message buffer
+ *  @size: Length of buffer
+ *  @mbx_id: id of mailbox to write
+ *
+ *  returns SUCCESS if it successfully copied message into the buffer
+ **/
+STATIC s32 ixgbe_write_mbx_vf(struct ixgbe_hw *hw, u32 *msg, u16 size,
+			      u16 mbx_id)
+{
+	s32 ret_val;
+	u16 i;
+
+	UNREFERENCED_1PARAMETER(mbx_id);
+
+	DEBUGFUNC("ixgbe_write_mbx_vf");
+
+	/* lock the mailbox to prevent pf/vf race condition */
+	ret_val = ixgbe_obtain_mbx_lock_vf(hw);
+	if (ret_val)
+		goto out_no_write;
+
+	/* flush msg and acks as we are overwriting the message buffer */
+	ixgbe_check_for_msg_vf(hw, 0);
+	ixgbe_check_for_ack_vf(hw, 0);
+
+	/* copy the caller specified message to the mailbox memory buffer */
+	for (i = 0; i < size; i++)
+		IXGBE_WRITE_REG_ARRAY(hw, IXGBE_VFMBMEM, i, msg[i]);
+
+	/* update stats */
+	hw->mbx.stats.msgs_tx++;
+
+	/* Drop VFU and interrupt the PF to tell it a message has been sent */
+	IXGBE_WRITE_REG(hw, IXGBE_VFMAILBOX, IXGBE_VFMAILBOX_REQ);
+
+out_no_write:
+	return ret_val;
+}
+
+/**
+ *  ixgbe_read_mbx_vf - Reads a message from the inbox intended for vf
+ *  @hw: pointer to the HW structure
+ *  @msg: The message buffer
+ *  @size: Length of buffer
+ *  @mbx_id: id of mailbox to read
+ *
+ *  returns SUCCESS if it successfuly read message from buffer
+ **/
+STATIC s32 ixgbe_read_mbx_vf(struct ixgbe_hw *hw, u32 *msg, u16 size,
+			     u16 mbx_id)
+{
+	s32 ret_val = IXGBE_SUCCESS;
+	u16 i;
+
+	DEBUGFUNC("ixgbe_read_mbx_vf");
+	UNREFERENCED_1PARAMETER(mbx_id);
+
+	/* lock the mailbox to prevent pf/vf race condition */
+	ret_val = ixgbe_obtain_mbx_lock_vf(hw);
+	if (ret_val)
+		goto out_no_read;
+
+	/* copy the message from the mailbox memory buffer */
+	for (i = 0; i < size; i++)
+		msg[i] = IXGBE_READ_REG_ARRAY(hw, IXGBE_VFMBMEM, i);
+
+	/* Acknowledge receipt and release mailbox, then we're done */
+	IXGBE_WRITE_REG(hw, IXGBE_VFMAILBOX, IXGBE_VFMAILBOX_ACK);
+
+	/* update stats */
+	hw->mbx.stats.msgs_rx++;
+
+out_no_read:
+	return ret_val;
+}
+
+/**
+ *  ixgbe_init_mbx_params_vf - set initial values for vf mailbox
+ *  @hw: pointer to the HW structure
+ *
+ *  Initializes the hw->mbx struct to correct values for vf mailbox
+ */
+void ixgbe_init_mbx_params_vf(struct ixgbe_hw *hw)
+{
+	struct ixgbe_mbx_info *mbx = &hw->mbx;
+
+	/* start mailbox as timed out and let the reset_hw call set the timeout
+	 * value to begin communications */
+	mbx->timeout = 0;
+	mbx->usec_delay = IXGBE_VF_MBX_INIT_DELAY;
+
+	mbx->size = IXGBE_VFMAILBOX_SIZE;
+
+	mbx->ops.read = ixgbe_read_mbx_vf;
+	mbx->ops.write = ixgbe_write_mbx_vf;
+	mbx->ops.read_posted = ixgbe_read_posted_mbx;
+	mbx->ops.write_posted = ixgbe_write_posted_mbx;
+	mbx->ops.check_for_msg = ixgbe_check_for_msg_vf;
+	mbx->ops.check_for_ack = ixgbe_check_for_ack_vf;
+	mbx->ops.check_for_rst = ixgbe_check_for_rst_vf;
+
+	mbx->stats.msgs_tx = 0;
+	mbx->stats.msgs_rx = 0;
+	mbx->stats.reqs = 0;
+	mbx->stats.acks = 0;
+	mbx->stats.rsts = 0;
+}
+
+STATIC s32 ixgbe_check_for_bit_pf(struct ixgbe_hw *hw, u32 mask, s32 index)
 {
 	u32 mbvficr = IXGBE_READ_REG(hw, IXGBE_MBVFICR(index));
+	s32 ret_val = IXGBE_ERR_MBX;
 
 	if (mbvficr & mask) {
+		ret_val = IXGBE_SUCCESS;
 		IXGBE_WRITE_REG(hw, IXGBE_MBVFICR(index), mask);
-		return 0;
 	}
 
-	return IXGBE_ERR_MBX;
+	return ret_val;
 }
 
 /**
@@ -252,18 +534,21 @@ static s32 ixgbe_check_for_bit_pf(struct ixgbe_hw *hw, u32 mask, s32 index)
  *
  *  returns SUCCESS if the VF has set the Status bit or else ERR_MBX
  **/
-static s32 ixgbe_check_for_msg_pf(struct ixgbe_hw *hw, u16 vf_number)
+STATIC s32 ixgbe_check_for_msg_pf(struct ixgbe_hw *hw, u16 vf_number)
 {
+	s32 ret_val = IXGBE_ERR_MBX;
 	s32 index = IXGBE_MBVFICR_INDEX(vf_number);
 	u32 vf_bit = vf_number % 16;
 
+	DEBUGFUNC("ixgbe_check_for_msg_pf");
+
 	if (!ixgbe_check_for_bit_pf(hw, IXGBE_MBVFICR_VFREQ_VF1 << vf_bit,
 				    index)) {
+		ret_val = IXGBE_SUCCESS;
 		hw->mbx.stats.reqs++;
-		return 0;
 	}
 
-	return IXGBE_ERR_MBX;
+	return ret_val;
 }
 
 /**
@@ -273,18 +558,21 @@ static s32 ixgbe_check_for_msg_pf(struct ixgbe_hw *hw, u16 vf_number)
  *
  *  returns SUCCESS if the VF has set the Status bit or else ERR_MBX
  **/
-static s32 ixgbe_check_for_ack_pf(struct ixgbe_hw *hw, u16 vf_number)
+STATIC s32 ixgbe_check_for_ack_pf(struct ixgbe_hw *hw, u16 vf_number)
 {
+	s32 ret_val = IXGBE_ERR_MBX;
 	s32 index = IXGBE_MBVFICR_INDEX(vf_number);
 	u32 vf_bit = vf_number % 16;
 
+	DEBUGFUNC("ixgbe_check_for_ack_pf");
+
 	if (!ixgbe_check_for_bit_pf(hw, IXGBE_MBVFICR_VFACK_VF1 << vf_bit,
 				    index)) {
+		ret_val = IXGBE_SUCCESS;
 		hw->mbx.stats.acks++;
-		return 0;
 	}
 
-	return IXGBE_ERR_MBX;
+	return ret_val;
 }
 
 /**
@@ -294,19 +582,23 @@ static s32 ixgbe_check_for_ack_pf(struct ixgbe_hw *hw, u16 vf_number)
  *
  *  returns SUCCESS if the VF has set the Status bit or else ERR_MBX
  **/
-static s32 ixgbe_check_for_rst_pf(struct ixgbe_hw *hw, u16 vf_number)
+STATIC s32 ixgbe_check_for_rst_pf(struct ixgbe_hw *hw, u16 vf_number)
 {
 	u32 reg_offset = (vf_number < 32) ? 0 : 1;
 	u32 vf_shift = vf_number % 32;
 	u32 vflre = 0;
+	s32 ret_val = IXGBE_ERR_MBX;
+
+	DEBUGFUNC("ixgbe_check_for_rst_pf");
 
 	switch (hw->mac.type) {
 	case ixgbe_mac_82599EB:
 		vflre = IXGBE_READ_REG(hw, IXGBE_VFLRE(reg_offset));
 		break;
-	case ixgbe_mac_X540:
 	case ixgbe_mac_X550:
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+	case ixgbe_mac_X540:
 		vflre = IXGBE_READ_REG(hw, IXGBE_VFLREC(reg_offset));
 		break;
 	default:
@@ -314,12 +606,12 @@ static s32 ixgbe_check_for_rst_pf(struct ixgbe_hw *hw, u16 vf_number)
 	}
 
 	if (vflre & (1 << vf_shift)) {
+		ret_val = IXGBE_SUCCESS;
 		IXGBE_WRITE_REG(hw, IXGBE_VFLREC(reg_offset), (1 << vf_shift));
 		hw->mbx.stats.rsts++;
-		return 0;
 	}
 
-	return IXGBE_ERR_MBX;
+	return ret_val;
 }
 
 /**
@@ -329,19 +621,26 @@ static s32 ixgbe_check_for_rst_pf(struct ixgbe_hw *hw, u16 vf_number)
  *
  *  return SUCCESS if we obtained the mailbox lock
  **/
-static s32 ixgbe_obtain_mbx_lock_pf(struct ixgbe_hw *hw, u16 vf_number)
+STATIC s32 ixgbe_obtain_mbx_lock_pf(struct ixgbe_hw *hw, u16 vf_number)
 {
+	s32 ret_val = IXGBE_ERR_MBX;
 	u32 p2v_mailbox;
 
+	DEBUGFUNC("ixgbe_obtain_mbx_lock_pf");
+
 	/* Take ownership of the buffer */
 	IXGBE_WRITE_REG(hw, IXGBE_PFMAILBOX(vf_number), IXGBE_PFMAILBOX_PFU);
 
 	/* reserve mailbox for vf use */
 	p2v_mailbox = IXGBE_READ_REG(hw, IXGBE_PFMAILBOX(vf_number));
 	if (p2v_mailbox & IXGBE_PFMAILBOX_PFU)
-		return 0;
+		ret_val = IXGBE_SUCCESS;
+	else
+		ERROR_REPORT2(IXGBE_ERROR_POLLING,
+			   "Failed to obtain mailbox lock for VF%d", vf_number);
+
 
-	return IXGBE_ERR_MBX;
+	return ret_val;
 }
 
 /**
@@ -353,16 +652,18 @@ static s32 ixgbe_obtain_mbx_lock_pf(struct ixgbe_hw *hw, u16 vf_number)
  *
  *  returns SUCCESS if it successfully copied message into the buffer
  **/
-static s32 ixgbe_write_mbx_pf(struct ixgbe_hw *hw, u32 *msg, u16 size,
+STATIC s32 ixgbe_write_mbx_pf(struct ixgbe_hw *hw, u32 *msg, u16 size,
 			      u16 vf_number)
 {
 	s32 ret_val;
 	u16 i;
 
+	DEBUGFUNC("ixgbe_write_mbx_pf");
+
 	/* lock the mailbox to prevent pf/vf race condition */
 	ret_val = ixgbe_obtain_mbx_lock_pf(hw, vf_number);
 	if (ret_val)
-		return ret_val;
+		goto out_no_write;
 
 	/* flush msg and acks as we are overwriting the message buffer */
 	ixgbe_check_for_msg_pf(hw, vf_number);
@@ -378,7 +679,9 @@ static s32 ixgbe_write_mbx_pf(struct ixgbe_hw *hw, u32 *msg, u16 size,
 	/* update stats */
 	hw->mbx.stats.msgs_tx++;
 
-	return 0;
+out_no_write:
+	return ret_val;
+
 }
 
 /**
@@ -392,16 +695,18 @@ static s32 ixgbe_write_mbx_pf(struct ixgbe_hw *hw, u32 *msg, u16 size,
  *  memory buffer.  The presumption is that the caller knows that there was
  *  a message due to a VF request so no polling for message is needed.
  **/
-static s32 ixgbe_read_mbx_pf(struct ixgbe_hw *hw, u32 *msg, u16 size,
+STATIC s32 ixgbe_read_mbx_pf(struct ixgbe_hw *hw, u32 *msg, u16 size,
 			     u16 vf_number)
 {
 	s32 ret_val;
 	u16 i;
 
+	DEBUGFUNC("ixgbe_read_mbx_pf");
+
 	/* lock the mailbox to prevent pf/vf race condition */
 	ret_val = ixgbe_obtain_mbx_lock_pf(hw, vf_number);
 	if (ret_val)
-		return ret_val;
+		goto out_no_read;
 
 	/* copy the message to the mailbox memory buffer */
 	for (i = 0; i < size; i++)
@@ -413,10 +718,10 @@ static s32 ixgbe_read_mbx_pf(struct ixgbe_hw *hw, u32 *msg, u16 size,
 	/* update stats */
 	hw->mbx.stats.msgs_rx++;
 
-	return 0;
+out_no_read:
+	return ret_val;
 }
 
-#ifdef CONFIG_PCI_IOV
 /**
  *  ixgbe_init_mbx_params_pf - set initial values for pf mailbox
  *  @hw: pointer to the HW structure
@@ -430,29 +735,26 @@ void ixgbe_init_mbx_params_pf(struct ixgbe_hw *hw)
 	if (hw->mac.type != ixgbe_mac_82599EB &&
 	    hw->mac.type != ixgbe_mac_X550 &&
 	    hw->mac.type != ixgbe_mac_X550EM_x &&
+	    hw->mac.type != ixgbe_mac_X550EM_a &&
 	    hw->mac.type != ixgbe_mac_X540)
 		return;
 
 	mbx->timeout = 0;
 	mbx->usec_delay = 0;
 
+	mbx->size = IXGBE_VFMAILBOX_SIZE;
+
+	mbx->ops.read = ixgbe_read_mbx_pf;
+	mbx->ops.write = ixgbe_write_mbx_pf;
+	mbx->ops.read_posted = ixgbe_read_posted_mbx;
+	mbx->ops.write_posted = ixgbe_write_posted_mbx;
+	mbx->ops.check_for_msg = ixgbe_check_for_msg_pf;
+	mbx->ops.check_for_ack = ixgbe_check_for_ack_pf;
+	mbx->ops.check_for_rst = ixgbe_check_for_rst_pf;
+
 	mbx->stats.msgs_tx = 0;
 	mbx->stats.msgs_rx = 0;
 	mbx->stats.reqs = 0;
 	mbx->stats.acks = 0;
 	mbx->stats.rsts = 0;
-
-	mbx->size = IXGBE_VFMAILBOX_SIZE;
 }
-#endif /* CONFIG_PCI_IOV */
-
-struct ixgbe_mbx_operations mbx_ops_generic = {
-	.read                   = ixgbe_read_mbx_pf,
-	.write                  = ixgbe_write_mbx_pf,
-	.read_posted            = ixgbe_read_posted_mbx,
-	.write_posted           = ixgbe_write_posted_mbx,
-	.check_for_msg          = ixgbe_check_for_msg_pf,
-	.check_for_ack          = ixgbe_check_for_ack_pf,
-	.check_for_rst          = ixgbe_check_for_rst_pf,
-};
-
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_mbx.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_mbx.h
index 8daa95f..b990c32 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_mbx.h
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_mbx.h
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -31,42 +27,52 @@
 
 #include "ixgbe_type.h"
 
-#define IXGBE_VFMAILBOX_SIZE        16 /* 16 32 bit words - 64 bytes */
-#define IXGBE_ERR_MBX               -100
-
-#define IXGBE_VFMAILBOX             0x002FC
-#define IXGBE_VFMBMEM               0x00200
-
-#define IXGBE_PFMAILBOX_STS   0x00000001 /* Initiate message send to VF */
-#define IXGBE_PFMAILBOX_ACK   0x00000002 /* Ack message recv'd from VF */
-#define IXGBE_PFMAILBOX_VFU   0x00000004 /* VF owns the mailbox buffer */
-#define IXGBE_PFMAILBOX_PFU   0x00000008 /* PF owns the mailbox buffer */
-#define IXGBE_PFMAILBOX_RVFU  0x00000010 /* Reset VFU - used when VF stuck */
-
-#define IXGBE_MBVFICR_VFREQ_MASK 0x0000FFFF /* bits for VF messages */
-#define IXGBE_MBVFICR_VFREQ_VF1  0x00000001 /* bit for VF 1 message */
-#define IXGBE_MBVFICR_VFACK_MASK 0xFFFF0000 /* bits for VF acks */
-#define IXGBE_MBVFICR_VFACK_VF1  0x00010000 /* bit for VF 1 ack */
-
+#define IXGBE_VFMAILBOX_SIZE	16 /* 16 32 bit words - 64 bytes */
+#define IXGBE_ERR_MBX		-100
+
+#define IXGBE_VFMAILBOX		0x002FC
+#define IXGBE_VFMBMEM		0x00200
+
+/* Define mailbox register bits */
+#define IXGBE_VFMAILBOX_REQ	0x00000001 /* Request for PF Ready bit */
+#define IXGBE_VFMAILBOX_ACK	0x00000002 /* Ack PF message received */
+#define IXGBE_VFMAILBOX_VFU	0x00000004 /* VF owns the mailbox buffer */
+#define IXGBE_VFMAILBOX_PFU	0x00000008 /* PF owns the mailbox buffer */
+#define IXGBE_VFMAILBOX_PFSTS	0x00000010 /* PF wrote a message in the MB */
+#define IXGBE_VFMAILBOX_PFACK	0x00000020 /* PF ack the previous VF msg */
+#define IXGBE_VFMAILBOX_RSTI	0x00000040 /* PF has reset indication */
+#define IXGBE_VFMAILBOX_RSTD	0x00000080 /* PF has indicated reset done */
+#define IXGBE_VFMAILBOX_R2C_BITS	0x000000B0 /* All read to clear bits */
+
+#define IXGBE_PFMAILBOX_STS	0x00000001 /* Initiate message send to VF */
+#define IXGBE_PFMAILBOX_ACK	0x00000002 /* Ack message recv'd from VF */
+#define IXGBE_PFMAILBOX_VFU	0x00000004 /* VF owns the mailbox buffer */
+#define IXGBE_PFMAILBOX_PFU	0x00000008 /* PF owns the mailbox buffer */
+#define IXGBE_PFMAILBOX_RVFU	0x00000010 /* Reset VFU - used when VF stuck */
+
+#define IXGBE_MBVFICR_VFREQ_MASK	0x0000FFFF /* bits for VF messages */
+#define IXGBE_MBVFICR_VFREQ_VF1		0x00000001 /* bit for VF 1 message */
+#define IXGBE_MBVFICR_VFACK_MASK	0xFFFF0000 /* bits for VF acks */
+#define IXGBE_MBVFICR_VFACK_VF1		0x00010000 /* bit for VF 1 ack */
 
 /* If it's a IXGBE_VF_* msg then it originates in the VF and is sent to the
  * PF.  The reverse is true if it is IXGBE_PF_*.
  * Message ACK's are the value or'd with 0xF0000000
  */
-#define IXGBE_VT_MSGTYPE_ACK      0x80000000  /* Messages below or'd with
-					       * this are the ACK */
-#define IXGBE_VT_MSGTYPE_NACK     0x40000000  /* Messages below or'd with
-					       * this are the NACK */
-#define IXGBE_VT_MSGTYPE_CTS      0x20000000  /* Indicates that VF is still
-						 clear to send requests */
-#define IXGBE_VT_MSGINFO_SHIFT    16
-/* bits 23:16 are used for exra info for certain messages */
-#define IXGBE_VT_MSGINFO_MASK     (0xFF << IXGBE_VT_MSGINFO_SHIFT)
+#define IXGBE_VT_MSGTYPE_ACK	0x80000000 /* Messages below or'd with
+					    * this are the ACK */
+#define IXGBE_VT_MSGTYPE_NACK	0x40000000 /* Messages below or'd with
+					    * this are the NACK */
+#define IXGBE_VT_MSGTYPE_CTS	0x20000000 /* Indicates that VF is still
+					    * clear to send requests */
+#define IXGBE_VT_MSGINFO_SHIFT	16
+/* bits 23:16 are used for extra info for certain messages */
+#define IXGBE_VT_MSGINFO_MASK	(0xFF << IXGBE_VT_MSGINFO_SHIFT)
 
 /* definitions to support mailbox API version negotiation */
 
 /*
- * Each element denotes a version of the API; existing numbers may not
+ * each element denotes a version of the API; existing numbers may not
  * change; any additions must go at the end
  */
 enum ixgbe_pfvf_api_rev {
@@ -74,15 +80,16 @@ enum ixgbe_pfvf_api_rev {
 	ixgbe_mbox_api_20,	/* API version 2.0, solaris Phase1 VF driver */
 	ixgbe_mbox_api_11,	/* API version 1.1, linux/freebsd VF driver */
 	ixgbe_mbox_api_12,	/* API version 1.2, linux/freebsd VF driver */
+	ixgbe_mbox_api_13,	/* API version 1.3, linux/freebsd VF driver */
 	/* This value should always be last */
 	ixgbe_mbox_api_unknown,	/* indicates that API version is not known */
 };
 
 /* mailbox API, legacy requests */
-#define IXGBE_VF_RESET            0x01 /* VF requests reset */
-#define IXGBE_VF_SET_MAC_ADDR     0x02 /* VF requests PF to set MAC addr */
-#define IXGBE_VF_SET_MULTICAST    0x03 /* VF requests PF to set MC addr */
-#define IXGBE_VF_SET_VLAN         0x04 /* VF requests PF to set VLAN */
+#define IXGBE_VF_RESET		0x01 /* VF requests reset */
+#define IXGBE_VF_SET_MAC_ADDR	0x02 /* VF requests PF to set MAC addr */
+#define IXGBE_VF_SET_MULTICAST	0x03 /* VF requests PF to set MC addr */
+#define IXGBE_VF_SET_VLAN	0x04 /* VF requests PF to set VLAN */
 
 /* mailbox API, version 1.0 VF requests */
 #define IXGBE_VF_SET_LPE	0x05 /* VF requests PF to set VMOLR.LPE */
@@ -92,37 +99,57 @@ enum ixgbe_pfvf_api_rev {
 /* mailbox API, version 1.1 VF requests */
 #define IXGBE_VF_GET_QUEUES	0x09 /* get queue configuration */
 
+/* mailbox API, version 1.2 VF requests */
+#define IXGBE_VF_GET_RETA      0x0a    /* VF request for RETA */
+#define IXGBE_VF_GET_RSS_KEY	0x0b    /* get RSS key */
+#define IXGBE_VF_UPDATE_XCAST_MODE	0x0c
+
+/* mode choices for IXGBE_VF_UPDATE_XCAST_MODE */
+enum ixgbevf_xcast_modes {
+	IXGBEVF_XCAST_MODE_NONE = 0,
+	IXGBEVF_XCAST_MODE_MULTI,
+	IXGBEVF_XCAST_MODE_ALLMULTI,
+	IXGBEVF_XCAST_MODE_PROMISC,
+};
+
 /* GET_QUEUES return data indices within the mailbox */
 #define IXGBE_VF_TX_QUEUES	1	/* number of Tx queues supported */
 #define IXGBE_VF_RX_QUEUES	2	/* number of Rx queues supported */
 #define IXGBE_VF_TRANS_VLAN	3	/* Indication of port vlan */
 #define IXGBE_VF_DEF_QUEUE	4	/* Default queue offset */
 
-/* mailbox API, version 1.2 VF requests */
-#define IXGBE_VF_GET_RETA	0x0a	/* VF request for RETA */
-#define IXGBE_VF_GET_RSS_KEY	0x0b	/* get RSS key */
-
-#define IXGBE_VF_UPDATE_XCAST_MODE	0x0c
-
 /* length of permanent address message returned from PF */
-#define IXGBE_VF_PERMADDR_MSG_LEN 4
+#define IXGBE_VF_PERMADDR_MSG_LEN	4
 /* word in permanent address message with the current multicast type */
-#define IXGBE_VF_MC_TYPE_WORD     3
+#define IXGBE_VF_MC_TYPE_WORD		3
+
+#define IXGBE_PF_CONTROL_MSG		0x0100 /* PF control message */
 
-#define IXGBE_PF_CONTROL_MSG      0x0100 /* PF control message */
+/* mailbox API, version 2.0 VF requests */
+#define IXGBE_VF_API_NEGOTIATE		0x08 /* negotiate API version */
+#define IXGBE_VF_GET_QUEUES		0x09 /* get queue configuration */
+#define IXGBE_VF_ENABLE_MACADDR		0x0A /* enable MAC address */
+#define IXGBE_VF_DISABLE_MACADDR	0x0B /* disable MAC address */
+#define IXGBE_VF_GET_MACADDRS		0x0C /* get all configured MAC addrs */
+#define IXGBE_VF_SET_MCAST_PROMISC	0x0D /* enable multicast promiscuous */
+#define IXGBE_VF_GET_MTU		0x0E /* get bounds on MTU */
+#define IXGBE_VF_SET_MTU		0x0F /* set a specific MTU */
 
-#define IXGBE_VF_MBX_INIT_TIMEOUT 2000 /* number of retries on mailbox */
-#define IXGBE_VF_MBX_INIT_DELAY   500  /* microseconds between retries */
+/* mailbox API, version 2.0 PF requests */
+#define IXGBE_PF_TRANSPARENT_VLAN	0x0101 /* enable transparent vlan */
+
+#define IXGBE_VF_MBX_INIT_TIMEOUT	2000 /* number of retries on mailbox */
+#define IXGBE_VF_MBX_INIT_DELAY		500  /* microseconds between retries */
 
 s32 ixgbe_read_mbx(struct ixgbe_hw *, u32 *, u16, u16);
 s32 ixgbe_write_mbx(struct ixgbe_hw *, u32 *, u16, u16);
+s32 ixgbe_read_posted_mbx(struct ixgbe_hw *, u32 *, u16, u16);
+s32 ixgbe_write_posted_mbx(struct ixgbe_hw *, u32 *, u16, u16);
 s32 ixgbe_check_for_msg(struct ixgbe_hw *, u16);
 s32 ixgbe_check_for_ack(struct ixgbe_hw *, u16);
 s32 ixgbe_check_for_rst(struct ixgbe_hw *, u16);
-#ifdef CONFIG_PCI_IOV
+void ixgbe_init_mbx_ops_generic(struct ixgbe_hw *hw);
+void ixgbe_init_mbx_params_vf(struct ixgbe_hw *);
 void ixgbe_init_mbx_params_pf(struct ixgbe_hw *);
-#endif /* CONFIG_PCI_IOV */
-
-extern struct ixgbe_mbx_operations mbx_ops_generic;
 
 #endif /* _IXGBE_MBX_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_osdep.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_osdep.h
new file mode 100644
index 00000000..2e40048
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_osdep.h
@@ -0,0 +1,200 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+
+/* glue for the OS independent part of ixgbe
+ * includes register access macros
+ */
+
+#ifndef _IXGBE_OSDEP_H_
+#define _IXGBE_OSDEP_H_
+
+#include <linux/pci.h>
+#include <linux/delay.h>
+#include <linux/interrupt.h>
+#include <linux/if_ether.h>
+#include <linux/sched.h>
+#include "kcompat.h"
+
+#define IXGBE_CPU_TO_BE16(_x) cpu_to_be16(_x)
+#define IXGBE_BE16_TO_CPU(_x) be16_to_cpu(_x)
+#define IXGBE_CPU_TO_BE32(_x) cpu_to_be32(_x)
+#define IXGBE_BE32_TO_CPU(_x) be32_to_cpu(_x)
+
+#define msec_delay(_x) msleep(_x)
+
+#define usec_delay(_x) udelay(_x)
+
+#define STATIC static
+
+#define IOMEM __iomem
+
+#ifdef DBG
+#define ASSERT(_x)		BUG_ON(!(_x))
+#define DEBUGOUT(S)		printk(KERN_DEBUG S)
+#define DEBUGOUT1(S, A...)	printk(KERN_DEBUG S, ## A)
+#define DEBUGOUT2(S, A...)	printk(KERN_DEBUG S, ## A)
+#define DEBUGOUT3(S, A...)	printk(KERN_DEBUG S, ## A)
+#define DEBUGOUT4(S, A...)	printk(KERN_DEBUG S, ## A)
+#define DEBUGOUT5(S, A...)	printk(KERN_DEBUG S, ## A)
+#define DEBUGOUT6(S, A...)	printk(KERN_DEBUG S, ## A)
+#else
+#define ASSERT(_x)		do {} while (0)
+#define DEBUGOUT(S)		do {} while (0)
+#define DEBUGOUT1(S, A...)	do {} while (0)
+#define DEBUGOUT2(S, A...)	do {} while (0)
+#define DEBUGOUT3(S, A...)	do {} while (0)
+#define DEBUGOUT4(S, A...)	do {} while (0)
+#define DEBUGOUT5(S, A...)	do {} while (0)
+#define DEBUGOUT6(S, A...)	do {} while (0)
+#endif
+
+#define DEBUGFUNC(S)		do {} while (0)
+
+#define IXGBE_SFP_DETECT_RETRIES	2
+
+struct ixgbe_hw;
+struct ixgbe_msg {
+	u16 msg_enable;
+};
+struct net_device *ixgbe_hw_to_netdev(const struct ixgbe_hw *hw);
+struct ixgbe_msg *ixgbe_hw_to_msg(const struct ixgbe_hw *hw);
+
+#define hw_dbg(hw, format, arg...) \
+	netdev_dbg(ixgbe_hw_to_netdev(hw), format, ## arg)
+#define hw_err(hw, format, arg...) \
+	netdev_err(ixgbe_hw_to_netdev(hw), format, ## arg)
+#define e_dev_info(format, arg...) \
+	dev_info(pci_dev_to_dev(adapter->pdev), format, ## arg)
+#define e_dev_warn(format, arg...) \
+	dev_warn(pci_dev_to_dev(adapter->pdev), format, ## arg)
+#define e_dev_err(format, arg...) \
+	dev_err(pci_dev_to_dev(adapter->pdev), format, ## arg)
+#define e_dev_notice(format, arg...) \
+	dev_notice(pci_dev_to_dev(adapter->pdev), format, ## arg)
+#define e_dbg(msglvl, format, arg...) \
+	netif_dbg(adapter, msglvl, adapter->netdev, format, ## arg)
+#define e_info(msglvl, format, arg...) \
+	netif_info(adapter, msglvl, adapter->netdev, format, ## arg)
+#define e_err(msglvl, format, arg...) \
+	netif_err(adapter, msglvl, adapter->netdev, format, ## arg)
+#define e_warn(msglvl, format, arg...) \
+	netif_warn(adapter, msglvl, adapter->netdev, format, ## arg)
+#define e_crit(msglvl, format, arg...) \
+	netif_crit(adapter, msglvl, adapter->netdev, format, ## arg)
+
+#define IXGBE_DEAD_READ_RETRIES 10
+#define IXGBE_DEAD_READ_REG 0xdeadbeefU
+#define IXGBE_FAILED_READ_REG 0xffffffffU
+#define IXGBE_FAILED_READ_CFG_DWORD 0xffffffffU
+#define IXGBE_FAILED_READ_CFG_WORD 0xffffU
+#define IXGBE_FAILED_READ_CFG_BYTE 0xffU
+
+#define IXGBE_WRITE_REG_ARRAY(a, reg, offset, value) \
+	IXGBE_WRITE_REG((a), (reg) + ((offset) << 2), (value))
+
+#define IXGBE_READ_REG(h, r) ixgbe_read_reg(h, r, false)
+#define IXGBE_R32_Q(h, r) ixgbe_read_reg(h, r, true)
+
+#define IXGBE_READ_REG_ARRAY(a, reg, offset) ( \
+	IXGBE_READ_REG((a), (reg) + ((offset) << 2)))
+
+#ifndef writeq
+#define writeq(val, addr)	do { writel((u32) (val), addr); \
+				     writel((u32) (val >> 32), (addr + 4)); \
+				} while (0);
+#endif
+
+#define IXGBE_WRITE_FLUSH(a) IXGBE_READ_REG(a, IXGBE_STATUS)
+
+u32 ixgbe_read_reg(struct ixgbe_hw *, u32 reg, bool quiet);
+extern u16 ixgbe_read_pci_cfg_word(struct ixgbe_hw *hw, u32 reg);
+extern void ixgbe_write_pci_cfg_word(struct ixgbe_hw *hw, u32 reg, u16 value);
+extern void ewarn(struct ixgbe_hw *hw, const char *str);
+
+#define IXGBE_READ_PCIE_WORD ixgbe_read_pci_cfg_word
+#define IXGBE_WRITE_PCIE_WORD ixgbe_write_pci_cfg_word
+#define IXGBE_EEPROM_GRANT_ATTEMPS 100
+#define IXGBE_HTONL(_i) htonl(_i)
+#define IXGBE_NTOHL(_i) ntohl(_i)
+#define IXGBE_NTOHS(_i) ntohs(_i)
+#define IXGBE_CPU_TO_LE32(_i) cpu_to_le32(_i)
+#define IXGBE_CPU_TO_LE16(_i) cpu_to_le16(_i)
+#define IXGBE_LE32_TO_CPU(_i) le32_to_cpu(_i)
+#define IXGBE_LE32_TO_CPUS(_i) le32_to_cpus(_i)
+#define EWARN(H, W) ewarn(H, W)
+
+enum {
+	IXGBE_ERROR_SOFTWARE,
+	IXGBE_ERROR_POLLING,
+	IXGBE_ERROR_INVALID_STATE,
+	IXGBE_ERROR_UNSUPPORTED,
+	IXGBE_ERROR_ARGUMENT,
+	IXGBE_ERROR_CAUTION,
+};
+
+#define ERROR_REPORT(level, format, arg...) do {				\
+	switch (level) {							\
+	case IXGBE_ERROR_SOFTWARE:						\
+	case IXGBE_ERROR_CAUTION:						\
+	case IXGBE_ERROR_POLLING:						\
+		netif_warn(ixgbe_hw_to_msg(hw), drv, ixgbe_hw_to_netdev(hw),	\
+			   format, ## arg);					\
+		break;								\
+	case IXGBE_ERROR_INVALID_STATE:						\
+	case IXGBE_ERROR_UNSUPPORTED:						\
+	case IXGBE_ERROR_ARGUMENT:						\
+		netif_err(ixgbe_hw_to_msg(hw), hw, ixgbe_hw_to_netdev(hw),	\
+			  format, ## arg);					\
+		break;								\
+	default:								\
+		break;								\
+	}									\
+} while (0)
+
+#define ERROR_REPORT1 ERROR_REPORT
+#define ERROR_REPORT2 ERROR_REPORT
+#define ERROR_REPORT3 ERROR_REPORT
+
+#define UNREFERENCED_XPARAMETER
+#define UNREFERENCED_1PARAMETER(_p) do {		\
+	uninitialized_var(_p);				\
+} while (0)
+#define UNREFERENCED_2PARAMETER(_p, _q) do {		\
+	uninitialized_var(_p);				\
+	uninitialized_var(_q);				\
+} while (0)
+#define UNREFERENCED_3PARAMETER(_p, _q, _r) do {	\
+	uninitialized_var(_p);				\
+	uninitialized_var(_q);				\
+	uninitialized_var(_r);				\
+} while (0)
+#define UNREFERENCED_4PARAMETER(_p, _q, _r, _s) do {	\
+	uninitialized_var(_p);				\
+	uninitialized_var(_q);				\
+	uninitialized_var(_r);				\
+	uninitialized_var(_s);				\
+} while (0)
+
+#endif /* _IXGBE_OSDEP_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_osdep2.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_osdep2.h
new file mode 100644
index 00000000..549b353
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_osdep2.h
@@ -0,0 +1,68 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#ifndef _IXGBE_OSDEP2_H_
+#define _IXGBE_OSDEP2_H_
+
+static inline bool ixgbe_removed(void __iomem *addr)
+{
+	return unlikely(!addr);
+}
+#define IXGBE_REMOVED(a) ixgbe_removed(a)
+
+static inline void IXGBE_WRITE_REG(struct ixgbe_hw *hw, u32 reg, u32 value)
+{
+	u8 __iomem *reg_addr;
+
+	reg_addr = ACCESS_ONCE(hw->hw_addr);
+	if (IXGBE_REMOVED(reg_addr))
+		return;
+#ifdef DBG
+	switch (reg) {
+	case IXGBE_EIMS:
+	case IXGBE_EIMC:
+	case IXGBE_EIAM:
+	case IXGBE_EIAC:
+	case IXGBE_EICR:
+	case IXGBE_EICS:
+		printk("%s: Reg - 0x%05X, value - 0x%08X\n", __func__,
+		       reg, value);
+	default:
+		break;
+	}
+#endif /* DBG */
+	writel(value, reg_addr + reg);
+}
+
+static inline void IXGBE_WRITE_REG64(struct ixgbe_hw *hw, u32 reg, u64 value)
+{
+	u8 __iomem *reg_addr;
+
+	reg_addr = ACCESS_ONCE(hw->hw_addr);
+	if (IXGBE_REMOVED(reg_addr))
+		return;
+	writeq(value, reg_addr + reg);
+}
+
+#endif /* _IXGBE_OSDEP2_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_param.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_param.c
new file mode 100644
index 00000000..5efd016
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_param.c
@@ -0,0 +1,1256 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#include <linux/types.h>
+#include <linux/module.h>
+
+#include "ixgbe.h"
+
+/* This is the only thing that needs to be changed to adjust the
+ * maximum number of ports that the driver can manage.
+ */
+
+#define IXGBE_MAX_NIC	32
+
+#define OPTION_UNSET	-1
+#define OPTION_DISABLED	0
+#define OPTION_ENABLED	1
+
+#define STRINGIFY(foo)	#foo /* magic for getting defines into strings */
+#define XSTRINGIFY(bar)	STRINGIFY(bar)
+
+/* All parameters are treated the same, as an integer array of values.
+ * This macro just reduces the need to repeat the same declaration code
+ * over and over (plus this helps to avoid typo bugs).
+ */
+
+#define IXGBE_PARAM_INIT { [0 ... IXGBE_MAX_NIC] = OPTION_UNSET }
+#ifndef module_param_array
+/* Module Parameters are always initialized to -1, so that the driver
+ * can tell the difference between no user specified value or the
+ * user asking for the default value.
+ * The true default values are loaded in when ixgbe_check_options is called.
+ *
+ * This is a GCC extension to ANSI C.
+ * See the item "Labelled Elements in Initializers" in the section
+ * "Extensions to the C Language Family" of the GCC documentation.
+ */
+
+#define IXGBE_PARAM(X, desc) \
+	static const int __devinitdata X[IXGBE_MAX_NIC+1] = IXGBE_PARAM_INIT; \
+	MODULE_PARM(X, "1-" __MODULE_STRING(IXGBE_MAX_NIC) "i"); \
+	MODULE_PARM_DESC(X, desc);
+#else
+#define IXGBE_PARAM(X, desc) \
+	static int __devinitdata X[IXGBE_MAX_NIC+1] = IXGBE_PARAM_INIT; \
+	static unsigned int num_##X; \
+	module_param_array_named(X, X, int, &num_##X, 0); \
+	MODULE_PARM_DESC(X, desc);
+#endif
+
+IXGBE_PARAM(EEE, "Energy Efficient Ethernet (EEE) ,0=disabled, 1=enabled )"
+	    "default EEE disable");
+/* IntMode (Interrupt Mode)
+ *
+ * Valid Range: 0-2
+ *  - 0 - Legacy Interrupt
+ *  - 1 - MSI Interrupt
+ *  - 2 - MSI-X Interrupt(s)
+ *
+ * Default Value: 2
+ */
+IXGBE_PARAM(InterruptType, "Change Interrupt Mode (0=Legacy, 1=MSI, 2=MSI-X), "
+	    "default IntMode (deprecated)");
+IXGBE_PARAM(IntMode, "Change Interrupt Mode (0=Legacy, 1=MSI, 2=MSI-X), "
+	    "default 2");
+#define IXGBE_INT_LEGACY		0
+#define IXGBE_INT_MSI			1
+#define IXGBE_INT_MSIX			2
+
+/* MQ - Multiple Queue enable/disable
+ *
+ * Valid Range: 0, 1
+ *  - 0 - disables MQ
+ *  - 1 - enables MQ
+ *
+ * Default Value: 1
+ */
+
+IXGBE_PARAM(MQ, "Disable or enable Multiple Queues, default 1");
+
+#if IS_ENABLED(CONFIG_DCA)
+/* DCA - Direct Cache Access (DCA) Control
+ *
+ * This option allows the device to hint to DCA enabled processors
+ * which CPU should have its cache warmed with the data being
+ * transferred over PCIe.  This can increase performance by reducing
+ * cache misses.  ixgbe hardware supports DCA for:
+ * tx descriptor writeback
+ * rx descriptor writeback
+ * rx data
+ * rx data header only (in packet split mode)
+ *
+ * enabling option 2 can cause cache thrash in some tests, particularly
+ * if the CPU is completely utilized
+ *
+ * Valid Range: 0 - 2
+ *  - 0 - disables DCA
+ *  - 1 - enables DCA
+ *  - 2 - enables DCA with rx data included
+ *
+ * Default Value: 2
+ */
+
+#define IXGBE_MAX_DCA 2
+
+IXGBE_PARAM(DCA, "Disable or enable Direct Cache Access, 0=disabled, "
+	    "1=descriptor only, 2=descriptor and data");
+#endif /* CONFIG_DCA */
+
+/* RSS - Receive-Side Scaling (RSS) Descriptor Queues
+ *
+ * Valid Range: 0-16
+ *  - 0 - enables RSS and sets the Desc. Q's to min(16, num_online_cpus()).
+ *  - 1-16 - enables RSS and sets the Desc. Q's to the specified value.
+ *
+ * Default Value: 0
+ */
+
+IXGBE_PARAM(RSS, "Number of Receive-Side Scaling Descriptor Queues, "
+	    "default 0=number of cpus");
+
+/* VMDQ - Virtual Machine Device Queues (VMDQ)
+ *
+ * Valid Range: 1-16
+ *  - 0/1 Disables VMDQ by allocating only a single queue.
+ *  - 2-16 - enables VMDQ and sets the Desc. Q's to the specified value.
+ *
+ * Default Value: 8
+ */
+
+#define IXGBE_DEFAULT_NUM_VMDQ 8
+
+IXGBE_PARAM(VMDQ, "Number of Virtual Machine Device Queues: 0/1 = disable (1 queue) "
+	    "2-16 enable (default=" XSTRINGIFY(IXGBE_DEFAULT_NUM_VMDQ) ")");
+
+#ifdef CONFIG_PCI_IOV
+/* max_vfs - SR I/O Virtualization
+ *
+ * Valid Range: 0-63
+ *  - 0 Disables SR-IOV
+ *  - 1-63 - enables SR-IOV and sets the number of VFs enabled
+ *
+ * Default Value: 0
+ */
+
+#define MAX_SRIOV_VFS 63
+
+IXGBE_PARAM(max_vfs, "Number of Virtual Functions: 0 = disable (default), "
+	    "1-" XSTRINGIFY(MAX_SRIOV_VFS) " = enable "
+	    "this many VFs");
+
+/* VEPA - Set internal bridge to VEPA mode
+ *
+ * Valid Range: 0-1
+ *  - 0 Set bridge to VEB mode
+ *  - 1 Set bridge to VEPA mode
+ *
+ * Default Value: 0
+ */
+/*
+ *Note:
+ *=====
+ * This provides ability to ensure VEPA mode on the internal bridge even if
+ * the kernel does not support the netdev bridge setting operations.
+*/
+IXGBE_PARAM(VEPA, "VEPA Bridge Mode: 0 = VEB (default), 1 = VEPA");
+#endif
+
+/* Interrupt Throttle Rate (interrupts/sec)
+ *
+ * Valid Range: 956-488281 (0=off, 1=dynamic)
+ *
+ * Default Value: 1
+ */
+#define DEFAULT_ITR		1
+IXGBE_PARAM(InterruptThrottleRate, "Maximum interrupts per second, per vector, "
+	    "(0,1,956-488281), default 1");
+#define MAX_ITR		IXGBE_MAX_INT_RATE
+#define MIN_ITR		IXGBE_MIN_INT_RATE
+
+#ifndef IXGBE_NO_LLI
+
+/* LLIPort (Low Latency Interrupt TCP Port)
+ *
+ * Valid Range: 0 - 65535
+ *
+ * Default Value: 0 (disabled)
+ */
+IXGBE_PARAM(LLIPort, "Low Latency Interrupt TCP Port (0-65535)");
+
+#define DEFAULT_LLIPORT		0
+#define MAX_LLIPORT		0xFFFF
+#define MIN_LLIPORT		0
+
+/* LLIPush (Low Latency Interrupt on TCP Push flag)
+ *
+ * Valid Range: 0,1
+ *
+ * Default Value: 0 (disabled)
+ */
+IXGBE_PARAM(LLIPush, "Low Latency Interrupt on TCP Push flag (0,1)");
+
+#define DEFAULT_LLIPUSH		0
+#define MAX_LLIPUSH		1
+#define MIN_LLIPUSH		0
+
+/* LLISize (Low Latency Interrupt on Packet Size)
+ *
+ * Valid Range: 0 - 1500
+ *
+ * Default Value: 0 (disabled)
+ */
+IXGBE_PARAM(LLISize, "Low Latency Interrupt on Packet Size (0-1500)");
+
+#define DEFAULT_LLISIZE		0
+#define MAX_LLISIZE		1500
+#define MIN_LLISIZE		0
+
+/* LLIEType (Low Latency Interrupt Ethernet Type)
+ *
+ * Valid Range: 0 - 0x8fff
+ *
+ * Default Value: 0 (disabled)
+ */
+IXGBE_PARAM(LLIEType, "Low Latency Interrupt Ethernet Protocol Type");
+
+#define DEFAULT_LLIETYPE	0
+#define MAX_LLIETYPE		0x8fff
+#define MIN_LLIETYPE		0
+
+/* LLIVLANP (Low Latency Interrupt on VLAN priority threshold)
+ *
+ * Valid Range: 0 - 7
+ *
+ * Default Value: 0 (disabled)
+ */
+IXGBE_PARAM(LLIVLANP, "Low Latency Interrupt on VLAN priority threshold");
+
+#define DEFAULT_LLIVLANP	0
+#define MAX_LLIVLANP		7
+#define MIN_LLIVLANP		0
+
+#endif /* IXGBE_NO_LLI */
+#ifdef HAVE_TX_MQ
+/* Flow Director packet buffer allocation level
+ *
+ * Valid Range: 1-3
+ *   1 = 8k hash/2k perfect,
+ *   2 = 16k hash/4k perfect,
+ *   3 = 32k hash/8k perfect
+ *
+ * Default Value: 0
+ */
+IXGBE_PARAM(FdirPballoc, "Flow Director packet buffer allocation level:\n"
+	    "\t\t\t1 = 8k hash filters or 2k perfect filters\n"
+	    "\t\t\t2 = 16k hash filters or 4k perfect filters\n"
+	    "\t\t\t3 = 32k hash filters or 8k perfect filters");
+
+#define IXGBE_DEFAULT_FDIR_PBALLOC IXGBE_FDIR_PBALLOC_64K
+
+/* Software ATR packet sample rate
+ *
+ * Valid Range: 0-255  0 = off, 1-255 = rate of Tx packet inspection
+ *
+ * Default Value: 20
+ */
+IXGBE_PARAM(AtrSampleRate, "Software ATR Tx packet sample rate");
+
+#define IXGBE_MAX_ATR_SAMPLE_RATE	255
+#define IXGBE_MIN_ATR_SAMPLE_RATE	1
+#define IXGBE_ATR_SAMPLE_RATE_OFF	0
+#define IXGBE_DEFAULT_ATR_SAMPLE_RATE	20
+#endif /* HAVE_TX_MQ */
+
+#if IS_ENABLED(CONFIG_FCOE)
+/* FCoE - Fibre Channel over Ethernet Offload  Enable/Disable
+ *
+ * Valid Range: 0, 1
+ *  - 0 - disables FCoE Offload
+ *  - 1 - enables FCoE Offload
+ *
+ * Default Value: 1
+ */
+IXGBE_PARAM(FCoE, "Disable or enable FCoE Offload, default 1");
+#endif /* CONFIG_FCOE */
+
+/* Enable/disable Malicious Driver Detection
+ *
+ * Valid Values: 0(off), 1(on)
+ *
+ * Default Value: 1
+ */
+IXGBE_PARAM(MDD, "Malicious Driver Detection: (0,1), default 1 = on");
+
+/* Enable/disable Large Receive Offload
+ *
+ * Valid Values: 0(off), 1(on)
+ *
+ * Default Value: 1
+ */
+IXGBE_PARAM(LRO, "Large Receive Offload (0,1), default 0 = off");
+
+/* Enable/disable support for untested SFP+ modules on 82599-based adapters
+ *
+ * Valid Values: 0(Disable), 1(Enable)
+ *
+ * Default Value: 0
+ */
+IXGBE_PARAM(allow_unsupported_sfp, "Allow unsupported and untested "
+	    "SFP+ modules on 82599 based adapters, default 0 = Disable");
+
+/* Enable/disable support for DMA coalescing
+ *
+ * Valid Values: 0(off), 41 - 10000(on)
+ *
+ * Default Value: 0
+ */
+IXGBE_PARAM(dmac_watchdog,
+	    "DMA coalescing watchdog in microseconds (0,41-10000), default 0 = off");
+
+/* Enable/disable support for VXLAN rx checksum offload
+ *
+ * Valid Values: 0(Disable), 1(Enable)
+ *
+ * Default Value: 1 on hardware that supports it
+ */
+IXGBE_PARAM(vxlan_rx,
+	    "VXLAN receive checksum offload (0,1), default 1 = Enable");
+
+
+struct ixgbe_option {
+	enum { enable_option, range_option, list_option } type;
+	const char *name;
+	const char *err;
+	const char *msg;
+	int def;
+	union {
+		struct { /* range_option info */
+			int min;
+			int max;
+		} r;
+		struct { /* list_option info */
+			int nr;
+			const struct ixgbe_opt_list {
+				int i;
+				char *str;
+			} *p;
+		} l;
+	} arg;
+};
+
+#ifndef IXGBE_NO_LLI
+#ifdef module_param_array
+/**
+ *  helper function to determine LLI support
+ *
+ *  LLI is only supported for 82599 and X540
+ *  LLIPush is not supported on 82599
+ **/
+static bool __devinit ixgbe_lli_supported(struct ixgbe_adapter *adapter,
+					  struct ixgbe_option *opt)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+
+	if (hw->mac.type == ixgbe_mac_82599EB) {
+
+		if (LLIPush[adapter->bd_number] > 0)
+			goto not_supp;
+
+		return true;
+	}
+
+	if (hw->mac.type == ixgbe_mac_X540)
+		return true;
+
+not_supp:
+	DPRINTK(PROBE, INFO, "%s not supported on this HW\n", opt->name);
+	return false;
+}
+#endif /* module_param_array */
+#endif /* IXGBE_NO_LLI */
+
+static int __devinit ixgbe_validate_option(unsigned int *value,
+					   struct ixgbe_option *opt)
+{
+	if (*value == OPTION_UNSET) {
+		printk(KERN_INFO "ixgbe: Invalid %s specified (%d),  %s\n",
+			opt->name, *value, opt->err);
+		*value = opt->def;
+		return 0;
+	}
+
+	switch (opt->type) {
+	case enable_option:
+		switch (*value) {
+		case OPTION_ENABLED:
+			printk(KERN_INFO "ixgbe: %s Enabled\n", opt->name);
+			return 0;
+		case OPTION_DISABLED:
+			printk(KERN_INFO "ixgbe: %s Disabled\n", opt->name);
+			return 0;
+		}
+		break;
+	case range_option:
+		if ((*value >= opt->arg.r.min && *value <= opt->arg.r.max) ||
+		    *value == opt->def) {
+			if (opt->msg)
+				printk(KERN_INFO "ixgbe: %s set to %d, %s\n",
+				       opt->name, *value, opt->msg);
+			else
+				printk(KERN_INFO "ixgbe: %s set to %d\n",
+				       opt->name, *value);
+			return 0;
+		}
+		break;
+	case list_option: {
+		int i;
+
+		for (i = 0; i < opt->arg.l.nr; i++) {
+			const struct ixgbe_opt_list *ent = &opt->arg.l.p[i];
+			if (*value == ent->i) {
+				if (ent->str[0] != '\0')
+					printk(KERN_INFO "%s\n", ent->str);
+				return 0;
+			}
+		}
+	}
+		break;
+	default:
+		BUG();
+	}
+
+	printk(KERN_INFO "ixgbe: Invalid %s specified (%d),  %s\n",
+	       opt->name, *value, opt->err);
+	*value = opt->def;
+	return -1;
+}
+
+#define LIST_LEN(l) (sizeof(l) / sizeof(l[0]))
+
+/**
+ * ixgbe_check_options - Range Checking for Command Line Parameters
+ * @adapter: board private structure
+ *
+ * This routine checks all command line parameters for valid user
+ * input.  If an invalid value is given, or if no user specified
+ * value exists, a default value is used.  The final value is stored
+ * in a variable in the adapter structure.
+ **/
+void __devinit ixgbe_check_options(struct ixgbe_adapter *adapter)
+{
+	unsigned int mdd;
+	int bd = adapter->bd_number;
+	u32 *aflags = &adapter->flags;
+	struct ixgbe_ring_feature *feature = adapter->ring_feature;
+	unsigned int vmdq;
+
+	if (bd >= IXGBE_MAX_NIC) {
+		printk(KERN_NOTICE
+		       "Warning: no configuration for board #%d\n", bd);
+		printk(KERN_NOTICE "Using defaults for all values\n");
+#ifndef module_param_array
+		bd = IXGBE_MAX_NIC;
+#endif
+	}
+
+	{ /* Interrupt Mode */
+		unsigned int int_mode;
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "Interrupt Mode",
+			.err =
+			  "using default of " __MODULE_STRING(IXGBE_INT_MSIX),
+			.def = IXGBE_INT_MSIX,
+			.arg = { .r = { .min = IXGBE_INT_LEGACY,
+					.max = IXGBE_INT_MSIX} }
+		};
+
+#ifdef module_param_array
+		if (num_IntMode > bd || num_InterruptType > bd) {
+#endif
+			int_mode = IntMode[bd];
+			if (int_mode == OPTION_UNSET)
+				int_mode = InterruptType[bd];
+			ixgbe_validate_option(&int_mode, &opt);
+			switch (int_mode) {
+			case IXGBE_INT_MSIX:
+				if (!(*aflags & IXGBE_FLAG_MSIX_CAPABLE))
+					printk(KERN_INFO
+					       "Ignoring MSI-X setting; "
+					       "support unavailable\n");
+				break;
+			case IXGBE_INT_MSI:
+				if (!(*aflags & IXGBE_FLAG_MSI_CAPABLE)) {
+					printk(KERN_INFO
+					       "Ignoring MSI setting; "
+					       "support unavailable\n");
+				} else {
+					*aflags &= ~IXGBE_FLAG_MSIX_CAPABLE;
+				}
+				break;
+			case IXGBE_INT_LEGACY:
+			default:
+				*aflags &= ~IXGBE_FLAG_MSIX_CAPABLE;
+				*aflags &= ~IXGBE_FLAG_MSI_CAPABLE;
+				break;
+			}
+#ifdef module_param_array
+		} else {
+			/* default settings */
+			if (*aflags & IXGBE_FLAG_MSIX_CAPABLE) {
+				*aflags |= IXGBE_FLAG_MSI_CAPABLE;
+			} else {
+				*aflags &= ~IXGBE_FLAG_MSIX_CAPABLE;
+				*aflags &= ~IXGBE_FLAG_MSI_CAPABLE;
+			}
+		}
+#endif
+	}
+	{ /* Multiple Queue Support */
+		static struct ixgbe_option opt = {
+			.type = enable_option,
+			.name = "Multiple Queue Support",
+			.err  = "defaulting to Enabled",
+			.def  = OPTION_ENABLED
+		};
+
+#ifdef module_param_array
+		if (num_MQ > bd) {
+#endif
+			unsigned int mq = MQ[bd];
+			ixgbe_validate_option(&mq, &opt);
+			if (mq)
+				*aflags |= IXGBE_FLAG_MQ_CAPABLE;
+			else
+				*aflags &= ~IXGBE_FLAG_MQ_CAPABLE;
+#ifdef module_param_array
+		} else {
+			*aflags |= IXGBE_FLAG_MQ_CAPABLE;
+		}
+#endif
+		/* Check Interoperability */
+		if ((*aflags & IXGBE_FLAG_MQ_CAPABLE) &&
+		    !(*aflags & IXGBE_FLAG_MSIX_CAPABLE)) {
+			DPRINTK(PROBE, INFO,
+				"Multiple queues are not supported while MSI-X "
+				"is disabled.  Disabling Multiple Queues.\n");
+			*aflags &= ~IXGBE_FLAG_MQ_CAPABLE;
+		}
+	}
+#if IS_ENABLED(CONFIG_DCA)
+	{ /* Direct Cache Access (DCA) */
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "Direct Cache Access (DCA)",
+			.err  = "defaulting to Enabled",
+			.def  = IXGBE_MAX_DCA,
+			.arg  = { .r = { .min = OPTION_DISABLED,
+					 .max = IXGBE_MAX_DCA} }
+		};
+		unsigned int dca = opt.def;
+
+#ifdef module_param_array
+		if (num_DCA > bd) {
+#endif
+			dca = DCA[bd];
+			ixgbe_validate_option(&dca, &opt);
+			if (!dca)
+				*aflags &= ~IXGBE_FLAG_DCA_CAPABLE;
+
+			/* Check Interoperability */
+			if (!(*aflags & IXGBE_FLAG_DCA_CAPABLE)) {
+				DPRINTK(PROBE, INFO, "DCA is disabled\n");
+				*aflags &= ~IXGBE_FLAG_DCA_ENABLED;
+			}
+
+			if (dca == IXGBE_MAX_DCA) {
+				DPRINTK(PROBE, INFO,
+					"DCA enabled for rx data\n");
+				adapter->flags |= IXGBE_FLAG_DCA_ENABLED_DATA;
+			}
+#ifdef module_param_array
+		} else {
+			/* make sure to clear the capability flag if the
+			 * option is disabled by default above */
+			if (opt.def == OPTION_DISABLED)
+				*aflags &= ~IXGBE_FLAG_DCA_CAPABLE;
+		}
+#endif
+		if (dca == IXGBE_MAX_DCA)
+			adapter->flags |= IXGBE_FLAG_DCA_ENABLED_DATA;
+	}
+#endif /* CONFIG_DCA */
+	{ /* Receive-Side Scaling (RSS) */
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "Receive-Side Scaling (RSS)",
+			.err  = "using default.",
+			.def  = 0,
+			.arg  = { .r = { .min = 0,
+					 .max = 16} }
+		};
+		unsigned int rss = RSS[bd];
+		/* adjust Max allowed RSS queues based on MAC type */
+		opt.arg.r.max = ixgbe_max_rss_indices(adapter);
+
+#ifdef module_param_array
+		if (num_RSS > bd) {
+#endif
+			ixgbe_validate_option(&rss, &opt);
+			/* base it off num_online_cpus() with hardware limit */
+			if (!rss)
+				rss = min_t(int, opt.arg.r.max,
+					    num_online_cpus());
+			else
+				feature[RING_F_FDIR].limit = rss;
+
+			feature[RING_F_RSS].limit = rss;
+#ifdef module_param_array
+		} else if (opt.def == 0) {
+			rss = min_t(int, ixgbe_max_rss_indices(adapter),
+				    num_online_cpus());
+			feature[RING_F_RSS].limit = rss;
+		}
+#endif
+		/* Check Interoperability */
+		if (rss > 1) {
+			if (!(*aflags & IXGBE_FLAG_MQ_CAPABLE)) {
+				DPRINTK(PROBE, INFO,
+					"Multiqueue is disabled.  "
+					"Limiting RSS.\n");
+				feature[RING_F_RSS].limit = 1;
+			}
+		}
+	}
+	{ /* Virtual Machine Device Queues (VMDQ) */
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "Virtual Machine Device Queues (VMDQ)",
+			.err  = "defaulting to Disabled",
+			.def  = OPTION_DISABLED,
+			.arg  = { .r = { .min = OPTION_DISABLED,
+					 .max = IXGBE_MAX_VMDQ_INDICES
+				} }
+		};
+
+		switch (adapter->hw.mac.type) {
+		case ixgbe_mac_82598EB:
+			/* 82598 only supports up to 16 pools */
+				opt.arg.r.max = 16;
+			break;
+		default:
+			break;
+		}
+
+#ifdef module_param_array
+		if (num_VMDQ > bd) {
+#endif
+			vmdq = VMDQ[bd];
+
+			ixgbe_validate_option(&vmdq, &opt);
+
+			/* zero or one both mean disabled from our driver's
+			 * perspective */
+			if (vmdq > 1) {
+				*aflags |= IXGBE_FLAG_VMDQ_ENABLED;
+			} else
+				*aflags &= ~IXGBE_FLAG_VMDQ_ENABLED;
+
+			feature[RING_F_VMDQ].limit = vmdq;
+#ifdef module_param_array
+		} else {
+			if (opt.def == OPTION_DISABLED)
+				*aflags &= ~IXGBE_FLAG_VMDQ_ENABLED;
+			else
+				*aflags |= IXGBE_FLAG_VMDQ_ENABLED;
+
+			feature[RING_F_VMDQ].limit = opt.def;
+		}
+#endif
+		/* Check Interoperability */
+		if (*aflags & IXGBE_FLAG_VMDQ_ENABLED) {
+			if (!(*aflags & IXGBE_FLAG_MQ_CAPABLE)) {
+				DPRINTK(PROBE, INFO,
+					"VMDQ is not supported while multiple "
+					"queues are disabled.  "
+					"Disabling VMDQ.\n");
+				*aflags &= ~IXGBE_FLAG_VMDQ_ENABLED;
+				feature[RING_F_VMDQ].limit = 0;
+			}
+		}
+	}
+#ifdef CONFIG_PCI_IOV
+	{ /* Single Root I/O Virtualization (SR-IOV) */
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "I/O Virtualization (IOV)",
+			.err  = "defaulting to Disabled",
+			.def  = OPTION_DISABLED,
+			.arg  = { .r = { .min = OPTION_DISABLED,
+					 .max = MAX_SRIOV_VFS} }
+		};
+
+#ifdef module_param_array
+		if (num_max_vfs > bd) {
+#endif
+			unsigned int vfs = max_vfs[bd];
+			if (ixgbe_validate_option(&vfs, &opt)) {
+				vfs = 0;
+				DPRINTK(PROBE, INFO,
+					"max_vfs out of range "
+					"Disabling SR-IOV.\n");
+			}
+
+			adapter->max_vfs = vfs;
+
+			if (vfs)
+				*aflags |= IXGBE_FLAG_SRIOV_ENABLED;
+			else
+				*aflags &= ~IXGBE_FLAG_SRIOV_ENABLED;
+#ifdef module_param_array
+		} else {
+			if (opt.def == OPTION_DISABLED) {
+				adapter->max_vfs = 0;
+				*aflags &= ~IXGBE_FLAG_SRIOV_ENABLED;
+			} else {
+				adapter->max_vfs = opt.def;
+				*aflags |= IXGBE_FLAG_SRIOV_ENABLED;
+			}
+		}
+#endif
+
+		/* Check Interoperability */
+		if (*aflags & IXGBE_FLAG_SRIOV_ENABLED) {
+			if (!(*aflags & IXGBE_FLAG_SRIOV_CAPABLE)) {
+				DPRINTK(PROBE, INFO,
+					"IOV is not supported on this "
+					"hardware.  Disabling IOV.\n");
+				*aflags &= ~IXGBE_FLAG_SRIOV_ENABLED;
+				adapter->max_vfs = 0;
+			} else if (!(*aflags & IXGBE_FLAG_MQ_CAPABLE)) {
+				DPRINTK(PROBE, INFO,
+					"IOV is not supported while multiple "
+					"queues are disabled.  "
+					"Disabling IOV.\n");
+				*aflags &= ~IXGBE_FLAG_SRIOV_ENABLED;
+				adapter->max_vfs = 0;
+			} 
+		}
+	}
+	{ /* VEPA Bridge Mode enable for SR-IOV mode */
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "VEPA Bridge Mode Enable",
+			.err  = "defaulting to disabled",
+			.def  = OPTION_DISABLED,
+			.arg  = { .r = { .min = OPTION_DISABLED,
+					 .max = OPTION_ENABLED} }
+		};
+
+#ifdef module_param_array
+		if (num_VEPA > bd) {
+#endif
+			unsigned int vepa = VEPA[bd];
+			ixgbe_validate_option(&vepa, &opt);
+			if (vepa)
+				adapter->flags |=
+					IXGBE_FLAG_SRIOV_VEPA_BRIDGE_MODE;
+#ifdef module_param_array
+		} else {
+			if (opt.def == OPTION_ENABLED)
+				adapter->flags |=
+					IXGBE_FLAG_SRIOV_VEPA_BRIDGE_MODE;
+		}
+#endif
+	}
+#endif /* CONFIG_PCI_IOV */
+	{ /* Interrupt Throttling Rate */
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "Interrupt Throttling Rate (ints/sec)",
+			.err  = "using default of "__MODULE_STRING(DEFAULT_ITR),
+			.def  = DEFAULT_ITR,
+			.arg  = { .r = { .min = MIN_ITR,
+					 .max = MAX_ITR } }
+		};
+
+#ifdef module_param_array
+		if (num_InterruptThrottleRate > bd) {
+#endif
+			u32 itr = InterruptThrottleRate[bd];
+			switch (itr) {
+			case 0:
+				DPRINTK(PROBE, INFO, "%s turned off\n",
+					opt.name);
+				adapter->rx_itr_setting = 0;
+				break;
+			case 1:
+				DPRINTK(PROBE, INFO, "dynamic interrupt "
+					"throttling enabled\n");
+				adapter->rx_itr_setting = 1;
+				break;
+			default:
+				ixgbe_validate_option(&itr, &opt);
+				/* the first bit is used as control */
+				adapter->rx_itr_setting = (1000000/itr) << 2;
+				break;
+			}
+			adapter->tx_itr_setting = adapter->rx_itr_setting;
+#ifdef module_param_array
+		} else {
+			adapter->rx_itr_setting = opt.def;
+			adapter->tx_itr_setting = opt.def;
+		}
+#endif
+	}
+#ifndef IXGBE_NO_LLI
+	{ /* Low Latency Interrupt TCP Port*/
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "Low Latency Interrupt TCP Port",
+			.err  = "using default of "
+					__MODULE_STRING(DEFAULT_LLIPORT),
+			.def  = DEFAULT_LLIPORT,
+			.arg  = { .r = { .min = MIN_LLIPORT,
+					 .max = MAX_LLIPORT } }
+		};
+
+#ifdef module_param_array
+		if (num_LLIPort > bd && ixgbe_lli_supported(adapter, &opt)) {
+#endif
+			adapter->lli_port = LLIPort[bd];
+			if (adapter->lli_port) {
+				ixgbe_validate_option(&adapter->lli_port, &opt);
+			} else {
+				DPRINTK(PROBE, INFO, "%s turned off\n",
+					opt.name);
+			}
+#ifdef module_param_array
+		} else {
+			adapter->lli_port = opt.def;
+		}
+#endif
+	}
+	{ /* Low Latency Interrupt on Packet Size */
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "Low Latency Interrupt on Packet Size",
+			.err  = "using default of "
+					__MODULE_STRING(DEFAULT_LLISIZE),
+			.def  = DEFAULT_LLISIZE,
+			.arg  = { .r = { .min = MIN_LLISIZE,
+					 .max = MAX_LLISIZE } }
+		};
+
+#ifdef module_param_array
+		if (num_LLISize > bd && ixgbe_lli_supported(adapter, &opt)) {
+#endif
+			adapter->lli_size = LLISize[bd];
+			if (adapter->lli_size) {
+				ixgbe_validate_option(&adapter->lli_size, &opt);
+			} else {
+				DPRINTK(PROBE, INFO, "%s turned off\n",
+					opt.name);
+			}
+#ifdef module_param_array
+		} else {
+			adapter->lli_size = opt.def;
+		}
+#endif
+	}
+	{ /*Low Latency Interrupt on TCP Push flag*/
+		static struct ixgbe_option opt = {
+			.type = enable_option,
+			.name = "Low Latency Interrupt on TCP Push flag",
+			.err  = "defaulting to Disabled",
+			.def  = OPTION_DISABLED
+		};
+
+#ifdef module_param_array
+		if (num_LLIPush > bd && ixgbe_lli_supported(adapter, &opt)) {
+#endif
+			unsigned int lli_push = LLIPush[bd];
+
+			ixgbe_validate_option(&lli_push, &opt);
+			if (lli_push)
+				*aflags |= IXGBE_FLAG_LLI_PUSH;
+			else
+				*aflags &= ~IXGBE_FLAG_LLI_PUSH;
+#ifdef module_param_array
+		} else {
+			*aflags &= ~IXGBE_FLAG_LLI_PUSH;
+		}
+#endif
+	}
+	{ /* Low Latency Interrupt EtherType*/
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "Low Latency Interrupt on Ethernet Protocol "
+				"Type",
+			.err  = "using default of "
+					__MODULE_STRING(DEFAULT_LLIETYPE),
+			.def  = DEFAULT_LLIETYPE,
+			.arg  = { .r = { .min = MIN_LLIETYPE,
+					 .max = MAX_LLIETYPE } }
+		};
+
+#ifdef module_param_array
+		if (num_LLIEType > bd && ixgbe_lli_supported(adapter, &opt)) {
+#endif
+			adapter->lli_etype = LLIEType[bd];
+			if (adapter->lli_etype) {
+				ixgbe_validate_option(&adapter->lli_etype,
+						      &opt);
+			} else {
+				DPRINTK(PROBE, INFO, "%s turned off\n",
+					opt.name);
+			}
+#ifdef module_param_array
+		} else {
+			adapter->lli_etype = opt.def;
+		}
+#endif
+	}
+	{ /* LLI VLAN Priority */
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "Low Latency Interrupt on VLAN priority "
+				"threshold",
+			.err  = "using default of "
+					__MODULE_STRING(DEFAULT_LLIVLANP),
+			.def  = DEFAULT_LLIVLANP,
+			.arg  = { .r = { .min = MIN_LLIVLANP,
+					 .max = MAX_LLIVLANP } }
+		};
+
+#ifdef module_param_array
+		if (num_LLIVLANP > bd && ixgbe_lli_supported(adapter, &opt)) {
+#endif
+			adapter->lli_vlan_pri = LLIVLANP[bd];
+			if (adapter->lli_vlan_pri) {
+				ixgbe_validate_option(&adapter->lli_vlan_pri,
+						      &opt);
+			} else {
+				DPRINTK(PROBE, INFO, "%s turned off\n",
+					opt.name);
+			}
+#ifdef module_param_array
+		} else {
+			adapter->lli_vlan_pri = opt.def;
+		}
+#endif
+	}
+#endif /* IXGBE_NO_LLI */
+#ifdef HAVE_TX_MQ
+	{ /* Flow Director packet buffer allocation */
+		unsigned int fdir_pballoc_mode;
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "Flow Director packet buffer allocation",
+			.err = "using default of "
+				__MODULE_STRING(IXGBE_DEFAULT_FDIR_PBALLOC),
+			.def = IXGBE_DEFAULT_FDIR_PBALLOC,
+			.arg = {.r = {.min = IXGBE_FDIR_PBALLOC_64K,
+				      .max = IXGBE_FDIR_PBALLOC_256K} }
+		};
+		char pstring[10];
+
+		if (adapter->hw.mac.type == ixgbe_mac_82598EB) {
+			adapter->fdir_pballoc = IXGBE_FDIR_PBALLOC_NONE;
+		} else if (num_FdirPballoc > bd) {
+			fdir_pballoc_mode = FdirPballoc[bd];
+			ixgbe_validate_option(&fdir_pballoc_mode, &opt);
+			switch (fdir_pballoc_mode) {
+			case IXGBE_FDIR_PBALLOC_256K:
+				adapter->fdir_pballoc = IXGBE_FDIR_PBALLOC_256K;
+				sprintf(pstring, "256kB");
+				break;
+			case IXGBE_FDIR_PBALLOC_128K:
+				adapter->fdir_pballoc = IXGBE_FDIR_PBALLOC_128K;
+				sprintf(pstring, "128kB");
+				break;
+			case IXGBE_FDIR_PBALLOC_64K:
+			default:
+				adapter->fdir_pballoc = IXGBE_FDIR_PBALLOC_64K;
+				sprintf(pstring, "64kB");
+				break;
+			}
+			DPRINTK(PROBE, INFO, "Flow Director will be allocated "
+				"%s of packet buffer\n", pstring);
+		} else {
+			adapter->fdir_pballoc = opt.def;
+		}
+		
+	}
+	{ /* Flow Director ATR Tx sample packet rate */
+		static struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "Software ATR Tx packet sample rate",
+			.err = "using default of "
+				__MODULE_STRING(IXGBE_DEFAULT_ATR_SAMPLE_RATE),
+			.def = IXGBE_DEFAULT_ATR_SAMPLE_RATE,
+			.arg = {.r = {.min = IXGBE_ATR_SAMPLE_RATE_OFF,
+				      .max = IXGBE_MAX_ATR_SAMPLE_RATE} }
+		};
+		static const char atr_string[] =
+					    "ATR Tx Packet sample rate set to";
+
+		if (adapter->hw.mac.type == ixgbe_mac_82598EB) {
+			adapter->atr_sample_rate = IXGBE_ATR_SAMPLE_RATE_OFF;
+		} else if (num_AtrSampleRate > bd) {
+			adapter->atr_sample_rate = AtrSampleRate[bd];
+
+			if (adapter->atr_sample_rate) {
+				ixgbe_validate_option(&adapter->atr_sample_rate,
+						      &opt);
+				DPRINTK(PROBE, INFO, "%s %d\n", atr_string,
+					adapter->atr_sample_rate);
+			}
+		} else {
+			adapter->atr_sample_rate = opt.def;
+		}
+	}
+#endif /* HAVE_TX_MQ */
+#if IS_ENABLED(CONFIG_FCOE)
+	{
+		*aflags &= ~IXGBE_FLAG_FCOE_CAPABLE;
+
+		switch (adapter->hw.mac.type) {
+		case ixgbe_mac_X540:
+		case ixgbe_mac_X550:
+		case ixgbe_mac_82599EB: {
+			struct ixgbe_option opt = {
+				.type = enable_option,
+				.name = "Enabled/Disable FCoE offload",
+				.err = "defaulting to Enabled",
+				.def = OPTION_ENABLED
+			};
+#ifdef module_param_array
+			if (num_FCoE > bd) {
+#endif
+				unsigned int fcoe = FCoE[bd];
+
+				ixgbe_validate_option(&fcoe, &opt);
+				if (fcoe)
+					*aflags |= IXGBE_FLAG_FCOE_CAPABLE;
+#ifdef module_param_array
+			} else {
+				if (opt.def == OPTION_ENABLED)
+					*aflags |= IXGBE_FLAG_FCOE_CAPABLE;
+			}
+#endif
+			DPRINTK(PROBE, INFO, "FCoE Offload feature %sabled\n",
+				(*aflags & IXGBE_FLAG_FCOE_CAPABLE) ?
+				"en" : "dis");
+		}
+			break;
+		default:
+			break;
+		}
+	}
+#endif /* CONFIG_FCOE */
+	{ /* LRO - Set Large Receive Offload */
+		struct ixgbe_option opt = {
+			.type = enable_option,
+			.name = "LRO - Large Receive Offload",
+			.err  = "defaulting to Disabled",
+			.def  = OPTION_DISABLED
+		};
+		struct net_device *netdev = adapter->netdev;
+
+		if (!(adapter->flags2 & IXGBE_FLAG2_RSC_CAPABLE))
+			opt.def = OPTION_DISABLED;
+
+#ifdef module_param_array
+		if (num_LRO > bd) {
+#endif
+			unsigned int lro = LRO[bd];
+			ixgbe_validate_option(&lro, &opt);
+			if (lro)
+				netdev->features |= NETIF_F_LRO;
+			else
+				netdev->features &= ~NETIF_F_LRO;
+#ifdef module_param_array
+		} else {
+			netdev->features &= ~NETIF_F_LRO;
+		}
+#endif
+		if ((netdev->features & NETIF_F_LRO) &&
+		    !(adapter->flags2 & IXGBE_FLAG2_RSC_CAPABLE)) {
+			DPRINTK(PROBE, INFO,
+				"RSC is not supported on this "
+				"hardware.  Disabling RSC.\n");
+			netdev->features &= ~NETIF_F_LRO;
+		}
+	}
+	{ /*
+	   * allow_unsupported_sfp - Enable/Disable support for unsupported
+	   * and untested SFP+ modules.
+	   */
+	struct ixgbe_option opt = {
+			.type = enable_option,
+			.name = "allow_unsupported_sfp",
+			.err  = "defaulting to Disabled",
+			.def  = OPTION_DISABLED
+		};
+#ifdef module_param_array
+		if (num_allow_unsupported_sfp > bd) {
+#endif
+			unsigned int enable_unsupported_sfp =
+						      allow_unsupported_sfp[bd];
+			ixgbe_validate_option(&enable_unsupported_sfp, &opt);
+			if (enable_unsupported_sfp) {
+				adapter->hw.allow_unsupported_sfp = true;
+			} else {
+				adapter->hw.allow_unsupported_sfp = false;
+			}
+#ifdef module_param_array
+		} else {
+				adapter->hw.allow_unsupported_sfp = false;
+		}
+#endif
+	}
+	{ /* DMA Coalescing */
+		struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "dmac_watchdog",
+			.err  = "defaulting to 0 (disabled)",
+			.def  = 0,
+			.arg  = { .r = { .min = 41, .max = 10000 } },
+		};
+		const char *cmsg = "DMA coalescing not supported on this hardware";
+
+		switch (adapter->hw.mac.type) {
+		case ixgbe_mac_X550:
+		case ixgbe_mac_X550EM_x:
+		case ixgbe_mac_X550EM_a:
+			if (adapter->rx_itr_setting || adapter->tx_itr_setting)
+				break;
+			opt.err = "interrupt throttling disabled also disables DMA coalescing";
+			opt.arg.r.min = 0;
+			opt.arg.r.max = 0;
+			break;
+		default:
+			opt.err = cmsg;
+			opt.msg = cmsg;
+			opt.arg.r.min = 0;
+			opt.arg.r.max = 0;
+		}
+#ifdef module_param_array
+		if (num_dmac_watchdog > bd) {
+#endif
+			unsigned int dmac_wd = dmac_watchdog[bd];
+
+			ixgbe_validate_option(&dmac_wd, &opt);
+			adapter->hw.mac.dmac_config.watchdog_timer = dmac_wd;
+#ifdef module_param_array
+		} else {
+			adapter->hw.mac.dmac_config.watchdog_timer = opt.def;
+		}
+#endif
+	}
+	{ /* VXLAN rx offload */
+		struct ixgbe_option opt = {
+			.type = range_option,
+			.name = "vxlan_rx",
+			.err  = "defaulting to 1 (enabled)",
+			.def  = 1,
+			.arg  = { .r = { .min = 0, .max = 1 } },
+		};
+		const char *cmsg = "VXLAN rx offload not supported on this hardware";
+		const u32 flag = IXGBE_FLAG_VXLAN_OFFLOAD_ENABLE;
+
+		if (!(adapter->flags & IXGBE_FLAG_VXLAN_OFFLOAD_CAPABLE)) {
+			opt.err = cmsg;
+			opt.msg = cmsg;
+			opt.def = 0;
+			opt.arg.r.max = 0;
+		}
+#ifdef module_param_array
+		if (num_vxlan_rx > bd) {
+#endif
+			unsigned int enable_vxlan_rx = vxlan_rx[bd];
+
+			ixgbe_validate_option(&enable_vxlan_rx, &opt);
+			if (enable_vxlan_rx)
+				adapter->flags |= flag;
+			else
+				adapter->flags &= ~flag;
+#ifdef module_param_array
+		} else if (opt.def) {
+			adapter->flags |= flag;
+		} else {
+			adapter->flags &= ~flag;
+		}
+#endif
+	}
+
+	{ /* MDD support */
+		struct ixgbe_option opt = {
+			.type = enable_option,
+			.name = "Malicious Driver Detection",
+			.err  = "defaulting to Enabled",
+			.def  = OPTION_ENABLED,
+		};
+
+		switch (adapter->hw.mac.type) {
+		case ixgbe_mac_X550:
+		case ixgbe_mac_X550EM_x:
+		case ixgbe_mac_X550EM_a:
+#ifdef module_param_array
+			if (num_MDD > bd) {
+#endif
+				mdd = MDD[bd];
+				ixgbe_validate_option(&mdd, &opt);
+
+				if (mdd){
+					*aflags |= IXGBE_FLAG_MDD_ENABLED;
+
+				} else{
+					*aflags &= ~IXGBE_FLAG_MDD_ENABLED;
+				}
+#ifdef module_param_array
+			} else {
+				*aflags |= IXGBE_FLAG_MDD_ENABLED;
+			}
+#endif
+			break;
+		default:
+			*aflags &= ~IXGBE_FLAG_MDD_ENABLED;
+			break;
+		}
+	}
+
+}
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_phy.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_phy.c
index 48d97cb7..442f9a9 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_phy.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_phy.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,37 +22,32 @@
 
 *******************************************************************************/
 
-#include <linux/pci.h>
-#include <linux/delay.h>
-#include <linux/sched.h>
-
-#include "ixgbe.h"
+#include "ixgbe_api.h"
+#include "ixgbe_common.h"
 #include "ixgbe_phy.h"
 
-static void ixgbe_i2c_start(struct ixgbe_hw *hw);
-static void ixgbe_i2c_stop(struct ixgbe_hw *hw);
-static s32 ixgbe_clock_in_i2c_byte(struct ixgbe_hw *hw, u8 *data);
-static s32 ixgbe_clock_out_i2c_byte(struct ixgbe_hw *hw, u8 data);
-static s32 ixgbe_get_i2c_ack(struct ixgbe_hw *hw);
-static s32 ixgbe_clock_in_i2c_bit(struct ixgbe_hw *hw, bool *data);
-static s32 ixgbe_clock_out_i2c_bit(struct ixgbe_hw *hw, bool data);
-static void ixgbe_raise_i2c_clk(struct ixgbe_hw *hw, u32 *i2cctl);
-static void ixgbe_lower_i2c_clk(struct ixgbe_hw *hw, u32 *i2cctl);
-static s32 ixgbe_set_i2c_data(struct ixgbe_hw *hw, u32 *i2cctl, bool data);
-static bool ixgbe_get_i2c_data(struct ixgbe_hw *hw, u32 *i2cctl);
-static void ixgbe_i2c_bus_clear(struct ixgbe_hw *hw);
-static enum ixgbe_phy_type ixgbe_get_phy_type_from_id(u32 phy_id);
-static s32 ixgbe_get_phy_id(struct ixgbe_hw *hw);
-static s32 ixgbe_identify_qsfp_module_generic(struct ixgbe_hw *hw);
+STATIC void ixgbe_i2c_start(struct ixgbe_hw *hw);
+STATIC void ixgbe_i2c_stop(struct ixgbe_hw *hw);
+STATIC s32 ixgbe_clock_in_i2c_byte(struct ixgbe_hw *hw, u8 *data);
+STATIC s32 ixgbe_clock_out_i2c_byte(struct ixgbe_hw *hw, u8 data);
+STATIC s32 ixgbe_get_i2c_ack(struct ixgbe_hw *hw);
+STATIC s32 ixgbe_clock_in_i2c_bit(struct ixgbe_hw *hw, bool *data);
+STATIC s32 ixgbe_clock_out_i2c_bit(struct ixgbe_hw *hw, bool data);
+STATIC void ixgbe_raise_i2c_clk(struct ixgbe_hw *hw, u32 *i2cctl);
+STATIC void ixgbe_lower_i2c_clk(struct ixgbe_hw *hw, u32 *i2cctl);
+STATIC s32 ixgbe_set_i2c_data(struct ixgbe_hw *hw, u32 *i2cctl, bool data);
+STATIC bool ixgbe_get_i2c_data(struct ixgbe_hw *hw, u32 *i2cctl);
+STATIC s32 ixgbe_read_i2c_sff8472_generic(struct ixgbe_hw *hw, u8 byte_offset,
+					  u8 *sff8472_data);
 
 /**
- *  ixgbe_out_i2c_byte_ack - Send I2C byte with ack
- *  @hw: pointer to the hardware structure
- *  @byte: byte to send
+ * ixgbe_out_i2c_byte_ack - Send I2C byte with ack
+ * @hw: pointer to the hardware structure
+ * @byte: byte to send
  *
- *  Returns an error code on error.
- **/
-static s32 ixgbe_out_i2c_byte_ack(struct ixgbe_hw *hw, u8 byte)
+ * Returns an error code on error.
+ */
+STATIC s32 ixgbe_out_i2c_byte_ack(struct ixgbe_hw *hw, u8 byte)
 {
 	s32 status;
 
@@ -67,13 +58,13 @@ static s32 ixgbe_out_i2c_byte_ack(struct ixgbe_hw *hw, u8 byte)
 }
 
 /**
- *  ixgbe_in_i2c_byte_ack - Receive an I2C byte and send ack
- *  @hw: pointer to the hardware structure
- *  @byte: pointer to a u8 to receive the byte
+ * ixgbe_in_i2c_byte_ack - Receive an I2C byte and send ack
+ * @hw: pointer to the hardware structure
+ * @byte: pointer to a u8 to receive the byte
  *
- *  Returns an error code on error.
- **/
-static s32 ixgbe_in_i2c_byte_ack(struct ixgbe_hw *hw, u8 *byte)
+ * Returns an error code on error.
+ */
+STATIC s32 ixgbe_in_i2c_byte_ack(struct ixgbe_hw *hw, u8 *byte)
 {
 	s32 status;
 
@@ -85,13 +76,13 @@ static s32 ixgbe_in_i2c_byte_ack(struct ixgbe_hw *hw, u8 *byte)
 }
 
 /**
- *  ixgbe_ones_comp_byte_add - Perform one's complement addition
- *  @add1: addend 1
- *  @add2: addend 2
+ * ixgbe_ones_comp_byte_add - Perform one's complement addition
+ * @add1 - addend 1
+ * @add2 - addend 2
  *
- *  Returns one's complement 8-bit sum.
- **/
-static u8 ixgbe_ones_comp_byte_add(u8 add1, u8 add2)
+ * Returns one's complement 8-bit sum.
+ */
+STATIC u8 ixgbe_ones_comp_byte_add(u8 add1, u8 add2)
 {
 	u16 sum = add1 + add2;
 
@@ -100,17 +91,17 @@ static u8 ixgbe_ones_comp_byte_add(u8 add1, u8 add2)
 }
 
 /**
- *  ixgbe_read_i2c_combined_generic_int - Perform I2C read combined operation
- *  @hw: pointer to the hardware structure
- *  @addr: I2C bus address to read from
- *  @reg: I2C device register to read from
- *  @val: pointer to location to receive read value
- *  @lock: true if to take and release semaphore
+ * ixgbe_read_i2c_combined_generic_int - Perform I2C read combined operation
+ * @hw: pointer to the hardware structure
+ * @addr: I2C bus address to read from
+ * @reg: I2C device register to read from
+ * @val: pointer to location to receive read value
+ * @lock: true if to take and release semaphore
  *
- *  Returns an error code on error.
+ * Returns an error code on error.
  */
-static s32 ixgbe_read_i2c_combined_generic_int(struct ixgbe_hw *hw, u8 addr,
-					       u16 reg, u16 *val, bool lock)
+s32 ixgbe_read_i2c_combined_generic_int(struct ixgbe_hw *hw, u8 addr, u16 reg,
+					u16 *val, bool lock)
 {
 	u32 swfw_mask = hw->phy.phy_semaphore_mask;
 	int max_retry = 3;
@@ -121,7 +112,7 @@ static s32 ixgbe_read_i2c_combined_generic_int(struct ixgbe_hw *hw, u8 addr,
 	u8 reg_high;
 	u8 csum;
 
-	reg_high = ((reg >> 7) & 0xFE) | 1;     /* Indicate read combined */
+	reg_high = ((reg >> 7) & 0xFE) | 1;	/* Indicate read combined */
 	csum = ixgbe_ones_comp_byte_add(reg_high, reg & 0xFF);
 	csum = ~csum;
 	do {
@@ -169,56 +160,26 @@ fail:
 			hw->mac.ops.release_swfw_sync(hw, swfw_mask);
 		retry++;
 		if (retry < max_retry)
-			hw_dbg(hw, "I2C byte read combined error - Retry.\n");
+			DEBUGOUT("I2C byte read combined error - Retrying.\n");
 		else
-			hw_dbg(hw, "I2C byte read combined error.\n");
+			DEBUGOUT("I2C byte read combined error.\n");
 	} while (retry < max_retry);
 
 	return IXGBE_ERR_I2C;
 }
 
 /**
- *  ixgbe_read_i2c_combined_generic - Perform I2C read combined operation
- *  @hw: pointer to the hardware structure
- *  @addr: I2C bus address to read from
- *  @reg: I2C device register to read from
- *  @val: pointer to location to receive read value
- *
- *  Returns an error code on error.
- */
-s32 ixgbe_read_i2c_combined_generic(struct ixgbe_hw *hw, u8 addr,
-				    u16 reg, u16 *val)
-{
-	return ixgbe_read_i2c_combined_generic_int(hw, addr, reg, val, true);
-}
-
-/**
- *  ixgbe_read_i2c_combined_generic_unlocked - Unlocked I2C read combined
- *  @hw: pointer to the hardware structure
- *  @addr: I2C bus address to read from
- *  @reg: I2C device register to read from
- *  @val: pointer to location to receive read value
- *
- *  Returns an error code on error.
- */
-s32 ixgbe_read_i2c_combined_generic_unlocked(struct ixgbe_hw *hw, u8 addr,
-					     u16 reg, u16 *val)
-{
-	return ixgbe_read_i2c_combined_generic_int(hw, addr, reg, val, false);
-}
-
-/**
- *  ixgbe_write_i2c_combined_generic_int - Perform I2C write combined operation
- *  @hw: pointer to the hardware structure
- *  @addr: I2C bus address to write to
- *  @reg: I2C device register to write to
- *  @val: value to write
- *  @lock: true if to take and release semaphore
+ * ixgbe_write_i2c_combined_generic_int - Perform I2C write combined operation
+ * @hw: pointer to the hardware structure
+ * @addr: I2C bus address to write to
+ * @reg: I2C device register to write to
+ * @val: value to write
+ * @lock: true if to take and release semaphore
  *
- *  Returns an error code on error.
+ * Returns an error code on error.
  */
-static s32 ixgbe_write_i2c_combined_generic_int(struct ixgbe_hw *hw, u8 addr,
-						u16 reg, u16 val, bool lock)
+s32 ixgbe_write_i2c_combined_generic_int(struct ixgbe_hw *hw, u8 addr, u16 reg,
+					 u16 val, bool lock)
 {
 	u32 swfw_mask = hw->phy.phy_semaphore_mask;
 	int max_retry = 1;
@@ -226,7 +187,7 @@ static s32 ixgbe_write_i2c_combined_generic_int(struct ixgbe_hw *hw, u8 addr,
 	u8 reg_high;
 	u8 csum;
 
-	reg_high = (reg >> 7) & 0xFE;   /* Indicate write combined */
+	reg_high = (reg >> 7) & 0xFE;	/* Indicate write combined */
 	csum = ixgbe_ones_comp_byte_add(reg_high, reg & 0xFF);
 	csum = ixgbe_ones_comp_byte_add(csum, val >> 8);
 	csum = ixgbe_ones_comp_byte_add(csum, val & 0xFF);
@@ -264,42 +225,86 @@ fail:
 			hw->mac.ops.release_swfw_sync(hw, swfw_mask);
 		retry++;
 		if (retry < max_retry)
-			hw_dbg(hw, "I2C byte write combined error - Retry.\n");
+			DEBUGOUT("I2C byte write combined error - Retrying.\n");
 		else
-			hw_dbg(hw, "I2C byte write combined error.\n");
+			DEBUGOUT("I2C byte write combined error.\n");
 	} while (retry < max_retry);
 
 	return IXGBE_ERR_I2C;
 }
 
 /**
- *  ixgbe_write_i2c_combined_generic - Perform I2C write combined operation
+ *  ixgbe_init_phy_ops_generic - Inits PHY function ptrs
  *  @hw: pointer to the hardware structure
- *  @addr: I2C bus address to write to
- *  @reg: I2C device register to write to
- *  @val: value to write
  *
- *  Returns an error code on error.
- */
-s32 ixgbe_write_i2c_combined_generic(struct ixgbe_hw *hw,
-				     u8 addr, u16 reg, u16 val)
+ *  Initialize the function pointers.
+ **/
+s32 ixgbe_init_phy_ops_generic(struct ixgbe_hw *hw)
 {
-	return ixgbe_write_i2c_combined_generic_int(hw, addr, reg, val, true);
+	struct ixgbe_phy_info *phy = &hw->phy;
+
+	DEBUGFUNC("ixgbe_init_phy_ops_generic");
+
+	/* PHY */
+	phy->ops.identify = ixgbe_identify_phy_generic;
+	phy->ops.reset = ixgbe_reset_phy_generic;
+	phy->ops.read_reg = ixgbe_read_phy_reg_generic;
+	phy->ops.write_reg = ixgbe_write_phy_reg_generic;
+	phy->ops.read_reg_mdi = ixgbe_read_phy_reg_mdi;
+	phy->ops.write_reg_mdi = ixgbe_write_phy_reg_mdi;
+	phy->ops.setup_link = ixgbe_setup_phy_link_generic;
+	phy->ops.setup_link_speed = ixgbe_setup_phy_link_speed_generic;
+	phy->ops.check_link = NULL;
+	phy->ops.get_firmware_version = ixgbe_get_phy_firmware_version_generic;
+	phy->ops.read_i2c_byte = ixgbe_read_i2c_byte_generic;
+	phy->ops.write_i2c_byte = ixgbe_write_i2c_byte_generic;
+	phy->ops.read_i2c_sff8472 = ixgbe_read_i2c_sff8472_generic;
+	phy->ops.read_i2c_eeprom = ixgbe_read_i2c_eeprom_generic;
+	phy->ops.write_i2c_eeprom = ixgbe_write_i2c_eeprom_generic;
+	phy->ops.i2c_bus_clear = ixgbe_i2c_bus_clear;
+	phy->ops.identify_sfp = ixgbe_identify_module_generic;
+	phy->sfp_type = ixgbe_sfp_type_unknown;
+	phy->ops.read_i2c_byte_unlocked = ixgbe_read_i2c_byte_generic_unlocked;
+	phy->ops.write_i2c_byte_unlocked =
+				ixgbe_write_i2c_byte_generic_unlocked;
+	phy->ops.check_overtemp = ixgbe_tn_check_overtemp;
+	return IXGBE_SUCCESS;
 }
 
 /**
- *  ixgbe_write_i2c_combined_generic_unlocked - Unlocked I2C write combined
- *  @hw: pointer to the hardware structure
- *  @addr: I2C bus address to write to
- *  @reg: I2C device register to write to
- *  @val: value to write
+ * ixgbe_probe_phy - Probe a single address for a PHY
+ * @hw: pointer to hardware structure
+ * @phy_addr: PHY address to probe
  *
- *  Returns an error code on error.
+ * Returns true if PHY found
  */
-s32 ixgbe_write_i2c_combined_generic_unlocked(struct ixgbe_hw *hw,
-					      u8 addr, u16 reg, u16 val)
+static bool ixgbe_probe_phy(struct ixgbe_hw *hw, u16 phy_addr)
 {
-	return ixgbe_write_i2c_combined_generic_int(hw, addr, reg, val, false);
+	u16 ext_ability = 0;
+
+	if (!ixgbe_validate_phy_addr(hw, phy_addr)) {
+		DEBUGOUT1("Unable to validate PHY address 0x%04X\n",
+			phy_addr);
+		return false;
+	}
+
+	if (ixgbe_get_phy_id(hw))
+		return false;
+
+	hw->phy.type = ixgbe_get_phy_type_from_id(hw->phy.id);
+
+	if (hw->phy.type == ixgbe_phy_unknown) {
+		hw->phy.ops.read_reg(hw, IXGBE_MDIO_PHY_EXT_ABILITY,
+				     IXGBE_MDIO_PMA_PMD_DEV_TYPE, &ext_ability);
+		if (ext_ability &
+		    (IXGBE_MDIO_PHY_10GBASET_ABILITY |
+		     IXGBE_MDIO_PHY_1000BASET_ABILITY))
+			hw->phy.type = ixgbe_phy_cu_unknown;
+		else
+			hw->phy.type = ixgbe_phy_generic;
+	}
+
+	return true;
 }
 
 /**
@@ -310,8 +315,10 @@ s32 ixgbe_write_i2c_combined_generic_unlocked(struct ixgbe_hw *hw,
  **/
 s32 ixgbe_identify_phy_generic(struct ixgbe_hw *hw)
 {
-	u32 phy_addr;
-	u16 ext_ability = 0;
+	s32 status = IXGBE_ERR_PHY_ADDR_INVALID;
+	u16 phy_addr;
+
+	DEBUGFUNC("ixgbe_identify_phy_generic");
 
 	if (!hw->phy.phy_semaphore_mask) {
 		if (hw->bus.lan_id)
@@ -320,37 +327,34 @@ s32 ixgbe_identify_phy_generic(struct ixgbe_hw *hw)
 			hw->phy.phy_semaphore_mask = IXGBE_GSSR_PHY0_SM;
 	}
 
-	if (hw->phy.type == ixgbe_phy_unknown) {
-		for (phy_addr = 0; phy_addr < IXGBE_MAX_PHY_ADDR; phy_addr++) {
-			hw->phy.mdio.prtad = phy_addr;
-			if (mdio45_probe(&hw->phy.mdio, phy_addr) == 0) {
-				ixgbe_get_phy_id(hw);
-				hw->phy.type =
-					ixgbe_get_phy_type_from_id(hw->phy.id);
-
-				if (hw->phy.type == ixgbe_phy_unknown) {
-					hw->phy.ops.read_reg(hw,
-							     MDIO_PMA_EXTABLE,
-							     MDIO_MMD_PMAPMD,
-							     &ext_ability);
-					if (ext_ability &
-					    (MDIO_PMA_EXTABLE_10GBT |
-					     MDIO_PMA_EXTABLE_1000BT))
-						hw->phy.type =
-							 ixgbe_phy_cu_unknown;
-					else
-						hw->phy.type =
-							 ixgbe_phy_generic;
-				}
+	if (hw->phy.type != ixgbe_phy_unknown)
+		return IXGBE_SUCCESS;
 
-				return 0;
-			}
+	if (hw->phy.nw_mng_if_sel) {
+		phy_addr = (hw->phy.nw_mng_if_sel &
+			    IXGBE_NW_MNG_IF_SEL_MDIO_PHY_ADD) >>
+			   IXGBE_NW_MNG_IF_SEL_MDIO_PHY_ADD_SHIFT;
+		if (ixgbe_probe_phy(hw, phy_addr))
+			return IXGBE_SUCCESS;
+		else
+			return IXGBE_ERR_PHY_ADDR_INVALID;
+	}
+
+	for (phy_addr = 0; phy_addr < IXGBE_MAX_PHY_ADDR; phy_addr++) {
+		if (ixgbe_probe_phy(hw, phy_addr)) {
+			status = IXGBE_SUCCESS;
+			break;
 		}
-		/* clear value if nothing found */
-		hw->phy.mdio.prtad = 0;
-		return IXGBE_ERR_PHY_ADDR_INVALID;
 	}
-	return 0;
+
+	/* Certain media types do not have a phy so an address will not
+	 * be found and the code will take this path.  Caller has to
+	 * decide if it is an error or not.
+	 */
+	if (status != IXGBE_SUCCESS)
+		hw->phy.addr = 0;
+
+	return status;
 }
 
 /**
@@ -359,20 +363,23 @@ s32 ixgbe_identify_phy_generic(struct ixgbe_hw *hw)
  *
  * This function checks the MMNGC.MNG_VETO bit to see if there are
  * any constraints on link from manageability.  For MAC's that don't
- * have this bit just return false since the link can not be blocked
+ * have this bit just return faluse since the link can not be blocked
  * via this method.
  **/
-bool ixgbe_check_reset_blocked(struct ixgbe_hw *hw)
+s32 ixgbe_check_reset_blocked(struct ixgbe_hw *hw)
 {
 	u32 mmngc;
 
+	DEBUGFUNC("ixgbe_check_reset_blocked");
+
 	/* If we don't have this bit, it can't be blocking */
 	if (hw->mac.type == ixgbe_mac_82598EB)
 		return false;
 
 	mmngc = IXGBE_READ_REG(hw, IXGBE_MMNGC);
 	if (mmngc & IXGBE_MMNGC_MNG_VETO) {
-		hw_dbg(hw, "MNG_VETO bit detected.\n");
+		ERROR_REPORT1(IXGBE_ERROR_SOFTWARE,
+			      "MNG_VETO bit detected.\n");
 		return true;
 	}
 
@@ -380,43 +387,77 @@ bool ixgbe_check_reset_blocked(struct ixgbe_hw *hw)
 }
 
 /**
+ *  ixgbe_validate_phy_addr - Determines phy address is valid
+ *  @hw: pointer to hardware structure
+ *
+ **/
+bool ixgbe_validate_phy_addr(struct ixgbe_hw *hw, u32 phy_addr)
+{
+	u16 phy_id = 0;
+	bool valid = false;
+
+	DEBUGFUNC("ixgbe_validate_phy_addr");
+
+	hw->phy.addr = phy_addr;
+	hw->phy.ops.read_reg(hw, IXGBE_MDIO_PHY_ID_HIGH,
+			     IXGBE_MDIO_PMA_PMD_DEV_TYPE, &phy_id);
+
+	if (phy_id != 0xFFFF && phy_id != 0x0)
+		valid = true;
+
+	DEBUGOUT1("PHY ID HIGH is 0x%04X\n", phy_id);
+
+	return valid;
+}
+
+/**
  *  ixgbe_get_phy_id - Get the phy type
  *  @hw: pointer to hardware structure
  *
  **/
-static s32 ixgbe_get_phy_id(struct ixgbe_hw *hw)
+s32 ixgbe_get_phy_id(struct ixgbe_hw *hw)
 {
-	s32 status;
+	u32 status;
 	u16 phy_id_high = 0;
 	u16 phy_id_low = 0;
 
-	status = hw->phy.ops.read_reg(hw, MDIO_DEVID1, MDIO_MMD_PMAPMD,
+	DEBUGFUNC("ixgbe_get_phy_id");
+
+	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_PHY_ID_HIGH,
+				      IXGBE_MDIO_PMA_PMD_DEV_TYPE,
 				      &phy_id_high);
 
-	if (!status) {
+	if (status == IXGBE_SUCCESS) {
 		hw->phy.id = (u32)(phy_id_high << 16);
-		status = hw->phy.ops.read_reg(hw, MDIO_DEVID2, MDIO_MMD_PMAPMD,
+		status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_PHY_ID_LOW,
+					      IXGBE_MDIO_PMA_PMD_DEV_TYPE,
 					      &phy_id_low);
 		hw->phy.id |= (u32)(phy_id_low & IXGBE_PHY_REVISION_MASK);
 		hw->phy.revision = (u32)(phy_id_low & ~IXGBE_PHY_REVISION_MASK);
 	}
+	DEBUGOUT2("PHY_ID_HIGH 0x%04X, PHY_ID_LOW 0x%04X\n",
+		  phy_id_high, phy_id_low);
+
 	return status;
 }
 
 /**
  *  ixgbe_get_phy_type_from_id - Get the phy type
- *  @hw: pointer to hardware structure
+ *  @phy_id: PHY ID information
  *
  **/
-static enum ixgbe_phy_type ixgbe_get_phy_type_from_id(u32 phy_id)
+enum ixgbe_phy_type ixgbe_get_phy_type_from_id(u32 phy_id)
 {
 	enum ixgbe_phy_type phy_type;
 
+	DEBUGFUNC("ixgbe_get_phy_type_from_id");
+
 	switch (phy_id) {
 	case TN1010_PHY_ID:
 		phy_type = ixgbe_phy_tn;
 		break;
-	case X550_PHY_ID:
+	case X550_PHY_ID2:
+	case X550_PHY_ID3:
 	case X540_PHY_ID:
 		phy_type = ixgbe_phy_aq;
 		break;
@@ -427,13 +468,17 @@ static enum ixgbe_phy_type ixgbe_get_phy_type_from_id(u32 phy_id)
 		phy_type = ixgbe_phy_nl;
 		break;
 	case X557_PHY_ID:
+	case X557_PHY_ID2:
 		phy_type = ixgbe_phy_x550em_ext_t;
 		break;
+	case IXGBE_M88E1500_E_PHY_ID:
+	case IXGBE_M88E1543_E_PHY_ID:
+		phy_type = ixgbe_phy_ext_1g_t;
+		break;
 	default:
 		phy_type = ixgbe_phy_unknown;
 		break;
 	}
-
 	return phy_type;
 }
 
@@ -445,30 +490,32 @@ s32 ixgbe_reset_phy_generic(struct ixgbe_hw *hw)
 {
 	u32 i;
 	u16 ctrl = 0;
-	s32 status = 0;
+	s32 status = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_reset_phy_generic");
 
 	if (hw->phy.type == ixgbe_phy_unknown)
 		status = ixgbe_identify_phy_generic(hw);
 
-	if (status != 0 || hw->phy.type == ixgbe_phy_none)
-		return status;
+	if (status != IXGBE_SUCCESS || hw->phy.type == ixgbe_phy_none)
+		goto out;
 
 	/* Don't reset PHY if it's shut down due to overtemp. */
 	if (!hw->phy.reset_if_overtemp &&
 	    (IXGBE_ERR_OVERTEMP == hw->phy.ops.check_overtemp(hw)))
-		return 0;
+		goto out;
 
 	/* Blocked by MNG FW so bail */
 	if (ixgbe_check_reset_blocked(hw))
-		return 0;
+		goto out;
 
 	/*
 	 * Perform soft PHY reset to the PHY_XS.
 	 * This will cause a soft reset to the PHY
 	 */
-	hw->phy.ops.write_reg(hw, MDIO_CTRL1,
-			      MDIO_MMD_PHYXS,
-			      MDIO_CTRL1_RESET);
+	hw->phy.ops.write_reg(hw, IXGBE_MDIO_PHY_XS_CONTROL,
+			      IXGBE_MDIO_PHY_XS_DEV_TYPE,
+			      IXGBE_MDIO_PHY_XS_RESET);
 
 	/*
 	 * Poll for reset bit to self-clear indicating reset is complete.
@@ -476,21 +523,42 @@ s32 ixgbe_reset_phy_generic(struct ixgbe_hw *hw)
 	 * 1.7 usec delay after the reset is complete.
 	 */
 	for (i = 0; i < 30; i++) {
-		msleep(100);
-		hw->phy.ops.read_reg(hw, MDIO_CTRL1,
-				     MDIO_MMD_PHYXS, &ctrl);
-		if (!(ctrl & MDIO_CTRL1_RESET)) {
-			udelay(2);
-			break;
+		msec_delay(100);
+		if (hw->phy.type == ixgbe_phy_x550em_ext_t) {
+			status = hw->phy.ops.read_reg(hw,
+						  IXGBE_MDIO_TX_VENDOR_ALARMS_3,
+						  IXGBE_MDIO_PMA_PMD_DEV_TYPE,
+						  &ctrl);
+			if (status != IXGBE_SUCCESS)
+				return status;
+
+			if (ctrl & IXGBE_MDIO_TX_VENDOR_ALARMS_3_RST_MASK) {
+				usec_delay(2);
+				break;
+			}
+		} else {
+			status = hw->phy.ops.read_reg(hw,
+						     IXGBE_MDIO_PHY_XS_CONTROL,
+						     IXGBE_MDIO_PHY_XS_DEV_TYPE,
+						     &ctrl);
+			if (status != IXGBE_SUCCESS)
+				return status;
+
+			if (!(ctrl & IXGBE_MDIO_PHY_XS_RESET)) {
+				usec_delay(2);
+				break;
+			}
 		}
 	}
 
-	if (ctrl & MDIO_CTRL1_RESET) {
-		hw_dbg(hw, "PHY reset polling failed to complete.\n");
-		return IXGBE_ERR_RESET_FAILED;
+	if (ctrl & IXGBE_MDIO_PHY_XS_RESET) {
+		status = IXGBE_ERR_RESET_FAILED;
+		ERROR_REPORT1(IXGBE_ERROR_POLLING,
+			     "PHY reset polling failed to complete.\n");
 	}
 
-	return 0;
+out:
+	return status;
 }
 
 /**
@@ -501,52 +569,56 @@ s32 ixgbe_reset_phy_generic(struct ixgbe_hw *hw)
  *  @phy_data: Pointer to read data from PHY register
  **/
 s32 ixgbe_read_phy_reg_mdi(struct ixgbe_hw *hw, u32 reg_addr, u32 device_type,
-		       u16 *phy_data)
+			   u16 *phy_data)
 {
 	u32 i, data, command;
 
 	/* Setup and write the address cycle command */
 	command = ((reg_addr << IXGBE_MSCA_NP_ADDR_SHIFT)  |
 		   (device_type << IXGBE_MSCA_DEV_TYPE_SHIFT) |
-		   (hw->phy.mdio.prtad << IXGBE_MSCA_PHY_ADDR_SHIFT) |
+		   (hw->phy.addr << IXGBE_MSCA_PHY_ADDR_SHIFT) |
 		   (IXGBE_MSCA_ADDR_CYCLE | IXGBE_MSCA_MDI_COMMAND));
 
 	IXGBE_WRITE_REG(hw, IXGBE_MSCA, command);
 
-	/* Check every 10 usec to see if the address cycle completed.
+	/*
+	 * Check every 10 usec to see if the address cycle completed.
 	 * The MDI Command bit will clear when the operation is
 	 * complete
 	 */
 	for (i = 0; i < IXGBE_MDIO_COMMAND_TIMEOUT; i++) {
-		udelay(10);
+		usec_delay(10);
 
 		command = IXGBE_READ_REG(hw, IXGBE_MSCA);
 		if ((command & IXGBE_MSCA_MDI_COMMAND) == 0)
-				break;
+			break;
 	}
 
 
 	if ((command & IXGBE_MSCA_MDI_COMMAND) != 0) {
-		hw_dbg(hw, "PHY address command did not complete.\n");
+		ERROR_REPORT1(IXGBE_ERROR_POLLING, "PHY address command did not complete.\n");
+		DEBUGOUT("PHY address command did not complete, returning IXGBE_ERR_PHY\n");
 		return IXGBE_ERR_PHY;
 	}
 
-	/* Address cycle complete, setup and write the read
+	/*
+	 * Address cycle complete, setup and write the read
 	 * command
 	 */
 	command = ((reg_addr << IXGBE_MSCA_NP_ADDR_SHIFT)  |
 		   (device_type << IXGBE_MSCA_DEV_TYPE_SHIFT) |
-		   (hw->phy.mdio.prtad << IXGBE_MSCA_PHY_ADDR_SHIFT) |
+		   (hw->phy.addr << IXGBE_MSCA_PHY_ADDR_SHIFT) |
 		   (IXGBE_MSCA_READ | IXGBE_MSCA_MDI_COMMAND));
 
 	IXGBE_WRITE_REG(hw, IXGBE_MSCA, command);
 
-	/* Check every 10 usec to see if the address cycle
+	/*
+	 * Check every 10 usec to see if the address cycle
 	 * completed. The MDI Command bit will clear when the
 	 * operation is complete
 	 */
 	for (i = 0; i < IXGBE_MDIO_COMMAND_TIMEOUT; i++) {
-		udelay(10);
+		usec_delay(10);
 
 		command = IXGBE_READ_REG(hw, IXGBE_MSCA);
 		if ((command & IXGBE_MSCA_MDI_COMMAND) == 0)
@@ -554,18 +626,20 @@ s32 ixgbe_read_phy_reg_mdi(struct ixgbe_hw *hw, u32 reg_addr, u32 device_type,
 	}
 
 	if ((command & IXGBE_MSCA_MDI_COMMAND) != 0) {
-		hw_dbg(hw, "PHY read command didn't complete\n");
+		ERROR_REPORT1(IXGBE_ERROR_POLLING, "PHY read command didn't complete\n");
+		DEBUGOUT("PHY read command didn't complete, returning IXGBE_ERR_PHY\n");
 		return IXGBE_ERR_PHY;
 	}
 
-	/* Read operation is complete.  Get the data
+	/*
+	 * Read operation is complete.  Get the data
 	 * from MSRWD
 	 */
 	data = IXGBE_READ_REG(hw, IXGBE_MSRWD);
 	data >>= IXGBE_MSRWD_READ_DATA_SHIFT;
 	*phy_data = (u16)(data);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -581,13 +655,14 @@ s32 ixgbe_read_phy_reg_generic(struct ixgbe_hw *hw, u32 reg_addr,
 	s32 status;
 	u32 gssr = hw->phy.phy_semaphore_mask;
 
-	if (hw->mac.ops.acquire_swfw_sync(hw, gssr) == 0) {
-		status = ixgbe_read_phy_reg_mdi(hw, reg_addr, device_type,
-						phy_data);
-		hw->mac.ops.release_swfw_sync(hw, gssr);
-	} else {
+	DEBUGFUNC("ixgbe_read_phy_reg_generic");
+
+	if (hw->mac.ops.acquire_swfw_sync(hw, gssr))
 		return IXGBE_ERR_SWFW_SYNC;
-	}
+
+	status = hw->phy.ops.read_reg_mdi(hw, reg_addr, device_type, phy_data);
+
+	hw->mac.ops.release_swfw_sync(hw, gssr);
 
 	return status;
 }
@@ -611,7 +686,7 @@ s32 ixgbe_write_phy_reg_mdi(struct ixgbe_hw *hw, u32 reg_addr,
 	/* Setup and write the address cycle command */
 	command = ((reg_addr << IXGBE_MSCA_NP_ADDR_SHIFT)  |
 		   (device_type << IXGBE_MSCA_DEV_TYPE_SHIFT) |
-		   (hw->phy.mdio.prtad << IXGBE_MSCA_PHY_ADDR_SHIFT) |
+		   (hw->phy.addr << IXGBE_MSCA_PHY_ADDR_SHIFT) |
 		   (IXGBE_MSCA_ADDR_CYCLE | IXGBE_MSCA_MDI_COMMAND));
 
 	IXGBE_WRITE_REG(hw, IXGBE_MSCA, command);
@@ -622,7 +697,7 @@ s32 ixgbe_write_phy_reg_mdi(struct ixgbe_hw *hw, u32 reg_addr,
 	 * complete
 	 */
 	for (i = 0; i < IXGBE_MDIO_COMMAND_TIMEOUT; i++) {
-		udelay(10);
+		usec_delay(10);
 
 		command = IXGBE_READ_REG(hw, IXGBE_MSCA);
 		if ((command & IXGBE_MSCA_MDI_COMMAND) == 0)
@@ -630,7 +705,7 @@ s32 ixgbe_write_phy_reg_mdi(struct ixgbe_hw *hw, u32 reg_addr,
 	}
 
 	if ((command & IXGBE_MSCA_MDI_COMMAND) != 0) {
-		hw_dbg(hw, "PHY address cmd didn't complete\n");
+		ERROR_REPORT1(IXGBE_ERROR_POLLING, "PHY address cmd didn't complete\n");
 		return IXGBE_ERR_PHY;
 	}
 
@@ -640,17 +715,18 @@ s32 ixgbe_write_phy_reg_mdi(struct ixgbe_hw *hw, u32 reg_addr,
 	 */
 	command = ((reg_addr << IXGBE_MSCA_NP_ADDR_SHIFT)  |
 		   (device_type << IXGBE_MSCA_DEV_TYPE_SHIFT) |
-		   (hw->phy.mdio.prtad << IXGBE_MSCA_PHY_ADDR_SHIFT) |
+		   (hw->phy.addr << IXGBE_MSCA_PHY_ADDR_SHIFT) |
 		   (IXGBE_MSCA_WRITE | IXGBE_MSCA_MDI_COMMAND));
 
 	IXGBE_WRITE_REG(hw, IXGBE_MSCA, command);
 
-	/* Check every 10 usec to see if the address cycle
+	/*
+	 * Check every 10 usec to see if the address cycle
 	 * completed. The MDI Command bit will clear when the
 	 * operation is complete
 	 */
 	for (i = 0; i < IXGBE_MDIO_COMMAND_TIMEOUT; i++) {
-		udelay(10);
+		usec_delay(10);
 
 		command = IXGBE_READ_REG(hw, IXGBE_MSCA);
 		if ((command & IXGBE_MSCA_MDI_COMMAND) == 0)
@@ -658,11 +734,11 @@ s32 ixgbe_write_phy_reg_mdi(struct ixgbe_hw *hw, u32 reg_addr,
 	}
 
 	if ((command & IXGBE_MSCA_MDI_COMMAND) != 0) {
-		hw_dbg(hw, "PHY write cmd didn't complete\n");
+		ERROR_REPORT1(IXGBE_ERROR_POLLING, "PHY write cmd didn't complete\n");
 		return IXGBE_ERR_PHY;
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -679,92 +755,106 @@ s32 ixgbe_write_phy_reg_generic(struct ixgbe_hw *hw, u32 reg_addr,
 	s32 status;
 	u32 gssr = hw->phy.phy_semaphore_mask;
 
-	if (hw->mac.ops.acquire_swfw_sync(hw, gssr) == 0) {
-		status = ixgbe_write_phy_reg_mdi(hw, reg_addr, device_type,
+	DEBUGFUNC("ixgbe_write_phy_reg_generic");
+
+	if (hw->mac.ops.acquire_swfw_sync(hw, gssr) == IXGBE_SUCCESS) {
+		status = hw->phy.ops.write_reg_mdi(hw, reg_addr, device_type,
 						 phy_data);
 		hw->mac.ops.release_swfw_sync(hw, gssr);
 	} else {
-		return IXGBE_ERR_SWFW_SYNC;
+		status = IXGBE_ERR_SWFW_SYNC;
 	}
 
 	return status;
 }
 
 /**
- *  ixgbe_setup_phy_link_generic - Set and restart autoneg
+ *  ixgbe_setup_phy_link_generic - Set and restart auto-neg
  *  @hw: pointer to hardware structure
  *
- *  Restart autonegotiation and PHY and waits for completion.
+ *  Restart auto-negotiation and PHY and waits for completion.
  **/
 s32 ixgbe_setup_phy_link_generic(struct ixgbe_hw *hw)
 {
-	s32 status = 0;
+	s32 status = IXGBE_SUCCESS;
 	u16 autoneg_reg = IXGBE_MII_AUTONEG_REG;
 	bool autoneg = false;
 	ixgbe_link_speed speed;
 
-	ixgbe_get_copper_link_capabilities_generic(hw, &speed, &autoneg);
-
-	if (speed & IXGBE_LINK_SPEED_10GB_FULL) {
-		/* Set or unset auto-negotiation 10G advertisement */
-		hw->phy.ops.read_reg(hw, MDIO_AN_10GBT_CTRL,
-				     MDIO_MMD_AN,
-				     &autoneg_reg);
+	DEBUGFUNC("ixgbe_setup_phy_link_generic");
 
-		autoneg_reg &= ~MDIO_AN_10GBT_CTRL_ADV10G;
-		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_10GB_FULL)
-			autoneg_reg |= MDIO_AN_10GBT_CTRL_ADV10G;
+	ixgbe_get_copper_link_capabilities_generic(hw, &speed, &autoneg);
 
-		hw->phy.ops.write_reg(hw, MDIO_AN_10GBT_CTRL,
-				      MDIO_MMD_AN,
-				      autoneg_reg);
+	/* Set or unset auto-negotiation 10G advertisement */
+	hw->phy.ops.read_reg(hw, IXGBE_MII_10GBASE_T_AUTONEG_CTRL_REG,
+			     IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+			     &autoneg_reg);
+
+	autoneg_reg &= ~IXGBE_MII_10GBASE_T_ADVERTISE;
+	if ((hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_10GB_FULL) &&
+	    (speed & IXGBE_LINK_SPEED_10GB_FULL))
+		autoneg_reg |= IXGBE_MII_10GBASE_T_ADVERTISE;
+
+	hw->phy.ops.write_reg(hw, IXGBE_MII_10GBASE_T_AUTONEG_CTRL_REG,
+			      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+			      autoneg_reg);
+
+	hw->phy.ops.read_reg(hw, IXGBE_MII_AUTONEG_VENDOR_PROVISION_1_REG,
+			     IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+			     &autoneg_reg);
+
+	if (hw->mac.type == ixgbe_mac_X550) {
+		/* Set or unset auto-negotiation 5G advertisement */
+		autoneg_reg &= ~IXGBE_MII_5GBASE_T_ADVERTISE;
+		if ((hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_5GB_FULL) &&
+		    (speed & IXGBE_LINK_SPEED_5GB_FULL))
+			autoneg_reg |= IXGBE_MII_5GBASE_T_ADVERTISE;
+
+		/* Set or unset auto-negotiation 2.5G advertisement */
+		autoneg_reg &= ~IXGBE_MII_2_5GBASE_T_ADVERTISE;
+		if ((hw->phy.autoneg_advertised &
+		     IXGBE_LINK_SPEED_2_5GB_FULL) &&
+		    (speed & IXGBE_LINK_SPEED_2_5GB_FULL))
+			autoneg_reg |= IXGBE_MII_2_5GBASE_T_ADVERTISE;
 	}
 
-	if (speed & IXGBE_LINK_SPEED_1GB_FULL) {
-		/* Set or unset auto-negotiation 1G advertisement */
-		hw->phy.ops.read_reg(hw,
-				     IXGBE_MII_AUTONEG_VENDOR_PROVISION_1_REG,
-				     MDIO_MMD_AN,
-				     &autoneg_reg);
+	/* Set or unset auto-negotiation 1G advertisement */
+	autoneg_reg &= ~IXGBE_MII_1GBASE_T_ADVERTISE;
+	if ((hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_1GB_FULL) &&
+	    (speed & IXGBE_LINK_SPEED_1GB_FULL))
+		autoneg_reg |= IXGBE_MII_1GBASE_T_ADVERTISE;
 
-		autoneg_reg &= ~IXGBE_MII_1GBASE_T_ADVERTISE;
-		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_1GB_FULL)
-			autoneg_reg |= IXGBE_MII_1GBASE_T_ADVERTISE;
+	hw->phy.ops.write_reg(hw, IXGBE_MII_AUTONEG_VENDOR_PROVISION_1_REG,
+			      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+			      autoneg_reg);
 
-		hw->phy.ops.write_reg(hw,
-				      IXGBE_MII_AUTONEG_VENDOR_PROVISION_1_REG,
-				      MDIO_MMD_AN,
-				      autoneg_reg);
-	}
+	/* Set or unset auto-negotiation 100M advertisement */
+	hw->phy.ops.read_reg(hw, IXGBE_MII_AUTONEG_ADVERTISE_REG,
+			     IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+			     &autoneg_reg);
 
-	if (speed & IXGBE_LINK_SPEED_100_FULL) {
-		/* Set or unset auto-negotiation 100M advertisement */
-		hw->phy.ops.read_reg(hw, MDIO_AN_ADVERTISE,
-				     MDIO_MMD_AN,
-				     &autoneg_reg);
+	autoneg_reg &= ~(IXGBE_MII_100BASE_T_ADVERTISE |
+			 IXGBE_MII_100BASE_T_ADVERTISE_HALF);
+	if ((hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_100_FULL) &&
+	    (speed & IXGBE_LINK_SPEED_100_FULL))
+		autoneg_reg |= IXGBE_MII_100BASE_T_ADVERTISE;
 
-		autoneg_reg &= ~(ADVERTISE_100FULL |
-				 ADVERTISE_100HALF);
-		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_100_FULL)
-			autoneg_reg |= ADVERTISE_100FULL;
-
-		hw->phy.ops.write_reg(hw, MDIO_AN_ADVERTISE,
-				      MDIO_MMD_AN,
-				      autoneg_reg);
-	}
+	hw->phy.ops.write_reg(hw, IXGBE_MII_AUTONEG_ADVERTISE_REG,
+			      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+			      autoneg_reg);
 
 	/* Blocked by MNG FW so don't reset PHY */
 	if (ixgbe_check_reset_blocked(hw))
-		return 0;
+		return status;
 
-	/* Restart PHY autonegotiation and wait for completion */
-	hw->phy.ops.read_reg(hw, MDIO_CTRL1,
-			     MDIO_MMD_AN, &autoneg_reg);
+	/* Restart PHY auto-negotiation. */
+	hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_CONTROL,
+			     IXGBE_MDIO_AUTO_NEG_DEV_TYPE, &autoneg_reg);
 
-	autoneg_reg |= MDIO_AN_CTRL1_RESTART;
+	autoneg_reg |= IXGBE_MII_RESTART;
 
-	hw->phy.ops.write_reg(hw, MDIO_CTRL1,
-			      MDIO_MMD_AN, autoneg_reg);
+	hw->phy.ops.write_reg(hw, IXGBE_MDIO_AUTO_NEG_CONTROL,
+			      IXGBE_MDIO_AUTO_NEG_DEV_TYPE, autoneg_reg);
 
 	return status;
 }
@@ -778,6 +868,9 @@ s32 ixgbe_setup_phy_link_speed_generic(struct ixgbe_hw *hw,
 				       ixgbe_link_speed speed,
 				       bool autoneg_wait_to_complete)
 {
+	UNREFERENCED_1PARAMETER(autoneg_wait_to_complete);
+
+	DEBUGFUNC("ixgbe_setup_phy_link_speed_generic");
 
 	/*
 	 * Clear autoneg_advertised and set new values based on input link
@@ -788,40 +881,50 @@ s32 ixgbe_setup_phy_link_speed_generic(struct ixgbe_hw *hw,
 	if (speed & IXGBE_LINK_SPEED_10GB_FULL)
 		hw->phy.autoneg_advertised |= IXGBE_LINK_SPEED_10GB_FULL;
 
+	if (speed & IXGBE_LINK_SPEED_5GB_FULL)
+		hw->phy.autoneg_advertised |= IXGBE_LINK_SPEED_5GB_FULL;
+
+	if (speed & IXGBE_LINK_SPEED_2_5GB_FULL)
+		hw->phy.autoneg_advertised |= IXGBE_LINK_SPEED_2_5GB_FULL;
+
 	if (speed & IXGBE_LINK_SPEED_1GB_FULL)
 		hw->phy.autoneg_advertised |= IXGBE_LINK_SPEED_1GB_FULL;
 
 	if (speed & IXGBE_LINK_SPEED_100_FULL)
 		hw->phy.autoneg_advertised |= IXGBE_LINK_SPEED_100_FULL;
 
+	if (speed & IXGBE_LINK_SPEED_10_FULL)
+		hw->phy.autoneg_advertised |= IXGBE_LINK_SPEED_10_FULL;
+
 	/* Setup link based on the new speed settings */
-	hw->phy.ops.setup_link(hw);
+	ixgbe_setup_phy_link(hw);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
- * ixgbe_get_copper_speeds_supported - Get copper link speed from phy
+ * ixgbe_get_copper_speeds_supported - Get copper link speeds from phy
  * @hw: pointer to hardware structure
  *
  * Determines the supported link capabilities by reading the PHY auto
  * negotiation register.
- */
+ **/
 static s32 ixgbe_get_copper_speeds_supported(struct ixgbe_hw *hw)
 {
-	u16 speed_ability;
 	s32 status;
+	u16 speed_ability;
 
-	status = hw->phy.ops.read_reg(hw, MDIO_SPEED, MDIO_MMD_PMAPMD,
+	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_PHY_SPEED_ABILITY,
+				      IXGBE_MDIO_PMA_PMD_DEV_TYPE,
 				      &speed_ability);
 	if (status)
 		return status;
 
-	if (speed_ability & MDIO_SPEED_10G)
+	if (speed_ability & IXGBE_MDIO_PHY_SPEED_10G)
 		hw->phy.speeds_supported |= IXGBE_LINK_SPEED_10GB_FULL;
-	if (speed_ability & MDIO_PMA_SPEED_1000)
+	if (speed_ability & IXGBE_MDIO_PHY_SPEED_1G)
 		hw->phy.speeds_supported |= IXGBE_LINK_SPEED_1GB_FULL;
-	if (speed_ability & MDIO_PMA_SPEED_100)
+	if (speed_ability & IXGBE_MDIO_PHY_SPEED_100M)
 		hw->phy.speeds_supported |= IXGBE_LINK_SPEED_100_FULL;
 
 	switch (hw->mac.type) {
@@ -830,26 +933,29 @@ static s32 ixgbe_get_copper_speeds_supported(struct ixgbe_hw *hw)
 		hw->phy.speeds_supported |= IXGBE_LINK_SPEED_5GB_FULL;
 		break;
 	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
 		hw->phy.speeds_supported &= ~IXGBE_LINK_SPEED_100_FULL;
 		break;
 	default:
 		break;
 	}
 
-	return 0;
+	return status;
 }
 
 /**
- * ixgbe_get_copper_link_capabilities_generic - Determines link capabilities
- * @hw: pointer to hardware structure
- * @speed: pointer to link speed
- * @autoneg: boolean auto-negotiation value
- */
+ *  ixgbe_get_copper_link_capabilities_generic - Determines link capabilities
+ *  @hw: pointer to hardware structure
+ *  @speed: pointer to link speed
+ *  @autoneg: boolean auto-negotiation value
+ **/
 s32 ixgbe_get_copper_link_capabilities_generic(struct ixgbe_hw *hw,
 					       ixgbe_link_speed *speed,
 					       bool *autoneg)
 {
-	s32 status = 0;
+	s32 status = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_get_copper_link_capabilities_generic");
 
 	*autoneg = true;
 	if (!hw->phy.speeds_supported)
@@ -869,13 +975,15 @@ s32 ixgbe_get_copper_link_capabilities_generic(struct ixgbe_hw *hw,
 s32 ixgbe_check_phy_link_tnx(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
 			     bool *link_up)
 {
-	s32 status;
+	s32 status = IXGBE_SUCCESS;
 	u32 time_out;
 	u32 max_time_out = 10;
 	u16 phy_link = 0;
 	u16 phy_speed = 0;
 	u16 phy_data = 0;
 
+	DEBUGFUNC("ixgbe_check_phy_link_tnx");
+
 	/* Initialize speed and link to default case */
 	*link_up = false;
 	*speed = IXGBE_LINK_SPEED_10GB_FULL;
@@ -886,15 +994,14 @@ s32 ixgbe_check_phy_link_tnx(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
 	 * be changed for other copper PHYs.
 	 */
 	for (time_out = 0; time_out < max_time_out; time_out++) {
-		udelay(10);
+		usec_delay(10);
 		status = hw->phy.ops.read_reg(hw,
-					      MDIO_STAT1,
-					      MDIO_MMD_VEND1,
-					      &phy_data);
-		phy_link = phy_data &
-			    IXGBE_MDIO_VENDOR_SPECIFIC_1_LINK_STATUS;
+					IXGBE_MDIO_VENDOR_SPECIFIC_1_STATUS,
+					IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
+					&phy_data);
+		phy_link = phy_data & IXGBE_MDIO_VENDOR_SPECIFIC_1_LINK_STATUS;
 		phy_speed = phy_data &
-			    IXGBE_MDIO_VENDOR_SPECIFIC_1_SPEED_STATUS;
+				 IXGBE_MDIO_VENDOR_SPECIFIC_1_SPEED_STATUS;
 		if (phy_link == IXGBE_MDIO_VENDOR_SPECIFIC_1_LINK_STATUS) {
 			*link_up = true;
 			if (phy_speed ==
@@ -908,41 +1015,41 @@ s32 ixgbe_check_phy_link_tnx(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
 }
 
 /**
- *	ixgbe_setup_phy_link_tnx - Set and restart autoneg
+ *	ixgbe_setup_phy_link_tnx - Set and restart auto-neg
  *	@hw: pointer to hardware structure
  *
- *	Restart autonegotiation and PHY and waits for completion.
- *      This function always returns success, this is nessary since
- *	it is called via a function pointer that could call other
- *	functions that could return an error.
+ *	Restart auto-negotiation and PHY and waits for completion.
  **/
 s32 ixgbe_setup_phy_link_tnx(struct ixgbe_hw *hw)
 {
+	s32 status = IXGBE_SUCCESS;
 	u16 autoneg_reg = IXGBE_MII_AUTONEG_REG;
 	bool autoneg = false;
 	ixgbe_link_speed speed;
 
+	DEBUGFUNC("ixgbe_setup_phy_link_tnx");
+
 	ixgbe_get_copper_link_capabilities_generic(hw, &speed, &autoneg);
 
 	if (speed & IXGBE_LINK_SPEED_10GB_FULL) {
 		/* Set or unset auto-negotiation 10G advertisement */
-		hw->phy.ops.read_reg(hw, MDIO_AN_10GBT_CTRL,
-				     MDIO_MMD_AN,
+		hw->phy.ops.read_reg(hw, IXGBE_MII_10GBASE_T_AUTONEG_CTRL_REG,
+				     IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
 				     &autoneg_reg);
 
-		autoneg_reg &= ~MDIO_AN_10GBT_CTRL_ADV10G;
+		autoneg_reg &= ~IXGBE_MII_10GBASE_T_ADVERTISE;
 		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_10GB_FULL)
-			autoneg_reg |= MDIO_AN_10GBT_CTRL_ADV10G;
+			autoneg_reg |= IXGBE_MII_10GBASE_T_ADVERTISE;
 
-		hw->phy.ops.write_reg(hw, MDIO_AN_10GBT_CTRL,
-				      MDIO_MMD_AN,
+		hw->phy.ops.write_reg(hw, IXGBE_MII_10GBASE_T_AUTONEG_CTRL_REG,
+				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
 				      autoneg_reg);
 	}
 
 	if (speed & IXGBE_LINK_SPEED_1GB_FULL) {
 		/* Set or unset auto-negotiation 1G advertisement */
 		hw->phy.ops.read_reg(hw, IXGBE_MII_AUTONEG_XNP_TX_REG,
-				     MDIO_MMD_AN,
+				     IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
 				     &autoneg_reg);
 
 		autoneg_reg &= ~IXGBE_MII_1GBASE_T_ADVERTISE_XNP_TX;
@@ -950,39 +1057,39 @@ s32 ixgbe_setup_phy_link_tnx(struct ixgbe_hw *hw)
 			autoneg_reg |= IXGBE_MII_1GBASE_T_ADVERTISE_XNP_TX;
 
 		hw->phy.ops.write_reg(hw, IXGBE_MII_AUTONEG_XNP_TX_REG,
-				      MDIO_MMD_AN,
+				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
 				      autoneg_reg);
 	}
 
 	if (speed & IXGBE_LINK_SPEED_100_FULL) {
 		/* Set or unset auto-negotiation 100M advertisement */
-		hw->phy.ops.read_reg(hw, MDIO_AN_ADVERTISE,
-				     MDIO_MMD_AN,
+		hw->phy.ops.read_reg(hw, IXGBE_MII_AUTONEG_ADVERTISE_REG,
+				     IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
 				     &autoneg_reg);
 
-		autoneg_reg &= ~(ADVERTISE_100FULL |
-				 ADVERTISE_100HALF);
+		autoneg_reg &= ~IXGBE_MII_100BASE_T_ADVERTISE;
 		if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_100_FULL)
-			autoneg_reg |= ADVERTISE_100FULL;
+			autoneg_reg |= IXGBE_MII_100BASE_T_ADVERTISE;
 
-		hw->phy.ops.write_reg(hw, MDIO_AN_ADVERTISE,
-				      MDIO_MMD_AN,
+		hw->phy.ops.write_reg(hw, IXGBE_MII_AUTONEG_ADVERTISE_REG,
+				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
 				      autoneg_reg);
 	}
 
 	/* Blocked by MNG FW so don't reset PHY */
 	if (ixgbe_check_reset_blocked(hw))
-		return 0;
+		return status;
+
+	/* Restart PHY auto-negotiation. */
+	hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_CONTROL,
+			     IXGBE_MDIO_AUTO_NEG_DEV_TYPE, &autoneg_reg);
 
-	/* Restart PHY autonegotiation and wait for completion */
-	hw->phy.ops.read_reg(hw, MDIO_CTRL1,
-			     MDIO_MMD_AN, &autoneg_reg);
+	autoneg_reg |= IXGBE_MII_RESTART;
 
-	autoneg_reg |= MDIO_AN_CTRL1_RESTART;
+	hw->phy.ops.write_reg(hw, IXGBE_MDIO_AUTO_NEG_CONTROL,
+			      IXGBE_MDIO_AUTO_NEG_DEV_TYPE, autoneg_reg);
 
-	hw->phy.ops.write_reg(hw, MDIO_CTRL1,
-			      MDIO_MMD_AN, autoneg_reg);
-	return 0;
+	return status;
 }
 
 /**
@@ -995,8 +1102,10 @@ s32 ixgbe_get_phy_firmware_version_tnx(struct ixgbe_hw *hw,
 {
 	s32 status;
 
+	DEBUGFUNC("ixgbe_get_phy_firmware_version_tnx");
+
 	status = hw->phy.ops.read_reg(hw, TNX_FW_REV,
-				      MDIO_MMD_VEND1,
+				      IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
 				      firmware_version);
 
 	return status;
@@ -1012,8 +1121,10 @@ s32 ixgbe_get_phy_firmware_version_generic(struct ixgbe_hw *hw,
 {
 	s32 status;
 
+	DEBUGFUNC("ixgbe_get_phy_firmware_version_generic");
+
 	status = hw->phy.ops.read_reg(hw, AQ_FW_REV,
-				      MDIO_MMD_VEND1,
+				      IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
 				      firmware_version);
 
 	return status;
@@ -1029,37 +1140,42 @@ s32 ixgbe_reset_phy_nl(struct ixgbe_hw *hw)
 	bool end_data = false;
 	u16 list_offset, data_offset;
 	u16 phy_data = 0;
-	s32 ret_val;
+	s32 ret_val = IXGBE_SUCCESS;
 	u32 i;
 
+	DEBUGFUNC("ixgbe_reset_phy_nl");
+
 	/* Blocked by MNG FW so bail */
 	if (ixgbe_check_reset_blocked(hw))
-		return 0;
+		goto out;
 
-	hw->phy.ops.read_reg(hw, MDIO_CTRL1, MDIO_MMD_PHYXS, &phy_data);
+	hw->phy.ops.read_reg(hw, IXGBE_MDIO_PHY_XS_CONTROL,
+			     IXGBE_MDIO_PHY_XS_DEV_TYPE, &phy_data);
 
 	/* reset the PHY and poll for completion */
-	hw->phy.ops.write_reg(hw, MDIO_CTRL1, MDIO_MMD_PHYXS,
-			      (phy_data | MDIO_CTRL1_RESET));
+	hw->phy.ops.write_reg(hw, IXGBE_MDIO_PHY_XS_CONTROL,
+			      IXGBE_MDIO_PHY_XS_DEV_TYPE,
+			      (phy_data | IXGBE_MDIO_PHY_XS_RESET));
 
 	for (i = 0; i < 100; i++) {
-		hw->phy.ops.read_reg(hw, MDIO_CTRL1, MDIO_MMD_PHYXS,
-				     &phy_data);
-		if ((phy_data & MDIO_CTRL1_RESET) == 0)
+		hw->phy.ops.read_reg(hw, IXGBE_MDIO_PHY_XS_CONTROL,
+				     IXGBE_MDIO_PHY_XS_DEV_TYPE, &phy_data);
+		if ((phy_data & IXGBE_MDIO_PHY_XS_RESET) == 0)
 			break;
-		usleep_range(10000, 20000);
+		msec_delay(10);
 	}
 
-	if ((phy_data & MDIO_CTRL1_RESET) != 0) {
-		hw_dbg(hw, "PHY reset did not complete.\n");
-		return IXGBE_ERR_PHY;
+	if ((phy_data & IXGBE_MDIO_PHY_XS_RESET) != 0) {
+		DEBUGOUT("PHY reset did not complete.\n");
+		ret_val = IXGBE_ERR_PHY;
+		goto out;
 	}
 
 	/* Get init offsets */
 	ret_val = ixgbe_get_sfp_init_sequence_offsets(hw, &list_offset,
 						      &data_offset);
-	if (ret_val)
-		return ret_val;
+	if (ret_val != IXGBE_SUCCESS)
+		goto out;
 
 	ret_val = hw->eeprom.ops.read(hw, data_offset, &block_crc);
 	data_offset++;
@@ -1076,52 +1192,57 @@ s32 ixgbe_reset_phy_nl(struct ixgbe_hw *hw)
 		switch (control) {
 		case IXGBE_DELAY_NL:
 			data_offset++;
-			hw_dbg(hw, "DELAY: %d MS\n", edata);
-			usleep_range(edata * 1000, edata * 2000);
+			DEBUGOUT1("DELAY: %d MS\n", edata);
+			msec_delay(edata);
 			break;
 		case IXGBE_DATA_NL:
-			hw_dbg(hw, "DATA:\n");
+			DEBUGOUT("DATA:\n");
 			data_offset++;
-			ret_val = hw->eeprom.ops.read(hw, data_offset++,
+			ret_val = hw->eeprom.ops.read(hw, data_offset,
 						      &phy_offset);
 			if (ret_val)
 				goto err_eeprom;
+			data_offset++;
 			for (i = 0; i < edata; i++) {
 				ret_val = hw->eeprom.ops.read(hw, data_offset,
 							      &eword);
 				if (ret_val)
 					goto err_eeprom;
 				hw->phy.ops.write_reg(hw, phy_offset,
-						      MDIO_MMD_PMAPMD, eword);
-				hw_dbg(hw, "Wrote %4.4x to %4.4x\n", eword,
-				       phy_offset);
+						      IXGBE_TWINAX_DEV, eword);
+				DEBUGOUT2("Wrote %4.4x to %4.4x\n", eword,
+					  phy_offset);
 				data_offset++;
 				phy_offset++;
 			}
 			break;
 		case IXGBE_CONTROL_NL:
 			data_offset++;
-			hw_dbg(hw, "CONTROL:\n");
+			DEBUGOUT("CONTROL:\n");
 			if (edata == IXGBE_CONTROL_EOL_NL) {
-				hw_dbg(hw, "EOL\n");
+				DEBUGOUT("EOL\n");
 				end_data = true;
 			} else if (edata == IXGBE_CONTROL_SOL_NL) {
-				hw_dbg(hw, "SOL\n");
+				DEBUGOUT("SOL\n");
 			} else {
-				hw_dbg(hw, "Bad control value\n");
-				return IXGBE_ERR_PHY;
+				DEBUGOUT("Bad control value\n");
+				ret_val = IXGBE_ERR_PHY;
+				goto out;
 			}
 			break;
 		default:
-			hw_dbg(hw, "Bad control type\n");
-			return IXGBE_ERR_PHY;
+			DEBUGOUT("Bad control type\n");
+			ret_val = IXGBE_ERR_PHY;
+			goto out;
 		}
 	}
 
+out:
 	return ret_val;
 
 err_eeprom:
-	hw_err(hw, "eeprom read at offset %d failed\n", data_offset);
+	ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+		      "eeprom read at offset %d failed", data_offset);
 	return IXGBE_ERR_PHY;
 }
 
@@ -1133,17 +1254,26 @@ err_eeprom:
  **/
 s32 ixgbe_identify_module_generic(struct ixgbe_hw *hw)
 {
+	s32 status = IXGBE_ERR_SFP_NOT_PRESENT;
+
+	DEBUGFUNC("ixgbe_identify_module_generic");
+
 	switch (hw->mac.ops.get_media_type(hw)) {
 	case ixgbe_media_type_fiber:
-		return ixgbe_identify_sfp_module_generic(hw);
+		status = ixgbe_identify_sfp_module_generic(hw);
+		break;
+
 	case ixgbe_media_type_fiber_qsfp:
-		return ixgbe_identify_qsfp_module_generic(hw);
+		status = ixgbe_identify_qsfp_module_generic(hw);
+		break;
+
 	default:
 		hw->phy.sfp_type = ixgbe_sfp_type_not_present;
-		return IXGBE_ERR_SFP_NOT_PRESENT;
+		status = IXGBE_ERR_SFP_NOT_PRESENT;
+		break;
 	}
 
-	return IXGBE_ERR_SFP_NOT_PRESENT;
+	return status;
 }
 
 /**
@@ -1154,8 +1284,7 @@ s32 ixgbe_identify_module_generic(struct ixgbe_hw *hw)
  **/
 s32 ixgbe_identify_sfp_module_generic(struct ixgbe_hw *hw)
 {
-	struct ixgbe_adapter *adapter = hw->back;
-	s32 status;
+	s32 status = IXGBE_ERR_PHY_ADDR_INVALID;
 	u32 vendor_oui = 0;
 	enum ixgbe_sfp_type stored_sfp_type = hw->phy.sfp_type;
 	u8 identifier = 0;
@@ -1166,241 +1295,258 @@ s32 ixgbe_identify_sfp_module_generic(struct ixgbe_hw *hw)
 	u8 cable_spec = 0;
 	u16 enforce_sfp = 0;
 
+	DEBUGFUNC("ixgbe_identify_sfp_module_generic");
+
 	if (hw->mac.ops.get_media_type(hw) != ixgbe_media_type_fiber) {
 		hw->phy.sfp_type = ixgbe_sfp_type_not_present;
-		return IXGBE_ERR_SFP_NOT_PRESENT;
+		status = IXGBE_ERR_SFP_NOT_PRESENT;
+		goto out;
 	}
 
-	/* LAN ID is needed for sfp_type determination */
+	/* LAN ID is needed for I2C access */
 	hw->mac.ops.set_lan_id(hw);
 
 	status = hw->phy.ops.read_i2c_eeprom(hw,
 					     IXGBE_SFF_IDENTIFIER,
 					     &identifier);
 
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		goto err_read_i2c_eeprom;
 
 	if (identifier != IXGBE_SFF_IDENTIFIER_SFP) {
 		hw->phy.type = ixgbe_phy_sfp_unsupported;
-		return IXGBE_ERR_SFP_NOT_SUPPORTED;
-	}
-	status = hw->phy.ops.read_i2c_eeprom(hw,
-					     IXGBE_SFF_1GBE_COMP_CODES,
-					     &comp_codes_1g);
-
-	if (status)
-		goto err_read_i2c_eeprom;
-
-	status = hw->phy.ops.read_i2c_eeprom(hw,
-					     IXGBE_SFF_10GBE_COMP_CODES,
-					     &comp_codes_10g);
-
-	if (status)
-		goto err_read_i2c_eeprom;
-	status = hw->phy.ops.read_i2c_eeprom(hw,
-					     IXGBE_SFF_CABLE_TECHNOLOGY,
-					     &cable_tech);
-
-	if (status)
-		goto err_read_i2c_eeprom;
-
-	 /* ID Module
-	  * =========
-	  * 0   SFP_DA_CU
-	  * 1   SFP_SR
-	  * 2   SFP_LR
-	  * 3   SFP_DA_CORE0 - 82599-specific
-	  * 4   SFP_DA_CORE1 - 82599-specific
-	  * 5   SFP_SR/LR_CORE0 - 82599-specific
-	  * 6   SFP_SR/LR_CORE1 - 82599-specific
-	  * 7   SFP_act_lmt_DA_CORE0 - 82599-specific
-	  * 8   SFP_act_lmt_DA_CORE1 - 82599-specific
-	  * 9   SFP_1g_cu_CORE0 - 82599-specific
-	  * 10  SFP_1g_cu_CORE1 - 82599-specific
-	  * 11  SFP_1g_sx_CORE0 - 82599-specific
-	  * 12  SFP_1g_sx_CORE1 - 82599-specific
-	  */
-	if (hw->mac.type == ixgbe_mac_82598EB) {
-		if (cable_tech & IXGBE_SFF_DA_PASSIVE_CABLE)
-			hw->phy.sfp_type = ixgbe_sfp_type_da_cu;
-		else if (comp_codes_10g & IXGBE_SFF_10GBASESR_CAPABLE)
-			hw->phy.sfp_type = ixgbe_sfp_type_sr;
-		else if (comp_codes_10g & IXGBE_SFF_10GBASELR_CAPABLE)
-			hw->phy.sfp_type = ixgbe_sfp_type_lr;
-		else
-			hw->phy.sfp_type = ixgbe_sfp_type_unknown;
+		status = IXGBE_ERR_SFP_NOT_SUPPORTED;
 	} else {
-		if (cable_tech & IXGBE_SFF_DA_PASSIVE_CABLE) {
-			if (hw->bus.lan_id == 0)
-				hw->phy.sfp_type =
-					     ixgbe_sfp_type_da_cu_core0;
-			else
-				hw->phy.sfp_type =
-					     ixgbe_sfp_type_da_cu_core1;
-		} else if (cable_tech & IXGBE_SFF_DA_ACTIVE_CABLE) {
-			hw->phy.ops.read_i2c_eeprom(
-					hw, IXGBE_SFF_CABLE_SPEC_COMP,
-					&cable_spec);
-			if (cable_spec &
-			    IXGBE_SFF_DA_SPEC_ACTIVE_LIMITING) {
-				if (hw->bus.lan_id == 0)
-					hw->phy.sfp_type =
-					ixgbe_sfp_type_da_act_lmt_core0;
-				else
-					hw->phy.sfp_type =
-					ixgbe_sfp_type_da_act_lmt_core1;
-			} else {
-				hw->phy.sfp_type =
-						ixgbe_sfp_type_unknown;
-			}
-		} else if (comp_codes_10g &
-			   (IXGBE_SFF_10GBASESR_CAPABLE |
-			    IXGBE_SFF_10GBASELR_CAPABLE)) {
-			if (hw->bus.lan_id == 0)
-				hw->phy.sfp_type =
-					      ixgbe_sfp_type_srlr_core0;
-			else
-				hw->phy.sfp_type =
-					      ixgbe_sfp_type_srlr_core1;
-		} else if (comp_codes_1g & IXGBE_SFF_1GBASET_CAPABLE) {
-			if (hw->bus.lan_id == 0)
-				hw->phy.sfp_type =
-					ixgbe_sfp_type_1g_cu_core0;
-			else
-				hw->phy.sfp_type =
-					ixgbe_sfp_type_1g_cu_core1;
-		} else if (comp_codes_1g & IXGBE_SFF_1GBASESX_CAPABLE) {
-			if (hw->bus.lan_id == 0)
-				hw->phy.sfp_type =
-					ixgbe_sfp_type_1g_sx_core0;
-			else
-				hw->phy.sfp_type =
-					ixgbe_sfp_type_1g_sx_core1;
-		} else if (comp_codes_1g & IXGBE_SFF_1GBASELX_CAPABLE) {
-			if (hw->bus.lan_id == 0)
-				hw->phy.sfp_type =
-					ixgbe_sfp_type_1g_lx_core0;
-			else
-				hw->phy.sfp_type =
-					ixgbe_sfp_type_1g_lx_core1;
-		} else {
-			hw->phy.sfp_type = ixgbe_sfp_type_unknown;
-		}
-	}
-
-	if (hw->phy.sfp_type != stored_sfp_type)
-		hw->phy.sfp_setup_needed = true;
-
-	/* Determine if the SFP+ PHY is dual speed or not. */
-	hw->phy.multispeed_fiber = false;
-	if (((comp_codes_1g & IXGBE_SFF_1GBASESX_CAPABLE) &&
-	     (comp_codes_10g & IXGBE_SFF_10GBASESR_CAPABLE)) ||
-	    ((comp_codes_1g & IXGBE_SFF_1GBASELX_CAPABLE) &&
-	     (comp_codes_10g & IXGBE_SFF_10GBASELR_CAPABLE)))
-		hw->phy.multispeed_fiber = true;
-
-	/* Determine PHY vendor */
-	if (hw->phy.type != ixgbe_phy_nl) {
-		hw->phy.id = identifier;
 		status = hw->phy.ops.read_i2c_eeprom(hw,
-					    IXGBE_SFF_VENDOR_OUI_BYTE0,
-					    &oui_bytes[0]);
+						     IXGBE_SFF_1GBE_COMP_CODES,
+						     &comp_codes_1g);
 
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto err_read_i2c_eeprom;
 
 		status = hw->phy.ops.read_i2c_eeprom(hw,
-					    IXGBE_SFF_VENDOR_OUI_BYTE1,
-					    &oui_bytes[1]);
+						     IXGBE_SFF_10GBE_COMP_CODES,
+						     &comp_codes_10g);
 
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto err_read_i2c_eeprom;
-
 		status = hw->phy.ops.read_i2c_eeprom(hw,
-					    IXGBE_SFF_VENDOR_OUI_BYTE2,
-					    &oui_bytes[2]);
+						     IXGBE_SFF_CABLE_TECHNOLOGY,
+						     &cable_tech);
 
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto err_read_i2c_eeprom;
 
-		vendor_oui =
-		  ((oui_bytes[0] << IXGBE_SFF_VENDOR_OUI_BYTE0_SHIFT) |
-		   (oui_bytes[1] << IXGBE_SFF_VENDOR_OUI_BYTE1_SHIFT) |
-		   (oui_bytes[2] << IXGBE_SFF_VENDOR_OUI_BYTE2_SHIFT));
-
-		switch (vendor_oui) {
-		case IXGBE_SFF_VENDOR_OUI_TYCO:
-			if (cable_tech & IXGBE_SFF_DA_PASSIVE_CABLE)
-				hw->phy.type =
-					    ixgbe_phy_sfp_passive_tyco;
-			break;
-		case IXGBE_SFF_VENDOR_OUI_FTL:
-			if (cable_tech & IXGBE_SFF_DA_ACTIVE_CABLE)
-				hw->phy.type = ixgbe_phy_sfp_ftl_active;
-			else
-				hw->phy.type = ixgbe_phy_sfp_ftl;
-			break;
-		case IXGBE_SFF_VENDOR_OUI_AVAGO:
-			hw->phy.type = ixgbe_phy_sfp_avago;
-			break;
-		case IXGBE_SFF_VENDOR_OUI_INTEL:
-			hw->phy.type = ixgbe_phy_sfp_intel;
-			break;
-		default:
+		 /* ID Module
+		  * =========
+		  * 0   SFP_DA_CU
+		  * 1   SFP_SR
+		  * 2   SFP_LR
+		  * 3   SFP_DA_CORE0 - 82599-specific
+		  * 4   SFP_DA_CORE1 - 82599-specific
+		  * 5   SFP_SR/LR_CORE0 - 82599-specific
+		  * 6   SFP_SR/LR_CORE1 - 82599-specific
+		  * 7   SFP_act_lmt_DA_CORE0 - 82599-specific
+		  * 8   SFP_act_lmt_DA_CORE1 - 82599-specific
+		  * 9   SFP_1g_cu_CORE0 - 82599-specific
+		  * 10  SFP_1g_cu_CORE1 - 82599-specific
+		  * 11  SFP_1g_sx_CORE0 - 82599-specific
+		  * 12  SFP_1g_sx_CORE1 - 82599-specific
+		  */
+		if (hw->mac.type == ixgbe_mac_82598EB) {
 			if (cable_tech & IXGBE_SFF_DA_PASSIVE_CABLE)
-				hw->phy.type =
-					 ixgbe_phy_sfp_passive_unknown;
-			else if (cable_tech & IXGBE_SFF_DA_ACTIVE_CABLE)
-				hw->phy.type =
-					ixgbe_phy_sfp_active_unknown;
+				hw->phy.sfp_type = ixgbe_sfp_type_da_cu;
+			else if (comp_codes_10g & IXGBE_SFF_10GBASESR_CAPABLE)
+				hw->phy.sfp_type = ixgbe_sfp_type_sr;
+			else if (comp_codes_10g & IXGBE_SFF_10GBASELR_CAPABLE)
+				hw->phy.sfp_type = ixgbe_sfp_type_lr;
 			else
-				hw->phy.type = ixgbe_phy_sfp_unknown;
-			break;
+				hw->phy.sfp_type = ixgbe_sfp_type_unknown;
+		} else {
+			if (cable_tech & IXGBE_SFF_DA_PASSIVE_CABLE) {
+				if (hw->bus.lan_id == 0)
+					hw->phy.sfp_type =
+						     ixgbe_sfp_type_da_cu_core0;
+				else
+					hw->phy.sfp_type =
+						     ixgbe_sfp_type_da_cu_core1;
+			} else if (cable_tech & IXGBE_SFF_DA_ACTIVE_CABLE) {
+				hw->phy.ops.read_i2c_eeprom(
+						hw, IXGBE_SFF_CABLE_SPEC_COMP,
+						&cable_spec);
+				if (cable_spec &
+				    IXGBE_SFF_DA_SPEC_ACTIVE_LIMITING) {
+					if (hw->bus.lan_id == 0)
+						hw->phy.sfp_type =
+						ixgbe_sfp_type_da_act_lmt_core0;
+					else
+						hw->phy.sfp_type =
+						ixgbe_sfp_type_da_act_lmt_core1;
+				} else {
+					hw->phy.sfp_type =
+							ixgbe_sfp_type_unknown;
+				}
+			} else if (comp_codes_10g &
+				   (IXGBE_SFF_10GBASESR_CAPABLE |
+				    IXGBE_SFF_10GBASELR_CAPABLE)) {
+				if (hw->bus.lan_id == 0)
+					hw->phy.sfp_type =
+						      ixgbe_sfp_type_srlr_core0;
+				else
+					hw->phy.sfp_type =
+						      ixgbe_sfp_type_srlr_core1;
+			} else if (comp_codes_1g & IXGBE_SFF_1GBASET_CAPABLE) {
+				if (hw->bus.lan_id == 0)
+					hw->phy.sfp_type =
+						ixgbe_sfp_type_1g_cu_core0;
+				else
+					hw->phy.sfp_type =
+						ixgbe_sfp_type_1g_cu_core1;
+			} else if (comp_codes_1g & IXGBE_SFF_1GBASESX_CAPABLE) {
+				if (hw->bus.lan_id == 0)
+					hw->phy.sfp_type =
+						ixgbe_sfp_type_1g_sx_core0;
+				else
+					hw->phy.sfp_type =
+						ixgbe_sfp_type_1g_sx_core1;
+			} else if (comp_codes_1g & IXGBE_SFF_1GBASELX_CAPABLE) {
+				if (hw->bus.lan_id == 0)
+					hw->phy.sfp_type =
+						ixgbe_sfp_type_1g_lx_core0;
+				else
+					hw->phy.sfp_type =
+						ixgbe_sfp_type_1g_lx_core1;
+			} else {
+				hw->phy.sfp_type = ixgbe_sfp_type_unknown;
+			}
 		}
-	}
 
-	/* Allow any DA cable vendor */
-	if (cable_tech & (IXGBE_SFF_DA_PASSIVE_CABLE |
-	    IXGBE_SFF_DA_ACTIVE_CABLE))
-		return 0;
+		if (hw->phy.sfp_type != stored_sfp_type)
+			hw->phy.sfp_setup_needed = true;
+
+		/* Determine if the SFP+ PHY is dual speed or not. */
+		hw->phy.multispeed_fiber = false;
+		if (((comp_codes_1g & IXGBE_SFF_1GBASESX_CAPABLE) &&
+		   (comp_codes_10g & IXGBE_SFF_10GBASESR_CAPABLE)) ||
+		   ((comp_codes_1g & IXGBE_SFF_1GBASELX_CAPABLE) &&
+		   (comp_codes_10g & IXGBE_SFF_10GBASELR_CAPABLE)))
+			hw->phy.multispeed_fiber = true;
+
+		/* Determine PHY vendor */
+		if (hw->phy.type != ixgbe_phy_nl) {
+			hw->phy.id = identifier;
+			status = hw->phy.ops.read_i2c_eeprom(hw,
+						    IXGBE_SFF_VENDOR_OUI_BYTE0,
+						    &oui_bytes[0]);
+
+			if (status != IXGBE_SUCCESS)
+				goto err_read_i2c_eeprom;
+
+			status = hw->phy.ops.read_i2c_eeprom(hw,
+						    IXGBE_SFF_VENDOR_OUI_BYTE1,
+						    &oui_bytes[1]);
+
+			if (status != IXGBE_SUCCESS)
+				goto err_read_i2c_eeprom;
+
+			status = hw->phy.ops.read_i2c_eeprom(hw,
+						    IXGBE_SFF_VENDOR_OUI_BYTE2,
+						    &oui_bytes[2]);
+
+			if (status != IXGBE_SUCCESS)
+				goto err_read_i2c_eeprom;
+
+			vendor_oui =
+			  ((oui_bytes[0] << IXGBE_SFF_VENDOR_OUI_BYTE0_SHIFT) |
+			   (oui_bytes[1] << IXGBE_SFF_VENDOR_OUI_BYTE1_SHIFT) |
+			   (oui_bytes[2] << IXGBE_SFF_VENDOR_OUI_BYTE2_SHIFT));
+
+			switch (vendor_oui) {
+			case IXGBE_SFF_VENDOR_OUI_TYCO:
+				if (cable_tech & IXGBE_SFF_DA_PASSIVE_CABLE)
+					hw->phy.type =
+						    ixgbe_phy_sfp_passive_tyco;
+				break;
+			case IXGBE_SFF_VENDOR_OUI_FTL:
+				if (cable_tech & IXGBE_SFF_DA_ACTIVE_CABLE)
+					hw->phy.type = ixgbe_phy_sfp_ftl_active;
+				else
+					hw->phy.type = ixgbe_phy_sfp_ftl;
+				break;
+			case IXGBE_SFF_VENDOR_OUI_AVAGO:
+				hw->phy.type = ixgbe_phy_sfp_avago;
+				break;
+			case IXGBE_SFF_VENDOR_OUI_INTEL:
+				hw->phy.type = ixgbe_phy_sfp_intel;
+				break;
+			default:
+				if (cable_tech & IXGBE_SFF_DA_PASSIVE_CABLE)
+					hw->phy.type =
+						 ixgbe_phy_sfp_passive_unknown;
+				else if (cable_tech & IXGBE_SFF_DA_ACTIVE_CABLE)
+					hw->phy.type =
+						ixgbe_phy_sfp_active_unknown;
+				else
+					hw->phy.type = ixgbe_phy_sfp_unknown;
+				break;
+			}
+		}
 
-	/* Verify supported 1G SFP modules */
-	if (comp_codes_10g == 0 &&
-	    !(hw->phy.sfp_type == ixgbe_sfp_type_1g_cu_core1 ||
-	      hw->phy.sfp_type == ixgbe_sfp_type_1g_cu_core0 ||
-	      hw->phy.sfp_type == ixgbe_sfp_type_1g_lx_core0 ||
-	      hw->phy.sfp_type == ixgbe_sfp_type_1g_lx_core1 ||
-	      hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core0 ||
-	      hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core1)) {
-		hw->phy.type = ixgbe_phy_sfp_unsupported;
-		return IXGBE_ERR_SFP_NOT_SUPPORTED;
-	}
+		/* Allow any DA cable vendor */
+		if (cable_tech & (IXGBE_SFF_DA_PASSIVE_CABLE |
+		    IXGBE_SFF_DA_ACTIVE_CABLE)) {
+			status = IXGBE_SUCCESS;
+			goto out;
+		}
 
-	/* Anything else 82598-based is supported */
-	if (hw->mac.type == ixgbe_mac_82598EB)
-		return 0;
+		/* Verify supported 1G SFP modules */
+		if (comp_codes_10g == 0 &&
+		    !(hw->phy.sfp_type == ixgbe_sfp_type_1g_cu_core1 ||
+		      hw->phy.sfp_type == ixgbe_sfp_type_1g_cu_core0 ||
+		      hw->phy.sfp_type == ixgbe_sfp_type_1g_lx_core0 ||
+		      hw->phy.sfp_type == ixgbe_sfp_type_1g_lx_core1 ||
+		      hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core0 ||
+		      hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core1)) {
+			hw->phy.type = ixgbe_phy_sfp_unsupported;
+			status = IXGBE_ERR_SFP_NOT_SUPPORTED;
+			goto out;
+		}
 
-	hw->mac.ops.get_device_caps(hw, &enforce_sfp);
-	if (!(enforce_sfp & IXGBE_DEVICE_CAPS_ALLOW_ANY_SFP) &&
-	    !(hw->phy.sfp_type == ixgbe_sfp_type_1g_cu_core0 ||
-	      hw->phy.sfp_type == ixgbe_sfp_type_1g_cu_core1 ||
-	      hw->phy.sfp_type == ixgbe_sfp_type_1g_lx_core0 ||
-	      hw->phy.sfp_type == ixgbe_sfp_type_1g_lx_core1 ||
-	      hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core0 ||
-	      hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core1)) {
-		/* Make sure we're a supported PHY type */
-		if (hw->phy.type == ixgbe_phy_sfp_intel)
-			return 0;
-		if (hw->allow_unsupported_sfp) {
-			e_warn(drv, "WARNING: Intel (R) Network Connections are quality tested using Intel (R) Ethernet Optics.  Using untested modules is not supported and may cause unstable operation or damage to the module or the adapter.  Intel Corporation is not responsible for any harm caused by using untested modules.\n");
-			return 0;
+		/* Anything else 82598-based is supported */
+		if (hw->mac.type == ixgbe_mac_82598EB) {
+			status = IXGBE_SUCCESS;
+			goto out;
+		}
+
+		ixgbe_get_device_caps(hw, &enforce_sfp);
+		if (!(enforce_sfp & IXGBE_DEVICE_CAPS_ALLOW_ANY_SFP) &&
+		    !(hw->phy.sfp_type == ixgbe_sfp_type_1g_cu_core0 ||
+		      hw->phy.sfp_type == ixgbe_sfp_type_1g_cu_core1 ||
+		      hw->phy.sfp_type == ixgbe_sfp_type_1g_lx_core0 ||
+		      hw->phy.sfp_type == ixgbe_sfp_type_1g_lx_core1 ||
+		      hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core0 ||
+		      hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core1)) {
+			/* Make sure we're a supported PHY type */
+			if (hw->phy.type == ixgbe_phy_sfp_intel) {
+				status = IXGBE_SUCCESS;
+			} else {
+				if (hw->allow_unsupported_sfp == true) {
+					EWARN(hw, "WARNING: Intel (R) Network Connections are quality tested using Intel (R) Ethernet Optics. Using untested modules is not supported and may cause unstable operation or damage to the module or the adapter. Intel Corporation is not responsible for any harm caused by using untested modules.\n");
+					status = IXGBE_SUCCESS;
+				} else {
+					DEBUGOUT("SFP+ module not supported\n");
+					hw->phy.type =
+						ixgbe_phy_sfp_unsupported;
+					status = IXGBE_ERR_SFP_NOT_SUPPORTED;
+				}
+			}
+		} else {
+			status = IXGBE_SUCCESS;
 		}
-		hw_dbg(hw, "SFP+ module not supported\n");
-		hw->phy.type = ixgbe_phy_sfp_unsupported;
-		return IXGBE_ERR_SFP_NOT_SUPPORTED;
 	}
-	return 0;
+
+out:
+	return status;
 
 err_read_i2c_eeprom:
 	hw->phy.sfp_type = ixgbe_sfp_type_not_present;
@@ -1412,15 +1558,76 @@ err_read_i2c_eeprom:
 }
 
 /**
- * ixgbe_identify_qsfp_module_generic - Identifies QSFP modules
- * @hw: pointer to hardware structure
+ *  ixgbe_get_supported_phy_sfp_layer_generic - Returns physical layer type
+ *  @hw: pointer to hardware structure
  *
- * Searches for and identifies the QSFP module and assigns appropriate PHY type
+ *  Determines physical layer capabilities of the current SFP.
+ */
+u64 ixgbe_get_supported_phy_sfp_layer_generic(struct ixgbe_hw *hw)
+{
+	u64 physical_layer = IXGBE_PHYSICAL_LAYER_UNKNOWN;
+	u8 comp_codes_10g = 0;
+	u8 comp_codes_1g = 0;
+
+	DEBUGFUNC("ixgbe_get_supported_phy_sfp_layer_generic");
+
+	hw->phy.ops.identify_sfp(hw);
+	if (hw->phy.sfp_type == ixgbe_sfp_type_not_present)
+		return physical_layer;
+
+	switch (hw->phy.type) {
+	case ixgbe_phy_sfp_passive_tyco:
+	case ixgbe_phy_sfp_passive_unknown:
+	case ixgbe_phy_qsfp_passive_unknown:
+		physical_layer = IXGBE_PHYSICAL_LAYER_SFP_PLUS_CU;
+		break;
+	case ixgbe_phy_sfp_ftl_active:
+	case ixgbe_phy_sfp_active_unknown:
+	case ixgbe_phy_qsfp_active_unknown:
+		physical_layer = IXGBE_PHYSICAL_LAYER_SFP_ACTIVE_DA;
+		break;
+	case ixgbe_phy_sfp_avago:
+	case ixgbe_phy_sfp_ftl:
+	case ixgbe_phy_sfp_intel:
+	case ixgbe_phy_sfp_unknown:
+		hw->phy.ops.read_i2c_eeprom(hw,
+		      IXGBE_SFF_1GBE_COMP_CODES, &comp_codes_1g);
+		hw->phy.ops.read_i2c_eeprom(hw,
+		      IXGBE_SFF_10GBE_COMP_CODES, &comp_codes_10g);
+		if (comp_codes_10g & IXGBE_SFF_10GBASESR_CAPABLE)
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_SR;
+		else if (comp_codes_10g & IXGBE_SFF_10GBASELR_CAPABLE)
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_LR;
+		else if (comp_codes_1g & IXGBE_SFF_1GBASET_CAPABLE)
+			physical_layer = IXGBE_PHYSICAL_LAYER_1000BASE_T;
+		else if (comp_codes_1g & IXGBE_SFF_1GBASESX_CAPABLE)
+			physical_layer = IXGBE_PHYSICAL_LAYER_1000BASE_SX;
+		break;
+	case ixgbe_phy_qsfp_intel:
+	case ixgbe_phy_qsfp_unknown:
+		hw->phy.ops.read_i2c_eeprom(hw,
+		      IXGBE_SFF_QSFP_10GBE_COMP, &comp_codes_10g);
+		if (comp_codes_10g & IXGBE_SFF_10GBASESR_CAPABLE)
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_SR;
+		else if (comp_codes_10g & IXGBE_SFF_10GBASELR_CAPABLE)
+			physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_LR;
+		break;
+	default:
+		break;
+	}
+
+	return physical_layer;
+}
+
+/**
+ *  ixgbe_identify_qsfp_module_generic - Identifies QSFP modules
+ *  @hw: pointer to hardware structure
+ *
+ *  Searches for and identifies the QSFP module and assigns appropriate PHY type
  **/
-static s32 ixgbe_identify_qsfp_module_generic(struct ixgbe_hw *hw)
+s32 ixgbe_identify_qsfp_module_generic(struct ixgbe_hw *hw)
 {
-	struct ixgbe_adapter *adapter = hw->back;
-	s32 status;
+	s32 status = IXGBE_ERR_PHY_ADDR_INVALID;
 	u32 vendor_oui = 0;
 	enum ixgbe_sfp_type stored_sfp_type = hw->phy.sfp_type;
 	u8 identifier = 0;
@@ -1433,23 +1640,27 @@ static s32 ixgbe_identify_qsfp_module_generic(struct ixgbe_hw *hw)
 	u8 device_tech = 0;
 	bool active_cable = false;
 
+	DEBUGFUNC("ixgbe_identify_qsfp_module_generic");
+
 	if (hw->mac.ops.get_media_type(hw) != ixgbe_media_type_fiber_qsfp) {
 		hw->phy.sfp_type = ixgbe_sfp_type_not_present;
-		return IXGBE_ERR_SFP_NOT_PRESENT;
+		status = IXGBE_ERR_SFP_NOT_PRESENT;
+		goto out;
 	}
 
-	/* LAN ID is needed for sfp_type determination */
+	/* LAN ID is needed for I2C access */
 	hw->mac.ops.set_lan_id(hw);
 
 	status = hw->phy.ops.read_i2c_eeprom(hw, IXGBE_SFF_IDENTIFIER,
 					     &identifier);
 
-	if (status != 0)
+	if (status != IXGBE_SUCCESS)
 		goto err_read_i2c_eeprom;
 
 	if (identifier != IXGBE_SFF_IDENTIFIER_QSFP_PLUS) {
 		hw->phy.type = ixgbe_phy_sfp_unsupported;
-		return IXGBE_ERR_SFP_NOT_SUPPORTED;
+		status = IXGBE_ERR_SFP_NOT_SUPPORTED;
+		goto out;
 	}
 
 	hw->phy.id = identifier;
@@ -1457,13 +1668,13 @@ static s32 ixgbe_identify_qsfp_module_generic(struct ixgbe_hw *hw)
 	status = hw->phy.ops.read_i2c_eeprom(hw, IXGBE_SFF_QSFP_10GBE_COMP,
 					     &comp_codes_10g);
 
-	if (status != 0)
+	if (status != IXGBE_SUCCESS)
 		goto err_read_i2c_eeprom;
 
 	status = hw->phy.ops.read_i2c_eeprom(hw, IXGBE_SFF_QSFP_1GBE_COMP,
 					     &comp_codes_1g);
 
-	if (status != 0)
+	if (status != IXGBE_SUCCESS)
 		goto err_read_i2c_eeprom;
 
 	if (comp_codes_10g & IXGBE_SFF_QSFP_DA_PASSIVE_CABLE) {
@@ -1484,8 +1695,7 @@ static s32 ixgbe_identify_qsfp_module_generic(struct ixgbe_hw *hw)
 
 		if (!active_cable) {
 			/* check for active DA cables that pre-date
-			 * SFF-8436 v3.6
-			 */
+			 * SFF-8436 v3.6 */
 			hw->phy.ops.read_i2c_eeprom(hw,
 					IXGBE_SFF_QSFP_CONNECTOR,
 					&connector);
@@ -1517,7 +1727,8 @@ static s32 ixgbe_identify_qsfp_module_generic(struct ixgbe_hw *hw)
 		} else {
 			/* unsupported module type */
 			hw->phy.type = ixgbe_phy_sfp_unsupported;
-			return IXGBE_ERR_SFP_NOT_SUPPORTED;
+			status = IXGBE_ERR_SFP_NOT_SUPPORTED;
+			goto out;
 		}
 	}
 
@@ -1527,61 +1738,68 @@ static s32 ixgbe_identify_qsfp_module_generic(struct ixgbe_hw *hw)
 	/* Determine if the QSFP+ PHY is dual speed or not. */
 	hw->phy.multispeed_fiber = false;
 	if (((comp_codes_1g & IXGBE_SFF_1GBASESX_CAPABLE) &&
-	     (comp_codes_10g & IXGBE_SFF_10GBASESR_CAPABLE)) ||
-	    ((comp_codes_1g & IXGBE_SFF_1GBASELX_CAPABLE) &&
-	     (comp_codes_10g & IXGBE_SFF_10GBASELR_CAPABLE)))
+	   (comp_codes_10g & IXGBE_SFF_10GBASESR_CAPABLE)) ||
+	   ((comp_codes_1g & IXGBE_SFF_1GBASELX_CAPABLE) &&
+	   (comp_codes_10g & IXGBE_SFF_10GBASELR_CAPABLE)))
 		hw->phy.multispeed_fiber = true;
 
 	/* Determine PHY vendor for optical modules */
 	if (comp_codes_10g & (IXGBE_SFF_10GBASESR_CAPABLE |
-			      IXGBE_SFF_10GBASELR_CAPABLE)) {
+			      IXGBE_SFF_10GBASELR_CAPABLE))  {
 		status = hw->phy.ops.read_i2c_eeprom(hw,
-					IXGBE_SFF_QSFP_VENDOR_OUI_BYTE0,
-					&oui_bytes[0]);
+					    IXGBE_SFF_QSFP_VENDOR_OUI_BYTE0,
+					    &oui_bytes[0]);
 
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto err_read_i2c_eeprom;
 
 		status = hw->phy.ops.read_i2c_eeprom(hw,
-					IXGBE_SFF_QSFP_VENDOR_OUI_BYTE1,
-					&oui_bytes[1]);
+					    IXGBE_SFF_QSFP_VENDOR_OUI_BYTE1,
+					    &oui_bytes[1]);
 
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto err_read_i2c_eeprom;
 
 		status = hw->phy.ops.read_i2c_eeprom(hw,
-					IXGBE_SFF_QSFP_VENDOR_OUI_BYTE2,
-					&oui_bytes[2]);
+					    IXGBE_SFF_QSFP_VENDOR_OUI_BYTE2,
+					    &oui_bytes[2]);
 
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto err_read_i2c_eeprom;
 
 		vendor_oui =
-			((oui_bytes[0] << IXGBE_SFF_VENDOR_OUI_BYTE0_SHIFT) |
-			 (oui_bytes[1] << IXGBE_SFF_VENDOR_OUI_BYTE1_SHIFT) |
-			 (oui_bytes[2] << IXGBE_SFF_VENDOR_OUI_BYTE2_SHIFT));
+		  ((oui_bytes[0] << IXGBE_SFF_VENDOR_OUI_BYTE0_SHIFT) |
+		   (oui_bytes[1] << IXGBE_SFF_VENDOR_OUI_BYTE1_SHIFT) |
+		   (oui_bytes[2] << IXGBE_SFF_VENDOR_OUI_BYTE2_SHIFT));
 
 		if (vendor_oui == IXGBE_SFF_VENDOR_OUI_INTEL)
 			hw->phy.type = ixgbe_phy_qsfp_intel;
 		else
 			hw->phy.type = ixgbe_phy_qsfp_unknown;
 
-		hw->mac.ops.get_device_caps(hw, &enforce_sfp);
+		ixgbe_get_device_caps(hw, &enforce_sfp);
 		if (!(enforce_sfp & IXGBE_DEVICE_CAPS_ALLOW_ANY_SFP)) {
 			/* Make sure we're a supported PHY type */
-			if (hw->phy.type == ixgbe_phy_qsfp_intel)
-				return 0;
-			if (hw->allow_unsupported_sfp) {
-				e_warn(drv, "WARNING: Intel (R) Network Connections are quality tested using Intel (R) Ethernet Optics. Using untested modules is not supported and may cause unstable operation or damage to the module or the adapter. Intel Corporation is not responsible for any harm caused by using untested modules.\n");
-				return 0;
+			if (hw->phy.type == ixgbe_phy_qsfp_intel) {
+				status = IXGBE_SUCCESS;
+			} else {
+				if (hw->allow_unsupported_sfp == true) {
+					EWARN(hw, "WARNING: Intel (R) Network Connections are quality tested using Intel (R) Ethernet Optics. Using untested modules is not supported and may cause unstable operation or damage to the module or the adapter. Intel Corporation is not responsible for any harm caused by using untested modules.\n");
+					status = IXGBE_SUCCESS;
+				} else {
+					DEBUGOUT("QSFP module not supported\n");
+					hw->phy.type =
+						ixgbe_phy_sfp_unsupported;
+					status = IXGBE_ERR_SFP_NOT_SUPPORTED;
+				}
 			}
-			hw_dbg(hw, "QSFP module not supported\n");
-			hw->phy.type = ixgbe_phy_sfp_unsupported;
-			return IXGBE_ERR_SFP_NOT_SUPPORTED;
+		} else {
+			status = IXGBE_SUCCESS;
 		}
-		return 0;
 	}
-	return 0;
+
+out:
+	return status;
 
 err_read_i2c_eeprom:
 	hw->phy.sfp_type = ixgbe_sfp_type_not_present;
@@ -1607,6 +1825,8 @@ s32 ixgbe_get_sfp_init_sequence_offsets(struct ixgbe_hw *hw,
 	u16 sfp_id;
 	u16 sfp_type = hw->phy.sfp_type;
 
+	DEBUGFUNC("ixgbe_get_sfp_init_sequence_offsets");
+
 	if (hw->phy.sfp_type == ixgbe_sfp_type_unknown)
 		return IXGBE_ERR_SFP_NOT_SUPPORTED;
 
@@ -1634,8 +1854,9 @@ s32 ixgbe_get_sfp_init_sequence_offsets(struct ixgbe_hw *hw,
 
 	/* Read offset to PHY init contents */
 	if (hw->eeprom.ops.read(hw, IXGBE_PHY_INIT_OFFSET_NL, list_offset)) {
-		hw_err(hw, "eeprom read at %d failed\n",
-		       IXGBE_PHY_INIT_OFFSET_NL);
+		ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+			      "eeprom read at offset %d failed",
+			      IXGBE_PHY_INIT_OFFSET_NL);
 		return IXGBE_ERR_SFP_NO_INIT_SEQ_PRESENT;
 	}
 
@@ -1658,7 +1879,7 @@ s32 ixgbe_get_sfp_init_sequence_offsets(struct ixgbe_hw *hw,
 			if (hw->eeprom.ops.read(hw, *list_offset, data_offset))
 				goto err_phy;
 			if ((!*data_offset) || (*data_offset == 0xFFFF)) {
-				hw_dbg(hw, "SFP+ module not supported\n");
+				DEBUGOUT("SFP+ module not supported\n");
 				return IXGBE_ERR_SFP_NOT_SUPPORTED;
 			} else {
 				break;
@@ -1671,14 +1892,15 @@ s32 ixgbe_get_sfp_init_sequence_offsets(struct ixgbe_hw *hw,
 	}
 
 	if (sfp_id == IXGBE_PHY_INIT_END_NL) {
-		hw_dbg(hw, "No matching SFP+ module found\n");
+		DEBUGOUT("No matching SFP+ module found\n");
 		return IXGBE_ERR_SFP_NOT_SUPPORTED;
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 
 err_phy:
-	hw_err(hw, "eeprom read at offset %d failed\n", *list_offset);
+	ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+		      "eeprom read at offset %d failed", *list_offset);
 	return IXGBE_ERR_PHY;
 }
 
@@ -1693,6 +1915,8 @@ err_phy:
 s32 ixgbe_read_i2c_eeprom_generic(struct ixgbe_hw *hw, u8 byte_offset,
 				  u8 *eeprom_data)
 {
+	DEBUGFUNC("ixgbe_read_i2c_eeprom_generic");
+
 	return hw->phy.ops.read_i2c_byte(hw, byte_offset,
 					 IXGBE_I2C_EEPROM_DEV_ADDR,
 					 eeprom_data);
@@ -1706,8 +1930,8 @@ s32 ixgbe_read_i2c_eeprom_generic(struct ixgbe_hw *hw, u8 byte_offset,
  *
  *  Performs byte read operation to SFP module's SFF-8472 data over I2C
  **/
-s32 ixgbe_read_i2c_sff8472_generic(struct ixgbe_hw *hw, u8 byte_offset,
-				   u8 *sff8472_data)
+STATIC s32 ixgbe_read_i2c_sff8472_generic(struct ixgbe_hw *hw, u8 byte_offset,
+					  u8 *sff8472_data)
 {
 	return hw->phy.ops.read_i2c_byte(hw, byte_offset,
 					 IXGBE_I2C_EEPROM_DEV_ADDR2,
@@ -1725,6 +1949,8 @@ s32 ixgbe_read_i2c_sff8472_generic(struct ixgbe_hw *hw, u8 byte_offset,
 s32 ixgbe_write_i2c_eeprom_generic(struct ixgbe_hw *hw, u8 byte_offset,
 				   u8 eeprom_data)
 {
+	DEBUGFUNC("ixgbe_write_i2c_eeprom_generic");
+
 	return hw->phy.ops.write_i2c_byte(hw, byte_offset,
 					  IXGBE_I2C_EEPROM_DEV_ADDR,
 					  eeprom_data);
@@ -1736,7 +1962,7 @@ s32 ixgbe_write_i2c_eeprom_generic(struct ixgbe_hw *hw, u8 byte_offset,
  * @offset: eeprom offset to be read
  * @addr: I2C address to be read
  */
-static bool ixgbe_is_sfp_probe(struct ixgbe_hw *hw, u8 offset, u8 addr)
+STATIC bool ixgbe_is_sfp_probe(struct ixgbe_hw *hw, u8 offset, u8 addr)
 {
 	if (addr == IXGBE_I2C_EEPROM_DEV_ADDR &&
 	    offset == IXGBE_SFF_IDENTIFIER &&
@@ -1754,23 +1980,24 @@ static bool ixgbe_is_sfp_probe(struct ixgbe_hw *hw, u8 offset, u8 addr)
  *
  *  Performs byte read operation to SFP module's EEPROM over I2C interface at
  *  a specified device address.
- */
-static s32 ixgbe_read_i2c_byte_generic_int(struct ixgbe_hw *hw, u8 byte_offset,
+ **/
+STATIC s32 ixgbe_read_i2c_byte_generic_int(struct ixgbe_hw *hw, u8 byte_offset,
 					   u8 dev_addr, u8 *data, bool lock)
 {
 	s32 status;
 	u32 max_retry = 10;
 	u32 retry = 0;
 	u32 swfw_mask = hw->phy.phy_semaphore_mask;
-	bool nack = true;
+	bool nack = 1;
+	*data = 0;
+
+	DEBUGFUNC("ixgbe_read_i2c_byte_generic");
 
 	if (hw->mac.type >= ixgbe_mac_X550)
 		max_retry = 3;
 	if (ixgbe_is_sfp_probe(hw, byte_offset, dev_addr))
 		max_retry = IXGBE_SFP_DETECT_RETRIES;
 
-	*data = 0;
-
 	do {
 		if (lock && hw->mac.ops.acquire_swfw_sync(hw, swfw_mask))
 			return IXGBE_ERR_SWFW_SYNC;
@@ -1779,56 +2006,56 @@ static s32 ixgbe_read_i2c_byte_generic_int(struct ixgbe_hw *hw, u8 byte_offset,
 
 		/* Device Address and write indication */
 		status = ixgbe_clock_out_i2c_byte(hw, dev_addr);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		status = ixgbe_get_i2c_ack(hw);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		status = ixgbe_clock_out_i2c_byte(hw, byte_offset);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		status = ixgbe_get_i2c_ack(hw);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		ixgbe_i2c_start(hw);
 
 		/* Device Address and read indication */
 		status = ixgbe_clock_out_i2c_byte(hw, (dev_addr | 0x1));
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		status = ixgbe_get_i2c_ack(hw);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		status = ixgbe_clock_in_i2c_byte(hw, data);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		status = ixgbe_clock_out_i2c_bit(hw, nack);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		ixgbe_i2c_stop(hw);
 		if (lock)
 			hw->mac.ops.release_swfw_sync(hw, swfw_mask);
-		return 0;
+		return IXGBE_SUCCESS;
 
 fail:
 		ixgbe_i2c_bus_clear(hw);
 		if (lock) {
 			hw->mac.ops.release_swfw_sync(hw, swfw_mask);
-			msleep(100);
+			msec_delay(100);
 		}
 		retry++;
 		if (retry < max_retry)
-			hw_dbg(hw, "I2C byte read error - Retrying.\n");
+			DEBUGOUT("I2C byte read error - Retrying.\n");
 		else
-			hw_dbg(hw, "I2C byte read error.\n");
+			DEBUGOUT("I2C byte read error.\n");
 
 	} while (retry < max_retry);
 
@@ -1843,7 +2070,7 @@ fail:
  *
  *  Performs byte read operation to SFP module's EEPROM over I2C interface at
  *  a specified device address.
- */
+ **/
 s32 ixgbe_read_i2c_byte_generic(struct ixgbe_hw *hw, u8 byte_offset,
 				u8 dev_addr, u8 *data)
 {
@@ -1859,7 +2086,7 @@ s32 ixgbe_read_i2c_byte_generic(struct ixgbe_hw *hw, u8 byte_offset,
  *
  *  Performs byte read operation to SFP module's EEPROM over I2C interface at
  *  a specified device address.
- */
+ **/
 s32 ixgbe_read_i2c_byte_generic_unlocked(struct ixgbe_hw *hw, u8 byte_offset,
 					 u8 dev_addr, u8 *data)
 {
@@ -1876,8 +2103,8 @@ s32 ixgbe_read_i2c_byte_generic_unlocked(struct ixgbe_hw *hw, u8 byte_offset,
  *
  *  Performs byte write operation to SFP module's EEPROM over I2C interface at
  *  a specified device address.
- */
-static s32 ixgbe_write_i2c_byte_generic_int(struct ixgbe_hw *hw, u8 byte_offset,
+ **/
+STATIC s32 ixgbe_write_i2c_byte_generic_int(struct ixgbe_hw *hw, u8 byte_offset,
 					    u8 dev_addr, u8 data, bool lock)
 {
 	s32 status;
@@ -1885,48 +2112,51 @@ static s32 ixgbe_write_i2c_byte_generic_int(struct ixgbe_hw *hw, u8 byte_offset,
 	u32 retry = 0;
 	u32 swfw_mask = hw->phy.phy_semaphore_mask;
 
-	if (lock && hw->mac.ops.acquire_swfw_sync(hw, swfw_mask))
+	DEBUGFUNC("ixgbe_write_i2c_byte_generic");
+
+	if (lock && hw->mac.ops.acquire_swfw_sync(hw, swfw_mask) !=
+	    IXGBE_SUCCESS)
 		return IXGBE_ERR_SWFW_SYNC;
 
 	do {
 		ixgbe_i2c_start(hw);
 
 		status = ixgbe_clock_out_i2c_byte(hw, dev_addr);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		status = ixgbe_get_i2c_ack(hw);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		status = ixgbe_clock_out_i2c_byte(hw, byte_offset);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		status = ixgbe_get_i2c_ack(hw);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		status = ixgbe_clock_out_i2c_byte(hw, data);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		status = ixgbe_get_i2c_ack(hw);
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			goto fail;
 
 		ixgbe_i2c_stop(hw);
 		if (lock)
 			hw->mac.ops.release_swfw_sync(hw, swfw_mask);
-		return 0;
+		return IXGBE_SUCCESS;
 
 fail:
 		ixgbe_i2c_bus_clear(hw);
 		retry++;
 		if (retry < max_retry)
-			hw_dbg(hw, "I2C byte write error - Retrying.\n");
+			DEBUGOUT("I2C byte write error - Retrying.\n");
 		else
-			hw_dbg(hw, "I2C byte write error.\n");
+			DEBUGOUT("I2C byte write error.\n");
 	} while (retry < max_retry);
 
 	if (lock)
@@ -1943,7 +2173,7 @@ fail:
  *
  *  Performs byte write operation to SFP module's EEPROM over I2C interface at
  *  a specified device address.
- */
+ **/
 s32 ixgbe_write_i2c_byte_generic(struct ixgbe_hw *hw, u8 byte_offset,
 				 u8 dev_addr, u8 data)
 {
@@ -1959,7 +2189,7 @@ s32 ixgbe_write_i2c_byte_generic(struct ixgbe_hw *hw, u8 byte_offset,
  *
  *  Performs byte write operation to SFP module's EEPROM over I2C interface at
  *  a specified device address.
- */
+ **/
 s32 ixgbe_write_i2c_byte_generic_unlocked(struct ixgbe_hw *hw, u8 byte_offset,
 					  u8 dev_addr, u8 data)
 {
@@ -1974,28 +2204,30 @@ s32 ixgbe_write_i2c_byte_generic_unlocked(struct ixgbe_hw *hw, u8 byte_offset,
  *  Sets I2C start condition (High -> Low on SDA while SCL is High)
  *  Set bit-bang mode on X550 hardware.
  **/
-static void ixgbe_i2c_start(struct ixgbe_hw *hw)
+STATIC void ixgbe_i2c_start(struct ixgbe_hw *hw)
 {
-	u32 i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL(hw));
+	u32 i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL_BY_MAC(hw));
+
+	DEBUGFUNC("ixgbe_i2c_start");
 
-	i2cctl |= IXGBE_I2C_BB_EN(hw);
+	i2cctl |= IXGBE_I2C_BB_EN_BY_MAC(hw);
 
 	/* Start condition must begin with data and clock high */
 	ixgbe_set_i2c_data(hw, &i2cctl, 1);
 	ixgbe_raise_i2c_clk(hw, &i2cctl);
 
 	/* Setup time for start condition (4.7us) */
-	udelay(IXGBE_I2C_T_SU_STA);
+	usec_delay(IXGBE_I2C_T_SU_STA);
 
 	ixgbe_set_i2c_data(hw, &i2cctl, 0);
 
 	/* Hold time for start condition (4us) */
-	udelay(IXGBE_I2C_T_HD_STA);
+	usec_delay(IXGBE_I2C_T_HD_STA);
 
 	ixgbe_lower_i2c_clk(hw, &i2cctl);
 
 	/* Minimum low period of clock is 4.7 us */
-	udelay(IXGBE_I2C_T_LOW);
+	usec_delay(IXGBE_I2C_T_LOW);
 
 }
 
@@ -2007,29 +2239,31 @@ static void ixgbe_i2c_start(struct ixgbe_hw *hw)
  *  Disables bit-bang mode and negates data output enable on X550
  *  hardware.
  **/
-static void ixgbe_i2c_stop(struct ixgbe_hw *hw)
+STATIC void ixgbe_i2c_stop(struct ixgbe_hw *hw)
 {
-	u32 i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL(hw));
-	u32 data_oe_bit = IXGBE_I2C_DATA_OE_N_EN(hw);
-	u32 clk_oe_bit = IXGBE_I2C_CLK_OE_N_EN(hw);
-	u32 bb_en_bit = IXGBE_I2C_BB_EN(hw);
+	u32 i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL_BY_MAC(hw));
+	u32 data_oe_bit = IXGBE_I2C_DATA_OE_N_EN_BY_MAC(hw);
+	u32 clk_oe_bit = IXGBE_I2C_CLK_OE_N_EN_BY_MAC(hw);
+	u32 bb_en_bit = IXGBE_I2C_BB_EN_BY_MAC(hw);
+
+	DEBUGFUNC("ixgbe_i2c_stop");
 
 	/* Stop condition must begin with data low and clock high */
 	ixgbe_set_i2c_data(hw, &i2cctl, 0);
 	ixgbe_raise_i2c_clk(hw, &i2cctl);
 
 	/* Setup time for stop condition (4us) */
-	udelay(IXGBE_I2C_T_SU_STO);
+	usec_delay(IXGBE_I2C_T_SU_STO);
 
 	ixgbe_set_i2c_data(hw, &i2cctl, 1);
 
 	/* bus free time between stop and start (4.7us)*/
-	udelay(IXGBE_I2C_T_BUF);
+	usec_delay(IXGBE_I2C_T_BUF);
 
 	if (bb_en_bit || data_oe_bit || clk_oe_bit) {
 		i2cctl &= ~bb_en_bit;
 		i2cctl |= data_oe_bit | clk_oe_bit;
-		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL(hw), i2cctl);
+		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL_BY_MAC(hw), i2cctl);
 		IXGBE_WRITE_FLUSH(hw);
 	}
 }
@@ -2041,10 +2275,12 @@ static void ixgbe_i2c_stop(struct ixgbe_hw *hw)
  *
  *  Clocks in one byte data via I2C data/clock
  **/
-static s32 ixgbe_clock_in_i2c_byte(struct ixgbe_hw *hw, u8 *data)
+STATIC s32 ixgbe_clock_in_i2c_byte(struct ixgbe_hw *hw, u8 *data)
 {
 	s32 i;
-	bool bit = false;
+	bool bit = 0;
+
+	DEBUGFUNC("ixgbe_clock_in_i2c_byte");
 
 	*data = 0;
 	for (i = 7; i >= 0; i--) {
@@ -2052,7 +2288,7 @@ static s32 ixgbe_clock_in_i2c_byte(struct ixgbe_hw *hw, u8 *data)
 		*data |= bit << i;
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2062,26 +2298,28 @@ static s32 ixgbe_clock_in_i2c_byte(struct ixgbe_hw *hw, u8 *data)
  *
  *  Clocks out one byte data via I2C data/clock
  **/
-static s32 ixgbe_clock_out_i2c_byte(struct ixgbe_hw *hw, u8 data)
+STATIC s32 ixgbe_clock_out_i2c_byte(struct ixgbe_hw *hw, u8 data)
 {
-	s32 status;
+	s32 status = IXGBE_SUCCESS;
 	s32 i;
 	u32 i2cctl;
-	bool bit = false;
+	bool bit;
+
+	DEBUGFUNC("ixgbe_clock_out_i2c_byte");
 
 	for (i = 7; i >= 0; i--) {
 		bit = (data >> i) & 0x1;
 		status = ixgbe_clock_out_i2c_bit(hw, bit);
 
-		if (status != 0)
+		if (status != IXGBE_SUCCESS)
 			break;
 	}
 
 	/* Release SDA line (set high) */
-	i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL(hw));
-	i2cctl |= IXGBE_I2C_DATA_OUT(hw);
-	i2cctl |= IXGBE_I2C_DATA_OE_N_EN(hw);
-	IXGBE_WRITE_REG(hw, IXGBE_I2CCTL(hw), i2cctl);
+	i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL_BY_MAC(hw));
+	i2cctl |= IXGBE_I2C_DATA_OUT_BY_MAC(hw);
+	i2cctl |= IXGBE_I2C_DATA_OE_N_EN_BY_MAC(hw);
+	IXGBE_WRITE_REG(hw, IXGBE_I2CCTL_BY_MAC(hw), i2cctl);
 	IXGBE_WRITE_FLUSH(hw);
 
 	return status;
@@ -2093,46 +2331,48 @@ static s32 ixgbe_clock_out_i2c_byte(struct ixgbe_hw *hw, u8 data)
  *
  *  Clocks in/out one bit via I2C data/clock
  **/
-static s32 ixgbe_get_i2c_ack(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_get_i2c_ack(struct ixgbe_hw *hw)
 {
-	u32 data_oe_bit = IXGBE_I2C_DATA_OE_N_EN(hw);
-	s32 status = 0;
+	u32 data_oe_bit = IXGBE_I2C_DATA_OE_N_EN_BY_MAC(hw);
+	s32 status = IXGBE_SUCCESS;
 	u32 i = 0;
-	u32 i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL(hw));
+	u32 i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL_BY_MAC(hw));
 	u32 timeout = 10;
-	bool ack = true;
+	bool ack = 1;
+
+	DEBUGFUNC("ixgbe_get_i2c_ack");
 
 	if (data_oe_bit) {
-		i2cctl |= IXGBE_I2C_DATA_OUT(hw);
+		i2cctl |= IXGBE_I2C_DATA_OUT_BY_MAC(hw);
 		i2cctl |= data_oe_bit;
-		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL(hw), i2cctl);
+		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL_BY_MAC(hw), i2cctl);
 		IXGBE_WRITE_FLUSH(hw);
 	}
 	ixgbe_raise_i2c_clk(hw, &i2cctl);
 
 	/* Minimum high period of clock is 4us */
-	udelay(IXGBE_I2C_T_HIGH);
+	usec_delay(IXGBE_I2C_T_HIGH);
 
 	/* Poll for ACK.  Note that ACK in I2C spec is
 	 * transition from 1 to 0 */
 	for (i = 0; i < timeout; i++) {
-		i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL(hw));
+		i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL_BY_MAC(hw));
 		ack = ixgbe_get_i2c_data(hw, &i2cctl);
 
-		udelay(1);
-		if (ack == 0)
+		usec_delay(1);
+		if (!ack)
 			break;
 	}
 
-	if (ack == 1) {
-		hw_dbg(hw, "I2C ack was not received.\n");
+	if (ack) {
+		DEBUGOUT("I2C ack was not received.\n");
 		status = IXGBE_ERR_I2C;
 	}
 
 	ixgbe_lower_i2c_clk(hw, &i2cctl);
 
 	/* Minimum low period of clock is 4.7 us */
-	udelay(IXGBE_I2C_T_LOW);
+	usec_delay(IXGBE_I2C_T_LOW);
 
 	return status;
 }
@@ -2144,31 +2384,33 @@ static s32 ixgbe_get_i2c_ack(struct ixgbe_hw *hw)
  *
  *  Clocks in one bit via I2C data/clock
  **/
-static s32 ixgbe_clock_in_i2c_bit(struct ixgbe_hw *hw, bool *data)
+STATIC s32 ixgbe_clock_in_i2c_bit(struct ixgbe_hw *hw, bool *data)
 {
-	u32 i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL(hw));
-	u32 data_oe_bit = IXGBE_I2C_DATA_OE_N_EN(hw);
+	u32 i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL_BY_MAC(hw));
+	u32 data_oe_bit = IXGBE_I2C_DATA_OE_N_EN_BY_MAC(hw);
+
+	DEBUGFUNC("ixgbe_clock_in_i2c_bit");
 
 	if (data_oe_bit) {
-		i2cctl |= IXGBE_I2C_DATA_OUT(hw);
+		i2cctl |= IXGBE_I2C_DATA_OUT_BY_MAC(hw);
 		i2cctl |= data_oe_bit;
-		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL(hw), i2cctl);
+		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL_BY_MAC(hw), i2cctl);
 		IXGBE_WRITE_FLUSH(hw);
 	}
 	ixgbe_raise_i2c_clk(hw, &i2cctl);
 
 	/* Minimum high period of clock is 4us */
-	udelay(IXGBE_I2C_T_HIGH);
+	usec_delay(IXGBE_I2C_T_HIGH);
 
-	i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL(hw));
+	i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL_BY_MAC(hw));
 	*data = ixgbe_get_i2c_data(hw, &i2cctl);
 
 	ixgbe_lower_i2c_clk(hw, &i2cctl);
 
 	/* Minimum low period of clock is 4.7 us */
-	udelay(IXGBE_I2C_T_LOW);
+	usec_delay(IXGBE_I2C_T_LOW);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -2178,31 +2420,35 @@ static s32 ixgbe_clock_in_i2c_bit(struct ixgbe_hw *hw, bool *data)
  *
  *  Clocks out one bit via I2C data/clock
  **/
-static s32 ixgbe_clock_out_i2c_bit(struct ixgbe_hw *hw, bool data)
+STATIC s32 ixgbe_clock_out_i2c_bit(struct ixgbe_hw *hw, bool data)
 {
 	s32 status;
-	u32 i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL(hw));
+	u32 i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL_BY_MAC(hw));
+
+	DEBUGFUNC("ixgbe_clock_out_i2c_bit");
 
 	status = ixgbe_set_i2c_data(hw, &i2cctl, data);
-	if (status == 0) {
+	if (status == IXGBE_SUCCESS) {
 		ixgbe_raise_i2c_clk(hw, &i2cctl);
 
 		/* Minimum high period of clock is 4us */
-		udelay(IXGBE_I2C_T_HIGH);
+		usec_delay(IXGBE_I2C_T_HIGH);
 
 		ixgbe_lower_i2c_clk(hw, &i2cctl);
 
 		/* Minimum low period of clock is 4.7 us.
 		 * This also takes care of the data hold time.
 		 */
-		udelay(IXGBE_I2C_T_LOW);
+		usec_delay(IXGBE_I2C_T_LOW);
 	} else {
-		hw_dbg(hw, "I2C data was not set to %X\n", data);
-		return IXGBE_ERR_I2C;
+		status = IXGBE_ERR_I2C;
+		ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+			     "I2C data was not set to %X\n", data);
 	}
 
-	return 0;
+	return status;
 }
+
 /**
  *  ixgbe_raise_i2c_clk - Raises the I2C SCL clock
  *  @hw: pointer to hardware structure
@@ -2211,27 +2457,30 @@ static s32 ixgbe_clock_out_i2c_bit(struct ixgbe_hw *hw, bool data)
  *  Raises the I2C clock line '0'->'1'
  *  Negates the I2C clock output enable on X550 hardware.
  **/
-static void ixgbe_raise_i2c_clk(struct ixgbe_hw *hw, u32 *i2cctl)
+STATIC void ixgbe_raise_i2c_clk(struct ixgbe_hw *hw, u32 *i2cctl)
 {
-	u32 clk_oe_bit = IXGBE_I2C_CLK_OE_N_EN(hw);
+	u32 clk_oe_bit = IXGBE_I2C_CLK_OE_N_EN_BY_MAC(hw);
 	u32 i = 0;
 	u32 timeout = IXGBE_I2C_CLOCK_STRETCHING_TIMEOUT;
 	u32 i2cctl_r = 0;
 
+	DEBUGFUNC("ixgbe_raise_i2c_clk");
+
 	if (clk_oe_bit) {
 		*i2cctl |= clk_oe_bit;
-		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL(hw), *i2cctl);
+		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL_BY_MAC(hw), *i2cctl);
 	}
 
 	for (i = 0; i < timeout; i++) {
-		*i2cctl |= IXGBE_I2C_CLK_OUT(hw);
-		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL(hw), *i2cctl);
+		*i2cctl |= IXGBE_I2C_CLK_OUT_BY_MAC(hw);
+
+		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL_BY_MAC(hw), *i2cctl);
 		IXGBE_WRITE_FLUSH(hw);
 		/* SCL rise time (1000ns) */
-		udelay(IXGBE_I2C_T_RISE);
+		usec_delay(IXGBE_I2C_T_RISE);
 
-		i2cctl_r = IXGBE_READ_REG(hw, IXGBE_I2CCTL(hw));
-		if (i2cctl_r & IXGBE_I2C_CLK_IN(hw))
+		i2cctl_r = IXGBE_READ_REG(hw, IXGBE_I2CCTL_BY_MAC(hw));
+		if (i2cctl_r & IXGBE_I2C_CLK_IN_BY_MAC(hw))
 			break;
 	}
 }
@@ -2244,17 +2493,18 @@ static void ixgbe_raise_i2c_clk(struct ixgbe_hw *hw, u32 *i2cctl)
  *  Lowers the I2C clock line '1'->'0'
  *  Asserts the I2C clock output enable on X550 hardware.
  **/
-static void ixgbe_lower_i2c_clk(struct ixgbe_hw *hw, u32 *i2cctl)
+STATIC void ixgbe_lower_i2c_clk(struct ixgbe_hw *hw, u32 *i2cctl)
 {
+	DEBUGFUNC("ixgbe_lower_i2c_clk");
 
-	*i2cctl &= ~IXGBE_I2C_CLK_OUT(hw);
-	*i2cctl &= ~IXGBE_I2C_CLK_OE_N_EN(hw);
+	*i2cctl &= ~(IXGBE_I2C_CLK_OUT_BY_MAC(hw));
+	*i2cctl &= ~IXGBE_I2C_CLK_OE_N_EN_BY_MAC(hw);
 
-	IXGBE_WRITE_REG(hw, IXGBE_I2CCTL(hw), *i2cctl);
+	IXGBE_WRITE_REG(hw, IXGBE_I2CCTL_BY_MAC(hw), *i2cctl);
 	IXGBE_WRITE_FLUSH(hw);
 
 	/* SCL fall time (300ns) */
-	udelay(IXGBE_I2C_T_FALL);
+	usec_delay(IXGBE_I2C_T_FALL);
 }
 
 /**
@@ -2266,38 +2516,43 @@ static void ixgbe_lower_i2c_clk(struct ixgbe_hw *hw, u32 *i2cctl)
  *  Sets the I2C data bit
  *  Asserts the I2C data output enable on X550 hardware.
  **/
-static s32 ixgbe_set_i2c_data(struct ixgbe_hw *hw, u32 *i2cctl, bool data)
+STATIC s32 ixgbe_set_i2c_data(struct ixgbe_hw *hw, u32 *i2cctl, bool data)
 {
-	u32 data_oe_bit = IXGBE_I2C_DATA_OE_N_EN(hw);
+	u32 data_oe_bit = IXGBE_I2C_DATA_OE_N_EN_BY_MAC(hw);
+	s32 status = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_set_i2c_data");
 
 	if (data)
-		*i2cctl |= IXGBE_I2C_DATA_OUT(hw);
+		*i2cctl |= IXGBE_I2C_DATA_OUT_BY_MAC(hw);
 	else
-		*i2cctl &= ~IXGBE_I2C_DATA_OUT(hw);
+		*i2cctl &= ~(IXGBE_I2C_DATA_OUT_BY_MAC(hw));
 	*i2cctl &= ~data_oe_bit;
 
-	IXGBE_WRITE_REG(hw, IXGBE_I2CCTL(hw), *i2cctl);
+	IXGBE_WRITE_REG(hw, IXGBE_I2CCTL_BY_MAC(hw), *i2cctl);
 	IXGBE_WRITE_FLUSH(hw);
 
 	/* Data rise/fall (1000ns/300ns) and set-up time (250ns) */
-	udelay(IXGBE_I2C_T_RISE + IXGBE_I2C_T_FALL + IXGBE_I2C_T_SU_DATA);
+	usec_delay(IXGBE_I2C_T_RISE + IXGBE_I2C_T_FALL + IXGBE_I2C_T_SU_DATA);
 
 	if (!data)	/* Can't verify data in this case */
-		return 0;
+		return IXGBE_SUCCESS;
 	if (data_oe_bit) {
 		*i2cctl |= data_oe_bit;
-		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL(hw), *i2cctl);
+		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL_BY_MAC(hw), *i2cctl);
 		IXGBE_WRITE_FLUSH(hw);
 	}
 
 	/* Verify data was set correctly */
-	*i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL(hw));
+	*i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL_BY_MAC(hw));
 	if (data != ixgbe_get_i2c_data(hw, i2cctl)) {
-		hw_dbg(hw, "Error - I2C data was not set to %X.\n", data);
-		return IXGBE_ERR_I2C;
+		status = IXGBE_ERR_I2C;
+		ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+			     "Error - I2C data was not set to %X.\n",
+			     data);
 	}
 
-	return 0;
+	return status;
 }
 
 /**
@@ -2308,20 +2563,26 @@ static s32 ixgbe_set_i2c_data(struct ixgbe_hw *hw, u32 *i2cctl, bool data)
  *  Returns the I2C data bit value
  *  Negates the I2C data output enable on X550 hardware.
  **/
-static bool ixgbe_get_i2c_data(struct ixgbe_hw *hw, u32 *i2cctl)
+STATIC bool ixgbe_get_i2c_data(struct ixgbe_hw *hw, u32 *i2cctl)
 {
-	u32 data_oe_bit = IXGBE_I2C_DATA_OE_N_EN(hw);
+	u32 data_oe_bit = IXGBE_I2C_DATA_OE_N_EN_BY_MAC(hw);
+	bool data;
+
+	DEBUGFUNC("ixgbe_get_i2c_data");
 
 	if (data_oe_bit) {
 		*i2cctl |= data_oe_bit;
-		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL(hw), *i2cctl);
+		IXGBE_WRITE_REG(hw, IXGBE_I2CCTL_BY_MAC(hw), *i2cctl);
 		IXGBE_WRITE_FLUSH(hw);
-		udelay(IXGBE_I2C_T_FALL);
+		usec_delay(IXGBE_I2C_T_FALL);
 	}
 
-	if (*i2cctl & IXGBE_I2C_DATA_IN(hw))
-		return true;
-	return false;
+	if (*i2cctl & IXGBE_I2C_DATA_IN_BY_MAC(hw))
+		data = 1;
+	else
+		data = 0;
+
+	return data;
 }
 
 /**
@@ -2331,13 +2592,15 @@ static bool ixgbe_get_i2c_data(struct ixgbe_hw *hw, u32 *i2cctl)
  *  Clears the I2C bus by sending nine clock pulses.
  *  Used when data line is stuck low.
  **/
-static void ixgbe_i2c_bus_clear(struct ixgbe_hw *hw)
+void ixgbe_i2c_bus_clear(struct ixgbe_hw *hw)
 {
 	u32 i2cctl;
 	u32 i;
 
+	DEBUGFUNC("ixgbe_i2c_bus_clear");
+
 	ixgbe_i2c_start(hw);
-	i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL(hw));
+	i2cctl = IXGBE_READ_REG(hw, IXGBE_I2CCTL_BY_MAC(hw));
 
 	ixgbe_set_i2c_data(hw, &i2cctl, 1);
 
@@ -2345,12 +2608,12 @@ static void ixgbe_i2c_bus_clear(struct ixgbe_hw *hw)
 		ixgbe_raise_i2c_clk(hw, &i2cctl);
 
 		/* Min high period of clock is 4us */
-		udelay(IXGBE_I2C_T_HIGH);
+		usec_delay(IXGBE_I2C_T_HIGH);
 
 		ixgbe_lower_i2c_clk(hw, &i2cctl);
 
 		/* Min low period of clock is 4.7us*/
-		udelay(IXGBE_I2C_T_LOW);
+		usec_delay(IXGBE_I2C_T_LOW);
 	}
 
 	ixgbe_i2c_start(hw);
@@ -2367,32 +2630,38 @@ static void ixgbe_i2c_bus_clear(struct ixgbe_hw *hw)
  **/
 s32 ixgbe_tn_check_overtemp(struct ixgbe_hw *hw)
 {
+	s32 status = IXGBE_SUCCESS;
 	u16 phy_data = 0;
 
+	DEBUGFUNC("ixgbe_tn_check_overtemp");
+
 	if (hw->device_id != IXGBE_DEV_ID_82599_T3_LOM)
-		return 0;
+		goto out;
 
 	/* Check that the LASI temp alarm status was triggered */
 	hw->phy.ops.read_reg(hw, IXGBE_TN_LASI_STATUS_REG,
-			     MDIO_MMD_PMAPMD, &phy_data);
+			     IXGBE_MDIO_PMA_PMD_DEV_TYPE, &phy_data);
 
 	if (!(phy_data & IXGBE_TN_LASI_STATUS_TEMP_ALARM))
-		return 0;
+		goto out;
 
-	return IXGBE_ERR_OVERTEMP;
+	status = IXGBE_ERR_OVERTEMP;
+	ERROR_REPORT1(IXGBE_ERROR_CAUTION, "Device over temperature");
+out:
+	return status;
 }
 
-/** ixgbe_set_copper_phy_power - Control power for copper phy
- *  @hw: pointer to hardware structure
- *  @on: true for on, false for off
- **/
+/**
+ * ixgbe_set_copper_phy_power - Control power for copper phy
+ * @hw: pointer to hardware structure
+ * @on: true for on, false for off
+ */
 s32 ixgbe_set_copper_phy_power(struct ixgbe_hw *hw, bool on)
 {
 	u32 status;
 	u16 reg;
 
-	/* Bail if we don't have copper phy */
-	if (hw->mac.ops.get_media_type(hw) != ixgbe_media_type_copper)
+	if (!on && ixgbe_mng_present(hw))
 		return 0;
 
 	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_VENDOR_SPECIFIC_1_CONTROL,
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_phy.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_phy.h
index 5abd66c..445394f 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_phy.h
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_phy.h
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -30,8 +26,9 @@
 #define _IXGBE_PHY_H_
 
 #include "ixgbe_type.h"
-#define IXGBE_I2C_EEPROM_DEV_ADDR    0xA0
-#define IXGBE_I2C_EEPROM_DEV_ADDR2   0xA2
+#define IXGBE_I2C_EEPROM_DEV_ADDR	0xA0
+#define IXGBE_I2C_EEPROM_DEV_ADDR2	0xA2
+#define IXGBE_I2C_EEPROM_BANK_LEN	0xFF
 
 /* EEPROM byte offsets */
 #define IXGBE_SFF_IDENTIFIER		0x0
@@ -58,98 +55,111 @@
 #define IXGBE_SFF_QSFP_DEVICE_TECH	0x93
 
 /* Bitmasks */
-#define IXGBE_SFF_DA_PASSIVE_CABLE		0x4
-#define IXGBE_SFF_DA_ACTIVE_CABLE		0x8
+#define IXGBE_SFF_DA_PASSIVE_CABLE	0x4
+#define IXGBE_SFF_DA_ACTIVE_CABLE	0x8
 #define IXGBE_SFF_DA_SPEC_ACTIVE_LIMITING	0x4
-#define IXGBE_SFF_1GBASESX_CAPABLE		0x1
-#define IXGBE_SFF_1GBASELX_CAPABLE		0x2
-#define IXGBE_SFF_1GBASET_CAPABLE		0x8
-#define IXGBE_SFF_10GBASESR_CAPABLE		0x10
-#define IXGBE_SFF_10GBASELR_CAPABLE		0x20
-#define IXGBE_SFF_SOFT_RS_SELECT_MASK		0x8
-#define IXGBE_SFF_SOFT_RS_SELECT_10G		0x8
-#define IXGBE_SFF_SOFT_RS_SELECT_1G		0x0
-#define IXGBE_SFF_ADDRESSING_MODE		0x4
-#define IXGBE_SFF_QSFP_DA_ACTIVE_CABLE		0x1
-#define IXGBE_SFF_QSFP_DA_PASSIVE_CABLE		0x8
+#define IXGBE_SFF_1GBASESX_CAPABLE	0x1
+#define IXGBE_SFF_1GBASELX_CAPABLE	0x2
+#define IXGBE_SFF_1GBASET_CAPABLE	0x8
+#define IXGBE_SFF_10GBASESR_CAPABLE	0x10
+#define IXGBE_SFF_10GBASELR_CAPABLE	0x20
+#define IXGBE_SFF_SOFT_RS_SELECT_MASK	0x8
+#define IXGBE_SFF_SOFT_RS_SELECT_10G	0x8
+#define IXGBE_SFF_SOFT_RS_SELECT_1G	0x0
+#define IXGBE_SFF_ADDRESSING_MODE	0x4
+#define IXGBE_SFF_QSFP_DA_ACTIVE_CABLE	0x1
+#define IXGBE_SFF_QSFP_DA_PASSIVE_CABLE	0x8
 #define IXGBE_SFF_QSFP_CONNECTOR_NOT_SEPARABLE	0x23
 #define IXGBE_SFF_QSFP_TRANSMITER_850NM_VCSEL	0x0
-#define IXGBE_I2C_EEPROM_READ_MASK		0x100
-#define IXGBE_I2C_EEPROM_STATUS_MASK		0x3
+#define IXGBE_I2C_EEPROM_READ_MASK	0x100
+#define IXGBE_I2C_EEPROM_STATUS_MASK	0x3
 #define IXGBE_I2C_EEPROM_STATUS_NO_OPERATION	0x0
-#define IXGBE_I2C_EEPROM_STATUS_PASS		0x1
-#define IXGBE_I2C_EEPROM_STATUS_FAIL		0x2
+#define IXGBE_I2C_EEPROM_STATUS_PASS	0x1
+#define IXGBE_I2C_EEPROM_STATUS_FAIL	0x2
 #define IXGBE_I2C_EEPROM_STATUS_IN_PROGRESS	0x3
-#define IXGBE_CS4227				0xBE    /* CS4227 address */
-#define IXGBE_CS4227_SCRATCH			2
-#define IXGBE_CS4227_RESET_PENDING		0x1357
-#define IXGBE_CS4227_RESET_COMPLETE		0x5AA5
-#define IXGBE_CS4227_RETRIES			15
-#define IXGBE_CS4227_EFUSE_STATUS		0x0181
-#define IXGBE_CS4227_LINE_SPARE22_MSB		0x12AD	/* Reg to set speed */
-#define IXGBE_CS4227_LINE_SPARE24_LSB		0x12B0	/* Reg to set EDC */
-#define IXGBE_CS4227_HOST_SPARE22_MSB		0x1AAD	/* Reg to set speed */
-#define IXGBE_CS4227_HOST_SPARE24_LSB		0x1AB0	/* Reg to program EDC */
-#define IXGBE_CS4227_EEPROM_STATUS		0x5001
-#define IXGBE_CS4227_EEPROM_LOAD_OK		0x0001
-#define IXGBE_CS4227_SPEED_1G			0x8000
-#define IXGBE_CS4227_SPEED_10G			0
-#define IXGBE_CS4227_EDC_MODE_CX1		0x0002
-#define IXGBE_CS4227_EDC_MODE_SR		0x0004
-#define IXGBE_CS4227_EDC_MODE_DIAG		0x0008
-#define IXGBE_CS4227_RESET_HOLD			500	/* microseconds */
-#define IXGBE_CS4227_RESET_DELAY		500	/* milliseconds */
-#define IXGBE_CS4227_CHECK_DELAY		30	/* milliseconds */
-#define IXGBE_PE				0xE0	/* Port expander addr */
-#define IXGBE_PE_OUTPUT				1	/* Output reg offset */
-#define IXGBE_PE_CONFIG				3	/* Config reg offset */
-#define IXGBE_PE_BIT1				(1 << 1)
+
+#define IXGBE_CS4227			0xBE	/* CS4227 address */
+#define IXGBE_CS4227_GLOBAL_ID_LSB	0
+#define IXGBE_CS4227_GLOBAL_ID_MSB	1
+#define IXGBE_CS4227_SCRATCH		2
+#define IXGBE_CS4227_GLOBAL_ID_VALUE	0x03E5
+#define IXGBE_CS4227_EFUSE_PDF_SKU	0x19F
+#define IXGBE_CS4223_SKU_ID		0x0010	/* Quad port */
+#define IXGBE_CS4227_SKU_ID		0x0014	/* Dual port */
+#define IXGBE_CS4227_RESET_PENDING	0x1357
+#define IXGBE_CS4227_RESET_COMPLETE	0x5AA5
+#define IXGBE_CS4227_RETRIES		15
+#define IXGBE_CS4227_EFUSE_STATUS	0x0181
+#define IXGBE_CS4227_LINE_SPARE22_MSB	0x12AD	/* Reg to program speed */
+#define IXGBE_CS4227_LINE_SPARE24_LSB	0x12B0	/* Reg to program EDC */
+#define IXGBE_CS4227_HOST_SPARE22_MSB	0x1AAD	/* Reg to program speed */
+#define IXGBE_CS4227_HOST_SPARE24_LSB	0x1AB0	/* Reg to program EDC */
+#define IXGBE_CS4227_EEPROM_STATUS	0x5001
+#define IXGBE_CS4227_EEPROM_LOAD_OK	0x0001
+#define IXGBE_CS4227_SPEED_1G		0x8000
+#define IXGBE_CS4227_SPEED_10G		0
+#define IXGBE_CS4227_EDC_MODE_CX1	0x0002
+#define IXGBE_CS4227_EDC_MODE_SR	0x0004
+#define IXGBE_CS4227_EDC_MODE_DIAG	0x0008
+#define IXGBE_CS4227_RESET_HOLD		500	/* microseconds */
+#define IXGBE_CS4227_RESET_DELAY	450	/* milliseconds */
+#define IXGBE_CS4227_CHECK_DELAY	30	/* milliseconds */
+#define IXGBE_PE			0xE0	/* Port expander address */
+#define IXGBE_PE_OUTPUT			1	/* Output register offset */
+#define IXGBE_PE_CONFIG			3	/* Config register offset */
+#define IXGBE_PE_BIT1			(1 << 1)
 
 /* Flow control defines */
-#define IXGBE_TAF_SYM_PAUSE                  0x400
-#define IXGBE_TAF_ASM_PAUSE                  0x800
+#define IXGBE_TAF_SYM_PAUSE		0x400
+#define IXGBE_TAF_ASM_PAUSE		0x800
 
 /* Bit-shift macros */
-#define IXGBE_SFF_VENDOR_OUI_BYTE0_SHIFT    24
-#define IXGBE_SFF_VENDOR_OUI_BYTE1_SHIFT    16
-#define IXGBE_SFF_VENDOR_OUI_BYTE2_SHIFT    8
+#define IXGBE_SFF_VENDOR_OUI_BYTE0_SHIFT	24
+#define IXGBE_SFF_VENDOR_OUI_BYTE1_SHIFT	16
+#define IXGBE_SFF_VENDOR_OUI_BYTE2_SHIFT	8
 
 /* Vendor OUIs: format of OUI is 0x[byte0][byte1][byte2][00] */
-#define IXGBE_SFF_VENDOR_OUI_TYCO     0x00407600
-#define IXGBE_SFF_VENDOR_OUI_FTL      0x00906500
-#define IXGBE_SFF_VENDOR_OUI_AVAGO    0x00176A00
-#define IXGBE_SFF_VENDOR_OUI_INTEL    0x001B2100
+#define IXGBE_SFF_VENDOR_OUI_TYCO	0x00407600
+#define IXGBE_SFF_VENDOR_OUI_FTL	0x00906500
+#define IXGBE_SFF_VENDOR_OUI_AVAGO	0x00176A00
+#define IXGBE_SFF_VENDOR_OUI_INTEL	0x001B2100
 
 /* I2C SDA and SCL timing parameters for standard mode */
-#define IXGBE_I2C_T_HD_STA  4
-#define IXGBE_I2C_T_LOW     5
-#define IXGBE_I2C_T_HIGH    4
-#define IXGBE_I2C_T_SU_STA  5
-#define IXGBE_I2C_T_HD_DATA 5
-#define IXGBE_I2C_T_SU_DATA 1
-#define IXGBE_I2C_T_RISE    1
-#define IXGBE_I2C_T_FALL    1
-#define IXGBE_I2C_T_SU_STO  4
-#define IXGBE_I2C_T_BUF     5
-
-#define IXGBE_SFP_DETECT_RETRIES	2
-
-#define IXGBE_TN_LASI_STATUS_REG        0x9005
-#define IXGBE_TN_LASI_STATUS_TEMP_ALARM 0x0008
-
-/* SFP+ SFF-8472 Compliance code */
-#define IXGBE_SFF_SFF_8472_UNSUP      0x00
-
+#define IXGBE_I2C_T_HD_STA	4
+#define IXGBE_I2C_T_LOW		5
+#define IXGBE_I2C_T_HIGH	4
+#define IXGBE_I2C_T_SU_STA	5
+#define IXGBE_I2C_T_HD_DATA	5
+#define IXGBE_I2C_T_SU_DATA	1
+#define IXGBE_I2C_T_RISE	1
+#define IXGBE_I2C_T_FALL	1
+#define IXGBE_I2C_T_SU_STO	4
+#define IXGBE_I2C_T_BUF		5
+
+#ifndef IXGBE_SFP_DETECT_RETRIES
+#define IXGBE_SFP_DETECT_RETRIES	10
+
+#endif /* IXGBE_SFP_DETECT_RETRIES */
+#define IXGBE_TN_LASI_STATUS_REG	0x9005
+#define IXGBE_TN_LASI_STATUS_TEMP_ALARM	0x0008
+
+/* SFP+ SFF-8472 Compliance */
+#define IXGBE_SFF_SFF_8472_UNSUP	0x00
+
+s32 ixgbe_init_phy_ops_generic(struct ixgbe_hw *hw);
+bool ixgbe_validate_phy_addr(struct ixgbe_hw *hw, u32 phy_addr);
+enum ixgbe_phy_type ixgbe_get_phy_type_from_id(u32 phy_id);
+s32 ixgbe_get_phy_id(struct ixgbe_hw *hw);
 s32 ixgbe_identify_phy_generic(struct ixgbe_hw *hw);
 s32 ixgbe_reset_phy_generic(struct ixgbe_hw *hw);
+s32 ixgbe_read_phy_reg_mdi(struct ixgbe_hw *hw, u32 reg_addr, u32 device_type,
+			   u16 *phy_data);
+s32 ixgbe_write_phy_reg_mdi(struct ixgbe_hw *hw, u32 reg_addr, u32 device_type,
+			    u16 phy_data);
 s32 ixgbe_read_phy_reg_generic(struct ixgbe_hw *hw, u32 reg_addr,
 			       u32 device_type, u16 *phy_data);
 s32 ixgbe_write_phy_reg_generic(struct ixgbe_hw *hw, u32 reg_addr,
 				u32 device_type, u16 phy_data);
-s32 ixgbe_read_phy_reg_mdi(struct ixgbe_hw *hw, u32 reg_addr,
-			   u32 device_type, u16 *phy_data);
-s32 ixgbe_write_phy_reg_mdi(struct ixgbe_hw *hw, u32 reg_addr,
-			    u32 device_type, u16 phy_data);
 s32 ixgbe_setup_phy_link_generic(struct ixgbe_hw *hw);
 s32 ixgbe_setup_phy_link_speed_generic(struct ixgbe_hw *hw,
 				       ixgbe_link_speed speed,
@@ -157,7 +167,7 @@ s32 ixgbe_setup_phy_link_speed_generic(struct ixgbe_hw *hw,
 s32 ixgbe_get_copper_link_capabilities_generic(struct ixgbe_hw *hw,
 					       ixgbe_link_speed *speed,
 					       bool *autoneg);
-bool ixgbe_check_reset_blocked(struct ixgbe_hw *hw);
+s32 ixgbe_check_reset_blocked(struct ixgbe_hw *hw);
 
 /* PHY specific */
 s32 ixgbe_check_phy_link_tnx(struct ixgbe_hw *hw,
@@ -173,6 +183,8 @@ s32 ixgbe_reset_phy_nl(struct ixgbe_hw *hw);
 s32 ixgbe_set_copper_phy_power(struct ixgbe_hw *hw, bool on);
 s32 ixgbe_identify_module_generic(struct ixgbe_hw *hw);
 s32 ixgbe_identify_sfp_module_generic(struct ixgbe_hw *hw);
+u64 ixgbe_get_supported_phy_sfp_layer_generic(struct ixgbe_hw *hw);
+s32 ixgbe_identify_qsfp_module_generic(struct ixgbe_hw *hw);
 s32 ixgbe_get_sfp_init_sequence_offsets(struct ixgbe_hw *hw,
 					u16 *list_offset,
 					u16 *data_offset);
@@ -187,16 +199,11 @@ s32 ixgbe_write_i2c_byte_generic_unlocked(struct ixgbe_hw *hw, u8 byte_offset,
 					  u8 dev_addr, u8 data);
 s32 ixgbe_read_i2c_eeprom_generic(struct ixgbe_hw *hw, u8 byte_offset,
 				  u8 *eeprom_data);
-s32 ixgbe_read_i2c_sff8472_generic(struct ixgbe_hw *hw, u8 byte_offset,
-				   u8 *sff8472_data);
 s32 ixgbe_write_i2c_eeprom_generic(struct ixgbe_hw *hw, u8 byte_offset,
 				   u8 eeprom_data);
-s32 ixgbe_read_i2c_combined_generic(struct ixgbe_hw *hw, u8 addr,
-				    u16 reg, u16 *val);
-s32 ixgbe_read_i2c_combined_generic_unlocked(struct ixgbe_hw *hw, u8 addr,
-					     u16 reg, u16 *val);
-s32 ixgbe_write_i2c_combined_generic(struct ixgbe_hw *hw, u8 addr,
-				     u16 reg, u16 val);
-s32 ixgbe_write_i2c_combined_generic_unlocked(struct ixgbe_hw *hw, u8 addr,
-					      u16 reg, u16 val);
+void ixgbe_i2c_bus_clear(struct ixgbe_hw *hw);
+s32 ixgbe_read_i2c_combined_generic_int(struct ixgbe_hw *, u8 addr, u16 reg,
+					u16 *val, bool lock);
+s32 ixgbe_write_i2c_combined_generic_int(struct ixgbe_hw *, u8 addr, u16 reg,
+					 u16 val, bool lock);
 #endif /* _IXGBE_PHY_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_procfs.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_procfs.c
new file mode 100644
index 00000000..54f0940
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_procfs.c
@@ -0,0 +1,938 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#include "ixgbe.h"
+#include "ixgbe_common.h"
+#include "ixgbe_type.h"
+
+#ifdef IXGBE_PROCFS
+#ifndef IXGBE_SYSFS
+
+#include <linux/module.h>
+#include <linux/types.h>
+#include <linux/proc_fs.h>
+#include <linux/device.h>
+#include <linux/netdevice.h>
+
+static struct proc_dir_entry *ixgbe_top_dir = NULL;
+
+static struct net_device_stats *procfs_get_stats(struct net_device *netdev)
+{
+#ifndef HAVE_NETDEV_STATS_IN_NETDEV
+	struct ixgbe_adapter *adapter;
+#endif
+	if (netdev == NULL)
+		return NULL;
+
+#ifdef HAVE_NETDEV_STATS_IN_NETDEV
+	/* only return the current stats */
+	return &netdev->stats;
+#else
+	adapter = netdev_priv(netdev);
+
+	/* only return the current stats */
+	return &adapter->net_stats;
+#endif /* HAVE_NETDEV_STATS_IN_NETDEV */
+}
+
+bool ixgbe_thermal_present(struct ixgbe_adapter *adapter)
+{
+	s32 status;
+	if (adapter == NULL)
+		return false;
+	status = ixgbe_init_thermal_sensor_thresh_generic(&(adapter->hw));
+	if (status != IXGBE_SUCCESS)
+		return false;
+
+	return true;
+}
+
+static int ixgbe_fwbanner(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+
+	return snprintf(page, count, "%s\n", adapter->eeprom_id);
+}
+
+static int ixgbe_porttype(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	return snprintf(page, count, "%d\n",
+			test_bit(__IXGBE_DOWN, &adapter->state));
+}
+
+static int ixgbe_portspeed(char *page, char __always_unused **start,
+			   off_t __always_unused off, int count,
+			   int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	int speed = 0;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+
+	switch (adapter->link_speed) {
+	case IXGBE_LINK_SPEED_100_FULL:
+		speed = 1;
+		break;
+	case IXGBE_LINK_SPEED_1GB_FULL:
+		speed = 10;
+		break;
+	case IXGBE_LINK_SPEED_10GB_FULL:
+		speed = 100;
+		break;
+	}
+	return snprintf(page, count, "%d\n", speed);
+}
+
+static int ixgbe_wqlflag(char *page, char __always_unused **start,
+			 off_t __always_unused off, int count,
+			 int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+
+	return snprintf(page, count, "%d\n", adapter->wol);
+}
+
+static int ixgbe_xflowctl(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct ixgbe_hw *hw;
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	return snprintf(page, count, "%d\n", hw->fc.current_mode);
+}
+
+static int ixgbe_rxdrops(char *page, char __always_unused **start,
+			 off_t __always_unused off, int count,
+			 int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct net_device_stats *net_stats;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	net_stats  = procfs_get_stats(adapter->netdev);
+	if (net_stats == NULL)
+		return snprintf(page, count, "error: no net stats\n");
+
+	return snprintf(page, count, "%lu\n",
+			net_stats->rx_dropped);
+}
+
+static int ixgbe_rxerrors(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct net_device_stats *net_stats;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	net_stats  = procfs_get_stats(adapter->netdev);
+	if (net_stats == NULL)
+		return snprintf(page, count, "error: no net stats\n");
+
+	return snprintf(page, count, "%lu\n", net_stats->rx_errors);
+}
+
+static int ixgbe_rxupacks(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_hw *hw;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	return snprintf(page, count, "%d\n", IXGBE_READ_REG(hw, IXGBE_TPR));
+}
+
+static int ixgbe_rxmpacks(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_hw *hw;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	return snprintf(page, count, "%d\n", IXGBE_READ_REG(hw, IXGBE_MPRC));
+}
+
+static int ixgbe_rxbpacks(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_hw *hw;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	return snprintf(page, count, "%d\n", IXGBE_READ_REG(hw, IXGBE_BPRC));
+}
+
+static int ixgbe_txupacks(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_hw *hw;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	return snprintf(page, count, "%d\n", IXGBE_READ_REG(hw, IXGBE_TPT));
+}
+
+static int ixgbe_txmpacks(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_hw *hw;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	return snprintf(page, count, "%d\n", IXGBE_READ_REG(hw, IXGBE_MPTC));
+}
+
+static int ixgbe_txbpacks(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_hw *hw;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	return snprintf(page, count, "%d\n", IXGBE_READ_REG(hw, IXGBE_BPTC));
+}
+
+static int ixgbe_txerrors(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct net_device_stats *net_stats;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	net_stats  = procfs_get_stats(adapter->netdev);
+	if (net_stats == NULL)
+		return snprintf(page, count, "error: no net stats\n");
+
+	return snprintf(page, count, "%lu\n",
+			net_stats->tx_errors);
+}
+
+static int ixgbe_txdrops(char *page, char __always_unused **start,
+			 off_t __always_unused off, int count,
+			 int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct net_device_stats *net_stats;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	net_stats  = procfs_get_stats(adapter->netdev);
+	if (net_stats == NULL)
+		return snprintf(page, count, "error: no net stats\n");
+
+	return snprintf(page, count, "%lu\n",
+			net_stats->tx_dropped);
+}
+
+static int ixgbe_rxframes(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct net_device_stats *net_stats;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	net_stats  = procfs_get_stats(adapter->netdev);
+	if (net_stats == NULL)
+		return snprintf(page, count, "error: no net stats\n");
+
+	return snprintf(page, count, "%lu\n",
+			net_stats->rx_packets);
+}
+
+static int ixgbe_rxbytes(char *page, char __always_unused **start,
+			 off_t __always_unused off, int count,
+			 int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct net_device_stats *net_stats;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	net_stats  = procfs_get_stats(adapter->netdev);
+	if (net_stats == NULL)
+		return snprintf(page, count, "error: no net stats\n");
+
+	return snprintf(page, count, "%lu\n",
+			net_stats->rx_bytes);
+}
+
+static int ixgbe_txframes(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct net_device_stats *net_stats;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	net_stats  = procfs_get_stats(adapter->netdev);
+	if (net_stats == NULL)
+		return snprintf(page, count, "error: no net stats\n");
+
+	return snprintf(page, count, "%lu\n",
+			net_stats->tx_packets);
+}
+
+static int ixgbe_txbytes(char *page, char __always_unused **start,
+			 off_t __always_unused off, int count,
+			 int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct net_device_stats *net_stats;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	net_stats  = procfs_get_stats(adapter->netdev);
+	if (net_stats == NULL)
+		return snprintf(page, count, "error: no net stats\n");
+
+	return snprintf(page, count, "%lu\n",
+			net_stats->tx_bytes);
+}
+
+static int ixgbe_linkstat(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_hw *hw;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	int bitmask = 0;
+	u32 link_speed;
+	bool link_up = false;
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	if (!test_bit(__IXGBE_DOWN, &adapter->state))
+		bitmask |= 1;
+
+	if (hw->mac.ops.check_link)
+		hw->mac.ops.check_link(hw, &link_speed, &link_up, false);
+	else
+		/* always assume link is up, if no check link function */
+		link_up = true;
+	if (link_up)
+		bitmask |= 2;
+
+	if (adapter->old_lsc != adapter->lsc_int) {
+		bitmask |= 4;
+		adapter->old_lsc = adapter->lsc_int;
+	}
+
+	return snprintf(page, count, "0x%X\n", bitmask);
+}
+
+static int ixgbe_funcid(char *page, char __always_unused **start,
+			off_t __always_unused off, int count,
+			int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct ixgbe_hw *hw;
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	return snprintf(page, count, "0x%X\n", hw->bus.func);
+}
+
+static int ixgbe_funcvers(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void __always_unused *data)
+{
+	return snprintf(page, count, "%s\n", ixgbe_driver_version);
+}
+
+static int ixgbe_macburn(char *page, char __always_unused **start,
+			 off_t __always_unused off, int count,
+			 int __always_unused *eof, void *data)
+{
+	struct ixgbe_hw *hw;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	return snprintf(page, count, "0x%02X%02X%02X%02X%02X%02X\n",
+		       (unsigned int)hw->mac.perm_addr[0],
+		       (unsigned int)hw->mac.perm_addr[1],
+		       (unsigned int)hw->mac.perm_addr[2],
+		       (unsigned int)hw->mac.perm_addr[3],
+		       (unsigned int)hw->mac.perm_addr[4],
+		       (unsigned int)hw->mac.perm_addr[5]);
+}
+
+static int ixgbe_macadmn(char *page, char __always_unused **start,
+			 off_t __always_unused off, int count,
+			 int __always_unused *eof, void *data)
+{
+	struct ixgbe_hw *hw;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	return snprintf(page, count, "0x%02X%02X%02X%02X%02X%02X\n",
+		       (unsigned int)hw->mac.addr[0],
+		       (unsigned int)hw->mac.addr[1],
+		       (unsigned int)hw->mac.addr[2],
+		       (unsigned int)hw->mac.addr[3],
+		       (unsigned int)hw->mac.addr[4],
+		       (unsigned int)hw->mac.addr[5]);
+}
+
+static int ixgbe_maclla1(char *page, char __always_unused **start,
+			 off_t __always_unused off, int count,
+			 int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct ixgbe_hw *hw;
+	int rc;
+	u16 eeprom_buff[6];
+	u16 first_word = 0x37;
+	const u16 word_count = ARRAY_SIZE(eeprom_buff);
+
+	if (!adapter)
+		return snprintf(page, count, "error: no adapter\n");
+
+	hw = &adapter->hw;
+
+	rc = hw->eeprom.ops.read_buffer(hw, first_word, 1, &first_word);
+	if (rc != 0)
+		return snprintf(page, count, "error: reading pointer to the EEPROM\n");
+
+	if (first_word != 0x0000 && first_word != 0xFFFF) {
+		rc = hw->eeprom.ops.read_buffer(hw, first_word, word_count,
+					eeprom_buff);
+		if (rc != 0)
+			return snprintf(page, count, "error: reading buffer\n");
+	} else {
+		memset(eeprom_buff, 0, sizeof(eeprom_buff));
+	}
+
+	switch (hw->bus.func) {
+	case 0:
+		return snprintf(page, count, "0x%04X%04X%04X\n",
+				eeprom_buff[0],
+				eeprom_buff[1],
+				eeprom_buff[2]);
+	case 1:
+		return snprintf(page, count, "0x%04X%04X%04X\n",
+				eeprom_buff[3],
+				eeprom_buff[4],
+				eeprom_buff[5]);
+	}
+	return snprintf(page, count, "unexpected port %d\n", hw->bus.func);
+}
+
+static int ixgbe_mtusize(char *page, char __always_unused **start,
+			 off_t __always_unused off, int count,
+			 int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct net_device *netdev;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	netdev = adapter->netdev;
+	if (netdev == NULL)
+		return snprintf(page, count, "error: no net device\n");
+
+	return snprintf(page, count, "%d\n", netdev->mtu);
+}
+
+static int ixgbe_featflag(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	int bitmask = 0;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct net_device *netdev;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	netdev = adapter->netdev;
+	if (netdev == NULL)
+		return snprintf(page, count, "error: no net device\n");
+	if (adapter->netdev->features & NETIF_F_RXCSUM)
+		bitmask |= 1;
+	return snprintf(page, count, "%d\n", bitmask);
+}
+
+static int ixgbe_lsominct(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void __always_unused *data)
+{
+	return snprintf(page, count, "%d\n", 1);
+}
+
+static int ixgbe_prommode(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	struct net_device *netdev;
+
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+	netdev = adapter->netdev;
+	if (netdev == NULL)
+		return snprintf(page, count, "error: no net device\n");
+
+	return snprintf(page, count, "%d\n",
+			netdev->flags & IFF_PROMISC);
+}
+
+static int ixgbe_txdscqsz(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+
+	return snprintf(page, count, "%d\n", adapter->tx_ring[0]->count);
+}
+
+static int ixgbe_rxdscqsz(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+
+	return snprintf(page, count, "%d\n", adapter->rx_ring[0]->count);
+}
+
+static int ixgbe_rxqavg(char *page, char __always_unused **start,
+			off_t __always_unused off, int count,
+			int __always_unused *eof, void *data)
+{
+	int index;
+	int diff = 0;
+	u16 ntc;
+	u16 ntu;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+
+	for (index = 0; index < adapter->num_rx_queues; index++) {
+		ntc = adapter->rx_ring[index]->next_to_clean;
+		ntu = adapter->rx_ring[index]->next_to_use;
+
+		if (ntc >= ntu)
+			diff += (ntc - ntu);
+		else
+			diff += (adapter->rx_ring[index]->count - ntu + ntc);
+	}
+	if (adapter->num_rx_queues <= 0)
+		return snprintf(page, count,
+				"can't calculate, number of queues %d\n",
+				adapter->num_rx_queues);
+	return snprintf(page, count, "%d\n", diff/adapter->num_rx_queues);
+}
+
+static int ixgbe_txqavg(char *page, char __always_unused **start,
+			off_t __always_unused off, int count,
+			int __always_unused *eof, void *data)
+{
+	int index;
+	int diff = 0;
+	u16 ntc;
+	u16 ntu;
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+
+	for (index = 0; index < adapter->num_tx_queues; index++) {
+		ntc = adapter->tx_ring[index]->next_to_clean;
+		ntu = adapter->tx_ring[index]->next_to_use;
+
+		if (ntc >= ntu)
+			diff += (ntc - ntu);
+		else
+			diff += (adapter->tx_ring[index]->count - ntu + ntc);
+	}
+	if (adapter->num_tx_queues <= 0)
+		return snprintf(page, count,
+				"can't calculate, number of queues %d\n",
+				adapter->num_tx_queues);
+	return snprintf(page, count, "%d\n",
+			diff/adapter->num_tx_queues);
+}
+
+static int ixgbe_iovotype(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void __always_unused *data)
+{
+	return snprintf(page, count, "2\n");
+}
+
+static int ixgbe_funcnbr(char *page, char __always_unused **start,
+			 off_t __always_unused off, int count,
+			 int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+
+	return snprintf(page, count, "%d\n", adapter->num_vfs);
+}
+
+static int ixgbe_pciebnbr(char *page, char __always_unused **start,
+			  off_t __always_unused off, int count,
+			  int __always_unused *eof, void *data)
+{
+	struct ixgbe_adapter *adapter = (struct ixgbe_adapter *)data;
+	if (adapter == NULL)
+		return snprintf(page, count, "error: no adapter\n");
+
+	return snprintf(page, count, "%d\n", adapter->pdev->bus->number);
+}
+
+static int ixgbe_therm_location(char *page, char __always_unused **start,
+				off_t __always_unused off, int count,
+				int __always_unused *eof, void *data)
+{
+	struct ixgbe_therm_proc_data *therm_data =
+		(struct ixgbe_therm_proc_data *)data;
+
+	if (therm_data == NULL)
+		return snprintf(page, count, "error: no therm_data\n");
+
+	return snprintf(page, count, "%d\n", therm_data->sensor_data->location);
+}
+
+
+static int ixgbe_therm_maxopthresh(char *page, char __always_unused **start,
+				   off_t __always_unused off, int count,
+				   int __always_unused *eof, void *data)
+{
+	struct ixgbe_therm_proc_data *therm_data =
+		(struct ixgbe_therm_proc_data *)data;
+
+	if (therm_data == NULL)
+		return snprintf(page, count, "error: no therm_data\n");
+
+	return snprintf(page, count, "%d\n",
+			therm_data->sensor_data->max_op_thresh);
+}
+
+
+static int ixgbe_therm_cautionthresh(char *page, char __always_unused **start,
+				     off_t __always_unused off, int count,
+				     int __always_unused *eof, void *data)
+{
+	struct ixgbe_therm_proc_data *therm_data =
+		(struct ixgbe_therm_proc_data *)data;
+
+	if (therm_data == NULL)
+		return snprintf(page, count, "error: no therm_data\n");
+
+	return snprintf(page, count, "%d\n",
+			therm_data->sensor_data->caution_thresh);
+}
+
+static int ixgbe_therm_temp(char *page, char __always_unused **start,
+			    off_t __always_unused off, int count,
+			    int __always_unused *eof, void *data)
+{
+	s32 status;
+	struct ixgbe_therm_proc_data *therm_data =
+		(struct ixgbe_therm_proc_data *)data;
+
+	if (therm_data == NULL)
+		return snprintf(page, count, "error: no therm_data\n");
+
+	status = ixgbe_get_thermal_sensor_data_generic(therm_data->hw);
+	if (status != IXGBE_SUCCESS)
+		snprintf(page, count, "error: status %d returned\n", status);
+
+	return snprintf(page, count, "%d\n", therm_data->sensor_data->temp);
+}
+
+
+struct ixgbe_proc_type {
+	char name[32];
+	int (*read)(char*, char**, off_t, int, int*, void*);
+};
+
+struct ixgbe_proc_type ixgbe_proc_entries[] = {
+	{"fwbanner", &ixgbe_fwbanner},
+	{"porttype", &ixgbe_porttype},
+	{"portspeed", &ixgbe_portspeed},
+	{"wqlflag", &ixgbe_wqlflag},
+	{"xflowctl", &ixgbe_xflowctl},
+	{"rxdrops", &ixgbe_rxdrops},
+	{"rxerrors", &ixgbe_rxerrors},
+	{"rxupacks", &ixgbe_rxupacks},
+	{"rxmpacks", &ixgbe_rxmpacks},
+	{"rxbpacks", &ixgbe_rxbpacks},
+	{"txdrops", &ixgbe_txdrops},
+	{"txerrors", &ixgbe_txerrors},
+	{"txupacks", &ixgbe_txupacks},
+	{"txmpacks", &ixgbe_txmpacks},
+	{"txbpacks", &ixgbe_txbpacks},
+	{"rxframes", &ixgbe_rxframes},
+	{"rxbytes", &ixgbe_rxbytes},
+	{"txframes", &ixgbe_txframes},
+	{"txbytes", &ixgbe_txbytes},
+	{"linkstat", &ixgbe_linkstat},
+	{"funcid", &ixgbe_funcid},
+	{"funcvers", &ixgbe_funcvers},
+	{"macburn", &ixgbe_macburn},
+	{"macadmn", &ixgbe_macadmn},
+	{"maclla1", &ixgbe_maclla1},
+	{"mtusize", &ixgbe_mtusize},
+	{"featflag", &ixgbe_featflag},
+	{"lsominct", &ixgbe_lsominct},
+	{"prommode", &ixgbe_prommode},
+	{"txdscqsz", &ixgbe_txdscqsz},
+	{"rxdscqsz", &ixgbe_rxdscqsz},
+	{"txqavg", &ixgbe_txqavg},
+	{"rxqavg", &ixgbe_rxqavg},
+	{"iovotype", &ixgbe_iovotype},
+	{"funcnbr", &ixgbe_funcnbr},
+	{"pciebnbr", &ixgbe_pciebnbr},
+	{"", NULL}
+};
+
+struct ixgbe_proc_type ixgbe_internal_entries[] = {
+	{"location", &ixgbe_therm_location},
+	{"temp", &ixgbe_therm_temp},
+	{"cautionthresh", &ixgbe_therm_cautionthresh},
+	{"maxopthresh", &ixgbe_therm_maxopthresh},
+	{"", NULL}
+};
+
+void ixgbe_del_proc_entries(struct ixgbe_adapter *adapter)
+{
+	int index;
+	int i;
+	char buf[16];	/* much larger than the sensor number will ever be */
+
+	if (ixgbe_top_dir == NULL)
+		return;
+
+	for (i = 0; i < IXGBE_MAX_SENSORS; i++) {
+		if (adapter->therm_dir[i] == NULL)
+			continue;
+
+		for (index = 0; ; index++) {
+			if (ixgbe_internal_entries[index].read == NULL)
+				break;
+
+			 remove_proc_entry(ixgbe_internal_entries[index].name,
+					   adapter->therm_dir[i]);
+		}
+		snprintf(buf, sizeof(buf), "sensor_%d", i);
+		remove_proc_entry(buf, adapter->info_dir);
+	}
+
+	if (adapter->info_dir != NULL) {
+		for (index = 0; ; index++) {
+			if (ixgbe_proc_entries[index].read == NULL)
+				break;
+			remove_proc_entry(ixgbe_proc_entries[index].name,
+					  adapter->info_dir);
+		}
+		remove_proc_entry("info", adapter->eth_dir);
+	}
+
+	if (adapter->eth_dir != NULL)
+		remove_proc_entry(pci_name(adapter->pdev), ixgbe_top_dir);
+}
+
+/* called from ixgbe_main.c */
+void ixgbe_procfs_exit(struct ixgbe_adapter *adapter)
+{
+	ixgbe_del_proc_entries(adapter);
+}
+
+int ixgbe_procfs_topdir_init()
+{
+	ixgbe_top_dir = proc_mkdir("driver/ixgbe", NULL);
+	if (ixgbe_top_dir == NULL)
+		return -ENOMEM;
+
+	return 0;
+}
+
+void ixgbe_procfs_topdir_exit()
+{
+	remove_proc_entry("driver/ixgbe", NULL);
+}
+
+/* called from ixgbe_main.c */
+int ixgbe_procfs_init(struct ixgbe_adapter *adapter)
+{
+	int rc = 0;
+	int index;
+	int i;
+	char buf[16];	/* much larger than the sensor number will ever be */
+
+	adapter->eth_dir = NULL;
+	adapter->info_dir = NULL;
+	for (i = 0; i < IXGBE_MAX_SENSORS; i++)
+		adapter->therm_dir[i] = NULL;
+
+	if (ixgbe_top_dir == NULL) {
+		rc = -ENOMEM;
+		goto fail;
+	}
+
+	adapter->eth_dir = proc_mkdir(pci_name(adapter->pdev), ixgbe_top_dir);
+	if (adapter->eth_dir == NULL) {
+		rc = -ENOMEM;
+		goto fail;
+	}
+
+	adapter->info_dir = proc_mkdir("info", adapter->eth_dir);
+	if (adapter->info_dir == NULL) {
+		rc = -ENOMEM;
+		goto fail;
+	}
+	for (index = 0; ; index++) {
+		if (ixgbe_proc_entries[index].read == NULL)
+			break;
+		if (!(create_proc_read_entry(ixgbe_proc_entries[index].name,
+					   0444,
+					   adapter->info_dir,
+					   ixgbe_proc_entries[index].read,
+					   adapter))) {
+
+			rc = -ENOMEM;
+			goto fail;
+		}
+	}
+	if (ixgbe_thermal_present(adapter) == false)
+		goto exit;
+
+	for (i = 0; i < IXGBE_MAX_SENSORS; i++) {
+
+		if (adapter->hw.mac.thermal_sensor_data.sensor[i].location ==
+		    0)
+			continue;
+
+		snprintf(buf, sizeof(buf), "sensor_%d", i);
+		adapter->therm_dir[i] = proc_mkdir(buf, adapter->info_dir);
+		if (adapter->therm_dir[i] == NULL) {
+			rc = -ENOMEM;
+			goto fail;
+		}
+		for (index = 0; ; index++) {
+			if (ixgbe_internal_entries[index].read == NULL)
+				break;
+			/*
+			 * therm_data struct contains pointer the read func
+			 * will be needing
+			 */
+			adapter->therm_data[i].hw = &adapter->hw;
+			adapter->therm_data[i].sensor_data =
+				&adapter->hw.mac.thermal_sensor_data.sensor[i];
+
+			if (!(create_proc_read_entry(
+					   ixgbe_internal_entries[index].name,
+					   0444,
+					   adapter->therm_dir[i],
+					   ixgbe_internal_entries[index].read,
+					   &adapter->therm_data[i]))) {
+				rc = -ENOMEM;
+				goto fail;
+			}
+		}
+	}
+	goto exit;
+
+fail:
+	ixgbe_del_proc_entries(adapter);
+exit:
+	return rc;
+}
+
+#endif /* !IXGBE_SYSFS */
+#endif /* IXGBE_PROCFS */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_ptp.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_ptp.c
index e5ba040..0fe1421 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_ptp.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_ptp.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -25,6 +21,7 @@
   Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
 
 *******************************************************************************/
+
 #include "ixgbe.h"
 #include <linux/ptp_classify.h>
 
@@ -93,10 +90,9 @@
 
 #define IXGBE_INCVAL_SHIFT_82599 7
 #define IXGBE_INCPER_SHIFT_82599 24
-#define IXGBE_MAX_TIMEADJ_VALUE  0x7FFFFFFFFFFFFFFFULL
 
 #define IXGBE_OVERFLOW_PERIOD    (HZ * 30)
-#define IXGBE_PTP_TX_TIMEOUT     (HZ * 15)
+#define IXGBE_PTP_TX_TIMEOUT     (HZ)
 
 /* half of a one second clock period, for use with PPS signal. We have to use
  * this instead of something pre-defined like IXGBE_PTP_PPS_HALF_SECOND, in
@@ -104,9 +100,69 @@
  */
 #define IXGBE_PTP_PPS_HALF_SECOND 500000000ULL
 
+/* In contrast, the X550 controller has two registers, SYSTIMEH and SYSTIMEL
+ * which contain measurements of seconds and nanoseconds respectively. This
+ * matches the standard linux representation of time in the kernel. In addition,
+ * the X550 also has a SYSTIMER register which represents residue, or
+ * subnanosecond overflow adjustments. To control clock adjustment, the TIMINCA
+ * register is used, but it is unlike the X540 and 82599 devices. TIMINCA
+ * represents units of 2^-32 nanoseconds, and uses 31 bits for this, with the
+ * high bit representing whether the adjustent is positive or negative. Every
+ * clock cycle, the X550 will add 12.5 ns + TIMINCA which can result in a range
+ * of 12 to 13 nanoseconds adjustment. Unlike the 82599 and X540 devices, the
+ * X550's clock for purposes of SYSTIME generation is constant and not dependant
+ * on the link speed.
+ *
+ *           SYSTIMEH           SYSTIMEL        SYSTIMER
+ *       +--------------+  +--------------+  +-------------+
+ * X550  |      32      |  |      32      |  |     32      |
+ *       *--------------+  +--------------+  +-------------+
+ *       \____seconds___/   \_nanoseconds_/  \__2^-32 ns__/
+ *
+ * This results in a full 96 bits to represent the clock, with 32 bits for
+ * seconds, 32 bits for nanoseconds (largest value is 0d999999999 or just under
+ * 1 second) and an additional 32 bits to measure sub nanosecond adjustments for
+ * underflow of adjustments.
+ *
+ * The 32 bits of seconds for the X550 overflows every
+ *   2^32 / ( 365.25 * 24 * 60 * 60 ) = ~136 years.
+ *
+ * In order to adjust the clock frequency for the X550, the TIMINCA register is
+ * provided. This register represents a + or minus nearly 0.5 ns adjustment to
+ * the base frequency. It is measured in 2^-32 ns units, with the high bit being
+ * the sign bit. This register enables software to calculate frequency
+ * adjustments and apply them directly to the clock rate.
+ *
+ * The math for converting ppb into TIMINCA values is fairly straightforward.
+ *   TIMINCA value = ( Base_Frequency * ppb ) / 1000000000ULL
+ *
+ * This assumes that ppb is never high enough to create a value bigger than
+ * TIMINCA's 31 bits can store. This is ensured by the stack. Calculating this
+ * value is also simple.
+ *   Max ppb = ( Max Adjustment / Base Frequency ) / 1000000000ULL
+ *
+ * For the X550, the Max adjustment is +/- 0.5 ns, and the base frequency is
+ * 12.5 nanoseconds. This means that the Max ppb is 39999999
+ *   Note: We subtract one in order to ensure no overflow, because the TIMINCA
+ *         register can only hold slightly under 0.5 nanoseconds.
+ *
+ * Because TIMINCA is measured in 2^-32 ns units, we have to convert 12.5 ns
+ * into 2^-32 units, which is
+ *
+ *  12.5 * 2^32 = C80000000
+ *
+ * Some revisions of hardware have a faster base frequency than the registers
+ * were defined for. To fix this, we use a timecounter structure with the
+ * proper mult and shift to convert the cycles into nanoseconds of time.
+ */
+#define IXGBE_X550_BASE_PERIOD 0xC80000000ULL
+#define INCVALUE_MASK	0x7FFFFFFF
+#define ISGN		0x80000000
+#define MAX_TIMADJ	0x7FFFFFFF
+
 /**
- * ixgbe_ptp_setup_sdp
- * @hw: the hardware private structure
+ * ixgbe_ptp_setup_sdp_X540
+ * @adapter: the adapter private structure
  *
  * this function enables or disables the clock out feature on SDP0 for
  * the X540 device. It will create a 1second periodic output that can
@@ -116,83 +172,119 @@
  * aligns the start of the PPS signal to that value. The shift is
  * necessary because it can change based on the link speed.
  */
-static void ixgbe_ptp_setup_sdp(struct ixgbe_adapter *adapter)
+static void ixgbe_ptp_setup_sdp_X540(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
-	int shift = adapter->cc.shift;
+	int shift = adapter->hw_cc.shift;
 	u32 esdp, tsauxc, clktiml, clktimh, trgttiml, trgttimh, rem;
 	u64 ns = 0, clock_edge = 0;
 
-	if ((adapter->flags2 & IXGBE_FLAG2_PTP_PPS_ENABLED) &&
-	    (hw->mac.type == ixgbe_mac_X540)) {
+	/* disable the pin first */
+	IXGBE_WRITE_REG(hw, IXGBE_TSAUXC, 0x0);
+	IXGBE_WRITE_FLUSH(hw);
 
-		/* disable the pin first */
-		IXGBE_WRITE_REG(hw, IXGBE_TSAUXC, 0x0);
-		IXGBE_WRITE_FLUSH(hw);
+	if (!(adapter->flags2 & IXGBE_FLAG2_PTP_PPS_ENABLED))
+		return;
 
-		esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
+	esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
 
-		/*
-		 * enable the SDP0 pin as output, and connected to the
-		 * native function for Timesync (ClockOut)
-		 */
-		esdp |= (IXGBE_ESDP_SDP0_DIR |
-			 IXGBE_ESDP_SDP0_NATIVE);
+	/*
+	 * enable the SDP0 pin as output, and connected to the
+	 * native function for Timesync (ClockOut)
+	 */
+	esdp |= IXGBE_ESDP_SDP0_DIR |
+		IXGBE_ESDP_SDP0_NATIVE;
 
-		/*
-		 * enable the Clock Out feature on SDP0, and allow
-		 * interrupts to occur when the pin changes
-		 */
-		tsauxc = (IXGBE_TSAUXC_EN_CLK |
-			  IXGBE_TSAUXC_SYNCLK |
-			  IXGBE_TSAUXC_SDP0_INT);
-
-		/* clock period (or pulse length) */
-		clktiml = (u32)(IXGBE_PTP_PPS_HALF_SECOND << shift);
-		clktimh = (u32)((IXGBE_PTP_PPS_HALF_SECOND << shift) >> 32);
-
-		/*
-		 * Account for the cyclecounter wrap-around value by
-		 * using the converted ns value of the current time to
-		 * check for when the next aligned second would occur.
-		 */
-		clock_edge |= (u64)IXGBE_READ_REG(hw, IXGBE_SYSTIML);
-		clock_edge |= (u64)IXGBE_READ_REG(hw, IXGBE_SYSTIMH) << 32;
-		ns = timecounter_cyc2time(&adapter->tc, clock_edge);
+	/*
+	 * enable the Clock Out feature on SDP0, and allow
+	 * interrupts to occur when the pin changes
+	 */
+	tsauxc = IXGBE_TSAUXC_EN_CLK |
+			IXGBE_TSAUXC_SYNCLK |
+			IXGBE_TSAUXC_SDP0_INT;
+
+	/* set to half clock period */
+	clktiml = (u32)(IXGBE_PTP_PPS_HALF_SECOND << shift);
+	clktimh = (u32)((IXGBE_PTP_PPS_HALF_SECOND << shift) >> 32);
 
-		div_u64_rem(ns, IXGBE_PTP_PPS_HALF_SECOND, &rem);
-		clock_edge += ((IXGBE_PTP_PPS_HALF_SECOND - (u64)rem) << shift);
+	/*
+	 * Account for the cyclecounter wrap-around value by
+	 * using the converted ns value of the current time to
+	 * check for when the next aligned second would occur.
+	 */
+	clock_edge |= (u64)IXGBE_READ_REG(hw, IXGBE_SYSTIML);
+	clock_edge |= (u64)IXGBE_READ_REG(hw, IXGBE_SYSTIMH) << 32;
+	ns = timecounter_cyc2time(&adapter->hw_tc, clock_edge);
 
-		/* specify the initial clock start time */
-		trgttiml = (u32)clock_edge;
-		trgttimh = (u32)(clock_edge >> 32);
+	div_u64_rem(ns, IXGBE_PTP_PPS_HALF_SECOND, &rem);
+	clock_edge += ((IXGBE_PTP_PPS_HALF_SECOND - (u64)rem) << shift);
 
-		IXGBE_WRITE_REG(hw, IXGBE_CLKTIML, clktiml);
-		IXGBE_WRITE_REG(hw, IXGBE_CLKTIMH, clktimh);
-		IXGBE_WRITE_REG(hw, IXGBE_TRGTTIML0, trgttiml);
-		IXGBE_WRITE_REG(hw, IXGBE_TRGTTIMH0, trgttimh);
+	/* specify the initial clock start time */
+	trgttiml = (u32)clock_edge;
+	trgttimh = (u32)(clock_edge >> 32);
 
-		IXGBE_WRITE_REG(hw, IXGBE_ESDP, esdp);
-		IXGBE_WRITE_REG(hw, IXGBE_TSAUXC, tsauxc);
-	} else {
-		IXGBE_WRITE_REG(hw, IXGBE_TSAUXC, 0x0);
-	}
+	IXGBE_WRITE_REG(hw, IXGBE_CLKTIML, clktiml);
+	IXGBE_WRITE_REG(hw, IXGBE_CLKTIMH, clktimh);
+	IXGBE_WRITE_REG(hw, IXGBE_TRGTTIML0, trgttiml);
+	IXGBE_WRITE_REG(hw, IXGBE_TRGTTIMH0, trgttimh);
+
+	IXGBE_WRITE_REG(hw, IXGBE_ESDP, esdp);
+	IXGBE_WRITE_REG(hw, IXGBE_TSAUXC, tsauxc);
 
 	IXGBE_WRITE_FLUSH(hw);
 }
 
 /**
- * ixgbe_ptp_read - read raw cycle counter (to be used by time counter)
- * @cc: the cyclecounter structure
+ * ixgbe_ptp_read_X550 - read cycle counter value
+ * @hw_cc: cyclecounter structure
+ *
+ * This function reads SYSTIME registers. It is called by the cyclecounter
+ * structure to convert from internal representation into nanoseconds. We need
+ * this for X550 since some skews do not have expected clock frequency and
+ * result of SYSTIME is 32bits of "billions of cycles" and 32 bits of
+ * "cycles", rather than seconds and nanoseconds.
+ */
+static u64 ixgbe_ptp_read_X550(const struct cyclecounter *hw_cc)
+{
+	struct ixgbe_adapter *adapter =
+		container_of(hw_cc, struct ixgbe_adapter, hw_cc);
+	struct ixgbe_hw *hw = &adapter->hw;
+	struct timespec64 ts;
+
+	/* storage is 32 bits of 'billions of cycles' and 32 bits of 'cycles'.
+	 * Some revisions of hardware run at a higher frequency and so the
+	 * cycles are not guaranteed to be nanoseconds. The timespec64 created
+	 * here is used for its math/conversions but does not necessarily
+	 * represent nominal time.
+	 *
+	 * It should be noted that this cyclecounter will overflow at a
+	 * non-bitmask field since we have to convert our billions of cycles
+	 * into an actual cycles count. This results in some possible weird
+	 * situations at high cycle counter stamps. However given that 32 bits
+	 * of "seconds" is ~138 years this isn't a problem. Even at the
+	 * increased frequency of some revisions, this is still ~103 years.
+	 * Since the SYSTIME values start at 0 and we never write them, it is
+	 * highly unlikely for the cyclecounter to overflow in practice.
+	 */
+	IXGBE_READ_REG(hw, IXGBE_SYSTIMR);
+	ts.tv_nsec = IXGBE_READ_REG(hw, IXGBE_SYSTIML);
+	ts.tv_sec = IXGBE_READ_REG(hw, IXGBE_SYSTIMH);
+
+	return (u64)timespec64_to_ns(&ts);
+}
+
+/**
+ * ixgbe_ptp_read_82599 - read raw cycle counter (to be used by time counter)
+ * @hw_cc: the cyclecounter structure
  *
  * this function reads the cyclecounter registers and is called by the
  * cyclecounter structure used to construct a ns counter from the
  * arbitrary fixed point registers
  */
-static cycle_t ixgbe_ptp_read(const struct cyclecounter *cc)
+static u64 ixgbe_ptp_read_82599(const struct cyclecounter *hw_cc)
 {
 	struct ixgbe_adapter *adapter =
-		container_of(cc, struct ixgbe_adapter, cc);
+		container_of(hw_cc, struct ixgbe_adapter, hw_cc);
 	struct ixgbe_hw *hw = &adapter->hw;
 	u64 stamp = 0;
 
@@ -203,20 +295,80 @@ static cycle_t ixgbe_ptp_read(const struct cyclecounter *cc)
 }
 
 /**
- * ixgbe_ptp_adjfreq
+ * ixgbe_ptp_convert_to_hwtstamp - convert register value to hw timestamp
+ * @adapter: private adapter structure
+ * @hwtstamp: stack timestamp structure
+ * @systim: unsigned 64bit system time value
+ *
+ * We need to convert the adapter's RX/TXSTMP registers into a hwtstamp value
+ * which can be used by the stack's ptp functions.
+ *
+ * The lock is used to protect consistency of the cyclecounter and the SYSTIME
+ * registers. However, it does not need to protect against the Rx or Tx
+ * timestamp registers, as there can't be a new timestamp until the old one is
+ * unlatched by reading.
+ *
+ * In addition to the timestamp in hardware, some controllers need a software
+ * overflow cyclecounter, and this function takes this into account as well.
+ **/
+static void ixgbe_ptp_convert_to_hwtstamp(struct ixgbe_adapter *adapter,
+					  struct skb_shared_hwtstamps *hwtstamp,
+					  u64 timestamp)
+{
+	unsigned long flags;
+	struct timespec64 systime;
+	u64 ns;
+
+	memset(hwtstamp, 0, sizeof(*hwtstamp));
+
+	switch (adapter->hw.mac.type) {
+	/* X550 and later hardware supposedly represent time using a seconds
+	 * and nanoseconds counter, instead of raw 64bits nanoseconds. We need
+	 * to convert the timestamp into cycles before it can be fed to the
+	 * cyclecounter. We need an actual cyclecounter because some revisions
+	 * of hardware run at a higher frequency and thus the counter does
+	 * not represent seconds/nanoseconds. Instead it can be thought of as
+	 * cycles and billions of cycles.
+	 */
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		/* Upper 32 bits represent billions of cycles, lower 32 bits
+		 * represent cycles. However, we use timespec64_to_ns for the
+		 * correct math even though the units haven't been corrected
+		 * yet.
+		 */
+		systime.tv_sec = timestamp >> 32;
+		systime.tv_nsec = timestamp & 0xFFFFFFFF;
+
+		timestamp = timespec64_to_ns(&systime);
+		break;
+	default:
+		break;
+	}
+
+	spin_lock_irqsave(&adapter->tmreg_lock, flags);
+	ns = timecounter_cyc2time(&adapter->hw_tc, timestamp);
+	spin_unlock_irqrestore(&adapter->tmreg_lock, flags);
+
+	hwtstamp->hwtstamp = ns_to_ktime(ns);
+}
+
+/**
+ * ixgbe_ptp_adjfreq_82599
  * @ptp: the ptp clock structure
  * @ppb: parts per billion adjustment from base
  *
  * adjust the frequency of the ptp cycle counter by the
  * indicated ppb from the base frequency.
  */
-static int ixgbe_ptp_adjfreq(struct ptp_clock_info *ptp, s32 ppb)
+static int ixgbe_ptp_adjfreq_82599(struct ptp_clock_info *ptp, s32 ppb)
 {
 	struct ixgbe_adapter *adapter =
 		container_of(ptp, struct ixgbe_adapter, ptp_caps);
 	struct ixgbe_hw *hw = &adapter->hw;
-	u64 freq;
-	u32 diff, incval;
+	u64 freq, incval;
+	u32 diff;
 	int neg_adj = 0;
 
 	if (ppb < 0) {
@@ -235,12 +387,16 @@ static int ixgbe_ptp_adjfreq(struct ptp_clock_info *ptp, s32 ppb)
 
 	switch (hw->mac.type) {
 	case ixgbe_mac_X540:
-		IXGBE_WRITE_REG(hw, IXGBE_TIMINCA, incval);
+		if (incval > 0xFFFFFFFFULL)
+			e_dev_warn("PTP ppb adjusted SYSTIME rate overflowed!\n");
+		IXGBE_WRITE_REG(hw, IXGBE_TIMINCA, (u32)incval);
 		break;
 	case ixgbe_mac_82599EB:
+		if (incval > 0x00FFFFFFULL)
+			e_dev_warn("PTP ppb adjusted SYSTIME rate overflowed!\n");
 		IXGBE_WRITE_REG(hw, IXGBE_TIMINCA,
 				(1 << IXGBE_INCPER_SHIFT_82599) |
-				incval);
+				((u32)incval & 0x00FFFFFFUL));
 		break;
 	default:
 		break;
@@ -250,44 +406,83 @@ static int ixgbe_ptp_adjfreq(struct ptp_clock_info *ptp, s32 ppb)
 }
 
 /**
- * ixgbe_ptp_adjtime
+ * ixgbe_ptp_adjfreq_X550
+ * @ptp: the ptp clock structure
+ * @ppb: parts per billion adjustment from base
+ *
+ * adjust the frequency of the SYSTIME registers by the indicated ppb from base
+ * frequency
+ */
+static int ixgbe_ptp_adjfreq_X550(struct ptp_clock_info *ptp, s32 ppb)
+{
+	struct ixgbe_adapter *adapter =
+		container_of(ptp, struct ixgbe_adapter, ptp_caps);
+	struct ixgbe_hw *hw = &adapter->hw;
+	int neg_adj = 0;
+	u64 rate = IXGBE_X550_BASE_PERIOD;
+	u32 inca;
+
+	if (ppb < 0) {
+		neg_adj = 1;
+		ppb = -ppb;
+	}
+	rate *= ppb;
+	rate = div_u64(rate, 1000000000ULL);
+
+	/* warn if rate is too large */
+	if (rate >= INCVALUE_MASK)
+		e_dev_warn("PTP ppb adjusted SYSTIME rate overflowed!\n");
+
+	inca = rate & INCVALUE_MASK;
+	if (neg_adj)
+		inca |= ISGN;
+
+	IXGBE_WRITE_REG(hw, IXGBE_TIMINCA, inca);
+
+	return 0;
+}
+
+/**
+ * ixgbe_ptp_adjtime_timecounter
  * @ptp: the ptp clock structure
  * @delta: offset to adjust the cycle counter by
  *
  * adjust the timer by resetting the timecounter structure.
  */
-static int ixgbe_ptp_adjtime(struct ptp_clock_info *ptp, s64 delta)
+static int ixgbe_ptp_adjtime_timecounter(struct ptp_clock_info *ptp,
+					 s64 delta)
 {
 	struct ixgbe_adapter *adapter =
 		container_of(ptp, struct ixgbe_adapter, ptp_caps);
 	unsigned long flags;
 
 	spin_lock_irqsave(&adapter->tmreg_lock, flags);
-	timecounter_adjtime(&adapter->tc, delta);
+	timecounter_adjtime(&adapter->hw_tc, delta);
 	spin_unlock_irqrestore(&adapter->tmreg_lock, flags);
 
-	ixgbe_ptp_setup_sdp(adapter);
+	if (adapter->ptp_setup_sdp)
+		adapter->ptp_setup_sdp(adapter);
 
 	return 0;
 }
 
 /**
- * ixgbe_ptp_gettime
+ * ixgbe_ptp_gettime64_timecounter
  * @ptp: the ptp clock structure
- * @ts: timespec structure to hold the current time value
+ * @ts: timespec64 structure to hold the current time value
  *
  * read the timecounter and return the correct value on ns,
- * after converting it into a struct timespec.
+ * after converting it into a struct timespec64.
  */
-static int ixgbe_ptp_gettime(struct ptp_clock_info *ptp, struct timespec64 *ts)
+static int ixgbe_ptp_gettime64_timecounter(struct ptp_clock_info *ptp, struct timespec64 *ts)
 {
 	struct ixgbe_adapter *adapter =
 		container_of(ptp, struct ixgbe_adapter, ptp_caps);
-	u64 ns;
 	unsigned long flags;
+	u64 ns;
 
 	spin_lock_irqsave(&adapter->tmreg_lock, flags);
-	ns = timecounter_read(&adapter->tc);
+	ns = timecounter_read(&adapter->hw_tc);
 	spin_unlock_irqrestore(&adapter->tmreg_lock, flags);
 
 	*ts = ns_to_timespec64(ns);
@@ -296,15 +491,15 @@ static int ixgbe_ptp_gettime(struct ptp_clock_info *ptp, struct timespec64 *ts)
 }
 
 /**
- * ixgbe_ptp_settime
+ * ixgbe_ptp_settime64_timecounter
  * @ptp: the ptp clock structure
- * @ts: the timespec containing the new time for the cycle counter
+ * @ts: the timespec64 containing the new time for the cycle counter
  *
  * reset the timecounter to use a new base value instead of the kernel
  * wall timer value.
  */
-static int ixgbe_ptp_settime(struct ptp_clock_info *ptp,
-			     const struct timespec64 *ts)
+static int ixgbe_ptp_settime64_timecounter(struct ptp_clock_info *ptp,
+					   const struct timespec64 *ts)
 {
 	struct ixgbe_adapter *adapter =
 		container_of(ptp, struct ixgbe_adapter, ptp_caps);
@@ -315,13 +510,39 @@ static int ixgbe_ptp_settime(struct ptp_clock_info *ptp,
 
 	/* reset the timecounter */
 	spin_lock_irqsave(&adapter->tmreg_lock, flags);
-	timecounter_init(&adapter->tc, &adapter->cc, ns);
+	timecounter_init(&adapter->hw_tc, &adapter->hw_cc, ns);
 	spin_unlock_irqrestore(&adapter->tmreg_lock, flags);
 
-	ixgbe_ptp_setup_sdp(adapter);
+	if (adapter->ptp_setup_sdp)
+		adapter->ptp_setup_sdp(adapter);
+	return 0;
+}
+
+#ifndef HAVE_PTP_CLOCK_INFO_GETTIME64
+static int ixgbe_ptp_gettime_timecounter(struct ptp_clock_info *ptp, struct timespec *ts)
+{
+	struct timespec64 ts64;
+	int err;
+
+	err = ixgbe_ptp_gettime64_timecounter(ptp, &ts64);
+	if (err)
+		return err;
+
+	*ts = timespec64_to_timespec(ts64);
+
 	return 0;
 }
 
+static int ixgbe_ptp_settime_timecounter(struct ptp_clock_info *ptp,
+					 const struct timespec *ts)
+{
+	struct timespec64 ts64;
+
+	ts64 = timespec_to_timespec64(*ts);
+	return ixgbe_ptp_settime64_timecounter(ptp, &ts64);
+}
+#endif
+
 /**
  * ixgbe_ptp_feature_enable
  * @ptp: the ptp clock structure
@@ -343,19 +564,14 @@ static int ixgbe_ptp_feature_enable(struct ptp_clock_info *ptp,
 	 * event when the clock SDP triggers. Clear mask when PPS is
 	 * disabled
 	 */
-	if (rq->type == PTP_CLK_REQ_PPS) {
-		switch (adapter->hw.mac.type) {
-		case ixgbe_mac_X540:
-			if (on)
-				adapter->flags2 |= IXGBE_FLAG2_PTP_PPS_ENABLED;
-			else
-				adapter->flags2 &= ~IXGBE_FLAG2_PTP_PPS_ENABLED;
-
-			ixgbe_ptp_setup_sdp(adapter);
-			return 0;
-		default:
-			break;
-		}
+	if (rq->type == PTP_CLK_REQ_PPS && adapter->ptp_setup_sdp) {
+		if (on)
+			adapter->flags2 |= IXGBE_FLAG2_PTP_PPS_ENABLED;
+		else
+			adapter->flags2 &= ~IXGBE_FLAG2_PTP_PPS_ENABLED;
+
+		adapter->ptp_setup_sdp(adapter);
+		return 0;
 	}
 
 	return -ENOTSUPP;
@@ -369,7 +585,7 @@ static int ixgbe_ptp_feature_enable(struct ptp_clock_info *ptp,
  * This function is called by the interrupt routine when checking for
  * interrupts. It will check and handle a pps event.
  */
-void ixgbe_ptp_check_pps_event(struct ixgbe_adapter *adapter, u32 eicr)
+void ixgbe_ptp_check_pps_event(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	struct ptp_clock_event event;
@@ -398,16 +614,18 @@ void ixgbe_ptp_check_pps_event(struct ixgbe_adapter *adapter, u32 eicr)
  *
  * this watchdog task periodically reads the timecounter
  * in order to prevent missing when the system time registers wrap
- * around. This needs to be run approximately twice a minute.
+ * around. This needs to be run approximately twice a minute for the fastest
+ * overflowing hardware. We run it for all hardware since it shouldn't have a
+ * large impact.
  */
 void ixgbe_ptp_overflow_check(struct ixgbe_adapter *adapter)
 {
 	bool timeout = time_is_before_jiffies(adapter->last_overflow_check +
-					     IXGBE_OVERFLOW_PERIOD);
+					      IXGBE_OVERFLOW_PERIOD);
 	struct timespec64 ts;
 
 	if (timeout) {
-		ixgbe_ptp_gettime(&adapter->ptp_caps, &ts);
+		ixgbe_ptp_gettime64_timecounter(&adapter->ptp_caps, &ts);
 		adapter->last_overflow_check = jiffies;
 	}
 }
@@ -424,8 +642,10 @@ void ixgbe_ptp_overflow_check(struct ixgbe_adapter *adapter)
 void ixgbe_ptp_rx_hang(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
+	struct ixgbe_ring *rx_ring;
 	u32 tsyncrxctl = IXGBE_READ_REG(hw, IXGBE_TSYNCRXCTL);
 	unsigned long rx_event;
+	int n;
 
 	/* if we don't have a valid timestamp in the registers, just update the
 	 * timeout counter and exit
@@ -437,15 +657,66 @@ void ixgbe_ptp_rx_hang(struct ixgbe_adapter *adapter)
 
 	/* determine the most recent watchdog or rx_timestamp event */
 	rx_event = adapter->last_rx_ptp_check;
-	if (time_after(adapter->last_rx_timestamp, rx_event))
-		rx_event = adapter->last_rx_timestamp;
+	for (n = 0; n < adapter->num_rx_queues; n++) {
+		rx_ring = adapter->rx_ring[n];
+		if (time_after(rx_ring->last_rx_timestamp, rx_event))
+			rx_event = rx_ring->last_rx_timestamp;
+	}
 
 	/* only need to read the high RXSTMP register to clear the lock */
 	if (time_is_before_jiffies(rx_event + 5*HZ)) {
 		IXGBE_READ_REG(hw, IXGBE_RXSTMPH);
 		adapter->last_rx_ptp_check = jiffies;
 
-		e_warn(drv, "clearing RX Timestamp hang\n");
+		adapter->rx_hwtstamp_cleared++;
+		e_warn(drv, "clearing RX Timestamp hang");
+	}
+}
+
+/**
+ * ixgbe_ptp_clear_tx_timestamp - utility function to clear Tx timestamp state
+ * @adapter: the private adapter structure
+ *
+ * This function should be called whenever the state related to a Tx timestamp
+ * needs to be cleared. This helps ensure that all related bits are reset for
+ * the next Tx timestamp event.
+ */
+static void ixgbe_ptp_clear_tx_timestamp(struct ixgbe_adapter *adapter)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+
+	IXGBE_READ_REG(hw, IXGBE_TXSTMPH);
+	if (adapter->ptp_tx_skb) {
+		dev_kfree_skb_any(adapter->ptp_tx_skb);
+		adapter->ptp_tx_skb = NULL;
+	}
+	clear_bit_unlock(__IXGBE_PTP_TX_IN_PROGRESS, &adapter->state);
+}
+
+/**
+ * ixgbe_ptp_tx_hang - detect error case where Tx timestamp never finishes
+ * @adapter: private network adapter structure
+ */
+void ixgbe_ptp_tx_hang(struct ixgbe_adapter *adapter)
+{
+	bool timeout = time_is_before_jiffies(adapter->ptp_tx_start +
+					      IXGBE_PTP_TX_TIMEOUT);
+
+	if (!adapter->ptp_tx_skb)
+		return;
+
+	if (!test_bit(__IXGBE_PTP_TX_IN_PROGRESS, &adapter->state))
+		return;
+
+	/* If we haven't received a timestamp within the timeout, it is
+	 * reasonable to assume that it will never occur, so we can unlock the
+	 * timestamp bit when this occurs.
+	 */
+	if (timeout) {
+		cancel_work_sync(&adapter->ptp_tx_work);
+		ixgbe_ptp_clear_tx_timestamp(adapter);
+		adapter->tx_hwtstamp_timeouts++;
+		e_warn(drv, "clearing Tx timestamp hang\n");
 	}
 }
 
@@ -459,25 +730,26 @@ void ixgbe_ptp_rx_hang(struct ixgbe_adapter *adapter)
  */
 static void ixgbe_ptp_tx_hwtstamp(struct ixgbe_adapter *adapter)
 {
+	struct sk_buff *skb = adapter->ptp_tx_skb;
 	struct ixgbe_hw *hw = &adapter->hw;
 	struct skb_shared_hwtstamps shhwtstamps;
-	u64 regval = 0, ns;
-	unsigned long flags;
+	u64 regval = 0;
 
 	regval |= (u64)IXGBE_READ_REG(hw, IXGBE_TXSTMPL);
 	regval |= (u64)IXGBE_READ_REG(hw, IXGBE_TXSTMPH) << 32;
+	ixgbe_ptp_convert_to_hwtstamp(adapter, &shhwtstamps, regval);
 
-	spin_lock_irqsave(&adapter->tmreg_lock, flags);
-	ns = timecounter_cyc2time(&adapter->tc, regval);
-	spin_unlock_irqrestore(&adapter->tmreg_lock, flags);
-
-	memset(&shhwtstamps, 0, sizeof(shhwtstamps));
-	shhwtstamps.hwtstamp = ns_to_ktime(ns);
-	skb_tstamp_tx(adapter->ptp_tx_skb, &shhwtstamps);
-
-	dev_kfree_skb_any(adapter->ptp_tx_skb);
+	/* Handle cleanup of the ptp_tx_skb ourselves, and unlock the state
+	 * bit prior to notifying the stack via skb_tstamp_tx(). This prevents
+	 * well behaved applications from attempting to timestamp again prior
+	 * to the lock bit being clear.
+	 */
 	adapter->ptp_tx_skb = NULL;
 	clear_bit_unlock(__IXGBE_PTP_TX_IN_PROGRESS, &adapter->state);
+
+	/* Notify the stack and then free the skb after we've unlocked */
+	skb_tstamp_tx(skb, &shhwtstamps);
+	dev_kfree_skb_any(skb);
 }
 
 /**
@@ -485,7 +757,7 @@ static void ixgbe_ptp_tx_hwtstamp(struct ixgbe_adapter *adapter)
  * @work: pointer to the work struct
  *
  * This work item polls TSYNCTXCTL valid bit to determine when a Tx hardware
- * timestamp has been taken for the current skb. It is necessary, because the
+ * timestamp has been taken for the current skb. It is necesary, because the
  * descriptor's "done" bit does not correlate with the timestamp event.
  */
 static void ixgbe_ptp_tx_hwtstamp_work(struct work_struct *work)
@@ -497,39 +769,86 @@ static void ixgbe_ptp_tx_hwtstamp_work(struct work_struct *work)
 					      IXGBE_PTP_TX_TIMEOUT);
 	u32 tsynctxctl;
 
-	if (timeout) {
-		dev_kfree_skb_any(adapter->ptp_tx_skb);
-		adapter->ptp_tx_skb = NULL;
-		clear_bit_unlock(__IXGBE_PTP_TX_IN_PROGRESS, &adapter->state);
-		e_warn(drv, "clearing Tx Timestamp hang\n");
+	/* we have to have a valid skb to poll for a timestamp */
+	if (!adapter->ptp_tx_skb) {
+		ixgbe_ptp_clear_tx_timestamp(adapter);
 		return;
 	}
 
+	/* stop polling once we have a valid timestamp */
 	tsynctxctl = IXGBE_READ_REG(hw, IXGBE_TSYNCTXCTL);
-	if (tsynctxctl & IXGBE_TSYNCTXCTL_VALID)
+	if (tsynctxctl & IXGBE_TSYNCTXCTL_VALID) {
 		ixgbe_ptp_tx_hwtstamp(adapter);
-	else
-		/* reschedule to keep checking if it's not available yet */
+		return;
+	}
+
+	/* check timeout last in case timestamp event just occurred */
+	if (timeout) {
+		ixgbe_ptp_clear_tx_timestamp(adapter);
+		adapter->tx_hwtstamp_timeouts++;
+		e_warn(drv, "clearing Tx Timestamp hang");
+	} else {
+		/* reschedule to keep checking until we timeout */
 		schedule_work(&adapter->ptp_tx_work);
+	}
 }
 
 /**
- * ixgbe_ptp_rx_hwtstamp - utility function which checks for RX time stamp
- * @adapter: pointer to adapter struct
+ * ixgbe_ptp_rx_pktstamp - utility function to get RX time stamp from buffer
+ * @q_vector: structure containing interrupt and ring information
+ * @skb: the packet
+ *
+ * This function will be called by the Rx routine of the timestamp for this
+ * packet is stored in the buffer. The value is stored in little endian format
+ * starting at the end of the packet data.
+ */
+void ixgbe_ptp_rx_pktstamp(struct ixgbe_q_vector *q_vector,
+			   struct sk_buff *skb)
+{
+	__le64 regval;
+
+	/* copy the bits out of the skb, and then trim the skb length */
+	skb_copy_bits(skb, skb->len - IXGBE_TS_HDR_LEN, &regval, IXGBE_TS_HDR_LEN);
+	__pskb_trim(skb, skb->len - IXGBE_TS_HDR_LEN);
+
+	/* The timestamp is recorded in little endian format, and is stored at
+	 * the end of the packet.
+	 *
+	 * DWORD: N              N + 1      N + 2
+	 * Field: End of Packet  SYSTIMH    SYSTIML
+	 */
+	ixgbe_ptp_convert_to_hwtstamp(q_vector->adapter, skb_hwtstamps(skb),
+				      le64_to_cpu(regval));
+}
+
+/**
+ * ixgbe_ptp_rx_rgtstamp - utility function which checks for RX time stamp
+ * @q_vector: structure containing interrupt and ring information
  * @skb: particular skb to send timestamp with
  *
  * if the timestamp is valid, we convert it into the timecounter ns
  * value, then store that result into the shhwtstamps structure which
  * is passed up the network stack
  */
-void ixgbe_ptp_rx_hwtstamp(struct ixgbe_adapter *adapter, struct sk_buff *skb)
+void ixgbe_ptp_rx_rgtstamp(struct ixgbe_q_vector *q_vector,
+			   struct sk_buff *skb)
 {
-	struct ixgbe_hw *hw = &adapter->hw;
-	struct skb_shared_hwtstamps *shhwtstamps;
-	u64 regval = 0, ns;
+	struct ixgbe_adapter *adapter;
+	struct ixgbe_hw *hw;
+	u64 regval = 0;
 	u32 tsyncrxctl;
-	unsigned long flags;
 
+	/* we cannot process timestamps on a ring without a q_vector */
+	if (!q_vector || !q_vector->adapter)
+		return;
+
+	adapter = q_vector->adapter;
+	hw = &adapter->hw;
+
+	/*
+	 * Read the tsyncrxctl register afterwards in order to prevent taking an
+	 * I/O hit on every packet.
+	 */
 	tsyncrxctl = IXGBE_READ_REG(hw, IXGBE_TSYNCRXCTL);
 	if (!(tsyncrxctl & IXGBE_TSYNCRXCTL_VALID))
 		return;
@@ -537,25 +856,24 @@ void ixgbe_ptp_rx_hwtstamp(struct ixgbe_adapter *adapter, struct sk_buff *skb)
 	regval |= (u64)IXGBE_READ_REG(hw, IXGBE_RXSTMPL);
 	regval |= (u64)IXGBE_READ_REG(hw, IXGBE_RXSTMPH) << 32;
 
-	spin_lock_irqsave(&adapter->tmreg_lock, flags);
-	ns = timecounter_cyc2time(&adapter->tc, regval);
-	spin_unlock_irqrestore(&adapter->tmreg_lock, flags);
-
-	shhwtstamps = skb_hwtstamps(skb);
-	shhwtstamps->hwtstamp = ns_to_ktime(ns);
-
-	/* Update the last_rx_timestamp timer in order to enable watchdog check
-	 * for error case of latched timestamp on a dropped packet.
-	 */
-	adapter->last_rx_timestamp = jiffies;
+	ixgbe_ptp_convert_to_hwtstamp(adapter, skb_hwtstamps(skb), regval);
 }
 
+/**
+ * ixgbe_ptp_get_ts_config - get current hardware timestamping configuration
+ * @adapter: pointer to adapter structure
+ * @ifreq: ioctl data
+ *
+ * This function returns the current timestamping settings. Rather than
+ * attempt to deconstruct registers to fill in the values, simply keep a copy
+ * of the old settings around, and return a copy when requested.
+ */
 int ixgbe_ptp_get_ts_config(struct ixgbe_adapter *adapter, struct ifreq *ifr)
 {
 	struct hwtstamp_config *config = &adapter->tstamp_config;
 
-	return copy_to_user(ifr->ifr_data, config,
-			    sizeof(*config)) ? -EFAULT : 0;
+	return copy_to_user(ifr->ifr_data, config, sizeof(*config)) ?
+		-EFAULT : 0;
 }
 
 /**
@@ -584,7 +902,7 @@ int ixgbe_ptp_get_ts_config(struct ixgbe_adapter *adapter, struct ifreq *ifr)
  * mode, if required to support the specifically requested mode.
  */
 static int ixgbe_ptp_set_timestamp_mode(struct ixgbe_adapter *adapter,
-				 struct hwtstamp_config *config)
+					struct hwtstamp_config *config)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	u32 tsync_tx_ctl = IXGBE_TSYNCTXCTL_ENABLED;
@@ -610,14 +928,20 @@ static int ixgbe_ptp_set_timestamp_mode(struct ixgbe_adapter *adapter,
 	case HWTSTAMP_FILTER_NONE:
 		tsync_rx_ctl = 0;
 		tsync_rx_mtrl = 0;
+		adapter->flags &= ~(IXGBE_FLAG_RX_HWTSTAMP_ENABLED |
+				    IXGBE_FLAG_RX_HWTSTAMP_IN_REGISTER);
 		break;
 	case HWTSTAMP_FILTER_PTP_V1_L4_SYNC:
 		tsync_rx_ctl |= IXGBE_TSYNCRXCTL_TYPE_L4_V1;
 		tsync_rx_mtrl |= IXGBE_RXMTRL_V1_SYNC_MSG;
+		adapter->flags |= (IXGBE_FLAG_RX_HWTSTAMP_ENABLED |
+				   IXGBE_FLAG_RX_HWTSTAMP_IN_REGISTER);
 		break;
 	case HWTSTAMP_FILTER_PTP_V1_L4_DELAY_REQ:
 		tsync_rx_ctl |= IXGBE_TSYNCRXCTL_TYPE_L4_V1;
 		tsync_rx_mtrl |= IXGBE_RXMTRL_V1_DELAY_REQ_MSG;
+		adapter->flags |= (IXGBE_FLAG_RX_HWTSTAMP_ENABLED |
+				   IXGBE_FLAG_RX_HWTSTAMP_IN_REGISTER);
 		break;
 	case HWTSTAMP_FILTER_PTP_V2_EVENT:
 	case HWTSTAMP_FILTER_PTP_V2_L2_EVENT:
@@ -631,26 +955,70 @@ static int ixgbe_ptp_set_timestamp_mode(struct ixgbe_adapter *adapter,
 		tsync_rx_ctl |= IXGBE_TSYNCRXCTL_TYPE_EVENT_V2;
 		is_l2 = true;
 		config->rx_filter = HWTSTAMP_FILTER_PTP_V2_EVENT;
+		adapter->flags |= (IXGBE_FLAG_RX_HWTSTAMP_ENABLED |
+				   IXGBE_FLAG_RX_HWTSTAMP_IN_REGISTER);
 		break;
 	case HWTSTAMP_FILTER_PTP_V1_L4_EVENT:
+#ifdef HAVE_HWTSTAMP_FILTER_NTP_ALL
+	case HWTSTAMP_FILTER_NTP_ALL:
+#endif /* HAVE_HWTSTAMP_FILTER_NTP_ALL */
 	case HWTSTAMP_FILTER_ALL:
+		/* The X550 controller is capable of timestamping all packets,
+		 * which allows it to accept any filter.
+		 */
+		if (hw->mac.type >= ixgbe_mac_X550) {
+			tsync_rx_ctl |= IXGBE_TSYNCRXCTL_TYPE_ALL;
+			config->rx_filter = HWTSTAMP_FILTER_ALL;
+			adapter->flags |= IXGBE_FLAG_RX_HWTSTAMP_ENABLED;
+			break;
+		}
+		/* fall through */
 	default:
-		/*
-		 * register RXMTRL must be set in order to do V1 packets,
+		/* register RXMTRL must be set in order to do V1 packets,
 		 * therefore it is not possible to time stamp both V1 Sync and
-		 * Delay_Req messages and hardware does not support
-		 * timestamping all packets => return error
+		 * Delay_Req messages unless hardware supports timestamping all
+		 * packets => return error
 		 */
+		adapter->flags &= ~(IXGBE_FLAG_RX_HWTSTAMP_ENABLED |
+				    IXGBE_FLAG_RX_HWTSTAMP_IN_REGISTER);
 		config->rx_filter = HWTSTAMP_FILTER_NONE;
 		return -ERANGE;
 	}
 
 	if (hw->mac.type == ixgbe_mac_82598EB) {
+		adapter->flags &= ~(IXGBE_FLAG_RX_HWTSTAMP_ENABLED |
+				    IXGBE_FLAG_RX_HWTSTAMP_IN_REGISTER);
 		if (tsync_rx_ctl | tsync_tx_ctl)
 			return -ERANGE;
 		return 0;
 	}
 
+	/* Per-packet timestamping only works if the filter is set to all
+	 * packets. Since this is desired, always timestamp all packets as long
+	 * as any Rx filter was configured.
+	 */
+	switch (hw->mac.type) {
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		/* enable timestamping all packets only if at least some
+		 * packets were requested. Otherwise, play nice and disable
+		 * timestamping */
+		if (config->rx_filter == HWTSTAMP_FILTER_NONE)
+			break;
+
+		tsync_rx_ctl = IXGBE_TSYNCRXCTL_ENABLED |
+			       IXGBE_TSYNCRXCTL_TYPE_ALL |
+			       IXGBE_TSYNCRXCTL_TSIP_UT_EN;
+		config->rx_filter = HWTSTAMP_FILTER_ALL;
+		adapter->flags |= IXGBE_FLAG_RX_HWTSTAMP_ENABLED;
+		adapter->flags &= ~IXGBE_FLAG_RX_HWTSTAMP_IN_REGISTER;
+		is_l2 = true;
+		break;
+	default:
+		break;
+	}
+
 	/* define ethertype filter for timestamping L2 packets */
 	if (is_l2)
 		IXGBE_WRITE_REG(hw, IXGBE_ETQF(IXGBE_ETQF_FILTER_1588),
@@ -677,9 +1045,9 @@ static int ixgbe_ptp_set_timestamp_mode(struct ixgbe_adapter *adapter,
 
 	IXGBE_WRITE_FLUSH(hw);
 
-	/* clear TX/RX time stamp registers, just to be sure */
-	regval = IXGBE_READ_REG(hw, IXGBE_TXSTMPH);
-	regval = IXGBE_READ_REG(hw, IXGBE_RXSTMPH);
+	/* clear TX/RX timestamp state, just to be sure */
+	ixgbe_ptp_clear_tx_timestamp(adapter);
+	IXGBE_READ_REG(hw, IXGBE_RXSTMPH);
 
 	return 0;
 }
@@ -712,23 +1080,9 @@ int ixgbe_ptp_set_ts_config(struct ixgbe_adapter *adapter, struct ifreq *ifr)
 		-EFAULT : 0;
 }
 
-/**
- * ixgbe_ptp_start_cyclecounter - create the cycle counter from hw
- * @adapter: pointer to the adapter structure
- *
- * This function should be called to set the proper values for the TIMINCA
- * register and tell the cyclecounter structure what the tick rate of SYSTIME
- * is. It does not directly modify SYSTIME registers or the timecounter
- * structure. It should be called whenever a new TIMINCA value is necessary,
- * such as during initialization or when the link speed changes.
- */
-void ixgbe_ptp_start_cyclecounter(struct ixgbe_adapter *adapter)
+static void ixgbe_ptp_link_speed_adjust(struct ixgbe_adapter *adapter,
+					u32 *shift, u32 *incval)
 {
-	struct ixgbe_hw *hw = &adapter->hw;
-	u32 incval = 0;
-	u32 shift = 0;
-	unsigned long flags;
-
 	/**
 	 * Scale the NIC cycle counter by a large factor so that
 	 * relatively small corrections to the frequency can be added
@@ -745,33 +1099,98 @@ void ixgbe_ptp_start_cyclecounter(struct ixgbe_adapter *adapter)
 	 */
 	switch (adapter->link_speed) {
 	case IXGBE_LINK_SPEED_100_FULL:
-		incval = IXGBE_INCVAL_100;
-		shift = IXGBE_INCVAL_SHIFT_100;
+		*shift = IXGBE_INCVAL_SHIFT_100;
+		*incval = IXGBE_INCVAL_100;
 		break;
 	case IXGBE_LINK_SPEED_1GB_FULL:
-		incval = IXGBE_INCVAL_1GB;
-		shift = IXGBE_INCVAL_SHIFT_1GB;
+		*shift = IXGBE_INCVAL_SHIFT_1GB;
+		*incval = IXGBE_INCVAL_1GB;
 		break;
 	case IXGBE_LINK_SPEED_10GB_FULL:
 	default:
-		incval = IXGBE_INCVAL_10GB;
-		shift = IXGBE_INCVAL_SHIFT_10GB;
+		*shift = IXGBE_INCVAL_SHIFT_10GB;
+		*incval = IXGBE_INCVAL_10GB;
 		break;
 	}
 
-	/**
-	 * Modify the calculated values to fit within the correct
-	 * number of bits specified by the hardware. The 82599 doesn't
-	 * have the same space as the X540, so bitshift the calculated
-	 * values to fit.
+	return;
+}
+
+/**
+ * ixgbe_ptp_start_cyclecounter - create the cycle counter from hw
+ * @adapter: pointer to the adapter structure
+ *
+ * This function should be called to set the proper values for the TIMINCA
+ * register and tell the cyclecounter structure what the tick rate of SYSTIME
+ * is. It does not directly modify SYSTIME registers or the timecounter
+ * structure. It should be called whenever a new TIMINCA value is necessary,
+ * such as during initialization or when the link speed changes.
+ */
+void ixgbe_ptp_start_cyclecounter(struct ixgbe_adapter *adapter)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	unsigned long flags;
+	struct cyclecounter cc;
+	u32 incval = 0;
+	u32 tsauxc = 0, fuse0 = 0;
+
+	/* For some of the boards below this mask is technically incorrect.
+	 * The timestamp mask overflows at approximately 61bits. However the
+	 * particular hardware does not overflow on an even bitmask value.
+	 * Instead, it overflows due to conversion of upper 32bits billions of
+	 * cycles. Timecounters are not really intended for this purpose so
+	 * they do not properly function if the overflow point isn't 2^N-1.
+	 * However, the actual SYSTIME values in question take ~138 years to
+	 * overflow. In practice this means they won't actually overflow. A
+	 * proper fix to this problem would require modification of the
+	 * timecounter delta calculations.
 	 */
+	cc.mask = CLOCKSOURCE_MASK(64);
+	cc.mult = 1;
+	cc.shift = 0;
+
 	switch (hw->mac.type) {
+	case ixgbe_mac_X550EM_x:
+		/* SYSTIME assumes X550EM_x board frequency is 300Mhz, and is
+		 * designed to represent seconds and nanoseconds when this is
+		 * the case. However, some revisions of hardware have a 400Mhz
+		 * clock and we have to compensate for this frequency
+		 * variation using corrected mult and shift values.
+		 */
+		fuse0 = IXGBE_READ_REG(hw, IXGBE_FUSES0_GROUP(0));
+		if (!(fuse0 & IXGBE_FUSES0_300MHZ)) {
+			cc.mult = 3;
+			cc.shift = 2;
+		}
+		/* fallthrough */
+	case ixgbe_mac_X550EM_a:
+	case ixgbe_mac_X550:
+		cc.read = ixgbe_ptp_read_X550;
+
+		/* enable SYSTIME counter */
+		IXGBE_WRITE_REG(hw, IXGBE_SYSTIMR, 0);
+		IXGBE_WRITE_REG(hw, IXGBE_SYSTIML, 0);
+		IXGBE_WRITE_REG(hw, IXGBE_SYSTIMH, 0);
+		tsauxc = IXGBE_READ_REG(hw, IXGBE_TSAUXC);
+		IXGBE_WRITE_REG(hw, IXGBE_TSAUXC,
+				tsauxc & ~IXGBE_TSAUXC_DISABLE_SYSTIME);
+		IXGBE_WRITE_REG(hw, IXGBE_TSIM, IXGBE_TSIM_TXTS);
+		IXGBE_WRITE_REG(hw, IXGBE_EIMS, IXGBE_EIMS_TIMESYNC);
+
+		IXGBE_WRITE_FLUSH(hw);
+		break;
 	case ixgbe_mac_X540:
+		cc.read = ixgbe_ptp_read_82599;
+
+		ixgbe_ptp_link_speed_adjust(adapter, &cc.shift, &incval);
 		IXGBE_WRITE_REG(hw, IXGBE_TIMINCA, incval);
 		break;
 	case ixgbe_mac_82599EB:
+		cc.read = ixgbe_ptp_read_82599;
+
+		ixgbe_ptp_link_speed_adjust(adapter, &cc.shift, &incval);
 		incval >>= IXGBE_INCVAL_SHIFT_82599;
-		shift -= IXGBE_INCVAL_SHIFT_82599;
+		cc.shift -= IXGBE_INCVAL_SHIFT_82599;
 		IXGBE_WRITE_REG(hw, IXGBE_TIMINCA,
 				(1 << IXGBE_INCPER_SHIFT_82599) |
 				incval);
@@ -787,13 +1206,7 @@ void ixgbe_ptp_start_cyclecounter(struct ixgbe_adapter *adapter)
 
 	/* need lock to prevent incorrect read while modifying cyclecounter */
 	spin_lock_irqsave(&adapter->tmreg_lock, flags);
-
-	memset(&adapter->cc, 0, sizeof(adapter->cc));
-	adapter->cc.read = ixgbe_ptp_read;
-	adapter->cc.mask = CYCLECOUNTER_MASK(64);
-	adapter->cc.shift = shift;
-	adapter->cc.mult = 1;
-
+	memcpy(&adapter->hw_cc, &cc, sizeof(adapter->hw_cc));
 	spin_unlock_irqrestore(&adapter->tmreg_lock, flags);
 }
 
@@ -801,55 +1214,55 @@ void ixgbe_ptp_start_cyclecounter(struct ixgbe_adapter *adapter)
  * ixgbe_ptp_reset
  * @adapter: the ixgbe private board structure
  *
- * When the MAC resets, all the hardware bits for timesync are reset. This
- * function is used to re-enable the device for PTP based on current settings.
- * We do lose the current clock time, so just reset the cyclecounter to the
- * system real clock time.
+ * When the MAC resets, all of the hardware configuration for timesync is
+ * reset. This function should be called to re-enable the device for PTP,
+ * using the last known settings. However, we do lose the current clock time,
+ * so we fallback to resetting it based on the kernel's realtime clock.
  *
- * This function will maintain hwtstamp_config settings, and resets the SDP
- * output if it was enabled.
+ * This function will maintain the hwtstamp_config settings, and it retriggers
+ * the SDP output if it's enabled.
  */
 void ixgbe_ptp_reset(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	unsigned long flags;
 
-	/* set SYSTIME registers to 0 just in case */
-	IXGBE_WRITE_REG(hw, IXGBE_SYSTIML, 0x00000000);
-	IXGBE_WRITE_REG(hw, IXGBE_SYSTIMH, 0x00000000);
-	IXGBE_WRITE_FLUSH(hw);
-
 	/* reset the hardware timestamping mode */
 	ixgbe_ptp_set_timestamp_mode(adapter, &adapter->tstamp_config);
 
+	/* 82598 does not support PTP */
+	if (hw->mac.type == ixgbe_mac_82598EB)
+		return;
+
 	ixgbe_ptp_start_cyclecounter(adapter);
 
 	spin_lock_irqsave(&adapter->tmreg_lock, flags);
-
-	/* reset the ns time counter */
-	timecounter_init(&adapter->tc, &adapter->cc,
+	timecounter_init(&adapter->hw_tc, &adapter->hw_cc,
 			 ktime_to_ns(ktime_get_real()));
-
 	spin_unlock_irqrestore(&adapter->tmreg_lock, flags);
 
+	adapter->last_overflow_check = jiffies;
+
 	/*
 	 * Now that the shift has been calculated and the systime
 	 * registers reset, (re-)enable the Clock out feature
 	 */
-	ixgbe_ptp_setup_sdp(adapter);
+	if (adapter->ptp_setup_sdp)
+		adapter->ptp_setup_sdp(adapter);
 }
 
 /**
  * ixgbe_ptp_create_clock
  * @adapter: the ixgbe private adapter structure
  *
- * This function performs setup of the user entry point function table and
- * initializes the PTP clock device, which is used to access the clock-like
- * features of the PTP core. It will be called by ixgbe_ptp_init, only if
- * there isn't already a clock device (such as after a suspend/resume cycle,
- * where the clock device wasn't destroyed).
+ * This functino performs setup of the user entry point function table and
+ * initalizes the PTP clock device used by userspace to access the clock-like
+ * features of the PTP core. It will be called by ixgbe_ptp_init, and may
+ * re-use a previously initialized clock (such as during a suspend/resume
+ * cycle).
  */
-static int ixgbe_ptp_create_clock(struct ixgbe_adapter *adapter)
+
+static long ixgbe_ptp_create_clock(struct ixgbe_adapter *adapter)
 {
 	struct net_device *netdev = adapter->netdev;
 	long err;
@@ -869,11 +1282,17 @@ static int ixgbe_ptp_create_clock(struct ixgbe_adapter *adapter)
 		adapter->ptp_caps.n_ext_ts = 0;
 		adapter->ptp_caps.n_per_out = 0;
 		adapter->ptp_caps.pps = 1;
-		adapter->ptp_caps.adjfreq = ixgbe_ptp_adjfreq;
-		adapter->ptp_caps.adjtime = ixgbe_ptp_adjtime;
-		adapter->ptp_caps.gettime64 = ixgbe_ptp_gettime;
-		adapter->ptp_caps.settime64 = ixgbe_ptp_settime;
+		adapter->ptp_caps.adjfreq = ixgbe_ptp_adjfreq_82599;
+		adapter->ptp_caps.adjtime = ixgbe_ptp_adjtime_timecounter;
+#ifdef HAVE_PTP_CLOCK_INFO_GETTIME64
+		adapter->ptp_caps.gettime64 = ixgbe_ptp_gettime64_timecounter;
+		adapter->ptp_caps.settime64 = ixgbe_ptp_settime64_timecounter;
+#else
+		adapter->ptp_caps.gettime = ixgbe_ptp_gettime_timecounter;
+		adapter->ptp_caps.settime = ixgbe_ptp_settime_timecounter;
+#endif
 		adapter->ptp_caps.enable = ixgbe_ptp_feature_enable;
+		adapter->ptp_setup_sdp = ixgbe_ptp_setup_sdp_X540;
 		break;
 	case ixgbe_mac_82599EB:
 		snprintf(adapter->ptp_caps.name,
@@ -885,30 +1304,58 @@ static int ixgbe_ptp_create_clock(struct ixgbe_adapter *adapter)
 		adapter->ptp_caps.n_ext_ts = 0;
 		adapter->ptp_caps.n_per_out = 0;
 		adapter->ptp_caps.pps = 0;
-		adapter->ptp_caps.adjfreq = ixgbe_ptp_adjfreq;
-		adapter->ptp_caps.adjtime = ixgbe_ptp_adjtime;
-		adapter->ptp_caps.gettime64 = ixgbe_ptp_gettime;
-		adapter->ptp_caps.settime64 = ixgbe_ptp_settime;
+		adapter->ptp_caps.adjfreq = ixgbe_ptp_adjfreq_82599;
+		adapter->ptp_caps.adjtime = ixgbe_ptp_adjtime_timecounter;
+#ifdef HAVE_PTP_CLOCK_INFO_GETTIME64
+		adapter->ptp_caps.gettime64 = ixgbe_ptp_gettime64_timecounter;
+		adapter->ptp_caps.settime64 = ixgbe_ptp_settime64_timecounter;
+#else
+		adapter->ptp_caps.gettime = ixgbe_ptp_gettime_timecounter;
+		adapter->ptp_caps.settime = ixgbe_ptp_settime_timecounter;
+#endif
+		adapter->ptp_caps.enable = ixgbe_ptp_feature_enable;
+		break;
+	case ixgbe_mac_X550:
+	case ixgbe_mac_X550EM_x:
+	case ixgbe_mac_X550EM_a:
+		snprintf(adapter->ptp_caps.name, 16, "%s", netdev->name);
+		adapter->ptp_caps.owner = THIS_MODULE;
+		adapter->ptp_caps.max_adj = 30000000;
+		adapter->ptp_caps.n_alarm = 0;
+		adapter->ptp_caps.n_ext_ts = 0;
+		adapter->ptp_caps.n_per_out = 0;
+		adapter->ptp_caps.pps = 0;
+		adapter->ptp_caps.adjfreq = ixgbe_ptp_adjfreq_X550;
+		adapter->ptp_caps.adjtime = ixgbe_ptp_adjtime_timecounter;
+#ifdef HAVE_PTP_CLOCK_INFO_GETTIME64
+		adapter->ptp_caps.gettime64 = ixgbe_ptp_gettime64_timecounter;
+		adapter->ptp_caps.settime64 = ixgbe_ptp_settime64_timecounter;
+#else
+		adapter->ptp_caps.gettime = ixgbe_ptp_gettime_timecounter;
+		adapter->ptp_caps.settime = ixgbe_ptp_settime_timecounter;
+#endif
 		adapter->ptp_caps.enable = ixgbe_ptp_feature_enable;
+		adapter->ptp_setup_sdp = NULL;
 		break;
 	default:
 		adapter->ptp_clock = NULL;
+		adapter->ptp_setup_sdp = NULL;
 		return -EOPNOTSUPP;
 	}
 
 	adapter->ptp_clock = ptp_clock_register(&adapter->ptp_caps,
-						&adapter->pdev->dev);
+						pci_dev_to_dev(adapter->pdev));
 	if (IS_ERR(adapter->ptp_clock)) {
 		err = PTR_ERR(adapter->ptp_clock);
 		adapter->ptp_clock = NULL;
 		e_dev_err("ptp_clock_register failed\n");
 		return err;
-	} else
+	} else if (adapter->ptp_clock)
 		e_dev_info("registered PHC device on %s\n", netdev->name);
 
-	/* set default timestamp mode to disabled here. We do this in
-	 * create_clock instead of init, because we don't want to override the
-	 * previous settings during a resume cycle.
+	/* Set the default timestamp mode to disabled here. We do this in
+	 * create_clock instead of initialization, because we don't want to
+	 * override the previous settings during a suspend/resume cycle.
 	 */
 	adapter->tstamp_config.rx_filter = HWTSTAMP_FILTER_NONE;
 	adapter->tstamp_config.tx_type = HWTSTAMP_TX_OFF;
@@ -920,26 +1367,25 @@ static int ixgbe_ptp_create_clock(struct ixgbe_adapter *adapter)
  * ixgbe_ptp_init
  * @adapter: the ixgbe private adapter structure
  *
- * This function performs the required steps for enabling PTP
- * support. If PTP support has already been loaded it simply calls the
+ * This function performs the required steps for enabling ptp
+ * support. If ptp support has already been loaded it simply calls the
  * cyclecounter init routine and exits.
  */
 void ixgbe_ptp_init(struct ixgbe_adapter *adapter)
 {
-	/* initialize the spin lock first since we can't control when a user
-	 * will call the entry functions once we have initialized the clock
-	 * device
+	/* initialize the spin lock first, since the user might call the clock
+	 * functions any time after we've initialized the ptp clock device.
 	 */
 	spin_lock_init(&adapter->tmreg_lock);
 
-	/* obtain a PTP device, or re-use an existing device */
+	/* obtain a ptp clock device, or re-use an existing device */
 	if (ixgbe_ptp_create_clock(adapter))
 		return;
 
-	/* we have a clock so we can initialize work now */
+	/* we have a clock, so we can intialize work for timestamps now */
 	INIT_WORK(&adapter->ptp_tx_work, ixgbe_ptp_tx_hwtstamp_work);
 
-	/* reset the PTP related hardware bits */
+	/* reset the ptp related hardware bits */
 	ixgbe_ptp_reset(adapter);
 
 	/* enter the IXGBE_PTP_RUNNING state */
@@ -949,45 +1395,39 @@ void ixgbe_ptp_init(struct ixgbe_adapter *adapter)
 }
 
 /**
- * ixgbe_ptp_suspend - stop PTP work items
- * @ adapter: pointer to adapter struct
+ * ixgbe_ptp_suspend - stop ptp work items
+ * @adapter: pointer to adapter struct
  *
- * this function suspends PTP activity, and prevents more PTP work from being
- * generated, but does not destroy the PTP clock device.
+ * This function suspends ptp activity, and prevents more work from being
+ * generated, but does not destroy the clock device.
  */
 void ixgbe_ptp_suspend(struct ixgbe_adapter *adapter)
 {
-	/* Leave the IXGBE_PTP_RUNNING state. */
+	/* leave the IXGBE_PTP_RUNNING STATE */
 	if (!test_and_clear_bit(__IXGBE_PTP_RUNNING, &adapter->state))
 		return;
 
-	/* since this might be called in suspend, we don't clear the state,
-	 * but simply reset the auxiliary PPS signal control register
-	 */
-	IXGBE_WRITE_REG(&adapter->hw, IXGBE_TSAUXC, 0x0);
+	adapter->flags2 &= ~IXGBE_FLAG2_PTP_PPS_ENABLED;
+	if (adapter->ptp_setup_sdp)
+		adapter->ptp_setup_sdp(adapter);
 
-	/* ensure that we cancel any pending PTP Tx work item in progress */
 	cancel_work_sync(&adapter->ptp_tx_work);
-	if (adapter->ptp_tx_skb) {
-		dev_kfree_skb_any(adapter->ptp_tx_skb);
-		adapter->ptp_tx_skb = NULL;
-		clear_bit_unlock(__IXGBE_PTP_TX_IN_PROGRESS, &adapter->state);
-	}
+	ixgbe_ptp_clear_tx_timestamp(adapter);
 }
 
 /**
- * ixgbe_ptp_stop - close the PTP device
+ * ixgbe_ptp_stop - destroy the ptp_clock device
  * @adapter: pointer to adapter struct
  *
- * completely destroy the PTP device, should only be called when the device is
- * being fully closed.
+ * Completely destroy the ptp_clock device, and disable all PTP related
+ * features. Intended to be run when the device is being closed.
  */
 void ixgbe_ptp_stop(struct ixgbe_adapter *adapter)
 {
-	/* first, suspend PTP activity */
+	/* first, suspend ptp activity */
 	ixgbe_ptp_suspend(adapter);
 
-	/* disable the PTP clock device */
+	/* now destroy the ptp clock device */
 	if (adapter->ptp_clock) {
 		ptp_clock_unregister(adapter->ptp_clock);
 		adapter->ptp_clock = NULL;
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_sriov.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_sriov.c
index fcd8b27..6938381 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_sriov.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_sriov.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,6 +22,7 @@
 
 *******************************************************************************/
 
+
 #include <linux/types.h>
 #include <linux/module.h>
 #include <linux/pci.h>
@@ -36,98 +33,155 @@
 #include <linux/ip.h>
 #include <linux/tcp.h>
 #include <linux/ipv6.h>
-#include <linux/if_bridge.h>
-#ifdef NETIF_F_HW_VLAN_CTAG_TX
-#include <linux/if_vlan.h>
-#endif
 
 #include "ixgbe.h"
 #include "ixgbe_type.h"
 #include "ixgbe_sriov.h"
 
 #ifdef CONFIG_PCI_IOV
-static int __ixgbe_enable_sriov(struct ixgbe_adapter *adapter)
+static inline void ixgbe_alloc_vf_macvlans(struct ixgbe_adapter *adapter,
+					   unsigned int num_vfs)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
-	int num_vf_macvlans, i;
 	struct vf_macvlans *mv_list;
-
-	adapter->flags |= IXGBE_FLAG_SRIOV_ENABLED;
-	e_info(probe, "SR-IOV enabled with %d VFs\n", adapter->num_vfs);
-
-	/* Enable VMDq flag so device will be set in VM mode */
-	adapter->flags |= IXGBE_FLAG_VMDQ_ENABLED;
-	if (!adapter->ring_feature[RING_F_VMDQ].limit)
-		adapter->ring_feature[RING_F_VMDQ].limit = 1;
-	adapter->ring_feature[RING_F_VMDQ].offset = adapter->num_vfs;
+	int num_vf_macvlans, i;
 
 	num_vf_macvlans = hw->mac.num_rar_entries -
-	(IXGBE_MAX_PF_MACVLANS + 1 + adapter->num_vfs);
+			  (IXGBE_MAX_PF_MACVLANS + 1 + num_vfs);
+	if (!num_vf_macvlans)
+		return;
 
-	adapter->mv_list = mv_list = kcalloc(num_vf_macvlans,
-					     sizeof(struct vf_macvlans),
-					     GFP_KERNEL);
+	mv_list = kcalloc(num_vf_macvlans, sizeof(struct vf_macvlans),
+			  GFP_KERNEL);
 	if (mv_list) {
 		/* Initialize list of VF macvlans */
 		INIT_LIST_HEAD(&adapter->vf_mvs.l);
 		for (i = 0; i < num_vf_macvlans; i++) {
-			mv_list->vf = -1;
-			mv_list->free = true;
-			list_add(&mv_list->l, &adapter->vf_mvs.l);
-			mv_list++;
+			mv_list[i].vf = -1;
+			mv_list[i].free = true;
+			list_add(&mv_list[i].l, &adapter->vf_mvs.l);
 		}
+		adapter->mv_list = mv_list;
 	}
+}
+
+static int __ixgbe_enable_sriov(struct ixgbe_adapter *adapter,
+				unsigned int num_vfs)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	int i;
+
+	adapter->flags |= IXGBE_FLAG_SRIOV_ENABLED;
+
+	/* Enable VMDq flag so device will be set in VM mode */
+	adapter->flags |= IXGBE_FLAG_VMDQ_ENABLED;
+	if (!adapter->ring_feature[RING_F_VMDQ].limit)
+		adapter->ring_feature[RING_F_VMDQ].limit = 1;
+
+	/* Allocate memory for per VF control structures */
+	adapter->vfinfo = kcalloc(num_vfs, sizeof(struct vf_data_storage),
+				  GFP_KERNEL);
+	if (!adapter->vfinfo)
+		return -ENOMEM;
 
 	/* Initialize default switching mode VEB */
 	IXGBE_WRITE_REG(hw, IXGBE_PFDTXGSWC, IXGBE_PFDTXGSWC_VT_LBEN);
-	adapter->bridge_mode = BRIDGE_MODE_VEB;
 
-	/* If call to enable VFs succeeded then allocate memory
-	 * for per VF control structures.
+	/* set adapter->num_vfs only after allocating vfinfo to avoid
+	 * NULL pointer issues when accessing adapter->vfinfo
 	 */
-	adapter->vfinfo =
-		kcalloc(adapter->num_vfs,
-			sizeof(struct vf_data_storage), GFP_KERNEL);
-	if (adapter->vfinfo) {
-		/* limit trafffic classes based on VFs enabled */
-		if ((adapter->hw.mac.type == ixgbe_mac_82599EB) &&
-		    (adapter->num_vfs < 16)) {
-			adapter->dcb_cfg.num_tcs.pg_tcs = MAX_TRAFFIC_CLASS;
-			adapter->dcb_cfg.num_tcs.pfc_tcs = MAX_TRAFFIC_CLASS;
-		} else if (adapter->num_vfs < 32) {
-			adapter->dcb_cfg.num_tcs.pg_tcs = 4;
-			adapter->dcb_cfg.num_tcs.pfc_tcs = 4;
-		} else {
-			adapter->dcb_cfg.num_tcs.pg_tcs = 1;
-			adapter->dcb_cfg.num_tcs.pfc_tcs = 1;
-		}
+	adapter->num_vfs = num_vfs;
 
-		/* Disable RSC when in SR-IOV mode */
-		adapter->flags2 &= ~(IXGBE_FLAG2_RSC_CAPABLE |
-				     IXGBE_FLAG2_RSC_ENABLED);
+	ixgbe_alloc_vf_macvlans(adapter, num_vfs);
 
-		for (i = 0; i < adapter->num_vfs; i++) {
-			/* enable spoof checking for all VFs */
-			adapter->vfinfo[i].spoofchk_enabled = true;
+	adapter->ring_feature[RING_F_VMDQ].offset = num_vfs;
 
-			/* We support VF RSS querying only for 82599 and x540
-			 * devices at the moment. These devices share RSS
-			 * indirection table and RSS hash key with PF therefore
-			 * we want to disable the querying by default.
-			 */
-			adapter->vfinfo[i].rss_query_enabled = 0;
+	/* enable L2 switch and replication */
+	adapter->flags |= IXGBE_FLAG_SRIOV_L2SWITCH_ENABLE |
+				IXGBE_FLAG_SRIOV_REPLICATION_ENABLE;
 
-			/* Untrust all VFs */
-			adapter->vfinfo[i].trusted = false;
+	/* limit traffic classes based on VFs enabled */
+	if ((adapter->hw.mac.type == ixgbe_mac_82599EB) &&
+		(adapter->num_vfs < 16)) {
+		adapter->dcb_cfg.num_tcs.pg_tcs =
+			IXGBE_DCB_MAX_TRAFFIC_CLASS;
+		adapter->dcb_cfg.num_tcs.pfc_tcs =
+			IXGBE_DCB_MAX_TRAFFIC_CLASS;
+	} else if (adapter->num_vfs < 32) {
+		adapter->dcb_cfg.num_tcs.pg_tcs = 4;
+		adapter->dcb_cfg.num_tcs.pfc_tcs = 4;
+	} else {
+		adapter->dcb_cfg.num_tcs.pg_tcs = 1;
+		adapter->dcb_cfg.num_tcs.pfc_tcs = 1;
+	}
+	adapter->dcb_cfg.vt_mode = true;
 
-			/* set the default xcast mode */
-			adapter->vfinfo[i].xcast_mode = IXGBEVF_XCAST_MODE_NONE;
-		}
+#ifdef IXGBE_DISABLE_VF_MQ
+	/* We do not support RSS w/ SR-IOV */
+	adapter->ring_feature[RING_F_RSS].limit = 1;
+#endif
 
-		return 0;
+	/* Disable RSC when in SR-IOV mode */
+	adapter->flags2 &= ~(IXGBE_FLAG2_RSC_CAPABLE |
+				IXGBE_FLAG2_RSC_ENABLED);
+
+	for (i = 0; i < adapter->num_vfs; i++) {
+		/* enable spoof checking for all VFs */
+		adapter->vfinfo[i].spoofchk_enabled = true;
+
+#ifdef HAVE_NDO_SET_VF_RSS_QUERY_EN
+		/* We support VF RSS querying only for 82599 and x540
+		 * devices at the moment. These devices share RSS
+		 * indirection table and RSS hash key with PF therefore
+		 * we want to disable the querying by default.
+		 */
+		adapter->vfinfo[i].rss_query_enabled = 0;
+
+#endif
+		/* Untrust all VFs */
+		adapter->vfinfo[i].trusted = false;
+
+		/* set the default xcast mode */
+		adapter->vfinfo[i].xcast_mode = IXGBEVF_XCAST_MODE_NONE;
 	}
 
-	return -ENOMEM;
+	e_dev_info("SR-IOV enabled with %d VFs\n", num_vfs);
+	if (hw->mac.type < ixgbe_mac_X550)
+		e_dev_info("configure port vlans to keep your VFs secure\n");
+
+	return 0;
+}
+
+/**
+ * ixgbe_get_vfs - Find and take references to all vf devices
+ * @adapter: Pointer to adapter struct
+ */
+static void ixgbe_get_vfs(struct ixgbe_adapter *adapter)
+{
+	struct pci_dev *pdev = adapter->pdev;
+	u16 vendor = pdev->vendor;
+	struct pci_dev *vfdev;
+	int vf = 0;
+	u16 vf_id;
+	int pos;
+
+	pos = pci_find_ext_capability(pdev, PCI_EXT_CAP_ID_SRIOV);
+	if (!pos)
+		return;
+	pci_read_config_word(pdev, pos + PCI_SRIOV_VF_DID, &vf_id);
+
+	vfdev = pci_get_device(vendor, vf_id, NULL);
+	for (; vfdev; vfdev = pci_get_device(vendor, vf_id, vfdev)) {
+		if (!vfdev->is_virtfn)
+			continue;
+		if (vfdev->physfn != pdev)
+			continue;
+		if (vf >= adapter->num_vfs)
+			continue;
+		pci_dev_get(vfdev);
+		adapter->vfinfo[vf].vfdev = vfdev;
+		++vf;
+	}
 }
 
 /* Note this function is called when the user wants to enable SR-IOV
@@ -136,9 +190,10 @@ static int __ixgbe_enable_sriov(struct ixgbe_adapter *adapter)
 void ixgbe_enable_sriov(struct ixgbe_adapter *adapter)
 {
 	int pre_existing_vfs = 0;
+	unsigned int num_vfs;
 
 	pre_existing_vfs = pci_num_vf(adapter->pdev);
-	if (!pre_existing_vfs && !adapter->num_vfs)
+	if (!pre_existing_vfs && !adapter->max_vfs)
 		return;
 
 	/* If there are pre-existing VFs then we have to force
@@ -148,7 +203,7 @@ void ixgbe_enable_sriov(struct ixgbe_adapter *adapter)
 	 * have been created via the new PCI SR-IOV sysfs interface.
 	 */
 	if (pre_existing_vfs) {
-		adapter->num_vfs = pre_existing_vfs;
+		num_vfs = pre_existing_vfs;
 		dev_warn(&adapter->pdev->dev,
 			 "Virtual Functions already enabled for this device - Please reload all VF drivers to avoid spoofed packet errors\n");
 	} else {
@@ -157,41 +212,52 @@ void ixgbe_enable_sriov(struct ixgbe_adapter *adapter)
 		 * The 82599 supports up to 64 VFs per physical function
 		 * but this implementation limits allocation to 63 so that
 		 * basic networking resources are still available to the
-		 * physical function.  If the user requests greater than
+		 * physical function.  If the user requests greater thn
 		 * 63 VFs then it is an error - reset to default of zero.
 		 */
-		adapter->num_vfs = min_t(unsigned int, adapter->num_vfs, IXGBE_MAX_VFS_DRV_LIMIT);
+		num_vfs = min_t(unsigned int, adapter->max_vfs,
+				IXGBE_MAX_VFS_DRV_LIMIT);
 
-		err = pci_enable_sriov(adapter->pdev, adapter->num_vfs);
+		err = pci_enable_sriov(adapter->pdev, num_vfs);
 		if (err) {
 			e_err(probe, "Failed to enable PCI sriov: %d\n", err);
-			adapter->num_vfs = 0;
 			return;
 		}
 	}
 
-	if (!__ixgbe_enable_sriov(adapter))
+	if (!__ixgbe_enable_sriov(adapter, num_vfs)) {
+		ixgbe_get_vfs(adapter);
 		return;
+	}
 
 	/* If we have gotten to this point then there is no memory available
 	 * to manage the VF devices - print message and bail.
 	 */
-	e_err(probe, "Unable to allocate memory for VF Data Storage - "
-	      "SRIOV disabled\n");
+	e_err(probe, "Unable to allocate memory for VF Data Storage - SRIOV disabled\n");
 	ixgbe_disable_sriov(adapter);
 }
 
-#endif /* #ifdef CONFIG_PCI_IOV */
+#endif /* CONFIG_PCI_IOV */
 int ixgbe_disable_sriov(struct ixgbe_adapter *adapter)
 {
+	unsigned int num_vfs = adapter->num_vfs, vf;
 	struct ixgbe_hw *hw = &adapter->hw;
 	u32 gpie;
 	u32 vmdctl;
-	int rss;
 
 	/* set num VFs to 0 to prevent access to vfinfo */
 	adapter->num_vfs = 0;
 
+	/* put the reference to all of the vf devices */
+	for (vf = 0; vf < num_vfs; ++vf) {
+		struct pci_dev *vfdev = adapter->vfinfo[vf].vfdev;
+
+		if (!vfdev)
+			continue;
+		adapter->vfinfo[vf].vfdev = NULL;
+		pci_dev_put(vfdev);
+	}
+
 	/* free VF control structures */
 	kfree(adapter->vfinfo);
 	adapter->vfinfo = NULL;
@@ -204,6 +270,11 @@ int ixgbe_disable_sriov(struct ixgbe_adapter *adapter)
 	if (!(adapter->flags & IXGBE_FLAG_SRIOV_ENABLED))
 		return 0;
 
+	/* Turn off malicious driver detection */
+	if ((hw->mac.ops.disable_mdd) &&
+		(!(adapter->flags & IXGBE_FLAG_MDD_ENABLED)))
+		hw->mac.ops.disable_mdd(hw);
+
 #ifdef CONFIG_PCI_IOV
 	/*
 	 * If our VFs are assigned we cannot shut down SR-IOV
@@ -231,70 +302,98 @@ int ixgbe_disable_sriov(struct ixgbe_adapter *adapter)
 	IXGBE_WRITE_FLUSH(hw);
 
 	/* Disable VMDq flag so device will be set in VM mode */
-	if (adapter->ring_feature[RING_F_VMDQ].limit == 1) {
+	if (adapter->ring_feature[RING_F_VMDQ].limit == 1)
 		adapter->flags &= ~IXGBE_FLAG_VMDQ_ENABLED;
-		adapter->flags &= ~IXGBE_FLAG_SRIOV_ENABLED;
-		rss = min_t(int, ixgbe_max_rss_indices(adapter),
-			    num_online_cpus());
-	} else {
-		rss = min_t(int, IXGBE_MAX_L2A_QUEUES, num_online_cpus());
-	}
 
+	adapter->flags &= ~IXGBE_FLAG_SRIOV_ENABLED;
 	adapter->ring_feature[RING_F_VMDQ].offset = 0;
-	adapter->ring_feature[RING_F_RSS].limit = rss;
 
 	/* take a breather then clean up driver data */
 	msleep(100);
 	return 0;
 }
 
-static int ixgbe_pci_sriov_enable(struct pci_dev *dev, int num_vfs)
+static int ixgbe_pci_sriov_enable(struct pci_dev __maybe_unused *dev, int __maybe_unused num_vfs)
 {
 #ifdef CONFIG_PCI_IOV
 	struct ixgbe_adapter *adapter = pci_get_drvdata(dev);
 	int err = 0;
+	u8 num_tc;
 	int i;
 	int pre_existing_vfs = pci_num_vf(dev);
 
+	if (!(adapter->flags & IXGBE_FLAG_SRIOV_CAPABLE)) {
+		e_dev_warn("SRIOV not supported on this device\n");
+		return -EOPNOTSUPP;
+	}
+
+	if (adapter->num_vfs == num_vfs)
+		return -EINVAL;
+
 	if (pre_existing_vfs && pre_existing_vfs != num_vfs)
 		err = ixgbe_disable_sriov(adapter);
 	else if (pre_existing_vfs && pre_existing_vfs == num_vfs)
-		return num_vfs;
+		goto out;
 
 	if (err)
-		return err;
-
-	/* While the SR-IOV capability structure reports total VFs to be 64,
-	 * we have to limit the actual number allocated based on two factors.
-	 * First, we reserve some transmit/receive resources for the PF.
-	 * Second, VMDQ also uses the same pools that SR-IOV does. We need to
-	 * account for this, so that we don't accidentally allocate more VFs
-	 * than we have available pools. The PCI bus driver already checks for
-	 * other values out of range.
+		goto err_out;
+
+	/* While the SR-IOV capability structure reports total VFs to be
+	 * 64 we limit the actual number that can be allocated as below
+	 * so that some transmit/receive resources can be reserved to the
+	 * PF.  The PCI bus driver already checks for other values out of
+	 * range.
+	 *    Num_TCs	MAX_VFs
+	 *	1	  63
+	 *	<=4	  31
+	 *	>4	  15
 	 */
-	if ((num_vfs + adapter->num_rx_pools) > IXGBE_MAX_VF_FUNCTIONS)
-		return -EPERM;
+	num_tc = netdev_get_num_tc(adapter->netdev);
 
-	adapter->num_vfs = num_vfs;
+	if (num_tc > 4) {
+		if (num_vfs > IXGBE_MAX_VFS_8TC) {
+			e_dev_err("Currently the device is configured with %d TCs, Creating more than %d VFs is not allowed\n", num_tc, IXGBE_MAX_VFS_8TC);
+			err = -EPERM;
+			goto err_out;
+		}
+	} else if ((num_tc > 1) && (num_tc <= 4)) {
+		if (num_vfs > IXGBE_MAX_VFS_4TC) {
+			e_dev_err("Currently the device is configured with %d TCs, Creating more than %d VFs is not allowed\n", num_tc, IXGBE_MAX_VFS_4TC);
+			err = -EPERM;
+			goto err_out;
+		}
+	} else {
+		if (num_vfs > IXGBE_MAX_VFS_1TC) {
+			e_dev_err("Currently the device is configured with %d TCs, Creating more than %d VFs is not allowed\n", num_tc, IXGBE_MAX_VFS_1TC);
+			err = -EPERM;
+			goto err_out;
+		}
+	}
 
-	err = __ixgbe_enable_sriov(adapter);
+	err = __ixgbe_enable_sriov(adapter, num_vfs);
 	if (err)
-		return  err;
+		goto err_out;
 
 	for (i = 0; i < adapter->num_vfs; i++)
 		ixgbe_vf_configuration(dev, (i | 0x10000000));
 
+	/* reset before enabling SRIOV to avoid mailbox issues */
+	ixgbe_sriov_reinit(adapter);
+
 	err = pci_enable_sriov(dev, num_vfs);
 	if (err) {
 		e_dev_warn("Failed to enable PCI sriov: %d\n", err);
-		return err;
+		goto err_out;
 	}
-	ixgbe_sriov_reinit(adapter);
+	ixgbe_get_vfs(adapter);
 
+out:
 	return num_vfs;
-#else
-	return 0;
+
+err_out:
+	return err;
 #endif
+	return 0;
 }
 
 static int ixgbe_pci_sriov_disable(struct pci_dev *dev)
@@ -305,6 +404,9 @@ static int ixgbe_pci_sriov_disable(struct pci_dev *dev)
 	u32 current_flags = adapter->flags;
 #endif
 
+	if (!adapter->num_vfs && !pci_num_vf(dev))
+		return -EINVAL;
+
 	err = ixgbe_disable_sriov(adapter);
 
 	/* Only reinit if no error and state changed */
@@ -341,20 +443,16 @@ static int ixgbe_set_vf_multicasts(struct ixgbe_adapter *adapter,
 	/* only so many hash values supported */
 	entries = min(entries, IXGBE_MAX_VF_MC_ENTRIES);
 
-	/*
-	 * salt away the number of multi cast addresses assigned
+	/* salt away the number of multi cast addresses assigned
 	 * to this VF for later use to restore when the PF multi cast
 	 * list changes
 	 */
 	vfinfo->num_vf_mc_hashes = entries;
 
-	/*
-	 * VFs are limited to using the MTA hash table for their multicast
-	 * addresses
-	 */
-	for (i = 0; i < entries; i++) {
+	/* VFs are limited to using the MTA hash table for their multicast
+	 * addresses */
+	for (i = 0; i < entries; i++)
 		vfinfo->vf_mc_hashes[i] = hash_list[i];
-	}
 
 	for (i = 0; i < vfinfo->num_vf_mc_hashes; i++) {
 		vector_reg = (vfinfo->vf_mc_hashes[i] >> 5) & 0x7F;
@@ -390,7 +488,6 @@ void ixgbe_restore_vf_multicasts(struct ixgbe_adapter *adapter)
 			mta_reg |= (1 << vector_bit);
 			IXGBE_WRITE_REG(hw, IXGBE_MTA(vector_reg), mta_reg);
 		}
-
 		if (vfinfo->num_vf_mc_hashes)
 			vmolr |= IXGBE_VMOLR_ROMPE;
 		else
@@ -401,22 +498,46 @@ void ixgbe_restore_vf_multicasts(struct ixgbe_adapter *adapter)
 	/* Restore any VF macvlans */
 	ixgbe_full_sync_mac_table(adapter);
 }
-#endif
+#endif /* CONFIG_PCI_IOV */
 
-static int ixgbe_set_vf_vlan(struct ixgbe_adapter *adapter, int add, int vid,
-			     u32 vf)
+int ixgbe_set_vf_vlan(struct ixgbe_adapter *adapter, int add, int vid, u32 vf)
 {
-	/* VLAN 0 is a special case, don't allow it to be removed */
-	if (!vid && !add)
-		return 0;
+	struct ixgbe_hw *hw = &adapter->hw;
+	int err;
 
-	return adapter->hw.mac.ops.set_vfta(&adapter->hw, vid, vf, (bool)add);
-}
+#ifndef HAVE_VLAN_RX_REGISTER
+	/* If VLAN overlaps with one the PF is currently monitoring make
+	 * sure that we are able to allocate a VLVF entry.  This may be
+	 * redundant but it guarantees PF will maintain visibility to
+	 * the VLAN.
+	 */
+	if (add && test_bit(vid, adapter->active_vlans)) {
+		err = hw->mac.ops.set_vfta(hw, vid, VMDQ_P(0), true, false);
+		if (err)
+			return err;
+	}
+#endif
+
+	err = hw->mac.ops.set_vfta(hw, vid, vf, !!add, false);
+#ifndef HAVE_VLAN_RX_REGISTER
 
-static s32 ixgbe_set_vf_lpe(struct ixgbe_adapter *adapter, u32 *msgbuf, u32 vf)
+	if (add && !err)
+		return err;
+
+	/* If we failed to add the VF VLAN or we are removing the VF VLAN
+	 * we may need to drop the PF pool bit in order to allow us to free
+	 * up the VLVF resources.
+	 */
+	if (test_bit(vid, adapter->active_vlans) ||
+	    (adapter->flags2 & IXGBE_FLAG2_VLAN_PROMISC))
+		ixgbe_update_pf_promisc_vlvf(adapter, vid);
+#endif
+
+	return err;
+}
+static int ixgbe_set_vf_lpe(struct ixgbe_adapter *adapter, u32 max_frame, u32 vf)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
-	int max_frame = msgbuf[1];
 	u32 max_frs;
 
 	/*
@@ -427,30 +548,31 @@ static s32 ixgbe_set_vf_lpe(struct ixgbe_adapter *adapter, u32 *msgbuf, u32 vf)
 	 * account before we can enable the VF for receive
 	 */
 	if (adapter->hw.mac.type == ixgbe_mac_82599EB) {
+
 		struct net_device *dev = adapter->netdev;
 		int pf_max_frame = dev->mtu + ETH_HLEN;
 		u32 reg_offset, vf_shift, vfre;
 		s32 err = 0;
 
-#ifdef CONFIG_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 		if (dev->features & NETIF_F_FCOE_MTU)
 			pf_max_frame = max_t(int, pf_max_frame,
 					     IXGBE_FCOE_JUMBO_FRAME_SIZE);
-
 #endif /* CONFIG_FCOE */
+
 		switch (adapter->vfinfo[vf].vf_api) {
 		case ixgbe_mbox_api_11:
 		case ixgbe_mbox_api_12:
-			/*
-			 * Version 1.1 supports jumbo frames on VFs if PF has
+		case ixgbe_mbox_api_13:
+			/* Version 1.1 supports jumbo frames on VFs if PF has
 			 * jumbo frames enabled which means legacy VFs are
 			 * disabled
 			 */
 			if (pf_max_frame > ETH_FRAME_LEN)
 				break;
+			/* fall through */
 		default:
-			/*
-			 * If the PF or VF are running w/ jumbo frames enabled
+			/* If the PF or VF are running w/ jumbo frames enabled
 			 * we need to shut down the VF Rx path as we cannot
 			 * support jumbo frames on legacy VFs
 			 */
@@ -478,12 +600,6 @@ static s32 ixgbe_set_vf_lpe(struct ixgbe_adapter *adapter, u32 *msgbuf, u32 vf)
 		}
 	}
 
-	/* MTU < 68 is an error and causes problems on some kernels */
-	if (max_frame > IXGBE_MAX_JUMBO_FRAME_SIZE) {
-		e_err(drv, "VF max_frame %d out of range\n", max_frame);
-		return -EINVAL;
-	}
-
 	/* pull current max frame size from hardware */
 	max_frs = IXGBE_READ_REG(hw, IXGBE_MAXFRS);
 	max_frs &= IXGBE_MHADD_MFS_MASK;
@@ -499,10 +615,10 @@ static s32 ixgbe_set_vf_lpe(struct ixgbe_adapter *adapter, u32 *msgbuf, u32 vf)
 	return 0;
 }
 
-static void ixgbe_set_vmolr(struct ixgbe_hw *hw, u32 vf, bool aupe)
+void ixgbe_set_vmolr(struct ixgbe_hw *hw, u32 vf, bool aupe)
 {
 	u32 vmolr = IXGBE_READ_REG(hw, IXGBE_VMOLR(vf));
-	vmolr |= IXGBE_VMOLR_BAM;
+	vmolr |=  IXGBE_VMOLR_BAM;
 	if (aupe)
 		vmolr |= IXGBE_VMOLR_AUPE;
 	else
@@ -510,66 +626,89 @@ static void ixgbe_set_vmolr(struct ixgbe_hw *hw, u32 vf, bool aupe)
 	IXGBE_WRITE_REG(hw, IXGBE_VMOLR(vf), vmolr);
 }
 
-static void ixgbe_clear_vmvir(struct ixgbe_adapter *adapter, u32 vf)
+static void ixgbe_set_vmvir(struct ixgbe_adapter *adapter,
+			    u16 vid, u16 qos, u32 vf)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
+	u32 vmvir = vid | (qos << VLAN_PRIO_SHIFT) | IXGBE_VMVIR_VLANA_DEFAULT;
 
-	IXGBE_WRITE_REG(hw, IXGBE_VMVIR(vf), 0);
+	IXGBE_WRITE_REG(hw, IXGBE_VMVIR(vf), vmvir);
 }
-static inline void ixgbe_vf_reset_event(struct ixgbe_adapter *adapter, u32 vf)
+
+static void ixgbe_clear_vmvir(struct ixgbe_adapter *adapter, u32 vf)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
-	struct vf_data_storage *vfinfo = &adapter->vfinfo[vf];
-	u8 num_tcs = netdev_get_num_tc(adapter->netdev);
-
-	/* add PF assigned VLAN or VLAN 0 */
-	ixgbe_set_vf_vlan(adapter, true, vfinfo->pf_vlan, vf);
-
-	/* reset offloads to defaults */
-	ixgbe_set_vmolr(hw, vf, !vfinfo->pf_vlan);
-
-	/* set outgoing tags for VFs */
-	if (!vfinfo->pf_vlan && !vfinfo->pf_qos && !num_tcs) {
-		ixgbe_clear_vmvir(adapter, vf);
-	} else {
-		if (vfinfo->pf_qos || !num_tcs)
-			ixgbe_set_vmvir(adapter, vfinfo->pf_vlan,
-					vfinfo->pf_qos, vf);
-		else
-			ixgbe_set_vmvir(adapter, vfinfo->pf_vlan,
-					adapter->default_up, vf);
 
-		if (vfinfo->spoofchk_enabled)
-			hw->mac.ops.set_vlan_anti_spoofing(hw, true, vf);
-	}
-
-	/* reset multicast table array for vf */
-	adapter->vfinfo[vf].num_vf_mc_hashes = 0;
-
-	/* Flush and reset the mta with the new values */
-	ixgbe_set_rx_mode(adapter->netdev);
-
-	ixgbe_del_mac_filter(adapter, adapter->vfinfo[vf].vf_mac_addresses, vf);
-
-	/* reset VF api back to unknown */
-	adapter->vfinfo[vf].vf_api = ixgbe_mbox_api_10;
+	IXGBE_WRITE_REG(hw, IXGBE_VMVIR(vf), 0);
 }
 
-static int ixgbe_set_vf_mac(struct ixgbe_adapter *adapter,
-			    int vf, unsigned char *mac_addr)
+static void ixgbe_clear_vf_vlans(struct ixgbe_adapter *adapter, u32 vf)
 {
-	ixgbe_del_mac_filter(adapter, adapter->vfinfo[vf].vf_mac_addresses, vf);
-	memcpy(adapter->vfinfo[vf].vf_mac_addresses, mac_addr, ETH_ALEN);
-	ixgbe_add_mac_filter(adapter, adapter->vfinfo[vf].vf_mac_addresses, vf);
-
-	return 0;
+	struct ixgbe_hw *hw = &adapter->hw;
+	u32 vlvfb_mask, pool_mask, i;
+
+	/* create mask for VF and other pools */
+	pool_mask = (u32)~BIT(VMDQ_P(0) % 32);
+	vlvfb_mask = BIT(vf % 32);
+
+	/* post increment loop, covers VLVF_ENTRIES - 1 to 0 */
+	for (i = IXGBE_VLVF_ENTRIES; i--;) {
+		u32 bits[2], vlvfb, vid, vfta, vlvf;
+		u32 word = i * 2 + vf / 32;
+		u32 mask;
+
+		vlvfb = IXGBE_READ_REG(hw, IXGBE_VLVFB(word));
+
+		/* if our bit isn't set we can skip it */
+		if (!(vlvfb & vlvfb_mask))
+			continue;
+
+		/* clear our bit from vlvfb */
+		vlvfb ^= vlvfb_mask;
+
+		/* create 64b mask to check to see if we should clear VLVF */
+		bits[word % 2] = vlvfb;
+		bits[~word % 2] = IXGBE_READ_REG(hw, IXGBE_VLVFB(word ^ 1));
+
+		/* if other pools are present, just remove ourselves */
+		if (bits[(VMDQ_P(0) / 32) ^ 1] ||
+		    (bits[VMDQ_P(0) / 32] & pool_mask))
+			goto update_vlvfb;
+
+		/* if PF is present, leave VFTA */
+		if (bits[0] || bits[1])
+			goto update_vlvf;
+
+		/* if we cannot determine VLAN just remove ourselves */
+		vlvf = IXGBE_READ_REG(hw, IXGBE_VLVF(i));
+		if (!vlvf)
+			goto update_vlvfb;
+
+		vid = vlvf & VLAN_VID_MASK;
+		mask = BIT(vid % 32);
+
+		/* clear bit from VFTA */
+		vfta = IXGBE_READ_REG(hw, IXGBE_VFTA(vid / 32));
+		if (vfta & mask)
+			IXGBE_WRITE_REG(hw, IXGBE_VFTA(vid / 32), vfta ^ mask);
+update_vlvf:
+		/* clear POOL selection enable */
+		IXGBE_WRITE_REG(hw, IXGBE_VLVF(i), 0);
+
+		if (!(adapter->flags2 & IXGBE_FLAG2_VLAN_PROMISC))
+			vlvfb = 0;
+update_vlvfb:
+		/* clear pool bits */
+		IXGBE_WRITE_REG(hw, IXGBE_VLVFB(word), vlvfb);
+	}
 }
 
 static int ixgbe_set_vf_macvlan(struct ixgbe_adapter *adapter,
 				int vf, int index, unsigned char *mac_addr)
 {
-	struct list_head *pos;
 	struct vf_macvlans *entry;
+	struct list_head *pos;
+	int retval = 0;
 
 	if (index <= 1) {
 		list_for_each(pos, &adapter->vf_mvs.l) {
@@ -610,28 +749,90 @@ static int ixgbe_set_vf_macvlan(struct ixgbe_adapter *adapter,
 	if (!entry || !entry->free)
 		return -ENOSPC;
 
+	retval = ixgbe_add_mac_filter(adapter, mac_addr, vf);
+	if (retval < 0)
+		return retval;
+
 	entry->free = false;
 	entry->is_macvlan = true;
 	entry->vf = vf;
 	memcpy(entry->vf_macvlan, mac_addr, ETH_ALEN);
 
-	ixgbe_add_mac_filter(adapter, mac_addr, vf);
-
 	return 0;
 }
 
+static inline void ixgbe_vf_reset_event(struct ixgbe_adapter *adapter, u32 vf)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	struct vf_data_storage *vfinfo = &adapter->vfinfo[vf];
+	u8 num_tcs = netdev_get_num_tc(adapter->netdev);
+
+	/* remove VLAN filters belonging to this VF */
+	ixgbe_clear_vf_vlans(adapter, vf);
+
+	/* add back PF assigned VLAN or VLAN 0 */
+	ixgbe_set_vf_vlan(adapter, true, vfinfo->pf_vlan, vf);
+
+	/* reset offloads to defaults */
+	ixgbe_set_vmolr(hw, vf, !vfinfo->pf_vlan);
+
+	/* set outgoing tags for VFs */
+	if (!vfinfo->pf_vlan && !vfinfo->pf_qos && !num_tcs) {
+		ixgbe_clear_vmvir(adapter, vf);
+	} else {
+		if (vfinfo->pf_qos || !num_tcs)
+			ixgbe_set_vmvir(adapter, vfinfo->pf_vlan,
+					vfinfo->pf_qos, vf);
+		else
+			ixgbe_set_vmvir(adapter, vfinfo->pf_vlan,
+					adapter->default_up, vf);
+	}
+
+	/* reset multicast table array for vf */
+	adapter->vfinfo[vf].num_vf_mc_hashes = 0;
+
+	/* Flush and reset the mta with the new values */
+	ixgbe_set_rx_mode(adapter->netdev);
+
+	ixgbe_del_mac_filter(adapter, adapter->vfinfo[vf].vf_mac_addresses, vf);
+	ixgbe_set_vf_macvlan(adapter, vf, 0, NULL);
+
+	/* reset VF api back to unknown */
+	adapter->vfinfo[vf].vf_api = ixgbe_mbox_api_10;
+}
+
+int ixgbe_set_vf_mac(struct ixgbe_adapter *adapter,
+		     int vf, unsigned char *mac_addr)
+{
+	s32 retval = 0;
+
+	ixgbe_del_mac_filter(adapter, adapter->vfinfo[vf].vf_mac_addresses, vf);
+	retval = ixgbe_add_mac_filter(adapter, mac_addr, vf);
+	if (retval >= 0)
+		memcpy(adapter->vfinfo[vf].vf_mac_addresses,
+		       mac_addr, ETH_ALEN);
+	else
+		memset(adapter->vfinfo[vf].vf_mac_addresses, 0, ETH_ALEN);
+
+	return retval;
+}
+
+#ifdef CONFIG_PCI_IOV
 int ixgbe_vf_configuration(struct pci_dev *pdev, unsigned int event_mask)
 {
+	unsigned char vf_mac_addr[6];
 	struct ixgbe_adapter *adapter = pci_get_drvdata(pdev);
 	unsigned int vfn = (event_mask & 0x3f);
-
 	bool enable = ((event_mask & 0x10000000U) != 0);
 
-	if (enable)
-		eth_zero_addr(adapter->vfinfo[vfn].vf_mac_addresses);
+	if (enable) {
+		memset(vf_mac_addr, 0, ETH_ALEN);
+		memcpy(adapter->vfinfo[vfn].vf_mac_addresses, vf_mac_addr, 6);
+	}
 
 	return 0;
 }
+#endif /* CONFIG_PCI_IOV */
 
 static inline void ixgbe_write_qde(struct ixgbe_adapter *adapter, u32 vf,
 				   u32 qde)
@@ -639,25 +840,25 @@ static inline void ixgbe_write_qde(struct ixgbe_adapter *adapter, u32 vf,
 	struct ixgbe_hw *hw = &adapter->hw;
 	struct ixgbe_ring_feature *vmdq = &adapter->ring_feature[RING_F_VMDQ];
 	u32 q_per_pool = __ALIGN_MASK(1, ~vmdq->mask);
+	u32 reg;
 	int i;
 
 	for (i = vf * q_per_pool; i < ((vf + 1) * q_per_pool); i++) {
-		u32 reg;
-
 		/* flush previous write */
 		IXGBE_WRITE_FLUSH(hw);
 
-		/* indicate to hardware that we want to set drop enable */
-		reg = IXGBE_QDE_WRITE | IXGBE_QDE_ENABLE;
+		/* drop enable should always be set in SRIOV mode*/
+		reg = IXGBE_QDE_WRITE | qde;
 		reg |= i <<  IXGBE_QDE_IDX_SHIFT;
 		IXGBE_WRITE_REG(hw, IXGBE_QDE, reg);
 	}
+
 }
 
 static int ixgbe_vf_reset_msg(struct ixgbe_adapter *adapter, u32 vf)
 {
-	struct ixgbe_ring_feature *vmdq = &adapter->ring_feature[RING_F_VMDQ];
 	struct ixgbe_hw *hw = &adapter->hw;
+	struct ixgbe_ring_feature *vmdq = &adapter->ring_feature[RING_F_VMDQ];
 	unsigned char *vf_mac = adapter->vfinfo[vf].vf_mac_addresses;
 	u32 reg, reg_offset, vf_shift;
 	u32 msgbuf[4] = {0, 0, 0, 0};
@@ -696,12 +897,12 @@ static int ixgbe_vf_reset_msg(struct ixgbe_adapter *adapter, u32 vf)
 		struct net_device *dev = adapter->netdev;
 		int pf_max_frame = dev->mtu + ETH_HLEN;
 
-#ifdef CONFIG_FCOE
+#if IS_ENABLED(CONFIG_FCOE)
 		if (dev->features & NETIF_F_FCOE_MTU)
 			pf_max_frame = max_t(int, pf_max_frame,
 					     IXGBE_FCOE_JUMBO_FRAME_SIZE);
-
 #endif /* CONFIG_FCOE */
+
 		if (pf_max_frame > ETH_FRAME_LEN)
 			reg &= ~(1 << vf_shift);
 	}
@@ -710,7 +911,6 @@ static int ixgbe_vf_reset_msg(struct ixgbe_adapter *adapter, u32 vf)
 	/* enable VF mailbox for further messages */
 	adapter->vfinfo[vf].clear_to_send = true;
 
-	/* Enable counting of spoofed packets in the SSVPC register */
 	reg = IXGBE_READ_REG(hw, IXGBE_VMECM(reg_offset));
 	reg |= (1 << vf_shift);
 	IXGBE_WRITE_REG(hw, IXGBE_VMECM(reg_offset), reg);
@@ -726,12 +926,12 @@ static int ixgbe_vf_reset_msg(struct ixgbe_adapter *adapter, u32 vf)
 
 	/* reply to reset with ack and vf mac address */
 	msgbuf[0] = IXGBE_VF_RESET;
-	if (!is_zero_ether_addr(vf_mac)) {
+	if (!is_zero_ether_addr(vf_mac) && adapter->vfinfo[vf].pf_set_mac) {
 		msgbuf[0] |= IXGBE_VT_MSGTYPE_ACK;
 		memcpy(addr, vf_mac, ETH_ALEN);
 	} else {
 		msgbuf[0] |= IXGBE_VT_MSGTYPE_NACK;
-		dev_warn(&adapter->pdev->dev,
+		dev_warn(pci_dev_to_dev(adapter->pdev),
 			 "VF %d has no MAC address assigned, you may have to assign one manually\n",
 			 vf);
 	}
@@ -756,52 +956,26 @@ static int ixgbe_set_vf_mac_addr(struct ixgbe_adapter *adapter,
 		return -1;
 	}
 
-	if (adapter->vfinfo[vf].pf_set_mac &&
-	    !ether_addr_equal(adapter->vfinfo[vf].vf_mac_addresses, new_mac)) {
+	if (adapter->vfinfo[vf].pf_set_mac && !adapter->vfinfo[vf].trusted &&
+	    memcmp(adapter->vfinfo[vf].vf_mac_addresses, new_mac,
+		   ETH_ALEN)) {
+		u8 *pm = adapter->vfinfo[vf].vf_mac_addresses;
 		e_warn(drv,
-		       "VF %d attempted to override administratively set MAC address\n"
-		       "Reload the VF driver to resume operations\n",
-		       vf);
+		       "VF %d attempted to set a new MAC address but it already has an administratively set MAC address %2.2X:%2.2X:%2.2X:%2.2X:%2.2X:%2.2X\n",
+		       vf, pm[0], pm[1], pm[2], pm[3], pm[4], pm[5]);
+		e_warn(drv, "Check the VF driver and if it is not using the correct MAC address you may need to reload the VF driver\n");
 		return -1;
 	}
-
 	return ixgbe_set_vf_mac(adapter, vf, new_mac) < 0;
 }
 
-static int ixgbe_find_vlvf_entry(struct ixgbe_hw *hw, u32 vlan)
-{
-	u32 vlvf;
-	s32 regindex;
-
-	/* short cut the special case */
-	if (vlan == 0)
-		return 0;
-
-	/* Search for the vlan id in the VLVF entries */
-	for (regindex = 1; regindex < IXGBE_VLVF_ENTRIES; regindex++) {
-		vlvf = IXGBE_READ_REG(hw, IXGBE_VLVF(regindex));
-		if ((vlvf & VLAN_VID_MASK) == vlan)
-			break;
-	}
-
-	/* Return a negative value if not found */
-	if (regindex >= IXGBE_VLVF_ENTRIES)
-		regindex = -1;
-
-	return regindex;
-}
-
 static int ixgbe_set_vf_vlan_msg(struct ixgbe_adapter *adapter,
 				 u32 *msgbuf, u32 vf)
 {
-	struct ixgbe_hw *hw = &adapter->hw;
-	int add = (msgbuf[0] & IXGBE_VT_MSGINFO_MASK) >> IXGBE_VT_MSGINFO_SHIFT;
-	int vid = (msgbuf[1] & IXGBE_VLVF_VLANID_MASK);
-	int err;
-	s32 reg_ndx;
-	u32 vlvf;
-	u32 bits;
+	u32 add = (msgbuf[0] & IXGBE_VT_MSGINFO_MASK) >> IXGBE_VT_MSGINFO_SHIFT;
+	u32 vid = (msgbuf[1] & IXGBE_VLVF_VLANID_MASK);
 	u8 tcs = netdev_get_num_tc(adapter->netdev);
+	int err = 0;
 
 	if (adapter->vfinfo[vf].pf_vlan || tcs) {
 		e_warn(drv,
@@ -811,28 +985,37 @@ static int ixgbe_set_vf_vlan_msg(struct ixgbe_adapter *adapter,
 		return -1;
 	}
 
-	if (add)
-		adapter->vfinfo[vf].vlan_count++;
-	else if (adapter->vfinfo[vf].vlan_count)
-		adapter->vfinfo[vf].vlan_count--;
+	/* VLAN 0 is a special case, don't allow it to be removed */
+	if (!vid && !add)
+		return 0;
+
+	err = ixgbe_set_vf_vlan(adapter, add, vid, vf);
+
+	if (err)
+		return err;
 
+#ifdef HAVE_VLAN_RX_REGISTER
 	/* in case of promiscuous mode any VLAN filter set for a VF must
 	 * also have the PF pool added to it.
 	 */
-	if (add && adapter->netdev->flags & IFF_PROMISC)
+	if (add && adapter->netdev->flags & IFF_PROMISC) {
 		err = ixgbe_set_vf_vlan(adapter, add, vid, VMDQ_P(0));
+		if (err)
+			return err;
+	}
 
-	err = ixgbe_set_vf_vlan(adapter, add, vid, vf);
-	if (!err && adapter->vfinfo[vf].spoofchk_enabled)
-		hw->mac.ops.set_vlan_anti_spoofing(hw, true, vf);
-
+#ifdef CONFIG_PCI_IOV
 	/* Go through all the checks to see if the VLAN filter should
 	 * be wiped completely.
 	 */
 	if (!add && adapter->netdev->flags & IFF_PROMISC) {
+		struct ixgbe_hw *hw = &adapter->hw;
+		u32 bits, vlvf;
+		s32 reg_ndx;
+
 		reg_ndx = ixgbe_find_vlvf_entry(hw, vid);
 		if (reg_ndx < 0)
-			return err;
+			goto out;
 		vlvf = IXGBE_READ_REG(hw, IXGBE_VLVF(reg_ndx));
 		/* See if any other pools are set for this VLAN filter
 		 * entry other than the PF.
@@ -853,11 +1036,15 @@ static int ixgbe_set_vf_vlan_msg(struct ixgbe_adapter *adapter,
 		 * is cleared if the PF only added itself to the pool
 		 * because the PF is in promiscuous mode.
 		 */
-		if ((vlvf & VLAN_VID_MASK) == vid &&
-		    !test_bit(vid, adapter->active_vlans) && !bits)
-			ixgbe_set_vf_vlan(adapter, add, vid, VMDQ_P(0));
+		if ((vlvf & VLAN_VID_MASK) == vid && !bits)
+			err = ixgbe_set_vf_vlan(adapter, add, vid, VMDQ_P(0));
 	}
 
+out:
+#endif /* CONFIG_PCI_IOV */
+#else /* HAVE_VLAN_RX_REGISTER */
+	return 0;
+#endif /* HAVE_VLAN_RX_REGISTER */
 	return err;
 }
 
@@ -869,7 +1056,8 @@ static int ixgbe_set_vf_macvlan_msg(struct ixgbe_adapter *adapter,
 		    IXGBE_VT_MSGINFO_SHIFT;
 	int err;
 
-	if (adapter->vfinfo[vf].pf_set_mac && index > 0) {
+	if (adapter->vfinfo[vf].pf_set_mac && !adapter->vfinfo[vf].trusted &&
+	    index > 0) {
 		e_warn(drv,
 		       "VF %d requested MACVLAN filter but is administratively denied\n",
 		       vf);
@@ -887,8 +1075,12 @@ static int ixgbe_set_vf_macvlan_msg(struct ixgbe_adapter *adapter,
 		 * If the VF is allowed to set MAC filters then turn off
 		 * anti-spoofing to avoid false positives.
 		 */
-		if (adapter->vfinfo[vf].spoofchk_enabled)
-			ixgbe_ndo_set_vf_spoofchk(adapter->netdev, vf, false);
+		if (adapter->vfinfo[vf].spoofchk_enabled) {
+			struct ixgbe_hw *hw = &adapter->hw;
+
+			hw->mac.ops.set_mac_anti_spoofing(hw, false, vf);
+			hw->mac.ops.set_vlan_anti_spoofing(hw, false, vf);
+		}
 	}
 
 	err = ixgbe_set_vf_macvlan(adapter, vf, index, new_mac);
@@ -909,6 +1101,7 @@ static int ixgbe_negotiate_vf_api(struct ixgbe_adapter *adapter,
 	case ixgbe_mbox_api_10:
 	case ixgbe_mbox_api_11:
 	case ixgbe_mbox_api_12:
+	case ixgbe_mbox_api_13:
 		adapter->vfinfo[vf].vf_api = api;
 		return 0;
 	default:
@@ -933,6 +1126,7 @@ static int ixgbe_get_vf_queues(struct ixgbe_adapter *adapter,
 	case ixgbe_mbox_api_20:
 	case ixgbe_mbox_api_11:
 	case ixgbe_mbox_api_12:
+	case ixgbe_mbox_api_13:
 		break;
 	default:
 		return -1;
@@ -960,6 +1154,7 @@ static int ixgbe_get_vf_queues(struct ixgbe_adapter *adapter,
 	return 0;
 }
 
+#ifdef HAVE_NDO_SET_VF_RSS_QUERY_EN
 static int ixgbe_get_vf_reta(struct ixgbe_adapter *adapter, u32 *msgbuf, u32 vf)
 {
 	u32 i, j;
@@ -972,8 +1167,13 @@ static int ixgbe_get_vf_reta(struct ixgbe_adapter *adapter, u32 *msgbuf, u32 vf)
 		return -EPERM;
 
 	/* verify the PF is supporting the correct API */
-	if (adapter->vfinfo[vf].vf_api != ixgbe_mbox_api_12)
+	switch (adapter->vfinfo[vf].vf_api) {
+	case ixgbe_mbox_api_12:
+	case ixgbe_mbox_api_13:
+		break;
+	default:
 		return -EOPNOTSUPP;
+	}
 
 	/* This mailbox command is supported (required) only for 82599 and x540
 	 * VFs which support up to 4 RSS queues. Therefore we will compress the
@@ -999,24 +1199,35 @@ static int ixgbe_get_vf_rss_key(struct ixgbe_adapter *adapter,
 		return -EPERM;
 
 	/* verify the PF is supporting the correct API */
-	if (adapter->vfinfo[vf].vf_api != ixgbe_mbox_api_12)
+	switch (adapter->vfinfo[vf].vf_api) {
+	case ixgbe_mbox_api_12:
+	case ixgbe_mbox_api_13:
+		break;
+	default:
 		return -EOPNOTSUPP;
+	}
 
-	memcpy(rss_key, adapter->rss_key, sizeof(adapter->rss_key));
+	memcpy(rss_key, adapter->rss_key, IXGBE_RSS_KEY_SIZE);
 
 	return 0;
 }
+#endif /* HAVE_NDO_SET_VF_RSS_QUERY_EN */
 
 static int ixgbe_update_vf_xcast_mode(struct ixgbe_adapter *adapter,
 				      u32 *msgbuf, u32 vf)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	int xcast_mode = msgbuf[1];
-	u32 vmolr, disable, enable;
+	u32 vmolr, fctrl, disable, enable;
 
 	/* verify the PF is supporting the correct APIs */
 	switch (adapter->vfinfo[vf].vf_api) {
 	case ixgbe_mbox_api_12:
+		/* promisc introduced in 1.3 version */
+		if (xcast_mode == IXGBEVF_XCAST_MODE_PROMISC)
+			return -EOPNOTSUPP;
+		/* Fall threw */
+	case ixgbe_mbox_api_13:
 		break;
 	default:
 		return -EOPNOTSUPP;
@@ -1032,17 +1243,34 @@ static int ixgbe_update_vf_xcast_mode(struct ixgbe_adapter *adapter,
 
 	switch (xcast_mode) {
 	case IXGBEVF_XCAST_MODE_NONE:
-		disable = IXGBE_VMOLR_BAM | IXGBE_VMOLR_ROMPE | IXGBE_VMOLR_MPE;
+		disable = IXGBE_VMOLR_BAM | IXGBE_VMOLR_ROMPE |
+			  IXGBE_VMOLR_MPE | IXGBE_VMOLR_UPE | IXGBE_VMOLR_VPE;
 		enable = 0;
 		break;
 	case IXGBEVF_XCAST_MODE_MULTI:
-		disable = IXGBE_VMOLR_MPE;
+		disable = IXGBE_VMOLR_MPE | IXGBE_VMOLR_UPE | IXGBE_VMOLR_VPE;
 		enable = IXGBE_VMOLR_BAM | IXGBE_VMOLR_ROMPE;
 		break;
 	case IXGBEVF_XCAST_MODE_ALLMULTI:
-		disable = 0;
+		disable = IXGBE_VMOLR_UPE | IXGBE_VMOLR_VPE;
 		enable = IXGBE_VMOLR_BAM | IXGBE_VMOLR_ROMPE | IXGBE_VMOLR_MPE;
 		break;
+	case IXGBEVF_XCAST_MODE_PROMISC:
+		if (hw->mac.type <= ixgbe_mac_82599EB)
+			return -EOPNOTSUPP;
+
+		fctrl = IXGBE_READ_REG(hw, IXGBE_FCTRL);
+		if (!(fctrl & IXGBE_FCTRL_UPE)) {
+			/* VF promisc requires PF in promisc */
+			e_warn(drv,
+			       "Enabling VF promisc requires PF in promisc\n");
+			return -EPERM;
+		}
+
+		disable = 0;
+		enable = IXGBE_VMOLR_BAM | IXGBE_VMOLR_ROMPE |
+			 IXGBE_VMOLR_MPE | IXGBE_VMOLR_UPE | IXGBE_VMOLR_VPE;
+		break;
 	default:
 		return -EOPNOTSUPP;
 	}
@@ -1076,7 +1304,7 @@ static int ixgbe_rcv_msg_from_vf(struct ixgbe_adapter *adapter, u32 vf)
 
 	/* this is a message we already processed, do nothing */
 	if (msgbuf[0] & (IXGBE_VT_MSGTYPE_ACK | IXGBE_VT_MSGTYPE_NACK))
-		return 0;
+		return retval;
 
 	/* flush the ack before we write any messages back */
 	IXGBE_WRITE_FLUSH(hw);
@@ -1088,10 +1316,11 @@ static int ixgbe_rcv_msg_from_vf(struct ixgbe_adapter *adapter, u32 vf)
 	 * until the vf completes a virtual function reset it should not be
 	 * allowed to start any configuration.
 	 */
+
 	if (!adapter->vfinfo[vf].clear_to_send) {
 		msgbuf[0] |= IXGBE_VT_MSGTYPE_NACK;
 		ixgbe_write_mbx(hw, msgbuf, 1, vf);
-		return 0;
+		return retval;
 	}
 
 	switch ((msgbuf[0] & 0xFFFF)) {
@@ -1105,7 +1334,11 @@ static int ixgbe_rcv_msg_from_vf(struct ixgbe_adapter *adapter, u32 vf)
 		retval = ixgbe_set_vf_vlan_msg(adapter, msgbuf, vf);
 		break;
 	case IXGBE_VF_SET_LPE:
-		retval = ixgbe_set_vf_lpe(adapter, msgbuf, vf);
+		if (msgbuf[1] > IXGBE_MAX_JUMBO_FRAME_SIZE) {
+			e_err(drv, "VF max_frame %d out of range\n", msgbuf[1]);
+			return -EINVAL;
+		}
+		retval = ixgbe_set_vf_lpe(adapter, msgbuf[1], vf);
 		break;
 	case IXGBE_VF_SET_MACVLAN:
 		retval = ixgbe_set_vf_macvlan_msg(adapter, msgbuf, vf);
@@ -1116,12 +1349,14 @@ static int ixgbe_rcv_msg_from_vf(struct ixgbe_adapter *adapter, u32 vf)
 	case IXGBE_VF_GET_QUEUES:
 		retval = ixgbe_get_vf_queues(adapter, msgbuf, vf);
 		break;
+#ifdef HAVE_NDO_SET_VF_RSS_QUERY_EN
 	case IXGBE_VF_GET_RETA:
 		retval = ixgbe_get_vf_reta(adapter, msgbuf, vf);
 		break;
 	case IXGBE_VF_GET_RSS_KEY:
 		retval = ixgbe_get_vf_rss_key(adapter, msgbuf, vf);
 		break;
+#endif /* HAVE_NDO_SET_VF_RSS_QUERY_EN */
 	case IXGBE_VF_UPDATE_XCAST_MODE:
 		retval = ixgbe_update_vf_xcast_mode(adapter, msgbuf, vf);
 		break;
@@ -1154,11 +1389,58 @@ static void ixgbe_rcv_ack_from_vf(struct ixgbe_adapter *adapter, u32 vf)
 		ixgbe_write_mbx(hw, &msg, 1, vf);
 }
 
+#define Q_BITMAP_DEPTH 2
+static void ixgbe_check_mdd_event(struct ixgbe_adapter *adapter)
+{
+	struct ixgbe_hw *hw = &adapter->hw;
+	u32 vf_bitmap[Q_BITMAP_DEPTH] = { 0 };
+	u32 j, i;
+	u32 ping;
+
+	if (!hw->mac.ops.mdd_event)
+		return;
+
+	/* Did we have a malicious event */
+	hw->mac.ops.mdd_event(hw, vf_bitmap);
+
+	/* Log any blocked queues and release lock */
+	for (i = 0; i < Q_BITMAP_DEPTH; i++) {
+		for (j = 0; j < 32 && vf_bitmap[i]; j++) {
+			u32 vf;
+
+			if (!(vf_bitmap[i] & (1 << j)))
+				continue;
+
+			/* The VF that malicious event occurred on */
+			vf = j + (i * 32);
+
+			dev_warn(pci_dev_to_dev(adapter->pdev),
+				"Malicious event on VF %d tx:%x rx:%x\n", vf,
+				IXGBE_READ_REG(hw, IXGBE_LVMMC_TX),
+				IXGBE_READ_REG(hw, IXGBE_LVMMC_RX));
+
+			/* restart the vf */
+			if (hw->mac.ops.restore_mdd_vf) {
+				hw->mac.ops.restore_mdd_vf(hw, vf);
+
+				/* get the VF to rebuild its queues */
+				adapter->vfinfo[vf].clear_to_send = 0;
+				ping = IXGBE_PF_CONTROL_MSG |
+				       IXGBE_VT_MSGTYPE_CTS;
+				ixgbe_write_mbx(hw, &ping, 1, vf);
+			}
+		}
+	}
+}
+
 void ixgbe_msg_task(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	u32 vf;
 
+	if (adapter->flags & IXGBE_FLAG_MDD_ENABLED && adapter->vfinfo)
+		ixgbe_check_mdd_event(adapter);
+
 	for (vf = 0; vf < adapter->num_vfs; vf++) {
 		/* process any reset requests */
 		if (!ixgbe_check_for_rst(hw, vf))
@@ -1186,6 +1468,7 @@ void ixgbe_disable_tx_rx(struct ixgbe_adapter *adapter)
 	IXGBE_WRITE_REG(hw, IXGBE_VFRE(1), 0);
 }
 
+#ifdef HAVE_NDO_SET_VF_TRUST
 static inline void ixgbe_ping_vf(struct ixgbe_adapter *adapter, int vf)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
@@ -1197,6 +1480,7 @@ static inline void ixgbe_ping_vf(struct ixgbe_adapter *adapter, int vf)
 	ixgbe_write_mbx(hw, &ping, 1, vf);
 }
 
+#endif
 void ixgbe_ping_all_vfs(struct ixgbe_adapter *adapter)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
@@ -1211,26 +1495,82 @@ void ixgbe_ping_all_vfs(struct ixgbe_adapter *adapter)
 	}
 }
 
+#ifdef HAVE_NDO_SET_VF_TRUST
+int ixgbe_ndo_set_vf_trust(struct net_device *netdev, int vf, bool setting)
+{
+	struct ixgbe_adapter *adapter = netdev_priv(netdev);
+
+	if (vf >= adapter->num_vfs)
+		return -EINVAL;
+
+	/* nothing to do */
+	if (adapter->vfinfo[vf].trusted == setting)
+		return 0;
+
+	adapter->vfinfo[vf].trusted = setting;
+
+	/* reset VF to reconfigure features */
+	adapter->vfinfo[vf].clear_to_send = false;
+	ixgbe_ping_vf(adapter, vf);
+
+	e_info(drv, "VF %u is %strusted\n", vf, setting ? "" : "not ");
+
+	return 0;
+}
+
+#endif
+#ifdef IFLA_VF_MAX
 int ixgbe_ndo_set_vf_mac(struct net_device *netdev, int vf, u8 *mac)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	if (!is_valid_ether_addr(mac) || (vf >= adapter->num_vfs))
+	s32 retval = 0;
+
+	if (vf >= adapter->num_vfs)
 		return -EINVAL;
-	adapter->vfinfo[vf].pf_set_mac = true;
-	dev_info(&adapter->pdev->dev, "setting MAC %pM on VF %d\n", mac, vf);
-	dev_info(&adapter->pdev->dev, "Reload the VF driver to make this"
-				      " change effective.");
-	if (test_bit(__IXGBE_DOWN, &adapter->state)) {
-		dev_warn(&adapter->pdev->dev, "The VF MAC address has been set,"
-			 " but the PF device is not up.\n");
-		dev_warn(&adapter->pdev->dev, "Bring the PF device up before"
-			 " attempting to use the VF device.\n");
+
+	if (is_valid_ether_addr(mac)) {
+		dev_info(pci_dev_to_dev(adapter->pdev), "setting MAC %pM on VF %d\n",
+			 mac, vf);
+		dev_info(pci_dev_to_dev(adapter->pdev), "Reload the VF driver to make this change effective.\n");
+
+		retval = ixgbe_set_vf_mac(adapter, vf, mac);
+		if (retval >= 0) {
+		/* pf_set_mac is used in ESX5.1 and base driver but not in ESX5.5 */
+			adapter->vfinfo[vf].pf_set_mac = true;
+
+			if (test_bit(__IXGBE_DOWN, &adapter->state)) {
+				dev_warn(pci_dev_to_dev(adapter->pdev), "The VF MAC address has been set, but the PF device is not up.\n");
+				dev_warn(pci_dev_to_dev(adapter->pdev), "Bring the PF device up before attempting to use the VF device.\n");
+			}
+		} else {
+			dev_warn(pci_dev_to_dev(adapter->pdev), "The VF MAC address was NOT set due to invalid or duplicate MAC address.\n");
+		}
+	} else if (is_zero_ether_addr(mac)) {
+		unsigned char *vf_mac_addr =
+					   adapter->vfinfo[vf].vf_mac_addresses;
+
+		/* nothing to do */
+		if (is_zero_ether_addr(vf_mac_addr))
+			return 0;
+
+		dev_info(pci_dev_to_dev(adapter->pdev), "removing MAC on VF %d\n",
+			 vf);
+
+		retval = ixgbe_del_mac_filter(adapter, vf_mac_addr, vf);
+		if (retval >= 0) {
+			adapter->vfinfo[vf].pf_set_mac = false;
+			memcpy(vf_mac_addr, mac, ETH_ALEN);
+		} else {
+			dev_warn(pci_dev_to_dev(adapter->pdev), "Could NOT remove the VF MAC address.\n");
+		}
+	} else {
+		retval = -EINVAL;
 	}
-	return ixgbe_set_vf_mac(adapter, vf, mac);
+	return retval;
 }
 
-static int ixgbe_enable_port_vlan(struct ixgbe_adapter *adapter, int vf,
-				  u16 vlan, u8 qos)
+static int ixgbe_enable_port_vlan(struct ixgbe_adapter *adapter,
+				   int vf, u16 vlan, u8 qos)
 {
 	struct ixgbe_hw *hw = &adapter->hw;
 	int err;
@@ -1239,26 +1579,23 @@ static int ixgbe_enable_port_vlan(struct ixgbe_adapter *adapter, int vf,
 	if (err)
 		goto out;
 
+	/* Revoke tagless access via VLAN 0 */
+	ixgbe_set_vf_vlan(adapter, false, 0, vf);
+
 	ixgbe_set_vmvir(adapter, vlan, qos, vf);
 	ixgbe_set_vmolr(hw, vf, false);
-	if (adapter->vfinfo[vf].spoofchk_enabled)
-		hw->mac.ops.set_vlan_anti_spoofing(hw, true, vf);
-	adapter->vfinfo[vf].vlan_count++;
 
 	/* enable hide vlan on X550 */
 	if (hw->mac.type >= ixgbe_mac_X550)
 		ixgbe_write_qde(adapter, vf, IXGBE_QDE_ENABLE |
 				IXGBE_QDE_HIDE_VLAN);
-
 	adapter->vfinfo[vf].pf_vlan = vlan;
 	adapter->vfinfo[vf].pf_qos = qos;
-	dev_info(&adapter->pdev->dev,
+	dev_info(pci_dev_to_dev(adapter->pdev),
 		 "Setting VLAN %d, QOS 0x%x on VF %d\n", vlan, qos, vf);
 	if (test_bit(__IXGBE_DOWN, &adapter->state)) {
-		dev_warn(&adapter->pdev->dev,
-			 "The VF VLAN has been set, but the PF device is not up.\n");
-		dev_warn(&adapter->pdev->dev,
-			 "Bring the PF device up before attempting to use the VF device.\n");
+		dev_warn(pci_dev_to_dev(adapter->pdev), "The VF VLAN has been set, but the PF device is not up.\n");
+		dev_warn(pci_dev_to_dev(adapter->pdev), "Bring the PF device up before attempting to use the VF device.\n");
 	}
 
 out:
@@ -1272,31 +1609,40 @@ static int ixgbe_disable_port_vlan(struct ixgbe_adapter *adapter, int vf)
 
 	err = ixgbe_set_vf_vlan(adapter, false,
 				adapter->vfinfo[vf].pf_vlan, vf);
+	/* Restore tagless access via VLAN 0 */
+	ixgbe_set_vf_vlan(adapter, true, 0, vf);
 	ixgbe_clear_vmvir(adapter, vf);
 	ixgbe_set_vmolr(hw, vf, true);
-	hw->mac.ops.set_vlan_anti_spoofing(hw, false, vf);
-	if (adapter->vfinfo[vf].vlan_count)
-		adapter->vfinfo[vf].vlan_count--;
 
 	/* disable hide VLAN on X550 */
 	if (hw->mac.type >= ixgbe_mac_X550)
 		ixgbe_write_qde(adapter, vf, IXGBE_QDE_ENABLE);
-
 	adapter->vfinfo[vf].pf_vlan = 0;
 	adapter->vfinfo[vf].pf_qos = 0;
 
 	return err;
 }
 
+#ifdef IFLA_VF_VLAN_INFO_MAX
+int ixgbe_ndo_set_vf_vlan(struct net_device *netdev, int vf, u16 vlan,
+			  u8 qos, __be16 vlan_proto)
+#else
 int ixgbe_ndo_set_vf_vlan(struct net_device *netdev, int vf, u16 vlan, u8 qos)
+#endif
 {
 	int err = 0;
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 
-	if ((vf >= adapter->num_vfs) || (vlan > 4095) || (qos > 7))
+	/* VLAN IDs accepted range 0-4094 */
+	if ((vf >= adapter->num_vfs) || (vlan > VLAN_VID_MASK-1) || (qos > 7))
 		return -EINVAL;
+#ifdef IFLA_VF_VLAN_INFO_MAX
+	if (vlan_proto != htons(ETH_P_8021Q))
+		return -EPROTONOSUPPORT;
+#endif
 	if (vlan || qos) {
-		/* Check if there is already a port VLAN set, if so
+		/*
+		 * Check if there is already a port VLAN set, if so
 		 * we have to delete the old one first before we
 		 * can set the new one.  The usage model had
 		 * previously assumed the user would delete the
@@ -1308,10 +1654,10 @@ int ixgbe_ndo_set_vf_vlan(struct net_device *netdev, int vf, u16 vlan, u8 qos)
 		if (err)
 			goto out;
 		err = ixgbe_enable_port_vlan(adapter, vf, vlan, qos);
+
 	} else {
 		err = ixgbe_disable_port_vlan(adapter, vf);
 	}
-
 out:
 	return err;
 }
@@ -1392,7 +1738,7 @@ void ixgbe_check_vf_rate_limit(struct ixgbe_adapter *adapter)
 
 	if (ixgbe_link_mbps(adapter) != adapter->vf_rate_link_speed) {
 		adapter->vf_rate_link_speed = 0;
-		dev_info(&adapter->pdev->dev,
+		dev_info(pci_dev_to_dev(adapter->pdev),
 			 "Link speed has been changed. VF Transmit rate is disabled\n");
 	}
 
@@ -1404,8 +1750,14 @@ void ixgbe_check_vf_rate_limit(struct ixgbe_adapter *adapter)
 	}
 }
 
-int ixgbe_ndo_set_vf_bw(struct net_device *netdev, int vf, int min_tx_rate,
+#ifdef HAVE_NDO_SET_VF_MIN_MAX_TX_RATE
+int ixgbe_ndo_set_vf_bw(struct net_device *netdev,
+			int vf,
+			int __always_unused min_tx_rate,
 			int max_tx_rate)
+#else
+int ixgbe_ndo_set_vf_bw(struct net_device *netdev, int vf, int max_tx_rate)
+#endif /* HAVE_NDO_SET_VF_MIN_MAX_TX_RATE */
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
 	int link_speed;
@@ -1423,9 +1775,6 @@ int ixgbe_ndo_set_vf_bw(struct net_device *netdev, int vf, int min_tx_rate,
 	if (link_speed != 10000)
 		return -EINVAL;
 
-	if (min_tx_rate)
-		return -EINVAL;
-
 	/* rate limit cannot be less than 10Mbs or greater than link speed */
 	if (max_tx_rate && ((max_tx_rate <= 10) || (max_tx_rate > link_speed)))
 		return -EINVAL;
@@ -1440,35 +1789,46 @@ int ixgbe_ndo_set_vf_bw(struct net_device *netdev, int vf, int min_tx_rate,
 	return 0;
 }
 
+#endif /* IFLA_VF_MAX */
+#if IS_ENABLED(CONFIG_PCI_IOV)
 int ixgbe_ndo_set_vf_spoofchk(struct net_device *netdev, int vf, bool setting)
 {
 	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-	int vf_target_reg = vf >> 3;
-	int vf_target_shift = vf % 8;
 	struct ixgbe_hw *hw = &adapter->hw;
-	u32 regval;
 
 	if (vf >= adapter->num_vfs)
 		return -EINVAL;
 
 	adapter->vfinfo[vf].spoofchk_enabled = setting;
 
-	regval = IXGBE_READ_REG(hw, IXGBE_PFVFSPOOF(vf_target_reg));
-	regval &= ~(1 << vf_target_shift);
-	regval |= (setting << vf_target_shift);
-	IXGBE_WRITE_REG(hw, IXGBE_PFVFSPOOF(vf_target_reg), regval);
-
-	if (adapter->vfinfo[vf].vlan_count) {
-		vf_target_shift += IXGBE_SPOOF_VLANAS_SHIFT;
-		regval = IXGBE_READ_REG(hw, IXGBE_PFVFSPOOF(vf_target_reg));
-		regval &= ~(1 << vf_target_shift);
-		regval |= (setting << vf_target_shift);
-		IXGBE_WRITE_REG(hw, IXGBE_PFVFSPOOF(vf_target_reg), regval);
-	}
+	/* configure MAC spoofing */
+	hw->mac.ops.set_mac_anti_spoofing(hw, setting, vf);
+
+	/* configure VLAN spoofing */
+	hw->mac.ops.set_vlan_anti_spoofing(hw, setting, vf);
 
+	/* Ensure LLDP and FC is set for Ethertype Antispoofing if we will be
+	 * calling set_ethertype_anti_spoofing for each VF in loop below
+	 */
+	if (hw->mac.ops.set_ethertype_anti_spoofing) {
+		IXGBE_WRITE_REG(hw, IXGBE_ETQF(IXGBE_ETQF_FILTER_LLDP),
+				(IXGBE_ETQF_FILTER_EN    |
+				 IXGBE_ETQF_TX_ANTISPOOF |
+				 IXGBE_ETH_P_LLDP));
+
+		IXGBE_WRITE_REG(hw, IXGBE_ETQF(IXGBE_ETQF_FILTER_FC),
+				(IXGBE_ETQF_FILTER_EN |
+				 IXGBE_ETQF_TX_ANTISPOOF |
+				 ETH_P_PAUSE));
+
+		hw->mac.ops.set_ethertype_anti_spoofing(hw, setting, vf);
+	}
 	return 0;
 }
 
+#endif /* CONFIG_PCI_IOV */
+#ifdef IFLA_VF_MAX
+#ifdef HAVE_NDO_SET_VF_RSS_QUERY_EN
 int ixgbe_ndo_set_vf_rss_query_en(struct net_device *netdev, int vf,
 				  bool setting)
 {
@@ -1489,28 +1849,7 @@ int ixgbe_ndo_set_vf_rss_query_en(struct net_device *netdev, int vf,
 	return 0;
 }
 
-int ixgbe_ndo_set_vf_trust(struct net_device *netdev, int vf, bool setting)
-{
-	struct ixgbe_adapter *adapter = netdev_priv(netdev);
-
-	if (vf >= adapter->num_vfs)
-		return -EINVAL;
-
-	/* nothing to do */
-	if (adapter->vfinfo[vf].trusted == setting)
-		return 0;
-
-	adapter->vfinfo[vf].trusted = setting;
-
-	/* reset VF to reconfigure features */
-	adapter->vfinfo[vf].clear_to_send = false;
-	ixgbe_ping_vf(adapter, vf);
-
-	e_info(drv, "VF %u is %strusted\n", vf, setting ? "" : "not ");
-
-	return 0;
-}
-
+#endif
 int ixgbe_ndo_get_vf_config(struct net_device *netdev,
 			    int vf, struct ifla_vf_info *ivi)
 {
@@ -1519,12 +1858,26 @@ int ixgbe_ndo_get_vf_config(struct net_device *netdev,
 		return -EINVAL;
 	ivi->vf = vf;
 	memcpy(&ivi->mac, adapter->vfinfo[vf].vf_mac_addresses, ETH_ALEN);
+
+#ifdef HAVE_NDO_SET_VF_MIN_MAX_TX_RATE
 	ivi->max_tx_rate = adapter->vfinfo[vf].tx_rate;
 	ivi->min_tx_rate = 0;
+#else
+	ivi->tx_rate = adapter->vfinfo[vf].tx_rate;
+#endif /* HAVE_NDO_SET_VF_MIN_MAX_TX_RATE */
+
 	ivi->vlan = adapter->vfinfo[vf].pf_vlan;
 	ivi->qos = adapter->vfinfo[vf].pf_qos;
+#ifdef HAVE_VF_SPOOFCHK_CONFIGURE
 	ivi->spoofchk = adapter->vfinfo[vf].spoofchk_enabled;
+#endif
+#ifdef HAVE_NDO_SET_VF_RSS_QUERY_EN
 	ivi->rss_query_en = adapter->vfinfo[vf].rss_query_enabled;
+#endif
+#ifdef HAVE_NDO_SET_VF_TRUST
 	ivi->trusted = adapter->vfinfo[vf].trusted;
+#endif
 	return 0;
 }
+#endif /* IFLA_VF_MAX */
+
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_sriov.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_sriov.h
index dad9257..5d080ba 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_sriov.h
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_sriov.h
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,47 +22,71 @@
 
 *******************************************************************************/
 
+
 #ifndef _IXGBE_SRIOV_H_
 #define _IXGBE_SRIOV_H_
 
-/*  ixgbe driver limit the max number of VFs could be enabled to
- *  63 (IXGBE_MAX_VF_FUNCTIONS - 1)
+/* ixgbe driver limit the max number of VFs could be enabled to
+ * 63 (IXGBE_MAX_VF_FUNCTIONS - 1)
  */
 #define IXGBE_MAX_VFS_DRV_LIMIT  (IXGBE_MAX_VF_FUNCTIONS - 1)
+#define IXGBE_MAX_VFS_1TC	 IXGBE_MAX_VFS_DRV_LIMIT
+#define IXGBE_MAX_VFS_4TC	 31
+#define IXGBE_MAX_VFS_8TC	 15
 
-#ifdef CONFIG_PCI_IOV
 void ixgbe_restore_vf_multicasts(struct ixgbe_adapter *adapter);
-#endif
+int ixgbe_set_vf_vlan(struct ixgbe_adapter *adapter, int add, int vid, u32 vf);
+void ixgbe_set_vmolr(struct ixgbe_hw *hw, u32 vf, bool aupe);
 void ixgbe_msg_task(struct ixgbe_adapter *adapter);
-int ixgbe_vf_configuration(struct pci_dev *pdev, unsigned int event_mask);
+int ixgbe_set_vf_mac(struct ixgbe_adapter *adapter,
+		     int vf, unsigned char *mac_addr);
 void ixgbe_disable_tx_rx(struct ixgbe_adapter *adapter);
 void ixgbe_ping_all_vfs(struct ixgbe_adapter *adapter);
+#ifdef IFLA_VF_MAX
 int ixgbe_ndo_set_vf_mac(struct net_device *netdev, int queue, u8 *mac);
+#ifdef IFLA_VF_VLAN_INFO_MAX
 int ixgbe_ndo_set_vf_vlan(struct net_device *netdev, int queue, u16 vlan,
-			   u8 qos);
+			  u8 qos, __be16 vlan_proto);
+#else
+int ixgbe_ndo_set_vf_vlan(struct net_device *netdev, int queue, u16 vlan,
+			  u8 qos);
+#endif
+#ifdef HAVE_NDO_SET_VF_MIN_MAX_TX_RATE
 int ixgbe_ndo_set_vf_bw(struct net_device *netdev, int vf, int min_tx_rate,
 			int max_tx_rate);
-int ixgbe_ndo_set_vf_spoofchk(struct net_device *netdev, int vf, bool setting);
+#else
+int ixgbe_ndo_set_vf_bw(struct net_device *netdev, int vf, int tx_rate);
+#endif /* HAVE_NDO_SET_VF_MIN_MAX_TX_RATE */
+#ifdef HAVE_NDO_SET_VF_RSS_QUERY_EN
 int ixgbe_ndo_set_vf_rss_query_en(struct net_device *netdev, int vf,
 				  bool setting);
+#endif
+#ifdef HAVE_NDO_SET_VF_TRUST
 int ixgbe_ndo_set_vf_trust(struct net_device *netdev, int vf, bool setting);
+#endif
 int ixgbe_ndo_get_vf_config(struct net_device *netdev,
 			    int vf, struct ifla_vf_info *ivi);
-void ixgbe_check_vf_rate_limit(struct ixgbe_adapter *adapter);
+#endif /* IFLA_VF_MAX */
 int ixgbe_disable_sriov(struct ixgbe_adapter *adapter);
 #ifdef CONFIG_PCI_IOV
+int ixgbe_vf_configuration(struct pci_dev *pdev, unsigned int event_mask);
 void ixgbe_enable_sriov(struct ixgbe_adapter *adapter);
+int ixgbe_ndo_set_vf_spoofchk(struct net_device *netdev, int vf, bool setting);
 #endif
 int ixgbe_pci_sriov_configure(struct pci_dev *dev, int num_vfs);
+#ifdef IFLA_VF_MAX
+void ixgbe_check_vf_rate_limit(struct ixgbe_adapter *adapter);
+#endif /* IFLA_VF_MAX */
+void ixgbe_dump_registers(struct ixgbe_adapter *adapter);
 
-static inline void ixgbe_set_vmvir(struct ixgbe_adapter *adapter,
-				   u16 vid, u16 qos, u32 vf)
-{
-	struct ixgbe_hw *hw = &adapter->hw;
-	u32 vmvir = vid | (qos << VLAN_PRIO_SHIFT) | IXGBE_VMVIR_VLANA_DEFAULT;
-
-	IXGBE_WRITE_REG(hw, IXGBE_VMVIR(vf), vmvir);
-}
-
+/*
+ * These are defined in ixgbe_type.h on behalf of the VF driver
+ * but we need them here unwrapped for the PF driver.
+ */
+#define IXGBE_DEV_ID_82599_VF			0x10ED
+#define IXGBE_DEV_ID_X540_VF			0x1515
+#define IXGBE_DEV_ID_X550_VF			0x1565
+#define IXGBE_DEV_ID_X550EM_X_VF		0x15A8
+#define IXGBE_DEV_ID_X550EM_A_VF		0x15C5
 #endif /* _IXGBE_SRIOV_H_ */
 
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_sysfs.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_sysfs.c
index ef6df3d..5d30be5 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_sysfs.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_sysfs.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2013 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -30,16 +26,22 @@
 #include "ixgbe_common.h"
 #include "ixgbe_type.h"
 
+#ifdef IXGBE_SYSFS
+
 #include <linux/module.h>
 #include <linux/types.h>
 #include <linux/sysfs.h>
 #include <linux/kobject.h>
 #include <linux/device.h>
 #include <linux/netdevice.h>
+#include <linux/time.h>
+#ifdef IXGBE_HWMON
 #include <linux/hwmon.h>
+#endif
 
+#ifdef IXGBE_HWMON
 /* hwmon callback functions */
-static ssize_t ixgbe_hwmon_show_location(struct device *dev,
+static ssize_t ixgbe_hwmon_show_location(struct device __always_unused *dev,
 					 struct device_attribute *attr,
 					 char *buf)
 {
@@ -49,7 +51,7 @@ static ssize_t ixgbe_hwmon_show_location(struct device *dev,
 		       ixgbe_attr->sensor->location);
 }
 
-static ssize_t ixgbe_hwmon_show_temp(struct device *dev,
+static ssize_t ixgbe_hwmon_show_temp(struct device __always_unused *dev,
 				     struct device_attribute *attr,
 				     char *buf)
 {
@@ -68,7 +70,7 @@ static ssize_t ixgbe_hwmon_show_temp(struct device *dev,
 	return sprintf(buf, "%u\n", value);
 }
 
-static ssize_t ixgbe_hwmon_show_cautionthresh(struct device *dev,
+static ssize_t ixgbe_hwmon_show_cautionthresh(struct device __always_unused *dev,
 				     struct device_attribute *attr,
 				     char *buf)
 {
@@ -82,7 +84,7 @@ static ssize_t ixgbe_hwmon_show_cautionthresh(struct device *dev,
 	return sprintf(buf, "%u\n", value);
 }
 
-static ssize_t ixgbe_hwmon_show_maxopthresh(struct device *dev,
+static ssize_t ixgbe_hwmon_show_maxopthresh(struct device __always_unused *dev,
 				     struct device_attribute *attr,
 				     char *buf)
 {
@@ -112,29 +114,29 @@ static int ixgbe_add_hwmon_attr(struct ixgbe_adapter *adapter,
 	unsigned int n_attr;
 	struct hwmon_attr *ixgbe_attr;
 
-	n_attr = adapter->ixgbe_hwmon_buff->n_hwmon;
-	ixgbe_attr = &adapter->ixgbe_hwmon_buff->hwmon_list[n_attr];
+	n_attr = adapter->ixgbe_hwmon_buff.n_hwmon;
+	ixgbe_attr = &adapter->ixgbe_hwmon_buff.hwmon_list[n_attr];
 
 	switch (type) {
 	case IXGBE_HWMON_TYPE_LOC:
 		ixgbe_attr->dev_attr.show = ixgbe_hwmon_show_location;
 		snprintf(ixgbe_attr->name, sizeof(ixgbe_attr->name),
-			 "temp%u_label", offset + 1);
+			 "temp%u_label", offset);
 		break;
 	case IXGBE_HWMON_TYPE_TEMP:
 		ixgbe_attr->dev_attr.show = ixgbe_hwmon_show_temp;
 		snprintf(ixgbe_attr->name, sizeof(ixgbe_attr->name),
-			 "temp%u_input", offset + 1);
+			 "temp%u_input", offset);
 		break;
 	case IXGBE_HWMON_TYPE_CAUTION:
 		ixgbe_attr->dev_attr.show = ixgbe_hwmon_show_cautionthresh;
 		snprintf(ixgbe_attr->name, sizeof(ixgbe_attr->name),
-			 "temp%u_max", offset + 1);
+			 "temp%u_max", offset);
 		break;
 	case IXGBE_HWMON_TYPE_MAX:
 		ixgbe_attr->dev_attr.show = ixgbe_hwmon_show_maxopthresh;
 		snprintf(ixgbe_attr->name, sizeof(ixgbe_attr->name),
-			 "temp%u_crit", offset + 1);
+			 "temp%u_crit", offset);
 		break;
 	default:
 		rc = -EPERM;
@@ -148,17 +150,35 @@ static int ixgbe_add_hwmon_attr(struct ixgbe_adapter *adapter,
 	ixgbe_attr->dev_attr.store = NULL;
 	ixgbe_attr->dev_attr.attr.mode = S_IRUGO;
 	ixgbe_attr->dev_attr.attr.name = ixgbe_attr->name;
-	sysfs_attr_init(&ixgbe_attr->dev_attr.attr);
 
-	adapter->ixgbe_hwmon_buff->attrs[n_attr] = &ixgbe_attr->dev_attr.attr;
+	rc = device_create_file(pci_dev_to_dev(adapter->pdev),
+				&ixgbe_attr->dev_attr);
 
-	++adapter->ixgbe_hwmon_buff->n_hwmon;
+	if (rc == 0)
+		++adapter->ixgbe_hwmon_buff.n_hwmon;
 
-	return 0;
+	return rc;
 }
+#endif /* IXGBE_HWMON */
 
-static void ixgbe_sysfs_del_adapter(struct ixgbe_adapter *adapter)
+static void ixgbe_sysfs_del_adapter(struct ixgbe_adapter __maybe_unused *adapter)
 {
+#ifdef IXGBE_HWMON
+	int i;
+
+	if (adapter == NULL)
+		return;
+
+	for (i = 0; i < adapter->ixgbe_hwmon_buff.n_hwmon; i++) {
+		device_remove_file(pci_dev_to_dev(adapter->pdev),
+			   &adapter->ixgbe_hwmon_buff.hwmon_list[i].dev_attr);
+	}
+
+	kfree(adapter->ixgbe_hwmon_buff.hwmon_list);
+
+	if (adapter->ixgbe_hwmon_buff.device)
+		hwmon_device_unregister(adapter->ixgbe_hwmon_buff.device);
+#endif /* IXGBE_HWMON */
 }
 
 /* called from ixgbe_main.c */
@@ -170,27 +190,43 @@ void ixgbe_sysfs_exit(struct ixgbe_adapter *adapter)
 /* called from ixgbe_main.c */
 int ixgbe_sysfs_init(struct ixgbe_adapter *adapter)
 {
-	struct hwmon_buff *ixgbe_hwmon;
-	struct device *hwmon_dev;
-	unsigned int i;
 	int rc = 0;
+#ifdef IXGBE_HWMON
+	struct hwmon_buff *ixgbe_hwmon = &adapter->ixgbe_hwmon_buff;
+	unsigned int i;
+	int n_attrs;
 
+#endif /* IXGBE_HWMON */
+	if (adapter == NULL)
+		goto err;
+
+#ifdef IXGBE_HWMON
 	/* If this method isn't defined we don't support thermals */
 	if (adapter->hw.mac.ops.init_thermal_sensor_thresh == NULL) {
-		goto exit;
+		goto no_thermal;
 	}
 
 	/* Don't create thermal hwmon interface if no sensors present */
 	if (adapter->hw.mac.ops.init_thermal_sensor_thresh(&adapter->hw))
-		goto exit;
-
-	ixgbe_hwmon = devm_kzalloc(&adapter->pdev->dev, sizeof(*ixgbe_hwmon),
-				   GFP_KERNEL);
-	if (ixgbe_hwmon == NULL) {
+		goto no_thermal;
+
+	/*
+	 * Allocation space for max attributs
+	 * max num sensors * values (loc, temp, max, caution)
+	 */
+	n_attrs = IXGBE_MAX_SENSORS * 4;
+	ixgbe_hwmon->hwmon_list = kcalloc(n_attrs, sizeof(struct hwmon_attr),
+					  GFP_KERNEL);
+	if (!ixgbe_hwmon->hwmon_list) {
 		rc = -ENOMEM;
-		goto exit;
+		goto err;
+	}
+
+	ixgbe_hwmon->device = hwmon_device_register(pci_dev_to_dev(adapter->pdev));
+	if (IS_ERR(ixgbe_hwmon->device)) {
+		rc = PTR_ERR(ixgbe_hwmon->device);
+		goto err;
 	}
-	adapter->ixgbe_hwmon_buff = ixgbe_hwmon;
 
 	for (i = 0; i < IXGBE_MAX_SENSORS; i++) {
 		/*
@@ -202,29 +238,20 @@ int ixgbe_sysfs_init(struct ixgbe_adapter *adapter)
 
 		/* Bail if any hwmon attr struct fails to initialize */
 		rc = ixgbe_add_hwmon_attr(adapter, i, IXGBE_HWMON_TYPE_CAUTION);
+		rc |= ixgbe_add_hwmon_attr(adapter, i, IXGBE_HWMON_TYPE_LOC);
+		rc |= ixgbe_add_hwmon_attr(adapter, i, IXGBE_HWMON_TYPE_TEMP);
+		rc |= ixgbe_add_hwmon_attr(adapter, i, IXGBE_HWMON_TYPE_MAX);
 		if (rc)
-			goto exit;
-		rc = ixgbe_add_hwmon_attr(adapter, i, IXGBE_HWMON_TYPE_LOC);
-		if (rc)
-			goto exit;
-		rc = ixgbe_add_hwmon_attr(adapter, i, IXGBE_HWMON_TYPE_TEMP);
-		if (rc)
-			goto exit;
-		rc = ixgbe_add_hwmon_attr(adapter, i, IXGBE_HWMON_TYPE_MAX);
-		if (rc)
-			goto exit;
+			goto err;
 	}
 
-	ixgbe_hwmon->groups[0] = &ixgbe_hwmon->group;
-	ixgbe_hwmon->group.attrs = ixgbe_hwmon->attrs;
+no_thermal:
+#endif /* IXGBE_HWMON */
+	goto exit;
 
-	hwmon_dev = devm_hwmon_device_register_with_groups(&adapter->pdev->dev,
-							   "ixgbe",
-							   ixgbe_hwmon,
-							   ixgbe_hwmon->groups);
-	if (IS_ERR(hwmon_dev))
-		rc = PTR_ERR(hwmon_dev);
+err:
+	ixgbe_sysfs_del_adapter(adapter);
 exit:
 	return rc;
 }
-
+#endif /* IXGBE_SYSFS */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_type.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_type.h
index 995f031..b5a5365 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_type.h
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_type.h
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2015 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -29,184 +25,245 @@
 #ifndef _IXGBE_TYPE_H_
 #define _IXGBE_TYPE_H_
 
-#include <linux/types.h>
-#include <linux/mdio.h>
-#include <linux/netdevice.h>
+/*
+ * The following is a brief description of the error categories used by the
+ * ERROR_REPORT* macros.
+ *
+ * - IXGBE_ERROR_INVALID_STATE
+ * This category is for errors which represent a serious failure state that is
+ * unexpected, and could be potentially harmful to device operation. It should
+ * not be used for errors relating to issues that can be worked around or
+ * ignored.
+ *
+ * - IXGBE_ERROR_POLLING
+ * This category is for errors related to polling/timeout issues and should be
+ * used in any case where the timeout occured, or a failure to obtain a lock, or
+ * failure to receive data within the time limit.
+ *
+ * - IXGBE_ERROR_CAUTION
+ * This category should be used for reporting issues that may be the cause of
+ * other errors, such as temperature warnings. It should indicate an event which
+ * could be serious, but hasn't necessarily caused problems yet.
+ *
+ * - IXGBE_ERROR_SOFTWARE
+ * This category is intended for errors due to software state preventing
+ * something. The category is not intended for errors due to bad arguments, or
+ * due to unsupported features. It should be used when a state occurs which
+ * prevents action but is not a serious issue.
+ *
+ * - IXGBE_ERROR_ARGUMENT
+ * This category is for when a bad or invalid argument is passed. It should be
+ * used whenever a function is called and error checking has detected the
+ * argument is wrong or incorrect.
+ *
+ * - IXGBE_ERROR_UNSUPPORTED
+ * This category is for errors which are due to unsupported circumstances or
+ * configuration issues. It should not be used when the issue is due to an
+ * invalid argument, but for when something has occurred that is unsupported
+ * (Ex: Flow control autonegotiation or an unsupported SFP+ module.)
+ */
+
+#include "ixgbe_osdep.h"
+
+/* Override this by setting IOMEM in your ixgbe_osdep.h header */
+#ifndef IOMEM
+#define IOMEM
+#endif
+
+/* Vendor ID */
+#define IXGBE_INTEL_VENDOR_ID			0x8086
 
 /* Device IDs */
-#define IXGBE_DEV_ID_82598               0x10B6
-#define IXGBE_DEV_ID_82598_BX            0x1508
-#define IXGBE_DEV_ID_82598AF_DUAL_PORT   0x10C6
-#define IXGBE_DEV_ID_82598AF_SINGLE_PORT 0x10C7
-#define IXGBE_DEV_ID_82598EB_SFP_LOM     0x10DB
-#define IXGBE_DEV_ID_82598AT             0x10C8
-#define IXGBE_DEV_ID_82598AT2            0x150B
-#define IXGBE_DEV_ID_82598EB_CX4         0x10DD
-#define IXGBE_DEV_ID_82598_CX4_DUAL_PORT 0x10EC
-#define IXGBE_DEV_ID_82598_DA_DUAL_PORT  0x10F1
-#define IXGBE_DEV_ID_82598_SR_DUAL_PORT_EM      0x10E1
-#define IXGBE_DEV_ID_82598EB_XF_LR       0x10F4
-#define IXGBE_DEV_ID_82599_KX4           0x10F7
-#define IXGBE_DEV_ID_82599_KX4_MEZZ      0x1514
-#define IXGBE_DEV_ID_82599_KR            0x1517
-#define IXGBE_DEV_ID_82599_T3_LOM        0x151C
-#define IXGBE_DEV_ID_82599_CX4           0x10F9
-#define IXGBE_DEV_ID_82599_SFP           0x10FB
-#define IXGBE_DEV_ID_82599_BACKPLANE_FCOE       0x152a
-#define IXGBE_DEV_ID_82599_SFP_FCOE      0x1529
-#define IXGBE_SUBDEV_ID_82599_SFP        0x11A9
-#define IXGBE_SUBDEV_ID_82599_SFP_WOL0   0x1071
-#define IXGBE_SUBDEV_ID_82599_RNDC       0x1F72
-#define IXGBE_SUBDEV_ID_82599_560FLR     0x17D0
-#define IXGBE_SUBDEV_ID_82599_SP_560FLR  0x211B
-#define IXGBE_SUBDEV_ID_82599_ECNA_DP    0x0470
-#define IXGBE_SUBDEV_ID_82599_LOM_SFP    0x8976
-#define IXGBE_DEV_ID_82599_SFP_EM        0x1507
-#define IXGBE_DEV_ID_82599_SFP_SF2       0x154D
-#define IXGBE_DEV_ID_82599EN_SFP         0x1557
-#define IXGBE_SUBDEV_ID_82599EN_SFP_OCP1 0x0001
-#define IXGBE_DEV_ID_82599_XAUI_LOM      0x10FC
-#define IXGBE_DEV_ID_82599_COMBO_BACKPLANE 0x10F8
-#define IXGBE_SUBDEV_ID_82599_KX4_KR_MEZZ  0x000C
-#define IXGBE_DEV_ID_82599_LS            0x154F
-#define IXGBE_DEV_ID_X540T               0x1528
-#define IXGBE_DEV_ID_82599_SFP_SF_QP     0x154A
-#define IXGBE_DEV_ID_82599_QSFP_SF_QP    0x1558
-#define IXGBE_DEV_ID_X540T1              0x1560
-
-#define IXGBE_DEV_ID_X550T		0x1563
-#define IXGBE_DEV_ID_X550EM_X_KX4	0x15AA
-#define IXGBE_DEV_ID_X550EM_X_KR	0x15AB
-#define IXGBE_DEV_ID_X550EM_X_SFP	0x15AC
-#define IXGBE_DEV_ID_X550EM_X_10G_T	0x15AD
-#define IXGBE_DEV_ID_X550EM_X_1G_T	0x15AE
-#define IXGBE_DEV_ID_X550_VF_HV	0x1564
-#define IXGBE_DEV_ID_X550_VF		0x1565
-#define IXGBE_DEV_ID_X550EM_X_VF	0x15A8
-#define IXGBE_DEV_ID_X550EM_X_VF_HV	0x15A9
-
-/* VF Device IDs */
-#define IXGBE_DEV_ID_82599_VF           0x10ED
-#define IXGBE_DEV_ID_X540_VF            0x1515
-#define IXGBE_DEV_ID_X550_VF		0x1565
-#define IXGBE_DEV_ID_X550EM_X_VF	0x15A8
-
-#define IXGBE_CAT(r, m)	IXGBE_##r##_##m
-
-#define IXGBE_BY_MAC(_hw, r)	((_hw)->mvals[IXGBE_CAT(r, IDX)])
+#define IXGBE_DEV_ID_82598			0x10B6
+#define IXGBE_DEV_ID_82598_BX			0x1508
+#define IXGBE_DEV_ID_82598AF_DUAL_PORT		0x10C6
+#define IXGBE_DEV_ID_82598AF_SINGLE_PORT	0x10C7
+#define IXGBE_DEV_ID_82598AT			0x10C8
+#define IXGBE_DEV_ID_82598AT2			0x150B
+#define IXGBE_DEV_ID_82598EB_SFP_LOM		0x10DB
+#define IXGBE_DEV_ID_82598EB_CX4		0x10DD
+#define IXGBE_DEV_ID_82598_CX4_DUAL_PORT	0x10EC
+#define IXGBE_DEV_ID_82598_DA_DUAL_PORT		0x10F1
+#define IXGBE_DEV_ID_82598_SR_DUAL_PORT_EM	0x10E1
+#define IXGBE_DEV_ID_82598EB_XF_LR		0x10F4
+#define IXGBE_DEV_ID_82599_KX4			0x10F7
+#define IXGBE_DEV_ID_82599_KX4_MEZZ		0x1514
+#define IXGBE_DEV_ID_82599_KR			0x1517
+#define IXGBE_DEV_ID_82599_COMBO_BACKPLANE	0x10F8
+#define IXGBE_SUBDEV_ID_82599_KX4_KR_MEZZ	0x000C
+#define IXGBE_DEV_ID_82599_CX4			0x10F9
+#define IXGBE_DEV_ID_82599_SFP			0x10FB
+#define IXGBE_SUBDEV_ID_82599_SFP		0x11A9
+#define IXGBE_SUBDEV_ID_82599_SFP_WOL0		0x1071
+#define IXGBE_SUBDEV_ID_82599_RNDC		0x1F72
+#define IXGBE_SUBDEV_ID_82599_560FLR		0x17D0
+#define IXGBE_SUBDEV_ID_82599_ECNA_DP		0x0470
+#define IXGBE_SUBDEV_ID_82599_SP_560FLR		0x211B
+#define IXGBE_SUBDEV_ID_82599_LOM_SNAP6		0x2159
+#define IXGBE_SUBDEV_ID_82599_SFP_1OCP		0x000D
+#define IXGBE_SUBDEV_ID_82599_SFP_2OCP		0x0008
+#define IXGBE_SUBDEV_ID_82599_SFP_LOM_OEM1	0x8976
+#define IXGBE_SUBDEV_ID_82599_SFP_LOM_OEM2	0x06EE
+#define IXGBE_DEV_ID_82599_BACKPLANE_FCOE	0x152A
+#define IXGBE_DEV_ID_82599_SFP_FCOE		0x1529
+#define IXGBE_DEV_ID_82599_SFP_EM		0x1507
+#define IXGBE_DEV_ID_82599_SFP_SF2		0x154D
+#define IXGBE_DEV_ID_82599_SFP_SF_QP		0x154A
+#define IXGBE_DEV_ID_82599_QSFP_SF_QP		0x1558
+#define IXGBE_DEV_ID_82599EN_SFP		0x1557
+#define IXGBE_SUBDEV_ID_82599EN_SFP_OCP1	0x0001
+#define IXGBE_DEV_ID_82599_XAUI_LOM		0x10FC
+#define IXGBE_DEV_ID_82599_T3_LOM		0x151C
+#define IXGBE_DEV_ID_82599_LS			0x154F
+#define IXGBE_DEV_ID_X540T			0x1528
+#define IXGBE_DEV_ID_X540T1			0x1560
+#define IXGBE_DEV_ID_X550T			0x1563
+#define IXGBE_DEV_ID_X550T1			0x15D1
+/* Placeholder value, pending official value. */
+#define IXGBE_DEV_ID_X550EM_A_KR		0x15C2
+#define IXGBE_DEV_ID_X550EM_A_KR_L		0x15C3
+#define IXGBE_DEV_ID_X550EM_A_SFP_N		0x15C4
+#define IXGBE_DEV_ID_X550EM_A_SGMII		0x15C6
+#define IXGBE_DEV_ID_X550EM_A_SGMII_L		0x15C7
+#define IXGBE_DEV_ID_X550EM_A_10G_T		0x15C8
+#define IXGBE_DEV_ID_X550EM_A_QSFP		0x15CA
+#define IXGBE_DEV_ID_X550EM_A_QSFP_N		0x15CC
+#define IXGBE_DEV_ID_X550EM_A_SFP		0x15CE
+#define IXGBE_DEV_ID_X550EM_A_1G_T		0x15E4
+#define IXGBE_DEV_ID_X550EM_A_1G_T_L		0x15E5
+#define IXGBE_DEV_ID_X550EM_X_KX4		0x15AA
+#define IXGBE_DEV_ID_X550EM_X_KR		0x15AB
+#define IXGBE_DEV_ID_X550EM_X_SFP		0x15AC
+#define IXGBE_DEV_ID_X550EM_X_10G_T		0x15AD
+#define IXGBE_DEV_ID_X550EM_X_1G_T		0x15AE
+#define IXGBE_DEV_ID_X550EM_X_XFI		0x15B0
+
+#define IXGBE_CAT(r,m) IXGBE_##r##m
+
+#define IXGBE_BY_MAC(_hw, r) ((_hw)->mvals[IXGBE_CAT(r, _IDX)])
 
 /* General Registers */
-#define IXGBE_CTRL      0x00000
-#define IXGBE_STATUS    0x00008
-#define IXGBE_CTRL_EXT  0x00018
-#define IXGBE_ESDP      0x00020
-#define IXGBE_EODSDP    0x00028
-
-#define IXGBE_I2CCTL_8259X	0x00028
-#define IXGBE_I2CCTL_X540	IXGBE_I2CCTL_8259X
+#define IXGBE_CTRL		0x00000
+#define IXGBE_STATUS		0x00008
+#define IXGBE_CTRL_EXT		0x00018
+#define IXGBE_ESDP		0x00020
+#define IXGBE_EODSDP		0x00028
+#define IXGBE_I2CCTL_82599	0x00028
+#define IXGBE_I2CCTL		IXGBE_I2CCTL_82599
+#define IXGBE_I2CCTL_X540	IXGBE_I2CCTL_82599
 #define IXGBE_I2CCTL_X550	0x15F5C
 #define IXGBE_I2CCTL_X550EM_x	IXGBE_I2CCTL_X550
 #define IXGBE_I2CCTL_X550EM_a	IXGBE_I2CCTL_X550
-#define IXGBE_I2CCTL(_hw)	IXGBE_BY_MAC((_hw), I2CCTL)
-
-#define IXGBE_LEDCTL    0x00200
-#define IXGBE_FRTIMER   0x00048
-#define IXGBE_TCPTIMER  0x0004C
-#define IXGBE_CORESPARE 0x00600
-#define IXGBE_EXVET     0x05078
+#define IXGBE_I2CCTL_BY_MAC(_hw) IXGBE_BY_MAC((_hw), I2CCTL)
+#define IXGBE_PHY_GPIO		0x00028
+#define IXGBE_MAC_GPIO		0x00030
+#define IXGBE_PHYINT_STATUS0	0x00100
+#define IXGBE_PHYINT_STATUS1	0x00104
+#define IXGBE_PHYINT_STATUS2	0x00108
+#define IXGBE_LEDCTL		0x00200
+#define IXGBE_FRTIMER		0x00048
+#define IXGBE_TCPTIMER		0x0004C
+#define IXGBE_CORESPARE		0x00600
+#define IXGBE_EXVET		0x05078
 
 /* NVM Registers */
-#define IXGBE_EEC_8259X		0x10010
-#define IXGBE_EEC_X540		IXGBE_EEC_8259X
-#define IXGBE_EEC_X550		IXGBE_EEC_8259X
-#define IXGBE_EEC_X550EM_x	IXGBE_EEC_8259X
+#define IXGBE_EEC		0x10010
+#define IXGBE_EEC_X540		IXGBE_EEC
+#define IXGBE_EEC_X550		IXGBE_EEC
+#define IXGBE_EEC_X550EM_x	IXGBE_EEC
 #define IXGBE_EEC_X550EM_a	0x15FF8
-#define IXGBE_EEC(_hw)		IXGBE_BY_MAC((_hw), EEC)
-#define IXGBE_EERD      0x10014
-#define IXGBE_EEWR      0x10018
-#define IXGBE_FLA_8259X		0x1001C
-#define IXGBE_FLA_X540		IXGBE_FLA_8259X
-#define IXGBE_FLA_X550		IXGBE_FLA_8259X
-#define IXGBE_FLA_X550EM_x	IXGBE_FLA_8259X
-#define IXGBE_FLA_X550EM_a	0x15F6C
-#define IXGBE_FLA(_hw)		IXGBE_BY_MAC((_hw), FLA)
-#define IXGBE_EEMNGCTL  0x10110
-#define IXGBE_EEMNGDATA 0x10114
-#define IXGBE_FLMNGCTL  0x10118
-#define IXGBE_FLMNGDATA 0x1011C
-#define IXGBE_FLMNGCNT  0x10120
-#define IXGBE_FLOP      0x1013C
-#define IXGBE_GRC_8259X		0x10200
-#define IXGBE_GRC_X540		IXGBE_GRC_8259X
-#define IXGBE_GRC_X550		IXGBE_GRC_8259X
-#define IXGBE_GRC_X550EM_x	IXGBE_GRC_8259X
+#define IXGBE_EEC_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), EEC)
+
+#define IXGBE_EERD		0x10014
+#define IXGBE_EEWR		0x10018
+
+#define IXGBE_FLA		0x1001C
+#define IXGBE_FLA_X540		IXGBE_FLA
+#define IXGBE_FLA_X550		IXGBE_FLA
+#define IXGBE_FLA_X550EM_x	IXGBE_FLA
+#define IXGBE_FLA_X550EM_a	0x15F68
+#define IXGBE_FLA_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), FLA)
+
+#define IXGBE_EEMNGCTL	0x10110
+#define IXGBE_EEMNGDATA	0x10114
+#define IXGBE_FLMNGCTL	0x10118
+#define IXGBE_FLMNGDATA	0x1011C
+#define IXGBE_FLMNGCNT	0x10120
+#define IXGBE_FLOP	0x1013C
+
+#define IXGBE_GRC		0x10200
+#define IXGBE_GRC_X540		IXGBE_GRC
+#define IXGBE_GRC_X550		IXGBE_GRC
+#define IXGBE_GRC_X550EM_x	IXGBE_GRC
 #define IXGBE_GRC_X550EM_a	0x15F64
-#define IXGBE_GRC(_hw)		IXGBE_BY_MAC((_hw), GRC)
+#define IXGBE_GRC_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), GRC)
 
-#define IXGBE_SRAMREL_8259X	0x10210
-#define IXGBE_SRAMREL_X540	IXGBE_SRAMREL_8259X
-#define IXGBE_SRAMREL_X550	IXGBE_SRAMREL_8259X
-#define IXGBE_SRAMREL_X550EM_x	IXGBE_SRAMREL_8259X
+#define IXGBE_SRAMREL		0x10210
+#define IXGBE_SRAMREL_X540	IXGBE_SRAMREL
+#define IXGBE_SRAMREL_X550	IXGBE_SRAMREL
+#define IXGBE_SRAMREL_X550EM_x	IXGBE_SRAMREL
 #define IXGBE_SRAMREL_X550EM_a	0x15F6C
-#define IXGBE_SRAMREL(_hw)	IXGBE_BY_MAC((_hw), SRAMREL)
+#define IXGBE_SRAMREL_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), SRAMREL)
+
+#define IXGBE_PHYDBG	0x10218
 
 /* General Receive Control */
-#define IXGBE_GRC_MNG  0x00000001 /* Manageability Enable */
-#define IXGBE_GRC_APME 0x00000002 /* APM enabled in EEPROM */
+#define IXGBE_GRC_MNG	0x00000001 /* Manageability Enable */
+#define IXGBE_GRC_APME	0x00000002 /* APM enabled in EEPROM */
 
-#define IXGBE_VPDDIAG0  0x10204
-#define IXGBE_VPDDIAG1  0x10208
+#define IXGBE_VPDDIAG0	0x10204
+#define IXGBE_VPDDIAG1	0x10208
 
 /* I2CCTL Bit Masks */
-#define IXGBE_I2C_CLK_IN_8259X		0x00000001
-#define IXGBE_I2C_CLK_IN_X540		IXGBE_I2C_CLK_IN_8259X
+#define IXGBE_I2C_CLK_IN		0x00000001
+#define IXGBE_I2C_CLK_IN_X540		IXGBE_I2C_CLK_IN
 #define IXGBE_I2C_CLK_IN_X550		0x00004000
 #define IXGBE_I2C_CLK_IN_X550EM_x	IXGBE_I2C_CLK_IN_X550
 #define IXGBE_I2C_CLK_IN_X550EM_a	IXGBE_I2C_CLK_IN_X550
-#define IXGBE_I2C_CLK_IN(_hw)		IXGBE_BY_MAC((_hw), I2C_CLK_IN)
+#define IXGBE_I2C_CLK_IN_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), I2C_CLK_IN)
 
-#define IXGBE_I2C_CLK_OUT_8259X		0x00000002
-#define IXGBE_I2C_CLK_OUT_X540		IXGBE_I2C_CLK_OUT_8259X
+#define IXGBE_I2C_CLK_OUT		0x00000002
+#define IXGBE_I2C_CLK_OUT_X540		IXGBE_I2C_CLK_OUT
 #define IXGBE_I2C_CLK_OUT_X550		0x00000200
 #define IXGBE_I2C_CLK_OUT_X550EM_x	IXGBE_I2C_CLK_OUT_X550
 #define IXGBE_I2C_CLK_OUT_X550EM_a	IXGBE_I2C_CLK_OUT_X550
-#define IXGBE_I2C_CLK_OUT(_hw)		IXGBE_BY_MAC((_hw), I2C_CLK_OUT)
+#define IXGBE_I2C_CLK_OUT_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), I2C_CLK_OUT)
 
-#define IXGBE_I2C_DATA_IN_8259X		0x00000004
-#define IXGBE_I2C_DATA_IN_X540		IXGBE_I2C_DATA_IN_8259X
+#define IXGBE_I2C_DATA_IN		0x00000004
+#define IXGBE_I2C_DATA_IN_X540		IXGBE_I2C_DATA_IN
 #define IXGBE_I2C_DATA_IN_X550		0x00001000
 #define IXGBE_I2C_DATA_IN_X550EM_x	IXGBE_I2C_DATA_IN_X550
 #define IXGBE_I2C_DATA_IN_X550EM_a	IXGBE_I2C_DATA_IN_X550
-#define IXGBE_I2C_DATA_IN(_hw)		IXGBE_BY_MAC((_hw), I2C_DATA_IN)
+#define IXGBE_I2C_DATA_IN_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), I2C_DATA_IN)
 
-#define IXGBE_I2C_DATA_OUT_8259X	0x00000008
-#define IXGBE_I2C_DATA_OUT_X540		IXGBE_I2C_DATA_OUT_8259X
+#define IXGBE_I2C_DATA_OUT		0x00000008
+#define IXGBE_I2C_DATA_OUT_X540		IXGBE_I2C_DATA_OUT
 #define IXGBE_I2C_DATA_OUT_X550		0x00000400
 #define IXGBE_I2C_DATA_OUT_X550EM_x	IXGBE_I2C_DATA_OUT_X550
 #define IXGBE_I2C_DATA_OUT_X550EM_a	IXGBE_I2C_DATA_OUT_X550
-#define IXGBE_I2C_DATA_OUT(_hw)		IXGBE_BY_MAC((_hw), I2C_DATA_OUT)
+#define IXGBE_I2C_DATA_OUT_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), I2C_DATA_OUT)
 
-#define IXGBE_I2C_DATA_OE_N_EN_8259X	0
-#define IXGBE_I2C_DATA_OE_N_EN_X540	IXGBE_I2C_DATA_OE_N_EN_8259X
+#define IXGBE_I2C_DATA_OE_N_EN		0
+#define IXGBE_I2C_DATA_OE_N_EN_X540	IXGBE_I2C_DATA_OE_N_EN
 #define IXGBE_I2C_DATA_OE_N_EN_X550	0x00000800
 #define IXGBE_I2C_DATA_OE_N_EN_X550EM_x	IXGBE_I2C_DATA_OE_N_EN_X550
 #define IXGBE_I2C_DATA_OE_N_EN_X550EM_a	IXGBE_I2C_DATA_OE_N_EN_X550
-#define IXGBE_I2C_DATA_OE_N_EN(_hw)	IXGBE_BY_MAC((_hw), I2C_DATA_OE_N_EN)
+#define IXGBE_I2C_DATA_OE_N_EN_BY_MAC(_hw) IXGBE_BY_MAC((_hw), I2C_DATA_OE_N_EN)
 
-#define IXGBE_I2C_BB_EN_8259X		0
-#define IXGBE_I2C_BB_EN_X540		IXGBE_I2C_BB_EN_8259X
+#define IXGBE_I2C_BB_EN			0
+#define IXGBE_I2C_BB_EN_X540		IXGBE_I2C_BB_EN
 #define IXGBE_I2C_BB_EN_X550		0x00000100
 #define IXGBE_I2C_BB_EN_X550EM_x	IXGBE_I2C_BB_EN_X550
 #define IXGBE_I2C_BB_EN_X550EM_a	IXGBE_I2C_BB_EN_X550
-#define IXGBE_I2C_BB_EN(_hw)		IXGBE_BY_MAC((_hw), I2C_BB_EN)
 
-#define IXGBE_I2C_CLK_OE_N_EN_8259X	0
-#define IXGBE_I2C_CLK_OE_N_EN_X540	IXGBE_I2C_CLK_OE_N_EN_8259X
+#define IXGBE_I2C_BB_EN_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), I2C_BB_EN)
+
+#define IXGBE_I2C_CLK_OE_N_EN		0
+#define IXGBE_I2C_CLK_OE_N_EN_X540	IXGBE_I2C_CLK_OE_N_EN
 #define IXGBE_I2C_CLK_OE_N_EN_X550	0x00002000
 #define IXGBE_I2C_CLK_OE_N_EN_X550EM_x	IXGBE_I2C_CLK_OE_N_EN_X550
 #define IXGBE_I2C_CLK_OE_N_EN_X550EM_a	IXGBE_I2C_CLK_OE_N_EN_X550
-#define IXGBE_I2C_CLK_OE_N_EN(_hw)	 IXGBE_BY_MAC((_hw), I2C_CLK_OE_N_EN)
-
+#define IXGBE_I2C_CLK_OE_N_EN_BY_MAC(_hw) IXGBE_BY_MAC((_hw), I2C_CLK_OE_N_EN)
 #define IXGBE_I2C_CLOCK_STRETCHING_TIMEOUT	500
 
 #define IXGBE_I2C_THERMAL_SENSOR_ADDR	0xF8
@@ -230,161 +287,211 @@ struct ixgbe_thermal_sensor_data {
 	struct ixgbe_thermal_diode_data sensor[IXGBE_MAX_SENSORS];
 };
 
+#define NVM_OROM_OFFSET		0x17
+#define NVM_OROM_BLK_LOW	0x83
+#define NVM_OROM_BLK_HI		0x84
+#define NVM_OROM_PATCH_MASK	0xFF
+#define NVM_OROM_SHIFT		8
+
+#define NVM_VER_MASK		0x00FF /* version mask */
+#define NVM_VER_SHIFT		8     /* version bit shift */
+#define NVM_OEM_PROD_VER_PTR	0x1B  /* OEM Product version block pointer */
+#define NVM_OEM_PROD_VER_CAP_OFF 0x1  /* OEM Product version format offset */
+#define NVM_OEM_PROD_VER_OFF_L	0x2   /* OEM Product version offset low */
+#define NVM_OEM_PROD_VER_OFF_H	0x3   /* OEM Product version offset high */
+#define NVM_OEM_PROD_VER_CAP_MASK 0xF /* OEM Product version cap mask */
+#define NVM_OEM_PROD_VER_MOD_LEN 0x3  /* OEM Product version module length */
+#define NVM_ETK_OFF_LOW		0x2D  /* version low order word */
+#define NVM_ETK_OFF_HI		0x2E  /* version high order word */
+#define NVM_ETK_SHIFT		16    /* high version word shift */
+#define NVM_VER_INVALID		0xFFFF
+#define NVM_ETK_VALID		0x8000
+#define NVM_INVALID_PTR		0xFFFF
+#define NVM_VER_SIZE		32    /* version sting size */
+
+struct ixgbe_nvm_version {
+	u32 etk_id;
+	u8  nvm_major;
+	u16 nvm_minor;
+	u8  nvm_id;
+
+	bool oem_valid;
+	u8   oem_major;
+	u8   oem_minor;
+	u16  oem_release;
+
+	bool or_valid;
+	u8  or_major;
+	u16 or_build;
+	u8  or_patch;
+
+};
+
 /* Interrupt Registers */
-#define IXGBE_EICR      0x00800
-#define IXGBE_EICS      0x00808
-#define IXGBE_EIMS      0x00880
-#define IXGBE_EIMC      0x00888
-#define IXGBE_EIAC      0x00810
-#define IXGBE_EIAM      0x00890
-#define IXGBE_EICS_EX(_i)   (0x00A90 + (_i) * 4)
-#define IXGBE_EIMS_EX(_i)   (0x00AA0 + (_i) * 4)
-#define IXGBE_EIMC_EX(_i)   (0x00AB0 + (_i) * 4)
-#define IXGBE_EIAM_EX(_i)   (0x00AD0 + (_i) * 4)
+#define IXGBE_EICR		0x00800
+#define IXGBE_EICS		0x00808
+#define IXGBE_EIMS		0x00880
+#define IXGBE_EIMC		0x00888
+#define IXGBE_EIAC		0x00810
+#define IXGBE_EIAM		0x00890
+#define IXGBE_EICS_EX(_i)	(0x00A90 + (_i) * 4)
+#define IXGBE_EIMS_EX(_i)	(0x00AA0 + (_i) * 4)
+#define IXGBE_EIMC_EX(_i)	(0x00AB0 + (_i) * 4)
+#define IXGBE_EIAM_EX(_i)	(0x00AD0 + (_i) * 4)
+/* 82599 EITR is only 12 bits, with the lower 3 always zero */
 /*
  * 82598 EITR is 16 bits but set the limits based on the max
- * supported by all ixgbe hardware.  82599 EITR is only 12 bits,
- * with the lower 3 always zero.
+ * supported by all ixgbe hardware
  */
-#define IXGBE_MAX_INT_RATE 488281
-#define IXGBE_MIN_INT_RATE 956
-#define IXGBE_MAX_EITR     0x00000FF8
-#define IXGBE_MIN_EITR     8
-#define IXGBE_EITR(_i)  (((_i) <= 23) ? (0x00820 + ((_i) * 4)) : \
-			 (0x012300 + (((_i) - 24) * 4)))
-#define IXGBE_EITR_ITR_INT_MASK 0x00000FF8
-#define IXGBE_EITR_LLI_MOD      0x00008000
-#define IXGBE_EITR_CNT_WDIS     0x80000000
-#define IXGBE_IVAR(_i)  (0x00900 + ((_i) * 4)) /* 24 at 0x900-0x960 */
-#define IXGBE_IVAR_MISC 0x00A00 /* misc MSI-X interrupt causes */
-#define IXGBE_EITRSEL   0x00894
-#define IXGBE_MSIXT     0x00000 /* MSI-X Table. 0x0000 - 0x01C */
-#define IXGBE_MSIXPBA   0x02000 /* MSI-X Pending bit array */
-#define IXGBE_PBACL(_i) (((_i) == 0) ? (0x11068) : (0x110C0 + ((_i) * 4)))
-#define IXGBE_GPIE      0x00898
+#define IXGBE_MAX_INT_RATE	488281
+#define IXGBE_MIN_INT_RATE	956
+#define IXGBE_MAX_EITR		0x00000FF8
+#define IXGBE_MIN_EITR		8
+#define IXGBE_EITR(_i)		(((_i) <= 23) ? (0x00820 + ((_i) * 4)) : \
+				 (0x012300 + (((_i) - 24) * 4)))
+#define IXGBE_EITR_ITR_INT_MASK	0x00000FF8
+#define IXGBE_EITR_LLI_MOD	0x00008000
+#define IXGBE_EITR_CNT_WDIS	0x80000000
+#define IXGBE_IVAR(_i)		(0x00900 + ((_i) * 4)) /* 24 at 0x900-0x960 */
+#define IXGBE_IVAR_MISC		0x00A00 /* misc MSI-X interrupt causes */
+#define IXGBE_EITRSEL		0x00894
+#define IXGBE_MSIXT		0x00000 /* MSI-X Table. 0x0000 - 0x01C */
+#define IXGBE_MSIXPBA		0x02000 /* MSI-X Pending bit array */
+#define IXGBE_PBACL(_i)	(((_i) == 0) ? (0x11068) : (0x110C0 + ((_i) * 4)))
+#define IXGBE_GPIE		0x00898
 
 /* Flow Control Registers */
-#define IXGBE_FCADBUL   0x03210
-#define IXGBE_FCADBUH   0x03214
-#define IXGBE_FCAMACL   0x04328
-#define IXGBE_FCAMACH   0x0432C
-#define IXGBE_FCRTH_82599(_i) (0x03260 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_FCRTL_82599(_i) (0x03220 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_PFCTOP    0x03008
-#define IXGBE_FCTTV(_i) (0x03200 + ((_i) * 4)) /* 4 of these (0-3) */
-#define IXGBE_FCRTL(_i) (0x03220 + ((_i) * 8)) /* 8 of these (0-7) */
-#define IXGBE_FCRTH(_i) (0x03260 + ((_i) * 8)) /* 8 of these (0-7) */
-#define IXGBE_FCRTV     0x032A0
-#define IXGBE_FCCFG     0x03D00
-#define IXGBE_TFCS      0x0CE00
+#define IXGBE_FCADBUL		0x03210
+#define IXGBE_FCADBUH		0x03214
+#define IXGBE_FCAMACL		0x04328
+#define IXGBE_FCAMACH		0x0432C
+#define IXGBE_FCRTH_82599(_i)	(0x03260 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_FCRTL_82599(_i)	(0x03220 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_PFCTOP		0x03008
+#define IXGBE_FCTTV(_i)		(0x03200 + ((_i) * 4)) /* 4 of these (0-3) */
+#define IXGBE_FCRTL(_i)		(0x03220 + ((_i) * 8)) /* 8 of these (0-7) */
+#define IXGBE_FCRTH(_i)		(0x03260 + ((_i) * 8)) /* 8 of these (0-7) */
+#define IXGBE_FCRTV		0x032A0
+#define IXGBE_FCCFG		0x03D00
+#define IXGBE_TFCS		0x0CE00
 
 /* Receive DMA Registers */
-#define IXGBE_RDBAL(_i) (((_i) < 64) ? (0x01000 + ((_i) * 0x40)) : \
+#define IXGBE_RDBAL(_i)	(((_i) < 64) ? (0x01000 + ((_i) * 0x40)) : \
 			 (0x0D000 + (((_i) - 64) * 0x40)))
-#define IXGBE_RDBAH(_i) (((_i) < 64) ? (0x01004 + ((_i) * 0x40)) : \
+#define IXGBE_RDBAH(_i)	(((_i) < 64) ? (0x01004 + ((_i) * 0x40)) : \
 			 (0x0D004 + (((_i) - 64) * 0x40)))
-#define IXGBE_RDLEN(_i) (((_i) < 64) ? (0x01008 + ((_i) * 0x40)) : \
+#define IXGBE_RDLEN(_i)	(((_i) < 64) ? (0x01008 + ((_i) * 0x40)) : \
 			 (0x0D008 + (((_i) - 64) * 0x40)))
-#define IXGBE_RDH(_i)   (((_i) < 64) ? (0x01010 + ((_i) * 0x40)) : \
+#define IXGBE_RDH(_i)	(((_i) < 64) ? (0x01010 + ((_i) * 0x40)) : \
 			 (0x0D010 + (((_i) - 64) * 0x40)))
-#define IXGBE_RDT(_i)   (((_i) < 64) ? (0x01018 + ((_i) * 0x40)) : \
+#define IXGBE_RDT(_i)	(((_i) < 64) ? (0x01018 + ((_i) * 0x40)) : \
 			 (0x0D018 + (((_i) - 64) * 0x40)))
-#define IXGBE_RXDCTL(_i) (((_i) < 64) ? (0x01028 + ((_i) * 0x40)) : \
-			 (0x0D028 + (((_i) - 64) * 0x40)))
-#define IXGBE_RSCCTL(_i) (((_i) < 64) ? (0x0102C + ((_i) * 0x40)) : \
-			 (0x0D02C + (((_i) - 64) * 0x40)))
-#define IXGBE_RSCDBU     0x03028
-#define IXGBE_RDDCC      0x02F20
-#define IXGBE_RXMEMWRAP  0x03190
-#define IXGBE_STARCTRL   0x03024
+#define IXGBE_RXDCTL(_i)	(((_i) < 64) ? (0x01028 + ((_i) * 0x40)) : \
+				 (0x0D028 + (((_i) - 64) * 0x40)))
+#define IXGBE_RSCCTL(_i)	(((_i) < 64) ? (0x0102C + ((_i) * 0x40)) : \
+				 (0x0D02C + (((_i) - 64) * 0x40)))
+#define IXGBE_RSCDBU	0x03028
+#define IXGBE_RDDCC	0x02F20
+#define IXGBE_RXMEMWRAP	0x03190
+#define IXGBE_STARCTRL	0x03024
 /*
  * Split and Replication Receive Control Registers
  * 00-15 : 0x02100 + n*4
  * 16-64 : 0x01014 + n*0x40
  * 64-127: 0x0D014 + (n-64)*0x40
  */
-#define IXGBE_SRRCTL(_i) (((_i) <= 15) ? (0x02100 + ((_i) * 4)) : \
-			  (((_i) < 64) ? (0x01014 + ((_i) * 0x40)) : \
-			  (0x0D014 + (((_i) - 64) * 0x40))))
+#define IXGBE_SRRCTL(_i)	(((_i) <= 15) ? (0x02100 + ((_i) * 4)) : \
+				 (((_i) < 64) ? (0x01014 + ((_i) * 0x40)) : \
+				 (0x0D014 + (((_i) - 64) * 0x40))))
 /*
  * Rx DCA Control Register:
  * 00-15 : 0x02200 + n*4
  * 16-64 : 0x0100C + n*0x40
  * 64-127: 0x0D00C + (n-64)*0x40
  */
-#define IXGBE_DCA_RXCTRL(_i)    (((_i) <= 15) ? (0x02200 + ((_i) * 4)) : \
+#define IXGBE_DCA_RXCTRL(_i)	(((_i) <= 15) ? (0x02200 + ((_i) * 4)) : \
 				 (((_i) < 64) ? (0x0100C + ((_i) * 0x40)) : \
 				 (0x0D00C + (((_i) - 64) * 0x40))))
-#define IXGBE_RDRXCTL           0x02F00
-#define IXGBE_RXPBSIZE(_i)      (0x03C00 + ((_i) * 4))
-					     /* 8 of these 0x03C00 - 0x03C1C */
-#define IXGBE_RXCTRL    0x03000
-#define IXGBE_DROPEN    0x03D04
-#define IXGBE_RXPBSIZE_SHIFT 10
+#define IXGBE_RDRXCTL		0x02F00
+/* 8 of these 0x03C00 - 0x03C1C */
+#define IXGBE_RXPBSIZE(_i)	(0x03C00 + ((_i) * 4))
+#define IXGBE_RXCTRL		0x03000
+#define IXGBE_DROPEN		0x03D04
+#define IXGBE_RXPBSIZE_SHIFT	10
+#define IXGBE_RXPBSIZE_MASK	0x000FFC00
 
 /* Receive Registers */
-#define IXGBE_RXCSUM    0x05000
-#define IXGBE_RFCTL     0x05008
-#define IXGBE_DRECCCTL  0x02F08
-#define IXGBE_DRECCCTL_DISABLE 0
+#define IXGBE_RXCSUM		0x05000
+#define IXGBE_RFCTL		0x05008
+#define IXGBE_DRECCCTL		0x02F08
+#define IXGBE_DRECCCTL_DISABLE	0
+#define IXGBE_DRECCCTL2		0x02F8C
+
 /* Multicast Table Array - 128 entries */
-#define IXGBE_MTA(_i)   (0x05200 + ((_i) * 4))
-#define IXGBE_RAL(_i)   (((_i) <= 15) ? (0x05400 + ((_i) * 8)) : \
-			 (0x0A200 + ((_i) * 8)))
-#define IXGBE_RAH(_i)   (((_i) <= 15) ? (0x05404 + ((_i) * 8)) : \
-			 (0x0A204 + ((_i) * 8)))
-#define IXGBE_MPSAR_LO(_i) (0x0A600 + ((_i) * 8))
-#define IXGBE_MPSAR_HI(_i) (0x0A604 + ((_i) * 8))
+#define IXGBE_MTA(_i)		(0x05200 + ((_i) * 4))
+#define IXGBE_RAL(_i)		(((_i) <= 15) ? (0x05400 + ((_i) * 8)) : \
+				 (0x0A200 + ((_i) * 8)))
+#define IXGBE_RAH(_i)		(((_i) <= 15) ? (0x05404 + ((_i) * 8)) : \
+				 (0x0A204 + ((_i) * 8)))
+#define IXGBE_MPSAR_LO(_i)	(0x0A600 + ((_i) * 8))
+#define IXGBE_MPSAR_HI(_i)	(0x0A604 + ((_i) * 8))
 /* Packet split receive type */
-#define IXGBE_PSRTYPE(_i)    (((_i) <= 15) ? (0x05480 + ((_i) * 4)) : \
-			      (0x0EA00 + ((_i) * 4)))
+#define IXGBE_PSRTYPE(_i)	(((_i) <= 15) ? (0x05480 + ((_i) * 4)) : \
+				 (0x0EA00 + ((_i) * 4)))
 /* array of 4096 1-bit vlan filters */
-#define IXGBE_VFTA(_i)  (0x0A000 + ((_i) * 4))
+#define IXGBE_VFTA(_i)		(0x0A000 + ((_i) * 4))
 /*array of 4096 4-bit vlan vmdq indices */
-#define IXGBE_VFTAVIND(_j, _i)  (0x0A200 + ((_j) * 0x200) + ((_i) * 4))
-#define IXGBE_FCTRL     0x05080
-#define IXGBE_VLNCTRL   0x05088
-#define IXGBE_MCSTCTRL  0x05090
-#define IXGBE_MRQC      0x05818
-#define IXGBE_SAQF(_i)  (0x0E000 + ((_i) * 4)) /* Source Address Queue Filter */
-#define IXGBE_DAQF(_i)  (0x0E200 + ((_i) * 4)) /* Dest. Address Queue Filter */
-#define IXGBE_SDPQF(_i) (0x0E400 + ((_i) * 4)) /* Src Dest. Addr Queue Filter */
-#define IXGBE_FTQF(_i)  (0x0E600 + ((_i) * 4)) /* Five Tuple Queue Filter */
-#define IXGBE_ETQF(_i)  (0x05128 + ((_i) * 4)) /* EType Queue Filter */
-#define IXGBE_ETQS(_i)  (0x0EC00 + ((_i) * 4)) /* EType Queue Select */
-#define IXGBE_SYNQF     0x0EC30 /* SYN Packet Queue Filter */
-#define IXGBE_RQTC      0x0EC70
-#define IXGBE_MTQC      0x08120
-#define IXGBE_VLVF(_i)  (0x0F100 + ((_i) * 4))  /* 64 of these (0-63) */
-#define IXGBE_VLVFB(_i) (0x0F200 + ((_i) * 4))  /* 128 of these (0-127) */
-#define IXGBE_VMVIR(_i) (0x08000 + ((_i) * 4))  /* 64 of these (0-63) */
-#define IXGBE_PFFLPL	0x050B0
-#define IXGBE_PFFLPH	0x050B4
-#define IXGBE_VT_CTL         0x051B0
-#define IXGBE_PFMAILBOX(_i)  (0x04B00 + (4 * (_i))) /* 64 total */
-#define IXGBE_PFMBMEM(_i)    (0x13000 + (64 * (_i))) /* 64 Mailboxes, 16 DW each */
-#define IXGBE_PFMBICR(_i)    (0x00710 + (4 * (_i))) /* 4 total */
-#define IXGBE_PFMBIMR(_i)    (0x00720 + (4 * (_i))) /* 4 total */
-#define IXGBE_VFRE(_i)       (0x051E0 + ((_i) * 4))
-#define IXGBE_VFTE(_i)       (0x08110 + ((_i) * 4))
-#define IXGBE_VMECM(_i)      (0x08790 + ((_i) * 4))
-#define IXGBE_QDE            0x2F04
-#define IXGBE_VMTXSW(_i)     (0x05180 + ((_i) * 4)) /* 2 total */
-#define IXGBE_VMOLR(_i)      (0x0F000 + ((_i) * 4)) /* 64 total */
-#define IXGBE_UTA(_i)        (0x0F400 + ((_i) * 4))
-#define IXGBE_MRCTL(_i)      (0x0F600 + ((_i) * 4))
-#define IXGBE_VMRVLAN(_i)    (0x0F610 + ((_i) * 4))
-#define IXGBE_VMRVM(_i)      (0x0F630 + ((_i) * 4))
-#define IXGBE_L34T_IMIR(_i)  (0x0E800 + ((_i) * 4)) /*128 of these (0-127)*/
-#define IXGBE_RXFECCERR0         0x051B8
-#define IXGBE_LLITHRESH 0x0EC90
-#define IXGBE_IMIR(_i)  (0x05A80 + ((_i) * 4))  /* 8 of these (0-7) */
-#define IXGBE_IMIREXT(_i)       (0x05AA0 + ((_i) * 4))  /* 8 of these (0-7) */
-#define IXGBE_IMIRVP    0x05AC0
-#define IXGBE_VMD_CTL   0x0581C
-#define IXGBE_RETA(_i)  (0x05C00 + ((_i) * 4))  /* 32 of these (0-31) */
-#define IXGBE_ERETA(_i)	(0x0EE80 + ((_i) * 4))  /* 96 of these (0-95) */
-#define IXGBE_RSSRK(_i) (0x05C80 + ((_i) * 4))  /* 10 of these (0-9) */
+#define IXGBE_VFTAVIND(_j, _i)	(0x0A200 + ((_j) * 0x200) + ((_i) * 4))
+#define IXGBE_FCTRL		0x05080
+#define IXGBE_VLNCTRL		0x05088
+#define IXGBE_MCSTCTRL		0x05090
+#define IXGBE_MRQC		0x05818
+#define IXGBE_SAQF(_i)	(0x0E000 + ((_i) * 4)) /* Source Address Queue Filter */
+#define IXGBE_DAQF(_i)	(0x0E200 + ((_i) * 4)) /* Dest. Address Queue Filter */
+#define IXGBE_SDPQF(_i)	(0x0E400 + ((_i) * 4)) /* Src Dest. Addr Queue Filter */
+#define IXGBE_FTQF(_i)	(0x0E600 + ((_i) * 4)) /* Five Tuple Queue Filter */
+#define IXGBE_ETQF(_i)	(0x05128 + ((_i) * 4)) /* EType Queue Filter */
+#define IXGBE_ETQS(_i)	(0x0EC00 + ((_i) * 4)) /* EType Queue Select */
+#define IXGBE_SYNQF	0x0EC30 /* SYN Packet Queue Filter */
+#define IXGBE_RQTC	0x0EC70
+#define IXGBE_MTQC	0x08120
+#define IXGBE_VLVF(_i)	(0x0F100 + ((_i) * 4))  /* 64 of these (0-63) */
+#define IXGBE_VLVFB(_i)	(0x0F200 + ((_i) * 4))  /* 128 of these (0-127) */
+#define IXGBE_VMVIR(_i)	(0x08000 + ((_i) * 4))  /* 64 of these (0-63) */
+#define IXGBE_PFFLPL		0x050B0
+#define IXGBE_PFFLPH		0x050B4
+#define IXGBE_VT_CTL		0x051B0
+#define IXGBE_PFMAILBOX(_i)	(0x04B00 + (4 * (_i))) /* 64 total */
+/* 64 Mailboxes, 16 DW each */
+#define IXGBE_PFMBMEM(_i)	(0x13000 + (64 * (_i)))
+#define IXGBE_PFMBICR(_i)	(0x00710 + (4 * (_i))) /* 4 total */
+#define IXGBE_PFMBIMR(_i)	(0x00720 + (4 * (_i))) /* 4 total */
+#define IXGBE_VFRE(_i)		(0x051E0 + ((_i) * 4))
+#define IXGBE_VFTE(_i)		(0x08110 + ((_i) * 4))
+#define IXGBE_VMECM(_i)		(0x08790 + ((_i) * 4))
+#define IXGBE_QDE		0x2F04
+#define IXGBE_VMTXSW(_i)	(0x05180 + ((_i) * 4)) /* 2 total */
+#define IXGBE_VMOLR(_i)		(0x0F000 + ((_i) * 4)) /* 64 total */
+#define IXGBE_UTA(_i)		(0x0F400 + ((_i) * 4))
+#define IXGBE_MRCTL(_i)		(0x0F600 + ((_i) * 4))
+#define IXGBE_VMRVLAN(_i)	(0x0F610 + ((_i) * 4))
+#define IXGBE_VMRVM(_i)		(0x0F630 + ((_i) * 4))
+#define IXGBE_LVMMC_RX		0x2FA8
+#define IXGBE_LVMMC_TX		0x8108
+#define IXGBE_LMVM_RX		0x2FA4
+#define IXGBE_LMVM_TX		0x8124
+#define IXGBE_WQBR_RX(_i)	(0x2FB0 + ((_i) * 4)) /* 4 total */
+#define IXGBE_WQBR_TX(_i)	(0x8130 + ((_i) * 4)) /* 4 total */
+#define IXGBE_L34T_IMIR(_i)	(0x0E800 + ((_i) * 4)) /*128 of these (0-127)*/
+#define IXGBE_RXFECCERR0	0x051B8
+#define IXGBE_LLITHRESH		0x0EC90
+#define IXGBE_IMIR(_i)		(0x05A80 + ((_i) * 4))  /* 8 of these (0-7) */
+#define IXGBE_IMIREXT(_i)	(0x05AA0 + ((_i) * 4))  /* 8 of these (0-7) */
+#define IXGBE_IMIRVP		0x05AC0
+#define IXGBE_VMD_CTL		0x0581C
+#define IXGBE_RETA(_i)		(0x05C00 + ((_i) * 4))  /* 32 of these (0-31) */
+#define IXGBE_ERETA(_i)		(0x0EE80 + ((_i) * 4))  /* 96 of these (0-95) */
+#define IXGBE_RSSRK(_i)		(0x05C80 + ((_i) * 4))  /* 10 of these (0-9) */
 
 /* Registers for setting up RSS on X550 with SRIOV
  * _p - pool number (0..63)
@@ -395,1195 +502,1387 @@ struct ixgbe_thermal_sensor_data {
 #define IXGBE_PFVFRETA(_i, _p)	(0x019000 + ((_i) * 4) + ((_p) * 0x40))
 
 /* Flow Director registers */
-#define IXGBE_FDIRCTRL  0x0EE00
-#define IXGBE_FDIRHKEY  0x0EE68
-#define IXGBE_FDIRSKEY  0x0EE6C
-#define IXGBE_FDIRDIP4M 0x0EE3C
-#define IXGBE_FDIRSIP4M 0x0EE40
-#define IXGBE_FDIRTCPM  0x0EE44
-#define IXGBE_FDIRUDPM  0x0EE48
+#define IXGBE_FDIRCTRL	0x0EE00
+#define IXGBE_FDIRHKEY	0x0EE68
+#define IXGBE_FDIRSKEY	0x0EE6C
+#define IXGBE_FDIRDIP4M	0x0EE3C
+#define IXGBE_FDIRSIP4M	0x0EE40
+#define IXGBE_FDIRTCPM	0x0EE44
+#define IXGBE_FDIRUDPM	0x0EE48
 #define IXGBE_FDIRSCTPM	0x0EE78
-#define IXGBE_FDIRIP6M  0x0EE74
-#define IXGBE_FDIRM     0x0EE70
+#define IXGBE_FDIRIP6M	0x0EE74
+#define IXGBE_FDIRM	0x0EE70
 
 /* Flow Director Stats registers */
-#define IXGBE_FDIRFREE  0x0EE38
-#define IXGBE_FDIRLEN   0x0EE4C
-#define IXGBE_FDIRUSTAT 0x0EE50
-#define IXGBE_FDIRFSTAT 0x0EE54
-#define IXGBE_FDIRMATCH 0x0EE58
-#define IXGBE_FDIRMISS  0x0EE5C
+#define IXGBE_FDIRFREE	0x0EE38
+#define IXGBE_FDIRLEN	0x0EE4C
+#define IXGBE_FDIRUSTAT	0x0EE50
+#define IXGBE_FDIRFSTAT	0x0EE54
+#define IXGBE_FDIRMATCH	0x0EE58
+#define IXGBE_FDIRMISS	0x0EE5C
 
 /* Flow Director Programming registers */
 #define IXGBE_FDIRSIPv6(_i) (0x0EE0C + ((_i) * 4)) /* 3 of these (0-2) */
-#define IXGBE_FDIRIPSA      0x0EE18
-#define IXGBE_FDIRIPDA      0x0EE1C
-#define IXGBE_FDIRPORT      0x0EE20
-#define IXGBE_FDIRVLAN      0x0EE24
-#define IXGBE_FDIRHASH      0x0EE28
-#define IXGBE_FDIRCMD       0x0EE2C
+#define IXGBE_FDIRIPSA	0x0EE18
+#define IXGBE_FDIRIPDA	0x0EE1C
+#define IXGBE_FDIRPORT	0x0EE20
+#define IXGBE_FDIRVLAN	0x0EE24
+#define IXGBE_FDIRHASH	0x0EE28
+#define IXGBE_FDIRCMD	0x0EE2C
 
 /* Transmit DMA registers */
-#define IXGBE_TDBAL(_i) (0x06000 + ((_i) * 0x40)) /* 32 of these (0-31)*/
-#define IXGBE_TDBAH(_i) (0x06004 + ((_i) * 0x40))
-#define IXGBE_TDLEN(_i) (0x06008 + ((_i) * 0x40))
-#define IXGBE_TDH(_i)   (0x06010 + ((_i) * 0x40))
-#define IXGBE_TDT(_i)   (0x06018 + ((_i) * 0x40))
-#define IXGBE_TXDCTL(_i) (0x06028 + ((_i) * 0x40))
-#define IXGBE_TDWBAL(_i) (0x06038 + ((_i) * 0x40))
-#define IXGBE_TDWBAH(_i) (0x0603C + ((_i) * 0x40))
-#define IXGBE_DTXCTL    0x07E00
-
-#define IXGBE_DMATXCTL      0x04A80
-#define IXGBE_PFVFSPOOF(_i) (0x08200 + ((_i) * 4)) /* 8 of these 0 - 7 */
-#define IXGBE_PFDTXGSWC     0x08220
-#define IXGBE_DTXMXSZRQ     0x08100
-#define IXGBE_DTXTCPFLGL    0x04A88
-#define IXGBE_DTXTCPFLGH    0x04A8C
-#define IXGBE_LBDRPEN       0x0CA00
-#define IXGBE_TXPBTHRESH(_i) (0x04950 + ((_i) * 4)) /* 8 of these 0 - 7 */
-
-#define IXGBE_DMATXCTL_TE       0x1 /* Transmit Enable */
-#define IXGBE_DMATXCTL_NS       0x2 /* No Snoop LSO hdr buffer */
-#define IXGBE_DMATXCTL_GDV      0x8 /* Global Double VLAN */
-#define IXGBE_DMATXCTL_VT_SHIFT 16  /* VLAN EtherType */
-
-#define IXGBE_PFDTXGSWC_VT_LBEN 0x1 /* Local L2 VT switch enable */
+#define IXGBE_TDBAL(_i)		(0x06000 + ((_i) * 0x40)) /* 32 of them (0-31)*/
+#define IXGBE_TDBAH(_i)		(0x06004 + ((_i) * 0x40))
+#define IXGBE_TDLEN(_i)		(0x06008 + ((_i) * 0x40))
+#define IXGBE_TDH(_i)		(0x06010 + ((_i) * 0x40))
+#define IXGBE_TDT(_i)		(0x06018 + ((_i) * 0x40))
+#define IXGBE_TXDCTL(_i)	(0x06028 + ((_i) * 0x40))
+#define IXGBE_TDWBAL(_i)	(0x06038 + ((_i) * 0x40))
+#define IXGBE_TDWBAH(_i)	(0x0603C + ((_i) * 0x40))
+#define IXGBE_DTXCTL		0x07E00
+
+#define IXGBE_DMATXCTL		0x04A80
+#define IXGBE_PFVFSPOOF(_i)	(0x08200 + ((_i) * 4)) /* 8 of these 0 - 7 */
+#define IXGBE_PFDTXGSWC		0x08220
+#define IXGBE_DTXMXSZRQ		0x08100
+#define IXGBE_DTXTCPFLGL	0x04A88
+#define IXGBE_DTXTCPFLGH	0x04A8C
+#define IXGBE_LBDRPEN		0x0CA00
+#define IXGBE_TXPBTHRESH(_i)	(0x04950 + ((_i) * 4)) /* 8 of these 0 - 7 */
+
+#define IXGBE_DMATXCTL_TE	0x1 /* Transmit Enable */
+#define IXGBE_DMATXCTL_NS	0x2 /* No Snoop LSO hdr buffer */
+#define IXGBE_DMATXCTL_GDV	0x8 /* Global Double VLAN */
+#define IXGBE_DMATXCTL_MDP_EN	0x20 /* Bit 5 */
+#define IXGBE_DMATXCTL_MBINTEN	0x40 /* Bit 6 */
+#define IXGBE_DMATXCTL_VT_SHIFT	16  /* VLAN EtherType */
+
+#define IXGBE_PFDTXGSWC_VT_LBEN	0x1 /* Local L2 VT switch enable */
 
 /* Anti-spoofing defines */
-#define IXGBE_SPOOF_MACAS_MASK          0xFF
-#define IXGBE_SPOOF_VLANAS_MASK         0xFF00
-#define IXGBE_SPOOF_VLANAS_SHIFT        8
+#define IXGBE_SPOOF_MACAS_MASK		0xFF
+#define IXGBE_SPOOF_VLANAS_MASK		0xFF00
+#define IXGBE_SPOOF_VLANAS_SHIFT	8
 #define IXGBE_SPOOF_ETHERTYPEAS		0xFF000000
 #define IXGBE_SPOOF_ETHERTYPEAS_SHIFT	16
-#define IXGBE_PFVFSPOOF_REG_COUNT       8
-
-#define IXGBE_DCA_TXCTRL(_i)    (0x07200 + ((_i) * 4)) /* 16 of these (0-15) */
+#define IXGBE_PFVFSPOOF_REG_COUNT	8
+/* 16 of these (0-15) */
+#define IXGBE_DCA_TXCTRL(_i)		(0x07200 + ((_i) * 4))
 /* Tx DCA Control register : 128 of these (0-127) */
-#define IXGBE_DCA_TXCTRL_82599(_i)  (0x0600C + ((_i) * 0x40))
-#define IXGBE_TIPG      0x0CB00
-#define IXGBE_TXPBSIZE(_i)      (0x0CC00 + ((_i) * 4)) /* 8 of these */
-#define IXGBE_MNGTXMAP  0x0CD10
-#define IXGBE_TIPG_FIBER_DEFAULT 3
-#define IXGBE_TXPBSIZE_SHIFT    10
+#define IXGBE_DCA_TXCTRL_82599(_i)	(0x0600C + ((_i) * 0x40))
+#define IXGBE_TIPG			0x0CB00
+#define IXGBE_TXPBSIZE(_i)		(0x0CC00 + ((_i) * 4)) /* 8 of these */
+#define IXGBE_MNGTXMAP			0x0CD10
+#define IXGBE_TIPG_FIBER_DEFAULT	3
+#define IXGBE_TXPBSIZE_SHIFT		10
 
 /* Wake up registers */
-#define IXGBE_WUC       0x05800
-#define IXGBE_WUFC      0x05808
-#define IXGBE_WUS       0x05810
-#define IXGBE_IPAV      0x05838
-#define IXGBE_IP4AT     0x05840 /* IPv4 table 0x5840-0x5858 */
-#define IXGBE_IP6AT     0x05880 /* IPv6 table 0x5880-0x588F */
-
-#define IXGBE_WUPL      0x05900
-#define IXGBE_WUPM      0x05A00 /* wake up pkt memory 0x5A00-0x5A7C */
+#define IXGBE_WUC	0x05800
+#define IXGBE_WUFC	0x05808
+#define IXGBE_WUS	0x05810
+#define IXGBE_IPAV	0x05838
+#define IXGBE_IP4AT	0x05840 /* IPv4 table 0x5840-0x5858 */
+#define IXGBE_IP6AT	0x05880 /* IPv6 table 0x5880-0x588F */
+
+#define IXGBE_WUPL	0x05900
+#define IXGBE_WUPM	0x05A00 /* wake up pkt memory 0x5A00-0x5A7C */
+#define IXGBE_PROXYS	0x05F60 /* Proxying Status Register */
+#define IXGBE_PROXYFC	0x05F64 /* Proxying Filter Control Register */
 #define IXGBE_VXLANCTRL	0x0000507C /* Rx filter VXLAN UDPPORT Register */
+
+/* masks for accessing VXLAN and GENEVE UDP ports */
+#define IXGBE_VXLANCTRL_VXLAN_UDPPORT_MASK	0x0000ffff /* VXLAN port */
+#define IXGBE_VXLANCTRL_GENEVE_UDPPORT_MASK	0xffff0000 /* GENEVE port */
+#define IXGBE_VXLANCTRL_ALL_UDPPORT_MASK	0xffffffff /* GENEVE/VXLAN */
+
+#define IXGBE_VXLANCTRL_GENEVE_UDPPORT_SHIFT	16
+
 #define IXGBE_FHFT(_n)	(0x09000 + ((_n) * 0x100)) /* Flex host filter table */
-#define IXGBE_FHFT_EXT(_n)	(0x09800 + ((_n) * 0x100)) /* Ext Flexible Host
-							    * Filter Table */
+/* Ext Flexible Host Filter Table */
+#define IXGBE_FHFT_EXT(_n)	(0x09800 + ((_n) * 0x100))
+#define IXGBE_FHFT_EXT_X550(_n)	(0x09600 + ((_n) * 0x100))
 
-#define IXGBE_FLEXIBLE_FILTER_COUNT_MAX         4
-#define IXGBE_EXT_FLEXIBLE_FILTER_COUNT_MAX     2
+/* Four Flexible Filters are supported */
+#define IXGBE_FLEXIBLE_FILTER_COUNT_MAX		4
+
+/* Six Flexible Filters are supported */
+#define IXGBE_FLEXIBLE_FILTER_COUNT_MAX_6	6
+/* Eight Flexible Filters are supported */
+#define IXGBE_FLEXIBLE_FILTER_COUNT_MAX_8	8
+#define IXGBE_EXT_FLEXIBLE_FILTER_COUNT_MAX	2
 
 /* Each Flexible Filter is at most 128 (0x80) bytes in length */
-#define IXGBE_FLEXIBLE_FILTER_SIZE_MAX  128
-#define IXGBE_FHFT_LENGTH_OFFSET        0xFC  /* Length byte in FHFT */
-#define IXGBE_FHFT_LENGTH_MASK          0x0FF /* Length in lower byte */
+#define IXGBE_FLEXIBLE_FILTER_SIZE_MAX		128
+#define IXGBE_FHFT_LENGTH_OFFSET		0xFC  /* Length byte in FHFT */
+#define IXGBE_FHFT_LENGTH_MASK			0x0FF /* Length in lower byte */
 
 /* Definitions for power management and wakeup registers */
 /* Wake Up Control */
-#define IXGBE_WUC_PME_EN     0x00000002 /* PME Enable */
-#define IXGBE_WUC_PME_STATUS 0x00000004 /* PME Status */
-#define IXGBE_WUC_WKEN       0x00000010 /* Enable PE_WAKE_N pin assertion  */
+#define IXGBE_WUC_PME_EN	0x00000002 /* PME Enable */
+#define IXGBE_WUC_PME_STATUS	0x00000004 /* PME Status */
+#define IXGBE_WUC_WKEN		0x00000010 /* Enable PE_WAKE_N pin assertion  */
 
 /* Wake Up Filter Control */
-#define IXGBE_WUFC_LNKC 0x00000001 /* Link Status Change Wakeup Enable */
-#define IXGBE_WUFC_MAG  0x00000002 /* Magic Packet Wakeup Enable */
-#define IXGBE_WUFC_EX   0x00000004 /* Directed Exact Wakeup Enable */
-#define IXGBE_WUFC_MC   0x00000008 /* Directed Multicast Wakeup Enable */
-#define IXGBE_WUFC_BC   0x00000010 /* Broadcast Wakeup Enable */
-#define IXGBE_WUFC_ARP  0x00000020 /* ARP Request Packet Wakeup Enable */
-#define IXGBE_WUFC_IPV4 0x00000040 /* Directed IPv4 Packet Wakeup Enable */
-#define IXGBE_WUFC_IPV6 0x00000080 /* Directed IPv6 Packet Wakeup Enable */
-#define IXGBE_WUFC_MNG  0x00000100 /* Directed Mgmt Packet Wakeup Enable */
-
-#define IXGBE_WUFC_IGNORE_TCO   0x00008000 /* Ignore WakeOn TCO packets */
-#define IXGBE_WUFC_FLX0 0x00010000 /* Flexible Filter 0 Enable */
-#define IXGBE_WUFC_FLX1 0x00020000 /* Flexible Filter 1 Enable */
-#define IXGBE_WUFC_FLX2 0x00040000 /* Flexible Filter 2 Enable */
-#define IXGBE_WUFC_FLX3 0x00080000 /* Flexible Filter 3 Enable */
-#define IXGBE_WUFC_FLX4 0x00100000 /* Flexible Filter 4 Enable */
-#define IXGBE_WUFC_FLX5 0x00200000 /* Flexible Filter 5 Enable */
-#define IXGBE_WUFC_FLX_FILTERS     0x000F0000 /* Mask for 4 flex filters */
-#define IXGBE_WUFC_EXT_FLX_FILTERS 0x00300000 /* Mask for Ext. flex filters */
-#define IXGBE_WUFC_ALL_FILTERS     0x003F00FF /* Mask for all wakeup filters */
-#define IXGBE_WUFC_FLX_OFFSET      16 /* Offset to the Flexible Filters bits */
+#define IXGBE_WUFC_LNKC	0x00000001 /* Link Status Change Wakeup Enable */
+#define IXGBE_WUFC_MAG	0x00000002 /* Magic Packet Wakeup Enable */
+#define IXGBE_WUFC_EX	0x00000004 /* Directed Exact Wakeup Enable */
+#define IXGBE_WUFC_MC	0x00000008 /* Directed Multicast Wakeup Enable */
+#define IXGBE_WUFC_BC	0x00000010 /* Broadcast Wakeup Enable */
+#define IXGBE_WUFC_ARP	0x00000020 /* ARP Request Packet Wakeup Enable */
+#define IXGBE_WUFC_IPV4	0x00000040 /* Directed IPv4 Packet Wakeup Enable */
+#define IXGBE_WUFC_IPV6	0x00000080 /* Directed IPv6 Packet Wakeup Enable */
+#define IXGBE_WUFC_MNG	0x00000100 /* Directed Mgmt Packet Wakeup Enable */
+
+#define IXGBE_WUFC_IGNORE_TCO	0x00008000 /* Ignore WakeOn TCO packets */
+#define IXGBE_WUFC_FLX0	0x00010000 /* Flexible Filter 0 Enable */
+#define IXGBE_WUFC_FLX1	0x00020000 /* Flexible Filter 1 Enable */
+#define IXGBE_WUFC_FLX2	0x00040000 /* Flexible Filter 2 Enable */
+#define IXGBE_WUFC_FLX3	0x00080000 /* Flexible Filter 3 Enable */
+#define IXGBE_WUFC_FLX4	0x00100000 /* Flexible Filter 4 Enable */
+#define IXGBE_WUFC_FLX5	0x00200000 /* Flexible Filter 5 Enable */
+#define IXGBE_WUFC_FLX_FILTERS		0x000F0000 /* Mask for 4 flex filters */
+#define IXGBE_WUFC_FLX_FILTERS_6	0x003F0000 /* Mask for 6 flex filters */
+#define IXGBE_WUFC_FLX_FILTERS_8	0x00FF0000 /* Mask for 8 flex filters */
+#define IXGBE_WUFC_FW_RST_WK	0x80000000 /* Ena wake on FW reset assertion */
+/* Mask for Ext. flex filters */
+#define IXGBE_WUFC_EXT_FLX_FILTERS	0x00300000
+#define IXGBE_WUFC_ALL_FILTERS		0x000F00FF /* Mask all 4 flex filters */
+#define IXGBE_WUFC_ALL_FILTERS_6	0x003F00FF /* Mask all 6 flex filters */
+#define IXGBE_WUFC_ALL_FILTERS_8	0x00FF00FF /* Mask all 8 flex filters */
+#define IXGBE_WUFC_FLX_OFFSET	16 /* Offset to the Flexible Filters bits */
 
 /* Wake Up Status */
-#define IXGBE_WUS_LNKC  IXGBE_WUFC_LNKC
-#define IXGBE_WUS_MAG   IXGBE_WUFC_MAG
-#define IXGBE_WUS_EX    IXGBE_WUFC_EX
-#define IXGBE_WUS_MC    IXGBE_WUFC_MC
-#define IXGBE_WUS_BC    IXGBE_WUFC_BC
-#define IXGBE_WUS_ARP   IXGBE_WUFC_ARP
-#define IXGBE_WUS_IPV4  IXGBE_WUFC_IPV4
-#define IXGBE_WUS_IPV6  IXGBE_WUFC_IPV6
-#define IXGBE_WUS_MNG   IXGBE_WUFC_MNG
-#define IXGBE_WUS_FLX0  IXGBE_WUFC_FLX0
-#define IXGBE_WUS_FLX1  IXGBE_WUFC_FLX1
-#define IXGBE_WUS_FLX2  IXGBE_WUFC_FLX2
-#define IXGBE_WUS_FLX3  IXGBE_WUFC_FLX3
-#define IXGBE_WUS_FLX4  IXGBE_WUFC_FLX4
-#define IXGBE_WUS_FLX5  IXGBE_WUFC_FLX5
-#define IXGBE_WUS_FLX_FILTERS  IXGBE_WUFC_FLX_FILTERS
-
-/* Wake Up Packet Length */
-#define IXGBE_WUPL_LENGTH_MASK 0xFFFF
+#define IXGBE_WUS_LNKC		IXGBE_WUFC_LNKC
+#define IXGBE_WUS_MAG		IXGBE_WUFC_MAG
+#define IXGBE_WUS_EX		IXGBE_WUFC_EX
+#define IXGBE_WUS_MC		IXGBE_WUFC_MC
+#define IXGBE_WUS_BC		IXGBE_WUFC_BC
+#define IXGBE_WUS_ARP		IXGBE_WUFC_ARP
+#define IXGBE_WUS_IPV4		IXGBE_WUFC_IPV4
+#define IXGBE_WUS_IPV6		IXGBE_WUFC_IPV6
+#define IXGBE_WUS_MNG		IXGBE_WUFC_MNG
+#define IXGBE_WUS_FLX0		IXGBE_WUFC_FLX0
+#define IXGBE_WUS_FLX1		IXGBE_WUFC_FLX1
+#define IXGBE_WUS_FLX2		IXGBE_WUFC_FLX2
+#define IXGBE_WUS_FLX3		IXGBE_WUFC_FLX3
+#define IXGBE_WUS_FLX4		IXGBE_WUFC_FLX4
+#define IXGBE_WUS_FLX5		IXGBE_WUFC_FLX5
+#define IXGBE_WUS_FLX_FILTERS	IXGBE_WUFC_FLX_FILTERS
+#define IXGBE_WUS_FW_RST_WK	IXGBE_WUFC_FW_RST_WK
+/* Proxy Status */
+#define IXGBE_PROXYS_EX		0x00000004 /* Exact packet received */
+#define IXGBE_PROXYS_ARP_DIR	0x00000020 /* ARP w/filter match received */
+#define IXGBE_PROXYS_NS		0x00000200 /* IPV6 NS received */
+#define IXGBE_PROXYS_NS_DIR	0x00000400 /* IPV6 NS w/DA match received */
+#define IXGBE_PROXYS_ARP	0x00000800 /* ARP request packet received */
+#define IXGBE_PROXYS_MLD	0x00001000 /* IPv6 MLD packet received */
+
+/* Proxying Filter Control */
+#define IXGBE_PROXYFC_ENABLE	0x00000001 /* Port Proxying Enable */
+#define IXGBE_PROXYFC_EX	0x00000004 /* Directed Exact Proxy Enable */
+#define IXGBE_PROXYFC_ARP_DIR	0x00000020 /* Directed ARP Proxy Enable */
+#define IXGBE_PROXYFC_NS	0x00000200 /* IPv6 Neighbor Solicitation */
+#define IXGBE_PROXYFC_ARP	0x00000800 /* ARP Request Proxy Enable */
+#define IXGBE_PROXYFC_MLD	0x00000800 /* IPv6 MLD Proxy Enable */
+#define IXGBE_PROXYFC_NO_TCO	0x00008000 /* Ignore TCO packets */
+
+#define IXGBE_WUPL_LENGTH_MASK	0xFFFF
 
 /* DCB registers */
-#define MAX_TRAFFIC_CLASS        8
-#define X540_TRAFFIC_CLASS       4
-#define IXGBE_RMCS      0x03D00
-#define IXGBE_DPMCS     0x07F40
-#define IXGBE_PDPMCS    0x0CD00
-#define IXGBE_RUPPBMR   0x050A0
-#define IXGBE_RT2CR(_i) (0x03C20 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_RT2SR(_i) (0x03C40 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_TDTQ2TCCR(_i)     (0x0602C + ((_i) * 0x40)) /* 8 of these (0-7) */
-#define IXGBE_TDTQ2TCSR(_i)     (0x0622C + ((_i) * 0x40)) /* 8 of these (0-7) */
-#define IXGBE_TDPT2TCCR(_i)     (0x0CD20 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_TDPT2TCSR(_i)     (0x0CD40 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_DCB_MAX_TRAFFIC_CLASS	8
+#define IXGBE_RMCS		0x03D00
+#define IXGBE_DPMCS		0x07F40
+#define IXGBE_PDPMCS		0x0CD00
+#define IXGBE_RUPPBMR		0x050A0
+#define IXGBE_RT2CR(_i)		(0x03C20 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_RT2SR(_i)		(0x03C40 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_TDTQ2TCCR(_i)	(0x0602C + ((_i) * 0x40)) /* 8 of these (0-7) */
+#define IXGBE_TDTQ2TCSR(_i)	(0x0622C + ((_i) * 0x40)) /* 8 of these (0-7) */
+#define IXGBE_TDPT2TCCR(_i)	(0x0CD20 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_TDPT2TCSR(_i)	(0x0CD40 + ((_i) * 4)) /* 8 of these (0-7) */
+
+/* Power Management */
+/* DMA Coalescing configuration */
+struct ixgbe_dmac_config {
+	u16	watchdog_timer; /* usec units */
+	bool	fcoe_en;
+	u32	link_speed;
+	u8	fcoe_tc;
+	u8	num_tcs;
+};
 
+/*
+ * DMA Coalescing threshold Rx PB TC[n] value in Kilobyte by link speed.
+ * DMACRXT = 10Gbps = 10,000 bits / usec = 1250 bytes / usec 70 * 1250 ==
+ * 87500 bytes [85KB]
+ */
+#define IXGBE_DMACRXT_10G		0x55
+#define IXGBE_DMACRXT_1G		0x09
+#define IXGBE_DMACRXT_100M		0x01
+
+/* DMA Coalescing registers */
+#define IXGBE_DMCMNGTH			0x15F20 /* Management Threshold */
+#define IXGBE_DMACR			0x02400 /* Control register */
+#define IXGBE_DMCTH(_i)			(0x03300 + ((_i) * 4)) /* 8 of these */
+#define IXGBE_DMCTLX			0x02404 /* Time to Lx request */
+/* DMA Coalescing register fields */
+#define IXGBE_DMCMNGTH_DMCMNGTH_MASK	0x000FFFF0 /* Mng Threshold mask */
+#define IXGBE_DMCMNGTH_DMCMNGTH_SHIFT	4 /* Management Threshold shift */
+#define IXGBE_DMACR_DMACWT_MASK		0x0000FFFF /* Watchdog Timer mask */
+#define IXGBE_DMACR_HIGH_PRI_TC_MASK	0x00FF0000
+#define IXGBE_DMACR_HIGH_PRI_TC_SHIFT	16
+#define IXGBE_DMACR_EN_MNG_IND		0x10000000 /* Enable Mng Indications */
+#define IXGBE_DMACR_LX_COAL_IND		0x40000000 /* Lx Coalescing indicate */
+#define IXGBE_DMACR_DMAC_EN		0x80000000 /* DMA Coalescing Enable */
+#define IXGBE_DMCTH_DMACRXT_MASK	0x000001FF /* Receive Threshold mask */
+#define IXGBE_DMCTLX_TTLX_MASK		0x00000FFF /* Time to Lx request mask */
+
+/* EEE registers */
+#define IXGBE_EEER			0x043A0 /* EEE register */
+#define IXGBE_EEE_STAT			0x04398 /* EEE Status */
+#define IXGBE_EEE_SU			0x04380 /* EEE Set up */
+#define IXGBE_EEE_SU_TEEE_DLY_SHIFT	26
+#define IXGBE_TLPIC			0x041F4 /* EEE Tx LPI count */
+#define IXGBE_RLPIC			0x041F8 /* EEE Rx LPI count */
+
+/* EEE register fields */
+#define IXGBE_EEER_TX_LPI_EN		0x00010000 /* Enable EEE LPI TX path */
+#define IXGBE_EEER_RX_LPI_EN		0x00020000 /* Enable EEE LPI RX path */
+#define IXGBE_EEE_STAT_NEG		0x20000000 /* EEE support neg on link */
+#define IXGBE_EEE_RX_LPI_STATUS		0x40000000 /* RX Link in LPI status */
+#define IXGBE_EEE_TX_LPI_STATUS		0x80000000 /* TX Link in LPI status */
 
 /* Security Control Registers */
-#define IXGBE_SECTXCTRL         0x08800
-#define IXGBE_SECTXSTAT         0x08804
-#define IXGBE_SECTXBUFFAF       0x08808
-#define IXGBE_SECTXMINIFG       0x08810
-#define IXGBE_SECRXCTRL         0x08D00
-#define IXGBE_SECRXSTAT         0x08D04
+#define IXGBE_SECTXCTRL		0x08800
+#define IXGBE_SECTXSTAT		0x08804
+#define IXGBE_SECTXBUFFAF	0x08808
+#define IXGBE_SECTXMINIFG	0x08810
+#define IXGBE_SECRXCTRL		0x08D00
+#define IXGBE_SECRXSTAT		0x08D04
 
 /* Security Bit Fields and Masks */
-#define IXGBE_SECTXCTRL_SECTX_DIS       0x00000001
-#define IXGBE_SECTXCTRL_TX_DIS          0x00000002
-#define IXGBE_SECTXCTRL_STORE_FORWARD   0x00000004
+#define IXGBE_SECTXCTRL_SECTX_DIS	0x00000001
+#define IXGBE_SECTXCTRL_TX_DIS		0x00000002
+#define IXGBE_SECTXCTRL_STORE_FORWARD	0x00000004
 
-#define IXGBE_SECTXSTAT_SECTX_RDY       0x00000001
-#define IXGBE_SECTXSTAT_ECC_TXERR       0x00000002
+#define IXGBE_SECTXSTAT_SECTX_RDY	0x00000001
+#define IXGBE_SECTXSTAT_ECC_TXERR	0x00000002
 
-#define IXGBE_SECRXCTRL_SECRX_DIS       0x00000001
-#define IXGBE_SECRXCTRL_RX_DIS          0x00000002
+#define IXGBE_SECRXCTRL_SECRX_DIS	0x00000001
+#define IXGBE_SECRXCTRL_RX_DIS		0x00000002
 
-#define IXGBE_SECRXSTAT_SECRX_RDY       0x00000001
-#define IXGBE_SECRXSTAT_ECC_RXERR       0x00000002
+#define IXGBE_SECRXSTAT_SECRX_RDY	0x00000001
+#define IXGBE_SECRXSTAT_ECC_RXERR	0x00000002
 
 /* LinkSec (MacSec) Registers */
-#define IXGBE_LSECTXCAP         0x08A00
-#define IXGBE_LSECRXCAP         0x08F00
-#define IXGBE_LSECTXCTRL        0x08A04
-#define IXGBE_LSECTXSCL         0x08A08 /* SCI Low */
-#define IXGBE_LSECTXSCH         0x08A0C /* SCI High */
-#define IXGBE_LSECTXSA          0x08A10
-#define IXGBE_LSECTXPN0         0x08A14
-#define IXGBE_LSECTXPN1         0x08A18
-#define IXGBE_LSECTXKEY0(_n)    (0x08A1C + (4 * (_n))) /* 4 of these (0-3) */
-#define IXGBE_LSECTXKEY1(_n)    (0x08A2C + (4 * (_n))) /* 4 of these (0-3) */
-#define IXGBE_LSECRXCTRL        0x08F04
-#define IXGBE_LSECRXSCL         0x08F08
-#define IXGBE_LSECRXSCH         0x08F0C
-#define IXGBE_LSECRXSA(_i)      (0x08F10 + (4 * (_i))) /* 2 of these (0-1) */
-#define IXGBE_LSECRXPN(_i)      (0x08F18 + (4 * (_i))) /* 2 of these (0-1) */
-#define IXGBE_LSECRXKEY(_n, _m) (0x08F20 + ((0x10 * (_n)) + (4 * (_m))))
-#define IXGBE_LSECTXUT          0x08A3C /* OutPktsUntagged */
-#define IXGBE_LSECTXPKTE        0x08A40 /* OutPktsEncrypted */
-#define IXGBE_LSECTXPKTP        0x08A44 /* OutPktsProtected */
-#define IXGBE_LSECTXOCTE        0x08A48 /* OutOctetsEncrypted */
-#define IXGBE_LSECTXOCTP        0x08A4C /* OutOctetsProtected */
-#define IXGBE_LSECRXUT          0x08F40 /* InPktsUntagged/InPktsNoTag */
-#define IXGBE_LSECRXOCTD        0x08F44 /* InOctetsDecrypted */
-#define IXGBE_LSECRXOCTV        0x08F48 /* InOctetsValidated */
-#define IXGBE_LSECRXBAD         0x08F4C /* InPktsBadTag */
-#define IXGBE_LSECRXNOSCI       0x08F50 /* InPktsNoSci */
-#define IXGBE_LSECRXUNSCI       0x08F54 /* InPktsUnknownSci */
-#define IXGBE_LSECRXUNCH        0x08F58 /* InPktsUnchecked */
-#define IXGBE_LSECRXDELAY       0x08F5C /* InPktsDelayed */
-#define IXGBE_LSECRXLATE        0x08F60 /* InPktsLate */
-#define IXGBE_LSECRXOK(_n)      (0x08F64 + (0x04 * (_n))) /* InPktsOk */
-#define IXGBE_LSECRXINV(_n)     (0x08F6C + (0x04 * (_n))) /* InPktsInvalid */
-#define IXGBE_LSECRXNV(_n)      (0x08F74 + (0x04 * (_n))) /* InPktsNotValid */
-#define IXGBE_LSECRXUNSA        0x08F7C /* InPktsUnusedSa */
-#define IXGBE_LSECRXNUSA        0x08F80 /* InPktsNotUsingSa */
+#define IXGBE_LSECTXCAP		0x08A00
+#define IXGBE_LSECRXCAP		0x08F00
+#define IXGBE_LSECTXCTRL	0x08A04
+#define IXGBE_LSECTXSCL		0x08A08 /* SCI Low */
+#define IXGBE_LSECTXSCH		0x08A0C /* SCI High */
+#define IXGBE_LSECTXSA		0x08A10
+#define IXGBE_LSECTXPN0		0x08A14
+#define IXGBE_LSECTXPN1		0x08A18
+#define IXGBE_LSECTXKEY0(_n)	(0x08A1C + (4 * (_n))) /* 4 of these (0-3) */
+#define IXGBE_LSECTXKEY1(_n)	(0x08A2C + (4 * (_n))) /* 4 of these (0-3) */
+#define IXGBE_LSECRXCTRL	0x08F04
+#define IXGBE_LSECRXSCL		0x08F08
+#define IXGBE_LSECRXSCH		0x08F0C
+#define IXGBE_LSECRXSA(_i)	(0x08F10 + (4 * (_i))) /* 2 of these (0-1) */
+#define IXGBE_LSECRXPN(_i)	(0x08F18 + (4 * (_i))) /* 2 of these (0-1) */
+#define IXGBE_LSECRXKEY(_n, _m)	(0x08F20 + ((0x10 * (_n)) + (4 * (_m))))
+#define IXGBE_LSECTXUT		0x08A3C /* OutPktsUntagged */
+#define IXGBE_LSECTXPKTE	0x08A40 /* OutPktsEncrypted */
+#define IXGBE_LSECTXPKTP	0x08A44 /* OutPktsProtected */
+#define IXGBE_LSECTXOCTE	0x08A48 /* OutOctetsEncrypted */
+#define IXGBE_LSECTXOCTP	0x08A4C /* OutOctetsProtected */
+#define IXGBE_LSECRXUT		0x08F40 /* InPktsUntagged/InPktsNoTag */
+#define IXGBE_LSECRXOCTD	0x08F44 /* InOctetsDecrypted */
+#define IXGBE_LSECRXOCTV	0x08F48 /* InOctetsValidated */
+#define IXGBE_LSECRXBAD		0x08F4C /* InPktsBadTag */
+#define IXGBE_LSECRXNOSCI	0x08F50 /* InPktsNoSci */
+#define IXGBE_LSECRXUNSCI	0x08F54 /* InPktsUnknownSci */
+#define IXGBE_LSECRXUNCH	0x08F58 /* InPktsUnchecked */
+#define IXGBE_LSECRXDELAY	0x08F5C /* InPktsDelayed */
+#define IXGBE_LSECRXLATE	0x08F60 /* InPktsLate */
+#define IXGBE_LSECRXOK(_n)	(0x08F64 + (0x04 * (_n))) /* InPktsOk */
+#define IXGBE_LSECRXINV(_n)	(0x08F6C + (0x04 * (_n))) /* InPktsInvalid */
+#define IXGBE_LSECRXNV(_n)	(0x08F74 + (0x04 * (_n))) /* InPktsNotValid */
+#define IXGBE_LSECRXUNSA	0x08F7C /* InPktsUnusedSa */
+#define IXGBE_LSECRXNUSA	0x08F80 /* InPktsNotUsingSa */
 
 /* LinkSec (MacSec) Bit Fields and Masks */
-#define IXGBE_LSECTXCAP_SUM_MASK        0x00FF0000
-#define IXGBE_LSECTXCAP_SUM_SHIFT       16
-#define IXGBE_LSECRXCAP_SUM_MASK        0x00FF0000
-#define IXGBE_LSECRXCAP_SUM_SHIFT       16
-
-#define IXGBE_LSECTXCTRL_EN_MASK        0x00000003
-#define IXGBE_LSECTXCTRL_DISABLE        0x0
-#define IXGBE_LSECTXCTRL_AUTH           0x1
-#define IXGBE_LSECTXCTRL_AUTH_ENCRYPT   0x2
-#define IXGBE_LSECTXCTRL_AISCI          0x00000020
-#define IXGBE_LSECTXCTRL_PNTHRSH_MASK   0xFFFFFF00
-#define IXGBE_LSECTXCTRL_RSV_MASK       0x000000D8
-
-#define IXGBE_LSECRXCTRL_EN_MASK        0x0000000C
-#define IXGBE_LSECRXCTRL_EN_SHIFT       2
-#define IXGBE_LSECRXCTRL_DISABLE        0x0
-#define IXGBE_LSECRXCTRL_CHECK          0x1
-#define IXGBE_LSECRXCTRL_STRICT         0x2
-#define IXGBE_LSECRXCTRL_DROP           0x3
-#define IXGBE_LSECRXCTRL_PLSH           0x00000040
-#define IXGBE_LSECRXCTRL_RP             0x00000080
-#define IXGBE_LSECRXCTRL_RSV_MASK       0xFFFFFF33
+#define IXGBE_LSECTXCAP_SUM_MASK	0x00FF0000
+#define IXGBE_LSECTXCAP_SUM_SHIFT	16
+#define IXGBE_LSECRXCAP_SUM_MASK	0x00FF0000
+#define IXGBE_LSECRXCAP_SUM_SHIFT	16
+
+#define IXGBE_LSECTXCTRL_EN_MASK	0x00000003
+#define IXGBE_LSECTXCTRL_DISABLE	0x0
+#define IXGBE_LSECTXCTRL_AUTH		0x1
+#define IXGBE_LSECTXCTRL_AUTH_ENCRYPT	0x2
+#define IXGBE_LSECTXCTRL_AISCI		0x00000020
+#define IXGBE_LSECTXCTRL_PNTHRSH_MASK	0xFFFFFF00
+#define IXGBE_LSECTXCTRL_RSV_MASK	0x000000D8
+
+#define IXGBE_LSECRXCTRL_EN_MASK	0x0000000C
+#define IXGBE_LSECRXCTRL_EN_SHIFT	2
+#define IXGBE_LSECRXCTRL_DISABLE	0x0
+#define IXGBE_LSECRXCTRL_CHECK		0x1
+#define IXGBE_LSECRXCTRL_STRICT		0x2
+#define IXGBE_LSECRXCTRL_DROP		0x3
+#define IXGBE_LSECRXCTRL_PLSH		0x00000040
+#define IXGBE_LSECRXCTRL_RP		0x00000080
+#define IXGBE_LSECRXCTRL_RSV_MASK	0xFFFFFF33
 
 /* IpSec Registers */
-#define IXGBE_IPSTXIDX          0x08900
-#define IXGBE_IPSTXSALT         0x08904
-#define IXGBE_IPSTXKEY(_i)      (0x08908 + (4 * (_i))) /* 4 of these (0-3) */
-#define IXGBE_IPSRXIDX          0x08E00
-#define IXGBE_IPSRXIPADDR(_i)   (0x08E04 + (4 * (_i))) /* 4 of these (0-3) */
-#define IXGBE_IPSRXSPI          0x08E14
-#define IXGBE_IPSRXIPIDX        0x08E18
-#define IXGBE_IPSRXKEY(_i)      (0x08E1C + (4 * (_i))) /* 4 of these (0-3) */
-#define IXGBE_IPSRXSALT         0x08E2C
-#define IXGBE_IPSRXMOD          0x08E30
-
-#define IXGBE_SECTXCTRL_STORE_FORWARD_ENABLE    0x4
+#define IXGBE_IPSTXIDX		0x08900
+#define IXGBE_IPSTXSALT		0x08904
+#define IXGBE_IPSTXKEY(_i)	(0x08908 + (4 * (_i))) /* 4 of these (0-3) */
+#define IXGBE_IPSRXIDX		0x08E00
+#define IXGBE_IPSRXIPADDR(_i)	(0x08E04 + (4 * (_i))) /* 4 of these (0-3) */
+#define IXGBE_IPSRXSPI		0x08E14
+#define IXGBE_IPSRXIPIDX	0x08E18
+#define IXGBE_IPSRXKEY(_i)	(0x08E1C + (4 * (_i))) /* 4 of these (0-3) */
+#define IXGBE_IPSRXSALT		0x08E2C
+#define IXGBE_IPSRXMOD		0x08E30
+
+#define IXGBE_SECTXCTRL_STORE_FORWARD_ENABLE	0x4
 
 /* DCB registers */
-#define IXGBE_RTRPCS      0x02430
-#define IXGBE_RTTDCS      0x04900
-#define IXGBE_RTTDCS_ARBDIS     0x00000040 /* DCB arbiter disable */
-#define IXGBE_RTTPCS      0x0CD00
-#define IXGBE_RTRUP2TC    0x03020
-#define IXGBE_RTTUP2TC    0x0C800
-#define IXGBE_RTRPT4C(_i) (0x02140 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_TXLLQ(_i)   (0x082E0 + ((_i) * 4)) /* 4 of these (0-3) */
-#define IXGBE_RTRPT4S(_i) (0x02160 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_RTTDT2C(_i) (0x04910 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_RTTDT2S(_i) (0x04930 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_RTTPT2C(_i) (0x0CD20 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_RTTPT2S(_i) (0x0CD40 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_RTTDQSEL    0x04904
-#define IXGBE_RTTDT1C     0x04908
-#define IXGBE_RTTDT1S     0x0490C
-#define IXGBE_RTTQCNCR    0x08B00
-#define IXGBE_RTTQCNTG    0x04A90
-#define IXGBE_RTTBCNRD    0x0498C
-#define IXGBE_RTTQCNRR    0x0498C
-#define IXGBE_RTTDTECC    0x04990
-#define IXGBE_RTTDTECC_NO_BCN   0x00000100
-#define IXGBE_RTTBCNRC    0x04984
-#define IXGBE_RTTBCNRC_RS_ENA	0x80000000
+#define IXGBE_RTRPCS		0x02430
+#define IXGBE_RTTDCS		0x04900
+#define IXGBE_RTTDCS_ARBDIS	0x00000040 /* DCB arbiter disable */
+#define IXGBE_RTTPCS		0x0CD00
+#define IXGBE_RTRUP2TC		0x03020
+#define IXGBE_RTTUP2TC		0x0C800
+#define IXGBE_RTRPT4C(_i)	(0x02140 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_TXLLQ(_i)		(0x082E0 + ((_i) * 4)) /* 4 of these (0-3) */
+#define IXGBE_RTRPT4S(_i)	(0x02160 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_RTTDT2C(_i)	(0x04910 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_RTTDT2S(_i)	(0x04930 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_RTTPT2C(_i)	(0x0CD20 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_RTTPT2S(_i)	(0x0CD40 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_RTTDQSEL		0x04904
+#define IXGBE_RTTDT1C		0x04908
+#define IXGBE_RTTDT1S		0x0490C
+#define IXGBE_RTTDTECC		0x04990
+#define IXGBE_RTTDTECC_NO_BCN	0x00000100
+
+#define IXGBE_RTTBCNRC			0x04984
+#define IXGBE_RTTBCNRC_RS_ENA		0x80000000
 #define IXGBE_RTTBCNRC_RF_DEC_MASK	0x00003FFF
 #define IXGBE_RTTBCNRC_RF_INT_SHIFT	14
-#define IXGBE_RTTBCNRC_RF_INT_MASK	\
+#define IXGBE_RTTBCNRC_RF_INT_MASK \
 	(IXGBE_RTTBCNRC_RF_DEC_MASK << IXGBE_RTTBCNRC_RF_INT_SHIFT)
-#define IXGBE_RTTBCNRM    0x04980
-#define IXGBE_RTTQCNRM    0x04980
+#define IXGBE_RTTBCNRM	0x04980
 
+/* FCoE DMA Context Registers */
 /* FCoE Direct DMA Context */
 #define IXGBE_FCDDC(_i, _j)	(0x20000 + ((_i) * 0x4) + ((_j) * 0x10))
-/* FCoE DMA Context Registers */
-#define IXGBE_FCPTRL    0x02410 /* FC User Desc. PTR Low */
-#define IXGBE_FCPTRH    0x02414 /* FC USer Desc. PTR High */
-#define IXGBE_FCBUFF    0x02418 /* FC Buffer Control */
-#define IXGBE_FCDMARW   0x02420 /* FC Receive DMA RW */
-#define IXGBE_FCINVST0  0x03FC0 /* FC Invalid DMA Context Status Reg 0 */
-#define IXGBE_FCINVST(_i)       (IXGBE_FCINVST0 + ((_i) * 4))
-#define IXGBE_FCBUFF_VALID      (1 << 0)   /* DMA Context Valid */
-#define IXGBE_FCBUFF_BUFFSIZE   (3 << 3)   /* User Buffer Size */
-#define IXGBE_FCBUFF_WRCONTX    (1 << 7)   /* 0: Initiator, 1: Target */
-#define IXGBE_FCBUFF_BUFFCNT    0x0000ff00 /* Number of User Buffers */
-#define IXGBE_FCBUFF_OFFSET     0xffff0000 /* User Buffer Offset */
-#define IXGBE_FCBUFF_BUFFSIZE_SHIFT  3
-#define IXGBE_FCBUFF_BUFFCNT_SHIFT   8
-#define IXGBE_FCBUFF_OFFSET_SHIFT    16
-#define IXGBE_FCDMARW_WE        (1 << 14)   /* Write enable */
-#define IXGBE_FCDMARW_RE        (1 << 15)   /* Read enable */
-#define IXGBE_FCDMARW_FCOESEL   0x000001ff  /* FC X_ID: 11 bits */
-#define IXGBE_FCDMARW_LASTSIZE  0xffff0000  /* Last User Buffer Size */
-#define IXGBE_FCDMARW_LASTSIZE_SHIFT 16
-
+#define IXGBE_FCPTRL		0x02410 /* FC User Desc. PTR Low */
+#define IXGBE_FCPTRH		0x02414 /* FC USer Desc. PTR High */
+#define IXGBE_FCBUFF		0x02418 /* FC Buffer Control */
+#define IXGBE_FCDMARW		0x02420 /* FC Receive DMA RW */
+#define IXGBE_FCBUFF_VALID	(1 << 0)   /* DMA Context Valid */
+#define IXGBE_FCBUFF_BUFFSIZE	(3 << 3)   /* User Buffer Size */
+#define IXGBE_FCBUFF_WRCONTX	(1 << 7)   /* 0: Initiator, 1: Target */
+#define IXGBE_FCBUFF_BUFFCNT	0x0000ff00 /* Number of User Buffers */
+#define IXGBE_FCBUFF_OFFSET	0xffff0000 /* User Buffer Offset */
+#define IXGBE_FCBUFF_BUFFSIZE_SHIFT	3
+#define IXGBE_FCBUFF_BUFFCNT_SHIFT	8
+#define IXGBE_FCBUFF_OFFSET_SHIFT	16
+#define IXGBE_FCDMARW_WE		(1 << 14)   /* Write enable */
+#define IXGBE_FCDMARW_RE		(1 << 15)   /* Read enable */
+#define IXGBE_FCDMARW_FCOESEL		0x000001ff  /* FC X_ID: 11 bits */
+#define IXGBE_FCDMARW_LASTSIZE		0xffff0000  /* Last User Buffer Size */
+#define IXGBE_FCDMARW_LASTSIZE_SHIFT	16
 /* FCoE SOF/EOF */
-#define IXGBE_TEOFF     0x04A94 /* Tx FC EOF */
-#define IXGBE_TSOFF     0x04A98 /* Tx FC SOF */
-#define IXGBE_REOFF     0x05158 /* Rx FC EOF */
-#define IXGBE_RSOFF     0x051F8 /* Rx FC SOF */
+#define IXGBE_TEOFF		0x04A94 /* Tx FC EOF */
+#define IXGBE_TSOFF		0x04A98 /* Tx FC SOF */
+#define IXGBE_REOFF		0x05158 /* Rx FC EOF */
+#define IXGBE_RSOFF		0x051F8 /* Rx FC SOF */
+/* FCoE Filter Context Registers */
+#define IXGBE_FCD_ID		0x05114 /* FCoE D_ID */
+#define IXGBE_FCSMAC		0x0510C /* FCoE Source MAC */
+#define IXGBE_FCFLTRW_SMAC_HIGH_SHIFT	16
 /* FCoE Direct Filter Context */
 #define IXGBE_FCDFC(_i, _j)	(0x28000 + ((_i) * 0x4) + ((_j) * 0x10))
 #define IXGBE_FCDFCD(_i)	(0x30000 + ((_i) * 0x4))
-/* FCoE Filter Context Registers */
-#define IXGBE_FCFLT     0x05108 /* FC FLT Context */
-#define IXGBE_FCFLTRW   0x05110 /* FC Filter RW Control */
-#define IXGBE_FCPARAM   0x051d8 /* FC Offset Parameter */
-#define IXGBE_FCFLT_VALID       (1 << 0)   /* Filter Context Valid */
-#define IXGBE_FCFLT_FIRST       (1 << 1)   /* Filter First */
-#define IXGBE_FCFLT_SEQID       0x00ff0000 /* Sequence ID */
-#define IXGBE_FCFLT_SEQCNT      0xff000000 /* Sequence Count */
-#define IXGBE_FCFLTRW_RVALDT    (1 << 13)  /* Fast Re-Validation */
-#define IXGBE_FCFLTRW_WE        (1 << 14)  /* Write Enable */
-#define IXGBE_FCFLTRW_RE        (1 << 15)  /* Read Enable */
+#define IXGBE_FCFLT		0x05108 /* FC FLT Context */
+#define IXGBE_FCFLTRW		0x05110 /* FC Filter RW Control */
+#define IXGBE_FCPARAM		0x051d8 /* FC Offset Parameter */
+#define IXGBE_FCFLT_VALID	(1 << 0)   /* Filter Context Valid */
+#define IXGBE_FCFLT_FIRST	(1 << 1)   /* Filter First */
+#define IXGBE_FCFLT_SEQID	0x00ff0000 /* Sequence ID */
+#define IXGBE_FCFLT_SEQCNT	0xff000000 /* Sequence Count */
+#define IXGBE_FCFLTRW_RVALDT	(1 << 13)  /* Fast Re-Validation */
+#define IXGBE_FCFLTRW_WE	(1 << 14)  /* Write Enable */
+#define IXGBE_FCFLTRW_RE	(1 << 15)  /* Read Enable */
 /* FCoE Receive Control */
-#define IXGBE_FCRXCTRL  0x05100 /* FC Receive Control */
-#define IXGBE_FCRXCTRL_FCOELLI  (1 << 0)   /* Low latency interrupt */
-#define IXGBE_FCRXCTRL_SAVBAD   (1 << 1)   /* Save Bad Frames */
-#define IXGBE_FCRXCTRL_FRSTRDH  (1 << 2)   /* EN 1st Read Header */
-#define IXGBE_FCRXCTRL_LASTSEQH (1 << 3)   /* EN Last Header in Seq */
-#define IXGBE_FCRXCTRL_ALLH     (1 << 4)   /* EN All Headers */
-#define IXGBE_FCRXCTRL_FRSTSEQH (1 << 5)   /* EN 1st Seq. Header */
-#define IXGBE_FCRXCTRL_ICRC     (1 << 6)   /* Ignore Bad FC CRC */
-#define IXGBE_FCRXCTRL_FCCRCBO  (1 << 7)   /* FC CRC Byte Ordering */
-#define IXGBE_FCRXCTRL_FCOEVER  0x00000f00 /* FCoE Version: 4 bits */
-#define IXGBE_FCRXCTRL_FCOEVER_SHIFT 8
+#define IXGBE_FCRXCTRL		0x05100 /* FC Receive Control */
+#define IXGBE_FCRXCTRL_FCOELLI	(1 << 0)   /* Low latency interrupt */
+#define IXGBE_FCRXCTRL_SAVBAD	(1 << 1)   /* Save Bad Frames */
+#define IXGBE_FCRXCTRL_FRSTRDH	(1 << 2)   /* EN 1st Read Header */
+#define IXGBE_FCRXCTRL_LASTSEQH	(1 << 3)   /* EN Last Header in Seq */
+#define IXGBE_FCRXCTRL_ALLH	(1 << 4)   /* EN All Headers */
+#define IXGBE_FCRXCTRL_FRSTSEQH	(1 << 5)   /* EN 1st Seq. Header */
+#define IXGBE_FCRXCTRL_ICRC	(1 << 6)   /* Ignore Bad FC CRC */
+#define IXGBE_FCRXCTRL_FCCRCBO	(1 << 7)   /* FC CRC Byte Ordering */
+#define IXGBE_FCRXCTRL_FCOEVER	0x00000f00 /* FCoE Version: 4 bits */
+#define IXGBE_FCRXCTRL_FCOEVER_SHIFT	8
 /* FCoE Redirection */
-#define IXGBE_FCRECTL   0x0ED00 /* FC Redirection Control */
-#define IXGBE_FCRETA0   0x0ED10 /* FC Redirection Table 0 */
-#define IXGBE_FCRETA(_i)        (IXGBE_FCRETA0 + ((_i) * 4)) /* FCoE Redir */
-#define IXGBE_FCRECTL_ENA       0x1        /* FCoE Redir Table Enable */
-#define IXGBE_FCRETA_SIZE       8          /* Max entries in FCRETA */
-#define IXGBE_FCRETA_ENTRY_MASK 0x0000007f /* 7 bits for the queue index */
+#define IXGBE_FCRECTL		0x0ED00 /* FC Redirection Control */
+#define IXGBE_FCRETA0		0x0ED10 /* FC Redirection Table 0 */
+#define IXGBE_FCRETA(_i)	(IXGBE_FCRETA0 + ((_i) * 4)) /* FCoE Redir */
+#define IXGBE_FCRECTL_ENA	0x1 /* FCoE Redir Table Enable */
+#define IXGBE_FCRETASEL_ENA	0x2 /* FCoE FCRETASEL bit */
+#define IXGBE_FCRETA_SIZE	8 /* Max entries in FCRETA */
+#define IXGBE_FCRETA_ENTRY_MASK	0x0000007f /* 7 bits for the queue index */
 #define IXGBE_FCRETA_SIZE_X550	32 /* Max entries in FCRETA */
 /* Higher 7 bits for the queue index */
 #define IXGBE_FCRETA_ENTRY_HIGH_MASK	0x007F0000
 #define IXGBE_FCRETA_ENTRY_HIGH_SHIFT	16
 
 /* Stats registers */
-#define IXGBE_CRCERRS   0x04000
-#define IXGBE_ILLERRC   0x04004
-#define IXGBE_ERRBC     0x04008
-#define IXGBE_MSPDC     0x04010
-#define IXGBE_MPC(_i)   (0x03FA0 + ((_i) * 4)) /* 8 of these 3FA0-3FBC*/
-#define IXGBE_MLFC      0x04034
-#define IXGBE_MRFC      0x04038
-#define IXGBE_RLEC      0x04040
-#define IXGBE_LXONTXC   0x03F60
-#define IXGBE_LXONRXC   0x0CF60
-#define IXGBE_LXOFFTXC  0x03F68
-#define IXGBE_LXOFFRXC  0x0CF68
-#define IXGBE_LXONRXCNT 0x041A4
-#define IXGBE_LXOFFRXCNT 0x041A8
-#define IXGBE_PXONRXCNT(_i)     (0x04140 + ((_i) * 4)) /* 8 of these */
-#define IXGBE_PXOFFRXCNT(_i)    (0x04160 + ((_i) * 4)) /* 8 of these */
-#define IXGBE_PXON2OFFCNT(_i)   (0x03240 + ((_i) * 4)) /* 8 of these */
-#define IXGBE_PXONTXC(_i)       (0x03F00 + ((_i) * 4)) /* 8 of these 3F00-3F1C*/
-#define IXGBE_PXONRXC(_i)       (0x0CF00 + ((_i) * 4)) /* 8 of these CF00-CF1C*/
-#define IXGBE_PXOFFTXC(_i)      (0x03F20 + ((_i) * 4)) /* 8 of these 3F20-3F3C*/
-#define IXGBE_PXOFFRXC(_i)      (0x0CF20 + ((_i) * 4)) /* 8 of these CF20-CF3C*/
-#define IXGBE_PRC64     0x0405C
-#define IXGBE_PRC127    0x04060
-#define IXGBE_PRC255    0x04064
-#define IXGBE_PRC511    0x04068
-#define IXGBE_PRC1023   0x0406C
-#define IXGBE_PRC1522   0x04070
-#define IXGBE_GPRC      0x04074
-#define IXGBE_BPRC      0x04078
-#define IXGBE_MPRC      0x0407C
-#define IXGBE_GPTC      0x04080
-#define IXGBE_GORCL     0x04088
-#define IXGBE_GORCH     0x0408C
-#define IXGBE_GOTCL     0x04090
-#define IXGBE_GOTCH     0x04094
-#define IXGBE_RNBC(_i)  (0x03FC0 + ((_i) * 4)) /* 8 of these 3FC0-3FDC*/
-#define IXGBE_RUC       0x040A4
-#define IXGBE_RFC       0x040A8
-#define IXGBE_ROC       0x040AC
-#define IXGBE_RJC       0x040B0
-#define IXGBE_MNGPRC    0x040B4
-#define IXGBE_MNGPDC    0x040B8
-#define IXGBE_MNGPTC    0x0CF90
-#define IXGBE_TORL      0x040C0
-#define IXGBE_TORH      0x040C4
-#define IXGBE_TPR       0x040D0
-#define IXGBE_TPT       0x040D4
-#define IXGBE_PTC64     0x040D8
-#define IXGBE_PTC127    0x040DC
-#define IXGBE_PTC255    0x040E0
-#define IXGBE_PTC511    0x040E4
-#define IXGBE_PTC1023   0x040E8
-#define IXGBE_PTC1522   0x040EC
-#define IXGBE_MPTC      0x040F0
-#define IXGBE_BPTC      0x040F4
-#define IXGBE_XEC       0x04120
-#define IXGBE_SSVPC     0x08780
-
-#define IXGBE_RQSMR(_i) (0x02300 + ((_i) * 4))
-#define IXGBE_TQSMR(_i) (((_i) <= 7) ? (0x07300 + ((_i) * 4)) : \
+#define IXGBE_CRCERRS	0x04000
+#define IXGBE_ILLERRC	0x04004
+#define IXGBE_ERRBC	0x04008
+#define IXGBE_MSPDC	0x04010
+#define IXGBE_MPC(_i)	(0x03FA0 + ((_i) * 4)) /* 8 of these 3FA0-3FBC*/
+#define IXGBE_MLFC	0x04034
+#define IXGBE_MRFC	0x04038
+#define IXGBE_RLEC	0x04040
+#define IXGBE_LXONTXC	0x03F60
+#define IXGBE_LXONRXC	0x0CF60
+#define IXGBE_LXOFFTXC	0x03F68
+#define IXGBE_LXOFFRXC	0x0CF68
+#define IXGBE_LXONRXCNT		0x041A4
+#define IXGBE_LXOFFRXCNT	0x041A8
+#define IXGBE_PXONRXCNT(_i)	(0x04140 + ((_i) * 4)) /* 8 of these */
+#define IXGBE_PXOFFRXCNT(_i)	(0x04160 + ((_i) * 4)) /* 8 of these */
+#define IXGBE_PXON2OFFCNT(_i)	(0x03240 + ((_i) * 4)) /* 8 of these */
+#define IXGBE_PXONTXC(_i)	(0x03F00 + ((_i) * 4)) /* 8 of these 3F00-3F1C*/
+#define IXGBE_PXONRXC(_i)	(0x0CF00 + ((_i) * 4)) /* 8 of these CF00-CF1C*/
+#define IXGBE_PXOFFTXC(_i)	(0x03F20 + ((_i) * 4)) /* 8 of these 3F20-3F3C*/
+#define IXGBE_PXOFFRXC(_i)	(0x0CF20 + ((_i) * 4)) /* 8 of these CF20-CF3C*/
+#define IXGBE_PRC64		0x0405C
+#define IXGBE_PRC127		0x04060
+#define IXGBE_PRC255		0x04064
+#define IXGBE_PRC511		0x04068
+#define IXGBE_PRC1023		0x0406C
+#define IXGBE_PRC1522		0x04070
+#define IXGBE_GPRC		0x04074
+#define IXGBE_BPRC		0x04078
+#define IXGBE_MPRC		0x0407C
+#define IXGBE_GPTC		0x04080
+#define IXGBE_GORCL		0x04088
+#define IXGBE_GORCH		0x0408C
+#define IXGBE_GOTCL		0x04090
+#define IXGBE_GOTCH		0x04094
+#define IXGBE_RNBC(_i)		(0x03FC0 + ((_i) * 4)) /* 8 of these 3FC0-3FDC*/
+#define IXGBE_RUC		0x040A4
+#define IXGBE_RFC		0x040A8
+#define IXGBE_ROC		0x040AC
+#define IXGBE_RJC		0x040B0
+#define IXGBE_MNGPRC		0x040B4
+#define IXGBE_MNGPDC		0x040B8
+#define IXGBE_MNGPTC		0x0CF90
+#define IXGBE_TORL		0x040C0
+#define IXGBE_TORH		0x040C4
+#define IXGBE_TPR		0x040D0
+#define IXGBE_TPT		0x040D4
+#define IXGBE_PTC64		0x040D8
+#define IXGBE_PTC127		0x040DC
+#define IXGBE_PTC255		0x040E0
+#define IXGBE_PTC511		0x040E4
+#define IXGBE_PTC1023		0x040E8
+#define IXGBE_PTC1522		0x040EC
+#define IXGBE_MPTC		0x040F0
+#define IXGBE_BPTC		0x040F4
+#define IXGBE_XEC		0x04120
+#define IXGBE_SSVPC		0x08780
+
+#define IXGBE_RQSMR(_i)	(0x02300 + ((_i) * 4))
+#define IXGBE_TQSMR(_i)	(((_i) <= 7) ? (0x07300 + ((_i) * 4)) : \
 			 (0x08600 + ((_i) * 4)))
-#define IXGBE_TQSM(_i)  (0x08600 + ((_i) * 4))
-
-#define IXGBE_QPRC(_i) (0x01030 + ((_i) * 0x40)) /* 16 of these */
-#define IXGBE_QPTC(_i) (0x06030 + ((_i) * 0x40)) /* 16 of these */
-#define IXGBE_QBRC(_i) (0x01034 + ((_i) * 0x40)) /* 16 of these */
-#define IXGBE_QBTC(_i) (0x06034 + ((_i) * 0x40)) /* 16 of these */
-#define IXGBE_QBRC_L(_i) (0x01034 + ((_i) * 0x40)) /* 16 of these */
-#define IXGBE_QBRC_H(_i) (0x01038 + ((_i) * 0x40)) /* 16 of these */
-#define IXGBE_QPRDC(_i) (0x01430 + ((_i) * 0x40)) /* 16 of these */
-#define IXGBE_QBTC_L(_i) (0x08700 + ((_i) * 0x8)) /* 16 of these */
-#define IXGBE_QBTC_H(_i) (0x08704 + ((_i) * 0x8)) /* 16 of these */
-#define IXGBE_FCCRC     0x05118 /* Count of Good Eth CRC w/ Bad FC CRC */
-#define IXGBE_FCOERPDC  0x0241C /* FCoE Rx Packets Dropped Count */
-#define IXGBE_FCLAST    0x02424 /* FCoE Last Error Count */
-#define IXGBE_FCOEPRC   0x02428 /* Number of FCoE Packets Received */
-#define IXGBE_FCOEDWRC  0x0242C /* Number of FCoE DWords Received */
-#define IXGBE_FCOEPTC   0x08784 /* Number of FCoE Packets Transmitted */
-#define IXGBE_FCOEDWTC  0x08788 /* Number of FCoE DWords Transmitted */
-#define IXGBE_O2BGPTC   0x041C4
-#define IXGBE_O2BSPC    0x087B0
-#define IXGBE_B2OSPC    0x041C0
-#define IXGBE_B2OGPRC   0x02F90
-#define IXGBE_PCRC8ECL  0x0E810
-#define IXGBE_PCRC8ECH  0x0E811
-#define IXGBE_PCRC8ECH_MASK     0x1F
-#define IXGBE_LDPCECL   0x0E820
-#define IXGBE_LDPCECH   0x0E821
-
-/* MII clause 22/28 definitions */
-#define IXGBE_MDIO_PHY_LOW_POWER_MODE	0x0800
-
-#define IXGBE_MDIO_XENPAK_LASI_STATUS	0x9005 /* XENPAK LASI Status register */
-#define IXGBE_XENPAK_LASI_LINK_STATUS_ALARM 0x1 /* Link Status Alarm change */
-
-#define IXGBE_MDIO_AUTO_NEG_LINK_STATUS	0x4 /* Indicates if link is up */
-
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_MASK	0x7 /* Speed/Duplex Mask */
-#define IXGBE_MDIO_AUTO_NEG_VEN_STAT_SPEED_MASK	0x6 /* Speed Mask */
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10M_HALF 0x0 /* 10Mb/s Half Duplex */
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10M_FULL 0x1 /* 10Mb/s Full Duplex */
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_100M_HALF 0x2 /* 100Mb/s H Duplex */
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_100M_FULL 0x3 /* 100Mb/s F Duplex */
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_1GB_HALF 0x4 /* 1Gb/s Half Duplex */
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_1GB_FULL 0x5 /* 1Gb/s Full Duplex */
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10GB_HALF 0x6 /* 10Gb/s Half Duplex */
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10GB_FULL 0x7 /* 10Gb/s Full Duplex */
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_1GB	0x4 /* 1Gb/s */
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10GB	0x6 /* 10Gb/s */
-
-#define IXGBE_MII_10GBASE_T_AUTONEG_CTRL_REG	0x20	/* 10G Control Reg */
-#define IXGBE_MII_AUTONEG_VENDOR_PROVISION_1_REG 0xC400	/* 1G Provisioning 1 */
-#define IXGBE_MII_AUTONEG_XNP_TX_REG		0x17	/* 1G XNP Transmit */
-#define IXGBE_MII_AUTONEG_ADVERTISE_REG		0x10	/* 100M Advertisement */
-#define IXGBE_MII_10GBASE_T_ADVERTISE		0x1000	/* full duplex, bit:12*/
-#define IXGBE_MII_1GBASE_T_ADVERTISE_XNP_TX	0x4000	/* full duplex, bit:14*/
-#define IXGBE_MII_1GBASE_T_ADVERTISE		0x8000	/* full duplex, bit:15*/
-#define IXGBE_MII_2_5GBASE_T_ADVERTISE		0x0400
-#define IXGBE_MII_5GBASE_T_ADVERTISE		0x0800
-#define IXGBE_MII_100BASE_T_ADVERTISE		0x0100	/* full duplex, bit:8 */
-#define IXGBE_MII_100BASE_T_ADVERTISE_HALF	0x0080	/* half duplex, bit:7 */
-#define IXGBE_MII_RESTART			0x200
-#define IXGBE_MII_AUTONEG_COMPLETE		0x20
-#define IXGBE_MII_AUTONEG_LINK_UP		0x04
-#define IXGBE_MII_AUTONEG_REG			0x0
+#define IXGBE_TQSM(_i)	(0x08600 + ((_i) * 4))
+
+#define IXGBE_QPRC(_i)	(0x01030 + ((_i) * 0x40)) /* 16 of these */
+#define IXGBE_QPTC(_i)	(0x06030 + ((_i) * 0x40)) /* 16 of these */
+#define IXGBE_QBRC(_i)	(0x01034 + ((_i) * 0x40)) /* 16 of these */
+#define IXGBE_QBTC(_i)	(0x06034 + ((_i) * 0x40)) /* 16 of these */
+#define IXGBE_QBRC_L(_i)	(0x01034 + ((_i) * 0x40)) /* 16 of these */
+#define IXGBE_QBRC_H(_i)	(0x01038 + ((_i) * 0x40)) /* 16 of these */
+#define IXGBE_QPRDC(_i)		(0x01430 + ((_i) * 0x40)) /* 16 of these */
+#define IXGBE_QBTC_L(_i)	(0x08700 + ((_i) * 0x8)) /* 16 of these */
+#define IXGBE_QBTC_H(_i)	(0x08704 + ((_i) * 0x8)) /* 16 of these */
+#define IXGBE_FCCRC		0x05118 /* Num of Good Eth CRC w/ Bad FC CRC */
+#define IXGBE_FCOERPDC		0x0241C /* FCoE Rx Packets Dropped Count */
+#define IXGBE_FCLAST		0x02424 /* FCoE Last Error Count */
+#define IXGBE_FCOEPRC		0x02428 /* Number of FCoE Packets Received */
+#define IXGBE_FCOEDWRC		0x0242C /* Number of FCoE DWords Received */
+#define IXGBE_FCOEPTC		0x08784 /* Number of FCoE Packets Transmitted */
+#define IXGBE_FCOEDWTC		0x08788 /* Number of FCoE DWords Transmitted */
+#define IXGBE_FCCRC_CNT_MASK	0x0000FFFF /* CRC_CNT: bit 0 - 15 */
+#define IXGBE_FCLAST_CNT_MASK	0x0000FFFF /* Last_CNT: bit 0 - 15 */
+#define IXGBE_O2BGPTC		0x041C4
+#define IXGBE_O2BSPC		0x087B0
+#define IXGBE_B2OSPC		0x041C0
+#define IXGBE_B2OGPRC		0x02F90
+#define IXGBE_BUPRC		0x04180
+#define IXGBE_BMPRC		0x04184
+#define IXGBE_BBPRC		0x04188
+#define IXGBE_BUPTC		0x0418C
+#define IXGBE_BMPTC		0x04190
+#define IXGBE_BBPTC		0x04194
+#define IXGBE_BCRCERRS		0x04198
+#define IXGBE_BXONRXC		0x0419C
+#define IXGBE_BXOFFRXC		0x041E0
+#define IXGBE_BXONTXC		0x041E4
+#define IXGBE_BXOFFTXC		0x041E8
 
 /* Management */
-#define IXGBE_MAVTV(_i) (0x05010 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_MFUTP(_i) (0x05030 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_MANC      0x05820
-#define IXGBE_MFVAL     0x05824
-#define IXGBE_MANC2H    0x05860
-#define IXGBE_MDEF(_i)  (0x05890 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_MIPAF     0x058B0
-#define IXGBE_MMAL(_i)  (0x05910 + ((_i) * 8)) /* 4 of these (0-3) */
-#define IXGBE_MMAH(_i)  (0x05914 + ((_i) * 8)) /* 4 of these (0-3) */
-#define IXGBE_FTFT      0x09400 /* 0x9400-0x97FC */
-#define IXGBE_METF(_i)  (0x05190 + ((_i) * 4)) /* 4 of these (0-3) */
-#define IXGBE_MDEF_EXT(_i) (0x05160 + ((_i) * 4)) /* 8 of these (0-7) */
-#define IXGBE_LSWFW     0x15014
+#define IXGBE_MAVTV(_i)		(0x05010 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_MFUTP(_i)		(0x05030 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_MANC		0x05820
+#define IXGBE_MFVAL		0x05824
+#define IXGBE_MANC2H		0x05860
+#define IXGBE_MDEF(_i)		(0x05890 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_MIPAF		0x058B0
+#define IXGBE_MMAL(_i)		(0x05910 + ((_i) * 8)) /* 4 of these (0-3) */
+#define IXGBE_MMAH(_i)		(0x05914 + ((_i) * 8)) /* 4 of these (0-3) */
+#define IXGBE_FTFT		0x09400 /* 0x9400-0x97FC */
+#define IXGBE_METF(_i)		(0x05190 + ((_i) * 4)) /* 4 of these (0-3) */
+#define IXGBE_MDEF_EXT(_i)	(0x05160 + ((_i) * 4)) /* 8 of these (0-7) */
+#define IXGBE_LSWFW		0x15F14
+#define IXGBE_BMCIP(_i)		(0x05050 + ((_i) * 4)) /* 0x5050-0x505C */
+#define IXGBE_BMCIPVAL		0x05060
+#define IXGBE_BMCIP_IPADDR_TYPE	0x00000001
+#define IXGBE_BMCIP_IPADDR_VALID	0x00000002
 
 /* Management Bit Fields and Masks */
+#define IXGBE_MANC_MPROXYE	0x40000000 /* Management Proxy Enable */
 #define IXGBE_MANC_RCV_TCO_EN	0x00020000 /* Rcv TCO packet enable */
+#define IXGBE_MANC_EN_BMC2OS	0x10000000 /* Ena BMC2OS and OS2BMC traffic */
+#define IXGBE_MANC_EN_BMC2OS_SHIFT	28
 
 /* Firmware Semaphore Register */
 #define IXGBE_FWSM_MODE_MASK	0xE
+#define IXGBE_FWSM_TS_ENABLED	0x1
 #define IXGBE_FWSM_FW_MODE_PT	0x4
 
 /* ARC Subsystem registers */
-#define IXGBE_HICR      0x15F00
-#define IXGBE_FWSTS     0x15F0C
-#define IXGBE_HSMC0R    0x15F04
-#define IXGBE_HSMC1R    0x15F08
-#define IXGBE_SWSR      0x15F10
-#define IXGBE_HFDR      0x15FE8
-#define IXGBE_FLEX_MNG  0x15800 /* 0x15800 - 0x15EFC */
-
-#define IXGBE_HICR_EN              0x01  /* Enable bit - RO */
+#define IXGBE_HICR		0x15F00
+#define IXGBE_FWSTS		0x15F0C
+#define IXGBE_HSMC0R		0x15F04
+#define IXGBE_HSMC1R		0x15F08
+#define IXGBE_SWSR		0x15F10
+#define IXGBE_HFDR		0x15FE8
+#define IXGBE_FLEX_MNG		0x15800 /* 0x15800 - 0x15EFC */
+
+#define IXGBE_HICR_EN		0x01  /* Enable bit - RO */
 /* Driver sets this bit when done to put command in RAM */
-#define IXGBE_HICR_C               0x02
-#define IXGBE_HICR_SV              0x04  /* Status Validity */
-#define IXGBE_HICR_FW_RESET_ENABLE 0x40
-#define IXGBE_HICR_FW_RESET        0x80
+#define IXGBE_HICR_C		0x02
+#define IXGBE_HICR_SV		0x04  /* Status Validity */
+#define IXGBE_HICR_FW_RESET_ENABLE	0x40
+#define IXGBE_HICR_FW_RESET	0x80
 
 /* PCI-E registers */
-#define IXGBE_GCR       0x11000
-#define IXGBE_GTV       0x11004
-#define IXGBE_FUNCTAG   0x11008
-#define IXGBE_GLT       0x1100C
-#define IXGBE_GSCL_1    0x11010
-#define IXGBE_GSCL_2    0x11014
-#define IXGBE_GSCL_3    0x11018
-#define IXGBE_GSCL_4    0x1101C
-#define IXGBE_GSCN_0    0x11020
-#define IXGBE_GSCN_1    0x11024
-#define IXGBE_GSCN_2    0x11028
-#define IXGBE_GSCN_3    0x1102C
-#define IXGBE_FACTPS_8259X	0x10150
-#define IXGBE_FACTPS_X540	IXGBE_FACTPS_8259X
-#define IXGBE_FACTPS_X550	IXGBE_FACTPS_8259X
-#define IXGBE_FACTPS_X550EM_x	IXGBE_FACTPS_8259X
+#define IXGBE_GCR		0x11000
+#define IXGBE_GTV		0x11004
+#define IXGBE_FUNCTAG		0x11008
+#define IXGBE_GLT		0x1100C
+#define IXGBE_PCIEPIPEADR	0x11004
+#define IXGBE_PCIEPIPEDAT	0x11008
+#define IXGBE_GSCL_1		0x11010
+#define IXGBE_GSCL_2		0x11014
+#define IXGBE_GSCL_1_X540	IXGBE_GSCL_1
+#define IXGBE_GSCL_2_X540	IXGBE_GSCL_2
+#define IXGBE_GSCL_3		0x11018
+#define IXGBE_GSCL_4		0x1101C
+#define IXGBE_GSCN_0		0x11020
+#define IXGBE_GSCN_1		0x11024
+#define IXGBE_GSCN_2		0x11028
+#define IXGBE_GSCN_3		0x1102C
+#define IXGBE_GSCN_0_X540	IXGBE_GSCN_0
+#define IXGBE_GSCN_1_X540	IXGBE_GSCN_1
+#define IXGBE_GSCN_2_X540	IXGBE_GSCN_2
+#define IXGBE_GSCN_3_X540	IXGBE_GSCN_3
+#define IXGBE_FACTPS		0x10150
+#define IXGBE_FACTPS_X540	IXGBE_FACTPS
+#define IXGBE_GSCL_1_X550	0x11800
+#define IXGBE_GSCL_2_X550	0x11804
+#define IXGBE_GSCL_1_X550EM_x	IXGBE_GSCL_1_X550
+#define IXGBE_GSCL_2_X550EM_x	IXGBE_GSCL_2_X550
+#define IXGBE_GSCN_0_X550	0x11820
+#define IXGBE_GSCN_1_X550	0x11824
+#define IXGBE_GSCN_2_X550	0x11828
+#define IXGBE_GSCN_3_X550	0x1182C
+#define IXGBE_GSCN_0_X550EM_x	IXGBE_GSCN_0_X550
+#define IXGBE_GSCN_1_X550EM_x	IXGBE_GSCN_1_X550
+#define IXGBE_GSCN_2_X550EM_x	IXGBE_GSCN_2_X550
+#define IXGBE_GSCN_3_X550EM_x	IXGBE_GSCN_3_X550
+#define IXGBE_FACTPS_X550	IXGBE_FACTPS
+#define IXGBE_FACTPS_X550EM_x	IXGBE_FACTPS
+#define IXGBE_GSCL_1_X550EM_a	IXGBE_GSCL_1_X550
+#define IXGBE_GSCL_2_X550EM_a	IXGBE_GSCL_2_X550
+#define IXGBE_GSCN_0_X550EM_a	IXGBE_GSCN_0_X550
+#define IXGBE_GSCN_1_X550EM_a	IXGBE_GSCN_1_X550
+#define IXGBE_GSCN_2_X550EM_a	IXGBE_GSCN_2_X550
+#define IXGBE_GSCN_3_X550EM_a	IXGBE_GSCN_3_X550
 #define IXGBE_FACTPS_X550EM_a	0x15FEC
-#define IXGBE_FACTPS(_hw)	IXGBE_BY_MAC((_hw), FACTPS)
+#define IXGBE_FACTPS_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), FACTPS)
 
-#define IXGBE_PCIEANACTL  0x11040
-#define IXGBE_SWSM_8259X	0x10140
-#define IXGBE_SWSM_X540		IXGBE_SWSM_8259X
-#define IXGBE_SWSM_X550		IXGBE_SWSM_8259X
-#define IXGBE_SWSM_X550EM_x	IXGBE_SWSM_8259X
+#define IXGBE_PCIEANACTL	0x11040
+#define IXGBE_SWSM		0x10140
+#define IXGBE_SWSM_X540		IXGBE_SWSM
+#define IXGBE_SWSM_X550		IXGBE_SWSM
+#define IXGBE_SWSM_X550EM_x	IXGBE_SWSM
 #define IXGBE_SWSM_X550EM_a	0x15F70
-#define IXGBE_SWSM(_hw)		IXGBE_BY_MAC((_hw), SWSM)
-#define IXGBE_FWSM_8259X	0x10148
-#define IXGBE_FWSM_X540		IXGBE_FWSM_8259X
-#define IXGBE_FWSM_X550		IXGBE_FWSM_8259X
-#define IXGBE_FWSM_X550EM_x	IXGBE_FWSM_8259X
+#define IXGBE_SWSM_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), SWSM)
+
+#define IXGBE_FWSM		0x10148
+#define IXGBE_FWSM_X540		IXGBE_FWSM
+#define IXGBE_FWSM_X550		IXGBE_FWSM
+#define IXGBE_FWSM_X550EM_x	IXGBE_FWSM
 #define IXGBE_FWSM_X550EM_a	0x15F74
-#define IXGBE_FWSM(_hw)		IXGBE_BY_MAC((_hw), FWSM)
-#define IXGBE_GSSR      0x10160
-#define IXGBE_MREVID    0x11064
-#define IXGBE_DCA_ID    0x11070
-#define IXGBE_DCA_CTRL  0x11074
-#define IXGBE_SWFW_SYNC_8259X		IXGBE_GSSR
-#define IXGBE_SWFW_SYNC_X540		IXGBE_SWFW_SYNC_8259X
-#define IXGBE_SWFW_SYNC_X550		IXGBE_SWFW_SYNC_8259X
-#define IXGBE_SWFW_SYNC_X550EM_x	IXGBE_SWFW_SYNC_8259X
+#define IXGBE_FWSM_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), FWSM)
+
+#define IXGBE_SWFW_SYNC		IXGBE_GSSR
+#define IXGBE_SWFW_SYNC_X540	IXGBE_SWFW_SYNC
+#define IXGBE_SWFW_SYNC_X550	IXGBE_SWFW_SYNC
+#define IXGBE_SWFW_SYNC_X550EM_x	IXGBE_SWFW_SYNC
 #define IXGBE_SWFW_SYNC_X550EM_a	0x15F78
-#define IXGBE_SWFW_SYNC(_hw)		IXGBE_BY_MAC((_hw), SWFW_SYNC)
-
-/* PCIe registers 82599-specific */
-#define IXGBE_GCR_EXT           0x11050
-#define IXGBE_GSCL_5_82599      0x11030
-#define IXGBE_GSCL_6_82599      0x11034
-#define IXGBE_GSCL_7_82599      0x11038
-#define IXGBE_GSCL_8_82599      0x1103C
-#define IXGBE_PHYADR_82599      0x11040
-#define IXGBE_PHYDAT_82599      0x11044
-#define IXGBE_PHYCTL_82599      0x11048
-#define IXGBE_PBACLR_82599      0x11068
-
-#define IXGBE_CIAA_8259X	0x11088
-#define IXGBE_CIAA_X540		IXGBE_CIAA_8259X
+#define IXGBE_SWFW_SYNC_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), SWFW_SYNC)
+
+#define IXGBE_GSSR		0x10160
+#define IXGBE_MREVID		0x11064
+#define IXGBE_DCA_ID		0x11070
+#define IXGBE_DCA_CTRL		0x11074
+
+/* PCI-E registers 82599-Specific */
+#define IXGBE_GCR_EXT		0x11050
+#define IXGBE_GSCL_5_82599	0x11030
+#define IXGBE_GSCL_6_82599	0x11034
+#define IXGBE_GSCL_7_82599	0x11038
+#define IXGBE_GSCL_8_82599	0x1103C
+#define IXGBE_GSCL_5_X540	IXGBE_GSCL_5_82599
+#define IXGBE_GSCL_6_X540	IXGBE_GSCL_6_82599
+#define IXGBE_GSCL_7_X540	IXGBE_GSCL_7_82599
+#define IXGBE_GSCL_8_X540	IXGBE_GSCL_8_82599
+#define IXGBE_PHYADR_82599	0x11040
+#define IXGBE_PHYDAT_82599	0x11044
+#define IXGBE_PHYCTL_82599	0x11048
+#define IXGBE_PBACLR_82599	0x11068
+#define IXGBE_CIAA		0x11088
+#define IXGBE_CIAD		0x1108C
+#define IXGBE_CIAA_82599	IXGBE_CIAA
+#define IXGBE_CIAD_82599	IXGBE_CIAD
+#define IXGBE_CIAA_X540		IXGBE_CIAA
+#define IXGBE_CIAD_X540		IXGBE_CIAD
+#define IXGBE_GSCL_5_X550	0x11810
+#define IXGBE_GSCL_6_X550	0x11814
+#define IXGBE_GSCL_7_X550	0x11818
+#define IXGBE_GSCL_8_X550	0x1181C
+#define IXGBE_GSCL_5_X550EM_x	IXGBE_GSCL_5_X550
+#define IXGBE_GSCL_6_X550EM_x	IXGBE_GSCL_6_X550
+#define IXGBE_GSCL_7_X550EM_x	IXGBE_GSCL_7_X550
+#define IXGBE_GSCL_8_X550EM_x	IXGBE_GSCL_8_X550
 #define IXGBE_CIAA_X550		0x11508
-#define IXGBE_CIAA_X550EM_x	IXGBE_CIAA_X550
-#define IXGBE_CIAA_X550EM_a	IXGBE_CIAA_X550
-#define IXGBE_CIAA(_hw)		IXGBE_BY_MAC((_hw), CIAA)
-
-#define IXGBE_CIAD_8259X	0x1108C
-#define IXGBE_CIAD_X540		IXGBE_CIAD_8259X
 #define IXGBE_CIAD_X550		0x11510
+#define IXGBE_CIAA_X550EM_x	IXGBE_CIAA_X550
 #define IXGBE_CIAD_X550EM_x	IXGBE_CIAD_X550
+#define IXGBE_GSCL_5_X550EM_a	IXGBE_GSCL_5_X550
+#define IXGBE_GSCL_6_X550EM_a	IXGBE_GSCL_6_X550
+#define IXGBE_GSCL_7_X550EM_a	IXGBE_GSCL_7_X550
+#define IXGBE_GSCL_8_X550EM_a	IXGBE_GSCL_8_X550
+#define IXGBE_CIAA_X550EM_a	IXGBE_CIAA_X550
 #define IXGBE_CIAD_X550EM_a	IXGBE_CIAD_X550
-#define IXGBE_CIAD(_hw)		IXGBE_BY_MAC((_hw), CIAD)
-
-#define IXGBE_PICAUSE           0x110B0
-#define IXGBE_PIENA             0x110B8
-#define IXGBE_CDQ_MBR_82599     0x110B4
-#define IXGBE_PCIESPARE         0x110BC
-#define IXGBE_MISC_REG_82599    0x110F0
-#define IXGBE_ECC_CTRL_0_82599  0x11100
-#define IXGBE_ECC_CTRL_1_82599  0x11104
-#define IXGBE_ECC_STATUS_82599  0x110E0
-#define IXGBE_BAR_CTRL_82599    0x110F4
+#define IXGBE_CIAA_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), CIAA)
+#define IXGBE_CIAD_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), CIAD)
+#define IXGBE_PICAUSE		0x110B0
+#define IXGBE_PIENA		0x110B8
+#define IXGBE_CDQ_MBR_82599	0x110B4
+#define IXGBE_PCIESPARE		0x110BC
+#define IXGBE_MISC_REG_82599	0x110F0
+#define IXGBE_ECC_CTRL_0_82599	0x11100
+#define IXGBE_ECC_CTRL_1_82599	0x11104
+#define IXGBE_ECC_STATUS_82599	0x110E0
+#define IXGBE_BAR_CTRL_82599	0x110F4
 
 /* PCI Express Control */
-#define IXGBE_GCR_CMPL_TMOUT_MASK       0x0000F000
-#define IXGBE_GCR_CMPL_TMOUT_10ms       0x00001000
-#define IXGBE_GCR_CMPL_TMOUT_RESEND     0x00010000
-#define IXGBE_GCR_CAP_VER2              0x00040000
-
-#define IXGBE_GCR_EXT_MSIX_EN           0x80000000
-#define IXGBE_GCR_EXT_BUFFERS_CLEAR     0x40000000
-#define IXGBE_GCR_EXT_VT_MODE_16        0x00000001
-#define IXGBE_GCR_EXT_VT_MODE_32        0x00000002
-#define IXGBE_GCR_EXT_VT_MODE_64        0x00000003
-#define IXGBE_GCR_EXT_SRIOV             (IXGBE_GCR_EXT_MSIX_EN | \
+#define IXGBE_GCR_CMPL_TMOUT_MASK	0x0000F000
+#define IXGBE_GCR_CMPL_TMOUT_10ms	0x00001000
+#define IXGBE_GCR_CMPL_TMOUT_RESEND	0x00010000
+#define IXGBE_GCR_CAP_VER2		0x00040000
+
+#define IXGBE_GCR_EXT_MSIX_EN		0x80000000
+#define IXGBE_GCR_EXT_BUFFERS_CLEAR	0x40000000
+#define IXGBE_GCR_EXT_VT_MODE_16	0x00000001
+#define IXGBE_GCR_EXT_VT_MODE_32	0x00000002
+#define IXGBE_GCR_EXT_VT_MODE_64	0x00000003
+#define IXGBE_GCR_EXT_SRIOV		(IXGBE_GCR_EXT_MSIX_EN | \
 					 IXGBE_GCR_EXT_VT_MODE_64)
-
+#define IXGBE_GCR_EXT_VT_MODE_MASK	0x00000003
 /* Time Sync Registers */
-#define IXGBE_TSYNCRXCTL 0x05188 /* Rx Time Sync Control register - RW */
-#define IXGBE_TSYNCTXCTL 0x08C00 /* Tx Time Sync Control register - RW */
-#define IXGBE_RXSTMPL    0x051E8 /* Rx timestamp Low - RO */
-#define IXGBE_RXSTMPH    0x051A4 /* Rx timestamp High - RO */
-#define IXGBE_RXSATRL    0x051A0 /* Rx timestamp attribute low - RO */
-#define IXGBE_RXSATRH    0x051A8 /* Rx timestamp attribute high - RO */
-#define IXGBE_RXMTRL     0x05120 /* RX message type register low - RW */
-#define IXGBE_TXSTMPL    0x08C04 /* Tx timestamp value Low - RO */
-#define IXGBE_TXSTMPH    0x08C08 /* Tx timestamp value High - RO */
-#define IXGBE_SYSTIML    0x08C0C /* System time register Low - RO */
-#define IXGBE_SYSTIMH    0x08C10 /* System time register High - RO */
-#define IXGBE_TIMINCA    0x08C14 /* Increment attributes register - RW */
-#define IXGBE_TIMADJL    0x08C18 /* Time Adjustment Offset register Low - RW */
-#define IXGBE_TIMADJH    0x08C1C /* Time Adjustment Offset register High - RW */
-#define IXGBE_TSAUXC     0x08C20 /* TimeSync Auxiliary Control register - RW */
-#define IXGBE_TRGTTIML0  0x08C24 /* Target Time Register 0 Low - RW */
-#define IXGBE_TRGTTIMH0  0x08C28 /* Target Time Register 0 High - RW */
-#define IXGBE_TRGTTIML1  0x08C2C /* Target Time Register 1 Low - RW */
-#define IXGBE_TRGTTIMH1  0x08C30 /* Target Time Register 1 High - RW */
-#define IXGBE_CLKTIML    0x08C34 /* Clock Out Time Register Low - RW */
-#define IXGBE_CLKTIMH    0x08C38 /* Clock Out Time Register High - RW */
-#define IXGBE_FREQOUT0   0x08C34 /* Frequency Out 0 Control register - RW */
-#define IXGBE_FREQOUT1   0x08C38 /* Frequency Out 1 Control register - RW */
-#define IXGBE_AUXSTMPL0  0x08C3C /* Auxiliary Time Stamp 0 register Low - RO */
-#define IXGBE_AUXSTMPH0  0x08C40 /* Auxiliary Time Stamp 0 register High - RO */
-#define IXGBE_AUXSTMPL1  0x08C44 /* Auxiliary Time Stamp 1 register Low - RO */
-#define IXGBE_AUXSTMPH1  0x08C48 /* Auxiliary Time Stamp 1 register High - RO */
+#define IXGBE_TSYNCRXCTL	0x05188 /* Rx Time Sync Control register - RW */
+#define IXGBE_TSYNCTXCTL	0x08C00 /* Tx Time Sync Control register - RW */
+#define IXGBE_RXSTMPL	0x051E8 /* Rx timestamp Low - RO */
+#define IXGBE_RXSTMPH	0x051A4 /* Rx timestamp High - RO */
+#define IXGBE_RXSATRL	0x051A0 /* Rx timestamp attribute low - RO */
+#define IXGBE_RXSATRH	0x051A8 /* Rx timestamp attribute high - RO */
+#define IXGBE_RXMTRL	0x05120 /* RX message type register low - RW */
+#define IXGBE_TXSTMPL	0x08C04 /* Tx timestamp value Low - RO */
+#define IXGBE_TXSTMPH	0x08C08 /* Tx timestamp value High - RO */
+#define IXGBE_SYSTIML	0x08C0C /* System time register Low - RO */
+#define IXGBE_SYSTIMH	0x08C10 /* System time register High - RO */
+#define IXGBE_SYSTIMR	0x08C58 /* System time register Residue - RO */
+#define IXGBE_TIMINCA	0x08C14 /* Increment attributes register - RW */
+#define IXGBE_TIMADJL	0x08C18 /* Time Adjustment Offset register Low - RW */
+#define IXGBE_TIMADJH	0x08C1C /* Time Adjustment Offset register High - RW */
+#define IXGBE_TSAUXC	0x08C20 /* TimeSync Auxiliary Control register - RW */
+#define IXGBE_TRGTTIML0	0x08C24 /* Target Time Register 0 Low - RW */
+#define IXGBE_TRGTTIMH0	0x08C28 /* Target Time Register 0 High - RW */
+#define IXGBE_TRGTTIML1	0x08C2C /* Target Time Register 1 Low - RW */
+#define IXGBE_TRGTTIMH1	0x08C30 /* Target Time Register 1 High - RW */
+#define IXGBE_CLKTIML	0x08C34 /* Clock Out Time Register Low - RW */
+#define IXGBE_CLKTIMH	0x08C38 /* Clock Out Time Register High - RW */
+#define IXGBE_FREQOUT0	0x08C34 /* Frequency Out 0 Control register - RW */
+#define IXGBE_FREQOUT1	0x08C38 /* Frequency Out 1 Control register - RW */
+#define IXGBE_AUXSTMPL0	0x08C3C /* Auxiliary Time Stamp 0 register Low - RO */
+#define IXGBE_AUXSTMPH0	0x08C40 /* Auxiliary Time Stamp 0 register High - RO */
+#define IXGBE_AUXSTMPL1	0x08C44 /* Auxiliary Time Stamp 1 register Low - RO */
+#define IXGBE_AUXSTMPH1	0x08C48 /* Auxiliary Time Stamp 1 register High - RO */
+#define IXGBE_TSIM	0x08C68 /* TimeSync Interrupt Mask Register - RW */
+#define IXGBE_TSICR	0x08C60 /* TimeSync Interrupt Cause Register - WO */
+#define IXGBE_TSSDP	0x0003C /* TimeSync SDP Configuration Register - RW */
 
 /* Diagnostic Registers */
-#define IXGBE_RDSTATCTL   0x02C20
-#define IXGBE_RDSTAT(_i)  (0x02C00 + ((_i) * 4)) /* 0x02C00-0x02C1C */
-#define IXGBE_RDHMPN      0x02F08
-#define IXGBE_RIC_DW(_i)  (0x02F10 + ((_i) * 4))
-#define IXGBE_RDPROBE     0x02F20
-#define IXGBE_RDMAM       0x02F30
-#define IXGBE_RDMAD       0x02F34
-#define IXGBE_TDSTATCTL   0x07C20
-#define IXGBE_TDSTAT(_i)  (0x07C00 + ((_i) * 4)) /* 0x07C00 - 0x07C1C */
-#define IXGBE_TDHMPN      0x07F08
-#define IXGBE_TDHMPN2     0x082FC
-#define IXGBE_TXDESCIC    0x082CC
-#define IXGBE_TIC_DW(_i)  (0x07F10 + ((_i) * 4))
-#define IXGBE_TIC_DW2(_i) (0x082B0 + ((_i) * 4))
-#define IXGBE_TDPROBE     0x07F20
-#define IXGBE_TXBUFCTRL   0x0C600
-#define IXGBE_TXBUFDATA0  0x0C610
-#define IXGBE_TXBUFDATA1  0x0C614
-#define IXGBE_TXBUFDATA2  0x0C618
-#define IXGBE_TXBUFDATA3  0x0C61C
-#define IXGBE_RXBUFCTRL   0x03600
-#define IXGBE_RXBUFDATA0  0x03610
-#define IXGBE_RXBUFDATA1  0x03614
-#define IXGBE_RXBUFDATA2  0x03618
-#define IXGBE_RXBUFDATA3  0x0361C
-#define IXGBE_PCIE_DIAG(_i)     (0x11090 + ((_i) * 4)) /* 8 of these */
-#define IXGBE_RFVAL     0x050A4
-#define IXGBE_MDFTC1    0x042B8
-#define IXGBE_MDFTC2    0x042C0
-#define IXGBE_MDFTFIFO1 0x042C4
-#define IXGBE_MDFTFIFO2 0x042C8
-#define IXGBE_MDFTS     0x042CC
-#define IXGBE_RXDATAWRPTR(_i)   (0x03700 + ((_i) * 4)) /* 8 of these 3700-370C*/
-#define IXGBE_RXDESCWRPTR(_i)   (0x03710 + ((_i) * 4)) /* 8 of these 3710-371C*/
-#define IXGBE_RXDATARDPTR(_i)   (0x03720 + ((_i) * 4)) /* 8 of these 3720-372C*/
-#define IXGBE_RXDESCRDPTR(_i)   (0x03730 + ((_i) * 4)) /* 8 of these 3730-373C*/
-#define IXGBE_TXDATAWRPTR(_i)   (0x0C700 + ((_i) * 4)) /* 8 of these C700-C70C*/
-#define IXGBE_TXDESCWRPTR(_i)   (0x0C710 + ((_i) * 4)) /* 8 of these C710-C71C*/
-#define IXGBE_TXDATARDPTR(_i)   (0x0C720 + ((_i) * 4)) /* 8 of these C720-C72C*/
-#define IXGBE_TXDESCRDPTR(_i)   (0x0C730 + ((_i) * 4)) /* 8 of these C730-C73C*/
-#define IXGBE_PCIEECCCTL 0x1106C
-#define IXGBE_RXWRPTR(_i)       (0x03100 + ((_i) * 4)) /* 8 of these 3100-310C*/
-#define IXGBE_RXUSED(_i)        (0x03120 + ((_i) * 4)) /* 8 of these 3120-312C*/
-#define IXGBE_RXRDPTR(_i)       (0x03140 + ((_i) * 4)) /* 8 of these 3140-314C*/
-#define IXGBE_RXRDWRPTR(_i)     (0x03160 + ((_i) * 4)) /* 8 of these 3160-310C*/
-#define IXGBE_TXWRPTR(_i)       (0x0C100 + ((_i) * 4)) /* 8 of these C100-C10C*/
-#define IXGBE_TXUSED(_i)        (0x0C120 + ((_i) * 4)) /* 8 of these C120-C12C*/
-#define IXGBE_TXRDPTR(_i)       (0x0C140 + ((_i) * 4)) /* 8 of these C140-C14C*/
-#define IXGBE_TXRDWRPTR(_i)     (0x0C160 + ((_i) * 4)) /* 8 of these C160-C10C*/
-#define IXGBE_PCIEECCCTL0 0x11100
-#define IXGBE_PCIEECCCTL1 0x11104
-#define IXGBE_RXDBUECC  0x03F70
-#define IXGBE_TXDBUECC  0x0CF70
-#define IXGBE_RXDBUEST 0x03F74
-#define IXGBE_TXDBUEST 0x0CF74
-#define IXGBE_PBTXECC   0x0C300
-#define IXGBE_PBRXECC   0x03300
-#define IXGBE_GHECCR    0x110B0
+#define IXGBE_RDSTATCTL		0x02C20
+#define IXGBE_RDSTAT(_i)	(0x02C00 + ((_i) * 4)) /* 0x02C00-0x02C1C */
+#define IXGBE_RDHMPN		0x02F08
+#define IXGBE_RIC_DW(_i)	(0x02F10 + ((_i) * 4))
+#define IXGBE_RDPROBE		0x02F20
+#define IXGBE_RDMAM		0x02F30
+#define IXGBE_RDMAD		0x02F34
+#define IXGBE_TDHMPN		0x07F08
+#define IXGBE_TDHMPN2		0x082FC
+#define IXGBE_TXDESCIC		0x082CC
+#define IXGBE_TIC_DW(_i)	(0x07F10 + ((_i) * 4))
+#define IXGBE_TIC_DW2(_i)	(0x082B0 + ((_i) * 4))
+#define IXGBE_TDPROBE		0x07F20
+#define IXGBE_TXBUFCTRL		0x0C600
+#define IXGBE_TXBUFDATA0	0x0C610
+#define IXGBE_TXBUFDATA1	0x0C614
+#define IXGBE_TXBUFDATA2	0x0C618
+#define IXGBE_TXBUFDATA3	0x0C61C
+#define IXGBE_RXBUFCTRL		0x03600
+#define IXGBE_RXBUFDATA0	0x03610
+#define IXGBE_RXBUFDATA1	0x03614
+#define IXGBE_RXBUFDATA2	0x03618
+#define IXGBE_RXBUFDATA3	0x0361C
+#define IXGBE_PCIE_DIAG(_i)	(0x11090 + ((_i) * 4)) /* 8 of these */
+#define IXGBE_RFVAL		0x050A4
+#define IXGBE_MDFTC1		0x042B8
+#define IXGBE_MDFTC2		0x042C0
+#define IXGBE_MDFTFIFO1		0x042C4
+#define IXGBE_MDFTFIFO2		0x042C8
+#define IXGBE_MDFTS		0x042CC
+#define IXGBE_RXDATAWRPTR(_i)	(0x03700 + ((_i) * 4)) /* 8 of these 3700-370C*/
+#define IXGBE_RXDESCWRPTR(_i)	(0x03710 + ((_i) * 4)) /* 8 of these 3710-371C*/
+#define IXGBE_RXDATARDPTR(_i)	(0x03720 + ((_i) * 4)) /* 8 of these 3720-372C*/
+#define IXGBE_RXDESCRDPTR(_i)	(0x03730 + ((_i) * 4)) /* 8 of these 3730-373C*/
+#define IXGBE_TXDATAWRPTR(_i)	(0x0C700 + ((_i) * 4)) /* 8 of these C700-C70C*/
+#define IXGBE_TXDESCWRPTR(_i)	(0x0C710 + ((_i) * 4)) /* 8 of these C710-C71C*/
+#define IXGBE_TXDATARDPTR(_i)	(0x0C720 + ((_i) * 4)) /* 8 of these C720-C72C*/
+#define IXGBE_TXDESCRDPTR(_i)	(0x0C730 + ((_i) * 4)) /* 8 of these C730-C73C*/
+#define IXGBE_PCIEECCCTL	0x1106C
+#define IXGBE_RXWRPTR(_i)	(0x03100 + ((_i) * 4)) /* 8 of these 3100-310C*/
+#define IXGBE_RXUSED(_i)	(0x03120 + ((_i) * 4)) /* 8 of these 3120-312C*/
+#define IXGBE_RXRDPTR(_i)	(0x03140 + ((_i) * 4)) /* 8 of these 3140-314C*/
+#define IXGBE_RXRDWRPTR(_i)	(0x03160 + ((_i) * 4)) /* 8 of these 3160-310C*/
+#define IXGBE_TXWRPTR(_i)	(0x0C100 + ((_i) * 4)) /* 8 of these C100-C10C*/
+#define IXGBE_TXUSED(_i)	(0x0C120 + ((_i) * 4)) /* 8 of these C120-C12C*/
+#define IXGBE_TXRDPTR(_i)	(0x0C140 + ((_i) * 4)) /* 8 of these C140-C14C*/
+#define IXGBE_TXRDWRPTR(_i)	(0x0C160 + ((_i) * 4)) /* 8 of these C160-C10C*/
+#define IXGBE_PCIEECCCTL0	0x11100
+#define IXGBE_PCIEECCCTL1	0x11104
+#define IXGBE_RXDBUECC		0x03F70
+#define IXGBE_TXDBUECC		0x0CF70
+#define IXGBE_RXDBUEST		0x03F74
+#define IXGBE_TXDBUEST		0x0CF74
+#define IXGBE_PBTXECC		0x0C300
+#define IXGBE_PBRXECC		0x03300
+#define IXGBE_GHECCR		0x110B0
 
 /* MAC Registers */
-#define IXGBE_PCS1GCFIG 0x04200
-#define IXGBE_PCS1GLCTL 0x04208
-#define IXGBE_PCS1GLSTA 0x0420C
-#define IXGBE_PCS1GDBG0 0x04210
-#define IXGBE_PCS1GDBG1 0x04214
-#define IXGBE_PCS1GANA  0x04218
-#define IXGBE_PCS1GANLP 0x0421C
-#define IXGBE_PCS1GANNP 0x04220
-#define IXGBE_PCS1GANLPNP 0x04224
-#define IXGBE_HLREG0    0x04240
-#define IXGBE_HLREG1    0x04244
-#define IXGBE_PAP       0x04248
-#define IXGBE_MACA      0x0424C
-#define IXGBE_APAE      0x04250
-#define IXGBE_ARD       0x04254
-#define IXGBE_AIS       0x04258
-#define IXGBE_MSCA      0x0425C
-#define IXGBE_MSRWD     0x04260
-#define IXGBE_MLADD     0x04264
-#define IXGBE_MHADD     0x04268
-#define IXGBE_MAXFRS    0x04268
-#define IXGBE_TREG      0x0426C
-#define IXGBE_PCSS1     0x04288
-#define IXGBE_PCSS2     0x0428C
-#define IXGBE_XPCSS     0x04290
-#define IXGBE_MFLCN     0x04294
-#define IXGBE_SERDESC   0x04298
-#define IXGBE_MACS      0x0429C
-#define IXGBE_AUTOC     0x042A0
-#define IXGBE_LINKS     0x042A4
-#define IXGBE_LINKS2    0x04324
-#define IXGBE_AUTOC2    0x042A8
-#define IXGBE_AUTOC3    0x042AC
-#define IXGBE_ANLP1     0x042B0
-#define IXGBE_ANLP2     0x042B4
-#define IXGBE_MACC      0x04330
-#define IXGBE_ATLASCTL  0x04800
-#define IXGBE_MMNGC     0x042D0
-#define IXGBE_ANLPNP1   0x042D4
-#define IXGBE_ANLPNP2   0x042D8
-#define IXGBE_KRPCSFC   0x042E0
-#define IXGBE_KRPCSS    0x042E4
-#define IXGBE_FECS1     0x042E8
-#define IXGBE_FECS2     0x042EC
-#define IXGBE_SMADARCTL 0x14F10
-#define IXGBE_MPVC      0x04318
-#define IXGBE_SGMIIC    0x04314
+#define IXGBE_PCS1GCFIG		0x04200
+#define IXGBE_PCS1GLCTL		0x04208
+#define IXGBE_PCS1GLSTA		0x0420C
+#define IXGBE_PCS1GDBG0		0x04210
+#define IXGBE_PCS1GDBG1		0x04214
+#define IXGBE_PCS1GANA		0x04218
+#define IXGBE_PCS1GANLP		0x0421C
+#define IXGBE_PCS1GANNP		0x04220
+#define IXGBE_PCS1GANLPNP	0x04224
+#define IXGBE_HLREG0		0x04240
+#define IXGBE_HLREG1		0x04244
+#define IXGBE_PAP		0x04248
+#define IXGBE_MACA		0x0424C
+#define IXGBE_APAE		0x04250
+#define IXGBE_ARD		0x04254
+#define IXGBE_AIS		0x04258
+#define IXGBE_MSCA		0x0425C
+#define IXGBE_MSRWD		0x04260
+#define IXGBE_MLADD		0x04264
+#define IXGBE_MHADD		0x04268
+#define IXGBE_MAXFRS		0x04268
+#define IXGBE_TREG		0x0426C
+#define IXGBE_PCSS1		0x04288
+#define IXGBE_PCSS2		0x0428C
+#define IXGBE_XPCSS		0x04290
+#define IXGBE_MFLCN		0x04294
+#define IXGBE_SERDESC		0x04298
+#define IXGBE_MAC_SGMII_BUSY	0x04298
+#define IXGBE_MACS		0x0429C
+#define IXGBE_AUTOC		0x042A0
+#define IXGBE_LINKS		0x042A4
+#define IXGBE_LINKS2		0x04324
+#define IXGBE_AUTOC2		0x042A8
+#define IXGBE_AUTOC3		0x042AC
+#define IXGBE_ANLP1		0x042B0
+#define IXGBE_ANLP2		0x042B4
+#define IXGBE_MACC		0x04330
+#define IXGBE_ATLASCTL		0x04800
+#define IXGBE_MMNGC		0x042D0
+#define IXGBE_ANLPNP1		0x042D4
+#define IXGBE_ANLPNP2		0x042D8
+#define IXGBE_KRPCSFC		0x042E0
+#define IXGBE_KRPCSS		0x042E4
+#define IXGBE_FECS1		0x042E8
+#define IXGBE_FECS2		0x042EC
+#define IXGBE_SMADARCTL		0x14F10
+#define IXGBE_MPVC		0x04318
+#define IXGBE_SGMIIC		0x04314
 
 /* Statistics Registers */
-#define IXGBE_RXNFGPC      0x041B0
-#define IXGBE_RXNFGBCL     0x041B4
-#define IXGBE_RXNFGBCH     0x041B8
-#define IXGBE_RXDGPC       0x02F50
-#define IXGBE_RXDGBCL      0x02F54
-#define IXGBE_RXDGBCH      0x02F58
-#define IXGBE_RXDDGPC      0x02F5C
-#define IXGBE_RXDDGBCL     0x02F60
-#define IXGBE_RXDDGBCH     0x02F64
-#define IXGBE_RXLPBKGPC    0x02F68
-#define IXGBE_RXLPBKGBCL   0x02F6C
-#define IXGBE_RXLPBKGBCH   0x02F70
-#define IXGBE_RXDLPBKGPC   0x02F74
-#define IXGBE_RXDLPBKGBCL  0x02F78
-#define IXGBE_RXDLPBKGBCH  0x02F7C
-#define IXGBE_TXDGPC       0x087A0
-#define IXGBE_TXDGBCL      0x087A4
-#define IXGBE_TXDGBCH      0x087A8
-
-#define IXGBE_RXDSTATCTRL 0x02F40
+#define IXGBE_RXNFGPC		0x041B0
+#define IXGBE_RXNFGBCL		0x041B4
+#define IXGBE_RXNFGBCH		0x041B8
+#define IXGBE_RXDGPC		0x02F50
+#define IXGBE_RXDGBCL		0x02F54
+#define IXGBE_RXDGBCH		0x02F58
+#define IXGBE_RXDDGPC		0x02F5C
+#define IXGBE_RXDDGBCL		0x02F60
+#define IXGBE_RXDDGBCH		0x02F64
+#define IXGBE_RXLPBKGPC		0x02F68
+#define IXGBE_RXLPBKGBCL	0x02F6C
+#define IXGBE_RXLPBKGBCH	0x02F70
+#define IXGBE_RXDLPBKGPC	0x02F74
+#define IXGBE_RXDLPBKGBCL	0x02F78
+#define IXGBE_RXDLPBKGBCH	0x02F7C
+#define IXGBE_TXDGPC		0x087A0
+#define IXGBE_TXDGBCL		0x087A4
+#define IXGBE_TXDGBCH		0x087A8
+
+#define IXGBE_RXDSTATCTRL	0x02F40
 
 /* Copper Pond 2 link timeout */
 #define IXGBE_VALIDATE_LINK_READY_TIMEOUT 50
 
 /* Omer CORECTL */
-#define IXGBE_CORECTL           0x014F00
+#define IXGBE_CORECTL			0x014F00
 /* BARCTRL */
-#define IXGBE_BARCTRL               0x110F4
-#define IXGBE_BARCTRL_FLSIZE        0x0700
-#define IXGBE_BARCTRL_FLSIZE_SHIFT  8
-#define IXGBE_BARCTRL_CSRSIZE       0x2000
+#define IXGBE_BARCTRL			0x110F4
+#define IXGBE_BARCTRL_FLSIZE		0x0700
+#define IXGBE_BARCTRL_FLSIZE_SHIFT	8
+#define IXGBE_BARCTRL_CSRSIZE		0x2000
 
 /* RSCCTL Bit Masks */
-#define IXGBE_RSCCTL_RSCEN          0x01
-#define IXGBE_RSCCTL_MAXDESC_1      0x00
-#define IXGBE_RSCCTL_MAXDESC_4      0x04
-#define IXGBE_RSCCTL_MAXDESC_8      0x08
-#define IXGBE_RSCCTL_MAXDESC_16     0x0C
+#define IXGBE_RSCCTL_RSCEN	0x01
+#define IXGBE_RSCCTL_MAXDESC_1	0x00
+#define IXGBE_RSCCTL_MAXDESC_4	0x04
+#define IXGBE_RSCCTL_MAXDESC_8	0x08
+#define IXGBE_RSCCTL_MAXDESC_16	0x0C
+#define IXGBE_RSCCTL_TS_DIS	0x02
 
 /* RSCDBU Bit Masks */
-#define IXGBE_RSCDBU_RSCSMALDIS_MASK    0x0000007F
-#define IXGBE_RSCDBU_RSCACKDIS          0x00000080
+#define IXGBE_RSCDBU_RSCSMALDIS_MASK	0x0000007F
+#define IXGBE_RSCDBU_RSCACKDIS		0x00000080
 
 /* RDRXCTL Bit Masks */
-#define IXGBE_RDRXCTL_RDMTS_1_2     0x00000000 /* Rx Desc Min Threshold Size */
-#define IXGBE_RDRXCTL_CRCSTRIP      0x00000002 /* CRC Strip */
-#define IXGBE_RDRXCTL_PSP           0x00000004 /* Pad small packet */
-#define IXGBE_RDRXCTL_MVMEN         0x00000020
-#define IXGBE_RDRXCTL_DMAIDONE      0x00000008 /* DMA init cycle done */
-#define IXGBE_RDRXCTL_AGGDIS        0x00010000 /* Aggregation disable */
-#define IXGBE_RDRXCTL_RSCFRSTSIZE   0x003E0000 /* RSC First packet size */
-#define IXGBE_RDRXCTL_RSCLLIDIS     0x00800000 /* Disable RSC compl on LLI */
-#define IXGBE_RDRXCTL_RSCACKC       0x02000000 /* must set 1 when RSC enabled */
-#define IXGBE_RDRXCTL_FCOE_WRFIX    0x04000000 /* must set 1 when RSC enabled */
+#define IXGBE_RDRXCTL_RDMTS_1_2		0x00000000 /* Rx Desc Min THLD Size */
+#define IXGBE_RDRXCTL_CRCSTRIP		0x00000002 /* CRC Strip */
+#define IXGBE_RDRXCTL_PSP		0x00000004 /* Pad Small Packet */
+#define IXGBE_RDRXCTL_MVMEN		0x00000020
+#define IXGBE_RDRXCTL_RSC_PUSH_DIS	0x00000020
+#define IXGBE_RDRXCTL_DMAIDONE		0x00000008 /* DMA init cycle done */
+#define IXGBE_RDRXCTL_RSC_PUSH		0x00000080
+#define IXGBE_RDRXCTL_AGGDIS		0x00010000 /* Aggregation disable */
+#define IXGBE_RDRXCTL_RSCFRSTSIZE	0x003E0000 /* RSC First packet size */
+#define IXGBE_RDRXCTL_RSCLLIDIS		0x00800000 /* Disable RSC compl on LLI*/
+#define IXGBE_RDRXCTL_RSCACKC		0x02000000 /* must set 1 when RSC ena */
+#define IXGBE_RDRXCTL_FCOE_WRFIX	0x04000000 /* must set 1 when RSC ena */
+#define IXGBE_RDRXCTL_MBINTEN		0x10000000
+#define IXGBE_RDRXCTL_MDP_EN		0x20000000
 
 /* RQTC Bit Masks and Shifts */
-#define IXGBE_RQTC_SHIFT_TC(_i)     ((_i) * 4)
-#define IXGBE_RQTC_TC0_MASK         (0x7 << 0)
-#define IXGBE_RQTC_TC1_MASK         (0x7 << 4)
-#define IXGBE_RQTC_TC2_MASK         (0x7 << 8)
-#define IXGBE_RQTC_TC3_MASK         (0x7 << 12)
-#define IXGBE_RQTC_TC4_MASK         (0x7 << 16)
-#define IXGBE_RQTC_TC5_MASK         (0x7 << 20)
-#define IXGBE_RQTC_TC6_MASK         (0x7 << 24)
-#define IXGBE_RQTC_TC7_MASK         (0x7 << 28)
+#define IXGBE_RQTC_SHIFT_TC(_i)	((_i) * 4)
+#define IXGBE_RQTC_TC0_MASK	(0x7 << 0)
+#define IXGBE_RQTC_TC1_MASK	(0x7 << 4)
+#define IXGBE_RQTC_TC2_MASK	(0x7 << 8)
+#define IXGBE_RQTC_TC3_MASK	(0x7 << 12)
+#define IXGBE_RQTC_TC4_MASK	(0x7 << 16)
+#define IXGBE_RQTC_TC5_MASK	(0x7 << 20)
+#define IXGBE_RQTC_TC6_MASK	(0x7 << 24)
+#define IXGBE_RQTC_TC7_MASK	(0x7 << 28)
 
 /* PSRTYPE.RQPL Bit masks and shift */
-#define IXGBE_PSRTYPE_RQPL_MASK     0x7
-#define IXGBE_PSRTYPE_RQPL_SHIFT    29
+#define IXGBE_PSRTYPE_RQPL_MASK		0x7
+#define IXGBE_PSRTYPE_RQPL_SHIFT	29
 
 /* CTRL Bit Masks */
-#define IXGBE_CTRL_GIO_DIS      0x00000004 /* Global IO Master Disable bit */
-#define IXGBE_CTRL_LNK_RST      0x00000008 /* Link Reset. Resets everything. */
-#define IXGBE_CTRL_RST          0x04000000 /* Reset (SW) */
-#define IXGBE_CTRL_RST_MASK     (IXGBE_CTRL_LNK_RST | IXGBE_CTRL_RST)
+#define IXGBE_CTRL_GIO_DIS	0x00000004 /* Global IO Master Disable bit */
+#define IXGBE_CTRL_LNK_RST	0x00000008 /* Link Reset. Resets everything. */
+#define IXGBE_CTRL_RST		0x04000000 /* Reset (SW) */
+#define IXGBE_CTRL_RST_MASK	(IXGBE_CTRL_LNK_RST | IXGBE_CTRL_RST)
 
 /* FACTPS */
-#define IXGBE_FACTPS_MNGCG      0x20000000 /* Manageblility Clock Gated */
-#define IXGBE_FACTPS_LFS        0x40000000 /* LAN Function Select */
+#define IXGBE_FACTPS_MNGCG	0x20000000 /* Manageblility Clock Gated */
+#define IXGBE_FACTPS_LFS	0x40000000 /* LAN Function Select */
 
 /* MHADD Bit Masks */
-#define IXGBE_MHADD_MFS_MASK    0xFFFF0000
-#define IXGBE_MHADD_MFS_SHIFT   16
+#define IXGBE_MHADD_MFS_MASK	0xFFFF0000
+#define IXGBE_MHADD_MFS_SHIFT	16
 
 /* Extended Device Control */
-#define IXGBE_CTRL_EXT_PFRSTD   0x00004000 /* Physical Function Reset Done */
-#define IXGBE_CTRL_EXT_NS_DIS   0x00010000 /* No Snoop disable */
-#define IXGBE_CTRL_EXT_RO_DIS   0x00020000 /* Relaxed Ordering disable */
-#define IXGBE_CTRL_EXT_DRV_LOAD 0x10000000 /* Driver loaded bit for FW */
+#define IXGBE_CTRL_EXT_PFRSTD	0x00004000 /* Physical Function Reset Done */
+#define IXGBE_CTRL_EXT_NS_DIS	0x00010000 /* No Snoop disable */
+#define IXGBE_CTRL_EXT_RO_DIS	0x00020000 /* Relaxed Ordering disable */
+#define IXGBE_CTRL_EXT_DRV_LOAD	0x10000000 /* Driver loaded bit for FW */
 
 /* Direct Cache Access (DCA) definitions */
-#define IXGBE_DCA_CTRL_DCA_ENABLE  0x00000000 /* DCA Enable */
-#define IXGBE_DCA_CTRL_DCA_DISABLE 0x00000001 /* DCA Disable */
-
-#define IXGBE_DCA_CTRL_DCA_MODE_CB1 0x00 /* DCA Mode CB1 */
-#define IXGBE_DCA_CTRL_DCA_MODE_CB2 0x02 /* DCA Mode CB2 */
-
-#define IXGBE_DCA_RXCTRL_CPUID_MASK 0x0000001F /* Rx CPUID Mask */
-#define IXGBE_DCA_RXCTRL_CPUID_MASK_82599  0xFF000000 /* Rx CPUID Mask */
-#define IXGBE_DCA_RXCTRL_CPUID_SHIFT_82599 24 /* Rx CPUID Shift */
-#define IXGBE_DCA_RXCTRL_DESC_DCA_EN (1 << 5) /* DCA Rx Desc enable */
-#define IXGBE_DCA_RXCTRL_HEAD_DCA_EN (1 << 6) /* DCA Rx Desc header enable */
-#define IXGBE_DCA_RXCTRL_DATA_DCA_EN (1 << 7) /* DCA Rx Desc payload enable */
-#define IXGBE_DCA_RXCTRL_DESC_RRO_EN (1 << 9) /* DCA Rx rd Desc Relax Order */
-#define IXGBE_DCA_RXCTRL_DATA_WRO_EN (1 << 13) /* Rx wr data Relax Order */
-#define IXGBE_DCA_RXCTRL_HEAD_WRO_EN (1 << 15) /* Rx wr header RO */
-
-#define IXGBE_DCA_TXCTRL_CPUID_MASK 0x0000001F /* Tx CPUID Mask */
-#define IXGBE_DCA_TXCTRL_CPUID_MASK_82599  0xFF000000 /* Tx CPUID Mask */
-#define IXGBE_DCA_TXCTRL_CPUID_SHIFT_82599 24 /* Tx CPUID Shift */
-#define IXGBE_DCA_TXCTRL_DESC_DCA_EN (1 << 5) /* DCA Tx Desc enable */
-#define IXGBE_DCA_TXCTRL_DESC_RRO_EN (1 << 9) /* Tx rd Desc Relax Order */
-#define IXGBE_DCA_TXCTRL_DESC_WRO_EN (1 << 11) /* Tx Desc writeback RO bit */
-#define IXGBE_DCA_TXCTRL_DATA_RRO_EN (1 << 13) /* Tx rd data Relax Order */
-#define IXGBE_DCA_MAX_QUEUES_82598   16 /* DCA regs only on 16 queues */
+#define IXGBE_DCA_CTRL_DCA_ENABLE	0x00000000 /* DCA Enable */
+#define IXGBE_DCA_CTRL_DCA_DISABLE	0x00000001 /* DCA Disable */
+
+#define IXGBE_DCA_CTRL_DCA_MODE_CB1	0x00 /* DCA Mode CB1 */
+#define IXGBE_DCA_CTRL_DCA_MODE_CB2	0x02 /* DCA Mode CB2 */
+
+#define IXGBE_DCA_RXCTRL_CPUID_MASK	0x0000001F /* Rx CPUID Mask */
+#define IXGBE_DCA_RXCTRL_CPUID_MASK_82599	0xFF000000 /* Rx CPUID Mask */
+#define IXGBE_DCA_RXCTRL_CPUID_SHIFT_82599	24 /* Rx CPUID Shift */
+#define IXGBE_DCA_RXCTRL_DESC_DCA_EN	(1 << 5) /* Rx Desc enable */
+#define IXGBE_DCA_RXCTRL_HEAD_DCA_EN	(1 << 6) /* Rx Desc header ena */
+#define IXGBE_DCA_RXCTRL_DATA_DCA_EN	(1 << 7) /* Rx Desc payload ena */
+#define IXGBE_DCA_RXCTRL_DESC_RRO_EN	(1 << 9) /* Rx rd Desc Relax Order */
+#define IXGBE_DCA_RXCTRL_DATA_WRO_EN	(1 << 13) /* Rx wr data Relax Order */
+#define IXGBE_DCA_RXCTRL_HEAD_WRO_EN	(1 << 15) /* Rx wr header RO */
+
+#define IXGBE_DCA_TXCTRL_CPUID_MASK	0x0000001F /* Tx CPUID Mask */
+#define IXGBE_DCA_TXCTRL_CPUID_MASK_82599	0xFF000000 /* Tx CPUID Mask */
+#define IXGBE_DCA_TXCTRL_CPUID_SHIFT_82599	24 /* Tx CPUID Shift */
+#define IXGBE_DCA_TXCTRL_DESC_DCA_EN	(1 << 5) /* DCA Tx Desc enable */
+#define IXGBE_DCA_TXCTRL_DESC_RRO_EN	(1 << 9) /* Tx rd Desc Relax Order */
+#define IXGBE_DCA_TXCTRL_DESC_WRO_EN	(1 << 11) /* Tx Desc writeback RO bit */
+#define IXGBE_DCA_TXCTRL_DATA_RRO_EN	(1 << 13) /* Tx rd data Relax Order */
+#define IXGBE_DCA_MAX_QUEUES_82598	16 /* DCA regs only on 16 queues */
 
 /* MSCA Bit Masks */
-#define IXGBE_MSCA_NP_ADDR_MASK      0x0000FFFF /* MDI Address (new protocol) */
-#define IXGBE_MSCA_NP_ADDR_SHIFT     0
-#define IXGBE_MSCA_DEV_TYPE_MASK     0x001F0000 /* Device Type (new protocol) */
-#define IXGBE_MSCA_DEV_TYPE_SHIFT    16 /* Register Address (old protocol */
-#define IXGBE_MSCA_PHY_ADDR_MASK     0x03E00000 /* PHY Address mask */
-#define IXGBE_MSCA_PHY_ADDR_SHIFT    21 /* PHY Address shift*/
-#define IXGBE_MSCA_OP_CODE_MASK      0x0C000000 /* OP CODE mask */
-#define IXGBE_MSCA_OP_CODE_SHIFT     26 /* OP CODE shift */
-#define IXGBE_MSCA_ADDR_CYCLE        0x00000000 /* OP CODE 00 (addr cycle) */
-#define IXGBE_MSCA_WRITE             0x04000000 /* OP CODE 01 (write) */
-#define IXGBE_MSCA_READ              0x0C000000 /* OP CODE 11 (read) */
-#define IXGBE_MSCA_READ_AUTOINC      0x08000000 /* OP CODE 10 (read, auto inc)*/
-#define IXGBE_MSCA_ST_CODE_MASK      0x30000000 /* ST Code mask */
-#define IXGBE_MSCA_ST_CODE_SHIFT     28 /* ST Code shift */
-#define IXGBE_MSCA_NEW_PROTOCOL      0x00000000 /* ST CODE 00 (new protocol) */
-#define IXGBE_MSCA_OLD_PROTOCOL      0x10000000 /* ST CODE 01 (old protocol) */
-#define IXGBE_MSCA_MDI_COMMAND       0x40000000 /* Initiate MDI command */
-#define IXGBE_MSCA_MDI_IN_PROG_EN    0x80000000 /* MDI in progress enable */
+#define IXGBE_MSCA_NP_ADDR_MASK		0x0000FFFF /* MDI Addr (new prot) */
+#define IXGBE_MSCA_NP_ADDR_SHIFT	0
+#define IXGBE_MSCA_DEV_TYPE_MASK	0x001F0000 /* Dev Type (new prot) */
+#define IXGBE_MSCA_DEV_TYPE_SHIFT	16 /* Register Address (old prot */
+#define IXGBE_MSCA_PHY_ADDR_MASK	0x03E00000 /* PHY Address mask */
+#define IXGBE_MSCA_PHY_ADDR_SHIFT	21 /* PHY Address shift*/
+#define IXGBE_MSCA_OP_CODE_MASK		0x0C000000 /* OP CODE mask */
+#define IXGBE_MSCA_OP_CODE_SHIFT	26 /* OP CODE shift */
+#define IXGBE_MSCA_ADDR_CYCLE		0x00000000 /* OP CODE 00 (addr cycle) */
+#define IXGBE_MSCA_WRITE		0x04000000 /* OP CODE 01 (wr) */
+#define IXGBE_MSCA_READ			0x0C000000 /* OP CODE 11 (rd) */
+#define IXGBE_MSCA_READ_AUTOINC		0x08000000 /* OP CODE 10 (rd auto inc)*/
+#define IXGBE_MSCA_ST_CODE_MASK		0x30000000 /* ST Code mask */
+#define IXGBE_MSCA_ST_CODE_SHIFT	28 /* ST Code shift */
+#define IXGBE_MSCA_NEW_PROTOCOL		0x00000000 /* ST CODE 00 (new prot) */
+#define IXGBE_MSCA_OLD_PROTOCOL		0x10000000 /* ST CODE 01 (old prot) */
+#define IXGBE_MSCA_MDI_COMMAND		0x40000000 /* Initiate MDI command */
+#define IXGBE_MSCA_MDI_IN_PROG_EN	0x80000000 /* MDI in progress ena */
 
 /* MSRWD bit masks */
-#define IXGBE_MSRWD_WRITE_DATA_MASK     0x0000FFFF
-#define IXGBE_MSRWD_WRITE_DATA_SHIFT    0
-#define IXGBE_MSRWD_READ_DATA_MASK      0xFFFF0000
-#define IXGBE_MSRWD_READ_DATA_SHIFT     16
+#define IXGBE_MSRWD_WRITE_DATA_MASK	0x0000FFFF
+#define IXGBE_MSRWD_WRITE_DATA_SHIFT	0
+#define IXGBE_MSRWD_READ_DATA_MASK	0xFFFF0000
+#define IXGBE_MSRWD_READ_DATA_SHIFT	16
 
 /* Atlas registers */
-#define IXGBE_ATLAS_PDN_LPBK    0x24
-#define IXGBE_ATLAS_PDN_10G     0xB
-#define IXGBE_ATLAS_PDN_1G      0xC
-#define IXGBE_ATLAS_PDN_AN      0xD
+#define IXGBE_ATLAS_PDN_LPBK		0x24
+#define IXGBE_ATLAS_PDN_10G		0xB
+#define IXGBE_ATLAS_PDN_1G		0xC
+#define IXGBE_ATLAS_PDN_AN		0xD
 
 /* Atlas bit masks */
-#define IXGBE_ATLASCTL_WRITE_CMD        0x00010000
-#define IXGBE_ATLAS_PDN_TX_REG_EN       0x10
-#define IXGBE_ATLAS_PDN_TX_10G_QL_ALL   0xF0
-#define IXGBE_ATLAS_PDN_TX_1G_QL_ALL    0xF0
-#define IXGBE_ATLAS_PDN_TX_AN_QL_ALL    0xF0
+#define IXGBE_ATLASCTL_WRITE_CMD	0x00010000
+#define IXGBE_ATLAS_PDN_TX_REG_EN	0x10
+#define IXGBE_ATLAS_PDN_TX_10G_QL_ALL	0xF0
+#define IXGBE_ATLAS_PDN_TX_1G_QL_ALL	0xF0
+#define IXGBE_ATLAS_PDN_TX_AN_QL_ALL	0xF0
 
 /* Omer bit masks */
-#define IXGBE_CORECTL_WRITE_CMD         0x00010000
-
-/* MDIO definitions */
+#define IXGBE_CORECTL_WRITE_CMD		0x00010000
 
+/* Device Type definitions for new protocol MDIO commands */
+#define IXGBE_MDIO_ZERO_DEV_TYPE		0x0
 #define IXGBE_MDIO_PMA_PMD_DEV_TYPE		0x1
-#define IXGBE_MDIO_PCS_DEV_TYPE		0x3
+#define IXGBE_MDIO_PCS_DEV_TYPE			0x3
 #define IXGBE_MDIO_PHY_XS_DEV_TYPE		0x4
 #define IXGBE_MDIO_AUTO_NEG_DEV_TYPE		0x7
 #define IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE	0x1E   /* Device 30 */
 #define IXGBE_TWINAX_DEV			1
 
-#define IXGBE_MDIO_COMMAND_TIMEOUT     100 /* PHY Timeout for 1 GB mode */
+#define IXGBE_MDIO_COMMAND_TIMEOUT	100 /* PHY Timeout for 1 GB mode */
 
-#define IXGBE_MDIO_VENDOR_SPECIFIC_1_CONTROL      0x0    /* VS1 Control Reg */
-#define IXGBE_MDIO_VENDOR_SPECIFIC_1_STATUS       0x1    /* VS1 Status Reg */
-#define IXGBE_MDIO_VENDOR_SPECIFIC_1_LINK_STATUS  0x0008 /* 1 = Link Up */
-#define IXGBE_MDIO_VENDOR_SPECIFIC_1_SPEED_STATUS 0x0010 /* 0 - 10G, 1 - 1G */
-#define IXGBE_MDIO_VENDOR_SPECIFIC_1_10G_SPEED    0x0018
-#define IXGBE_MDIO_VENDOR_SPECIFIC_1_1G_SPEED     0x0010
+#define IXGBE_MDIO_VENDOR_SPECIFIC_1_CONTROL		0x0 /* VS1 Ctrl Reg */
+#define IXGBE_MDIO_VENDOR_SPECIFIC_1_STATUS		0x1 /* VS1 Status Reg */
+#define IXGBE_MDIO_VENDOR_SPECIFIC_1_LINK_STATUS	0x0008 /* 1 = Link Up */
+#define IXGBE_MDIO_VENDOR_SPECIFIC_1_SPEED_STATUS	0x0010 /* 0-10G, 1-1G */
+#define IXGBE_MDIO_VENDOR_SPECIFIC_1_10G_SPEED		0x0018
+#define IXGBE_MDIO_VENDOR_SPECIFIC_1_1G_SPEED		0x0010
 
 #define IXGBE_MDIO_AUTO_NEG_CONTROL	0x0 /* AUTO_NEG Control Reg */
 #define IXGBE_MDIO_AUTO_NEG_STATUS	0x1 /* AUTO_NEG Status Reg */
 #define IXGBE_MDIO_AUTO_NEG_VENDOR_STAT	0xC800 /* AUTO_NEG Vendor Status Reg */
-#define IXGBE_MDIO_AUTO_NEG_VENDOR_TX_ALARM  0xCC00 /* AUTO_NEG Vendor TX Reg */
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_TX_ALARM 0xCC00 /* AUTO_NEG Vendor TX Reg */
 #define IXGBE_MDIO_AUTO_NEG_VENDOR_TX_ALARM2 0xCC01 /* AUTO_NEG Vendor Tx Reg */
 #define IXGBE_MDIO_AUTO_NEG_VEN_LSC	0x1 /* AUTO_NEG Vendor Tx LSC */
 #define IXGBE_MDIO_AUTO_NEG_ADVT	0x10 /* AUTO_NEG Advt Reg */
 #define IXGBE_MDIO_AUTO_NEG_LP		0x13 /* AUTO_NEG LP Status Reg */
 #define IXGBE_MDIO_AUTO_NEG_EEE_ADVT	0x3C /* AUTO_NEG EEE Advt Reg */
-
-#define IXGBE_MDIO_PHY_SET_LOW_POWER_MODE	 0x0800 /* Set low power mode */
+#define IXGBE_AUTO_NEG_10GBASE_EEE_ADVT	0x8  /* AUTO NEG EEE 10GBaseT Advt */
+#define IXGBE_AUTO_NEG_1000BASE_EEE_ADVT 0x4  /* AUTO NEG EEE 1000BaseT Advt */
+#define IXGBE_AUTO_NEG_100BASE_EEE_ADVT	0x2  /* AUTO NEG EEE 100BaseT Advt */
+#define IXGBE_MDIO_PHY_XS_CONTROL	0x0 /* PHY_XS Control Reg */
+#define IXGBE_MDIO_PHY_XS_RESET		0x8000 /* PHY_XS Reset */
+#define IXGBE_MDIO_PHY_ID_HIGH		0x2 /* PHY ID High Reg*/
+#define IXGBE_MDIO_PHY_ID_LOW		0x3 /* PHY ID Low Reg*/
+#define IXGBE_MDIO_PHY_SPEED_ABILITY	0x4 /* Speed Ability Reg */
+#define IXGBE_MDIO_PHY_SPEED_10G	0x0001 /* 10G capable */
+#define IXGBE_MDIO_PHY_SPEED_1G		0x0010 /* 1G capable */
+#define IXGBE_MDIO_PHY_SPEED_100M	0x0020 /* 100M capable */
+#define IXGBE_MDIO_PHY_EXT_ABILITY	0xB /* Ext Ability Reg */
+#define IXGBE_MDIO_PHY_10GBASET_ABILITY		0x0004 /* 10GBaseT capable */
+#define IXGBE_MDIO_PHY_1000BASET_ABILITY	0x0020 /* 1000BaseT capable */
+#define IXGBE_MDIO_PHY_100BASETX_ABILITY	0x0080 /* 100BaseTX capable */
+#define IXGBE_MDIO_PHY_SET_LOW_POWER_MODE	0x0800 /* Set low power mode */
 #define IXGBE_AUTO_NEG_LP_STATUS	0xE820 /* AUTO NEG Rx LP Status Reg */
-#define IXGBE_AUTO_NEG_LP_1000BASE_CAP	0x8000 /* AUTO NEG Rx LP 1000BaseT */
-#define IXGBE_MDIO_TX_VENDOR_ALARMS_3	0xCC02 /* Vendor Alarms 3 Reg */
-#define IXGBE_MDIO_TX_VENDOR_ALARMS_3_RST_MASK 0x3 /* PHY Reset Complete Mask */
+#define IXGBE_AUTO_NEG_LP_1000BASE_CAP	0x8000 /* AUTO NEG Rx LP 1000BaseT Cap */
+#define IXGBE_AUTO_NEG_LP_10GBASE_CAP	0x0800 /* AUTO NEG Rx LP 10GBaseT Cap */
+#define IXGBE_AUTO_NEG_10GBASET_STAT	0x0021 /* AUTO NEG 10G BaseT Stat */
+
+#define IXGBE_MDIO_TX_VENDOR_ALARMS_3		0xCC02 /* Vendor Alarms 3 Reg */
+#define IXGBE_MDIO_TX_VENDOR_ALARMS_3_RST_MASK	0x3 /* PHY Reset Complete Mask */
 #define IXGBE_MDIO_GLOBAL_RES_PR_10 0xC479 /* Global Resv Provisioning 10 Reg */
-#define IXGBE_MDIO_POWER_UP_STALL	0x8000 /* Power Up Stall */
+#define IXGBE_MDIO_POWER_UP_STALL		0x8000 /* Power Up Stall */
 #define IXGBE_MDIO_GLOBAL_INT_CHIP_STD_MASK	0xFF00 /* int std mask */
 #define IXGBE_MDIO_GLOBAL_CHIP_STD_INT_FLAG	0xFC00 /* chip std int flag */
 #define IXGBE_MDIO_GLOBAL_INT_CHIP_VEN_MASK	0xFF01 /* int chip-wide mask */
 #define IXGBE_MDIO_GLOBAL_INT_CHIP_VEN_FLAG	0xFC01 /* int chip-wide mask */
 #define IXGBE_MDIO_GLOBAL_ALARM_1		0xCC00 /* Global alarm 1 */
+#define IXGBE_MDIO_GLOBAL_ALM_1_DEV_FAULT	0x0010 /* device fault */
 #define IXGBE_MDIO_GLOBAL_ALM_1_HI_TMP_FAIL	0x4000 /* high temp failure */
+#define IXGBE_MDIO_GLOBAL_FAULT_MSG	0xC850 /* Global Fault Message */
+#define IXGBE_MDIO_GLOBAL_FAULT_MSG_HI_TMP	0x8007 /* high temp failure */
 #define IXGBE_MDIO_GLOBAL_INT_MASK		0xD400 /* Global int mask */
-/* autoneg vendor alarm int enable */
-#define IXGBE_MDIO_GLOBAL_AN_VEN_ALM_INT_EN	0x1000
+#define IXGBE_MDIO_GLOBAL_AN_VEN_ALM_INT_EN	0x1000 /* autoneg vendor alarm int enable */
 #define IXGBE_MDIO_GLOBAL_ALARM_1_INT		0x4 /* int in Global alarm 1 */
 #define IXGBE_MDIO_GLOBAL_VEN_ALM_INT_EN	0x1 /* vendor alarm int enable */
 #define IXGBE_MDIO_GLOBAL_STD_ALM2_INT		0x200 /* vendor alarm2 int mask */
 #define IXGBE_MDIO_GLOBAL_INT_HI_TEMP_EN	0x4000 /* int high temp enable */
-
+#define IXGBE_MDIO_GLOBAL_INT_DEV_FAULT_EN 0x0010 /* int dev fault enable */
+#define IXGBE_MDIO_PMA_PMD_CONTROL_ADDR	0x0000 /* PMA/PMD Control Reg */
 #define IXGBE_MDIO_PMA_PMD_SDA_SCL_ADDR	0xC30A /* PHY_XS SDA/SCL Addr Reg */
 #define IXGBE_MDIO_PMA_PMD_SDA_SCL_DATA	0xC30B /* PHY_XS SDA/SCL Data Reg */
-#define IXGBE_MDIO_PMA_PMD_SDA_SCL_STAT	0xC30C /* PHY_XS SDA/SCL Stat Reg */
-#define IXGBE_MDIO_PMA_TX_VEN_LASI_INT_MASK	0xD401 /* PHY TX Vendor LASI */
-#define IXGBE_MDIO_PMA_TX_VEN_LASI_INT_EN	0x1 /* PHY TX Vendor LASI enable */
-#define IXGBE_MDIO_PMD_STD_TX_DISABLE_CNTR	0x9 /* Standard Tx Dis Reg */
-#define IXGBE_MDIO_PMD_GLOBAL_TX_DISABLE	0x0001 /* PMD Global Tx Dis */
+#define IXGBE_MDIO_PMA_PMD_SDA_SCL_STAT	0xC30C /* PHY_XS SDA/SCL Status Reg */
+#define IXGBE_MDIO_PMA_TX_VEN_LASI_INT_MASK 0xD401 /* PHY TX Vendor LASI */
+#define IXGBE_MDIO_PMA_TX_VEN_LASI_INT_EN   0x1 /* PHY TX Vendor LASI enable */
+#define IXGBE_MDIO_PMD_STD_TX_DISABLE_CNTR 0x9 /* Standard Transmit Dis Reg */
+#define IXGBE_MDIO_PMD_GLOBAL_TX_DISABLE 0x0001 /* PMD Global Transmit Dis */
+
+#define IXGBE_PCRC8ECL		0x0E810 /* PCR CRC-8 Error Count Lo */
+#define IXGBE_PCRC8ECH		0x0E811 /* PCR CRC-8 Error Count Hi */
+#define IXGBE_PCRC8ECH_MASK	0x1F
+#define IXGBE_LDPCECL		0x0E820 /* PCR Uncorrected Error Count Lo */
+#define IXGBE_LDPCECH		0x0E821 /* PCR Uncorrected Error Count Hi */
 
 /* MII clause 22/28 definitions */
+#define IXGBE_MDIO_PHY_LOW_POWER_MODE	0x0800
+
+#define IXGBE_MDIO_XENPAK_LASI_STATUS		0x9005 /* XENPAK LASI Status register*/
+#define IXGBE_XENPAK_LASI_LINK_STATUS_ALARM	0x1 /* Link Status Alarm change */
+
+#define IXGBE_MDIO_AUTO_NEG_LINK_STATUS		0x4 /* Indicates if link is up */
+
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_MASK	0x7 /* Speed/Duplex Mask */
+#define IXGBE_MDIO_AUTO_NEG_VEN_STAT_SPEED_MASK		0x6 /* Speed Mask */
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10M_HALF	0x0 /* 10Mb/s Half Duplex */
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10M_FULL	0x1 /* 10Mb/s Full Duplex */
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_100M_HALF	0x2 /* 100Mb/s Half Duplex */
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_100M_FULL	0x3 /* 100Mb/s Full Duplex */
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_1GB_HALF	0x4 /* 1Gb/s Half Duplex */
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_1GB_FULL	0x5 /* 1Gb/s Full Duplex */
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10GB_HALF	0x6 /* 10Gb/s Half Duplex */
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10GB_FULL	0x7 /* 10Gb/s Full Duplex */
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_1GB		0x4 /* 1Gb/s */
+#define IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10GB		0x6 /* 10Gb/s */
+
+#define IXGBE_MII_10GBASE_T_AUTONEG_CTRL_REG	0x20   /* 10G Control Reg */
 #define IXGBE_MII_AUTONEG_VENDOR_PROVISION_1_REG 0xC400 /* 1G Provisioning 1 */
-#define IXGBE_MII_AUTONEG_XNP_TX_REG             0x17   /* 1G XNP Transmit */
-#define IXGBE_MII_1GBASE_T_ADVERTISE_XNP_TX      0x4000 /* full duplex, bit:14*/
-#define IXGBE_MII_1GBASE_T_ADVERTISE             0x8000 /* full duplex, bit:15*/
-#define IXGBE_MII_AUTONEG_REG                    0x0
+#define IXGBE_MII_AUTONEG_XNP_TX_REG		0x17   /* 1G XNP Transmit */
+#define IXGBE_MII_AUTONEG_ADVERTISE_REG		0x10   /* 100M Advertisement */
+#define IXGBE_MII_10GBASE_T_ADVERTISE		0x1000 /* full duplex, bit:12*/
+#define IXGBE_MII_1GBASE_T_ADVERTISE_XNP_TX	0x4000 /* full duplex, bit:14*/
+#define IXGBE_MII_1GBASE_T_ADVERTISE		0x8000 /* full duplex, bit:15*/
+#define IXGBE_MII_2_5GBASE_T_ADVERTISE		0x0400
+#define IXGBE_MII_5GBASE_T_ADVERTISE		0x0800
+#define IXGBE_MII_100BASE_T_ADVERTISE		0x0100 /* full duplex, bit:8 */
+#define IXGBE_MII_100BASE_T_ADVERTISE_HALF	0x0080 /* half duplex, bit:7 */
+#define IXGBE_MII_RESTART			0x200
+#define IXGBE_MII_AUTONEG_COMPLETE		0x20
+#define IXGBE_MII_AUTONEG_LINK_UP		0x04
+#define IXGBE_MII_AUTONEG_REG			0x0
 
-#define IXGBE_PHY_REVISION_MASK        0xFFFFFFF0
-#define IXGBE_MAX_PHY_ADDR             32
+#define IXGBE_PHY_REVISION_MASK		0xFFFFFFF0
+#define IXGBE_MAX_PHY_ADDR		32
 
 /* PHY IDs*/
-#define TN1010_PHY_ID    0x00A19410
-#define TNX_FW_REV       0xB
-#define X540_PHY_ID      0x01540200
-#define X550_PHY_ID      0x01540220
-#define X557_PHY_ID      0x01540240
-#define QT2022_PHY_ID    0x0043A400
-#define ATH_PHY_ID       0x03429050
-#define AQ_FW_REV        0x20
+#define TN1010_PHY_ID	0x00A19410
+#define TNX_FW_REV	0xB
+#define X540_PHY_ID	0x01540200
+#define X550_PHY_ID2	0x01540223
+#define X550_PHY_ID3	0x01540221
+#define X557_PHY_ID	0x01540240
+#define X557_PHY_ID2	0x01540250
+#define AQ_FW_REV	0x20
+#define QT2022_PHY_ID	0x0043A400
+#define ATH_PHY_ID	0x03429050
 
 /* PHY Types */
-#define IXGBE_M88E1145_E_PHY_ID  0x01410CD0
+#define IXGBE_M88E1500_E_PHY_ID	0x01410DD0
+#define IXGBE_M88E1543_E_PHY_ID	0x01410EA0
 
 /* Special PHY Init Routine */
-#define IXGBE_PHY_INIT_OFFSET_NL 0x002B
-#define IXGBE_PHY_INIT_END_NL    0xFFFF
-#define IXGBE_CONTROL_MASK_NL    0xF000
-#define IXGBE_DATA_MASK_NL       0x0FFF
-#define IXGBE_CONTROL_SHIFT_NL   12
-#define IXGBE_DELAY_NL           0
-#define IXGBE_DATA_NL            1
-#define IXGBE_CONTROL_NL         0x000F
-#define IXGBE_CONTROL_EOL_NL     0x0FFF
-#define IXGBE_CONTROL_SOL_NL     0x0000
+#define IXGBE_PHY_INIT_OFFSET_NL	0x002B
+#define IXGBE_PHY_INIT_END_NL		0xFFFF
+#define IXGBE_CONTROL_MASK_NL		0xF000
+#define IXGBE_DATA_MASK_NL		0x0FFF
+#define IXGBE_CONTROL_SHIFT_NL		12
+#define IXGBE_DELAY_NL			0
+#define IXGBE_DATA_NL			1
+#define IXGBE_CONTROL_NL		0x000F
+#define IXGBE_CONTROL_EOL_NL		0x0FFF
+#define IXGBE_CONTROL_SOL_NL		0x0000
 
 /* General purpose Interrupt Enable */
-#define IXGBE_SDP0_GPIEN_8259X		0x00000001 /* SDP0 */
-#define IXGBE_SDP1_GPIEN_8259X		0x00000002 /* SDP1 */
-#define IXGBE_SDP2_GPIEN_8259X		0x00000004 /* SDP2 */
-#define IXGBE_SDP0_GPIEN_X540		0x00000002 /* SDP0 on X540 and X550 */
-#define IXGBE_SDP1_GPIEN_X540		0x00000004 /* SDP1 on X540 and X550 */
-#define IXGBE_SDP2_GPIEN_X540		0x00000008 /* SDP2 on X540 and X550 */
-#define IXGBE_SDP0_GPIEN_X550		IXGBE_SDP0_GPIEN_X540
-#define IXGBE_SDP1_GPIEN_X550		IXGBE_SDP1_GPIEN_X540
-#define IXGBE_SDP2_GPIEN_X550		IXGBE_SDP2_GPIEN_X540
+#define IXGBE_SDP0_GPIEN	0x00000001 /* SDP0 */
+#define IXGBE_SDP1_GPIEN	0x00000002 /* SDP1 */
+#define IXGBE_SDP2_GPIEN	0x00000004 /* SDP2 */
+#define IXGBE_SDP0_GPIEN_X540	0x00000002 /* SDP0 on X540 and X550 */
+#define IXGBE_SDP1_GPIEN_X540	0x00000004 /* SDP1 on X540 and X550 */
+#define IXGBE_SDP2_GPIEN_X540	0x00000008 /* SDP2 on X540 and X550 */
+#define IXGBE_SDP0_GPIEN_X550	IXGBE_SDP0_GPIEN_X540
+#define IXGBE_SDP1_GPIEN_X550	IXGBE_SDP1_GPIEN_X540
+#define IXGBE_SDP2_GPIEN_X550	IXGBE_SDP2_GPIEN_X540
 #define IXGBE_SDP0_GPIEN_X550EM_x	IXGBE_SDP0_GPIEN_X540
 #define IXGBE_SDP1_GPIEN_X550EM_x	IXGBE_SDP1_GPIEN_X540
 #define IXGBE_SDP2_GPIEN_X550EM_x	IXGBE_SDP2_GPIEN_X540
 #define IXGBE_SDP0_GPIEN_X550EM_a	IXGBE_SDP0_GPIEN_X540
 #define IXGBE_SDP1_GPIEN_X550EM_a	IXGBE_SDP1_GPIEN_X540
 #define IXGBE_SDP2_GPIEN_X550EM_a	IXGBE_SDP2_GPIEN_X540
-#define IXGBE_SDP0_GPIEN(_hw)		IXGBE_BY_MAC((_hw), SDP0_GPIEN)
-#define IXGBE_SDP1_GPIEN(_hw)		IXGBE_BY_MAC((_hw), SDP1_GPIEN)
-#define IXGBE_SDP2_GPIEN(_hw)		IXGBE_BY_MAC((_hw), SDP2_GPIEN)
-
-#define IXGBE_GPIE_MSIX_MODE     0x00000010 /* MSI-X mode */
-#define IXGBE_GPIE_OCD           0x00000020 /* Other Clear Disable */
-#define IXGBE_GPIE_EIMEN         0x00000040 /* Immediate Interrupt Enable */
-#define IXGBE_GPIE_EIAME         0x40000000
-#define IXGBE_GPIE_PBA_SUPPORT   0x80000000
-#define IXGBE_GPIE_RSC_DELAY_SHIFT 11
-#define IXGBE_GPIE_VTMODE_MASK   0x0000C000 /* VT Mode Mask */
-#define IXGBE_GPIE_VTMODE_16     0x00004000 /* 16 VFs 8 queues per VF */
-#define IXGBE_GPIE_VTMODE_32     0x00008000 /* 32 VFs 4 queues per VF */
-#define IXGBE_GPIE_VTMODE_64     0x0000C000 /* 64 VFs 2 queues per VF */
+#define IXGBE_SDP0_GPIEN_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), SDP0_GPIEN)
+#define IXGBE_SDP1_GPIEN_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), SDP1_GPIEN)
+#define IXGBE_SDP2_GPIEN_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), SDP2_GPIEN)
+
+#define IXGBE_GPIE_MSIX_MODE	0x00000010 /* MSI-X mode */
+#define IXGBE_GPIE_OCD		0x00000020 /* Other Clear Disable */
+#define IXGBE_GPIE_EIMEN	0x00000040 /* Immediate Interrupt Enable */
+#define IXGBE_GPIE_EIAME	0x40000000
+#define IXGBE_GPIE_PBA_SUPPORT	0x80000000
+#define IXGBE_GPIE_RSC_DELAY_SHIFT	11
+#define IXGBE_GPIE_VTMODE_MASK	0x0000C000 /* VT Mode Mask */
+#define IXGBE_GPIE_VTMODE_16	0x00004000 /* 16 VFs 8 queues per VF */
+#define IXGBE_GPIE_VTMODE_32	0x00008000 /* 32 VFs 4 queues per VF */
+#define IXGBE_GPIE_VTMODE_64	0x0000C000 /* 64 VFs 2 queues per VF */
 
 /* Packet Buffer Initialization */
-#define IXGBE_TXPBSIZE_20KB     0x00005000 /* 20KB Packet Buffer */
-#define IXGBE_TXPBSIZE_40KB     0x0000A000 /* 40KB Packet Buffer */
-#define IXGBE_RXPBSIZE_48KB     0x0000C000 /* 48KB Packet Buffer */
-#define IXGBE_RXPBSIZE_64KB     0x00010000 /* 64KB Packet Buffer */
-#define IXGBE_RXPBSIZE_80KB     0x00014000 /* 80KB Packet Buffer */
-#define IXGBE_RXPBSIZE_128KB    0x00020000 /* 128KB Packet Buffer */
-#define IXGBE_RXPBSIZE_MAX      0x00080000 /* 512KB Packet Buffer*/
-#define IXGBE_TXPBSIZE_MAX      0x00028000 /* 160KB Packet Buffer*/
-
-#define IXGBE_TXPKT_SIZE_MAX    0xA        /* Max Tx Packet size  */
+#define IXGBE_MAX_PACKET_BUFFERS	8
+
+#define IXGBE_TXPBSIZE_20KB	0x00005000 /* 20KB Packet Buffer */
+#define IXGBE_TXPBSIZE_40KB	0x0000A000 /* 40KB Packet Buffer */
+#define IXGBE_RXPBSIZE_48KB	0x0000C000 /* 48KB Packet Buffer */
+#define IXGBE_RXPBSIZE_64KB	0x00010000 /* 64KB Packet Buffer */
+#define IXGBE_RXPBSIZE_80KB	0x00014000 /* 80KB Packet Buffer */
+#define IXGBE_RXPBSIZE_128KB	0x00020000 /* 128KB Packet Buffer */
+#define IXGBE_RXPBSIZE_MAX	0x00080000 /* 512KB Packet Buffer */
+#define IXGBE_TXPBSIZE_MAX	0x00028000 /* 160KB Packet Buffer */
+
+#define IXGBE_TXPKT_SIZE_MAX	0xA /* Max Tx Packet size */
 #define IXGBE_MAX_PB		8
 
 /* Packet buffer allocation strategies */
 enum {
-	PBA_STRATEGY_EQUAL	= 0,	/* Distribute PB space equally */
+	PBA_STRATEGY_EQUAL	= 0, /* Distribute PB space equally */
 #define PBA_STRATEGY_EQUAL	PBA_STRATEGY_EQUAL
-	PBA_STRATEGY_WEIGHTED	= 1,	/* Weight front half of TCs */
+	PBA_STRATEGY_WEIGHTED	= 1, /* Weight front half of TCs */
 #define PBA_STRATEGY_WEIGHTED	PBA_STRATEGY_WEIGHTED
 };
 
 /* Transmit Flow Control status */
-#define IXGBE_TFCS_TXOFF         0x00000001
-#define IXGBE_TFCS_TXOFF0        0x00000100
-#define IXGBE_TFCS_TXOFF1        0x00000200
-#define IXGBE_TFCS_TXOFF2        0x00000400
-#define IXGBE_TFCS_TXOFF3        0x00000800
-#define IXGBE_TFCS_TXOFF4        0x00001000
-#define IXGBE_TFCS_TXOFF5        0x00002000
-#define IXGBE_TFCS_TXOFF6        0x00004000
-#define IXGBE_TFCS_TXOFF7        0x00008000
+#define IXGBE_TFCS_TXOFF	0x00000001
+#define IXGBE_TFCS_TXOFF0	0x00000100
+#define IXGBE_TFCS_TXOFF1	0x00000200
+#define IXGBE_TFCS_TXOFF2	0x00000400
+#define IXGBE_TFCS_TXOFF3	0x00000800
+#define IXGBE_TFCS_TXOFF4	0x00001000
+#define IXGBE_TFCS_TXOFF5	0x00002000
+#define IXGBE_TFCS_TXOFF6	0x00004000
+#define IXGBE_TFCS_TXOFF7	0x00008000
 
 /* TCP Timer */
-#define IXGBE_TCPTIMER_KS            0x00000100
-#define IXGBE_TCPTIMER_COUNT_ENABLE  0x00000200
-#define IXGBE_TCPTIMER_COUNT_FINISH  0x00000400
-#define IXGBE_TCPTIMER_LOOP          0x00000800
-#define IXGBE_TCPTIMER_DURATION_MASK 0x000000FF
+#define IXGBE_TCPTIMER_KS		0x00000100
+#define IXGBE_TCPTIMER_COUNT_ENABLE	0x00000200
+#define IXGBE_TCPTIMER_COUNT_FINISH	0x00000400
+#define IXGBE_TCPTIMER_LOOP		0x00000800
+#define IXGBE_TCPTIMER_DURATION_MASK	0x000000FF
 
 /* HLREG0 Bit Masks */
-#define IXGBE_HLREG0_TXCRCEN      0x00000001   /* bit  0 */
-#define IXGBE_HLREG0_RXCRCSTRP    0x00000002   /* bit  1 */
-#define IXGBE_HLREG0_JUMBOEN      0x00000004   /* bit  2 */
-#define IXGBE_HLREG0_TXPADEN      0x00000400   /* bit 10 */
-#define IXGBE_HLREG0_TXPAUSEEN    0x00001000   /* bit 12 */
-#define IXGBE_HLREG0_RXPAUSEEN    0x00004000   /* bit 14 */
-#define IXGBE_HLREG0_LPBK         0x00008000   /* bit 15 */
-#define IXGBE_HLREG0_MDCSPD       0x00010000   /* bit 16 */
-#define IXGBE_HLREG0_CONTMDC      0x00020000   /* bit 17 */
-#define IXGBE_HLREG0_CTRLFLTR     0x00040000   /* bit 18 */
-#define IXGBE_HLREG0_PREPEND      0x00F00000   /* bits 20-23 */
-#define IXGBE_HLREG0_PRIPAUSEEN   0x01000000   /* bit 24 */
-#define IXGBE_HLREG0_RXPAUSERECDA 0x06000000   /* bits 25-26 */
-#define IXGBE_HLREG0_RXLNGTHERREN 0x08000000   /* bit 27 */
-#define IXGBE_HLREG0_RXPADSTRIPEN 0x10000000   /* bit 28 */
+#define IXGBE_HLREG0_TXCRCEN		0x00000001 /* bit  0 */
+#define IXGBE_HLREG0_RXCRCSTRP		0x00000002 /* bit  1 */
+#define IXGBE_HLREG0_JUMBOEN		0x00000004 /* bit  2 */
+#define IXGBE_HLREG0_TXPADEN		0x00000400 /* bit 10 */
+#define IXGBE_HLREG0_TXPAUSEEN		0x00001000 /* bit 12 */
+#define IXGBE_HLREG0_RXPAUSEEN		0x00004000 /* bit 14 */
+#define IXGBE_HLREG0_LPBK		0x00008000 /* bit 15 */
+#define IXGBE_HLREG0_MDCSPD		0x00010000 /* bit 16 */
+#define IXGBE_HLREG0_CONTMDC		0x00020000 /* bit 17 */
+#define IXGBE_HLREG0_CTRLFLTR		0x00040000 /* bit 18 */
+#define IXGBE_HLREG0_PREPEND		0x00F00000 /* bits 20-23 */
+#define IXGBE_HLREG0_PRIPAUSEEN		0x01000000 /* bit 24 */
+#define IXGBE_HLREG0_RXPAUSERECDA	0x06000000 /* bits 25-26 */
+#define IXGBE_HLREG0_RXLNGTHERREN	0x08000000 /* bit 27 */
+#define IXGBE_HLREG0_RXPADSTRIPEN	0x10000000 /* bit 28 */
 
 /* VMD_CTL bitmasks */
-#define IXGBE_VMD_CTL_VMDQ_EN     0x00000001
-#define IXGBE_VMD_CTL_VMDQ_FILTER 0x00000002
+#define IXGBE_VMD_CTL_VMDQ_EN		0x00000001
+#define IXGBE_VMD_CTL_VMDQ_FILTER	0x00000002
 
 /* VT_CTL bitmasks */
-#define IXGBE_VT_CTL_DIS_DEFPL  0x20000000 /* disable default pool */
-#define IXGBE_VT_CTL_REPLEN     0x40000000 /* replication enabled */
-#define IXGBE_VT_CTL_VT_ENABLE  0x00000001  /* Enable VT Mode */
-#define IXGBE_VT_CTL_POOL_SHIFT 7
-#define IXGBE_VT_CTL_POOL_MASK  (0x3F << IXGBE_VT_CTL_POOL_SHIFT)
+#define IXGBE_VT_CTL_DIS_DEFPL		0x20000000 /* disable default pool */
+#define IXGBE_VT_CTL_REPLEN		0x40000000 /* replication enabled */
+#define IXGBE_VT_CTL_VT_ENABLE		0x00000001  /* Enable VT Mode */
+#define IXGBE_VT_CTL_POOL_SHIFT		7
+#define IXGBE_VT_CTL_POOL_MASK		(0x3F << IXGBE_VT_CTL_POOL_SHIFT)
 
 /* VMOLR bitmasks */
-#define IXGBE_VMOLR_AUPE        0x01000000 /* accept untagged packets */
-#define IXGBE_VMOLR_ROMPE       0x02000000 /* accept packets in MTA tbl */
-#define IXGBE_VMOLR_ROPE        0x04000000 /* accept packets in UC tbl */
-#define IXGBE_VMOLR_BAM         0x08000000 /* accept broadcast packets */
-#define IXGBE_VMOLR_MPE         0x10000000 /* multicast promiscuous */
+#define IXGBE_VMOLR_UPE		0x00400000 /* unicast promiscuous */
+#define IXGBE_VMOLR_VPE		0x00800000 /* VLAN promiscuous */
+#define IXGBE_VMOLR_AUPE	0x01000000 /* accept untagged packets */
+#define IXGBE_VMOLR_ROMPE	0x02000000 /* accept packets in MTA tbl */
+#define IXGBE_VMOLR_ROPE	0x04000000 /* accept packets in UC tbl */
+#define IXGBE_VMOLR_BAM		0x08000000 /* accept broadcast packets */
+#define IXGBE_VMOLR_MPE		0x10000000 /* multicast promiscuous */
 
 /* VFRE bitmask */
-#define IXGBE_VFRE_ENABLE_ALL   0xFFFFFFFF
+#define IXGBE_VFRE_ENABLE_ALL	0xFFFFFFFF
 
-#define IXGBE_VF_INIT_TIMEOUT   200 /* Number of retries to clear RSTI */
+#define IXGBE_VF_INIT_TIMEOUT	200 /* Number of retries to clear RSTI */
 
 /* RDHMPN and TDHMPN bitmasks */
-#define IXGBE_RDHMPN_RDICADDR       0x007FF800
-#define IXGBE_RDHMPN_RDICRDREQ      0x00800000
-#define IXGBE_RDHMPN_RDICADDR_SHIFT 11
-#define IXGBE_TDHMPN_TDICADDR       0x003FF800
-#define IXGBE_TDHMPN_TDICRDREQ      0x00800000
-#define IXGBE_TDHMPN_TDICADDR_SHIFT 11
-
-#define IXGBE_RDMAM_MEM_SEL_SHIFT   13
-#define IXGBE_RDMAM_DWORD_SHIFT     9
-#define IXGBE_RDMAM_DESC_COMP_FIFO  1
-#define IXGBE_RDMAM_DFC_CMD_FIFO    2
-#define IXGBE_RDMAM_TCN_STATUS_RAM  4
-#define IXGBE_RDMAM_WB_COLL_FIFO    5
-#define IXGBE_RDMAM_QSC_CNT_RAM     6
-#define IXGBE_RDMAM_QSC_QUEUE_CNT   8
-#define IXGBE_RDMAM_QSC_QUEUE_RAM   0xA
-#define IXGBE_RDMAM_DESC_COM_FIFO_RANGE     135
-#define IXGBE_RDMAM_DESC_COM_FIFO_COUNT     4
-#define IXGBE_RDMAM_DFC_CMD_FIFO_RANGE      48
-#define IXGBE_RDMAM_DFC_CMD_FIFO_COUNT      7
-#define IXGBE_RDMAM_TCN_STATUS_RAM_RANGE    256
-#define IXGBE_RDMAM_TCN_STATUS_RAM_COUNT    9
-#define IXGBE_RDMAM_WB_COLL_FIFO_RANGE      8
-#define IXGBE_RDMAM_WB_COLL_FIFO_COUNT      4
-#define IXGBE_RDMAM_QSC_CNT_RAM_RANGE       64
-#define IXGBE_RDMAM_QSC_CNT_RAM_COUNT       4
-#define IXGBE_RDMAM_QSC_QUEUE_CNT_RANGE     32
-#define IXGBE_RDMAM_QSC_QUEUE_CNT_COUNT     4
-#define IXGBE_RDMAM_QSC_QUEUE_RAM_RANGE     128
-#define IXGBE_RDMAM_QSC_QUEUE_RAM_COUNT     8
-
-#define IXGBE_TXDESCIC_READY        0x80000000
+#define IXGBE_RDHMPN_RDICADDR		0x007FF800
+#define IXGBE_RDHMPN_RDICRDREQ		0x00800000
+#define IXGBE_RDHMPN_RDICADDR_SHIFT	11
+#define IXGBE_TDHMPN_TDICADDR		0x003FF800
+#define IXGBE_TDHMPN_TDICRDREQ		0x00800000
+#define IXGBE_TDHMPN_TDICADDR_SHIFT	11
+
+#define IXGBE_RDMAM_MEM_SEL_SHIFT		13
+#define IXGBE_RDMAM_DWORD_SHIFT			9
+#define IXGBE_RDMAM_DESC_COMP_FIFO		1
+#define IXGBE_RDMAM_DFC_CMD_FIFO		2
+#define IXGBE_RDMAM_RSC_HEADER_ADDR		3
+#define IXGBE_RDMAM_TCN_STATUS_RAM		4
+#define IXGBE_RDMAM_WB_COLL_FIFO		5
+#define IXGBE_RDMAM_QSC_CNT_RAM			6
+#define IXGBE_RDMAM_QSC_FCOE_RAM		7
+#define IXGBE_RDMAM_QSC_QUEUE_CNT		8
+#define IXGBE_RDMAM_QSC_QUEUE_RAM		0xA
+#define IXGBE_RDMAM_QSC_RSC_RAM			0xB
+#define IXGBE_RDMAM_DESC_COM_FIFO_RANGE		135
+#define IXGBE_RDMAM_DESC_COM_FIFO_COUNT		4
+#define IXGBE_RDMAM_DFC_CMD_FIFO_RANGE		48
+#define IXGBE_RDMAM_DFC_CMD_FIFO_COUNT		7
+#define IXGBE_RDMAM_RSC_HEADER_ADDR_RANGE	32
+#define IXGBE_RDMAM_RSC_HEADER_ADDR_COUNT	4
+#define IXGBE_RDMAM_TCN_STATUS_RAM_RANGE	256
+#define IXGBE_RDMAM_TCN_STATUS_RAM_COUNT	9
+#define IXGBE_RDMAM_WB_COLL_FIFO_RANGE		8
+#define IXGBE_RDMAM_WB_COLL_FIFO_COUNT		4
+#define IXGBE_RDMAM_QSC_CNT_RAM_RANGE		64
+#define IXGBE_RDMAM_QSC_CNT_RAM_COUNT		4
+#define IXGBE_RDMAM_QSC_FCOE_RAM_RANGE		512
+#define IXGBE_RDMAM_QSC_FCOE_RAM_COUNT		5
+#define IXGBE_RDMAM_QSC_QUEUE_CNT_RANGE		32
+#define IXGBE_RDMAM_QSC_QUEUE_CNT_COUNT		4
+#define IXGBE_RDMAM_QSC_QUEUE_RAM_RANGE		128
+#define IXGBE_RDMAM_QSC_QUEUE_RAM_COUNT		8
+#define IXGBE_RDMAM_QSC_RSC_RAM_RANGE		32
+#define IXGBE_RDMAM_QSC_RSC_RAM_COUNT		8
+
+#define IXGBE_TXDESCIC_READY	0x80000000
 
 /* Receive Checksum Control */
-#define IXGBE_RXCSUM_IPPCSE     0x00001000   /* IP payload checksum enable */
-#define IXGBE_RXCSUM_PCSD       0x00002000   /* packet checksum disabled */
+#define IXGBE_RXCSUM_IPPCSE	0x00001000 /* IP payload checksum enable */
+#define IXGBE_RXCSUM_PCSD	0x00002000 /* packet checksum disabled */
 
 /* FCRTL Bit Masks */
-#define IXGBE_FCRTL_XONE        0x80000000  /* XON enable */
-#define IXGBE_FCRTH_FCEN        0x80000000  /* Packet buffer fc enable */
+#define IXGBE_FCRTL_XONE	0x80000000 /* XON enable */
+#define IXGBE_FCRTH_FCEN	0x80000000 /* Packet buffer fc enable */
 
 /* PAP bit masks*/
-#define IXGBE_PAP_TXPAUSECNT_MASK   0x0000FFFF /* Pause counter mask */
+#define IXGBE_PAP_TXPAUSECNT_MASK	0x0000FFFF /* Pause counter mask */
 
 /* RMCS Bit Masks */
-#define IXGBE_RMCS_RRM          0x00000002 /* Receive Recycle Mode enable */
+#define IXGBE_RMCS_RRM			0x00000002 /* Rx Recycle Mode enable */
 /* Receive Arbitration Control: 0 Round Robin, 1 DFP */
-#define IXGBE_RMCS_RAC          0x00000004
-#define IXGBE_RMCS_DFP          IXGBE_RMCS_RAC /* Deficit Fixed Priority ena */
-#define IXGBE_RMCS_TFCE_802_3X         0x00000008 /* Tx Priority FC ena */
-#define IXGBE_RMCS_TFCE_PRIORITY       0x00000010 /* Tx Priority FC ena */
-#define IXGBE_RMCS_ARBDIS       0x00000040 /* Arbitration disable bit */
+#define IXGBE_RMCS_RAC			0x00000004
+/* Deficit Fixed Prio ena */
+#define IXGBE_RMCS_DFP			IXGBE_RMCS_RAC
+#define IXGBE_RMCS_TFCE_802_3X		0x00000008 /* Tx Priority FC ena */
+#define IXGBE_RMCS_TFCE_PRIORITY	0x00000010 /* Tx Priority FC ena */
+#define IXGBE_RMCS_ARBDIS		0x00000040 /* Arbitration disable bit */
 
 /* FCCFG Bit Masks */
-#define IXGBE_FCCFG_TFCE_802_3X         0x00000008 /* Tx link FC enable */
-#define IXGBE_FCCFG_TFCE_PRIORITY       0x00000010 /* Tx priority FC enable */
+#define IXGBE_FCCFG_TFCE_802_3X		0x00000008 /* Tx link FC enable */
+#define IXGBE_FCCFG_TFCE_PRIORITY	0x00000010 /* Tx priority FC enable */
 
 /* Interrupt register bitmasks */
 
 /* Extended Interrupt Cause Read */
-#define IXGBE_EICR_RTX_QUEUE    0x0000FFFF /* RTx Queue Interrupt */
-#define IXGBE_EICR_FLOW_DIR     0x00010000 /* FDir Exception */
-#define IXGBE_EICR_RX_MISS      0x00020000 /* Packet Buffer Overrun */
-#define IXGBE_EICR_PCI          0x00040000 /* PCI Exception */
-#define IXGBE_EICR_MAILBOX      0x00080000 /* VF to PF Mailbox Interrupt */
-#define IXGBE_EICR_LSC          0x00100000 /* Link Status Change */
-#define IXGBE_EICR_LINKSEC      0x00200000 /* PN Threshold */
-#define IXGBE_EICR_MNG          0x00400000 /* Manageability Event Interrupt */
-#define IXGBE_EICR_TS           0x00800000 /* Thermal Sensor Event */
-#define IXGBE_EICR_TIMESYNC     0x01000000 /* Timesync Event */
-#define IXGBE_EICR_GPI_SDP0_8259X	0x01000000 /* Gen Purpose INT on SDP0 */
-#define IXGBE_EICR_GPI_SDP1_8259X	0x02000000 /* Gen Purpose INT on SDP1 */
-#define IXGBE_EICR_GPI_SDP2_8259X	0x04000000 /* Gen Purpose INT on SDP2 */
-#define IXGBE_EICR_GPI_SDP0_X540	0x02000000
-#define IXGBE_EICR_GPI_SDP1_X540	0x04000000
-#define IXGBE_EICR_GPI_SDP2_X540	0x08000000
+#define IXGBE_EICR_RTX_QUEUE	0x0000FFFF /* RTx Queue Interrupt */
+#define IXGBE_EICR_FLOW_DIR	0x00010000 /* FDir Exception */
+#define IXGBE_EICR_RX_MISS	0x00020000 /* Packet Buffer Overrun */
+#define IXGBE_EICR_PCI		0x00040000 /* PCI Exception */
+#define IXGBE_EICR_MAILBOX	0x00080000 /* VF to PF Mailbox Interrupt */
+#define IXGBE_EICR_LSC		0x00100000 /* Link Status Change */
+#define IXGBE_EICR_LINKSEC	0x00200000 /* PN Threshold */
+#define IXGBE_EICR_MNG		0x00400000 /* Manageability Event Interrupt */
+#define IXGBE_EICR_TS		0x00800000 /* Thermal Sensor Event */
+#define IXGBE_EICR_TIMESYNC	0x01000000 /* Timesync Event */
+#define IXGBE_EICR_GPI_SDP0	0x01000000 /* Gen Purpose Interrupt on SDP0 */
+#define IXGBE_EICR_GPI_SDP1	0x02000000 /* Gen Purpose Interrupt on SDP1 */
+#define IXGBE_EICR_GPI_SDP2	0x04000000 /* Gen Purpose Interrupt on SDP2 */
+#define IXGBE_EICR_ECC		0x10000000 /* ECC Error */
+#define IXGBE_EICR_GPI_SDP0_X540 0x02000000 /* Gen Purpose Interrupt on SDP0 */
+#define IXGBE_EICR_GPI_SDP1_X540 0x04000000 /* Gen Purpose Interrupt on SDP1 */
+#define IXGBE_EICR_GPI_SDP2_X540 0x08000000 /* Gen Purpose Interrupt on SDP2 */
 #define IXGBE_EICR_GPI_SDP0_X550	IXGBE_EICR_GPI_SDP0_X540
 #define IXGBE_EICR_GPI_SDP1_X550	IXGBE_EICR_GPI_SDP1_X540
 #define IXGBE_EICR_GPI_SDP2_X550	IXGBE_EICR_GPI_SDP2_X540
@@ -1593,357 +1892,373 @@ enum {
 #define IXGBE_EICR_GPI_SDP0_X550EM_a	IXGBE_EICR_GPI_SDP0_X540
 #define IXGBE_EICR_GPI_SDP1_X550EM_a	IXGBE_EICR_GPI_SDP1_X540
 #define IXGBE_EICR_GPI_SDP2_X550EM_a	IXGBE_EICR_GPI_SDP2_X540
-#define IXGBE_EICR_GPI_SDP0(_hw)	IXGBE_BY_MAC((_hw), EICR_GPI_SDP0)
-#define IXGBE_EICR_GPI_SDP1(_hw)	IXGBE_BY_MAC((_hw), EICR_GPI_SDP1)
-#define IXGBE_EICR_GPI_SDP2(_hw)	IXGBE_BY_MAC((_hw), EICR_GPI_SDP2)
+#define IXGBE_EICR_GPI_SDP0_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), EICR_GPI_SDP0)
+#define IXGBE_EICR_GPI_SDP1_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), EICR_GPI_SDP1)
+#define IXGBE_EICR_GPI_SDP2_BY_MAC(_hw)	IXGBE_BY_MAC((_hw), EICR_GPI_SDP2)
 
-#define IXGBE_EICR_ECC          0x10000000 /* ECC Error */
-#define IXGBE_EICR_PBUR         0x10000000 /* Packet Buffer Handler Error */
-#define IXGBE_EICR_DHER         0x20000000 /* Descriptor Handler Error */
-#define IXGBE_EICR_TCP_TIMER    0x40000000 /* TCP Timer */
-#define IXGBE_EICR_OTHER        0x80000000 /* Interrupt Cause Active */
+#define IXGBE_EICR_PBUR		0x10000000 /* Packet Buffer Handler Error */
+#define IXGBE_EICR_DHER		0x20000000 /* Descriptor Handler Error */
+#define IXGBE_EICR_TCP_TIMER	0x40000000 /* TCP Timer */
+#define IXGBE_EICR_OTHER	0x80000000 /* Interrupt Cause Active */
 
 /* Extended Interrupt Cause Set */
-#define IXGBE_EICS_RTX_QUEUE    IXGBE_EICR_RTX_QUEUE /* RTx Queue Interrupt */
-#define IXGBE_EICS_FLOW_DIR     IXGBE_EICR_FLOW_DIR  /* FDir Exception */
-#define IXGBE_EICS_RX_MISS      IXGBE_EICR_RX_MISS   /* Pkt Buffer Overrun */
-#define IXGBE_EICS_PCI          IXGBE_EICR_PCI       /* PCI Exception */
-#define IXGBE_EICS_MAILBOX      IXGBE_EICR_MAILBOX   /* VF to PF Mailbox Int */
-#define IXGBE_EICS_LSC          IXGBE_EICR_LSC       /* Link Status Change */
-#define IXGBE_EICS_MNG          IXGBE_EICR_MNG       /* MNG Event Interrupt */
-#define IXGBE_EICS_TIMESYNC     IXGBE_EICR_TIMESYNC  /* Timesync Event */
-#define IXGBE_EICS_GPI_SDP0(_hw)	IXGBE_EICR_GPI_SDP0(_hw)
-#define IXGBE_EICS_GPI_SDP1(_hw)	IXGBE_EICR_GPI_SDP1(_hw)
-#define IXGBE_EICS_GPI_SDP2(_hw)	IXGBE_EICR_GPI_SDP2(_hw)
-#define IXGBE_EICS_ECC          IXGBE_EICR_ECC       /* ECC Error */
-#define IXGBE_EICS_PBUR         IXGBE_EICR_PBUR      /* Pkt Buf Handler Err */
-#define IXGBE_EICS_DHER         IXGBE_EICR_DHER      /* Desc Handler Error */
-#define IXGBE_EICS_TCP_TIMER    IXGBE_EICR_TCP_TIMER /* TCP Timer */
-#define IXGBE_EICS_OTHER        IXGBE_EICR_OTHER     /* INT Cause Active */
+#define IXGBE_EICS_RTX_QUEUE	IXGBE_EICR_RTX_QUEUE /* RTx Queue Interrupt */
+#define IXGBE_EICS_FLOW_DIR	IXGBE_EICR_FLOW_DIR  /* FDir Exception */
+#define IXGBE_EICS_RX_MISS	IXGBE_EICR_RX_MISS   /* Pkt Buffer Overrun */
+#define IXGBE_EICS_PCI		IXGBE_EICR_PCI /* PCI Exception */
+#define IXGBE_EICS_MAILBOX	IXGBE_EICR_MAILBOX   /* VF to PF Mailbox Int */
+#define IXGBE_EICS_LSC		IXGBE_EICR_LSC /* Link Status Change */
+#define IXGBE_EICS_MNG		IXGBE_EICR_MNG /* MNG Event Interrupt */
+#define IXGBE_EICS_TIMESYNC	IXGBE_EICR_TIMESYNC /* Timesync Event */
+#define IXGBE_EICS_GPI_SDP0	IXGBE_EICR_GPI_SDP0 /* SDP0 Gen Purpose Int */
+#define IXGBE_EICS_GPI_SDP1	IXGBE_EICR_GPI_SDP1 /* SDP1 Gen Purpose Int */
+#define IXGBE_EICS_GPI_SDP2	IXGBE_EICR_GPI_SDP2 /* SDP2 Gen Purpose Int */
+#define IXGBE_EICS_ECC		IXGBE_EICR_ECC /* ECC Error */
+#define IXGBE_EICS_GPI_SDP0_BY_MAC(_hw)	IXGBE_EICR_GPI_SDP0_BY_MAC(_hw)
+#define IXGBE_EICS_GPI_SDP1_BY_MAC(_hw)	IXGBE_EICR_GPI_SDP1_BY_MAC(_hw)
+#define IXGBE_EICS_GPI_SDP2_BY_MAC(_hw)	IXGBE_EICR_GPI_SDP2_BY_MAC(_hw)
+#define IXGBE_EICS_PBUR		IXGBE_EICR_PBUR /* Pkt Buf Handler Err */
+#define IXGBE_EICS_DHER		IXGBE_EICR_DHER /* Desc Handler Error */
+#define IXGBE_EICS_TCP_TIMER	IXGBE_EICR_TCP_TIMER /* TCP Timer */
+#define IXGBE_EICS_OTHER	IXGBE_EICR_OTHER /* INT Cause Active */
 
 /* Extended Interrupt Mask Set */
-#define IXGBE_EIMS_RTX_QUEUE    IXGBE_EICR_RTX_QUEUE /* RTx Queue Interrupt */
-#define IXGBE_EIMS_FLOW_DIR     IXGBE_EICR_FLOW_DIR  /* FDir Exception */
-#define IXGBE_EIMS_RX_MISS      IXGBE_EICR_RX_MISS   /* Packet Buffer Overrun */
-#define IXGBE_EIMS_PCI          IXGBE_EICR_PCI       /* PCI Exception */
-#define IXGBE_EIMS_MAILBOX      IXGBE_EICR_MAILBOX   /* VF to PF Mailbox Int */
-#define IXGBE_EIMS_LSC          IXGBE_EICR_LSC       /* Link Status Change */
-#define IXGBE_EIMS_MNG          IXGBE_EICR_MNG       /* MNG Event Interrupt */
-#define IXGBE_EIMS_TS           IXGBE_EICR_TS        /* Thermel Sensor Event */
-#define IXGBE_EIMS_TIMESYNC     IXGBE_EICR_TIMESYNC  /* Timesync Event */
-#define IXGBE_EIMS_GPI_SDP0(_hw)	IXGBE_EICR_GPI_SDP0(_hw)
-#define IXGBE_EIMS_GPI_SDP1(_hw)	IXGBE_EICR_GPI_SDP1(_hw)
-#define IXGBE_EIMS_GPI_SDP2(_hw)	IXGBE_EICR_GPI_SDP2(_hw)
-#define IXGBE_EIMS_ECC          IXGBE_EICR_ECC       /* ECC Error */
-#define IXGBE_EIMS_PBUR         IXGBE_EICR_PBUR      /* Pkt Buf Handler Err */
-#define IXGBE_EIMS_DHER         IXGBE_EICR_DHER      /* Descr Handler Error */
-#define IXGBE_EIMS_TCP_TIMER    IXGBE_EICR_TCP_TIMER /* TCP Timer */
-#define IXGBE_EIMS_OTHER        IXGBE_EICR_OTHER     /* INT Cause Active */
+#define IXGBE_EIMS_RTX_QUEUE	IXGBE_EICR_RTX_QUEUE /* RTx Queue Interrupt */
+#define IXGBE_EIMS_FLOW_DIR	IXGBE_EICR_FLOW_DIR /* FDir Exception */
+#define IXGBE_EIMS_RX_MISS	IXGBE_EICR_RX_MISS /* Packet Buffer Overrun */
+#define IXGBE_EIMS_PCI		IXGBE_EICR_PCI /* PCI Exception */
+#define IXGBE_EIMS_MAILBOX	IXGBE_EICR_MAILBOX   /* VF to PF Mailbox Int */
+#define IXGBE_EIMS_LSC		IXGBE_EICR_LSC /* Link Status Change */
+#define IXGBE_EIMS_MNG		IXGBE_EICR_MNG /* MNG Event Interrupt */
+#define IXGBE_EIMS_TS		IXGBE_EICR_TS /* Thermal Sensor Event */
+#define IXGBE_EIMS_TIMESYNC	IXGBE_EICR_TIMESYNC /* Timesync Event */
+#define IXGBE_EIMS_GPI_SDP0	IXGBE_EICR_GPI_SDP0 /* SDP0 Gen Purpose Int */
+#define IXGBE_EIMS_GPI_SDP1	IXGBE_EICR_GPI_SDP1 /* SDP1 Gen Purpose Int */
+#define IXGBE_EIMS_GPI_SDP2	IXGBE_EICR_GPI_SDP2 /* SDP2 Gen Purpose Int */
+#define IXGBE_EIMS_ECC		IXGBE_EICR_ECC /* ECC Error */
+#define IXGBE_EIMS_GPI_SDP0_BY_MAC(_hw)	IXGBE_EICR_GPI_SDP0_BY_MAC(_hw)
+#define IXGBE_EIMS_GPI_SDP1_BY_MAC(_hw)	IXGBE_EICR_GPI_SDP1_BY_MAC(_hw)
+#define IXGBE_EIMS_GPI_SDP2_BY_MAC(_hw)	IXGBE_EICR_GPI_SDP2_BY_MAC(_hw)
+#define IXGBE_EIMS_PBUR		IXGBE_EICR_PBUR /* Pkt Buf Handler Err */
+#define IXGBE_EIMS_DHER		IXGBE_EICR_DHER /* Descr Handler Error */
+#define IXGBE_EIMS_TCP_TIMER	IXGBE_EICR_TCP_TIMER /* TCP Timer */
+#define IXGBE_EIMS_OTHER	IXGBE_EICR_OTHER /* INT Cause Active */
 
 /* Extended Interrupt Mask Clear */
-#define IXGBE_EIMC_RTX_QUEUE    IXGBE_EICR_RTX_QUEUE /* RTx Queue Interrupt */
-#define IXGBE_EIMC_FLOW_DIR     IXGBE_EICR_FLOW_DIR  /* FDir Exception */
-#define IXGBE_EIMC_RX_MISS      IXGBE_EICR_RX_MISS   /* Packet Buffer Overrun */
-#define IXGBE_EIMC_PCI          IXGBE_EICR_PCI       /* PCI Exception */
-#define IXGBE_EIMC_MAILBOX      IXGBE_EICR_MAILBOX   /* VF to PF Mailbox Int */
-#define IXGBE_EIMC_LSC          IXGBE_EICR_LSC       /* Link Status Change */
-#define IXGBE_EIMC_MNG          IXGBE_EICR_MNG       /* MNG Event Interrupt */
-#define IXGBE_EIMC_TIMESYNC     IXGBE_EICR_TIMESYNC  /* Timesync Event */
-#define IXGBE_EIMC_GPI_SDP0(_hw)	IXGBE_EICR_GPI_SDP0(_hw)
-#define IXGBE_EIMC_GPI_SDP1(_hw)	IXGBE_EICR_GPI_SDP1(_hw)
-#define IXGBE_EIMC_GPI_SDP2(_hw)	IXGBE_EICR_GPI_SDP2(_hw)
-#define IXGBE_EIMC_ECC          IXGBE_EICR_ECC       /* ECC Error */
-#define IXGBE_EIMC_PBUR         IXGBE_EICR_PBUR      /* Pkt Buf Handler Err */
-#define IXGBE_EIMC_DHER         IXGBE_EICR_DHER      /* Desc Handler Err */
-#define IXGBE_EIMC_TCP_TIMER    IXGBE_EICR_TCP_TIMER /* TCP Timer */
-#define IXGBE_EIMC_OTHER        IXGBE_EICR_OTHER     /* INT Cause Active */
+#define IXGBE_EIMC_RTX_QUEUE	IXGBE_EICR_RTX_QUEUE /* RTx Queue Interrupt */
+#define IXGBE_EIMC_FLOW_DIR	IXGBE_EICR_FLOW_DIR /* FDir Exception */
+#define IXGBE_EIMC_RX_MISS	IXGBE_EICR_RX_MISS /* Packet Buffer Overrun */
+#define IXGBE_EIMC_PCI		IXGBE_EICR_PCI /* PCI Exception */
+#define IXGBE_EIMC_MAILBOX	IXGBE_EICR_MAILBOX /* VF to PF Mailbox Int */
+#define IXGBE_EIMC_LSC		IXGBE_EICR_LSC /* Link Status Change */
+#define IXGBE_EIMC_MNG		IXGBE_EICR_MNG /* MNG Event Interrupt */
+#define IXGBE_EIMC_TIMESYNC	IXGBE_EICR_TIMESYNC /* Timesync Event */
+#define IXGBE_EIMC_GPI_SDP0	IXGBE_EICR_GPI_SDP0 /* SDP0 Gen Purpose Int */
+#define IXGBE_EIMC_GPI_SDP1	IXGBE_EICR_GPI_SDP1 /* SDP1 Gen Purpose Int */
+#define IXGBE_EIMC_GPI_SDP2	IXGBE_EICR_GPI_SDP2  /* SDP2 Gen Purpose Int */
+#define IXGBE_EIMC_ECC		IXGBE_EICR_ECC /* ECC Error */
+#define IXGBE_EIMC_GPI_SDP0_BY_MAC(_hw)	IXGBE_EICR_GPI_SDP0_BY_MAC(_hw)
+#define IXGBE_EIMC_GPI_SDP1_BY_MAC(_hw)	IXGBE_EICR_GPI_SDP1_BY_MAC(_hw)
+#define IXGBE_EIMC_GPI_SDP2_BY_MAC(_hw)	IXGBE_EICR_GPI_SDP2_BY_MAC(_hw)
+#define IXGBE_EIMC_PBUR		IXGBE_EICR_PBUR /* Pkt Buf Handler Err */
+#define IXGBE_EIMC_DHER		IXGBE_EICR_DHER /* Desc Handler Err */
+#define IXGBE_EIMC_TCP_TIMER	IXGBE_EICR_TCP_TIMER /* TCP Timer */
+#define IXGBE_EIMC_OTHER	IXGBE_EICR_OTHER /* INT Cause Active */
 
 #define IXGBE_EIMS_ENABLE_MASK ( \
-				IXGBE_EIMS_RTX_QUEUE       | \
-				IXGBE_EIMS_LSC             | \
-				IXGBE_EIMS_TCP_TIMER       | \
+				IXGBE_EIMS_RTX_QUEUE	| \
+				IXGBE_EIMS_LSC		| \
+				IXGBE_EIMS_TCP_TIMER	| \
 				IXGBE_EIMS_OTHER)
 
 /* Immediate Interrupt Rx (A.K.A. Low Latency Interrupt) */
-#define IXGBE_IMIR_PORT_IM_EN     0x00010000  /* TCP port enable */
-#define IXGBE_IMIR_PORT_BP        0x00020000  /* TCP port check bypass */
-#define IXGBE_IMIREXT_SIZE_BP     0x00001000  /* Packet size bypass */
-#define IXGBE_IMIREXT_CTRL_URG    0x00002000  /* Check URG bit in header */
-#define IXGBE_IMIREXT_CTRL_ACK    0x00004000  /* Check ACK bit in header */
-#define IXGBE_IMIREXT_CTRL_PSH    0x00008000  /* Check PSH bit in header */
-#define IXGBE_IMIREXT_CTRL_RST    0x00010000  /* Check RST bit in header */
-#define IXGBE_IMIREXT_CTRL_SYN    0x00020000  /* Check SYN bit in header */
-#define IXGBE_IMIREXT_CTRL_FIN    0x00040000  /* Check FIN bit in header */
-#define IXGBE_IMIREXT_CTRL_BP     0x00080000  /* Bypass check of control bits */
-#define IXGBE_IMIR_SIZE_BP_82599  0x00001000 /* Packet size bypass */
-#define IXGBE_IMIR_CTRL_URG_82599 0x00002000 /* Check URG bit in header */
-#define IXGBE_IMIR_CTRL_ACK_82599 0x00004000 /* Check ACK bit in header */
-#define IXGBE_IMIR_CTRL_PSH_82599 0x00008000 /* Check PSH bit in header */
-#define IXGBE_IMIR_CTRL_RST_82599 0x00010000 /* Check RST bit in header */
-#define IXGBE_IMIR_CTRL_SYN_82599 0x00020000 /* Check SYN bit in header */
-#define IXGBE_IMIR_CTRL_FIN_82599 0x00040000 /* Check FIN bit in header */
-#define IXGBE_IMIR_CTRL_BP_82599  0x00080000 /* Bypass check of control bits */
-#define IXGBE_IMIR_LLI_EN_82599   0x00100000 /* Enables low latency Int */
-#define IXGBE_IMIR_RX_QUEUE_MASK_82599  0x0000007F /* Rx Queue Mask */
-#define IXGBE_IMIR_RX_QUEUE_SHIFT_82599 21 /* Rx Queue Shift */
-#define IXGBE_IMIRVP_PRIORITY_MASK      0x00000007 /* VLAN priority mask */
-#define IXGBE_IMIRVP_PRIORITY_EN        0x00000008 /* VLAN priority enable */
-
-#define IXGBE_MAX_FTQF_FILTERS          128
-#define IXGBE_FTQF_PROTOCOL_MASK        0x00000003
-#define IXGBE_FTQF_PROTOCOL_TCP         0x00000000
-#define IXGBE_FTQF_PROTOCOL_UDP         0x00000001
-#define IXGBE_FTQF_PROTOCOL_SCTP        2
-#define IXGBE_FTQF_PRIORITY_MASK        0x00000007
-#define IXGBE_FTQF_PRIORITY_SHIFT       2
-#define IXGBE_FTQF_POOL_MASK            0x0000003F
-#define IXGBE_FTQF_POOL_SHIFT           8
-#define IXGBE_FTQF_5TUPLE_MASK_MASK     0x0000001F
-#define IXGBE_FTQF_5TUPLE_MASK_SHIFT    25
-#define IXGBE_FTQF_SOURCE_ADDR_MASK     0x1E
-#define IXGBE_FTQF_DEST_ADDR_MASK       0x1D
-#define IXGBE_FTQF_SOURCE_PORT_MASK     0x1B
-#define IXGBE_FTQF_DEST_PORT_MASK       0x17
-#define IXGBE_FTQF_PROTOCOL_COMP_MASK   0x0F
-#define IXGBE_FTQF_POOL_MASK_EN         0x40000000
-#define IXGBE_FTQF_QUEUE_ENABLE         0x80000000
+#define IXGBE_IMIR_PORT_IM_EN	0x00010000  /* TCP port enable */
+#define IXGBE_IMIR_PORT_BP	0x00020000  /* TCP port check bypass */
+#define IXGBE_IMIREXT_SIZE_BP	0x00001000  /* Packet size bypass */
+#define IXGBE_IMIREXT_CTRL_URG	0x00002000  /* Check URG bit in header */
+#define IXGBE_IMIREXT_CTRL_ACK	0x00004000  /* Check ACK bit in header */
+#define IXGBE_IMIREXT_CTRL_PSH	0x00008000  /* Check PSH bit in header */
+#define IXGBE_IMIREXT_CTRL_RST	0x00010000  /* Check RST bit in header */
+#define IXGBE_IMIREXT_CTRL_SYN	0x00020000  /* Check SYN bit in header */
+#define IXGBE_IMIREXT_CTRL_FIN	0x00040000  /* Check FIN bit in header */
+#define IXGBE_IMIREXT_CTRL_BP	0x00080000  /* Bypass check of control bits */
+#define IXGBE_IMIR_SIZE_BP_82599	0x00001000 /* Packet size bypass */
+#define IXGBE_IMIR_CTRL_URG_82599	0x00002000 /* Check URG bit in header */
+#define IXGBE_IMIR_CTRL_ACK_82599	0x00004000 /* Check ACK bit in header */
+#define IXGBE_IMIR_CTRL_PSH_82599	0x00008000 /* Check PSH bit in header */
+#define IXGBE_IMIR_CTRL_RST_82599	0x00010000 /* Check RST bit in header */
+#define IXGBE_IMIR_CTRL_SYN_82599	0x00020000 /* Check SYN bit in header */
+#define IXGBE_IMIR_CTRL_FIN_82599	0x00040000 /* Check FIN bit in header */
+#define IXGBE_IMIR_CTRL_BP_82599	0x00080000 /* Bypass chk of ctrl bits */
+#define IXGBE_IMIR_LLI_EN_82599		0x00100000 /* Enables low latency Int */
+#define IXGBE_IMIR_RX_QUEUE_MASK_82599	0x0000007F /* Rx Queue Mask */
+#define IXGBE_IMIR_RX_QUEUE_SHIFT_82599	21 /* Rx Queue Shift */
+#define IXGBE_IMIRVP_PRIORITY_MASK	0x00000007 /* VLAN priority mask */
+#define IXGBE_IMIRVP_PRIORITY_EN	0x00000008 /* VLAN priority enable */
+
+#define IXGBE_MAX_FTQF_FILTERS		128
+#define IXGBE_FTQF_PROTOCOL_MASK	0x00000003
+#define IXGBE_FTQF_PROTOCOL_TCP		0x00000000
+#define IXGBE_FTQF_PROTOCOL_UDP		0x00000001
+#define IXGBE_FTQF_PROTOCOL_SCTP	2
+#define IXGBE_FTQF_PRIORITY_MASK	0x00000007
+#define IXGBE_FTQF_PRIORITY_SHIFT	2
+#define IXGBE_FTQF_POOL_MASK		0x0000003F
+#define IXGBE_FTQF_POOL_SHIFT		8
+#define IXGBE_FTQF_5TUPLE_MASK_MASK	0x0000001F
+#define IXGBE_FTQF_5TUPLE_MASK_SHIFT	25
+#define IXGBE_FTQF_SOURCE_ADDR_MASK	0x1E
+#define IXGBE_FTQF_DEST_ADDR_MASK	0x1D
+#define IXGBE_FTQF_SOURCE_PORT_MASK	0x1B
+#define IXGBE_FTQF_DEST_PORT_MASK	0x17
+#define IXGBE_FTQF_PROTOCOL_COMP_MASK	0x0F
+#define IXGBE_FTQF_POOL_MASK_EN		0x40000000
+#define IXGBE_FTQF_QUEUE_ENABLE		0x80000000
 
 /* Interrupt clear mask */
-#define IXGBE_IRQ_CLEAR_MASK    0xFFFFFFFF
+#define IXGBE_IRQ_CLEAR_MASK	0xFFFFFFFF
 
 /* Interrupt Vector Allocation Registers */
-#define IXGBE_IVAR_REG_NUM      25
-#define IXGBE_IVAR_REG_NUM_82599       64
-#define IXGBE_IVAR_TXRX_ENTRY   96
-#define IXGBE_IVAR_RX_ENTRY     64
-#define IXGBE_IVAR_RX_QUEUE(_i)    (0 + (_i))
-#define IXGBE_IVAR_TX_QUEUE(_i)    (64 + (_i))
-#define IXGBE_IVAR_TX_ENTRY     32
+#define IXGBE_IVAR_REG_NUM		25
+#define IXGBE_IVAR_REG_NUM_82599	64
+#define IXGBE_IVAR_TXRX_ENTRY		96
+#define IXGBE_IVAR_RX_ENTRY		64
+#define IXGBE_IVAR_RX_QUEUE(_i)		(0 + (_i))
+#define IXGBE_IVAR_TX_QUEUE(_i)		(64 + (_i))
+#define IXGBE_IVAR_TX_ENTRY		32
 
-#define IXGBE_IVAR_TCP_TIMER_INDEX       96 /* 0 based index */
-#define IXGBE_IVAR_OTHER_CAUSES_INDEX    97 /* 0 based index */
+#define IXGBE_IVAR_TCP_TIMER_INDEX	96 /* 0 based index */
+#define IXGBE_IVAR_OTHER_CAUSES_INDEX	97 /* 0 based index */
 
-#define IXGBE_MSIX_VECTOR(_i)   (0 + (_i))
+#define IXGBE_MSIX_VECTOR(_i)		(0 + (_i))
 
-#define IXGBE_IVAR_ALLOC_VAL    0x80 /* Interrupt Allocation valid */
+#define IXGBE_IVAR_ALLOC_VAL		0x80 /* Interrupt Allocation valid */
 
 /* ETYPE Queue Filter/Select Bit Masks */
-#define IXGBE_MAX_ETQF_FILTERS  8
-#define IXGBE_ETQF_FCOE         0x08000000 /* bit 27 */
-#define IXGBE_ETQF_BCN          0x10000000 /* bit 28 */
-#define IXGBE_ETQF_TX_ANTISPOOF	0x20000000 /* bit 29 */
-#define IXGBE_ETQF_1588         0x40000000 /* bit 30 */
-#define IXGBE_ETQF_FILTER_EN    0x80000000 /* bit 31 */
-#define IXGBE_ETQF_POOL_ENABLE   (1 << 26) /* bit 26 */
+#define IXGBE_MAX_ETQF_FILTERS		8
+#define IXGBE_ETQF_FCOE			0x08000000 /* bit 27 */
+#define IXGBE_ETQF_BCN			0x10000000 /* bit 28 */
+#define IXGBE_ETQF_TX_ANTISPOOF		0x20000000 /* bit 29 */
+#define IXGBE_ETQF_1588			0x40000000 /* bit 30 */
+#define IXGBE_ETQF_FILTER_EN		0x80000000 /* bit 31 */
+#define IXGBE_ETQF_POOL_ENABLE		(1 << 26) /* bit 26 */
 #define IXGBE_ETQF_POOL_SHIFT		20
 
-#define IXGBE_ETQS_RX_QUEUE     0x007F0000 /* bits 22:16 */
-#define IXGBE_ETQS_RX_QUEUE_SHIFT       16
-#define IXGBE_ETQS_LLI          0x20000000 /* bit 29 */
-#define IXGBE_ETQS_QUEUE_EN     0x80000000 /* bit 31 */
+#define IXGBE_ETQS_RX_QUEUE		0x007F0000 /* bits 22:16 */
+#define IXGBE_ETQS_RX_QUEUE_SHIFT	16
+#define IXGBE_ETQS_LLI			0x20000000 /* bit 29 */
+#define IXGBE_ETQS_QUEUE_EN		0x80000000 /* bit 31 */
 
 /*
  * ETQF filter list: one static filter per filter consumer. This is
- *                   to avoid filter collisions later. Add new filters
- *                   here!!
+ *		   to avoid filter collisions later. Add new filters
+ *		   here!!
  *
  * Current filters:
- *    EAPOL 802.1x (0x888e): Filter 0
- *    FCoE (0x8906):         Filter 2
- *    1588 (0x88f7):         Filter 3
- *    FIP  (0x8914):         Filter 4
- *    LLDP (0x88CC):         Filter 5
- *    LACP (0x8809):         Filter 6
- *    FC   (0x8808):         Filter 7
+ *	EAPOL 802.1x (0x888e): Filter 0
+ *	FCoE (0x8906):	 Filter 2
+ *	1588 (0x88f7):	 Filter 3
+ *	FIP  (0x8914):	 Filter 4
+ *	LLDP (0x88CC):	 Filter 5
+ *	LACP (0x8809):	 Filter 6
+ *	FC   (0x8808):	 Filter 7
  */
-#define IXGBE_ETQF_FILTER_EAPOL          0
-#define IXGBE_ETQF_FILTER_FCOE           2
-#define IXGBE_ETQF_FILTER_1588           3
-#define IXGBE_ETQF_FILTER_FIP            4
-#define IXGBE_ETQF_FILTER_LLDP		 5
-#define IXGBE_ETQF_FILTER_LACP		 6
-#define IXGBE_ETQF_FILTER_FC		 7
-
+#define IXGBE_ETQF_FILTER_EAPOL		0
+#define IXGBE_ETQF_FILTER_FCOE		2
+#define IXGBE_ETQF_FILTER_1588		3
+#define IXGBE_ETQF_FILTER_FIP		4
+#define IXGBE_ETQF_FILTER_LLDP		5
+#define IXGBE_ETQF_FILTER_LACP		6
+#define IXGBE_ETQF_FILTER_FC		7
 /* VLAN Control Bit Masks */
-#define IXGBE_VLNCTRL_VET       0x0000FFFF  /* bits 0-15 */
-#define IXGBE_VLNCTRL_CFI       0x10000000  /* bit 28 */
-#define IXGBE_VLNCTRL_CFIEN     0x20000000  /* bit 29 */
-#define IXGBE_VLNCTRL_VFE       0x40000000  /* bit 30 */
-#define IXGBE_VLNCTRL_VME       0x80000000  /* bit 31 */
+#define IXGBE_VLNCTRL_VET		0x0000FFFF  /* bits 0-15 */
+#define IXGBE_VLNCTRL_CFI		0x10000000  /* bit 28 */
+#define IXGBE_VLNCTRL_CFIEN		0x20000000  /* bit 29 */
+#define IXGBE_VLNCTRL_VFE		0x40000000  /* bit 30 */
+#define IXGBE_VLNCTRL_VME		0x80000000  /* bit 31 */
 
 /* VLAN pool filtering masks */
-#define IXGBE_VLVF_VIEN         0x80000000  /* filter is valid */
-#define IXGBE_VLVF_ENTRIES      64
-#define IXGBE_VLVF_VLANID_MASK  0x00000FFF
-
+#define IXGBE_VLVF_VIEN			0x80000000  /* filter is valid */
+#define IXGBE_VLVF_ENTRIES		64
+#define IXGBE_VLVF_VLANID_MASK		0x00000FFF
 /* Per VF Port VLAN insertion rules */
-#define IXGBE_VMVIR_VLANA_DEFAULT 0x40000000 /* Always use default VLAN */
-#define IXGBE_VMVIR_VLANA_NEVER   0x80000000 /* Never insert VLAN tag */
+#define IXGBE_VMVIR_VLANA_DEFAULT	0x40000000 /* Always use default VLAN */
+#define IXGBE_VMVIR_VLANA_NEVER		0x80000000 /* Never insert VLAN tag */
 
-#define IXGBE_ETHERNET_IEEE_VLAN_TYPE 0x8100  /* 802.1q protocol */
+#define IXGBE_ETHERNET_IEEE_VLAN_TYPE	0x8100  /* 802.1q protocol */
 
 /* STATUS Bit Masks */
-#define IXGBE_STATUS_LAN_ID         0x0000000C /* LAN ID */
-#define IXGBE_STATUS_LAN_ID_SHIFT   2          /* LAN ID Shift*/
-#define IXGBE_STATUS_GIO            0x00080000 /* GIO Master Enable Status */
+#define IXGBE_STATUS_LAN_ID		0x0000000C /* LAN ID */
+#define IXGBE_STATUS_LAN_ID_SHIFT	2 /* LAN ID Shift*/
+#define IXGBE_STATUS_GIO		0x00080000 /* GIO Master Ena Status */
 
-#define IXGBE_STATUS_LAN_ID_0   0x00000000 /* LAN ID 0 */
-#define IXGBE_STATUS_LAN_ID_1   0x00000004 /* LAN ID 1 */
+#define IXGBE_STATUS_LAN_ID_0	0x00000000 /* LAN ID 0 */
+#define IXGBE_STATUS_LAN_ID_1	0x00000004 /* LAN ID 1 */
 
 /* ESDP Bit Masks */
-#define IXGBE_ESDP_SDP0 0x00000001 /* SDP0 Data Value */
-#define IXGBE_ESDP_SDP1 0x00000002 /* SDP1 Data Value */
-#define IXGBE_ESDP_SDP2 0x00000004 /* SDP2 Data Value */
-#define IXGBE_ESDP_SDP3 0x00000008 /* SDP3 Data Value */
-#define IXGBE_ESDP_SDP4 0x00000010 /* SDP4 Data Value */
-#define IXGBE_ESDP_SDP5 0x00000020 /* SDP5 Data Value */
-#define IXGBE_ESDP_SDP6 0x00000040 /* SDP6 Data Value */
-#define IXGBE_ESDP_SDP0_DIR     0x00000100 /* SDP0 IO direction */
-#define IXGBE_ESDP_SDP1_DIR     0x00000200 /* SDP1 IO direction */
-#define IXGBE_ESDP_SDP4_DIR     0x00000004 /* SDP4 IO direction */
-#define IXGBE_ESDP_SDP5_DIR     0x00002000 /* SDP5 IO direction */
-#define IXGBE_ESDP_SDP0_NATIVE  0x00010000 /* SDP0 Native Function */
-#define IXGBE_ESDP_SDP1_NATIVE  0x00020000 /* SDP1 IO mode */
+#define IXGBE_ESDP_SDP0		0x00000001 /* SDP0 Data Value */
+#define IXGBE_ESDP_SDP1		0x00000002 /* SDP1 Data Value */
+#define IXGBE_ESDP_SDP2		0x00000004 /* SDP2 Data Value */
+#define IXGBE_ESDP_SDP3		0x00000008 /* SDP3 Data Value */
+#define IXGBE_ESDP_SDP4		0x00000010 /* SDP4 Data Value */
+#define IXGBE_ESDP_SDP5		0x00000020 /* SDP5 Data Value */
+#define IXGBE_ESDP_SDP6		0x00000040 /* SDP6 Data Value */
+#define IXGBE_ESDP_SDP7		0x00000080 /* SDP7 Data Value */
+#define IXGBE_ESDP_SDP0_DIR	0x00000100 /* SDP0 IO direction */
+#define IXGBE_ESDP_SDP1_DIR	0x00000200 /* SDP1 IO direction */
+#define IXGBE_ESDP_SDP2_DIR	0x00000400 /* SDP1 IO direction */
+#define IXGBE_ESDP_SDP3_DIR	0x00000800 /* SDP3 IO direction */
+#define IXGBE_ESDP_SDP4_DIR	0x00001000 /* SDP4 IO direction */
+#define IXGBE_ESDP_SDP5_DIR	0x00002000 /* SDP5 IO direction */
+#define IXGBE_ESDP_SDP6_DIR	0x00004000 /* SDP6 IO direction */
+#define IXGBE_ESDP_SDP7_DIR	0x00008000 /* SDP7 IO direction */
+#define IXGBE_ESDP_SDP0_NATIVE	0x00010000 /* SDP0 IO mode */
+#define IXGBE_ESDP_SDP1_NATIVE	0x00020000 /* SDP1 IO mode */
+
 
 /* LEDCTL Bit Masks */
-#define IXGBE_LED_IVRT_BASE      0x00000040
-#define IXGBE_LED_BLINK_BASE     0x00000080
-#define IXGBE_LED_MODE_MASK_BASE 0x0000000F
-#define IXGBE_LED_OFFSET(_base, _i) (_base << (8 * (_i)))
-#define IXGBE_LED_MODE_SHIFT(_i) (8 * (_i))
-#define IXGBE_LED_IVRT(_i)       IXGBE_LED_OFFSET(IXGBE_LED_IVRT_BASE, _i)
-#define IXGBE_LED_BLINK(_i)      IXGBE_LED_OFFSET(IXGBE_LED_BLINK_BASE, _i)
-#define IXGBE_LED_MODE_MASK(_i)  IXGBE_LED_OFFSET(IXGBE_LED_MODE_MASK_BASE, _i)
+#define IXGBE_LED_IVRT_BASE		0x00000040
+#define IXGBE_LED_BLINK_BASE		0x00000080
+#define IXGBE_LED_MODE_MASK_BASE	0x0000000F
+#define IXGBE_LED_OFFSET(_base, _i)	(_base << (8 * (_i)))
+#define IXGBE_LED_MODE_SHIFT(_i)	(8*(_i))
+#define IXGBE_LED_IVRT(_i)	IXGBE_LED_OFFSET(IXGBE_LED_IVRT_BASE, _i)
+#define IXGBE_LED_BLINK(_i)	IXGBE_LED_OFFSET(IXGBE_LED_BLINK_BASE, _i)
+#define IXGBE_LED_MODE_MASK(_i)	IXGBE_LED_OFFSET(IXGBE_LED_MODE_MASK_BASE, _i)
+#define IXGBE_X557_LED_MANUAL_SET_MASK	(1 << 8)
+#define IXGBE_X557_MAX_LED_INDEX	3
+#define IXGBE_X557_LED_PROVISIONING	0xC430
 
 /* LED modes */
-#define IXGBE_LED_LINK_UP       0x0
-#define IXGBE_LED_LINK_10G      0x1
-#define IXGBE_LED_MAC           0x2
-#define IXGBE_LED_FILTER        0x3
-#define IXGBE_LED_LINK_ACTIVE   0x4
-#define IXGBE_LED_LINK_1G       0x5
-#define IXGBE_LED_ON            0xE
-#define IXGBE_LED_OFF           0xF
+#define IXGBE_LED_LINK_UP	0x0
+#define IXGBE_LED_LINK_10G	0x1
+#define IXGBE_LED_MAC		0x2
+#define IXGBE_LED_FILTER	0x3
+#define IXGBE_LED_LINK_ACTIVE	0x4
+#define IXGBE_LED_LINK_1G	0x5
+#define IXGBE_LED_ON		0xE
+#define IXGBE_LED_OFF		0xF
 
 /* AUTOC Bit Masks */
 #define IXGBE_AUTOC_KX4_KX_SUPP_MASK 0xC0000000
-#define IXGBE_AUTOC_KX4_SUPP    0x80000000
-#define IXGBE_AUTOC_KX_SUPP     0x40000000
-#define IXGBE_AUTOC_PAUSE       0x30000000
-#define IXGBE_AUTOC_ASM_PAUSE   0x20000000
-#define IXGBE_AUTOC_SYM_PAUSE   0x10000000
-#define IXGBE_AUTOC_RF          0x08000000
-#define IXGBE_AUTOC_PD_TMR      0x06000000
-#define IXGBE_AUTOC_AN_RX_LOOSE 0x01000000
-#define IXGBE_AUTOC_AN_RX_DRIFT 0x00800000
-#define IXGBE_AUTOC_AN_RX_ALIGN 0x007C0000
-#define IXGBE_AUTOC_FECA        0x00040000
-#define IXGBE_AUTOC_FECR        0x00020000
-#define IXGBE_AUTOC_KR_SUPP     0x00010000
-#define IXGBE_AUTOC_AN_RESTART  0x00001000
-#define IXGBE_AUTOC_FLU         0x00000001
-#define IXGBE_AUTOC_LMS_SHIFT   13
-#define IXGBE_AUTOC_LMS_10G_SERIAL      (0x3 << IXGBE_AUTOC_LMS_SHIFT)
-#define IXGBE_AUTOC_LMS_KX4_KX_KR       (0x4 << IXGBE_AUTOC_LMS_SHIFT)
-#define IXGBE_AUTOC_LMS_SGMII_1G_100M   (0x5 << IXGBE_AUTOC_LMS_SHIFT)
-#define IXGBE_AUTOC_LMS_KX4_KX_KR_1G_AN (0x6 << IXGBE_AUTOC_LMS_SHIFT)
-#define IXGBE_AUTOC_LMS_KX4_KX_KR_SGMII (0x7 << IXGBE_AUTOC_LMS_SHIFT)
-#define IXGBE_AUTOC_LMS_MASK            (0x7 << IXGBE_AUTOC_LMS_SHIFT)
-#define IXGBE_AUTOC_LMS_1G_LINK_NO_AN   (0x0 << IXGBE_AUTOC_LMS_SHIFT)
-#define IXGBE_AUTOC_LMS_10G_LINK_NO_AN  (0x1 << IXGBE_AUTOC_LMS_SHIFT)
-#define IXGBE_AUTOC_LMS_1G_AN           (0x2 << IXGBE_AUTOC_LMS_SHIFT)
-#define IXGBE_AUTOC_LMS_KX4_AN          (0x4 << IXGBE_AUTOC_LMS_SHIFT)
-#define IXGBE_AUTOC_LMS_KX4_AN_1G_AN    (0x6 << IXGBE_AUTOC_LMS_SHIFT)
-#define IXGBE_AUTOC_LMS_ATTACH_TYPE     (0x7 << IXGBE_AUTOC_10G_PMA_PMD_SHIFT)
-
-#define IXGBE_AUTOC_1G_PMA_PMD_MASK    0x00000200
-#define IXGBE_AUTOC_1G_PMA_PMD_SHIFT   9
-#define IXGBE_AUTOC_10G_PMA_PMD_MASK   0x00000180
-#define IXGBE_AUTOC_10G_PMA_PMD_SHIFT  7
-#define IXGBE_AUTOC_10G_XAUI   (0x0 << IXGBE_AUTOC_10G_PMA_PMD_SHIFT)
-#define IXGBE_AUTOC_10G_KX4    (0x1 << IXGBE_AUTOC_10G_PMA_PMD_SHIFT)
-#define IXGBE_AUTOC_10G_CX4    (0x2 << IXGBE_AUTOC_10G_PMA_PMD_SHIFT)
-#define IXGBE_AUTOC_1G_BX      (0x0 << IXGBE_AUTOC_1G_PMA_PMD_SHIFT)
-#define IXGBE_AUTOC_1G_KX      (0x1 << IXGBE_AUTOC_1G_PMA_PMD_SHIFT)
-#define IXGBE_AUTOC_1G_SFI     (0x0 << IXGBE_AUTOC_1G_PMA_PMD_SHIFT)
-#define IXGBE_AUTOC_1G_KX_BX   (0x1 << IXGBE_AUTOC_1G_PMA_PMD_SHIFT)
-
-#define IXGBE_AUTOC2_UPPER_MASK  0xFFFF0000
-#define IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_MASK  0x00030000
-#define IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_SHIFT 16
-#define IXGBE_AUTOC2_10G_KR  (0x0 << IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_SHIFT)
-#define IXGBE_AUTOC2_10G_XFI (0x1 << IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_SHIFT)
-#define IXGBE_AUTOC2_10G_SFI (0x2 << IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_SHIFT)
-#define IXGBE_AUTOC2_LINK_DISABLE_ON_D3_MASK  0x50000000
-#define IXGBE_AUTOC2_LINK_DISABLE_MASK        0x70000000
-
-#define IXGBE_MACC_FLU       0x00000001
-#define IXGBE_MACC_FSV_10G   0x00030000
-#define IXGBE_MACC_FS        0x00040000
-#define IXGBE_MAC_RX2TX_LPBK 0x00000002
-
-/* Veto Bit definition */
-#define IXGBE_MMNGC_MNG_VETO  0x00000001
+#define IXGBE_AUTOC_KX4_SUPP	0x80000000
+#define IXGBE_AUTOC_KX_SUPP	0x40000000
+#define IXGBE_AUTOC_PAUSE	0x30000000
+#define IXGBE_AUTOC_ASM_PAUSE	0x20000000
+#define IXGBE_AUTOC_SYM_PAUSE	0x10000000
+#define IXGBE_AUTOC_RF		0x08000000
+#define IXGBE_AUTOC_PD_TMR	0x06000000
+#define IXGBE_AUTOC_AN_RX_LOOSE	0x01000000
+#define IXGBE_AUTOC_AN_RX_DRIFT	0x00800000
+#define IXGBE_AUTOC_AN_RX_ALIGN	0x007C0000
+#define IXGBE_AUTOC_FECA	0x00040000
+#define IXGBE_AUTOC_FECR	0x00020000
+#define IXGBE_AUTOC_KR_SUPP	0x00010000
+#define IXGBE_AUTOC_AN_RESTART	0x00001000
+#define IXGBE_AUTOC_FLU		0x00000001
+#define IXGBE_AUTOC_LMS_SHIFT	13
+#define IXGBE_AUTOC_LMS_10G_SERIAL	(0x3 << IXGBE_AUTOC_LMS_SHIFT)
+#define IXGBE_AUTOC_LMS_KX4_KX_KR	(0x4 << IXGBE_AUTOC_LMS_SHIFT)
+#define IXGBE_AUTOC_LMS_SGMII_1G_100M	(0x5 << IXGBE_AUTOC_LMS_SHIFT)
+#define IXGBE_AUTOC_LMS_KX4_KX_KR_1G_AN	(0x6 << IXGBE_AUTOC_LMS_SHIFT)
+#define IXGBE_AUTOC_LMS_KX4_KX_KR_SGMII	(0x7 << IXGBE_AUTOC_LMS_SHIFT)
+#define IXGBE_AUTOC_LMS_MASK		(0x7 << IXGBE_AUTOC_LMS_SHIFT)
+#define IXGBE_AUTOC_LMS_1G_LINK_NO_AN	(0x0 << IXGBE_AUTOC_LMS_SHIFT)
+#define IXGBE_AUTOC_LMS_10G_LINK_NO_AN	(0x1 << IXGBE_AUTOC_LMS_SHIFT)
+#define IXGBE_AUTOC_LMS_1G_AN		(0x2 << IXGBE_AUTOC_LMS_SHIFT)
+#define IXGBE_AUTOC_LMS_KX4_AN		(0x4 << IXGBE_AUTOC_LMS_SHIFT)
+#define IXGBE_AUTOC_LMS_KX4_AN_1G_AN	(0x6 << IXGBE_AUTOC_LMS_SHIFT)
+#define IXGBE_AUTOC_LMS_ATTACH_TYPE	(0x7 << IXGBE_AUTOC_10G_PMA_PMD_SHIFT)
+
+#define IXGBE_AUTOC_1G_PMA_PMD_MASK	0x00000200
+#define IXGBE_AUTOC_1G_PMA_PMD_SHIFT	9
+#define IXGBE_AUTOC_10G_PMA_PMD_MASK	0x00000180
+#define IXGBE_AUTOC_10G_PMA_PMD_SHIFT	7
+#define IXGBE_AUTOC_10G_XAUI	(0x0 << IXGBE_AUTOC_10G_PMA_PMD_SHIFT)
+#define IXGBE_AUTOC_10G_KX4	(0x1 << IXGBE_AUTOC_10G_PMA_PMD_SHIFT)
+#define IXGBE_AUTOC_10G_CX4	(0x2 << IXGBE_AUTOC_10G_PMA_PMD_SHIFT)
+#define IXGBE_AUTOC_1G_BX	(0x0 << IXGBE_AUTOC_1G_PMA_PMD_SHIFT)
+#define IXGBE_AUTOC_1G_KX	(0x1 << IXGBE_AUTOC_1G_PMA_PMD_SHIFT)
+#define IXGBE_AUTOC_1G_SFI	(0x0 << IXGBE_AUTOC_1G_PMA_PMD_SHIFT)
+#define IXGBE_AUTOC_1G_KX_BX	(0x1 << IXGBE_AUTOC_1G_PMA_PMD_SHIFT)
+
+#define IXGBE_AUTOC2_UPPER_MASK	0xFFFF0000
+#define IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_MASK	0x00030000
+#define IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_SHIFT	16
+#define IXGBE_AUTOC2_10G_KR	(0x0 << IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_SHIFT)
+#define IXGBE_AUTOC2_10G_XFI	(0x1 << IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_SHIFT)
+#define IXGBE_AUTOC2_10G_SFI	(0x2 << IXGBE_AUTOC2_10G_SERIAL_PMA_PMD_SHIFT)
+#define IXGBE_AUTOC2_LINK_DISABLE_ON_D3_MASK	0x50000000
+#define IXGBE_AUTOC2_LINK_DISABLE_MASK		0x70000000
+
+#define IXGBE_MACC_FLU		0x00000001
+#define IXGBE_MACC_FSV_10G	0x00030000
+#define IXGBE_MACC_FS		0x00040000
+#define IXGBE_MAC_RX2TX_LPBK	0x00000002
+
+/* Veto Bit definiton */
+#define IXGBE_MMNGC_MNG_VETO	0x00000001
 
 /* LINKS Bit Masks */
-#define IXGBE_LINKS_KX_AN_COMP  0x80000000
-#define IXGBE_LINKS_UP          0x40000000
-#define IXGBE_LINKS_SPEED       0x20000000
-#define IXGBE_LINKS_MODE        0x18000000
-#define IXGBE_LINKS_RX_MODE     0x06000000
-#define IXGBE_LINKS_TX_MODE     0x01800000
-#define IXGBE_LINKS_XGXS_EN     0x00400000
-#define IXGBE_LINKS_SGMII_EN    0x02000000
-#define IXGBE_LINKS_PCS_1G_EN   0x00200000
-#define IXGBE_LINKS_1G_AN_EN    0x00100000
-#define IXGBE_LINKS_KX_AN_IDLE  0x00080000
-#define IXGBE_LINKS_1G_SYNC     0x00040000
-#define IXGBE_LINKS_10G_ALIGN   0x00020000
-#define IXGBE_LINKS_10G_LANE_SYNC 0x00017000
-#define IXGBE_LINKS_TL_FAULT    0x00001000
-#define IXGBE_LINKS_SIGNAL      0x00000F00
-
-#define IXGBE_LINKS_SPEED_NON_STD   0x08000000
-#define IXGBE_LINKS_SPEED_82599     0x30000000
-#define IXGBE_LINKS_SPEED_10G_82599 0x30000000
-#define IXGBE_LINKS_SPEED_1G_82599  0x20000000
-#define IXGBE_LINKS_SPEED_100_82599 0x10000000
-#define IXGBE_LINK_UP_TIME      90 /* 9.0 Seconds */
-#define IXGBE_AUTO_NEG_TIME     45 /* 4.5 Seconds */
-
-#define IXGBE_LINKS2_AN_SUPPORTED   0x00000040
+#define IXGBE_LINKS_KX_AN_COMP	0x80000000
+#define IXGBE_LINKS_UP		0x40000000
+#define IXGBE_LINKS_SPEED	0x20000000
+#define IXGBE_LINKS_MODE	0x18000000
+#define IXGBE_LINKS_RX_MODE	0x06000000
+#define IXGBE_LINKS_TX_MODE	0x01800000
+#define IXGBE_LINKS_XGXS_EN	0x00400000
+#define IXGBE_LINKS_SGMII_EN	0x02000000
+#define IXGBE_LINKS_PCS_1G_EN	0x00200000
+#define IXGBE_LINKS_1G_AN_EN	0x00100000
+#define IXGBE_LINKS_KX_AN_IDLE	0x00080000
+#define IXGBE_LINKS_1G_SYNC	0x00040000
+#define IXGBE_LINKS_10G_ALIGN	0x00020000
+#define IXGBE_LINKS_10G_LANE_SYNC	0x00017000
+#define IXGBE_LINKS_TL_FAULT		0x00001000
+#define IXGBE_LINKS_SIGNAL		0x00000F00
+
+#define IXGBE_LINKS_SPEED_NON_STD	0x08000000
+#define IXGBE_LINKS_SPEED_82599		0x30000000
+#define IXGBE_LINKS_SPEED_10G_82599	0x30000000
+#define IXGBE_LINKS_SPEED_1G_82599	0x20000000
+#define IXGBE_LINKS_SPEED_100_82599	0x10000000
+#define IXGBE_LINKS_SPEED_10_X550EM_A	0x00000000
+#define IXGBE_LINK_UP_TIME		90 /* 9.0 Seconds */
+#define IXGBE_AUTO_NEG_TIME		45 /* 4.5 Seconds */
+
+#define IXGBE_LINKS2_AN_SUPPORTED	0x00000040
 
 /* PCS1GLSTA Bit Masks */
-#define IXGBE_PCS1GLSTA_LINK_OK         1
-#define IXGBE_PCS1GLSTA_SYNK_OK         0x10
-#define IXGBE_PCS1GLSTA_AN_COMPLETE     0x10000
-#define IXGBE_PCS1GLSTA_AN_PAGE_RX      0x20000
-#define IXGBE_PCS1GLSTA_AN_TIMED_OUT    0x40000
-#define IXGBE_PCS1GLSTA_AN_REMOTE_FAULT 0x80000
-#define IXGBE_PCS1GLSTA_AN_ERROR_RWS    0x100000
+#define IXGBE_PCS1GLSTA_LINK_OK		1
+#define IXGBE_PCS1GLSTA_SYNK_OK		0x10
+#define IXGBE_PCS1GLSTA_AN_COMPLETE	0x10000
+#define IXGBE_PCS1GLSTA_AN_PAGE_RX	0x20000
+#define IXGBE_PCS1GLSTA_AN_TIMED_OUT	0x40000
+#define IXGBE_PCS1GLSTA_AN_REMOTE_FAULT	0x80000
+#define IXGBE_PCS1GLSTA_AN_ERROR_RWS	0x100000
 
-#define IXGBE_PCS1GANA_SYM_PAUSE        0x80
-#define IXGBE_PCS1GANA_ASM_PAUSE        0x100
+#define IXGBE_PCS1GANA_SYM_PAUSE	0x80
+#define IXGBE_PCS1GANA_ASM_PAUSE	0x100
 
 /* PCS1GLCTL Bit Masks */
-#define IXGBE_PCS1GLCTL_AN_1G_TIMEOUT_EN  0x00040000 /* PCS 1G autoneg to en */
-#define IXGBE_PCS1GLCTL_FLV_LINK_UP     1
-#define IXGBE_PCS1GLCTL_FORCE_LINK      0x20
-#define IXGBE_PCS1GLCTL_LOW_LINK_LATCH  0x40
-#define IXGBE_PCS1GLCTL_AN_ENABLE       0x10000
-#define IXGBE_PCS1GLCTL_AN_RESTART      0x20000
+#define IXGBE_PCS1GLCTL_AN_1G_TIMEOUT_EN 0x00040000 /* PCS 1G autoneg to en */
+#define IXGBE_PCS1GLCTL_FLV_LINK_UP	1
+#define IXGBE_PCS1GLCTL_FORCE_LINK	0x20
+#define IXGBE_PCS1GLCTL_LOW_LINK_LATCH	0x40
+#define IXGBE_PCS1GLCTL_AN_ENABLE	0x10000
+#define IXGBE_PCS1GLCTL_AN_RESTART	0x20000
 
 /* ANLP1 Bit Masks */
-#define IXGBE_ANLP1_PAUSE               0x0C00
-#define IXGBE_ANLP1_SYM_PAUSE           0x0400
-#define IXGBE_ANLP1_ASM_PAUSE           0x0800
-#define IXGBE_ANLP1_AN_STATE_MASK       0x000f0000
+#define IXGBE_ANLP1_PAUSE		0x0C00
+#define IXGBE_ANLP1_SYM_PAUSE		0x0400
+#define IXGBE_ANLP1_ASM_PAUSE		0x0800
+#define IXGBE_ANLP1_AN_STATE_MASK	0x000f0000
 
 /* SW Semaphore Register bitmasks */
-#define IXGBE_SWSM_SMBI 0x00000001 /* Driver Semaphore bit */
-#define IXGBE_SWSM_SWESMBI 0x00000002 /* FW Semaphore bit */
-#define IXGBE_SWSM_WMNG 0x00000004 /* Wake MNG Clock */
-#define IXGBE_SWFW_REGSMP 0x80000000 /* Register Semaphore bit 31 */
+#define IXGBE_SWSM_SMBI		0x00000001 /* Driver Semaphore bit */
+#define IXGBE_SWSM_SWESMBI	0x00000002 /* FW Semaphore bit */
+#define IXGBE_SWSM_WMNG		0x00000004 /* Wake MNG Clock */
+#define IXGBE_SWFW_REGSMP	0x80000000 /* Register Semaphore bit 31 */
 
 /* SW_FW_SYNC/GSSR definitions */
 #define IXGBE_GSSR_EEP_SM		0x0001
@@ -1951,46 +2266,54 @@ enum {
 #define IXGBE_GSSR_PHY1_SM		0x0004
 #define IXGBE_GSSR_MAC_CSR_SM		0x0008
 #define IXGBE_GSSR_FLASH_SM		0x0010
+#define IXGBE_GSSR_NVM_UPDATE_SM	0x0200
 #define IXGBE_GSSR_SW_MNG_SM		0x0400
-#define IXGBE_GSSR_SHARED_I2C_SM	0x1806 /* Wait for both phys & I2Cs */
-#define IXGBE_GSSR_I2C_MASK		0x1800
-#define IXGBE_GSSR_NVM_PHY_MASK		0xF
+#define IXGBE_GSSR_TOKEN_SM	0x40000000 /* SW bit for shared access */
+#define IXGBE_GSSR_SHARED_I2C_SM 0x1806 /* Wait for both phys and both I2Cs */
+#define IXGBE_GSSR_I2C_MASK	0x1800
+#define IXGBE_GSSR_NVM_PHY_MASK	0xF
 
 /* FW Status register bitmask */
-#define IXGBE_FWSTS_FWRI    0x00000200 /* Firmware Reset Indication */
+#define IXGBE_FWSTS_FWRI	0x00000200 /* Firmware Reset Indication */
 
 /* EEC Register */
-#define IXGBE_EEC_SK        0x00000001 /* EEPROM Clock */
-#define IXGBE_EEC_CS        0x00000002 /* EEPROM Chip Select */
-#define IXGBE_EEC_DI        0x00000004 /* EEPROM Data In */
-#define IXGBE_EEC_DO        0x00000008 /* EEPROM Data Out */
-#define IXGBE_EEC_FWE_MASK  0x00000030 /* FLASH Write Enable */
-#define IXGBE_EEC_FWE_DIS   0x00000010 /* Disable FLASH writes */
-#define IXGBE_EEC_FWE_EN    0x00000020 /* Enable FLASH writes */
-#define IXGBE_EEC_FWE_SHIFT 4
-#define IXGBE_EEC_REQ       0x00000040 /* EEPROM Access Request */
-#define IXGBE_EEC_GNT       0x00000080 /* EEPROM Access Grant */
-#define IXGBE_EEC_PRES      0x00000100 /* EEPROM Present */
-#define IXGBE_EEC_ARD       0x00000200 /* EEPROM Auto Read Done */
-#define IXGBE_EEC_FLUP      0x00800000 /* Flash update command */
-#define IXGBE_EEC_SEC1VAL   0x02000000 /* Sector 1 Valid */
-#define IXGBE_EEC_FLUDONE   0x04000000 /* Flash update done */
+#define IXGBE_EEC_SK		0x00000001 /* EEPROM Clock */
+#define IXGBE_EEC_CS		0x00000002 /* EEPROM Chip Select */
+#define IXGBE_EEC_DI		0x00000004 /* EEPROM Data In */
+#define IXGBE_EEC_DO		0x00000008 /* EEPROM Data Out */
+#define IXGBE_EEC_FWE_MASK	0x00000030 /* FLASH Write Enable */
+#define IXGBE_EEC_FWE_DIS	0x00000010 /* Disable FLASH writes */
+#define IXGBE_EEC_FWE_EN	0x00000020 /* Enable FLASH writes */
+#define IXGBE_EEC_FWE_SHIFT	4
+#define IXGBE_EEC_REQ		0x00000040 /* EEPROM Access Request */
+#define IXGBE_EEC_GNT		0x00000080 /* EEPROM Access Grant */
+#define IXGBE_EEC_PRES		0x00000100 /* EEPROM Present */
+#define IXGBE_EEC_ARD		0x00000200 /* EEPROM Auto Read Done */
+#define IXGBE_EEC_FLUP		0x00800000 /* Flash update command */
+#define IXGBE_EEC_SEC1VAL	0x02000000 /* Sector 1 Valid */
+#define IXGBE_EEC_FLUDONE	0x04000000 /* Flash update done */
 /* EEPROM Addressing bits based on type (0-small, 1-large) */
-#define IXGBE_EEC_ADDR_SIZE 0x00000400
-#define IXGBE_EEC_SIZE      0x00007800 /* EEPROM Size */
-#define IXGBE_EERD_MAX_ADDR 0x00003FFF /* EERD alows 14 bits for addr. */
+#define IXGBE_EEC_ADDR_SIZE	0x00000400
+#define IXGBE_EEC_SIZE		0x00007800 /* EEPROM Size */
+#define IXGBE_EERD_MAX_ADDR	0x00003FFF /* EERD alows 14 bits for addr. */
+
+#define IXGBE_EEC_SIZE_SHIFT		11
+#define IXGBE_EEPROM_WORD_SIZE_SHIFT	6
+#define IXGBE_EEPROM_OPCODE_BITS	8
 
-#define IXGBE_EEC_SIZE_SHIFT          11
-#define IXGBE_EEPROM_WORD_SIZE_SHIFT  6
-#define IXGBE_EEPROM_OPCODE_BITS      8
+/* FLA Register */
+#define IXGBE_FLA_LOCKED	0x00000040
 
 /* Part Number String Length */
-#define IXGBE_PBANUM_LENGTH 11
+#define IXGBE_PBANUM_LENGTH	11
 
 /* Checksum and EEPROM pointers */
 #define IXGBE_PBANUM_PTR_GUARD		0xFAFA
 #define IXGBE_EEPROM_CHECKSUM		0x3F
 #define IXGBE_EEPROM_SUM		0xBABA
+#define IXGBE_EEPROM_CTRL_4		0x45
+#define IXGBE_EE_CTRL_4_INST_ID		0x10
+#define IXGBE_EE_CTRL_4_INST_ID_SHIFT	4
 #define IXGBE_PCIE_ANALOG_PTR		0x03
 #define IXGBE_ATLAS0_CONFIG_PTR		0x04
 #define IXGBE_PHY_PTR			0x04
@@ -2013,138 +2336,154 @@ enum {
 #define IXGBE_FW_PTR			0x0F
 #define IXGBE_PBANUM0_PTR		0x15
 #define IXGBE_PBANUM1_PTR		0x16
+#define IXGBE_ALT_MAC_ADDR_PTR		0x37
 #define IXGBE_FREE_SPACE_PTR		0X3E
 
 /* External Thermal Sensor Config */
-#define IXGBE_ETS_CFG                   0x26
-#define IXGBE_ETS_LTHRES_DELTA_MASK     0x07C0
-#define IXGBE_ETS_LTHRES_DELTA_SHIFT    6
-#define IXGBE_ETS_TYPE_MASK             0x0038
-#define IXGBE_ETS_TYPE_SHIFT            3
-#define IXGBE_ETS_TYPE_EMC              0x000
-#define IXGBE_ETS_TYPE_EMC_SHIFTED      0x000
-#define IXGBE_ETS_NUM_SENSORS_MASK      0x0007
-#define IXGBE_ETS_DATA_LOC_MASK         0x3C00
-#define IXGBE_ETS_DATA_LOC_SHIFT        10
-#define IXGBE_ETS_DATA_INDEX_MASK       0x0300
-#define IXGBE_ETS_DATA_INDEX_SHIFT      8
-#define IXGBE_ETS_DATA_HTHRESH_MASK     0x00FF
-
-#define IXGBE_SAN_MAC_ADDR_PTR  0x28
-#define IXGBE_DEVICE_CAPS       0x2C
-#define IXGBE_SERIAL_NUMBER_MAC_ADDR 0x11
-#define IXGBE_PCIE_MSIX_82599_CAPS  0x72
+#define IXGBE_ETS_CFG			0x26
+#define IXGBE_ETS_LTHRES_DELTA_MASK	0x07C0
+#define IXGBE_ETS_LTHRES_DELTA_SHIFT	6
+#define IXGBE_ETS_TYPE_MASK		0x0038
+#define IXGBE_ETS_TYPE_SHIFT		3
+#define IXGBE_ETS_TYPE_EMC		0x000
+#define IXGBE_ETS_NUM_SENSORS_MASK	0x0007
+#define IXGBE_ETS_DATA_LOC_MASK		0x3C00
+#define IXGBE_ETS_DATA_LOC_SHIFT	10
+#define IXGBE_ETS_DATA_INDEX_MASK	0x0300
+#define IXGBE_ETS_DATA_INDEX_SHIFT	8
+#define IXGBE_ETS_DATA_HTHRESH_MASK	0x00FF
+
+#define IXGBE_SAN_MAC_ADDR_PTR		0x28
+#define IXGBE_DEVICE_CAPS		0x2C
+#define IXGBE_82599_SERIAL_NUMBER_MAC_ADDR	0x11
+#define IXGBE_X550_SERIAL_NUMBER_MAC_ADDR	0x04
+
+#define IXGBE_PCIE_MSIX_82599_CAPS	0x72
 #define IXGBE_MAX_MSIX_VECTORS_82599	0x40
-#define IXGBE_PCIE_MSIX_82598_CAPS  0x62
+#define IXGBE_PCIE_MSIX_82598_CAPS	0x62
 #define IXGBE_MAX_MSIX_VECTORS_82598	0x13
 
 /* MSI-X capability fields masks */
-#define IXGBE_PCIE_MSIX_TBL_SZ_MASK     0x7FF
+#define IXGBE_PCIE_MSIX_TBL_SZ_MASK	0x7FF
 
 /* Legacy EEPROM word offsets */
-#define IXGBE_ISCSI_BOOT_CAPS           0x0033
-#define IXGBE_ISCSI_SETUP_PORT_0        0x0030
-#define IXGBE_ISCSI_SETUP_PORT_1        0x0034
+#define IXGBE_ISCSI_BOOT_CAPS		0x0033
+#define IXGBE_ISCSI_SETUP_PORT_0	0x0030
+#define IXGBE_ISCSI_SETUP_PORT_1	0x0034
 
 /* EEPROM Commands - SPI */
-#define IXGBE_EEPROM_MAX_RETRY_SPI      5000 /* Max wait 5ms for RDY signal */
-#define IXGBE_EEPROM_STATUS_RDY_SPI     0x01
-#define IXGBE_EEPROM_READ_OPCODE_SPI    0x03  /* EEPROM read opcode */
-#define IXGBE_EEPROM_WRITE_OPCODE_SPI   0x02  /* EEPROM write opcode */
-#define IXGBE_EEPROM_A8_OPCODE_SPI      0x08  /* opcode bit-3 = addr bit-8 */
-#define IXGBE_EEPROM_WREN_OPCODE_SPI    0x06  /* EEPROM set Write Ena latch */
+#define IXGBE_EEPROM_MAX_RETRY_SPI	5000 /* Max wait 5ms for RDY signal */
+#define IXGBE_EEPROM_STATUS_RDY_SPI	0x01
+#define IXGBE_EEPROM_READ_OPCODE_SPI	0x03  /* EEPROM read opcode */
+#define IXGBE_EEPROM_WRITE_OPCODE_SPI	0x02  /* EEPROM write opcode */
+#define IXGBE_EEPROM_A8_OPCODE_SPI	0x08  /* opcode bit-3 = addr bit-8 */
+#define IXGBE_EEPROM_WREN_OPCODE_SPI	0x06  /* EEPROM set Write Ena latch */
 /* EEPROM reset Write Enable latch */
-#define IXGBE_EEPROM_WRDI_OPCODE_SPI    0x04
-#define IXGBE_EEPROM_RDSR_OPCODE_SPI    0x05  /* EEPROM read Status reg */
-#define IXGBE_EEPROM_WRSR_OPCODE_SPI    0x01  /* EEPROM write Status reg */
-#define IXGBE_EEPROM_ERASE4K_OPCODE_SPI 0x20  /* EEPROM ERASE 4KB */
-#define IXGBE_EEPROM_ERASE64K_OPCODE_SPI  0xD8  /* EEPROM ERASE 64KB */
-#define IXGBE_EEPROM_ERASE256_OPCODE_SPI  0xDB  /* EEPROM ERASE 256B */
+#define IXGBE_EEPROM_WRDI_OPCODE_SPI	0x04
+#define IXGBE_EEPROM_RDSR_OPCODE_SPI	0x05  /* EEPROM read Status reg */
+#define IXGBE_EEPROM_WRSR_OPCODE_SPI	0x01  /* EEPROM write Status reg */
+#define IXGBE_EEPROM_ERASE4K_OPCODE_SPI	0x20  /* EEPROM ERASE 4KB */
+#define IXGBE_EEPROM_ERASE64K_OPCODE_SPI	0xD8  /* EEPROM ERASE 64KB */
+#define IXGBE_EEPROM_ERASE256_OPCODE_SPI	0xDB  /* EEPROM ERASE 256B */
 
 /* EEPROM Read Register */
-#define IXGBE_EEPROM_RW_REG_DATA   16 /* data offset in EEPROM read reg */
-#define IXGBE_EEPROM_RW_REG_DONE   2  /* Offset to READ done bit */
-#define IXGBE_EEPROM_RW_REG_START  1  /* First bit to start operation */
-#define IXGBE_EEPROM_RW_ADDR_SHIFT 2  /* Shift to the address bits */
-#define IXGBE_NVM_POLL_WRITE       1  /* Flag for polling for write complete */
-#define IXGBE_NVM_POLL_READ        0  /* Flag for polling for read complete */
-
-#define NVM_INIT_CTRL_3			0x38
-#define NVM_INIT_CTRL_3_LPLU		0x8
-#define NVM_INIT_CTRL_3_D10GMP_PORT0	0x40
-#define NVM_INIT_CTRL_3_D10GMP_PORT1	0x100
-
-#define IXGBE_EEPROM_PAGE_SIZE_MAX       128
-#define IXGBE_EEPROM_RD_BUFFER_MAX_COUNT 512 /* EEPROM words # read in burst */
-#define IXGBE_EEPROM_WR_BUFFER_MAX_COUNT 256 /* EEPROM words # wr in burst */
-
-#define IXGBE_EEPROM_CTRL_2	1 /* EEPROM CTRL word 2 */
-#define IXGBE_EEPROM_CCD_BIT	2 /* EEPROM Core Clock Disable bit */
+#define IXGBE_EEPROM_RW_REG_DATA	16 /* data offset in EEPROM read reg */
+#define IXGBE_EEPROM_RW_REG_DONE	2 /* Offset to READ done bit */
+#define IXGBE_EEPROM_RW_REG_START	1 /* First bit to start operation */
+#define IXGBE_EEPROM_RW_ADDR_SHIFT	2 /* Shift to the address bits */
+#define IXGBE_NVM_POLL_WRITE		1 /* Flag for polling for wr complete */
+#define IXGBE_NVM_POLL_READ		0 /* Flag for polling for rd complete */
+
+#define NVM_INIT_CTRL_3		0x38
+#define NVM_INIT_CTRL_3_LPLU	0x8
+#define NVM_INIT_CTRL_3_D10GMP_PORT0 0x40
+#define NVM_INIT_CTRL_3_D10GMP_PORT1 0x100
+
+#define IXGBE_ETH_LENGTH_OF_ADDRESS	6
+
+#define IXGBE_EEPROM_PAGE_SIZE_MAX	128
+#define IXGBE_EEPROM_RD_BUFFER_MAX_COUNT	256 /* words rd in burst */
+#define IXGBE_EEPROM_WR_BUFFER_MAX_COUNT	256 /* words wr in burst */
+#define IXGBE_EEPROM_CTRL_2		1 /* EEPROM CTRL word 2 */
+#define IXGBE_EEPROM_CCD_BIT		2
 
 #ifndef IXGBE_EEPROM_GRANT_ATTEMPTS
-#define IXGBE_EEPROM_GRANT_ATTEMPTS 1000 /* EEPROM # attempts to gain grant */
+#define IXGBE_EEPROM_GRANT_ATTEMPTS	1000 /* EEPROM attempts to gain grant */
 #endif
 
 #ifndef IXGBE_EERD_EEWR_ATTEMPTS
 /* Number of 5 microseconds we wait for EERD read and
  * EERW write to complete */
-#define IXGBE_EERD_EEWR_ATTEMPTS 100000
+#define IXGBE_EERD_EEWR_ATTEMPTS	100000
 #endif
 
 #ifndef IXGBE_FLUDONE_ATTEMPTS
 /* # attempts we wait for flush update to complete */
-#define IXGBE_FLUDONE_ATTEMPTS 20000
+#define IXGBE_FLUDONE_ATTEMPTS		20000
 #endif
 
-#define IXGBE_PCIE_CTRL2                 0x5   /* PCIe Control 2 Offset */
-#define IXGBE_PCIE_CTRL2_DUMMY_ENABLE    0x8   /* Dummy Function Enable */
-#define IXGBE_PCIE_CTRL2_LAN_DISABLE     0x2   /* LAN PCI Disable */
-#define IXGBE_PCIE_CTRL2_DISABLE_SELECT  0x1   /* LAN Disable Select */
-
-#define IXGBE_SAN_MAC_ADDR_PORT0_OFFSET  0x0
-#define IXGBE_SAN_MAC_ADDR_PORT1_OFFSET  0x3
-#define IXGBE_DEVICE_CAPS_ALLOW_ANY_SFP  0x1
-#define IXGBE_DEVICE_CAPS_FCOE_OFFLOADS  0x2
-#define IXGBE_FW_LESM_PARAMETERS_PTR     0x2
-#define IXGBE_FW_LESM_STATE_1            0x1
-#define IXGBE_FW_LESM_STATE_ENABLED      0x8000 /* LESM Enable bit */
-#define IXGBE_FW_PASSTHROUGH_PATCH_CONFIG_PTR   0x4
-#define IXGBE_FW_PATCH_VERSION_4         0x7
-#define IXGBE_FCOE_IBA_CAPS_BLK_PTR         0x33 /* iSCSI/FCOE block */
-#define IXGBE_FCOE_IBA_CAPS_FCOE            0x20 /* FCOE flags */
-#define IXGBE_ISCSI_FCOE_BLK_PTR            0x17 /* iSCSI/FCOE block */
-#define IXGBE_ISCSI_FCOE_FLAGS_OFFSET       0x0  /* FCOE flags */
-#define IXGBE_ISCSI_FCOE_FLAGS_ENABLE       0x1  /* FCOE flags enable bit */
-#define IXGBE_ALT_SAN_MAC_ADDR_BLK_PTR      0x27 /* Alt. SAN MAC block */
-#define IXGBE_ALT_SAN_MAC_ADDR_CAPS_OFFSET  0x0 /* Alt. SAN MAC capability */
-#define IXGBE_ALT_SAN_MAC_ADDR_PORT0_OFFSET 0x1 /* Alt. SAN MAC 0 offset */
-#define IXGBE_ALT_SAN_MAC_ADDR_PORT1_OFFSET 0x4 /* Alt. SAN MAC 1 offset */
-#define IXGBE_ALT_SAN_MAC_ADDR_WWNN_OFFSET  0x7 /* Alt. WWNN prefix offset */
-#define IXGBE_ALT_SAN_MAC_ADDR_WWPN_OFFSET  0x8 /* Alt. WWPN prefix offset */
-#define IXGBE_ALT_SAN_MAC_ADDR_CAPS_SANMAC  0x0 /* Alt. SAN MAC exists */
-#define IXGBE_ALT_SAN_MAC_ADDR_CAPS_ALTWWN  0x1 /* Alt. WWN base exists */
-
-#define IXGBE_DEVICE_CAPS_WOL_PORT0_1  0x4 /* WoL supported on ports 0 & 1 */
-#define IXGBE_DEVICE_CAPS_WOL_PORT0    0x8 /* WoL supported on port 0 */
-#define IXGBE_DEVICE_CAPS_WOL_MASK     0xC /* Mask for WoL capabilities */
+#define IXGBE_PCIE_CTRL2		0x5   /* PCIe Control 2 Offset */
+#define IXGBE_PCIE_CTRL2_DUMMY_ENABLE	0x8   /* Dummy Function Enable */
+#define IXGBE_PCIE_CTRL2_LAN_DISABLE	0x2   /* LAN PCI Disable */
+#define IXGBE_PCIE_CTRL2_DISABLE_SELECT	0x1   /* LAN Disable Select */
+
+#define IXGBE_SAN_MAC_ADDR_PORT0_OFFSET		0x0
+#define IXGBE_SAN_MAC_ADDR_PORT1_OFFSET		0x3
+#define IXGBE_DEVICE_CAPS_ALLOW_ANY_SFP		0x1
+#define IXGBE_DEVICE_CAPS_FCOE_OFFLOADS		0x2
+#define IXGBE_DEVICE_CAPS_NO_CROSSTALK_WR	(1 << 7)
+#define IXGBE_FW_LESM_PARAMETERS_PTR		0x2
+#define IXGBE_FW_LESM_STATE_1			0x1
+#define IXGBE_FW_LESM_STATE_ENABLED		0x8000 /* LESM Enable bit */
+#define IXGBE_FW_PASSTHROUGH_PATCH_CONFIG_PTR	0x4
+#define IXGBE_FW_PATCH_VERSION_4		0x7
+#define IXGBE_FCOE_IBA_CAPS_BLK_PTR		0x33 /* iSCSI/FCOE block */
+#define IXGBE_FCOE_IBA_CAPS_FCOE		0x20 /* FCOE flags */
+#define IXGBE_ISCSI_FCOE_BLK_PTR		0x17 /* iSCSI/FCOE block */
+#define IXGBE_ISCSI_FCOE_FLAGS_OFFSET		0x0 /* FCOE flags */
+#define IXGBE_ISCSI_FCOE_FLAGS_ENABLE		0x1 /* FCOE flags enable bit */
+#define IXGBE_ALT_SAN_MAC_ADDR_BLK_PTR		0x27 /* Alt. SAN MAC block */
+#define IXGBE_ALT_SAN_MAC_ADDR_CAPS_OFFSET	0x0 /* Alt SAN MAC capability */
+#define IXGBE_ALT_SAN_MAC_ADDR_PORT0_OFFSET	0x1 /* Alt SAN MAC 0 offset */
+#define IXGBE_ALT_SAN_MAC_ADDR_PORT1_OFFSET	0x4 /* Alt SAN MAC 1 offset */
+#define IXGBE_ALT_SAN_MAC_ADDR_WWNN_OFFSET	0x7 /* Alt WWNN prefix offset */
+#define IXGBE_ALT_SAN_MAC_ADDR_WWPN_OFFSET	0x8 /* Alt WWPN prefix offset */
+#define IXGBE_ALT_SAN_MAC_ADDR_CAPS_SANMAC	0x0 /* Alt SAN MAC exists */
+#define IXGBE_ALT_SAN_MAC_ADDR_CAPS_ALTWWN	0x1 /* Alt WWN base exists */
+
+/* FW header offset */
+#define IXGBE_X540_FW_PASSTHROUGH_PATCH_CONFIG_PTR	0x4
+#define IXGBE_X540_FW_MODULE_MASK			0x7FFF
+/* 4KB multiplier */
+#define IXGBE_X540_FW_MODULE_LENGTH			0x1000
+/* version word 2 (month & day) */
+#define IXGBE_X540_FW_PATCH_VERSION_2		0x5
+/* version word 3 (silicon compatibility & year) */
+#define IXGBE_X540_FW_PATCH_VERSION_3		0x6
+/* version word 4 (major & minor numbers) */
+#define IXGBE_X540_FW_PATCH_VERSION_4		0x7
+
+#define IXGBE_DEVICE_CAPS_WOL_PORT0_1	0x4 /* WoL supported on ports 0 & 1 */
+#define IXGBE_DEVICE_CAPS_WOL_PORT0	0x8 /* WoL supported on port 0 */
+#define IXGBE_DEVICE_CAPS_WOL_MASK	0xC /* Mask for WoL capabilities */
 
 /* PCI Bus Info */
-#define IXGBE_PCI_DEVICE_STATUS   0xAA
-#define IXGBE_PCI_DEVICE_STATUS_TRANSACTION_PENDING   0x0020
-#define IXGBE_PCI_LINK_STATUS     0xB2
-#define IXGBE_PCI_DEVICE_CONTROL2 0xC8
-#define IXGBE_PCI_LINK_WIDTH      0x3F0
-#define IXGBE_PCI_LINK_WIDTH_1    0x10
-#define IXGBE_PCI_LINK_WIDTH_2    0x20
-#define IXGBE_PCI_LINK_WIDTH_4    0x40
-#define IXGBE_PCI_LINK_WIDTH_8    0x80
-#define IXGBE_PCI_LINK_SPEED      0xF
-#define IXGBE_PCI_LINK_SPEED_2500 0x1
-#define IXGBE_PCI_LINK_SPEED_5000 0x2
-#define IXGBE_PCI_LINK_SPEED_8000 0x3
-#define IXGBE_PCI_HEADER_TYPE_REGISTER  0x0E
-#define IXGBE_PCI_HEADER_TYPE_MULTIFUNC 0x80
-#define IXGBE_PCI_DEVICE_CONTROL2_16ms  0x0005
+#define IXGBE_PCI_DEVICE_STATUS		0xAA
+#define IXGBE_PCI_DEVICE_STATUS_TRANSACTION_PENDING	0x0020
+#define IXGBE_PCI_LINK_STATUS		0xB2
+#define IXGBE_PCI_DEVICE_CONTROL2	0xC8
+#define IXGBE_PCI_LINK_WIDTH		0x3F0
+#define IXGBE_PCI_LINK_WIDTH_1		0x10
+#define IXGBE_PCI_LINK_WIDTH_2		0x20
+#define IXGBE_PCI_LINK_WIDTH_4		0x40
+#define IXGBE_PCI_LINK_WIDTH_8		0x80
+#define IXGBE_PCI_LINK_SPEED		0xF
+#define IXGBE_PCI_LINK_SPEED_2500	0x1
+#define IXGBE_PCI_LINK_SPEED_5000	0x2
+#define IXGBE_PCI_LINK_SPEED_8000	0x3
+#define IXGBE_PCI_HEADER_TYPE_REGISTER	0x0E
+#define IXGBE_PCI_HEADER_TYPE_MULTIFUNC	0x80
+#define IXGBE_PCI_DEVICE_CONTROL2_16ms	0x0005
 
 #define IXGBE_PCIDEVCTRL2_TIMEO_MASK	0xf
 #define IXGBE_PCIDEVCTRL2_16_32ms_def	0x0
@@ -2160,55 +2499,72 @@ enum {
 /* Number of 100 microseconds we wait for PCI Express master disable */
 #define IXGBE_PCI_MASTER_DISABLE_TIMEOUT	800
 
+/* Check whether address is multicast. This is little-endian specific check.*/
+#define IXGBE_IS_MULTICAST(Address) \
+		(bool)(((u8 *)(Address))[0] & ((u8)0x01))
+
+/* Check whether an address is broadcast. */
+#define IXGBE_IS_BROADCAST(Address) \
+		((((u8 *)(Address))[0] == ((u8)0xff)) && \
+		(((u8 *)(Address))[1] == ((u8)0xff)))
+
 /* RAH */
-#define IXGBE_RAH_VIND_MASK     0x003C0000
-#define IXGBE_RAH_VIND_SHIFT    18
-#define IXGBE_RAH_AV            0x80000000
-#define IXGBE_CLEAR_VMDQ_ALL    0xFFFFFFFF
+#define IXGBE_RAH_VIND_MASK	0x003C0000
+#define IXGBE_RAH_VIND_SHIFT	18
+#define IXGBE_RAH_AV		0x80000000
+#define IXGBE_CLEAR_VMDQ_ALL	0xFFFFFFFF
 
 /* Header split receive */
-#define IXGBE_RFCTL_ISCSI_DIS       0x00000001
-#define IXGBE_RFCTL_ISCSI_DWC_MASK  0x0000003E
-#define IXGBE_RFCTL_ISCSI_DWC_SHIFT 1
+#define IXGBE_RFCTL_ISCSI_DIS		0x00000001
+#define IXGBE_RFCTL_ISCSI_DWC_MASK	0x0000003E
+#define IXGBE_RFCTL_ISCSI_DWC_SHIFT	1
 #define IXGBE_RFCTL_RSC_DIS		0x00000020
-#define IXGBE_RFCTL_NFSW_DIS        0x00000040
-#define IXGBE_RFCTL_NFSR_DIS        0x00000080
-#define IXGBE_RFCTL_NFS_VER_MASK    0x00000300
-#define IXGBE_RFCTL_NFS_VER_SHIFT   8
-#define IXGBE_RFCTL_NFS_VER_2       0
-#define IXGBE_RFCTL_NFS_VER_3       1
-#define IXGBE_RFCTL_NFS_VER_4       2
-#define IXGBE_RFCTL_IPV6_DIS        0x00000400
-#define IXGBE_RFCTL_IPV6_XSUM_DIS   0x00000800
-#define IXGBE_RFCTL_IPFRSP_DIS      0x00004000
-#define IXGBE_RFCTL_IPV6_EX_DIS     0x00010000
-#define IXGBE_RFCTL_NEW_IPV6_EXT_DIS 0x00020000
+#define IXGBE_RFCTL_NFSW_DIS		0x00000040
+#define IXGBE_RFCTL_NFSR_DIS		0x00000080
+#define IXGBE_RFCTL_NFS_VER_MASK	0x00000300
+#define IXGBE_RFCTL_NFS_VER_SHIFT	8
+#define IXGBE_RFCTL_NFS_VER_2		0
+#define IXGBE_RFCTL_NFS_VER_3		1
+#define IXGBE_RFCTL_NFS_VER_4		2
+#define IXGBE_RFCTL_IPV6_DIS		0x00000400
+#define IXGBE_RFCTL_IPV6_XSUM_DIS	0x00000800
+#define IXGBE_RFCTL_IPFRSP_DIS		0x00004000
+#define IXGBE_RFCTL_IPV6_EX_DIS		0x00010000
+#define IXGBE_RFCTL_NEW_IPV6_EXT_DIS	0x00020000
 
 /* Transmit Config masks */
-#define IXGBE_TXDCTL_ENABLE     0x02000000 /* Enable specific Tx Queue */
-#define IXGBE_TXDCTL_SWFLSH     0x04000000 /* Tx Desc. write-back flushing */
-#define IXGBE_TXDCTL_WTHRESH_SHIFT      16 /* shift to WTHRESH bits */
+#define IXGBE_TXDCTL_ENABLE		0x02000000 /* Ena specific Tx Queue */
+#define IXGBE_TXDCTL_SWFLSH		0x04000000 /* Tx Desc. wr-bk flushing */
+#define IXGBE_TXDCTL_WTHRESH_SHIFT	16 /* shift to WTHRESH bits */
 /* Enable short packet padding to 64 bytes */
-#define IXGBE_TX_PAD_ENABLE     0x00000400
-#define IXGBE_JUMBO_FRAME_ENABLE 0x00000004  /* Allow jumbo frames */
+#define IXGBE_TX_PAD_ENABLE		0x00000400
+#define IXGBE_JUMBO_FRAME_ENABLE	0x00000004  /* Allow jumbo frames */
 /* This allows for 16K packets + 4k for vlan */
-#define IXGBE_MAX_FRAME_SZ      0x40040000
+#define IXGBE_MAX_FRAME_SZ		0x40040000
 
-#define IXGBE_TDWBAL_HEAD_WB_ENABLE   0x1      /* Tx head write-back enable */
-#define IXGBE_TDWBAL_SEQNUM_WB_ENABLE 0x2      /* Tx seq# write-back enable */
+#define IXGBE_TDWBAL_HEAD_WB_ENABLE	0x1 /* Tx head write-back enable */
+#define IXGBE_TDWBAL_SEQNUM_WB_ENABLE	0x2 /* Tx seq# write-back enable */
 
 /* Receive Config masks */
-#define IXGBE_RXCTRL_RXEN       0x00000001  /* Enable Receiver */
-#define IXGBE_RXCTRL_DMBYPS     0x00000002  /* Descriptor Monitor Bypass */
-#define IXGBE_RXDCTL_ENABLE     0x02000000  /* Enable specific Rx Queue */
-#define IXGBE_RXDCTL_SWFLSH     0x04000000  /* Rx Desc. write-back flushing */
-#define IXGBE_RXDCTL_RLPMLMASK  0x00003FFF  /* Only supported on the X540 */
-#define IXGBE_RXDCTL_RLPML_EN   0x00008000
-#define IXGBE_RXDCTL_VME        0x40000000  /* VLAN mode enable */
-
-#define IXGBE_TSAUXC_EN_CLK   0x00000004
-#define IXGBE_TSAUXC_SYNCLK   0x00000008
-#define IXGBE_TSAUXC_SDP0_INT 0x00000040
+#define IXGBE_RXCTRL_RXEN		0x00000001 /* Enable Receiver */
+#define IXGBE_RXCTRL_DMBYPS		0x00000002 /* Desc Monitor Bypass */
+#define IXGBE_RXDCTL_ENABLE		0x02000000 /* Ena specific Rx Queue */
+#define IXGBE_RXDCTL_SWFLSH		0x04000000 /* Rx Desc wr-bk flushing */
+#define IXGBE_RXDCTL_RLPMLMASK		0x00003FFF /* X540 supported only */
+#define IXGBE_RXDCTL_RLPML_EN		0x00008000
+#define IXGBE_RXDCTL_VME		0x40000000 /* VLAN mode enable */
+
+#define IXGBE_TSAUXC_EN_CLK		0x00000004
+#define IXGBE_TSAUXC_SYNCLK		0x00000008
+#define IXGBE_TSAUXC_SDP0_INT		0x00000040
+#define IXGBE_TSAUXC_EN_TT0		0x00000001
+#define IXGBE_TSAUXC_EN_TT1		0x00000002
+#define IXGBE_TSAUXC_ST0		0x00000010
+#define IXGBE_TSAUXC_DISABLE_SYSTIME	0x80000000
+
+#define IXGBE_TSSDP_TS_SDP0_SEL_MASK	0x000000C0
+#define IXGBE_TSSDP_TS_SDP0_CLK0	0x00000080
+#define IXGBE_TSSDP_TS_SDP0_EN		0x00000100
 
 #define IXGBE_TSYNCTXCTL_VALID		0x00000001 /* Tx timestamp valid */
 #define IXGBE_TSYNCTXCTL_ENABLED	0x00000010 /* Tx timestamping enabled */
@@ -2218,8 +2574,19 @@ enum {
 #define IXGBE_TSYNCRXCTL_TYPE_L2_V2	0x00
 #define IXGBE_TSYNCRXCTL_TYPE_L4_V1	0x02
 #define IXGBE_TSYNCRXCTL_TYPE_L2_L4_V2	0x04
+#define IXGBE_TSYNCRXCTL_TYPE_ALL	0x08
 #define IXGBE_TSYNCRXCTL_TYPE_EVENT_V2	0x0A
 #define IXGBE_TSYNCRXCTL_ENABLED	0x00000010 /* Rx Timestamping enabled */
+#define IXGBE_TSYNCRXCTL_TSIP_UT_EN	0x00800000 /* Rx Timestamp in Packet */
+#define IXGBE_TSYNCRXCTL_TSIP_UP_MASK	0xFF000000 /* Rx Timestamp UP Mask */
+
+#define IXGBE_TSIM_SYS_WRAP		0x00000001
+#define IXGBE_TSIM_TXTS			0x00000002
+#define IXGBE_TSIM_TADJ			0x00000080
+
+#define IXGBE_TSICR_SYS_WRAP		IXGBE_TSIM_SYS_WRAP
+#define IXGBE_TSICR_TXTS		IXGBE_TSIM_TXTS
+#define IXGBE_TSICR_TADJ		IXGBE_TSIM_TADJ
 
 #define IXGBE_RXMTRL_V1_CTRLT_MASK	0x000000FF
 #define IXGBE_RXMTRL_V1_SYNC_MSG	0x00
@@ -2228,61 +2595,59 @@ enum {
 #define IXGBE_RXMTRL_V1_DELAY_RESP_MSG	0x03
 #define IXGBE_RXMTRL_V1_MGMT_MSG	0x04
 
-#define IXGBE_RXMTRL_V2_MSGID_MASK		0x0000FF00
-#define IXGBE_RXMTRL_V2_SYNC_MSG		0x0000
-#define IXGBE_RXMTRL_V2_DELAY_REQ_MSG		0x0100
-#define IXGBE_RXMTRL_V2_PDELAY_REQ_MSG		0x0200
-#define IXGBE_RXMTRL_V2_PDELAY_RESP_MSG		0x0300
-#define IXGBE_RXMTRL_V2_FOLLOWUP_MSG		0x0800
-#define IXGBE_RXMTRL_V2_DELAY_RESP_MSG		0x0900
-#define IXGBE_RXMTRL_V2_PDELAY_FOLLOWUP_MSG	0x0A00
-#define IXGBE_RXMTRL_V2_ANNOUNCE_MSG		0x0B00
-#define IXGBE_RXMTRL_V2_SIGNALING_MSG		0x0C00
-#define IXGBE_RXMTRL_V2_MGMT_MSG		0x0D00
-
-#define IXGBE_FCTRL_SBP 0x00000002 /* Store Bad Packet */
-#define IXGBE_FCTRL_MPE 0x00000100 /* Multicast Promiscuous Ena*/
-#define IXGBE_FCTRL_UPE 0x00000200 /* Unicast Promiscuous Ena */
-#define IXGBE_FCTRL_BAM 0x00000400 /* Broadcast Accept Mode */
-#define IXGBE_FCTRL_PMCF 0x00001000 /* Pass MAC Control Frames */
-#define IXGBE_FCTRL_DPF 0x00002000 /* Discard Pause Frame */
+#define IXGBE_RXMTRL_V2_MSGID_MASK	0x0000FF00
+#define IXGBE_RXMTRL_V2_SYNC_MSG	0x0000
+#define IXGBE_RXMTRL_V2_DELAY_REQ_MSG	0x0100
+#define IXGBE_RXMTRL_V2_PDELAY_REQ_MSG	0x0200
+#define IXGBE_RXMTRL_V2_PDELAY_RESP_MSG	0x0300
+#define IXGBE_RXMTRL_V2_FOLLOWUP_MSG	0x0800
+#define IXGBE_RXMTRL_V2_DELAY_RESP_MSG	0x0900
+#define IXGBE_RXMTRL_V2_PDELAY_FOLLOWUP_MSG 0x0A00
+#define IXGBE_RXMTRL_V2_ANNOUNCE_MSG	0x0B00
+#define IXGBE_RXMTRL_V2_SIGNALLING_MSG	0x0C00
+#define IXGBE_RXMTRL_V2_MGMT_MSG	0x0D00
+
+#define IXGBE_FCTRL_SBP		0x00000002 /* Store Bad Packet */
+#define IXGBE_FCTRL_MPE		0x00000100 /* Multicast Promiscuous Ena*/
+#define IXGBE_FCTRL_UPE		0x00000200 /* Unicast Promiscuous Ena */
+#define IXGBE_FCTRL_BAM		0x00000400 /* Broadcast Accept Mode */
+#define IXGBE_FCTRL_PMCF	0x00001000 /* Pass MAC Control Frames */
+#define IXGBE_FCTRL_DPF		0x00002000 /* Discard Pause Frame */
 /* Receive Priority Flow Control Enable */
-#define IXGBE_FCTRL_RPFCE 0x00004000
-#define IXGBE_FCTRL_RFCE 0x00008000 /* Receive Flow Control Ena */
-#define IXGBE_MFLCN_PMCF        0x00000001 /* Pass MAC Control Frames */
-#define IXGBE_MFLCN_DPF         0x00000002 /* Discard Pause Frame */
-#define IXGBE_MFLCN_RPFCE       0x00000004 /* Receive Priority FC Enable */
-#define IXGBE_MFLCN_RFCE        0x00000008 /* Receive FC Enable */
-#define IXGBE_MFLCN_RPFCE_MASK	0x00000FF4 /* Receive FC Mask */
-
-#define IXGBE_MFLCN_RPFCE_SHIFT		 4
+#define IXGBE_FCTRL_RPFCE	0x00004000
+#define IXGBE_FCTRL_RFCE	0x00008000 /* Receive Flow Control Ena */
+#define IXGBE_MFLCN_PMCF	0x00000001 /* Pass MAC Control Frames */
+#define IXGBE_MFLCN_DPF		0x00000002 /* Discard Pause Frame */
+#define IXGBE_MFLCN_RPFCE	0x00000004 /* Receive Priority FC Enable */
+#define IXGBE_MFLCN_RFCE	0x00000008 /* Receive FC Enable */
+#define IXGBE_MFLCN_RPFCE_MASK	0x00000FF4 /* Rx Priority FC bitmap mask */
+#define IXGBE_MFLCN_RPFCE_SHIFT	4 /* Rx Priority FC bitmap shift */
 
 /* Multiple Receive Queue Control */
-#define IXGBE_MRQC_RSSEN                 0x00000001  /* RSS Enable */
-#define IXGBE_MRQC_MRQE_MASK                    0xF /* Bits 3:0 */
-#define IXGBE_MRQC_RT8TCEN               0x00000002 /* 8 TC no RSS */
-#define IXGBE_MRQC_RT4TCEN               0x00000003 /* 4 TC no RSS */
-#define IXGBE_MRQC_RTRSS8TCEN            0x00000004 /* 8 TC w/ RSS */
-#define IXGBE_MRQC_RTRSS4TCEN            0x00000005 /* 4 TC w/ RSS */
-#define IXGBE_MRQC_VMDQEN                0x00000008 /* VMDq2 64 pools no RSS */
-#define IXGBE_MRQC_VMDQRSS32EN           0x0000000A /* VMDq2 32 pools w/ RSS */
-#define IXGBE_MRQC_VMDQRSS64EN           0x0000000B /* VMDq2 64 pools w/ RSS */
-#define IXGBE_MRQC_VMDQRT8TCEN           0x0000000C /* VMDq2/RT 16 pool 8 TC */
-#define IXGBE_MRQC_VMDQRT4TCEN           0x0000000D /* VMDq2/RT 32 pool 4 TC */
-#define IXGBE_MRQC_RSS_FIELD_MASK        0xFFFF0000
-#define IXGBE_MRQC_RSS_FIELD_IPV4_TCP    0x00010000
-#define IXGBE_MRQC_RSS_FIELD_IPV4        0x00020000
+#define IXGBE_MRQC_RSSEN	0x00000001  /* RSS Enable */
+#define IXGBE_MRQC_MRQE_MASK	0xF /* Bits 3:0 */
+#define IXGBE_MRQC_RT8TCEN	0x00000002 /* 8 TC no RSS */
+#define IXGBE_MRQC_RT4TCEN	0x00000003 /* 4 TC no RSS */
+#define IXGBE_MRQC_RTRSS8TCEN	0x00000004 /* 8 TC w/ RSS */
+#define IXGBE_MRQC_RTRSS4TCEN	0x00000005 /* 4 TC w/ RSS */
+#define IXGBE_MRQC_VMDQEN	0x00000008 /* VMDq2 64 pools no RSS */
+#define IXGBE_MRQC_VMDQRSS32EN	0x0000000A /* VMDq2 32 pools w/ RSS */
+#define IXGBE_MRQC_VMDQRSS64EN	0x0000000B /* VMDq2 64 pools w/ RSS */
+#define IXGBE_MRQC_VMDQRT8TCEN	0x0000000C /* VMDq2/RT 16 pool 8 TC */
+#define IXGBE_MRQC_VMDQRT4TCEN	0x0000000D /* VMDq2/RT 32 pool 4 TC */
+#define IXGBE_MRQC_L3L4TXSWEN	0x00008000 /* Enable L3/L4 Tx switch */
+#define IXGBE_MRQC_RSS_FIELD_MASK	0xFFFF0000
+#define IXGBE_MRQC_RSS_FIELD_IPV4_TCP	0x00010000
+#define IXGBE_MRQC_RSS_FIELD_IPV4	0x00020000
 #define IXGBE_MRQC_RSS_FIELD_IPV6_EX_TCP 0x00040000
-#define IXGBE_MRQC_RSS_FIELD_IPV6_EX     0x00080000
-#define IXGBE_MRQC_RSS_FIELD_IPV6        0x00100000
-#define IXGBE_MRQC_RSS_FIELD_IPV6_TCP    0x00200000
-#define IXGBE_MRQC_RSS_FIELD_IPV4_UDP    0x00400000
-#define IXGBE_MRQC_RSS_FIELD_IPV6_UDP    0x00800000
+#define IXGBE_MRQC_RSS_FIELD_IPV6_EX	0x00080000
+#define IXGBE_MRQC_RSS_FIELD_IPV6	0x00100000
+#define IXGBE_MRQC_RSS_FIELD_IPV6_TCP	0x00200000
+#define IXGBE_MRQC_RSS_FIELD_IPV4_UDP	0x00400000
+#define IXGBE_MRQC_RSS_FIELD_IPV6_UDP	0x00800000
 #define IXGBE_MRQC_RSS_FIELD_IPV6_EX_UDP 0x01000000
-#define IXGBE_MRQC_MULTIPLE_RSS          0x00002000
-#define IXGBE_MRQC_L3L4TXSWEN            0x00008000
-
-#define IXGBE_FWSM_TS_ENABLED	0x1
+#define IXGBE_MRQC_MULTIPLE_RSS		0x00002000
+#define IXGBE_MRQC_L3L4TXSWEN		0x00008000
 
 /* Queue Drop Enable */
 #define IXGBE_QDE_ENABLE	0x00000001
@@ -2290,296 +2655,383 @@ enum {
 #define IXGBE_QDE_IDX_MASK	0x00007F00
 #define IXGBE_QDE_IDX_SHIFT	8
 #define IXGBE_QDE_WRITE		0x00010000
-
-#define IXGBE_TXD_POPTS_IXSM 0x01       /* Insert IP checksum */
-#define IXGBE_TXD_POPTS_TXSM 0x02       /* Insert TCP/UDP checksum */
-#define IXGBE_TXD_CMD_EOP    0x01000000 /* End of Packet */
-#define IXGBE_TXD_CMD_IFCS   0x02000000 /* Insert FCS (Ethernet CRC) */
-#define IXGBE_TXD_CMD_IC     0x04000000 /* Insert Checksum */
-#define IXGBE_TXD_CMD_RS     0x08000000 /* Report Status */
-#define IXGBE_TXD_CMD_DEXT   0x20000000 /* Descriptor extension (0 = legacy) */
-#define IXGBE_TXD_CMD_VLE    0x40000000 /* Add VLAN tag */
-#define IXGBE_TXD_STAT_DD    0x00000001 /* Descriptor Done */
-
-#define IXGBE_RXDADV_IPSEC_STATUS_SECP                  0x00020000
-#define IXGBE_RXDADV_IPSEC_ERROR_INVALID_PROTOCOL       0x08000000
-#define IXGBE_RXDADV_IPSEC_ERROR_INVALID_LENGTH         0x10000000
-#define IXGBE_RXDADV_IPSEC_ERROR_AUTH_FAILED            0x18000000
-#define IXGBE_RXDADV_IPSEC_ERROR_BIT_MASK               0x18000000
+#define IXGBE_QDE_READ		0x00020000
+
+#define IXGBE_TXD_POPTS_IXSM	0x01 /* Insert IP checksum */
+#define IXGBE_TXD_POPTS_TXSM	0x02 /* Insert TCP/UDP checksum */
+#define IXGBE_TXD_CMD_EOP	0x01000000 /* End of Packet */
+#define IXGBE_TXD_CMD_IFCS	0x02000000 /* Insert FCS (Ethernet CRC) */
+#define IXGBE_TXD_CMD_IC	0x04000000 /* Insert Checksum */
+#define IXGBE_TXD_CMD_RS	0x08000000 /* Report Status */
+#define IXGBE_TXD_CMD_DEXT	0x20000000 /* Desc extension (0 = legacy) */
+#define IXGBE_TXD_CMD_VLE	0x40000000 /* Add VLAN tag */
+#define IXGBE_TXD_STAT_DD	0x00000001 /* Descriptor Done */
+
+#define IXGBE_RXDADV_IPSEC_STATUS_SECP		0x00020000
+#define IXGBE_RXDADV_IPSEC_ERROR_INVALID_PROTOCOL 0x08000000
+#define IXGBE_RXDADV_IPSEC_ERROR_INVALID_LENGTH	0x10000000
+#define IXGBE_RXDADV_IPSEC_ERROR_AUTH_FAILED	0x18000000
+#define IXGBE_RXDADV_IPSEC_ERROR_BIT_MASK	0x18000000
 /* Multiple Transmit Queue Command Register */
-#define IXGBE_MTQC_RT_ENA       0x1 /* DCB Enable */
-#define IXGBE_MTQC_VT_ENA       0x2 /* VMDQ2 Enable */
-#define IXGBE_MTQC_64Q_1PB      0x0 /* 64 queues 1 pack buffer */
-#define IXGBE_MTQC_32VF         0x8 /* 4 TX Queues per pool w/32VF's */
-#define IXGBE_MTQC_64VF         0x4 /* 2 TX Queues per pool w/64VF's */
-#define IXGBE_MTQC_8TC_8TQ      0xC /* 8 TC if RT_ENA or 8 TQ if VT_ENA */
-#define IXGBE_MTQC_4TC_4TQ	0x8 /* 4 TC if RT_ENA or 4 TQ if VT_ENA */
+#define IXGBE_MTQC_RT_ENA	0x1 /* DCB Enable */
+#define IXGBE_MTQC_VT_ENA	0x2 /* VMDQ2 Enable */
+#define IXGBE_MTQC_64Q_1PB	0x0 /* 64 queues 1 pack buffer */
+#define IXGBE_MTQC_32VF		0x8 /* 4 TX Queues per pool w/32VF's */
+#define IXGBE_MTQC_64VF		0x4 /* 2 TX Queues per pool w/64VF's */
+#define IXGBE_MTQC_4TC_4TQ	0x8 /* 4 TC if RT_ENA and VT_ENA */
+#define IXGBE_MTQC_8TC_8TQ	0xC /* 8 TC if RT_ENA or 8 TQ if VT_ENA */
 
 /* Receive Descriptor bit definitions */
-#define IXGBE_RXD_STAT_DD       0x01    /* Descriptor Done */
-#define IXGBE_RXD_STAT_EOP      0x02    /* End of Packet */
-#define IXGBE_RXD_STAT_FLM      0x04    /* FDir Match */
-#define IXGBE_RXD_STAT_VP       0x08    /* IEEE VLAN Packet */
-#define IXGBE_RXDADV_NEXTP_MASK   0x000FFFF0 /* Next Descriptor Index */
-#define IXGBE_RXDADV_NEXTP_SHIFT  0x00000004
-#define IXGBE_RXD_STAT_UDPCS    0x10    /* UDP xsum calculated */
-#define IXGBE_RXD_STAT_L4CS     0x20    /* L4 xsum calculated */
-#define IXGBE_RXD_STAT_IPCS     0x40    /* IP xsum calculated */
-#define IXGBE_RXD_STAT_PIF      0x80    /* passed in-exact filter */
-#define IXGBE_RXD_STAT_CRCV     0x100   /* Speculative CRC Valid */
-#define IXGBE_RXD_STAT_OUTERIPCS  0x100 /* Cloud IP xsum calculated */
-#define IXGBE_RXD_STAT_VEXT     0x200   /* 1st VLAN found */
-#define IXGBE_RXD_STAT_UDPV     0x400   /* Valid UDP checksum */
-#define IXGBE_RXD_STAT_DYNINT   0x800   /* Pkt caused INT via DYNINT */
-#define IXGBE_RXD_STAT_LLINT    0x800   /* Pkt caused Low Latency Interrupt */
-#define IXGBE_RXD_STAT_TS       0x10000 /* Time Stamp */
-#define IXGBE_RXD_STAT_SECP     0x20000 /* Security Processing */
-#define IXGBE_RXD_STAT_LB       0x40000 /* Loopback Status */
-#define IXGBE_RXD_STAT_ACK      0x8000  /* ACK Packet indication */
-#define IXGBE_RXD_ERR_CE        0x01    /* CRC Error */
-#define IXGBE_RXD_ERR_LE        0x02    /* Length Error */
-#define IXGBE_RXD_ERR_PE        0x08    /* Packet Error */
-#define IXGBE_RXD_ERR_OSE       0x10    /* Oversize Error */
-#define IXGBE_RXD_ERR_USE       0x20    /* Undersize Error */
-#define IXGBE_RXD_ERR_TCPE      0x40    /* TCP/UDP Checksum Error */
-#define IXGBE_RXD_ERR_IPE       0x80    /* IP Checksum Error */
-#define IXGBE_RXDADV_ERR_MASK           0xfff00000 /* RDESC.ERRORS mask */
-#define IXGBE_RXDADV_ERR_SHIFT          20         /* RDESC.ERRORS shift */
+#define IXGBE_RXD_STAT_DD	0x01 /* Descriptor Done */
+#define IXGBE_RXD_STAT_EOP	0x02 /* End of Packet */
+#define IXGBE_RXD_STAT_FLM	0x04 /* FDir Match */
+#define IXGBE_RXD_STAT_VP	0x08 /* IEEE VLAN Packet */
+#define IXGBE_RXDADV_NEXTP_MASK	0x000FFFF0 /* Next Descriptor Index */
+#define IXGBE_RXDADV_NEXTP_SHIFT	0x00000004
+#define IXGBE_RXD_STAT_UDPCS	0x10 /* UDP xsum calculated */
+#define IXGBE_RXD_STAT_L4CS	0x20 /* L4 xsum calculated */
+#define IXGBE_RXD_STAT_IPCS	0x40 /* IP xsum calculated */
+#define IXGBE_RXD_STAT_PIF	0x80 /* passed in-exact filter */
+#define IXGBE_RXD_STAT_CRCV	0x100 /* Speculative CRC Valid */
+#define IXGBE_RXD_STAT_OUTERIPCS	0x100 /* Cloud IP xsum calculated */
+#define IXGBE_RXD_STAT_VEXT	0x200 /* 1st VLAN found */
+#define IXGBE_RXD_STAT_UDPV	0x400 /* Valid UDP checksum */
+#define IXGBE_RXD_STAT_DYNINT	0x800 /* Pkt caused INT via DYNINT */
+#define IXGBE_RXD_STAT_LLINT	0x800 /* Pkt caused Low Latency Interrupt */
+#define IXGBE_RXD_STAT_TSIP	0x08000 /* Time Stamp in packet buffer */
+#define IXGBE_RXD_STAT_TS	0x10000 /* Time Stamp */
+#define IXGBE_RXD_STAT_SECP	0x20000 /* Security Processing */
+#define IXGBE_RXD_STAT_LB	0x40000 /* Loopback Status */
+#define IXGBE_RXD_STAT_ACK	0x8000 /* ACK Packet indication */
+#define IXGBE_RXD_ERR_CE	0x01 /* CRC Error */
+#define IXGBE_RXD_ERR_LE	0x02 /* Length Error */
+#define IXGBE_RXD_ERR_PE	0x08 /* Packet Error */
+#define IXGBE_RXD_ERR_OSE	0x10 /* Oversize Error */
+#define IXGBE_RXD_ERR_USE	0x20 /* Undersize Error */
+#define IXGBE_RXD_ERR_TCPE	0x40 /* TCP/UDP Checksum Error */
+#define IXGBE_RXD_ERR_IPE	0x80 /* IP Checksum Error */
+#define IXGBE_RXDADV_ERR_MASK		0xfff00000 /* RDESC.ERRORS mask */
+#define IXGBE_RXDADV_ERR_SHIFT		20 /* RDESC.ERRORS shift */
 #define IXGBE_RXDADV_ERR_OUTERIPER	0x04000000 /* CRC IP Header error */
-#define IXGBE_RXDADV_ERR_FCEOFE         0x80000000 /* FCoEFe/IPE */
-#define IXGBE_RXDADV_ERR_FCERR          0x00700000 /* FCERR/FDIRERR */
-#define IXGBE_RXDADV_ERR_FDIR_LEN       0x00100000 /* FDIR Length error */
-#define IXGBE_RXDADV_ERR_FDIR_DROP      0x00200000 /* FDIR Drop error */
-#define IXGBE_RXDADV_ERR_FDIR_COLL      0x00400000 /* FDIR Collision error */
-#define IXGBE_RXDADV_ERR_HBO    0x00800000 /*Header Buffer Overflow */
-#define IXGBE_RXDADV_ERR_CE     0x01000000 /* CRC Error */
-#define IXGBE_RXDADV_ERR_LE     0x02000000 /* Length Error */
-#define IXGBE_RXDADV_ERR_PE     0x08000000 /* Packet Error */
-#define IXGBE_RXDADV_ERR_OSE    0x10000000 /* Oversize Error */
-#define IXGBE_RXDADV_ERR_USE    0x20000000 /* Undersize Error */
-#define IXGBE_RXDADV_ERR_TCPE   0x40000000 /* TCP/UDP Checksum Error */
-#define IXGBE_RXDADV_ERR_IPE    0x80000000 /* IP Checksum Error */
-#define IXGBE_RXD_VLAN_ID_MASK  0x0FFF  /* VLAN ID is in lower 12 bits */
-#define IXGBE_RXD_PRI_MASK      0xE000  /* Priority is in upper 3 bits */
-#define IXGBE_RXD_PRI_SHIFT     13
-#define IXGBE_RXD_CFI_MASK      0x1000  /* CFI is bit 12 */
-#define IXGBE_RXD_CFI_SHIFT     12
-
-#define IXGBE_RXDADV_STAT_DD            IXGBE_RXD_STAT_DD  /* Done */
-#define IXGBE_RXDADV_STAT_EOP           IXGBE_RXD_STAT_EOP /* End of Packet */
-#define IXGBE_RXDADV_STAT_FLM           IXGBE_RXD_STAT_FLM /* FDir Match */
-#define IXGBE_RXDADV_STAT_VP            IXGBE_RXD_STAT_VP  /* IEEE VLAN Pkt */
-#define IXGBE_RXDADV_STAT_MASK          0x000fffff /* Stat/NEXTP: bit 0-19 */
-#define IXGBE_RXDADV_STAT_FCEOFS        0x00000040 /* FCoE EOF/SOF Stat */
-#define IXGBE_RXDADV_STAT_FCSTAT        0x00000030 /* FCoE Pkt Stat */
-#define IXGBE_RXDADV_STAT_FCSTAT_NOMTCH 0x00000000 /* 00: No Ctxt Match */
-#define IXGBE_RXDADV_STAT_FCSTAT_NODDP  0x00000010 /* 01: Ctxt w/o DDP */
-#define IXGBE_RXDADV_STAT_FCSTAT_FCPRSP 0x00000020 /* 10: Recv. FCP_RSP */
-#define IXGBE_RXDADV_STAT_FCSTAT_DDP    0x00000030 /* 11: Ctxt w/ DDP */
-#define IXGBE_RXDADV_STAT_TS		0x00010000 /* IEEE 1588 Time Stamp */
+#define IXGBE_RXDADV_ERR_RXE		0x20000000 /* Any MAC Error */
+#define IXGBE_RXDADV_ERR_FCEOFE		0x80000000 /* FCEOFe/IPE */
+#define IXGBE_RXDADV_ERR_FCERR		0x00700000 /* FCERR/FDIRERR */
+#define IXGBE_RXDADV_ERR_FDIR_LEN	0x00100000 /* FDIR Length error */
+#define IXGBE_RXDADV_ERR_FDIR_DROP	0x00200000 /* FDIR Drop error */
+#define IXGBE_RXDADV_ERR_FDIR_COLL	0x00400000 /* FDIR Collision error */
+#define IXGBE_RXDADV_ERR_HBO	0x00800000 /*Header Buffer Overflow */
+#define IXGBE_RXDADV_ERR_CE	0x01000000 /* CRC Error */
+#define IXGBE_RXDADV_ERR_LE	0x02000000 /* Length Error */
+#define IXGBE_RXDADV_ERR_PE	0x08000000 /* Packet Error */
+#define IXGBE_RXDADV_ERR_OSE	0x10000000 /* Oversize Error */
+#define IXGBE_RXDADV_ERR_USE	0x20000000 /* Undersize Error */
+#define IXGBE_RXDADV_ERR_TCPE	0x40000000 /* TCP/UDP Checksum Error */
+#define IXGBE_RXDADV_ERR_IPE	0x80000000 /* IP Checksum Error */
+#define IXGBE_RXD_VLAN_ID_MASK	0x0FFF  /* VLAN ID is in lower 12 bits */
+#define IXGBE_RXD_PRI_MASK	0xE000  /* Priority is in upper 3 bits */
+#define IXGBE_RXD_PRI_SHIFT	13
+#define IXGBE_RXD_CFI_MASK	0x1000  /* CFI is bit 12 */
+#define IXGBE_RXD_CFI_SHIFT	12
+
+#define IXGBE_RXDADV_STAT_DD		IXGBE_RXD_STAT_DD  /* Done */
+#define IXGBE_RXDADV_STAT_EOP		IXGBE_RXD_STAT_EOP /* End of Packet */
+#define IXGBE_RXDADV_STAT_FLM		IXGBE_RXD_STAT_FLM /* FDir Match */
+#define IXGBE_RXDADV_STAT_VP		IXGBE_RXD_STAT_VP  /* IEEE VLAN Pkt */
+#define IXGBE_RXDADV_STAT_MASK		0x000fffff /* Stat/NEXTP: bit 0-19 */
+#define IXGBE_RXDADV_STAT_FCEOFS	0x00000040 /* FCoE EOF/SOF Stat */
+#define IXGBE_RXDADV_STAT_FCSTAT	0x00000030 /* FCoE Pkt Stat */
+#define IXGBE_RXDADV_STAT_FCSTAT_NOMTCH	0x00000000 /* 00: No Ctxt Match */
+#define IXGBE_RXDADV_STAT_FCSTAT_NODDP	0x00000010 /* 01: Ctxt w/o DDP */
+#define IXGBE_RXDADV_STAT_FCSTAT_FCPRSP	0x00000020 /* 10: Recv. FCP_RSP */
+#define IXGBE_RXDADV_STAT_FCSTAT_DDP	0x00000030 /* 11: Ctxt w/ DDP */
+#define IXGBE_RXDADV_STAT_TS		0x00010000 /* IEEE1588 Time Stamp */
+#define IXGBE_RXDADV_STAT_TSIP		0x00008000 /* Time Stamp in packet buffer */
 
 /* PSRTYPE bit definitions */
-#define IXGBE_PSRTYPE_TCPHDR    0x00000010
-#define IXGBE_PSRTYPE_UDPHDR    0x00000020
-#define IXGBE_PSRTYPE_IPV4HDR   0x00000100
-#define IXGBE_PSRTYPE_IPV6HDR   0x00000200
-#define IXGBE_PSRTYPE_L2HDR     0x00001000
+#define IXGBE_PSRTYPE_TCPHDR	0x00000010
+#define IXGBE_PSRTYPE_UDPHDR	0x00000020
+#define IXGBE_PSRTYPE_IPV4HDR	0x00000100
+#define IXGBE_PSRTYPE_IPV6HDR	0x00000200
+#define IXGBE_PSRTYPE_L2HDR	0x00001000
 
 /* SRRCTL bit definitions */
-#define IXGBE_SRRCTL_BSIZEPKT_SHIFT     10     /* so many KBs */
-#define IXGBE_SRRCTL_RDMTS_SHIFT        22
-#define IXGBE_SRRCTL_RDMTS_MASK         0x01C00000
-#define IXGBE_SRRCTL_DROP_EN            0x10000000
-#define IXGBE_SRRCTL_BSIZEPKT_MASK      0x0000007F
-#define IXGBE_SRRCTL_BSIZEHDR_MASK      0x00003F00
-#define IXGBE_SRRCTL_DESCTYPE_LEGACY    0x00000000
+#define IXGBE_SRRCTL_BSIZEPKT_SHIFT	10 /* so many KBs */
+#define IXGBE_SRRCTL_BSIZEHDRSIZE_SHIFT	2 /* 64byte resolution (>> 6)
+					   * + at bit 8 offset (<< 8)
+					   *  = (<< 2)
+					   */
+#define IXGBE_SRRCTL_RDMTS_SHIFT	22
+#define IXGBE_SRRCTL_RDMTS_MASK		0x01C00000
+#define IXGBE_SRRCTL_DROP_EN		0x10000000
+#define IXGBE_SRRCTL_BSIZEPKT_MASK	0x0000007F
+#define IXGBE_SRRCTL_BSIZEHDR_MASK	0x00003F00
+#define IXGBE_SRRCTL_DESCTYPE_LEGACY	0x00000000
 #define IXGBE_SRRCTL_DESCTYPE_ADV_ONEBUF 0x02000000
-#define IXGBE_SRRCTL_DESCTYPE_HDR_SPLIT  0x04000000
+#define IXGBE_SRRCTL_DESCTYPE_HDR_SPLIT	0x04000000
 #define IXGBE_SRRCTL_DESCTYPE_HDR_REPLICATION_LARGE_PKT 0x08000000
 #define IXGBE_SRRCTL_DESCTYPE_HDR_SPLIT_ALWAYS 0x0A000000
-#define IXGBE_SRRCTL_DESCTYPE_MASK      0x0E000000
+#define IXGBE_SRRCTL_DESCTYPE_MASK	0x0E000000
 
-#define IXGBE_RXDPS_HDRSTAT_HDRSP       0x00008000
-#define IXGBE_RXDPS_HDRSTAT_HDRLEN_MASK 0x000003FF
+#define IXGBE_RXDPS_HDRSTAT_HDRSP	0x00008000
+#define IXGBE_RXDPS_HDRSTAT_HDRLEN_MASK	0x000003FF
 
-#define IXGBE_RXDADV_RSSTYPE_MASK       0x0000000F
-#define IXGBE_RXDADV_PKTTYPE_MASK       0x0000FFF0
-#define IXGBE_RXDADV_PKTTYPE_MASK_EX    0x0001FFF0
-#define IXGBE_RXDADV_HDRBUFLEN_MASK     0x00007FE0
-#define IXGBE_RXDADV_RSCCNT_MASK        0x001E0000
-#define IXGBE_RXDADV_RSCCNT_SHIFT       17
-#define IXGBE_RXDADV_HDRBUFLEN_SHIFT    5
-#define IXGBE_RXDADV_SPLITHEADER_EN     0x00001000
-#define IXGBE_RXDADV_SPH                0x8000
+#define IXGBE_RXDADV_RSSTYPE_MASK	0x0000000F
+#define IXGBE_RXDADV_PKTTYPE_MASK	0x0000FFF0
+#define IXGBE_RXDADV_PKTTYPE_MASK_EX	0x0001FFF0
+#define IXGBE_RXDADV_HDRBUFLEN_MASK	0x00007FE0
+#define IXGBE_RXDADV_RSCCNT_MASK	0x001E0000
+#define IXGBE_RXDADV_RSCCNT_SHIFT	17
+#define IXGBE_RXDADV_HDRBUFLEN_SHIFT	5
+#define IXGBE_RXDADV_SPLITHEADER_EN	0x00001000
+#define IXGBE_RXDADV_SPH		0x8000
 
 /* RSS Hash results */
-#define IXGBE_RXDADV_RSSTYPE_NONE       0x00000000
-#define IXGBE_RXDADV_RSSTYPE_IPV4_TCP   0x00000001
-#define IXGBE_RXDADV_RSSTYPE_IPV4       0x00000002
-#define IXGBE_RXDADV_RSSTYPE_IPV6_TCP   0x00000003
-#define IXGBE_RXDADV_RSSTYPE_IPV6_EX    0x00000004
-#define IXGBE_RXDADV_RSSTYPE_IPV6       0x00000005
+#define IXGBE_RXDADV_RSSTYPE_NONE	0x00000000
+#define IXGBE_RXDADV_RSSTYPE_IPV4_TCP	0x00000001
+#define IXGBE_RXDADV_RSSTYPE_IPV4	0x00000002
+#define IXGBE_RXDADV_RSSTYPE_IPV6_TCP	0x00000003
+#define IXGBE_RXDADV_RSSTYPE_IPV6_EX	0x00000004
+#define IXGBE_RXDADV_RSSTYPE_IPV6	0x00000005
 #define IXGBE_RXDADV_RSSTYPE_IPV6_TCP_EX 0x00000006
-#define IXGBE_RXDADV_RSSTYPE_IPV4_UDP   0x00000007
-#define IXGBE_RXDADV_RSSTYPE_IPV6_UDP   0x00000008
+#define IXGBE_RXDADV_RSSTYPE_IPV4_UDP	0x00000007
+#define IXGBE_RXDADV_RSSTYPE_IPV6_UDP	0x00000008
 #define IXGBE_RXDADV_RSSTYPE_IPV6_UDP_EX 0x00000009
 
 /* RSS Packet Types as indicated in the receive descriptor. */
-#define IXGBE_RXDADV_PKTTYPE_NONE       0x00000000
-#define IXGBE_RXDADV_PKTTYPE_IPV4       0x00000010 /* IPv4 hdr present */
-#define IXGBE_RXDADV_PKTTYPE_IPV4_EX    0x00000020 /* IPv4 hdr + extensions */
-#define IXGBE_RXDADV_PKTTYPE_IPV6       0x00000040 /* IPv6 hdr present */
-#define IXGBE_RXDADV_PKTTYPE_IPV6_EX    0x00000080 /* IPv6 hdr + extensions */
-#define IXGBE_RXDADV_PKTTYPE_TCP        0x00000100 /* TCP hdr present */
-#define IXGBE_RXDADV_PKTTYPE_UDP        0x00000200 /* UDP hdr present */
-#define IXGBE_RXDADV_PKTTYPE_SCTP       0x00000400 /* SCTP hdr present */
-#define IXGBE_RXDADV_PKTTYPE_NFS        0x00000800 /* NFS hdr present */
+#define IXGBE_RXDADV_PKTTYPE_NONE	0x00000000
+#define IXGBE_RXDADV_PKTTYPE_IPV4	0x00000010 /* IPv4 hdr present */
+#define IXGBE_RXDADV_PKTTYPE_IPV4_EX	0x00000020 /* IPv4 hdr + extensions */
+#define IXGBE_RXDADV_PKTTYPE_IPV6	0x00000040 /* IPv6 hdr present */
+#define IXGBE_RXDADV_PKTTYPE_IPV6_EX	0x00000080 /* IPv6 hdr + extensions */
+#define IXGBE_RXDADV_PKTTYPE_TCP	0x00000100 /* TCP hdr present */
+#define IXGBE_RXDADV_PKTTYPE_UDP	0x00000200 /* UDP hdr present */
+#define IXGBE_RXDADV_PKTTYPE_SCTP	0x00000400 /* SCTP hdr present */
+#define IXGBE_RXDADV_PKTTYPE_NFS	0x00000800 /* NFS hdr present */
+#define IXGBE_RXDADV_PKTTYPE_GENEVE	0x00000800 /* GENEVE hdr present */
 #define IXGBE_RXDADV_PKTTYPE_VXLAN	0x00000800 /* VXLAN hdr present */
 #define IXGBE_RXDADV_PKTTYPE_TUNNEL	0x00010000 /* Tunnel type */
-#define IXGBE_RXDADV_PKTTYPE_IPSEC_ESP  0x00001000 /* IPSec ESP */
-#define IXGBE_RXDADV_PKTTYPE_IPSEC_AH   0x00002000 /* IPSec AH */
-#define IXGBE_RXDADV_PKTTYPE_LINKSEC    0x00004000 /* LinkSec Encap */
-#define IXGBE_RXDADV_PKTTYPE_ETQF       0x00008000 /* PKTTYPE is ETQF index */
-#define IXGBE_RXDADV_PKTTYPE_ETQF_MASK  0x00000070 /* ETQF has 8 indices */
-#define IXGBE_RXDADV_PKTTYPE_ETQF_SHIFT 4          /* Right-shift 4 bits */
+#define IXGBE_RXDADV_PKTTYPE_IPSEC_ESP	0x00001000 /* IPSec ESP */
+#define IXGBE_RXDADV_PKTTYPE_IPSEC_AH	0x00002000 /* IPSec AH */
+#define IXGBE_RXDADV_PKTTYPE_LINKSEC	0x00004000 /* LinkSec Encap */
+#define IXGBE_RXDADV_PKTTYPE_ETQF	0x00008000 /* PKTTYPE is ETQF index */
+#define IXGBE_RXDADV_PKTTYPE_ETQF_MASK	0x00000070 /* ETQF has 8 indices */
+#define IXGBE_RXDADV_PKTTYPE_ETQF_SHIFT	4 /* Right-shift 4 bits */
 
 /* Security Processing bit Indication */
-#define IXGBE_RXDADV_LNKSEC_STATUS_SECP         0x00020000
-#define IXGBE_RXDADV_LNKSEC_ERROR_NO_SA_MATCH   0x08000000
-#define IXGBE_RXDADV_LNKSEC_ERROR_REPLAY_ERROR  0x10000000
-#define IXGBE_RXDADV_LNKSEC_ERROR_BIT_MASK      0x18000000
-#define IXGBE_RXDADV_LNKSEC_ERROR_BAD_SIG       0x18000000
+#define IXGBE_RXDADV_LNKSEC_STATUS_SECP		0x00020000
+#define IXGBE_RXDADV_LNKSEC_ERROR_NO_SA_MATCH	0x08000000
+#define IXGBE_RXDADV_LNKSEC_ERROR_REPLAY_ERROR	0x10000000
+#define IXGBE_RXDADV_LNKSEC_ERROR_BIT_MASK	0x18000000
+#define IXGBE_RXDADV_LNKSEC_ERROR_BAD_SIG	0x18000000
 
 /* Masks to determine if packets should be dropped due to frame errors */
 #define IXGBE_RXD_ERR_FRAME_ERR_MASK ( \
-				      IXGBE_RXD_ERR_CE | \
-				      IXGBE_RXD_ERR_LE | \
-				      IXGBE_RXD_ERR_PE | \
-				      IXGBE_RXD_ERR_OSE | \
-				      IXGBE_RXD_ERR_USE)
+				IXGBE_RXD_ERR_CE | \
+				IXGBE_RXD_ERR_LE | \
+				IXGBE_RXD_ERR_PE | \
+				IXGBE_RXD_ERR_OSE | \
+				IXGBE_RXD_ERR_USE)
 
 #define IXGBE_RXDADV_ERR_FRAME_ERR_MASK ( \
-				      IXGBE_RXDADV_ERR_CE | \
-				      IXGBE_RXDADV_ERR_LE | \
-				      IXGBE_RXDADV_ERR_PE | \
-				      IXGBE_RXDADV_ERR_OSE | \
-				      IXGBE_RXDADV_ERR_USE)
+				IXGBE_RXDADV_ERR_CE | \
+				IXGBE_RXDADV_ERR_LE | \
+				IXGBE_RXDADV_ERR_PE | \
+				IXGBE_RXDADV_ERR_OSE | \
+				IXGBE_RXDADV_ERR_USE)
+
+#define IXGBE_RXDADV_ERR_FRAME_ERR_MASK_82599	IXGBE_RXDADV_ERR_RXE
 
 /* Multicast bit mask */
-#define IXGBE_MCSTCTRL_MFE      0x4
+#define IXGBE_MCSTCTRL_MFE	0x4
 
 /* Number of Transmit and Receive Descriptors must be a multiple of 8 */
-#define IXGBE_REQ_TX_DESCRIPTOR_MULTIPLE  8
-#define IXGBE_REQ_RX_DESCRIPTOR_MULTIPLE  8
-#define IXGBE_REQ_TX_BUFFER_GRANULARITY   1024
+#define IXGBE_REQ_TX_DESCRIPTOR_MULTIPLE	8
+#define IXGBE_REQ_RX_DESCRIPTOR_MULTIPLE	8
+#define IXGBE_REQ_TX_BUFFER_GRANULARITY		1024
 
 /* Vlan-specific macros */
-#define IXGBE_RX_DESC_SPECIAL_VLAN_MASK  0x0FFF /* VLAN ID in lower 12 bits */
-#define IXGBE_RX_DESC_SPECIAL_PRI_MASK   0xE000 /* Priority in upper 3 bits */
-#define IXGBE_RX_DESC_SPECIAL_PRI_SHIFT  0x000D /* Priority in upper 3 of 16 */
-#define IXGBE_TX_DESC_SPECIAL_PRI_SHIFT  IXGBE_RX_DESC_SPECIAL_PRI_SHIFT
+#define IXGBE_RX_DESC_SPECIAL_VLAN_MASK	0x0FFF /* VLAN ID in lower 12 bits */
+#define IXGBE_RX_DESC_SPECIAL_PRI_MASK	0xE000 /* Priority in upper 3 bits */
+#define IXGBE_RX_DESC_SPECIAL_PRI_SHIFT	0x000D /* Priority in upper 3 of 16 */
+#define IXGBE_TX_DESC_SPECIAL_PRI_SHIFT	IXGBE_RX_DESC_SPECIAL_PRI_SHIFT
 
 /* SR-IOV specific macros */
-#define IXGBE_MBVFICR_INDEX(vf_number)   (vf_number >> 4)
+#define IXGBE_MBVFICR_INDEX(vf_number)	(vf_number >> 4)
 #define IXGBE_MBVFICR(_i)		(0x00710 + ((_i) * 4))
-#define IXGBE_VFLRE(_i)		((((_i) & 1) ? 0x001C0 : 0x00600))
-#define IXGBE_VFLREC(_i)		(0x00700 + ((_i) * 4))
+#define IXGBE_VFLRE(_i)			(((_i & 1) ? 0x001C0 : 0x00600))
+#define IXGBE_VFLREC(_i)		 (0x00700 + ((_i) * 4))
 /* Translated register #defines */
+#define IXGBE_PVFCTRL(P)	(0x00300 + (4 * (P)))
+#define IXGBE_PVFSTATUS(P)	(0x00008 + (0 * (P)))
+#define IXGBE_PVFLINKS(P)	(0x042A4 + (0 * (P)))
+#define IXGBE_PVFRTIMER(P)	(0x00048 + (0 * (P)))
+#define IXGBE_PVFMAILBOX(P)	(0x04C00 + (4 * (P)))
+#define IXGBE_PVFRXMEMWRAP(P)	(0x03190 + (0 * (P)))
+#define IXGBE_PVTEICR(P)	(0x00B00 + (4 * (P)))
+#define IXGBE_PVTEICS(P)	(0x00C00 + (4 * (P)))
+#define IXGBE_PVTEIMS(P)	(0x00D00 + (4 * (P)))
+#define IXGBE_PVTEIMC(P)	(0x00E00 + (4 * (P)))
+#define IXGBE_PVTEIAC(P)	(0x00F00 + (4 * (P)))
+#define IXGBE_PVTEIAM(P)	(0x04D00 + (4 * (P)))
+#define IXGBE_PVTEITR(P)	(((P) < 24) ? (0x00820 + ((P) * 4)) : \
+				 (0x012300 + (((P) - 24) * 4)))
+#define IXGBE_PVTIVAR(P)	(0x12500 + (4 * (P)))
+#define IXGBE_PVTIVAR_MISC(P)	(0x04E00 + (4 * (P)))
+#define IXGBE_PVTRSCINT(P)	(0x12000 + (4 * (P)))
+#define IXGBE_VFPBACL(P)	(0x110C8 + (4 * (P)))
+#define IXGBE_PVFRDBAL(P)	((P < 64) ? (0x01000 + (0x40 * (P))) \
+				 : (0x0D000 + (0x40 * ((P) - 64))))
+#define IXGBE_PVFRDBAH(P)	((P < 64) ? (0x01004 + (0x40 * (P))) \
+				 : (0x0D004 + (0x40 * ((P) - 64))))
+#define IXGBE_PVFRDLEN(P)	((P < 64) ? (0x01008 + (0x40 * (P))) \
+				 : (0x0D008 + (0x40 * ((P) - 64))))
+#define IXGBE_PVFRDH(P)		((P < 64) ? (0x01010 + (0x40 * (P))) \
+				 : (0x0D010 + (0x40 * ((P) - 64))))
+#define IXGBE_PVFRDT(P)		((P < 64) ? (0x01018 + (0x40 * (P))) \
+				 : (0x0D018 + (0x40 * ((P) - 64))))
+#define IXGBE_PVFRXDCTL(P)	((P < 64) ? (0x01028 + (0x40 * (P))) \
+				 : (0x0D028 + (0x40 * ((P) - 64))))
+#define IXGBE_PVFSRRCTL(P)	((P < 64) ? (0x01014 + (0x40 * (P))) \
+				 : (0x0D014 + (0x40 * ((P) - 64))))
+#define IXGBE_PVFPSRTYPE(P)	(0x0EA00 + (4 * (P)))
+#define IXGBE_PVFTDBAL(P)	(0x06000 + (0x40 * (P)))
+#define IXGBE_PVFTDBAH(P)	(0x06004 + (0x40 * (P)))
+#define IXGBE_PVFTDLEN(P)	(0x06008 + (0x40 * (P)))
 #define IXGBE_PVFTDH(P)		(0x06010 + (0x40 * (P)))
 #define IXGBE_PVFTDT(P)		(0x06018 + (0x40 * (P)))
+#define IXGBE_PVFTXDCTL(P)	(0x06028 + (0x40 * (P)))
 #define IXGBE_PVFTDWBAL(P)	(0x06038 + (0x40 * (P)))
 #define IXGBE_PVFTDWBAH(P)	(0x0603C + (0x40 * (P)))
+#define IXGBE_PVFDCA_RXCTRL(P)	(((P) < 64) ? (0x0100C + (0x40 * (P))) \
+				 : (0x0D00C + (0x40 * ((P) - 64))))
+#define IXGBE_PVFDCA_TXCTRL(P)	(0x0600C + (0x40 * (P)))
+#define IXGBE_PVFGPRC(x)	(0x0101C + (0x40 * (x)))
+#define IXGBE_PVFGPTC(x)	(0x08300 + (0x04 * (x)))
+#define IXGBE_PVFGORC_LSB(x)	(0x01020 + (0x40 * (x)))
+#define IXGBE_PVFGORC_MSB(x)	(0x0D020 + (0x40 * (x)))
+#define IXGBE_PVFGOTC_LSB(x)	(0x08400 + (0x08 * (x)))
+#define IXGBE_PVFGOTC_MSB(x)	(0x08404 + (0x08 * (x)))
+#define IXGBE_PVFMPRC(x)	(0x0D01C + (0x40 * (x)))
 
 #define IXGBE_PVFTDWBALn(q_per_pool, vf_number, vf_q_index) \
 		(IXGBE_PVFTDWBAL((q_per_pool)*(vf_number) + (vf_q_index)))
 #define IXGBE_PVFTDWBAHn(q_per_pool, vf_number, vf_q_index) \
 		(IXGBE_PVFTDWBAH((q_per_pool)*(vf_number) + (vf_q_index)))
 
-#define IXGBE_PVFTDHN(q_per_pool, vf_number, vf_q_index) \
+#define IXGBE_PVFTDHn(q_per_pool, vf_number, vf_q_index) \
 		(IXGBE_PVFTDH((q_per_pool)*(vf_number) + (vf_q_index)))
-#define IXGBE_PVFTDTN(q_per_pool, vf_number, vf_q_index) \
+#define IXGBE_PVFTDTn(q_per_pool, vf_number, vf_q_index) \
 		(IXGBE_PVFTDT((q_per_pool)*(vf_number) + (vf_q_index)))
 
+/* Little Endian defines */
+#ifndef __le16
+#define __le16  u16
+#endif
+#ifndef __le32
+#define __le32  u32
+#endif
+#ifndef __le64
+#define __le64  u64
+
+#endif
+#ifndef __be16
+/* Big Endian defines */
+#define __be16  u16
+#define __be32  u32
+#define __be64  u64
+
+#endif
 enum ixgbe_fdir_pballoc_type {
 	IXGBE_FDIR_PBALLOC_NONE = 0,
 	IXGBE_FDIR_PBALLOC_64K  = 1,
 	IXGBE_FDIR_PBALLOC_128K = 2,
 	IXGBE_FDIR_PBALLOC_256K = 3,
 };
-#define IXGBE_FDIR_PBALLOC_SIZE_SHIFT           16
 
 /* Flow Director register values */
-#define IXGBE_FDIRCTRL_PBALLOC_64K              0x00000001
-#define IXGBE_FDIRCTRL_PBALLOC_128K             0x00000002
-#define IXGBE_FDIRCTRL_PBALLOC_256K             0x00000003
-#define IXGBE_FDIRCTRL_INIT_DONE                0x00000008
-#define IXGBE_FDIRCTRL_PERFECT_MATCH            0x00000010
-#define IXGBE_FDIRCTRL_REPORT_STATUS            0x00000020
-#define IXGBE_FDIRCTRL_REPORT_STATUS_ALWAYS     0x00000080
-#define IXGBE_FDIRCTRL_DROP_Q_SHIFT             8
-#define IXGBE_FDIRCTRL_FLEX_SHIFT               16
-#define IXGBE_FDIRCTRL_SEARCHLIM                0x00800000
-#define IXGBE_FDIRCTRL_MAX_LENGTH_SHIFT         24
-#define IXGBE_FDIRCTRL_FULL_THRESH_MASK         0xF0000000
-#define IXGBE_FDIRCTRL_FULL_THRESH_SHIFT        28
-
-#define IXGBE_FDIRTCPM_DPORTM_SHIFT             16
-#define IXGBE_FDIRUDPM_DPORTM_SHIFT             16
-#define IXGBE_FDIRIP6M_DIPM_SHIFT               16
-#define IXGBE_FDIRM_VLANID                      0x00000001
-#define IXGBE_FDIRM_VLANP                       0x00000002
-#define IXGBE_FDIRM_POOL                        0x00000004
-#define IXGBE_FDIRM_L4P                         0x00000008
-#define IXGBE_FDIRM_FLEX                        0x00000010
-#define IXGBE_FDIRM_DIPv6                       0x00000020
-
-#define IXGBE_FDIRFREE_FREE_MASK                0xFFFF
-#define IXGBE_FDIRFREE_FREE_SHIFT               0
-#define IXGBE_FDIRFREE_COLL_MASK                0x7FFF0000
-#define IXGBE_FDIRFREE_COLL_SHIFT               16
-#define IXGBE_FDIRLEN_MAXLEN_MASK               0x3F
-#define IXGBE_FDIRLEN_MAXLEN_SHIFT              0
-#define IXGBE_FDIRLEN_MAXHASH_MASK              0x7FFF0000
-#define IXGBE_FDIRLEN_MAXHASH_SHIFT             16
-#define IXGBE_FDIRUSTAT_ADD_MASK                0xFFFF
-#define IXGBE_FDIRUSTAT_ADD_SHIFT               0
-#define IXGBE_FDIRUSTAT_REMOVE_MASK             0xFFFF0000
-#define IXGBE_FDIRUSTAT_REMOVE_SHIFT            16
-#define IXGBE_FDIRFSTAT_FADD_MASK               0x00FF
-#define IXGBE_FDIRFSTAT_FADD_SHIFT              0
-#define IXGBE_FDIRFSTAT_FREMOVE_MASK            0xFF00
-#define IXGBE_FDIRFSTAT_FREMOVE_SHIFT           8
-#define IXGBE_FDIRPORT_DESTINATION_SHIFT        16
-#define IXGBE_FDIRVLAN_FLEX_SHIFT               16
-#define IXGBE_FDIRHASH_BUCKET_VALID_SHIFT       15
-#define IXGBE_FDIRHASH_SIG_SW_INDEX_SHIFT       16
-
-#define IXGBE_FDIRCMD_CMD_MASK                  0x00000003
-#define IXGBE_FDIRCMD_CMD_ADD_FLOW              0x00000001
-#define IXGBE_FDIRCMD_CMD_REMOVE_FLOW           0x00000002
-#define IXGBE_FDIRCMD_CMD_QUERY_REM_FILT        0x00000003
-#define IXGBE_FDIRCMD_FILTER_VALID              0x00000004
-#define IXGBE_FDIRCMD_FILTER_UPDATE             0x00000008
-#define IXGBE_FDIRCMD_IPv6DMATCH                0x00000010
-#define IXGBE_FDIRCMD_L4TYPE_UDP                0x00000020
-#define IXGBE_FDIRCMD_L4TYPE_TCP                0x00000040
-#define IXGBE_FDIRCMD_L4TYPE_SCTP               0x00000060
-#define IXGBE_FDIRCMD_IPV6                      0x00000080
-#define IXGBE_FDIRCMD_CLEARHT                   0x00000100
-#define IXGBE_FDIRCMD_DROP                      0x00000200
-#define IXGBE_FDIRCMD_INT                       0x00000400
-#define IXGBE_FDIRCMD_LAST                      0x00000800
-#define IXGBE_FDIRCMD_COLLISION                 0x00001000
-#define IXGBE_FDIRCMD_QUEUE_EN                  0x00008000
-#define IXGBE_FDIRCMD_FLOW_TYPE_SHIFT           5
-#define IXGBE_FDIRCMD_RX_QUEUE_SHIFT            16
-#define IXGBE_FDIRCMD_RX_TUNNEL_FILTER_SHIFT	23
-#define IXGBE_FDIRCMD_VT_POOL_SHIFT             24
-#define IXGBE_FDIR_INIT_DONE_POLL               10
-#define IXGBE_FDIRCMD_CMD_POLL                  10
+#define IXGBE_FDIRCTRL_PBALLOC_64K		0x00000001
+#define IXGBE_FDIRCTRL_PBALLOC_128K		0x00000002
+#define IXGBE_FDIRCTRL_PBALLOC_256K		0x00000003
+#define IXGBE_FDIRCTRL_INIT_DONE		0x00000008
+#define IXGBE_FDIRCTRL_PERFECT_MATCH		0x00000010
+#define IXGBE_FDIRCTRL_REPORT_STATUS		0x00000020
+#define IXGBE_FDIRCTRL_REPORT_STATUS_ALWAYS	0x00000080
+#define IXGBE_FDIRCTRL_DROP_Q_SHIFT		8
+#define IXGBE_FDIRCTRL_DROP_Q_MASK		0x00007F00
+#define IXGBE_FDIRCTRL_FLEX_SHIFT		16
+#define IXGBE_FDIRCTRL_DROP_NO_MATCH		0x00008000
+#define IXGBE_FDIRCTRL_FILTERMODE_SHIFT		21
+#define IXGBE_FDIRCTRL_FILTERMODE_MACVLAN	0x0001 /* bit 23:21, 001b */
+#define IXGBE_FDIRCTRL_FILTERMODE_CLOUD		0x0002 /* bit 23:21, 010b */
+#define IXGBE_FDIRCTRL_SEARCHLIM		0x00800000
+#define IXGBE_FDIRCTRL_FILTERMODE_MASK		0x00E00000
+#define IXGBE_FDIRCTRL_MAX_LENGTH_SHIFT		24
+#define IXGBE_FDIRCTRL_FULL_THRESH_MASK		0xF0000000
+#define IXGBE_FDIRCTRL_FULL_THRESH_SHIFT	28
+
+#define IXGBE_FDIRTCPM_DPORTM_SHIFT		16
+#define IXGBE_FDIRUDPM_DPORTM_SHIFT		16
+#define IXGBE_FDIRIP6M_DIPM_SHIFT		16
+#define IXGBE_FDIRM_VLANID			0x00000001
+#define IXGBE_FDIRM_VLANP			0x00000002
+#define IXGBE_FDIRM_POOL			0x00000004
+#define IXGBE_FDIRM_L4P				0x00000008
+#define IXGBE_FDIRM_FLEX			0x00000010
+#define IXGBE_FDIRM_DIPv6			0x00000020
+#define IXGBE_FDIRM_L3P				0x00000040
+
+#define IXGBE_FDIRIP6M_INNER_MAC	0x03F0 /* bit 9:4 */
+#define IXGBE_FDIRIP6M_TUNNEL_TYPE	0x0800 /* bit 11 */
+#define IXGBE_FDIRIP6M_TNI_VNI		0xF000 /* bit 15:12 */
+#define IXGBE_FDIRIP6M_TNI_VNI_24	0x1000 /* bit 12 */
+#define IXGBE_FDIRIP6M_ALWAYS_MASK	0x040F /* bit 10, 3:0 */
+
+#define IXGBE_FDIRFREE_FREE_MASK		0xFFFF
+#define IXGBE_FDIRFREE_FREE_SHIFT		0
+#define IXGBE_FDIRFREE_COLL_MASK		0x7FFF0000
+#define IXGBE_FDIRFREE_COLL_SHIFT		16
+#define IXGBE_FDIRLEN_MAXLEN_MASK		0x3F
+#define IXGBE_FDIRLEN_MAXLEN_SHIFT		0
+#define IXGBE_FDIRLEN_MAXHASH_MASK		0x7FFF0000
+#define IXGBE_FDIRLEN_MAXHASH_SHIFT		16
+#define IXGBE_FDIRUSTAT_ADD_MASK		0xFFFF
+#define IXGBE_FDIRUSTAT_ADD_SHIFT		0
+#define IXGBE_FDIRUSTAT_REMOVE_MASK		0xFFFF0000
+#define IXGBE_FDIRUSTAT_REMOVE_SHIFT		16
+#define IXGBE_FDIRFSTAT_FADD_MASK		0x00FF
+#define IXGBE_FDIRFSTAT_FADD_SHIFT		0
+#define IXGBE_FDIRFSTAT_FREMOVE_MASK		0xFF00
+#define IXGBE_FDIRFSTAT_FREMOVE_SHIFT		8
+#define IXGBE_FDIRPORT_DESTINATION_SHIFT	16
+#define IXGBE_FDIRVLAN_FLEX_SHIFT		16
+#define IXGBE_FDIRHASH_BUCKET_VALID_SHIFT	15
+#define IXGBE_FDIRHASH_SIG_SW_INDEX_SHIFT	16
+
+#define IXGBE_FDIRCMD_CMD_MASK			0x00000003
+#define IXGBE_FDIRCMD_CMD_ADD_FLOW		0x00000001
+#define IXGBE_FDIRCMD_CMD_REMOVE_FLOW		0x00000002
+#define IXGBE_FDIRCMD_CMD_QUERY_REM_FILT	0x00000003
+#define IXGBE_FDIRCMD_FILTER_VALID		0x00000004
+#define IXGBE_FDIRCMD_FILTER_UPDATE		0x00000008
+#define IXGBE_FDIRCMD_IPv6DMATCH		0x00000010
+#define IXGBE_FDIRCMD_L4TYPE_UDP		0x00000020
+#define IXGBE_FDIRCMD_L4TYPE_TCP		0x00000040
+#define IXGBE_FDIRCMD_L4TYPE_SCTP		0x00000060
+#define IXGBE_FDIRCMD_IPV6			0x00000080
+#define IXGBE_FDIRCMD_CLEARHT			0x00000100
+#define IXGBE_FDIRCMD_DROP			0x00000200
+#define IXGBE_FDIRCMD_INT			0x00000400
+#define IXGBE_FDIRCMD_LAST			0x00000800
+#define IXGBE_FDIRCMD_COLLISION			0x00001000
+#define IXGBE_FDIRCMD_QUEUE_EN			0x00008000
+#define IXGBE_FDIRCMD_FLOW_TYPE_SHIFT		5
+#define IXGBE_FDIRCMD_RX_QUEUE_SHIFT		16
+#define IXGBE_FDIRCMD_TUNNEL_FILTER_SHIFT	23
+#define IXGBE_FDIRCMD_VT_POOL_SHIFT		24
+#define IXGBE_FDIR_INIT_DONE_POLL		10
+#define IXGBE_FDIRCMD_CMD_POLL			10
 #define IXGBE_FDIRCMD_TUNNEL_FILTER		0x00800000
-
-#define IXGBE_FDIR_DROP_QUEUE                   127
+#define IXGBE_FDIR_DROP_QUEUE			127
 
 /* Manageablility Host Interface defines */
 #define IXGBE_HI_MAX_BLOCK_BYTE_LENGTH	1792 /* Num of bytes in range */
@@ -2588,15 +3040,17 @@ enum ixgbe_fdir_pballoc_type {
 #define IXGBE_HI_FLASH_ERASE_TIMEOUT	1000 /* Process Erase command limit */
 #define IXGBE_HI_FLASH_UPDATE_TIMEOUT	5000 /* Process Update command limit */
 #define IXGBE_HI_FLASH_APPLY_TIMEOUT	0 /* Process Apply command limit */
+#define IXGBE_HI_PHY_MGMT_REQ_TIMEOUT	2000 /* Wait up to 2 seconds */
 
 /* CEM Support */
 #define FW_CEM_HDR_LEN			0x4
 #define FW_CEM_CMD_DRIVER_INFO		0xDD
 #define FW_CEM_CMD_DRIVER_INFO_LEN	0x5
-#define FW_CEM_CMD_RESERVED		0x0
+#define FW_CEM_CMD_RESERVED		0X0
 #define FW_CEM_UNUSED_VER		0x0
 #define FW_CEM_MAX_RETRIES		3
 #define FW_CEM_RESP_STATUS_SUCCESS	0x1
+#define FW_CEM_DRIVER_VERSION_SIZE	39 /* +9 would send 48 bytes to fw */
 #define FW_READ_SHADOW_RAM_CMD		0x31
 #define FW_READ_SHADOW_RAM_LEN		0x6
 #define FW_WRITE_SHADOW_RAM_CMD		0x33
@@ -2608,8 +3062,78 @@ enum ixgbe_fdir_pballoc_type {
 #define FW_MAX_READ_BUFFER_SIZE		1024
 #define FW_DISABLE_RXEN_CMD		0xDE
 #define FW_DISABLE_RXEN_LEN		0x1
+#define FW_PHY_MGMT_REQ_CMD		0x20
+#define FW_PHY_TOKEN_REQ_CMD		0xA
+#define FW_PHY_TOKEN_REQ_LEN		2
+#define FW_PHY_TOKEN_REQ		0
+#define FW_PHY_TOKEN_REL		1
+#define FW_PHY_TOKEN_OK			1
+#define FW_PHY_TOKEN_RETRY		0x80
+#define FW_PHY_TOKEN_DELAY		5	/* milliseconds */
+#define FW_PHY_TOKEN_WAIT		5	/* seconds */
+#define FW_PHY_TOKEN_RETRIES ((FW_PHY_TOKEN_WAIT * 1000) / FW_PHY_TOKEN_DELAY)
+#define FW_INT_PHY_REQ_CMD		0xB
+#define FW_INT_PHY_REQ_LEN		10
+#define FW_INT_PHY_REQ_READ		0
+#define FW_INT_PHY_REQ_WRITE		1
+#define FW_PHY_ACT_REQ_CMD		5
+#define FW_PHY_ACT_DATA_COUNT		4
+#define FW_PHY_ACT_REQ_LEN		(4 + 4 * FW_PHY_ACT_DATA_COUNT)
+#define FW_PHY_ACT_INIT_PHY		1
+#define FW_PHY_ACT_SETUP_LINK		2
+#define FW_PHY_ACT_LINK_SPEED_10	(1u << 0)
+#define FW_PHY_ACT_LINK_SPEED_100	(1u << 1)
+#define FW_PHY_ACT_LINK_SPEED_1G	(1u << 2)
+#define FW_PHY_ACT_LINK_SPEED_2_5G	(1u << 3)
+#define FW_PHY_ACT_LINK_SPEED_5G	(1u << 4)
+#define FW_PHY_ACT_LINK_SPEED_10G	(1u << 5)
+#define FW_PHY_ACT_LINK_SPEED_20G	(1u << 6)
+#define FW_PHY_ACT_LINK_SPEED_25G	(1u << 7)
+#define FW_PHY_ACT_LINK_SPEED_40G	(1u << 8)
+#define FW_PHY_ACT_LINK_SPEED_50G	(1u << 9)
+#define FW_PHY_ACT_LINK_SPEED_100G	(1u << 10)
+#define FW_PHY_ACT_SETUP_LINK_PAUSE_SHIFT 16
+#define FW_PHY_ACT_SETUP_LINK_PAUSE_MASK (3u << \
+					  FW_PHY_ACT_SETUP_LINK_PAUSE_SHIFT)
+#define FW_PHY_ACT_SETUP_LINK_PAUSE_NONE 0u
+#define FW_PHY_ACT_SETUP_LINK_PAUSE_TX	1u
+#define FW_PHY_ACT_SETUP_LINK_PAUSE_RX	2u
+#define FW_PHY_ACT_SETUP_LINK_PAUSE_RXTX 3u
+#define FW_PHY_ACT_SETUP_LINK_LP	(1u << 18)
+#define FW_PHY_ACT_SETUP_LINK_HP	(1u << 19)
+#define FW_PHY_ACT_SETUP_LINK_EEE	(1u << 20)
+#define FW_PHY_ACT_SETUP_LINK_AN	(1u << 22)
+#define FW_PHY_ACT_SETUP_LINK_RSP_DOWN	(1u << 0)
+#define FW_PHY_ACT_GET_LINK_INFO	3
+#define FW_PHY_ACT_GET_LINK_INFO_EEE	(1u << 19)
+#define FW_PHY_ACT_GET_LINK_INFO_FC_TX	(1u << 20)
+#define FW_PHY_ACT_GET_LINK_INFO_FC_RX	(1u << 21)
+#define FW_PHY_ACT_GET_LINK_INFO_POWER	(1u << 22)
+#define FW_PHY_ACT_GET_LINK_INFO_AN_COMPLETE	(1u << 24)
+#define FW_PHY_ACT_GET_LINK_INFO_TEMP	(1u << 25)
+#define FW_PHY_ACT_GET_LINK_INFO_LP_FC_TX	(1u << 28)
+#define FW_PHY_ACT_GET_LINK_INFO_LP_FC_RX	(1u << 29)
+#define FW_PHY_ACT_FORCE_LINK_DOWN	4
+#define FW_PHY_ACT_FORCE_LINK_DOWN_OFF	(1u << 0)
+#define FW_PHY_ACT_PHY_SW_RESET		5
+#define FW_PHY_ACT_PHY_HW_RESET		6
+#define FW_PHY_ACT_GET_PHY_INFO		7
+#define FW_PHY_ACT_UD_2			0x1002
+#define FW_PHY_ACT_UD_2_10G_KR_EEE	(1u << 6)
+#define FW_PHY_ACT_UD_2_10G_KX4_EEE	(1u << 5)
+#define FW_PHY_ACT_UD_2_1G_KX_EEE	(1u << 4)
+#define FW_PHY_ACT_UD_2_10G_T_EEE	(1u << 3)
+#define FW_PHY_ACT_UD_2_1G_T_EEE	(1u << 2)
+#define FW_PHY_ACT_UD_2_100M_TX_EEE	(1u << 1)
+#define FW_PHY_ACT_RETRIES		50
+#define FW_PHY_INFO_SPEED_MASK		0xFFFu
+#define FW_PHY_INFO_ID_HI_MASK		0xFFFF0000u
+#define FW_PHY_INFO_ID_LO_MASK		0x0000FFFFu
 
 /* Host Interface Command Structures */
+
+#pragma pack(push, 1)
+
 struct ixgbe_hic_hdr {
 	u8 cmd;
 	u8 buf_len;
@@ -2630,7 +3154,7 @@ struct ixgbe_hic_hdr2_req {
 struct ixgbe_hic_hdr2_rsp {
 	u8 cmd;
 	u8 buf_lenl;
-	u8 buf_lenh_status;     /* 7-5: high bits of buf_len, 4-0: status */
+	u8 buf_lenh_status;	/* 7-5: high bits of buf_len, 4-0: status */
 	u8 checksum;
 };
 
@@ -2650,6 +3174,16 @@ struct ixgbe_hic_drv_info {
 	u16 pad2; /* end spacing to ensure length is mult. of dword2 */
 };
 
+struct ixgbe_hic_drv_info2 {
+	struct ixgbe_hic_hdr hdr;
+	u8 port_num;
+	u8 ver_sub;
+	u8 ver_build;
+	u8 ver_min;
+	u8 ver_maj;
+	char driver_string[FW_CEM_DRIVER_VERSION_SIZE];
+};
+
 /* These need to be dword aligned */
 struct ixgbe_hic_read_shadow_ram {
 	union ixgbe_hic_hdr2 hdr;
@@ -2662,8 +3196,8 @@ struct ixgbe_hic_read_shadow_ram {
 
 struct ixgbe_hic_write_shadow_ram {
 	union ixgbe_hic_hdr2 hdr;
-	__be32 address;
-	__be16 length;
+	u32 address;
+	u16 length;
 	u16 pad2;
 	u16 data;
 	u16 pad3;
@@ -2676,20 +3210,88 @@ struct ixgbe_hic_disable_rxen {
 	u16 pad3;
 };
 
+struct ixgbe_hic_phy_token_req {
+	struct ixgbe_hic_hdr hdr;
+	u8 port_number;
+	u8 command_type;
+	u16 pad;
+};
+
+struct ixgbe_hic_internal_phy_req {
+	struct ixgbe_hic_hdr hdr;
+	u8 port_number;
+	u8 command_type;
+	__be16 address;
+	u16 rsv1;
+	__be32 write_data;
+	u16 pad;
+};
+
+struct ixgbe_hic_internal_phy_resp {
+	struct ixgbe_hic_hdr hdr;
+	__be32 read_data;
+};
+
+struct ixgbe_hic_phy_activity_req {
+	struct ixgbe_hic_hdr hdr;
+	u8 port_number;
+	u8 pad;
+	__le16 activity_id;
+	__be32 data[FW_PHY_ACT_DATA_COUNT];
+};
+
+struct ixgbe_hic_phy_activity_resp {
+	struct ixgbe_hic_hdr hdr;
+	__be32 data[FW_PHY_ACT_DATA_COUNT];
+};
+
+#pragma pack(pop)
+
+/* Transmit Descriptor - Legacy */
+struct ixgbe_legacy_tx_desc {
+	u64 buffer_addr; /* Address of the descriptor's data buffer */
+	union {
+		__le32 data;
+		struct {
+			__le16 length; /* Data buffer length */
+			u8 cso; /* Checksum offset */
+			u8 cmd; /* Descriptor control */
+		} flags;
+	} lower;
+	union {
+		__le32 data;
+		struct {
+			u8 status; /* Descriptor status */
+			u8 css; /* Checksum start */
+			__le16 vlan;
+		} fields;
+	} upper;
+};
+
 /* Transmit Descriptor - Advanced */
 union ixgbe_adv_tx_desc {
 	struct {
-		__le64 buffer_addr;      /* Address of descriptor's data buf */
+		__le64 buffer_addr; /* Address of descriptor's data buf */
 		__le32 cmd_type_len;
 		__le32 olinfo_status;
 	} read;
 	struct {
-		__le64 rsvd;       /* Reserved */
+		__le64 rsvd; /* Reserved */
 		__le32 nxtseq_seed;
 		__le32 status;
 	} wb;
 };
 
+/* Receive Descriptor - Legacy */
+struct ixgbe_legacy_rx_desc {
+	__le64 buffer_addr; /* Address of the descriptor's data buffer */
+	__le16 length; /* Length of data DMAed into data buffer */
+	__le16 csum; /* Packet checksum */
+	u8 status;   /* Descriptor status */
+	u8 errors;   /* Descriptor Errors */
+	__le16 vlan;
+};
+
 /* Receive Descriptor - Advanced */
 union ixgbe_adv_rx_desc {
 	struct {
@@ -2730,84 +3332,115 @@ struct ixgbe_adv_tx_context_desc {
 };
 
 /* Adv Transmit Descriptor Config Masks */
-#define IXGBE_ADVTXD_DTALEN_MASK      0x0000FFFF /* Data buf length(bytes) */
-#define IXGBE_ADVTXD_MAC_LINKSEC      0x00040000 /* Insert LinkSec */
-#define IXGBE_ADVTXD_MAC_TSTAMP	      0x00080000 /* IEEE 1588 Time Stamp */
-#define IXGBE_ADVTXD_IPSEC_SA_INDEX_MASK   0x000003FF /* IPSec SA index */
-#define IXGBE_ADVTXD_IPSEC_ESP_LEN_MASK    0x000001FF /* IPSec ESP length */
-#define IXGBE_ADVTXD_DTYP_MASK  0x00F00000 /* DTYP mask */
-#define IXGBE_ADVTXD_DTYP_CTXT  0x00200000 /* Advanced Context Desc */
-#define IXGBE_ADVTXD_DTYP_DATA  0x00300000 /* Advanced Data Descriptor */
-#define IXGBE_ADVTXD_DCMD_EOP   IXGBE_TXD_CMD_EOP  /* End of Packet */
-#define IXGBE_ADVTXD_DCMD_IFCS  IXGBE_TXD_CMD_IFCS /* Insert FCS */
-#define IXGBE_ADVTXD_DCMD_RS    IXGBE_TXD_CMD_RS   /* Report Status */
-#define IXGBE_ADVTXD_DCMD_DDTYP_ISCSI 0x10000000    /* DDP hdr type or iSCSI */
-#define IXGBE_ADVTXD_DCMD_DEXT  IXGBE_TXD_CMD_DEXT /* Desc ext (1=Adv) */
-#define IXGBE_ADVTXD_DCMD_VLE   IXGBE_TXD_CMD_VLE  /* VLAN pkt enable */
-#define IXGBE_ADVTXD_DCMD_TSE   0x80000000 /* TCP Seg enable */
-#define IXGBE_ADVTXD_STAT_DD    IXGBE_TXD_STAT_DD  /* Descriptor Done */
-#define IXGBE_ADVTXD_STAT_SN_CRC      0x00000002 /* NXTSEQ/SEED pres in WB */
-#define IXGBE_ADVTXD_STAT_RSV   0x0000000C /* STA Reserved */
-#define IXGBE_ADVTXD_IDX_SHIFT  4 /* Adv desc Index shift */
-#define IXGBE_ADVTXD_CC         0x00000080 /* Check Context */
-#define IXGBE_ADVTXD_POPTS_SHIFT      8  /* Adv desc POPTS shift */
-#define IXGBE_ADVTXD_POPTS_IXSM (IXGBE_TXD_POPTS_IXSM << \
-				 IXGBE_ADVTXD_POPTS_SHIFT)
-#define IXGBE_ADVTXD_POPTS_TXSM (IXGBE_TXD_POPTS_TXSM << \
-				 IXGBE_ADVTXD_POPTS_SHIFT)
-#define IXGBE_ADVTXD_POPTS_ISCO_1ST  0x00000000 /* 1st TSO of iSCSI PDU */
-#define IXGBE_ADVTXD_POPTS_ISCO_MDL  0x00000800 /* Middle TSO of iSCSI PDU */
-#define IXGBE_ADVTXD_POPTS_ISCO_LAST 0x00001000 /* Last TSO of iSCSI PDU */
-#define IXGBE_ADVTXD_POPTS_ISCO_FULL 0x00001800 /* 1st&Last TSO-full iSCSI PDU */
-#define IXGBE_ADVTXD_POPTS_RSV       0x00002000 /* POPTS Reserved */
-#define IXGBE_ADVTXD_PAYLEN_SHIFT    14 /* Adv desc PAYLEN shift */
-#define IXGBE_ADVTXD_MACLEN_SHIFT    9  /* Adv ctxt desc mac len shift */
-#define IXGBE_ADVTXD_VLAN_SHIFT      16  /* Adv ctxt vlan tag shift */
-#define IXGBE_ADVTXD_TUCMD_IPV4      0x00000400  /* IP Packet Type: 1=IPv4 */
-#define IXGBE_ADVTXD_TUCMD_IPV6      0x00000000  /* IP Packet Type: 0=IPv6 */
-#define IXGBE_ADVTXD_TUCMD_L4T_UDP   0x00000000  /* L4 Packet TYPE of UDP */
-#define IXGBE_ADVTXD_TUCMD_L4T_TCP   0x00000800  /* L4 Packet TYPE of TCP */
-#define IXGBE_ADVTXD_TUCMD_L4T_SCTP  0x00001000  /* L4 Packet TYPE of SCTP */
-#define IXGBE_ADVTXD_TUCMD_MKRREQ    0x00002000 /*Req requires Markers and CRC*/
-#define IXGBE_ADVTXD_POPTS_IPSEC      0x00000400 /* IPSec offload request */
+#define IXGBE_ADVTXD_DTALEN_MASK	0x0000FFFF /* Data buf length(bytes) */
+#define IXGBE_ADVTXD_MAC_LINKSEC	0x00040000 /* Insert LinkSec */
+#define IXGBE_ADVTXD_MAC_TSTAMP		0x00080000 /* IEEE1588 time stamp */
+#define IXGBE_ADVTXD_IPSEC_SA_INDEX_MASK 0x000003FF /* IPSec SA index */
+#define IXGBE_ADVTXD_IPSEC_ESP_LEN_MASK	0x000001FF /* IPSec ESP length */
+#define IXGBE_ADVTXD_DTYP_MASK		0x00F00000 /* DTYP mask */
+#define IXGBE_ADVTXD_DTYP_CTXT		0x00200000 /* Adv Context Desc */
+#define IXGBE_ADVTXD_DTYP_DATA		0x00300000 /* Adv Data Descriptor */
+#define IXGBE_ADVTXD_DCMD_EOP		IXGBE_TXD_CMD_EOP  /* End of Packet */
+#define IXGBE_ADVTXD_DCMD_IFCS		IXGBE_TXD_CMD_IFCS /* Insert FCS */
+#define IXGBE_ADVTXD_DCMD_RS		IXGBE_TXD_CMD_RS /* Report Status */
+#define IXGBE_ADVTXD_DCMD_DDTYP_ISCSI	0x10000000 /* DDP hdr type or iSCSI */
+#define IXGBE_ADVTXD_DCMD_DEXT		IXGBE_TXD_CMD_DEXT /* Desc ext 1=Adv */
+#define IXGBE_ADVTXD_DCMD_VLE		IXGBE_TXD_CMD_VLE  /* VLAN pkt enable */
+#define IXGBE_ADVTXD_DCMD_TSE		0x80000000 /* TCP Seg enable */
+#define IXGBE_ADVTXD_STAT_DD		IXGBE_TXD_STAT_DD  /* Descriptor Done */
+#define IXGBE_ADVTXD_STAT_SN_CRC	0x00000002 /* NXTSEQ/SEED pres in WB */
+#define IXGBE_ADVTXD_STAT_RSV		0x0000000C /* STA Reserved */
+#define IXGBE_ADVTXD_IDX_SHIFT		4 /* Adv desc Index shift */
+#define IXGBE_ADVTXD_CC			0x00000080 /* Check Context */
+#define IXGBE_ADVTXD_POPTS_SHIFT	8  /* Adv desc POPTS shift */
+#define IXGBE_ADVTXD_POPTS_IXSM		(IXGBE_TXD_POPTS_IXSM << \
+					 IXGBE_ADVTXD_POPTS_SHIFT)
+#define IXGBE_ADVTXD_POPTS_TXSM		(IXGBE_TXD_POPTS_TXSM << \
+					 IXGBE_ADVTXD_POPTS_SHIFT)
+#define IXGBE_ADVTXD_POPTS_ISCO_1ST	0x00000000 /* 1st TSO of iSCSI PDU */
+#define IXGBE_ADVTXD_POPTS_ISCO_MDL	0x00000800 /* Middle TSO of iSCSI PDU */
+#define IXGBE_ADVTXD_POPTS_ISCO_LAST	0x00001000 /* Last TSO of iSCSI PDU */
+/* 1st&Last TSO-full iSCSI PDU */
+#define IXGBE_ADVTXD_POPTS_ISCO_FULL	0x00001800
+#define IXGBE_ADVTXD_POPTS_RSV		0x00002000 /* POPTS Reserved */
+#define IXGBE_ADVTXD_PAYLEN_SHIFT	14 /* Adv desc PAYLEN shift */
+#define IXGBE_ADVTXD_MACLEN_SHIFT	9  /* Adv ctxt desc mac len shift */
+#define IXGBE_ADVTXD_VLAN_SHIFT		16  /* Adv ctxt vlan tag shift */
+#define IXGBE_ADVTXD_TUCMD_IPV4		0x00000400 /* IP Packet Type: 1=IPv4 */
+#define IXGBE_ADVTXD_TUCMD_IPV6		0x00000000 /* IP Packet Type: 0=IPv6 */
+#define IXGBE_ADVTXD_TUCMD_L4T_UDP	0x00000000 /* L4 Packet TYPE of UDP */
+#define IXGBE_ADVTXD_TUCMD_L4T_TCP	0x00000800 /* L4 Packet TYPE of TCP */
+#define IXGBE_ADVTXD_TUCMD_L4T_SCTP	0x00001000 /* L4 Packet TYPE of SCTP */
+#define IXGBE_ADVTXD_TUCMD_L4T_RSV	0x00001800 /* RSV L4 Packet TYPE */
+#define IXGBE_ADVTXD_TUCMD_MKRREQ	0x00002000 /* req Markers and CRC */
+#define IXGBE_ADVTXD_POPTS_IPSEC	0x00000400 /* IPSec offload request */
 #define IXGBE_ADVTXD_TUCMD_IPSEC_TYPE_ESP 0x00002000 /* IPSec Type ESP */
 #define IXGBE_ADVTXD_TUCMD_IPSEC_ENCRYPT_EN 0x00004000/* ESP Encrypt Enable */
-#define IXGBE_ADVTXT_TUCMD_FCOE      0x00008000       /* FCoE Frame Type */
-#define IXGBE_ADVTXD_FCOEF_EOF_MASK  (0x3 << 10)      /* FC EOF index */
-#define IXGBE_ADVTXD_FCOEF_SOF       ((1 << 2) << 10) /* FC SOF index */
-#define IXGBE_ADVTXD_FCOEF_PARINC    ((1 << 3) << 10) /* Rel_Off in F_CTL */
-#define IXGBE_ADVTXD_FCOEF_ORIE      ((1 << 4) << 10) /* Orientation: End */
-#define IXGBE_ADVTXD_FCOEF_ORIS      ((1 << 5) << 10) /* Orientation: Start */
-#define IXGBE_ADVTXD_FCOEF_EOF_N     (0x0 << 10)      /* 00: EOFn */
-#define IXGBE_ADVTXD_FCOEF_EOF_T     (0x1 << 10)      /* 01: EOFt */
-#define IXGBE_ADVTXD_FCOEF_EOF_NI    (0x2 << 10)      /* 10: EOFni */
-#define IXGBE_ADVTXD_FCOEF_EOF_A     (0x3 << 10)      /* 11: EOFa */
-#define IXGBE_ADVTXD_L4LEN_SHIFT     8  /* Adv ctxt L4LEN shift */
-#define IXGBE_ADVTXD_MSS_SHIFT       16  /* Adv ctxt MSS shift */
-
+#define IXGBE_ADVTXT_TUCMD_FCOE		0x00008000 /* FCoE Frame Type */
+#define IXGBE_ADVTXD_FCOEF_EOF_MASK	(0x3 << 10) /* FC EOF index */
+#define IXGBE_ADVTXD_FCOEF_SOF		((1 << 2) << 10) /* FC SOF index */
+#define IXGBE_ADVTXD_FCOEF_PARINC	((1 << 3) << 10) /* Rel_Off in F_CTL */
+#define IXGBE_ADVTXD_FCOEF_ORIE		((1 << 4) << 10) /* Orientation End */
+#define IXGBE_ADVTXD_FCOEF_ORIS		((1 << 5) << 10) /* Orientation Start */
+#define IXGBE_ADVTXD_FCOEF_EOF_N	(0x0 << 10) /* 00: EOFn */
+#define IXGBE_ADVTXD_FCOEF_EOF_T	(0x1 << 10) /* 01: EOFt */
+#define IXGBE_ADVTXD_FCOEF_EOF_NI	(0x2 << 10) /* 10: EOFni */
+#define IXGBE_ADVTXD_FCOEF_EOF_A	(0x3 << 10) /* 11: EOFa */
+#define IXGBE_ADVTXD_L4LEN_SHIFT	8  /* Adv ctxt L4LEN shift */
+#define IXGBE_ADVTXD_MSS_SHIFT		16  /* Adv ctxt MSS shift */
+
+#define IXGBE_ADVTXD_OUTER_IPLEN	16 /* Adv ctxt OUTERIPLEN shift */
+#define IXGBE_ADVTXD_TUNNEL_LEN 	24 /* Adv ctxt TUNNELLEN shift */
+#define IXGBE_ADVTXD_TUNNEL_TYPE_SHIFT	16 /* Adv Tx Desc Tunnel Type shift */
+#define IXGBE_ADVTXD_OUTERIPCS_SHIFT	17 /* Adv Tx Desc OUTERIPCS Shift */
+#define IXGBE_ADVTXD_TUNNEL_TYPE_NVGRE	1  /* Adv Tx Desc Tunnel Type NVGRE */
+/* Adv Tx Desc OUTERIPCS Shift for X550EM_a */
+#define IXGBE_ADVTXD_OUTERIPCS_SHIFT_X550EM_a	26
 /* Autonegotiation advertised speeds */
 typedef u32 ixgbe_autoneg_advertised;
 /* Link speed */
 typedef u32 ixgbe_link_speed;
 #define IXGBE_LINK_SPEED_UNKNOWN	0
+#define IXGBE_LINK_SPEED_10_FULL	0x0002
 #define IXGBE_LINK_SPEED_100_FULL	0x0008
 #define IXGBE_LINK_SPEED_1GB_FULL	0x0020
 #define IXGBE_LINK_SPEED_2_5GB_FULL	0x0400
 #define IXGBE_LINK_SPEED_5GB_FULL	0x0800
 #define IXGBE_LINK_SPEED_10GB_FULL	0x0080
-#define IXGBE_LINK_SPEED_82598_AUTONEG (IXGBE_LINK_SPEED_1GB_FULL | \
-					IXGBE_LINK_SPEED_10GB_FULL)
-#define IXGBE_LINK_SPEED_82599_AUTONEG (IXGBE_LINK_SPEED_100_FULL | \
-					IXGBE_LINK_SPEED_1GB_FULL | \
-					IXGBE_LINK_SPEED_10GB_FULL)
+#define IXGBE_LINK_SPEED_82598_AUTONEG	(IXGBE_LINK_SPEED_1GB_FULL | \
+					 IXGBE_LINK_SPEED_10GB_FULL)
+#define IXGBE_LINK_SPEED_82599_AUTONEG	(IXGBE_LINK_SPEED_100_FULL | \
+					 IXGBE_LINK_SPEED_1GB_FULL | \
+					 IXGBE_LINK_SPEED_10GB_FULL)
+
+/* Physical layer type */
+typedef u64 ixgbe_physical_layer;
+#define IXGBE_PHYSICAL_LAYER_UNKNOWN		0
+#define IXGBE_PHYSICAL_LAYER_10GBASE_T		0x00001
+#define IXGBE_PHYSICAL_LAYER_1000BASE_T		0x00002
+#define IXGBE_PHYSICAL_LAYER_100BASE_TX		0x00004
+#define IXGBE_PHYSICAL_LAYER_SFP_PLUS_CU	0x00008
+#define IXGBE_PHYSICAL_LAYER_10GBASE_LR		0x00010
+#define IXGBE_PHYSICAL_LAYER_10GBASE_LRM	0x00020
+#define IXGBE_PHYSICAL_LAYER_10GBASE_SR		0x00040
+#define IXGBE_PHYSICAL_LAYER_10GBASE_KX4	0x00080
+#define IXGBE_PHYSICAL_LAYER_10GBASE_CX4	0x00100
+#define IXGBE_PHYSICAL_LAYER_1000BASE_KX	0x00200
+#define IXGBE_PHYSICAL_LAYER_1000BASE_BX	0x00400
+#define IXGBE_PHYSICAL_LAYER_10GBASE_KR		0x00800
+#define IXGBE_PHYSICAL_LAYER_10GBASE_XAUI	0x01000
+#define IXGBE_PHYSICAL_LAYER_SFP_ACTIVE_DA	0x02000
+#define IXGBE_PHYSICAL_LAYER_1000BASE_SX	0x04000
+#define IXGBE_PHYSICAL_LAYER_10BASE_T		0x08000
+#define IXGBE_PHYSICAL_LAYER_2500BASE_KX	0x10000
 
 /* Flow Control Data Sheet defined values
  * Calculation and defines taken from 802.1bb Annex O
  */
 
 /* BitTimes (BT) conversion */
-#define IXGBE_BT2KB(BT) ((BT + (8 * 1024 - 1)) / (8 * 1024))
-#define IXGBE_B2BT(BT) (BT * 8)
+#define IXGBE_BT2KB(BT)		((BT + (8 * 1024 - 1)) / (8 * 1024))
+#define IXGBE_B2BT(BT)		(BT * 8)
 
 /* Calculate Delay to respond to PFC */
 #define IXGBE_PFC_D	672
@@ -2817,8 +3450,8 @@ typedef u32 ixgbe_link_speed;
 #define IXGBE_CABLE_DO	5000 /* Delay Optical */
 
 /* Calculate Interface Delay X540 */
-#define IXGBE_PHY_DC	25600	/* Delay 10G BASET */
-#define IXGBE_MAC_DC	8192	/* Delay Copper XAUI interface */
+#define IXGBE_PHY_DC	25600 /* Delay 10G BASET */
+#define IXGBE_MAC_DC	8192  /* Delay Copper XAUI interface */
 #define IXGBE_XAUI_DC	(2 * 2048) /* Delay Copper Phy */
 
 #define IXGBE_ID_X540	(IXGBE_MAC_DC + IXGBE_XAUI_DC + IXGBE_PHY_DC)
@@ -2864,8 +3497,8 @@ typedef u32 ixgbe_link_speed;
 			(2 * IXGBE_LOW_DV_X540(_max_frame_tc))
 
 /* Software ATR hash keys */
-#define IXGBE_ATR_BUCKET_HASH_KEY    0x3DAD14E2
-#define IXGBE_ATR_SIGNATURE_HASH_KEY 0x174D3614
+#define IXGBE_ATR_BUCKET_HASH_KEY	0x3DAD14E2
+#define IXGBE_ATR_SIGNATURE_HASH_KEY	0x174D3614
 
 /* Software ATR input stream values and masks */
 #define IXGBE_ATR_HASH_MASK		0x7fff
@@ -2876,14 +3509,22 @@ typedef u32 ixgbe_link_speed;
 #define IXGBE_ATR_L4TYPE_IPV6_MASK	0x4
 #define IXGBE_ATR_L4TYPE_TUNNEL_MASK	0x10
 enum ixgbe_atr_flow_type {
-	IXGBE_ATR_FLOW_TYPE_IPV4   = 0x0,
-	IXGBE_ATR_FLOW_TYPE_UDPV4  = 0x1,
-	IXGBE_ATR_FLOW_TYPE_TCPV4  = 0x2,
-	IXGBE_ATR_FLOW_TYPE_SCTPV4 = 0x3,
-	IXGBE_ATR_FLOW_TYPE_IPV6   = 0x4,
-	IXGBE_ATR_FLOW_TYPE_UDPV6  = 0x5,
-	IXGBE_ATR_FLOW_TYPE_TCPV6  = 0x6,
-	IXGBE_ATR_FLOW_TYPE_SCTPV6 = 0x7,
+	IXGBE_ATR_FLOW_TYPE_IPV4	= 0x0,
+	IXGBE_ATR_FLOW_TYPE_UDPV4	= 0x1,
+	IXGBE_ATR_FLOW_TYPE_TCPV4	= 0x2,
+	IXGBE_ATR_FLOW_TYPE_SCTPV4	= 0x3,
+	IXGBE_ATR_FLOW_TYPE_IPV6	= 0x4,
+	IXGBE_ATR_FLOW_TYPE_UDPV6	= 0x5,
+	IXGBE_ATR_FLOW_TYPE_TCPV6	= 0x6,
+	IXGBE_ATR_FLOW_TYPE_SCTPV6	= 0x7,
+	IXGBE_ATR_FLOW_TYPE_TUNNELED_IPV4	= 0x10,
+	IXGBE_ATR_FLOW_TYPE_TUNNELED_UDPV4	= 0x11,
+	IXGBE_ATR_FLOW_TYPE_TUNNELED_TCPV4	= 0x12,
+	IXGBE_ATR_FLOW_TYPE_TUNNELED_SCTPV4	= 0x13,
+	IXGBE_ATR_FLOW_TYPE_TUNNELED_IPV6	= 0x14,
+	IXGBE_ATR_FLOW_TYPE_TUNNELED_UDPV6	= 0x15,
+	IXGBE_ATR_FLOW_TYPE_TUNNELED_TCPV6	= 0x16,
+	IXGBE_ATR_FLOW_TYPE_TUNNELED_SCTPV6	= 0x17,
 };
 
 /* Flow Director ATR input struct. */
@@ -2891,28 +3532,34 @@ union ixgbe_atr_input {
 	/*
 	 * Byte layout in order, all values with MSB first:
 	 *
-	 * vm_pool    - 1 byte
-	 * flow_type  - 1 byte
-	 * vlan_id    - 2 bytes
-	 * src_ip     - 16 bytes
-	 * dst_ip     - 16 bytes
-	 * src_port   - 2 bytes
-	 * dst_port   - 2 bytes
-	 * flex_bytes - 2 bytes
-	 * bkt_hash   - 2 bytes
+	 * vm_pool	- 1 byte
+	 * flow_type	- 1 byte
+	 * vlan_id	- 2 bytes
+	 * src_ip	- 16 bytes
+	 * inner_mac	- 6 bytes
+	 * cloud_mode	- 2 bytes
+	 * tni_vni	- 4 bytes
+	 * dst_ip	- 16 bytes
+	 * src_port	- 2 bytes
+	 * dst_port	- 2 bytes
+	 * flex_bytes	- 2 bytes
+	 * bkt_hash	- 2 bytes
 	 */
 	struct {
-		u8     vm_pool;
-		u8     flow_type;
+		u8 vm_pool;
+		u8 flow_type;
 		__be16 vlan_id;
 		__be32 dst_ip[4];
 		__be32 src_ip[4];
+		u8 inner_mac[6];
+		__be16 tunnel_type;
+		__be32 tni_vni;
 		__be16 src_port;
 		__be16 dst_port;
 		__be16 flex_bytes;
 		__be16 bkt_hash;
 	} formatted;
-	__be32 dword_stream[11];
+	__be32 dword_stream[14];
 };
 
 /* Flow Director compressed ATR hash input struct */
@@ -2931,7 +3578,7 @@ union ixgbe_atr_hash_dword {
 	__be32 dword;
 };
 
-#define IXGBE_MVALS_INIT(m)		\
+#define IXGBE_MVALS_INIT(m)	\
 	IXGBE_CAT(EEC, m),		\
 	IXGBE_CAT(FLA, m),		\
 	IXGBE_CAT(GRC, m),		\
@@ -2958,10 +3605,21 @@ union ixgbe_atr_hash_dword {
 	IXGBE_CAT(I2CCTL, m)
 
 enum ixgbe_mvals {
-	IXGBE_MVALS_INIT(IDX),
+	IXGBE_MVALS_INIT(_IDX),
 	IXGBE_MVALS_IDX_LIMIT
 };
 
+/*
+ * Unavailable: The FCoE Boot Option ROM is not present in the flash.
+ * Disabled: Present; boot order is not set for any targets on the port.
+ * Enabled: Present; boot order is set for at least one target on the port.
+ */
+enum ixgbe_fcoe_boot_status {
+	ixgbe_fcoe_bootstatus_disabled = 0,
+	ixgbe_fcoe_bootstatus_enabled = 1,
+	ixgbe_fcoe_bootstatus_unavailable = 0xFFFF
+};
+
 enum ixgbe_eeprom_type {
 	ixgbe_eeprom_uninitialized = 0,
 	ixgbe_eeprom_spi,
@@ -2976,6 +3634,7 @@ enum ixgbe_mac_type {
 	ixgbe_mac_X540,
 	ixgbe_mac_X550,
 	ixgbe_mac_X550EM_x,
+	ixgbe_mac_X550EM_a,
 	ixgbe_num_macs
 };
 
@@ -2986,7 +3645,9 @@ enum ixgbe_phy_type {
 	ixgbe_phy_aq,
 	ixgbe_phy_x550em_kr,
 	ixgbe_phy_x550em_kx4,
+	ixgbe_phy_x550em_xfi,
 	ixgbe_phy_x550em_ext_t,
+	ixgbe_phy_ext_1g_t,
 	ixgbe_phy_cu_unknown,
 	ixgbe_phy_qt,
 	ixgbe_phy_xaui,
@@ -3003,22 +3664,24 @@ enum ixgbe_phy_type {
 	ixgbe_phy_qsfp_active_unknown,
 	ixgbe_phy_qsfp_intel,
 	ixgbe_phy_qsfp_unknown,
-	ixgbe_phy_sfp_unsupported,
+	ixgbe_phy_sfp_unsupported, /*Enforce bit set with unsupported module*/
+	ixgbe_phy_sgmii,
+	ixgbe_phy_fw,
 	ixgbe_phy_generic
 };
 
 /*
  * SFP+ module type IDs:
  *
- * ID   Module Type
+ * ID	Module Type
  * =============
- * 0    SFP_DA_CU
- * 1    SFP_SR
- * 2    SFP_LR
- * 3    SFP_DA_CU_CORE0 - 82599-specific
- * 4    SFP_DA_CU_CORE1 - 82599-specific
- * 5    SFP_SR/LR_CORE0 - 82599-specific
- * 6    SFP_SR/LR_CORE1 - 82599-specific
+ * 0	SFP_DA_CU
+ * 1	SFP_SR
+ * 2	SFP_LR
+ * 3	SFP_DA_CU_CORE0 - 82599-specific
+ * 4	SFP_DA_CU_CORE1 - 82599-specific
+ * 5	SFP_SR/LR_CORE0 - 82599-specific
+ * 6	SFP_SR/LR_CORE1 - 82599-specific
  */
 enum ixgbe_sfp_type {
 	ixgbe_sfp_type_da_cu = 0,
@@ -3071,6 +3734,8 @@ enum ixgbe_smart_speed {
 /* PCI bus types */
 enum ixgbe_bus_type {
 	ixgbe_bus_type_unknown = 0,
+	ixgbe_bus_type_pci,
+	ixgbe_bus_type_pcix,
 	ixgbe_bus_type_pci_express,
 	ixgbe_bus_type_internal,
 	ixgbe_bus_type_reserved
@@ -3078,27 +3743,27 @@ enum ixgbe_bus_type {
 
 /* PCI bus speeds */
 enum ixgbe_bus_speed {
-	ixgbe_bus_speed_unknown = 0,
-	ixgbe_bus_speed_33      = 33,
-	ixgbe_bus_speed_66      = 66,
-	ixgbe_bus_speed_100     = 100,
-	ixgbe_bus_speed_120     = 120,
-	ixgbe_bus_speed_133     = 133,
-	ixgbe_bus_speed_2500    = 2500,
-	ixgbe_bus_speed_5000    = 5000,
-	ixgbe_bus_speed_8000    = 8000,
+	ixgbe_bus_speed_unknown	= 0,
+	ixgbe_bus_speed_33	= 33,
+	ixgbe_bus_speed_66	= 66,
+	ixgbe_bus_speed_100	= 100,
+	ixgbe_bus_speed_120	= 120,
+	ixgbe_bus_speed_133	= 133,
+	ixgbe_bus_speed_2500	= 2500,
+	ixgbe_bus_speed_5000	= 5000,
+	ixgbe_bus_speed_8000	= 8000,
 	ixgbe_bus_speed_reserved
 };
 
 /* PCI bus widths */
 enum ixgbe_bus_width {
-	ixgbe_bus_width_unknown = 0,
-	ixgbe_bus_width_pcie_x1 = 1,
-	ixgbe_bus_width_pcie_x2 = 2,
-	ixgbe_bus_width_pcie_x4 = 4,
-	ixgbe_bus_width_pcie_x8 = 8,
-	ixgbe_bus_width_32      = 32,
-	ixgbe_bus_width_64      = 64,
+	ixgbe_bus_width_unknown	= 0,
+	ixgbe_bus_width_pcie_x1	= 1,
+	ixgbe_bus_width_pcie_x2	= 2,
+	ixgbe_bus_width_pcie_x4	= 4,
+	ixgbe_bus_width_pcie_x8	= 8,
+	ixgbe_bus_width_32	= 32,
+	ixgbe_bus_width_64	= 64,
 	ixgbe_bus_width_reserved
 };
 
@@ -3107,7 +3772,6 @@ struct ixgbe_addr_filter_info {
 	u32 rar_used_count;
 	u32 mta_in_use;
 	u32 overflow_promisc;
-	bool uc_set_promisc;
 	bool user_set_promisc;
 };
 
@@ -3118,13 +3782,14 @@ struct ixgbe_bus_info {
 	enum ixgbe_bus_type type;
 
 	u16 func;
-	u16 lan_id;
+	u8 lan_id;
+	u16 instance_id;
 };
 
 /* Flow control parameters */
 struct ixgbe_fc_info {
-	u32 high_water[MAX_TRAFFIC_CLASS]; /* Flow Control High-water */
-	u32 low_water[MAX_TRAFFIC_CLASS]; /* Flow Control Low-water */
+	u32 high_water[IXGBE_DCB_MAX_TRAFFIC_CLASS]; /* Flow Ctrl High-water */
+	u32 low_water[IXGBE_DCB_MAX_TRAFFIC_CLASS]; /* Flow Ctrl Low-water */
 	u16 pause_time; /* Flow Control Pause timer */
 	bool send_xon; /* Flow control send XON */
 	bool strict_ieee; /* Strict IEEE mode */
@@ -3185,8 +3850,6 @@ struct ixgbe_hw_stats {
 	u64 mptc;
 	u64 bptc;
 	u64 xec;
-	u64 rqsmr[16];
-	u64 tqsmr[8];
 	u64 qprc[16];
 	u64 qptc[16];
 	u64 qbrc[16];
@@ -3200,6 +3863,7 @@ struct ixgbe_hw_stats {
 	u64 fdirmatch;
 	u64 fdirmiss;
 	u64 fccrc;
+	u64 fclast;
 	u64 fcoerpdc;
 	u64 fcoeprc;
 	u64 fcoeptc;
@@ -3207,6 +3871,8 @@ struct ixgbe_hw_stats {
 	u64 fcoedwtc;
 	u64 fcoe_noddp;
 	u64 fcoe_noddp_ext_buff;
+	u64 ldpcec;
+	u64 pcrc8ec;
 	u64 b2ospc;
 	u64 b2ogprc;
 	u64 o2bgptc;
@@ -3238,21 +3904,25 @@ struct ixgbe_mac_operations {
 	s32 (*start_hw)(struct ixgbe_hw *);
 	s32 (*clear_hw_cntrs)(struct ixgbe_hw *);
 	enum ixgbe_media_type (*get_media_type)(struct ixgbe_hw *);
+	u64 (*get_supported_physical_layer)(struct ixgbe_hw *);
 	s32 (*get_mac_addr)(struct ixgbe_hw *, u8 *);
 	s32 (*get_san_mac_addr)(struct ixgbe_hw *, u8 *);
+	s32 (*set_san_mac_addr)(struct ixgbe_hw *, u8 *);
 	s32 (*get_device_caps)(struct ixgbe_hw *, u16 *);
 	s32 (*get_wwn_prefix)(struct ixgbe_hw *, u16 *, u16 *);
+	s32 (*get_fcoe_boot_status)(struct ixgbe_hw *, u16 *);
 	s32 (*stop_adapter)(struct ixgbe_hw *);
 	s32 (*get_bus_info)(struct ixgbe_hw *);
 	void (*set_lan_id)(struct ixgbe_hw *);
 	s32 (*read_analog_reg8)(struct ixgbe_hw*, u32, u8*);
 	s32 (*write_analog_reg8)(struct ixgbe_hw*, u32, u8);
 	s32 (*setup_sfp)(struct ixgbe_hw *);
-	s32 (*disable_rx_buff)(struct ixgbe_hw *);
-	s32 (*enable_rx_buff)(struct ixgbe_hw *);
 	s32 (*enable_rx_dma)(struct ixgbe_hw *, u32);
+	s32 (*disable_sec_rx_path)(struct ixgbe_hw *);
+	s32 (*enable_sec_rx_path)(struct ixgbe_hw *);
 	s32 (*acquire_swfw_sync)(struct ixgbe_hw *, u32);
 	void (*release_swfw_sync)(struct ixgbe_hw *, u32);
+	void (*init_swfw_sync)(struct ixgbe_hw *);
 	s32 (*prot_autoc_read)(struct ixgbe_hw *, bool *, u32 *);
 	s32 (*prot_autoc_write)(struct ixgbe_hw *, u32, bool);
 
@@ -3260,7 +3930,6 @@ struct ixgbe_mac_operations {
 	void (*disable_tx_laser)(struct ixgbe_hw *);
 	void (*enable_tx_laser)(struct ixgbe_hw *);
 	void (*flap_tx_laser)(struct ixgbe_hw *);
-	void (*stop_link_on_d3)(struct ixgbe_hw *);
 	s32 (*setup_link)(struct ixgbe_hw *, ixgbe_link_speed, bool);
 	s32 (*setup_mac_link)(struct ixgbe_hw *, ixgbe_link_speed, bool);
 	s32 (*check_link)(struct ixgbe_hw *, ixgbe_link_speed *, bool *, bool);
@@ -3268,48 +3937,65 @@ struct ixgbe_mac_operations {
 				     bool *);
 	void (*set_rate_select_speed)(struct ixgbe_hw *, ixgbe_link_speed);
 
-	/* Packet Buffer Manipulation */
-	void (*set_rxpba)(struct ixgbe_hw *, int, u32, int);
+	/* Packet Buffer manipulation */
+	void (*setup_rxpba)(struct ixgbe_hw *, int, u32, int);
 
 	/* LED */
 	s32 (*led_on)(struct ixgbe_hw *, u32);
 	s32 (*led_off)(struct ixgbe_hw *, u32);
 	s32 (*blink_led_start)(struct ixgbe_hw *, u32);
 	s32 (*blink_led_stop)(struct ixgbe_hw *, u32);
+	s32 (*init_led_link_act)(struct ixgbe_hw *);
 
 	/* RAR, Multicast, VLAN */
 	s32 (*set_rar)(struct ixgbe_hw *, u32, u8 *, u32, u32);
+	s32 (*set_uc_addr)(struct ixgbe_hw *, u32, u8 *);
 	s32 (*clear_rar)(struct ixgbe_hw *, u32);
+	s32 (*insert_mac_addr)(struct ixgbe_hw *, u8 *, u32);
 	s32 (*set_vmdq)(struct ixgbe_hw *, u32, u32);
 	s32 (*set_vmdq_san_mac)(struct ixgbe_hw *, u32);
 	s32 (*clear_vmdq)(struct ixgbe_hw *, u32, u32);
 	s32 (*init_rx_addrs)(struct ixgbe_hw *);
-	s32 (*update_mc_addr_list)(struct ixgbe_hw *, struct net_device *);
+	s32 (*update_uc_addr_list)(struct ixgbe_hw *, u8 *, u32,
+				   ixgbe_mc_addr_itr);
+	s32 (*update_mc_addr_list)(struct ixgbe_hw *, u8 *, u32,
+				   ixgbe_mc_addr_itr, bool clear);
 	s32 (*enable_mc)(struct ixgbe_hw *);
 	s32 (*disable_mc)(struct ixgbe_hw *);
 	s32 (*clear_vfta)(struct ixgbe_hw *);
-	s32 (*set_vfta)(struct ixgbe_hw *, u32, u32, bool);
+	s32 (*set_vfta)(struct ixgbe_hw *, u32, u32, bool, bool);
+	s32 (*set_vlvf)(struct ixgbe_hw *, u32, u32, bool, u32 *, u32,
+			bool);
 	s32 (*init_uta_tables)(struct ixgbe_hw *);
 	void (*set_mac_anti_spoofing)(struct ixgbe_hw *, bool, int);
 	void (*set_vlan_anti_spoofing)(struct ixgbe_hw *, bool, int);
 
 	/* Flow Control */
 	s32 (*fc_enable)(struct ixgbe_hw *);
+	s32 (*setup_fc)(struct ixgbe_hw *);
+	void (*fc_autoneg)(struct ixgbe_hw *);
 
 	/* Manageability interface */
-	s32 (*set_fw_drv_ver)(struct ixgbe_hw *, u8, u8, u8, u8);
+	s32 (*set_fw_drv_ver)(struct ixgbe_hw *, u8, u8, u8, u8, u16,
+			      const char *);
 	s32 (*get_thermal_sensor_data)(struct ixgbe_hw *);
 	s32 (*init_thermal_sensor_thresh)(struct ixgbe_hw *hw);
+	void (*get_rtrup2tc)(struct ixgbe_hw *hw, u8 *map);
 	void (*disable_rx)(struct ixgbe_hw *hw);
 	void (*enable_rx)(struct ixgbe_hw *hw);
 	void (*set_source_address_pruning)(struct ixgbe_hw *, bool,
 					   unsigned int);
 	void (*set_ethertype_anti_spoofing)(struct ixgbe_hw *, bool, int);
-
-	/* DMA Coalescing */
-	s32 (*dmac_config)(struct ixgbe_hw *hw);
 	s32 (*dmac_update_tcs)(struct ixgbe_hw *hw);
 	s32 (*dmac_config_tcs)(struct ixgbe_hw *hw);
+	s32 (*dmac_config)(struct ixgbe_hw *hw);
+	s32 (*setup_eee)(struct ixgbe_hw *hw, bool enable_eee);
+	s32 (*read_iosf_sb_reg)(struct ixgbe_hw *, u32, u32, u32 *);
+	s32 (*write_iosf_sb_reg)(struct ixgbe_hw *, u32, u32, u32);
+	void (*disable_mdd)(struct ixgbe_hw *hw);
+	void (*enable_mdd)(struct ixgbe_hw *hw);
+	void (*mdd_event)(struct ixgbe_hw *hw, u32 *vf_bitmap);
+	void (*restore_mdd_vf)(struct ixgbe_hw *hw, u32 vf);
 };
 
 struct ixgbe_phy_operations {
@@ -3331,92 +4017,113 @@ struct ixgbe_phy_operations {
 	s32 (*read_i2c_sff8472)(struct ixgbe_hw *, u8 , u8 *);
 	s32 (*read_i2c_eeprom)(struct ixgbe_hw *, u8 , u8 *);
 	s32 (*write_i2c_eeprom)(struct ixgbe_hw *, u8, u8);
-	s32 (*read_i2c_combined)(struct ixgbe_hw *, u8 addr, u16 reg, u16 *val);
-	s32 (*write_i2c_combined)(struct ixgbe_hw *, u8 addr, u16 reg, u16 val);
+	void (*i2c_bus_clear)(struct ixgbe_hw *);
 	s32 (*check_overtemp)(struct ixgbe_hw *);
 	s32 (*set_phy_power)(struct ixgbe_hw *, bool on);
 	s32 (*enter_lplu)(struct ixgbe_hw *);
 	s32 (*handle_lasi)(struct ixgbe_hw *hw);
-	s32 (*read_i2c_combined_unlocked)(struct ixgbe_hw *, u8 addr, u16 reg,
-					  u16 *value);
-	s32 (*write_i2c_combined_unlocked)(struct ixgbe_hw *, u8 addr, u16 reg,
-					   u16 value);
+	s32 (*read_i2c_byte_unlocked)(struct ixgbe_hw *, u8 offset, u8 addr,
+				      u8 *value);
+	s32 (*write_i2c_byte_unlocked)(struct ixgbe_hw *, u8 offset, u8 addr,
+				       u8 value);
+};
+
+struct ixgbe_link_operations {
+	s32 (*read_link)(struct ixgbe_hw *, u8 addr, u16 reg, u16 *val);
+	s32 (*read_link_unlocked)(struct ixgbe_hw *, u8 addr, u16 reg,
+				  u16 *val);
+	s32 (*write_link)(struct ixgbe_hw *, u8 addr, u16 reg, u16 val);
+	s32 (*write_link_unlocked)(struct ixgbe_hw *, u8 addr, u16 reg,
+				   u16 val);
+};
+
+struct ixgbe_link_info {
+	struct ixgbe_link_operations ops;
+	u8 addr;
 };
 
 struct ixgbe_eeprom_info {
-	struct ixgbe_eeprom_operations  ops;
-	enum ixgbe_eeprom_type          type;
-	u32                             semaphore_delay;
-	u16                             word_size;
-	u16                             address_bits;
-	u16                             word_page_size;
-	u16				ctrl_word_3;
+	struct ixgbe_eeprom_operations ops;
+	enum ixgbe_eeprom_type type;
+	u32 semaphore_delay;
+	u16 word_size;
+	u16 address_bits;
+	u16 word_page_size;
+	u16 ctrl_word_3;
 };
 
 #define IXGBE_FLAGS_DOUBLE_RESET_REQUIRED	0x01
 struct ixgbe_mac_info {
-	struct ixgbe_mac_operations     ops;
-	enum ixgbe_mac_type             type;
-	u8                              addr[ETH_ALEN];
-	u8                              perm_addr[ETH_ALEN];
-	u8                              san_addr[ETH_ALEN];
+	struct ixgbe_mac_operations ops;
+	enum ixgbe_mac_type type;
+	u8 addr[IXGBE_ETH_LENGTH_OF_ADDRESS];
+	u8 perm_addr[IXGBE_ETH_LENGTH_OF_ADDRESS];
+	u8 san_addr[IXGBE_ETH_LENGTH_OF_ADDRESS];
 	/* prefix for World Wide Node Name (WWNN) */
-	u16                             wwnn_prefix;
+	u16 wwnn_prefix;
 	/* prefix for World Wide Port Name (WWPN) */
-	u16                             wwpn_prefix;
-	u16				max_msix_vectors;
+	u16 wwpn_prefix;
 #define IXGBE_MAX_MTA			128
-	u32				mta_shadow[IXGBE_MAX_MTA];
-	s32                             mc_filter_type;
-	u32                             mcft_size;
-	u32                             vft_size;
-	u32                             num_rar_entries;
-	u32                             rar_highwater;
-	u32				rx_pb_size;
-	u32                             max_tx_queues;
-	u32                             max_rx_queues;
-	u32                             orig_autoc;
-	u32                             orig_autoc2;
-	bool                            orig_link_settings_stored;
-	bool                            autotry_restart;
-	u8                              flags;
-	u8				san_mac_rar_index;
+	u32 mta_shadow[IXGBE_MAX_MTA];
+	s32 mc_filter_type;
+	u32 mcft_size;
+	u32 vft_size;
+	u32 num_rar_entries;
+	u32 rar_highwater;
+	u32 rx_pb_size;
+	u32 max_tx_queues;
+	u32 max_rx_queues;
+	u32 orig_autoc;
+	u8  san_mac_rar_index;
+	bool get_link_status;
+	u32 orig_autoc2;
+	u16 max_msix_vectors;
+	bool arc_subsystem_valid;
+	bool orig_link_settings_stored;
+	bool autotry_restart;
+	u8 flags;
 	struct ixgbe_thermal_sensor_data  thermal_sensor_data;
-	bool				set_lben;
+	bool thermal_sensor_enabled;
+	struct ixgbe_dmac_config dmac_config;
+	bool set_lben;
+	u32  max_link_up_time;
+	u8   led_link_act;
 };
 
 struct ixgbe_phy_info {
-	struct ixgbe_phy_operations     ops;
-	struct mdio_if_info		mdio;
-	enum ixgbe_phy_type             type;
-	u32                             id;
-	enum ixgbe_sfp_type             sfp_type;
-	bool                            sfp_setup_needed;
-	u32                             revision;
-	enum ixgbe_media_type           media_type;
-	u32				phy_semaphore_mask;
-	bool                            reset_disable;
-	ixgbe_autoneg_advertised        autoneg_advertised;
-	ixgbe_link_speed		speeds_supported;
-	enum ixgbe_smart_speed          smart_speed;
-	bool                            smart_speed_active;
-	bool                            multispeed_fiber;
-	bool                            reset_if_overtemp;
-	bool                            qsfp_shared_i2c_bus;
-	u32				nw_mng_if_sel;
+	struct ixgbe_phy_operations ops;
+	enum ixgbe_phy_type type;
+	u32 addr;
+	u32 id;
+	enum ixgbe_sfp_type sfp_type;
+	bool sfp_setup_needed;
+	u32 revision;
+	enum ixgbe_media_type media_type;
+	u32 phy_semaphore_mask;
+	bool reset_disable;
+	ixgbe_autoneg_advertised autoneg_advertised;
+	ixgbe_link_speed speeds_supported;
+	ixgbe_link_speed eee_speeds_supported;
+	ixgbe_link_speed eee_speeds_advertised;
+	enum ixgbe_smart_speed smart_speed;
+	bool smart_speed_active;
+	bool multispeed_fiber;
+	bool reset_if_overtemp;
+	bool qsfp_shared_i2c_bus;
+	u32 nw_mng_if_sel;
 };
 
 #include "ixgbe_mbx.h"
 
 struct ixgbe_mbx_operations {
-	s32 (*init_params)(struct ixgbe_hw *hw);
-	s32 (*read)(struct ixgbe_hw *, u32 *, u16,  u16);
-	s32 (*write)(struct ixgbe_hw *, u32 *, u16, u16);
-	s32 (*read_posted)(struct ixgbe_hw *, u32 *, u16,  u16);
-	s32 (*write_posted)(struct ixgbe_hw *, u32 *, u16, u16);
-	s32 (*check_for_msg)(struct ixgbe_hw *, u16);
-	s32 (*check_for_ack)(struct ixgbe_hw *, u16);
-	s32 (*check_for_rst)(struct ixgbe_hw *, u16);
+	void (*init_params)(struct ixgbe_hw *hw);
+	s32  (*read)(struct ixgbe_hw *, u32 *, u16,  u16);
+	s32  (*write)(struct ixgbe_hw *, u32 *, u16, u16);
+	s32  (*read_posted)(struct ixgbe_hw *, u32 *, u16,  u16);
+	s32  (*write_posted)(struct ixgbe_hw *, u32 *, u16, u16);
+	s32  (*check_for_msg)(struct ixgbe_hw *, u16);
+	s32  (*check_for_ack)(struct ixgbe_hw *, u16);
+	s32  (*check_for_rst)(struct ixgbe_hw *, u16);
 };
 
 struct ixgbe_mbx_stats {
@@ -3438,102 +4145,147 @@ struct ixgbe_mbx_info {
 };
 
 struct ixgbe_hw {
-	u8 __iomem			*hw_addr;
-	void				*back;
-	struct ixgbe_mac_info		mac;
-	struct ixgbe_addr_filter_info	addr_ctrl;
-	struct ixgbe_fc_info		fc;
-	struct ixgbe_phy_info		phy;
-	struct ixgbe_eeprom_info	eeprom;
-	struct ixgbe_bus_info		bus;
-	struct ixgbe_mbx_info		mbx;
-	const u32			*mvals;
-	u16				device_id;
-	u16				vendor_id;
-	u16				subsystem_device_id;
-	u16				subsystem_vendor_id;
-	u8				revision_id;
-	bool				adapter_stopped;
-	bool				force_full_reset;
-	bool				allow_unsupported_sfp;
-	bool				wol_enabled;
-};
-
-struct ixgbe_info {
-	enum ixgbe_mac_type		mac;
-	s32 				(*get_invariants)(struct ixgbe_hw *);
-	struct ixgbe_mac_operations	*mac_ops;
-	struct ixgbe_eeprom_operations	*eeprom_ops;
-	struct ixgbe_phy_operations	*phy_ops;
-	struct ixgbe_mbx_operations	*mbx_ops;
-	const u32			*mvals;
+	u8 IOMEM *hw_addr;
+	void *back;
+	struct ixgbe_mac_info mac;
+	struct ixgbe_addr_filter_info addr_ctrl;
+	struct ixgbe_fc_info fc;
+	struct ixgbe_phy_info phy;
+	struct ixgbe_link_info link;
+	struct ixgbe_eeprom_info eeprom;
+	struct ixgbe_bus_info bus;
+	struct ixgbe_mbx_info mbx;
+	const u32 *mvals;
+	u16 device_id;
+	u16 vendor_id;
+	u16 subsystem_device_id;
+	u16 subsystem_vendor_id;
+	u8 revision_id;
+	bool adapter_stopped;
+	int api_version;
+	bool force_full_reset;
+	bool allow_unsupported_sfp;
+	bool wol_enabled;
+	bool need_crosstalk_fix;
 };
 
+#define ixgbe_call_func(hw, func, params, error) \
+		(func != NULL) ? func params : error
 
 /* Error Codes */
-#define IXGBE_ERR_EEPROM                        -1
-#define IXGBE_ERR_EEPROM_CHECKSUM               -2
-#define IXGBE_ERR_PHY                           -3
-#define IXGBE_ERR_CONFIG                        -4
-#define IXGBE_ERR_PARAM                         -5
-#define IXGBE_ERR_MAC_TYPE                      -6
-#define IXGBE_ERR_UNKNOWN_PHY                   -7
-#define IXGBE_ERR_LINK_SETUP                    -8
-#define IXGBE_ERR_ADAPTER_STOPPED               -9
-#define IXGBE_ERR_INVALID_MAC_ADDR              -10
-#define IXGBE_ERR_DEVICE_NOT_SUPPORTED          -11
-#define IXGBE_ERR_MASTER_REQUESTS_PENDING       -12
-#define IXGBE_ERR_INVALID_LINK_SETTINGS         -13
-#define IXGBE_ERR_AUTONEG_NOT_COMPLETE          -14
-#define IXGBE_ERR_RESET_FAILED                  -15
-#define IXGBE_ERR_SWFW_SYNC                     -16
-#define IXGBE_ERR_PHY_ADDR_INVALID              -17
-#define IXGBE_ERR_I2C                           -18
-#define IXGBE_ERR_SFP_NOT_SUPPORTED             -19
-#define IXGBE_ERR_SFP_NOT_PRESENT               -20
-#define IXGBE_ERR_SFP_NO_INIT_SEQ_PRESENT       -21
-#define IXGBE_ERR_NO_SAN_ADDR_PTR               -22
-#define IXGBE_ERR_FDIR_REINIT_FAILED            -23
-#define IXGBE_ERR_EEPROM_VERSION                -24
-#define IXGBE_ERR_NO_SPACE                      -25
-#define IXGBE_ERR_OVERTEMP                      -26
-#define IXGBE_ERR_FC_NOT_NEGOTIATED             -27
-#define IXGBE_ERR_FC_NOT_SUPPORTED              -28
-#define IXGBE_ERR_SFP_SETUP_NOT_COMPLETE        -30
-#define IXGBE_ERR_PBA_SECTION                   -31
-#define IXGBE_ERR_INVALID_ARGUMENT              -32
-#define IXGBE_ERR_HOST_INTERFACE_COMMAND        -33
+#define IXGBE_SUCCESS				0
+#define IXGBE_ERR_EEPROM			-1
+#define IXGBE_ERR_EEPROM_CHECKSUM		-2
+#define IXGBE_ERR_PHY				-3
+#define IXGBE_ERR_CONFIG			-4
+#define IXGBE_ERR_PARAM				-5
+#define IXGBE_ERR_MAC_TYPE			-6
+#define IXGBE_ERR_UNKNOWN_PHY			-7
+#define IXGBE_ERR_LINK_SETUP			-8
+#define IXGBE_ERR_ADAPTER_STOPPED		-9
+#define IXGBE_ERR_INVALID_MAC_ADDR		-10
+#define IXGBE_ERR_DEVICE_NOT_SUPPORTED		-11
+#define IXGBE_ERR_MASTER_REQUESTS_PENDING	-12
+#define IXGBE_ERR_INVALID_LINK_SETTINGS		-13
+#define IXGBE_ERR_AUTONEG_NOT_COMPLETE		-14
+#define IXGBE_ERR_RESET_FAILED			-15
+#define IXGBE_ERR_SWFW_SYNC			-16
+#define IXGBE_ERR_PHY_ADDR_INVALID		-17
+#define IXGBE_ERR_I2C				-18
+#define IXGBE_ERR_SFP_NOT_SUPPORTED		-19
+#define IXGBE_ERR_SFP_NOT_PRESENT		-20
+#define IXGBE_ERR_SFP_NO_INIT_SEQ_PRESENT	-21
+#define IXGBE_ERR_NO_SAN_ADDR_PTR		-22
+#define IXGBE_ERR_FDIR_REINIT_FAILED		-23
+#define IXGBE_ERR_EEPROM_VERSION		-24
+#define IXGBE_ERR_NO_SPACE			-25
+#define IXGBE_ERR_OVERTEMP			-26
+#define IXGBE_ERR_FC_NOT_NEGOTIATED		-27
+#define IXGBE_ERR_FC_NOT_SUPPORTED		-28
+#define IXGBE_ERR_SFP_SETUP_NOT_COMPLETE	-30
+#define IXGBE_ERR_PBA_SECTION			-31
+#define IXGBE_ERR_INVALID_ARGUMENT		-32
+#define IXGBE_ERR_HOST_INTERFACE_COMMAND	-33
+#define IXGBE_ERR_OUT_OF_MEM			-34
+#define IXGBE_ERR_FEATURE_NOT_SUPPORTED		-36
+#define IXGBE_ERR_EEPROM_PROTECTED_REGION	-37
 #define IXGBE_ERR_FDIR_CMD_INCOMPLETE		-38
-#define IXGBE_NOT_IMPLEMENTED                   0x7FFFFFFF
+#define IXGBE_ERR_FW_RESP_INVALID		-39
+#define IXGBE_ERR_TOKEN_RETRY			-40
+
+#define IXGBE_NOT_IMPLEMENTED			0x7FFFFFFF
 
 #define IXGBE_FUSES0_GROUP(_i)		(0x11158 + ((_i) * 4))
-#define IXGBE_FUSES0_300MHZ		BIT(5)
-#define IXGBE_FUSES0_REV1		BIT(6)
+#define IXGBE_FUSES0_300MHZ		(1 << 5)
+#define IXGBE_FUSES0_REV_MASK		(3 << 6)
 
 #define IXGBE_KRM_PORT_CAR_GEN_CTRL(P)	((P) ? 0x8010 : 0x4010)
+#define IXGBE_KRM_LINK_S1(P)		((P) ? 0x8200 : 0x4200)
 #define IXGBE_KRM_LINK_CTRL_1(P)	((P) ? 0x820C : 0x420C)
+#define IXGBE_KRM_AN_CNTL_1(P)		((P) ? 0x822C : 0x422C)
+#define IXGBE_KRM_AN_CNTL_4(P)		((P) ? 0x8238 : 0x4238)
+#define IXGBE_KRM_AN_CNTL_8(P)		((P) ? 0x8248 : 0x4248)
+#define IXGBE_KRM_PCS_KX_AN(P)		((P) ? 0x9918 : 0x5918)
+#define IXGBE_KRM_PCS_KX_AN_LP(P)	((P) ? 0x991C : 0x591C)
+#define IXGBE_KRM_SGMII_CTRL(P)		((P) ? 0x82A0 : 0x42A0)
+#define IXGBE_KRM_LP_BASE_PAGE_HIGH(P)	((P) ? 0x836C : 0x436C)
 #define IXGBE_KRM_DSP_TXFFE_STATE_4(P)	((P) ? 0x8634 : 0x4634)
 #define IXGBE_KRM_DSP_TXFFE_STATE_5(P)	((P) ? 0x8638 : 0x4638)
 #define IXGBE_KRM_RX_TRN_LINKUP_CTRL(P)	((P) ? 0x8B00 : 0x4B00)
 #define IXGBE_KRM_PMD_DFX_BURNIN(P)	((P) ? 0x8E00 : 0x4E00)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20(P)	((P) ? 0x9054 : 0x5054)
 #define IXGBE_KRM_TX_COEFF_CTRL_1(P)	((P) ? 0x9520 : 0x5520)
 #define IXGBE_KRM_RX_ANA_CTL(P)		((P) ? 0x9A00 : 0x5A00)
 
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_SFI_10G_DA		~(0x3 << 20)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_SFI_10G_SR		(1u << 20)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_SFI_10G_LR		(0x2 << 20)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_SGMII_EN		(1u << 25)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_AN37_EN		(1u << 26)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_AN_EN		(1u << 27)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_10M		~(0x7 << 28)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_100M		(1u << 28)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_1G		(0x2 << 28)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_10G		(0x3 << 28)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_AN		(0x4 << 28)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_2_5G		(0x7 << 28)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_MASK		(0x7 << 28)
+#define IXGBE_KRM_PMD_FLX_MASK_ST20_FW_AN_RESTART	(1u << 31)
+
 #define IXGBE_KRM_PORT_CAR_GEN_CTRL_NELB_32B		(1 << 9)
 #define IXGBE_KRM_PORT_CAR_GEN_CTRL_NELB_KRPCS		(1 << 11)
 
 #define IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_MASK	(0x7 << 8)
 #define IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_1G	(2 << 8)
 #define IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_10G	(4 << 8)
+#define IXGBE_KRM_LINK_CTRL_1_TETH_AN_SGMII_EN		(1 << 12)
+#define IXGBE_KRM_LINK_CTRL_1_TETH_AN_CLAUSE_37_EN	(1 << 13)
 #define IXGBE_KRM_LINK_CTRL_1_TETH_AN_FEC_REQ		(1 << 14)
 #define IXGBE_KRM_LINK_CTRL_1_TETH_AN_CAP_FEC		(1 << 15)
 #define IXGBE_KRM_LINK_CTRL_1_TETH_AN_CAP_KX		(1 << 16)
 #define IXGBE_KRM_LINK_CTRL_1_TETH_AN_CAP_KR		(1 << 18)
 #define IXGBE_KRM_LINK_CTRL_1_TETH_EEE_CAP_KX		(1 << 24)
 #define IXGBE_KRM_LINK_CTRL_1_TETH_EEE_CAP_KR		(1 << 26)
+#define IXGBE_KRM_LINK_S1_MAC_AN_COMPLETE		(1 << 28)
 #define IXGBE_KRM_LINK_CTRL_1_TETH_AN_ENABLE		(1 << 29)
 #define IXGBE_KRM_LINK_CTRL_1_TETH_AN_RESTART		(1 << 31)
 
+#define IXGBE_KRM_AN_CNTL_1_SYM_PAUSE			(1 << 28)
+#define IXGBE_KRM_AN_CNTL_1_ASM_PAUSE			(1 << 29)
+#define IXGBE_KRM_PCS_KX_AN_SYM_PAUSE			(1 << 1)
+#define IXGBE_KRM_PCS_KX_AN_ASM_PAUSE			(1 << 2)
+#define IXGBE_KRM_PCS_KX_AN_LP_SYM_PAUSE		(1 << 2)
+#define IXGBE_KRM_PCS_KX_AN_LP_ASM_PAUSE		(1 << 3)
+#define IXGBE_KRM_AN_CNTL_4_ECSR_AN37_OVER_73		(1 << 29)
+#define IXGBE_KRM_AN_CNTL_8_LINEAR			(1 << 0)
+#define IXGBE_KRM_AN_CNTL_8_LIMITING			(1 << 1)
+
+#define IXGBE_KRM_LP_BASE_PAGE_HIGH_SYM_PAUSE		(1 << 10)
+#define IXGBE_KRM_LP_BASE_PAGE_HIGH_ASM_PAUSE		(1 << 11)
+
+#define IXGBE_KRM_SGMII_CTRL_MAC_TAR_FORCE_100_D	(1 << 12)
+#define IXGBE_KRM_SGMII_CTRL_MAC_TAR_FORCE_10_D		(1 << 19)
+
 #define IXGBE_KRM_DSP_TXFFE_STATE_C0_EN			(1 << 6)
 #define IXGBE_KRM_DSP_TXFFE_STATE_CP1_CN1_EN		(1 << 15)
 #define IXGBE_KRM_DSP_TXFFE_STATE_CO_ADAPT_EN		(1 << 16)
@@ -3548,35 +4300,38 @@ struct ixgbe_info {
 #define IXGBE_KRM_TX_COEFF_CTRL_1_CZERO_EN		(1 << 3)
 #define IXGBE_KRM_TX_COEFF_CTRL_1_OVRRD_EN		(1 << 31)
 
-#define IXGBE_KX4_LINK_CNTL_1				0x4C
-#define IXGBE_KX4_LINK_CNTL_1_TETH_AN_CAP_KX		(1 << 16)
-#define IXGBE_KX4_LINK_CNTL_1_TETH_AN_CAP_KX4		(1 << 17)
-#define IXGBE_KX4_LINK_CNTL_1_TETH_EEE_CAP_KX		(1 << 24)
-#define IXGBE_KX4_LINK_CNTL_1_TETH_EEE_CAP_KX4		(1 << 25)
-#define IXGBE_KX4_LINK_CNTL_1_TETH_AN_ENABLE		(1 << 29)
-#define IXGBE_KX4_LINK_CNTL_1_TETH_FORCE_LINK_UP	(1 << 30)
-#define IXGBE_KX4_LINK_CNTL_1_TETH_AN_RESTART		(1 << 31)
-
-#define IXGBE_SB_IOSF_INDIRECT_CTRL		0x00011144
-#define IXGBE_SB_IOSF_INDIRECT_DATA		0x00011148
+#define IXGBE_SB_IOSF_INDIRECT_CTRL	0x00011144
+#define IXGBE_SB_IOSF_INDIRECT_DATA	0x00011148
 
 #define IXGBE_SB_IOSF_CTRL_ADDR_SHIFT		0
 #define IXGBE_SB_IOSF_CTRL_ADDR_MASK		0xFF
 #define IXGBE_SB_IOSF_CTRL_RESP_STAT_SHIFT	18
-#define IXGBE_SB_IOSF_CTRL_RESP_STAT_MASK \
+#define IXGBE_SB_IOSF_CTRL_RESP_STAT_MASK	\
 				(0x3 << IXGBE_SB_IOSF_CTRL_RESP_STAT_SHIFT)
 #define IXGBE_SB_IOSF_CTRL_CMPL_ERR_SHIFT	20
-#define IXGBE_SB_IOSF_CTRL_CMPL_ERR_MASK \
+#define IXGBE_SB_IOSF_CTRL_CMPL_ERR_MASK	\
 				(0xFF << IXGBE_SB_IOSF_CTRL_CMPL_ERR_SHIFT)
 #define IXGBE_SB_IOSF_CTRL_TARGET_SELECT_SHIFT	28
 #define IXGBE_SB_IOSF_CTRL_TARGET_SELECT_MASK	0x7
 #define IXGBE_SB_IOSF_CTRL_BUSY_SHIFT		31
 #define IXGBE_SB_IOSF_CTRL_BUSY		(1 << IXGBE_SB_IOSF_CTRL_BUSY_SHIFT)
 #define IXGBE_SB_IOSF_TARGET_KR_PHY	0
-#define IXGBE_SB_IOSF_TARGET_KX4_UNIPHY	1
-#define IXGBE_SB_IOSF_TARGET_KX4_PCS0	2
-#define IXGBE_SB_IOSF_TARGET_KX4_PCS1	3
 
 #define IXGBE_NW_MNG_IF_SEL		0x00011178
-#define IXGBE_NW_MNG_IF_SEL_INT_PHY_MODE	BIT(24)
+#define IXGBE_NW_MNG_IF_SEL_MDIO_ACT	(1u << 1)
+#define IXGBE_NW_MNG_IF_SEL_MDIO_IF_MODE	(1u << 2)
+#define IXGBE_NW_MNG_IF_SEL_EN_SHARED_MDIO	(1u << 13)
+#define IXGBE_NW_MNG_IF_SEL_PHY_SPEED_10M	(1u << 17)
+#define IXGBE_NW_MNG_IF_SEL_PHY_SPEED_100M	(1u << 18)
+#define IXGBE_NW_MNG_IF_SEL_PHY_SPEED_1G	(1u << 19)
+#define IXGBE_NW_MNG_IF_SEL_PHY_SPEED_2_5G	(1u << 20)
+#define IXGBE_NW_MNG_IF_SEL_PHY_SPEED_10G	(1u << 21)
+#define IXGBE_NW_MNG_IF_SEL_SGMII_ENABLE	(1u << 25)
+#define IXGBE_NW_MNG_IF_SEL_INT_PHY_MODE (1 << 24) /* X552 reg field only */
+#define IXGBE_NW_MNG_IF_SEL_MDIO_PHY_ADD_SHIFT 3
+#define IXGBE_NW_MNG_IF_SEL_MDIO_PHY_ADD	\
+				(0x1F << IXGBE_NW_MNG_IF_SEL_MDIO_PHY_ADD_SHIFT)
+
+#include "ixgbe_osdep2.h"
+
 #endif /* _IXGBE_TYPE_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_x540.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_x540.c
index c1d4584..a575617 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_x540.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_x540.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
 
-  Intel 10 Gigabit PCI Express Linux driver
-  Copyright(c) 1999 - 2014 Intel Corporation.
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
 
   This program is free software; you can redistribute it and/or modify it
   under the terms and conditions of the GNU General Public License,
@@ -12,10 +12,6 @@
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
 
-  You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
-
   The full GNU General Public License is included in this distribution in
   the file called "COPYING".
 
@@ -26,13 +22,11 @@
 
 *******************************************************************************/
 
-#include <linux/pci.h>
-#include <linux/delay.h>
-#include <linux/sched.h>
-
-#include "ixgbe.h"
-#include "ixgbe_phy.h"
 #include "ixgbe_x540.h"
+#include "ixgbe_type.h"
+#include "ixgbe_api.h"
+#include "ixgbe_common.h"
+#include "ixgbe_phy.h"
 
 #define IXGBE_X540_MAX_TX_QUEUES	128
 #define IXGBE_X540_MAX_RX_QUEUES	128
@@ -41,47 +35,154 @@
 #define IXGBE_X540_VFT_TBL_SIZE		128
 #define IXGBE_X540_RX_PB_SIZE		384
 
-static s32 ixgbe_update_flash_X540(struct ixgbe_hw *hw);
-static s32 ixgbe_poll_flash_update_done_X540(struct ixgbe_hw *hw);
-static s32 ixgbe_get_swfw_sync_semaphore(struct ixgbe_hw *hw);
-static void ixgbe_release_swfw_sync_semaphore(struct ixgbe_hw *hw);
+STATIC s32 ixgbe_poll_flash_update_done_X540(struct ixgbe_hw *hw);
+STATIC s32 ixgbe_get_swfw_sync_semaphore(struct ixgbe_hw *hw);
+STATIC void ixgbe_release_swfw_sync_semaphore(struct ixgbe_hw *hw);
 
-enum ixgbe_media_type ixgbe_get_media_type_X540(struct ixgbe_hw *hw)
-{
-	return ixgbe_media_type_copper;
-}
-
-s32 ixgbe_get_invariants_X540(struct ixgbe_hw *hw)
+/**
+ *  ixgbe_init_ops_X540 - Inits func ptrs and MAC type
+ *  @hw: pointer to hardware structure
+ *
+ *  Initialize the function pointers and assign the MAC type for X540.
+ *  Does not touch the hardware.
+ **/
+s32 ixgbe_init_ops_X540(struct ixgbe_hw *hw)
 {
 	struct ixgbe_mac_info *mac = &hw->mac;
 	struct ixgbe_phy_info *phy = &hw->phy;
+	struct ixgbe_eeprom_info *eeprom = &hw->eeprom;
+	s32 ret_val;
 
-	/* set_phy_power was set by default to NULL */
-	if (!ixgbe_mng_present(hw))
-		phy->ops.set_phy_power = ixgbe_set_copper_phy_power;
+	DEBUGFUNC("ixgbe_init_ops_X540");
+
+	ret_val = ixgbe_init_phy_ops_generic(hw);
+	ret_val = ixgbe_init_ops_generic(hw);
+
+	/* EEPROM */
+	eeprom->ops.init_params = ixgbe_init_eeprom_params_X540;
+	eeprom->ops.read = ixgbe_read_eerd_X540;
+	eeprom->ops.read_buffer = ixgbe_read_eerd_buffer_X540;
+	eeprom->ops.write = ixgbe_write_eewr_X540;
+	eeprom->ops.write_buffer = ixgbe_write_eewr_buffer_X540;
+	eeprom->ops.update_checksum = ixgbe_update_eeprom_checksum_X540;
+	eeprom->ops.validate_checksum = ixgbe_validate_eeprom_checksum_X540;
+	eeprom->ops.calc_checksum = ixgbe_calc_eeprom_checksum_X540;
+
+	/* PHY */
+	phy->ops.init = ixgbe_init_phy_ops_generic;
+	phy->ops.reset = NULL;
+	phy->ops.set_phy_power = ixgbe_set_copper_phy_power;
+
+	/* MAC */
+	mac->ops.reset_hw = ixgbe_reset_hw_X540;
+	mac->ops.get_media_type = ixgbe_get_media_type_X540;
+	mac->ops.get_supported_physical_layer =
+				    ixgbe_get_supported_physical_layer_X540;
+	mac->ops.read_analog_reg8 = NULL;
+	mac->ops.write_analog_reg8 = NULL;
+	mac->ops.start_hw = ixgbe_start_hw_X540;
+	mac->ops.get_san_mac_addr = ixgbe_get_san_mac_addr_generic;
+	mac->ops.set_san_mac_addr = ixgbe_set_san_mac_addr_generic;
+	mac->ops.get_device_caps = ixgbe_get_device_caps_generic;
+	mac->ops.get_wwn_prefix = ixgbe_get_wwn_prefix_generic;
+	mac->ops.get_fcoe_boot_status = ixgbe_get_fcoe_boot_status_generic;
+	mac->ops.acquire_swfw_sync = ixgbe_acquire_swfw_sync_X540;
+	mac->ops.release_swfw_sync = ixgbe_release_swfw_sync_X540;
+	mac->ops.init_swfw_sync = ixgbe_init_swfw_sync_X540;
+	mac->ops.disable_sec_rx_path = ixgbe_disable_sec_rx_path_generic;
+	mac->ops.enable_sec_rx_path = ixgbe_enable_sec_rx_path_generic;
+
+	/* RAR, Multicast, VLAN */
+	mac->ops.set_vmdq = ixgbe_set_vmdq_generic;
+	mac->ops.set_vmdq_san_mac = ixgbe_set_vmdq_san_mac_generic;
+	mac->ops.clear_vmdq = ixgbe_clear_vmdq_generic;
+	mac->ops.insert_mac_addr = ixgbe_insert_mac_addr_generic;
+	mac->rar_highwater = 1;
+	mac->ops.set_vfta = ixgbe_set_vfta_generic;
+	mac->ops.set_vlvf = ixgbe_set_vlvf_generic;
+	mac->ops.clear_vfta = ixgbe_clear_vfta_generic;
+	mac->ops.init_uta_tables = ixgbe_init_uta_tables_generic;
+	mac->ops.set_mac_anti_spoofing = ixgbe_set_mac_anti_spoofing;
+	mac->ops.set_vlan_anti_spoofing = ixgbe_set_vlan_anti_spoofing;
+
+	/* Link */
+	mac->ops.get_link_capabilities =
+				ixgbe_get_copper_link_capabilities_generic;
+	mac->ops.setup_link = ixgbe_setup_mac_link_X540;
+	mac->ops.setup_rxpba = ixgbe_set_rxpba_generic;
+	mac->ops.check_link = ixgbe_check_mac_link_generic;
+
+	mac->mcft_size		= IXGBE_X540_MC_TBL_SIZE;
+	mac->vft_size		= IXGBE_X540_VFT_TBL_SIZE;
+	mac->num_rar_entries	= IXGBE_X540_RAR_ENTRIES;
+	mac->rx_pb_size		= IXGBE_X540_RX_PB_SIZE;
+	mac->max_rx_queues	= IXGBE_X540_MAX_RX_QUEUES;
+	mac->max_tx_queues	= IXGBE_X540_MAX_TX_QUEUES;
+	mac->max_msix_vectors	= ixgbe_get_pcie_msix_count_generic(hw);
 
-	mac->mcft_size = IXGBE_X540_MC_TBL_SIZE;
-	mac->vft_size = IXGBE_X540_VFT_TBL_SIZE;
-	mac->num_rar_entries = IXGBE_X540_RAR_ENTRIES;
-	mac->rx_pb_size = IXGBE_X540_RX_PB_SIZE;
-	mac->max_rx_queues = IXGBE_X540_MAX_RX_QUEUES;
-	mac->max_tx_queues = IXGBE_X540_MAX_TX_QUEUES;
-	mac->max_msix_vectors = ixgbe_get_pcie_msix_count_generic(hw);
+	/*
+	 * FWSM register
+	 * ARC supported; valid only if manageability features are
+	 * enabled.
+	 */
+	mac->arc_subsystem_valid = !!(IXGBE_READ_REG(hw, IXGBE_FWSM_BY_MAC(hw))
+				     & IXGBE_FWSM_MODE_MASK);
 
-	return 0;
+	hw->mbx.ops.init_params = ixgbe_init_mbx_params_pf;
+
+	/* LEDs */
+	mac->ops.blink_led_start = ixgbe_blink_led_start_X540;
+	mac->ops.blink_led_stop = ixgbe_blink_led_stop_X540;
+
+	/* Manageability interface */
+	mac->ops.set_fw_drv_ver = ixgbe_set_fw_drv_ver_generic;
+
+	mac->ops.get_rtrup2tc = ixgbe_dcb_get_rtrup2tc_generic;
+
+	return ret_val;
 }
 
 /**
- *  ixgbe_setup_mac_link_X540 - Set the auto advertised capabilitires
+ *  ixgbe_get_link_capabilities_X540 - Determines link capabilities
+ *  @hw: pointer to hardware structure
+ *  @speed: pointer to link speed
+ *  @autoneg: true when autoneg or autotry is enabled
+ *
+ *  Determines the link capabilities by reading the AUTOC register.
+ **/
+s32 ixgbe_get_link_capabilities_X540(struct ixgbe_hw *hw,
+				     ixgbe_link_speed *speed,
+				     bool *autoneg)
+{
+	ixgbe_get_copper_link_capabilities_generic(hw, speed, autoneg);
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_get_media_type_X540 - Get media type
+ *  @hw: pointer to hardware structure
+ *
+ *  Returns the media type (fiber, copper, backplane)
+ **/
+enum ixgbe_media_type ixgbe_get_media_type_X540(struct ixgbe_hw *hw)
+{
+	UNREFERENCED_1PARAMETER(hw);
+	return ixgbe_media_type_copper;
+}
+
+/**
+ *  ixgbe_setup_mac_link_X540 - Sets the auto advertised capabilities
  *  @hw: pointer to hardware structure
  *  @speed: new link speed
  *  @autoneg_wait_to_complete: true when waiting for completion is needed
  **/
-s32 ixgbe_setup_mac_link_X540(struct ixgbe_hw *hw, ixgbe_link_speed speed,
+s32 ixgbe_setup_mac_link_X540(struct ixgbe_hw *hw,
+			      ixgbe_link_speed speed,
 			      bool autoneg_wait_to_complete)
 {
-	return hw->phy.ops.setup_link_speed(hw, speed,
-					    autoneg_wait_to_complete);
+	DEBUGFUNC("ixgbe_setup_mac_link_X540");
+	return hw->phy.ops.setup_link_speed(hw, speed, autoneg_wait_to_complete);
 }
 
 /**
@@ -89,31 +190,40 @@ s32 ixgbe_setup_mac_link_X540(struct ixgbe_hw *hw, ixgbe_link_speed speed,
  *  @hw: pointer to hardware structure
  *
  *  Resets the hardware by resetting the transmit and receive units, masks
- *  and clears all interrupts, perform a PHY reset, and perform a link (MAC)
- *  reset.
+ *  and clears all interrupts, and perform a reset.
  **/
 s32 ixgbe_reset_hw_X540(struct ixgbe_hw *hw)
 {
 	s32 status;
 	u32 ctrl, i;
+	u32 swfw_mask = hw->phy.phy_semaphore_mask;
+
+	DEBUGFUNC("ixgbe_reset_hw_X540");
 
 	/* Call adapter stop to disable tx/rx and clear interrupts */
 	status = hw->mac.ops.stop_adapter(hw);
-	if (status)
-		return status;
+	if (status != IXGBE_SUCCESS)
+		goto reset_hw_out;
 
 	/* flush pending Tx transactions */
 	ixgbe_clear_tx_pending(hw);
 
 mac_reset_top:
+	status = hw->mac.ops.acquire_swfw_sync(hw, swfw_mask);
+	if (status != IXGBE_SUCCESS) {
+		ERROR_REPORT2(IXGBE_ERROR_CAUTION,
+			"semaphore failed with %d", status);
+		return IXGBE_ERR_SWFW_SYNC;
+	}
 	ctrl = IXGBE_CTRL_RST;
 	ctrl |= IXGBE_READ_REG(hw, IXGBE_CTRL);
 	IXGBE_WRITE_REG(hw, IXGBE_CTRL, ctrl);
 	IXGBE_WRITE_FLUSH(hw);
+	hw->mac.ops.release_swfw_sync(hw, swfw_mask);
 
 	/* Poll for reset bit to self-clear indicating reset is complete */
 	for (i = 0; i < 10; i++) {
-		udelay(1);
+		usec_delay(1);
 		ctrl = IXGBE_READ_REG(hw, IXGBE_CTRL);
 		if (!(ctrl & IXGBE_CTRL_RST_MASK))
 			break;
@@ -121,9 +231,10 @@ mac_reset_top:
 
 	if (ctrl & IXGBE_CTRL_RST_MASK) {
 		status = IXGBE_ERR_RESET_FAILED;
-		hw_dbg(hw, "Reset polling failed to complete.\n");
+		ERROR_REPORT1(IXGBE_ERROR_POLLING,
+			     "Reset polling failed to complete.\n");
 	}
-	msleep(100);
+	msec_delay(100);
 
 	/*
 	 * Double resets are required for recovery from certain error
@@ -146,20 +257,24 @@ mac_reset_top:
 	 * clear the multicast table.  Also reset num_rar_entries to 128,
 	 * since we modify this value when programming the SAN MAC address.
 	 */
-	hw->mac.num_rar_entries = IXGBE_X540_MAX_TX_QUEUES;
+	hw->mac.num_rar_entries = 128;
 	hw->mac.ops.init_rx_addrs(hw);
 
 	/* Store the permanent SAN mac address */
 	hw->mac.ops.get_san_mac_addr(hw, hw->mac.san_addr);
 
 	/* Add the SAN MAC address to the RAR only if it's a valid address */
-	if (is_valid_ether_addr(hw->mac.san_addr)) {
-		hw->mac.ops.set_rar(hw, hw->mac.num_rar_entries - 1,
-				    hw->mac.san_addr, 0, IXGBE_RAH_AV);
-
+	if (ixgbe_validate_mac_addr(hw->mac.san_addr) == 0) {
 		/* Save the SAN MAC RAR index */
 		hw->mac.san_mac_rar_index = hw->mac.num_rar_entries - 1;
 
+		hw->mac.ops.set_rar(hw, hw->mac.san_mac_rar_index,
+				    hw->mac.san_addr, 0, IXGBE_RAH_AV);
+
+		/* clear VMDq pool/queue selection for this RAR */
+		hw->mac.ops.clear_vmdq(hw, hw->mac.san_mac_rar_index,
+				       IXGBE_CLEAR_VMDQ_ALL);
+
 		/* Reserve the last RAR for the SAN MAC address */
 		hw->mac.num_rar_entries--;
 	}
@@ -168,6 +283,7 @@ mac_reset_top:
 	hw->mac.ops.get_wwn_prefix(hw, &hw->mac.wwnn_prefix,
 				   &hw->mac.wwpn_prefix);
 
+reset_hw_out:
 	return status;
 }
 
@@ -181,13 +297,43 @@ mac_reset_top:
  **/
 s32 ixgbe_start_hw_X540(struct ixgbe_hw *hw)
 {
-	s32 ret_val;
+	s32 ret_val = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_start_hw_X540");
 
 	ret_val = ixgbe_start_hw_generic(hw);
-	if (ret_val)
-		return ret_val;
+	if (ret_val != IXGBE_SUCCESS)
+		goto out;
+
+	ret_val = ixgbe_start_hw_gen2(hw);
+
+out:
+	return ret_val;
+}
 
-	return ixgbe_start_hw_gen2(hw);
+/**
+ *  ixgbe_get_supported_physical_layer_X540 - Returns physical layer type
+ *  @hw: pointer to hardware structure
+ *
+ *  Determines physical layer capabilities of the current configuration.
+ **/
+u64 ixgbe_get_supported_physical_layer_X540(struct ixgbe_hw *hw)
+{
+	u64 physical_layer = IXGBE_PHYSICAL_LAYER_UNKNOWN;
+	u16 ext_ability = 0;
+
+	DEBUGFUNC("ixgbe_get_supported_physical_layer_X540");
+
+	hw->phy.ops.read_reg(hw, IXGBE_MDIO_PHY_EXT_ABILITY,
+	IXGBE_MDIO_PMA_PMD_DEV_TYPE, &ext_ability);
+	if (ext_ability & IXGBE_MDIO_PHY_10GBASET_ABILITY)
+		physical_layer |= IXGBE_PHYSICAL_LAYER_10GBASE_T;
+	if (ext_ability & IXGBE_MDIO_PHY_1000BASET_ABILITY)
+		physical_layer |= IXGBE_PHYSICAL_LAYER_1000BASE_T;
+	if (ext_ability & IXGBE_MDIO_PHY_100BASETX_ABILITY)
+		physical_layer |= IXGBE_PHYSICAL_LAYER_100BASE_TX;
+
+	return physical_layer;
 }
 
 /**
@@ -203,21 +349,23 @@ s32 ixgbe_init_eeprom_params_X540(struct ixgbe_hw *hw)
 	u32 eec;
 	u16 eeprom_size;
 
+	DEBUGFUNC("ixgbe_init_eeprom_params_X540");
+
 	if (eeprom->type == ixgbe_eeprom_uninitialized) {
 		eeprom->semaphore_delay = 10;
 		eeprom->type = ixgbe_flash;
 
-		eec = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
+		eec = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
 		eeprom_size = (u16)((eec & IXGBE_EEC_SIZE) >>
 				    IXGBE_EEC_SIZE_SHIFT);
 		eeprom->word_size = 1 << (eeprom_size +
 					  IXGBE_EEPROM_WORD_SIZE_SHIFT);
 
-		hw_dbg(hw, "Eeprom params: type = %d, size = %d\n",
-		       eeprom->type, eeprom->word_size);
+		DEBUGOUT2("Eeprom params: type = %d, size = %d\n",
+			  eeprom->type, eeprom->word_size);
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -228,21 +376,24 @@ s32 ixgbe_init_eeprom_params_X540(struct ixgbe_hw *hw)
  *
  *  Reads a 16 bit word from the EEPROM using the EERD register.
  **/
-static s32 ixgbe_read_eerd_X540(struct ixgbe_hw *hw, u16 offset, u16 *data)
+s32 ixgbe_read_eerd_X540(struct ixgbe_hw *hw, u16 offset, u16 *data)
 {
-	s32 status;
-
-	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM))
-		return IXGBE_ERR_SWFW_SYNC;
-
-	status = ixgbe_read_eerd_generic(hw, offset, data);
+	s32 status = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_read_eerd_X540");
+	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM) ==
+	    IXGBE_SUCCESS) {
+		status = ixgbe_read_eerd_generic(hw, offset, data);
+		hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
+	} else {
+		status = IXGBE_ERR_SWFW_SYNC;
+	}
 
-	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
 	return status;
 }
 
 /**
- *  ixgbe_read_eerd_buffer_X540 - Read EEPROM word(s) using EERD
+ *  ixgbe_read_eerd_buffer_X540- Read EEPROM word(s) using EERD
  *  @hw: pointer to hardware structure
  *  @offset: offset of  word in the EEPROM to read
  *  @words: number of words
@@ -250,17 +401,21 @@ static s32 ixgbe_read_eerd_X540(struct ixgbe_hw *hw, u16 offset, u16 *data)
  *
  *  Reads a 16 bit word(s) from the EEPROM using the EERD register.
  **/
-static s32 ixgbe_read_eerd_buffer_X540(struct ixgbe_hw *hw,
-				       u16 offset, u16 words, u16 *data)
+s32 ixgbe_read_eerd_buffer_X540(struct ixgbe_hw *hw,
+				u16 offset, u16 words, u16 *data)
 {
-	s32 status;
-
-	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM))
-		return IXGBE_ERR_SWFW_SYNC;
-
-	status = ixgbe_read_eerd_buffer_generic(hw, offset, words, data);
+	s32 status = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_read_eerd_buffer_X540");
+	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM) ==
+	    IXGBE_SUCCESS) {
+		status = ixgbe_read_eerd_buffer_generic(hw, offset,
+							words, data);
+		hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
+	} else {
+		status = IXGBE_ERR_SWFW_SYNC;
+	}
 
-	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
 	return status;
 }
 
@@ -272,16 +427,19 @@ static s32 ixgbe_read_eerd_buffer_X540(struct ixgbe_hw *hw,
  *
  *  Write a 16 bit word to the EEPROM using the EEWR register.
  **/
-static s32 ixgbe_write_eewr_X540(struct ixgbe_hw *hw, u16 offset, u16 data)
+s32 ixgbe_write_eewr_X540(struct ixgbe_hw *hw, u16 offset, u16 data)
 {
-	s32 status;
-
-	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM))
-		return IXGBE_ERR_SWFW_SYNC;
-
-	status = ixgbe_write_eewr_generic(hw, offset, data);
+	s32 status = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_write_eewr_X540");
+	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM) ==
+	    IXGBE_SUCCESS) {
+		status = ixgbe_write_eewr_generic(hw, offset, data);
+		hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
+	} else {
+		status = IXGBE_ERR_SWFW_SYNC;
+	}
 
-	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
 	return status;
 }
 
@@ -294,17 +452,21 @@ static s32 ixgbe_write_eewr_X540(struct ixgbe_hw *hw, u16 offset, u16 data)
  *
  *  Write a 16 bit word(s) to the EEPROM using the EEWR register.
  **/
-static s32 ixgbe_write_eewr_buffer_X540(struct ixgbe_hw *hw,
-					u16 offset, u16 words, u16 *data)
+s32 ixgbe_write_eewr_buffer_X540(struct ixgbe_hw *hw,
+				 u16 offset, u16 words, u16 *data)
 {
-	s32 status;
-
-	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM))
-		return IXGBE_ERR_SWFW_SYNC;
-
-	status = ixgbe_write_eewr_buffer_generic(hw, offset, words, data);
+	s32 status = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_write_eewr_buffer_X540");
+	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM) ==
+	    IXGBE_SUCCESS) {
+		status = ixgbe_write_eewr_buffer_generic(hw, offset,
+							 words, data);
+		hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
+	} else {
+		status = IXGBE_ERR_SWFW_SYNC;
+	}
 
-	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
 	return status;
 }
 
@@ -315,35 +477,37 @@ static s32 ixgbe_write_eewr_buffer_X540(struct ixgbe_hw *hw,
  *  be used internally by function which utilize ixgbe_acquire_swfw_sync_X540.
  *
  *  @hw: pointer to hardware structure
+ *
+ *  Returns a negative error code on error, or the 16-bit checksum
  **/
-static s32 ixgbe_calc_eeprom_checksum_X540(struct ixgbe_hw *hw)
+s32 ixgbe_calc_eeprom_checksum_X540(struct ixgbe_hw *hw)
 {
-	u16 i;
-	u16 j;
+	u16 i, j;
 	u16 checksum = 0;
 	u16 length = 0;
 	u16 pointer = 0;
 	u16 word = 0;
-	u16 checksum_last_word = IXGBE_EEPROM_CHECKSUM;
 	u16 ptr_start = IXGBE_PCIE_ANALOG_PTR;
 
-	/*
-	 * Do not use hw->eeprom.ops.read because we do not want to take
+	/* Do not use hw->eeprom.ops.read because we do not want to take
 	 * the synchronization semaphores here. Instead use
 	 * ixgbe_read_eerd_generic
 	 */
 
-	/* Include 0x0-0x3F in the checksum */
-	for (i = 0; i < checksum_last_word; i++) {
+	DEBUGFUNC("ixgbe_calc_eeprom_checksum_X540");
+
+	/* Include 0x0 up to IXGBE_EEPROM_CHECKSUM; do not include the
+	 * checksum itself
+	 */
+	for (i = 0; i < IXGBE_EEPROM_CHECKSUM; i++) {
 		if (ixgbe_read_eerd_generic(hw, i, &word)) {
-			hw_dbg(hw, "EEPROM read failed\n");
+			DEBUGOUT("EEPROM read failed\n");
 			return IXGBE_ERR_EEPROM;
 		}
 		checksum += word;
 	}
 
-	/*
-	 * Include all data from pointers 0x3, 0x6-0xE.  This excludes the
+	/* Include all data from pointers 0x3, 0x6-0xE.  This excludes the
 	 * FW, PHY module, and PCIe Expansion/Option ROM pointers.
 	 */
 	for (i = ptr_start; i < IXGBE_FW_PTR; i++) {
@@ -351,8 +515,8 @@ static s32 ixgbe_calc_eeprom_checksum_X540(struct ixgbe_hw *hw)
 			continue;
 
 		if (ixgbe_read_eerd_generic(hw, i, &pointer)) {
-			hw_dbg(hw, "EEPROM read failed\n");
-			break;
+			DEBUGOUT("EEPROM read failed\n");
+			return IXGBE_ERR_EEPROM;
 		}
 
 		/* Skip pointer section if the pointer is invalid. */
@@ -361,9 +525,8 @@ static s32 ixgbe_calc_eeprom_checksum_X540(struct ixgbe_hw *hw)
 			continue;
 
 		if (ixgbe_read_eerd_generic(hw, pointer, &length)) {
-			hw_dbg(hw, "EEPROM read failed\n");
+			DEBUGOUT("EEPROM read failed\n");
 			return IXGBE_ERR_EEPROM;
-			break;
 		}
 
 		/* Skip pointer section if length is invalid. */
@@ -373,7 +536,7 @@ static s32 ixgbe_calc_eeprom_checksum_X540(struct ixgbe_hw *hw)
 
 		for (j = pointer + 1; j <= pointer + length; j++) {
 			if (ixgbe_read_eerd_generic(hw, j, &word)) {
-				hw_dbg(hw, "EEPROM read failed\n");
+				DEBUGOUT("EEPROM read failed\n");
 				return IXGBE_ERR_EEPROM;
 			}
 			checksum += word;
@@ -393,20 +556,22 @@ static s32 ixgbe_calc_eeprom_checksum_X540(struct ixgbe_hw *hw)
  *  Performs checksum calculation and validates the EEPROM checksum.  If the
  *  caller does not need checksum_val, the value can be NULL.
  **/
-static s32 ixgbe_validate_eeprom_checksum_X540(struct ixgbe_hw *hw,
-					       u16 *checksum_val)
+s32 ixgbe_validate_eeprom_checksum_X540(struct ixgbe_hw *hw,
+					u16 *checksum_val)
 {
 	s32 status;
 	u16 checksum;
 	u16 read_checksum = 0;
 
+	DEBUGFUNC("ixgbe_validate_eeprom_checksum_X540");
+
 	/* Read the first word from the EEPROM. If this times out or fails, do
 	 * not continue or we could be in for a very long wait while every
 	 * EEPROM read fails
 	 */
 	status = hw->eeprom.ops.read(hw, 0, &checksum);
 	if (status) {
-		hw_dbg(hw, "EEPROM read failed\n");
+		DEBUGOUT("EEPROM read failed\n");
 		return status;
 	}
 
@@ -431,7 +596,8 @@ static s32 ixgbe_validate_eeprom_checksum_X540(struct ixgbe_hw *hw,
 	 * calculated checksum
 	 */
 	if (read_checksum != checksum) {
-		hw_dbg(hw, "Invalid EEPROM checksum");
+		ERROR_REPORT1(IXGBE_ERROR_INVALID_STATE,
+			     "Invalid EEPROM checksum");
 		status = IXGBE_ERR_EEPROM_CHECKSUM;
 	}
 
@@ -453,23 +619,25 @@ out:
  * checksum and updates the EEPROM and instructs the hardware to update
  * the flash.
  **/
-static s32 ixgbe_update_eeprom_checksum_X540(struct ixgbe_hw *hw)
+s32 ixgbe_update_eeprom_checksum_X540(struct ixgbe_hw *hw)
 {
 	s32 status;
 	u16 checksum;
 
+	DEBUGFUNC("ixgbe_update_eeprom_checksum_X540");
+
 	/* Read the first word from the EEPROM. If this times out or fails, do
 	 * not continue or we could be in for a very long wait while every
 	 * EEPROM read fails
 	 */
 	status = hw->eeprom.ops.read(hw, 0, &checksum);
 	if (status) {
-		hw_dbg(hw, "EEPROM read failed\n");
+		DEBUGOUT("EEPROM read failed\n");
 		return status;
 	}
 
 	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM))
-		return  IXGBE_ERR_SWFW_SYNC;
+		return IXGBE_ERR_SWFW_SYNC;
 
 	status = hw->eeprom.ops.calc_checksum(hw);
 	if (status < 0)
@@ -488,129 +656,143 @@ static s32 ixgbe_update_eeprom_checksum_X540(struct ixgbe_hw *hw)
 
 out:
 	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
+
 	return status;
 }
 
 /**
- * ixgbe_update_flash_X540 - Instruct HW to copy EEPROM to Flash device
- * @hw: pointer to hardware structure
+ *  ixgbe_update_flash_X540 - Instruct HW to copy EEPROM to Flash device
+ *  @hw: pointer to hardware structure
  *
- * Set FLUP (bit 23) of the EEC register to instruct Hardware to copy
- * EEPROM from shadow RAM to the flash device.
+ *  Set FLUP (bit 23) of the EEC register to instruct Hardware to copy
+ *  EEPROM from shadow RAM to the flash device.
  **/
-static s32 ixgbe_update_flash_X540(struct ixgbe_hw *hw)
+s32 ixgbe_update_flash_X540(struct ixgbe_hw *hw)
 {
 	u32 flup;
 	s32 status;
 
+	DEBUGFUNC("ixgbe_update_flash_X540");
+
 	status = ixgbe_poll_flash_update_done_X540(hw);
 	if (status == IXGBE_ERR_EEPROM) {
-		hw_dbg(hw, "Flash update time out\n");
-		return status;
+		DEBUGOUT("Flash update time out\n");
+		goto out;
 	}
 
-	flup = IXGBE_READ_REG(hw, IXGBE_EEC(hw)) | IXGBE_EEC_FLUP;
-	IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), flup);
+	flup = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw)) | IXGBE_EEC_FLUP;
+	IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), flup);
 
 	status = ixgbe_poll_flash_update_done_X540(hw);
-	if (status == 0)
-		hw_dbg(hw, "Flash update complete\n");
+	if (status == IXGBE_SUCCESS)
+		DEBUGOUT("Flash update complete\n");
 	else
-		hw_dbg(hw, "Flash update time out\n");
+		DEBUGOUT("Flash update time out\n");
 
-	if (hw->revision_id == 0) {
-		flup = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
+	if (hw->mac.type == ixgbe_mac_X540 && hw->revision_id == 0) {
+		flup = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
 
 		if (flup & IXGBE_EEC_SEC1VAL) {
 			flup |= IXGBE_EEC_FLUP;
-			IXGBE_WRITE_REG(hw, IXGBE_EEC(hw), flup);
+			IXGBE_WRITE_REG(hw, IXGBE_EEC_BY_MAC(hw), flup);
 		}
 
 		status = ixgbe_poll_flash_update_done_X540(hw);
-		if (status == 0)
-			hw_dbg(hw, "Flash update complete\n");
+		if (status == IXGBE_SUCCESS)
+			DEBUGOUT("Flash update complete\n");
 		else
-			hw_dbg(hw, "Flash update time out\n");
+			DEBUGOUT("Flash update time out\n");
 	}
-
+out:
 	return status;
 }
 
 /**
- * ixgbe_poll_flash_update_done_X540 - Poll flash update status
- * @hw: pointer to hardware structure
+ *  ixgbe_poll_flash_update_done_X540 - Poll flash update status
+ *  @hw: pointer to hardware structure
  *
- * Polls the FLUDONE (bit 26) of the EEC Register to determine when the
- * flash update is done.
+ *  Polls the FLUDONE (bit 26) of the EEC Register to determine when the
+ *  flash update is done.
  **/
-static s32 ixgbe_poll_flash_update_done_X540(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_poll_flash_update_done_X540(struct ixgbe_hw *hw)
 {
 	u32 i;
 	u32 reg;
+	s32 status = IXGBE_ERR_EEPROM;
+
+	DEBUGFUNC("ixgbe_poll_flash_update_done_X540");
 
 	for (i = 0; i < IXGBE_FLUDONE_ATTEMPTS; i++) {
-		reg = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
-		if (reg & IXGBE_EEC_FLUDONE)
-			return 0;
-		udelay(5);
+		reg = IXGBE_READ_REG(hw, IXGBE_EEC_BY_MAC(hw));
+		if (reg & IXGBE_EEC_FLUDONE) {
+			status = IXGBE_SUCCESS;
+			break;
+		}
+		msec_delay(5);
 	}
-	return IXGBE_ERR_EEPROM;
+
+	if (i == IXGBE_FLUDONE_ATTEMPTS)
+		ERROR_REPORT1(IXGBE_ERROR_POLLING,
+			     "Flash update status polling timed out");
+
+	return status;
 }
 
 /**
- * ixgbe_acquire_swfw_sync_X540 - Acquire SWFW semaphore
- * @hw: pointer to hardware structure
- * @mask: Mask to specify which semaphore to acquire
+ *  ixgbe_acquire_swfw_sync_X540 - Acquire SWFW semaphore
+ *  @hw: pointer to hardware structure
+ *  @mask: Mask to specify which semaphore to acquire
  *
- * Acquires the SWFW semaphore thought the SW_FW_SYNC register for
- * the specified function (CSR, PHY0, PHY1, NVM, Flash)
+ *  Acquires the SWFW semaphore thought the SW_FW_SYNC register for
+ *  the specified function (CSR, PHY0, PHY1, NVM, Flash)
  **/
 s32 ixgbe_acquire_swfw_sync_X540(struct ixgbe_hw *hw, u32 mask)
 {
 	u32 swmask = mask & IXGBE_GSSR_NVM_PHY_MASK;
-	u32 swi2c_mask = mask & IXGBE_GSSR_I2C_MASK;
 	u32 fwmask = swmask << 5;
+	u32 swi2c_mask = mask & IXGBE_GSSR_I2C_MASK;
 	u32 timeout = 200;
 	u32 hwmask = 0;
 	u32 swfw_sync;
 	u32 i;
 
+	DEBUGFUNC("ixgbe_acquire_swfw_sync_X540");
+
 	if (swmask & IXGBE_GSSR_EEP_SM)
-		hwmask = IXGBE_GSSR_FLASH_SM;
+		hwmask |= IXGBE_GSSR_FLASH_SM;
 
-	/* SW only mask does not have FW bit pair */
+	/* SW only mask doesn't have FW bit pair */
 	if (mask & IXGBE_GSSR_SW_MNG_SM)
 		swmask |= IXGBE_GSSR_SW_MNG_SM;
 
 	swmask |= swi2c_mask;
 	fwmask |= swi2c_mask << 2;
+	if (hw->mac.type == ixgbe_mac_X550)
+		timeout = 1000;
+
 	for (i = 0; i < timeout; i++) {
 		/* SW NVM semaphore bit is used for access to all
 		 * SW_FW_SYNC bits (not just NVM)
 		 */
-		if (ixgbe_get_swfw_sync_semaphore(hw))
+		if (ixgbe_get_swfw_sync_semaphore(hw)) {
+			DEBUGOUT("Failed to get NVM access and register semaphore, returning IXGBE_ERR_SWFW_SYNC\n");
 			return IXGBE_ERR_SWFW_SYNC;
+		}
 
-		swfw_sync = IXGBE_READ_REG(hw, IXGBE_SWFW_SYNC(hw));
+		swfw_sync = IXGBE_READ_REG(hw, IXGBE_SWFW_SYNC_BY_MAC(hw));
 		if (!(swfw_sync & (fwmask | swmask | hwmask))) {
 			swfw_sync |= swmask;
-			IXGBE_WRITE_REG(hw, IXGBE_SWFW_SYNC(hw), swfw_sync);
+			IXGBE_WRITE_REG(hw, IXGBE_SWFW_SYNC_BY_MAC(hw),
+					swfw_sync);
 			ixgbe_release_swfw_sync_semaphore(hw);
-			usleep_range(5000, 6000);
-			return 0;
+			return IXGBE_SUCCESS;
 		}
 		/* Firmware currently using resource (fwmask), hardware
 		 * currently using resource (hwmask), or other software
 		 * thread currently using resource (swmask)
 		 */
 		ixgbe_release_swfw_sync_semaphore(hw);
-		usleep_range(5000, 10000);
-	}
-
-	/* Failed to get SW only semaphore */
-	if (swmask == IXGBE_GSSR_SW_MNG_SM) {
-		hw_dbg(hw, "Failed to get SW only semaphore\n");
-		return IXGBE_ERR_SWFW_SYNC;
+		msec_delay(5);
 	}
 
 	/* If the resource is not released by the FW/HW the SW can assume that
@@ -618,15 +800,17 @@ s32 ixgbe_acquire_swfw_sync_X540(struct ixgbe_hw *hw, u32 mask)
 	 * of the requested resource(s) while ignoring the corresponding FW/HW
 	 * bits in the SW_FW_SYNC register.
 	 */
-	if (ixgbe_get_swfw_sync_semaphore(hw))
+	if (ixgbe_get_swfw_sync_semaphore(hw)) {
+		DEBUGOUT("Failed to get NVM sempahore and register semaphore while forcefully ignoring FW sempahore bit(s) and setting SW semaphore bit(s), returning IXGBE_ERR_SWFW_SYNC\n");
 		return IXGBE_ERR_SWFW_SYNC;
-	swfw_sync = IXGBE_READ_REG(hw, IXGBE_SWFW_SYNC(hw));
+	}
+	swfw_sync = IXGBE_READ_REG(hw, IXGBE_SWFW_SYNC_BY_MAC(hw));
 	if (swfw_sync & (fwmask | hwmask)) {
 		swfw_sync |= swmask;
-		IXGBE_WRITE_REG(hw, IXGBE_SWFW_SYNC(hw), swfw_sync);
+		IXGBE_WRITE_REG(hw, IXGBE_SWFW_SYNC_BY_MAC(hw), swfw_sync);
 		ixgbe_release_swfw_sync_semaphore(hw);
-		usleep_range(5000, 6000);
-		return 0;
+		msec_delay(5);
+		return IXGBE_SUCCESS;
 	}
 	/* If the resource is not released by other SW the SW can assume that
 	 * the other SW malfunctions. In that case the SW should clear all SW
@@ -635,114 +819,163 @@ s32 ixgbe_acquire_swfw_sync_X540(struct ixgbe_hw *hw, u32 mask)
 	 */
 	if (swfw_sync & swmask) {
 		u32 rmask = IXGBE_GSSR_EEP_SM | IXGBE_GSSR_PHY0_SM |
-			    IXGBE_GSSR_PHY1_SM | IXGBE_GSSR_MAC_CSR_SM;
+			    IXGBE_GSSR_PHY1_SM | IXGBE_GSSR_MAC_CSR_SM |
+			    IXGBE_GSSR_SW_MNG_SM;
 
 		if (swi2c_mask)
 			rmask |= IXGBE_GSSR_I2C_MASK;
 		ixgbe_release_swfw_sync_X540(hw, rmask);
 		ixgbe_release_swfw_sync_semaphore(hw);
+		DEBUGOUT("Resource not released by other SW, returning IXGBE_ERR_SWFW_SYNC\n");
 		return IXGBE_ERR_SWFW_SYNC;
 	}
 	ixgbe_release_swfw_sync_semaphore(hw);
+	DEBUGOUT("Returning error IXGBE_ERR_SWFW_SYNC\n");
 
 	return IXGBE_ERR_SWFW_SYNC;
 }
 
 /**
- * ixgbe_release_swfw_sync_X540 - Release SWFW semaphore
- * @hw: pointer to hardware structure
- * @mask: Mask to specify which semaphore to release
+ *  ixgbe_release_swfw_sync_X540 - Release SWFW semaphore
+ *  @hw: pointer to hardware structure
+ *  @mask: Mask to specify which semaphore to release
  *
- * Releases the SWFW semaphore through the SW_FW_SYNC register
- * for the specified function (CSR, PHY0, PHY1, EVM, Flash)
+ *  Releases the SWFW semaphore through the SW_FW_SYNC register
+ *  for the specified function (CSR, PHY0, PHY1, EVM, Flash)
  **/
 void ixgbe_release_swfw_sync_X540(struct ixgbe_hw *hw, u32 mask)
 {
 	u32 swmask = mask & (IXGBE_GSSR_NVM_PHY_MASK | IXGBE_GSSR_SW_MNG_SM);
 	u32 swfw_sync;
 
+	DEBUGFUNC("ixgbe_release_swfw_sync_X540");
+
 	if (mask & IXGBE_GSSR_I2C_MASK)
 		swmask |= mask & IXGBE_GSSR_I2C_MASK;
 	ixgbe_get_swfw_sync_semaphore(hw);
 
-	swfw_sync = IXGBE_READ_REG(hw, IXGBE_SWFW_SYNC(hw));
+	swfw_sync = IXGBE_READ_REG(hw, IXGBE_SWFW_SYNC_BY_MAC(hw));
 	swfw_sync &= ~swmask;
-	IXGBE_WRITE_REG(hw, IXGBE_SWFW_SYNC(hw), swfw_sync);
+	IXGBE_WRITE_REG(hw, IXGBE_SWFW_SYNC_BY_MAC(hw), swfw_sync);
 
 	ixgbe_release_swfw_sync_semaphore(hw);
-	usleep_range(5000, 6000);
+	msec_delay(2);
 }
 
 /**
- * ixgbe_get_swfw_sync_semaphore - Get hardware semaphore
- * @hw: pointer to hardware structure
+ *  ixgbe_get_swfw_sync_semaphore - Get hardware semaphore
+ *  @hw: pointer to hardware structure
  *
- * Sets the hardware semaphores so SW/FW can gain control of shared resources
- */
-static s32 ixgbe_get_swfw_sync_semaphore(struct ixgbe_hw *hw)
+ *  Sets the hardware semaphores so SW/FW can gain control of shared resources
+ **/
+STATIC s32 ixgbe_get_swfw_sync_semaphore(struct ixgbe_hw *hw)
 {
+	s32 status = IXGBE_ERR_EEPROM;
 	u32 timeout = 2000;
 	u32 i;
 	u32 swsm;
 
+	DEBUGFUNC("ixgbe_get_swfw_sync_semaphore");
+
 	/* Get SMBI software semaphore between device drivers first */
 	for (i = 0; i < timeout; i++) {
-		/* If the SMBI bit is 0 when we read it, then the bit will be
+		/*
+		 * If the SMBI bit is 0 when we read it, then the bit will be
 		 * set and we have the semaphore
 		 */
-		swsm = IXGBE_READ_REG(hw, IXGBE_SWSM(hw));
-		if (!(swsm & IXGBE_SWSM_SMBI))
+		swsm = IXGBE_READ_REG(hw, IXGBE_SWSM_BY_MAC(hw));
+		if (!(swsm & IXGBE_SWSM_SMBI)) {
+			status = IXGBE_SUCCESS;
 			break;
-		usleep_range(50, 100);
-	}
-
-	if (i == timeout) {
-		hw_dbg(hw,
-		       "Software semaphore SMBI between device drivers not granted.\n");
-		return IXGBE_ERR_EEPROM;
+		}
+		usec_delay(50);
 	}
 
 	/* Now get the semaphore between SW/FW through the REGSMP bit */
-	for (i = 0; i < timeout; i++) {
-		swsm = IXGBE_READ_REG(hw, IXGBE_SWFW_SYNC(hw));
-		if (!(swsm & IXGBE_SWFW_REGSMP))
-			return 0;
+	if (status == IXGBE_SUCCESS) {
+		for (i = 0; i < timeout; i++) {
+			swsm = IXGBE_READ_REG(hw, IXGBE_SWFW_SYNC_BY_MAC(hw));
+			if (!(swsm & IXGBE_SWFW_REGSMP))
+				break;
 
-		usleep_range(50, 100);
+			usec_delay(50);
+		}
+
+		/*
+		 * Release semaphores and return error if SW NVM semaphore
+		 * was not granted because we don't have access to the EEPROM
+		 */
+		if (i >= timeout) {
+			ERROR_REPORT1(IXGBE_ERROR_POLLING,
+				"REGSMP Software NVM semaphore not granted.\n");
+			ixgbe_release_swfw_sync_semaphore(hw);
+			status = IXGBE_ERR_EEPROM;
+		}
+	} else {
+		ERROR_REPORT1(IXGBE_ERROR_POLLING,
+			     "Software semaphore SMBI between device drivers "
+			     "not granted.\n");
 	}
 
-	/* Release semaphores and return error if SW NVM semaphore
-	 * was not granted because we do not have access to the EEPROM
-	 */
-	hw_dbg(hw, "REGSMP Software NVM semaphore not granted\n");
-	ixgbe_release_swfw_sync_semaphore(hw);
-	return IXGBE_ERR_EEPROM;
+	return status;
 }
 
 /**
- * ixgbe_release_nvm_semaphore - Release hardware semaphore
- * @hw: pointer to hardware structure
+ *  ixgbe_release_swfw_sync_semaphore - Release hardware semaphore
+ *  @hw: pointer to hardware structure
  *
- * This function clears hardware semaphore bits.
+ *  This function clears hardware semaphore bits.
  **/
-static void ixgbe_release_swfw_sync_semaphore(struct ixgbe_hw *hw)
+STATIC void ixgbe_release_swfw_sync_semaphore(struct ixgbe_hw *hw)
 {
-	 u32 swsm;
+	u32 swsm;
+
+	DEBUGFUNC("ixgbe_release_swfw_sync_semaphore");
 
 	/* Release both semaphores by writing 0 to the bits REGSMP and SMBI */
 
-	swsm = IXGBE_READ_REG(hw, IXGBE_SWFW_SYNC(hw));
+	swsm = IXGBE_READ_REG(hw, IXGBE_SWFW_SYNC_BY_MAC(hw));
 	swsm &= ~IXGBE_SWFW_REGSMP;
-	IXGBE_WRITE_REG(hw, IXGBE_SWFW_SYNC(hw), swsm);
+	IXGBE_WRITE_REG(hw, IXGBE_SWFW_SYNC_BY_MAC(hw), swsm);
 
-	swsm = IXGBE_READ_REG(hw, IXGBE_SWSM(hw));
+	swsm = IXGBE_READ_REG(hw, IXGBE_SWSM_BY_MAC(hw));
 	swsm &= ~IXGBE_SWSM_SMBI;
-	IXGBE_WRITE_REG(hw, IXGBE_SWSM(hw), swsm);
+	IXGBE_WRITE_REG(hw, IXGBE_SWSM_BY_MAC(hw), swsm);
 
 	IXGBE_WRITE_FLUSH(hw);
 }
 
 /**
+ *  ixgbe_init_swfw_sync_X540 - Release hardware semaphore
+ *  @hw: pointer to hardware structure
+ *
+ *  This function reset hardware semaphore bits for a semaphore that may
+ *  have be left locked due to a catastrophic failure.
+ **/
+void ixgbe_init_swfw_sync_X540(struct ixgbe_hw *hw)
+{
+	u32 rmask;
+
+	/* First try to grab the semaphore but we don't need to bother
+	 * looking to see whether we got the lock or not since we do
+	 * the same thing regardless of whether we got the lock or not.
+	 * We got the lock - we release it.
+	 * We timeout trying to get the lock - we force its release.
+	 */
+	ixgbe_get_swfw_sync_semaphore(hw);
+	ixgbe_release_swfw_sync_semaphore(hw);
+
+	/* Acquire and release all software resources. */
+	rmask = IXGBE_GSSR_EEP_SM | IXGBE_GSSR_PHY0_SM |
+		IXGBE_GSSR_PHY1_SM | IXGBE_GSSR_MAC_CSR_SM |
+		IXGBE_GSSR_SW_MNG_SM;
+
+	rmask |= IXGBE_GSSR_I2C_MASK;
+	ixgbe_acquire_swfw_sync_X540(hw, rmask);
+	ixgbe_release_swfw_sync_X540(hw, rmask);
+}
+
+/**
  * ixgbe_blink_led_start_X540 - Blink LED based on index.
  * @hw: pointer to hardware structure
  * @index: led number to blink
@@ -757,13 +990,18 @@ s32 ixgbe_blink_led_start_X540(struct ixgbe_hw *hw, u32 index)
 	ixgbe_link_speed speed;
 	bool link_up;
 
+	DEBUGFUNC("ixgbe_blink_led_start_X540");
+
+	if (index > 3)
+		return IXGBE_ERR_PARAM;
+
 	/*
 	 * Link should be up in order for the blink bit in the LED control
 	 * register to work. Force link and speed in the MAC if link is down.
 	 * This will be reversed when we stop the blinking.
 	 */
 	hw->mac.ops.check_link(hw, &speed, &link_up, false);
-	if (!link_up) {
+	if (link_up == false) {
 		macc_reg = IXGBE_READ_REG(hw, IXGBE_MACC);
 		macc_reg |= IXGBE_MACC_FLU | IXGBE_MACC_FSV_10G | IXGBE_MACC_FS;
 		IXGBE_WRITE_REG(hw, IXGBE_MACC, macc_reg);
@@ -775,7 +1013,7 @@ s32 ixgbe_blink_led_start_X540(struct ixgbe_hw *hw, u32 index)
 	IXGBE_WRITE_REG(hw, IXGBE_LEDCTL, ledctl_reg);
 	IXGBE_WRITE_FLUSH(hw);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -791,6 +1029,11 @@ s32 ixgbe_blink_led_stop_X540(struct ixgbe_hw *hw, u32 index)
 	u32 macc_reg;
 	u32 ledctl_reg;
 
+	if (index > 3)
+		return IXGBE_ERR_PARAM;
+
+	DEBUGFUNC("ixgbe_blink_led_stop_X540");
+
 	/* Restore the LED to its default value. */
 	ledctl_reg = IXGBE_READ_REG(hw, IXGBE_LEDCTL);
 	ledctl_reg &= ~IXGBE_LED_MODE_MASK(index);
@@ -804,101 +1047,5 @@ s32 ixgbe_blink_led_stop_X540(struct ixgbe_hw *hw, u32 index)
 	IXGBE_WRITE_REG(hw, IXGBE_MACC, macc_reg);
 	IXGBE_WRITE_FLUSH(hw);
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
-static struct ixgbe_mac_operations mac_ops_X540 = {
-	.init_hw                = &ixgbe_init_hw_generic,
-	.reset_hw               = &ixgbe_reset_hw_X540,
-	.start_hw               = &ixgbe_start_hw_X540,
-	.clear_hw_cntrs         = &ixgbe_clear_hw_cntrs_generic,
-	.get_media_type         = &ixgbe_get_media_type_X540,
-	.enable_rx_dma          = &ixgbe_enable_rx_dma_generic,
-	.get_mac_addr           = &ixgbe_get_mac_addr_generic,
-	.get_san_mac_addr       = &ixgbe_get_san_mac_addr_generic,
-	.get_device_caps        = &ixgbe_get_device_caps_generic,
-	.get_wwn_prefix         = &ixgbe_get_wwn_prefix_generic,
-	.stop_adapter           = &ixgbe_stop_adapter_generic,
-	.get_bus_info           = &ixgbe_get_bus_info_generic,
-	.set_lan_id             = &ixgbe_set_lan_id_multi_port_pcie,
-	.read_analog_reg8       = NULL,
-	.write_analog_reg8      = NULL,
-	.setup_link             = &ixgbe_setup_mac_link_X540,
-	.set_rxpba		= &ixgbe_set_rxpba_generic,
-	.check_link             = &ixgbe_check_mac_link_generic,
-	.get_link_capabilities  = &ixgbe_get_copper_link_capabilities_generic,
-	.led_on                 = &ixgbe_led_on_generic,
-	.led_off                = &ixgbe_led_off_generic,
-	.blink_led_start        = &ixgbe_blink_led_start_X540,
-	.blink_led_stop         = &ixgbe_blink_led_stop_X540,
-	.set_rar                = &ixgbe_set_rar_generic,
-	.clear_rar              = &ixgbe_clear_rar_generic,
-	.set_vmdq               = &ixgbe_set_vmdq_generic,
-	.set_vmdq_san_mac	= &ixgbe_set_vmdq_san_mac_generic,
-	.clear_vmdq             = &ixgbe_clear_vmdq_generic,
-	.init_rx_addrs          = &ixgbe_init_rx_addrs_generic,
-	.update_mc_addr_list    = &ixgbe_update_mc_addr_list_generic,
-	.enable_mc              = &ixgbe_enable_mc_generic,
-	.disable_mc             = &ixgbe_disable_mc_generic,
-	.clear_vfta             = &ixgbe_clear_vfta_generic,
-	.set_vfta               = &ixgbe_set_vfta_generic,
-	.fc_enable              = &ixgbe_fc_enable_generic,
-	.set_fw_drv_ver         = &ixgbe_set_fw_drv_ver_generic,
-	.init_uta_tables        = &ixgbe_init_uta_tables_generic,
-	.setup_sfp              = NULL,
-	.set_mac_anti_spoofing  = &ixgbe_set_mac_anti_spoofing,
-	.set_vlan_anti_spoofing = &ixgbe_set_vlan_anti_spoofing,
-	.acquire_swfw_sync      = &ixgbe_acquire_swfw_sync_X540,
-	.release_swfw_sync      = &ixgbe_release_swfw_sync_X540,
-	.disable_rx_buff	= &ixgbe_disable_rx_buff_generic,
-	.enable_rx_buff		= &ixgbe_enable_rx_buff_generic,
-	.get_thermal_sensor_data = NULL,
-	.init_thermal_sensor_thresh = NULL,
-	.prot_autoc_read	= &prot_autoc_read_generic,
-	.prot_autoc_write	= &prot_autoc_write_generic,
-	.enable_rx		= &ixgbe_enable_rx_generic,
-	.disable_rx		= &ixgbe_disable_rx_generic,
-};
-
-static struct ixgbe_eeprom_operations eeprom_ops_X540 = {
-	.init_params            = &ixgbe_init_eeprom_params_X540,
-	.read                   = &ixgbe_read_eerd_X540,
-	.read_buffer		= &ixgbe_read_eerd_buffer_X540,
-	.write                  = &ixgbe_write_eewr_X540,
-	.write_buffer		= &ixgbe_write_eewr_buffer_X540,
-	.calc_checksum		= &ixgbe_calc_eeprom_checksum_X540,
-	.validate_checksum      = &ixgbe_validate_eeprom_checksum_X540,
-	.update_checksum        = &ixgbe_update_eeprom_checksum_X540,
-};
-
-static struct ixgbe_phy_operations phy_ops_X540 = {
-	.identify               = &ixgbe_identify_phy_generic,
-	.identify_sfp           = &ixgbe_identify_sfp_module_generic,
-	.init			= NULL,
-	.reset                  = NULL,
-	.read_reg               = &ixgbe_read_phy_reg_generic,
-	.write_reg              = &ixgbe_write_phy_reg_generic,
-	.setup_link             = &ixgbe_setup_phy_link_generic,
-	.setup_link_speed       = &ixgbe_setup_phy_link_speed_generic,
-	.read_i2c_byte          = &ixgbe_read_i2c_byte_generic,
-	.write_i2c_byte         = &ixgbe_write_i2c_byte_generic,
-	.read_i2c_sff8472	= &ixgbe_read_i2c_sff8472_generic,
-	.read_i2c_eeprom        = &ixgbe_read_i2c_eeprom_generic,
-	.write_i2c_eeprom       = &ixgbe_write_i2c_eeprom_generic,
-	.check_overtemp         = &ixgbe_tn_check_overtemp,
-	.set_phy_power          = &ixgbe_set_copper_phy_power,
-	.get_firmware_version   = &ixgbe_get_phy_firmware_version_generic,
-};
-
-static const u32 ixgbe_mvals_X540[IXGBE_MVALS_IDX_LIMIT] = {
-	IXGBE_MVALS_INIT(X540)
-};
-
-struct ixgbe_info ixgbe_X540_info = {
-	.mac                    = ixgbe_mac_X540,
-	.get_invariants         = &ixgbe_get_invariants_X540,
-	.mac_ops                = &mac_ops_X540,
-	.eeprom_ops             = &eeprom_ops_X540,
-	.phy_ops                = &phy_ops_X540,
-	.mbx_ops                = &mbx_ops_generic,
-	.mvals			= ixgbe_mvals_X540,
-};
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_x540.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_x540.h
index a1468b1..4cace85 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_x540.h
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_x540.h
@@ -1,39 +1,58 @@
 /*******************************************************************************
- *
- * Intel 10 Gigabit PCI Express Linux driver
- *  Copyright(c) 1999 - 2014 Intel Corporation.
- *
- *  This program is free software; you can redistribute it and/or modify it
- *  under the terms and conditions of the GNU General Public License,
- *  version 2, as published by the Free Software Foundation.
- *
- *  This program is distributed in the hope it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- *  more details.
- *
- *  The full GNU General Public License is included in this distribution in
- *  the file called "COPYING".
- *
- *  Contact Information:
- *  Linux NICS <linux.nics@intel.com>
- *  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
- *  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
- *
- *****************************************************************************/
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#ifndef _IXGBE_X540_H_
+#define _IXGBE_X540_H_
 
 #include "ixgbe_type.h"
 
-s32 ixgbe_get_invariants_X540(struct ixgbe_hw *hw);
+s32 ixgbe_get_link_capabilities_X540(struct ixgbe_hw *hw,
+				     ixgbe_link_speed *speed, bool *autoneg);
+enum ixgbe_media_type ixgbe_get_media_type_X540(struct ixgbe_hw *hw);
 s32 ixgbe_setup_mac_link_X540(struct ixgbe_hw *hw, ixgbe_link_speed speed,
-			      bool autoneg_wait_to_complete);
+			      bool link_up_wait_to_complete);
 s32 ixgbe_reset_hw_X540(struct ixgbe_hw *hw);
 s32 ixgbe_start_hw_X540(struct ixgbe_hw *hw);
-enum ixgbe_media_type ixgbe_get_media_type_X540(struct ixgbe_hw *hw);
-s32 ixgbe_setup_mac_link_X540(struct ixgbe_hw *hw, ixgbe_link_speed speed,
-			      bool autoneg_wait_to_complete);
-s32 ixgbe_blink_led_start_X540(struct ixgbe_hw *hw, u32 index);
-s32 ixgbe_blink_led_stop_X540(struct ixgbe_hw *hw, u32 index);
+u64 ixgbe_get_supported_physical_layer_X540(struct ixgbe_hw *hw);
+
+s32 ixgbe_init_eeprom_params_X540(struct ixgbe_hw *hw);
+s32 ixgbe_read_eerd_X540(struct ixgbe_hw *hw, u16 offset, u16 *data);
+s32 ixgbe_read_eerd_buffer_X540(struct ixgbe_hw *hw, u16 offset, u16 words,
+				u16 *data);
+s32 ixgbe_write_eewr_X540(struct ixgbe_hw *hw, u16 offset, u16 data);
+s32 ixgbe_write_eewr_buffer_X540(struct ixgbe_hw *hw, u16 offset, u16 words,
+				 u16 *data);
+s32 ixgbe_update_eeprom_checksum_X540(struct ixgbe_hw *hw);
+s32 ixgbe_validate_eeprom_checksum_X540(struct ixgbe_hw *hw, u16 *checksum_val);
+s32 ixgbe_calc_eeprom_checksum_X540(struct ixgbe_hw *hw);
+s32 ixgbe_update_flash_X540(struct ixgbe_hw *hw);
+
 s32 ixgbe_acquire_swfw_sync_X540(struct ixgbe_hw *hw, u32 mask);
 void ixgbe_release_swfw_sync_X540(struct ixgbe_hw *hw, u32 mask);
-s32 ixgbe_init_eeprom_params_X540(struct ixgbe_hw *hw);
+void ixgbe_init_swfw_sync_X540(struct ixgbe_hw *hw);
+
+s32 ixgbe_blink_led_start_X540(struct ixgbe_hw *hw, u32 index);
+s32 ixgbe_blink_led_stop_X540(struct ixgbe_hw *hw, u32 index);
+#endif /* _IXGBE_X540_H_ */
+
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_x550.c b/drivers/net/ethernet/intel/ixgbe/ixgbe_x550.c
index a75f2e3..ad9df6e 100644
--- a/drivers/net/ethernet/intel/ixgbe/ixgbe_x550.c
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_x550.c
@@ -1,59 +1,95 @@
 /*******************************************************************************
- *
- *  Intel 10 Gigabit PCI Express Linux driver
- *  Copyright(c) 1999 - 2015 Intel Corporation.
- *
- *  This program is free software; you can redistribute it and/or modify it
- *  under the terms and conditions of the GNU General Public License,
- *  version 2, as published by the Free Software Foundation.
- *
- *  This program is distributed in the hope it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- *  more details.
- *
- *  The full GNU General Public License is included in this distribution in
- *  the file called "COPYING".
- *
- *  Contact Information:
- *  Linux NICS <linux.nics@intel.com>
- *  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
- *  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
- *
- ******************************************************************************/
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#include "ixgbe_x550.h"
 #include "ixgbe_x540.h"
 #include "ixgbe_type.h"
+#include "ixgbe_api.h"
 #include "ixgbe_common.h"
 #include "ixgbe_phy.h"
 
-static s32 ixgbe_get_invariants_X550_x(struct ixgbe_hw *hw)
-{
-	struct ixgbe_mac_info *mac = &hw->mac;
-	struct ixgbe_phy_info *phy = &hw->phy;
-
-	/* Start with X540 invariants, since so simular */
-	ixgbe_get_invariants_X540(hw);
-
-	if (mac->ops.get_media_type(hw) != ixgbe_media_type_copper)
-		phy->ops.set_phy_power = NULL;
-
-	return 0;
-}
+STATIC s32 ixgbe_setup_ixfi_x550em(struct ixgbe_hw *hw, ixgbe_link_speed *speed);
+STATIC s32 ixgbe_acquire_swfw_sync_X550a(struct ixgbe_hw *, u32 mask);
+STATIC void ixgbe_release_swfw_sync_X550a(struct ixgbe_hw *, u32 mask);
+STATIC s32 ixgbe_read_mng_if_sel_x550em(struct ixgbe_hw *hw);
 
-/** ixgbe_setup_mux_ctl - Setup ESDP register for I2C mux control
+/**
+ *  ixgbe_init_ops_X550 - Inits func ptrs and MAC type
  *  @hw: pointer to hardware structure
+ *
+ *  Initialize the function pointers and assign the MAC type for X550.
+ *  Does not touch the hardware.
  **/
-static void ixgbe_setup_mux_ctl(struct ixgbe_hw *hw)
+s32 ixgbe_init_ops_X550(struct ixgbe_hw *hw)
 {
-	u32 esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
+	struct ixgbe_mac_info *mac = &hw->mac;
+	struct ixgbe_eeprom_info *eeprom = &hw->eeprom;
+	s32 ret_val;
 
-	if (hw->bus.lan_id) {
-		esdp &= ~(IXGBE_ESDP_SDP1_NATIVE | IXGBE_ESDP_SDP1);
-		esdp |= IXGBE_ESDP_SDP1_DIR;
+	DEBUGFUNC("ixgbe_init_ops_X550");
+
+	ret_val = ixgbe_init_ops_X540(hw);
+	mac->ops.dmac_config = ixgbe_dmac_config_X550;
+	mac->ops.dmac_config_tcs = ixgbe_dmac_config_tcs_X550;
+	mac->ops.dmac_update_tcs = ixgbe_dmac_update_tcs_X550;
+	mac->ops.setup_eee = NULL;
+	mac->ops.set_source_address_pruning =
+			ixgbe_set_source_address_pruning_X550;
+	mac->ops.set_ethertype_anti_spoofing =
+			ixgbe_set_ethertype_anti_spoofing_X550;
+
+	mac->ops.get_rtrup2tc = ixgbe_dcb_get_rtrup2tc_generic;
+	eeprom->ops.init_params = ixgbe_init_eeprom_params_X550;
+	eeprom->ops.calc_checksum = ixgbe_calc_eeprom_checksum_X550;
+	eeprom->ops.read = ixgbe_read_ee_hostif_X550;
+	eeprom->ops.read_buffer = ixgbe_read_ee_hostif_buffer_X550;
+	eeprom->ops.write = ixgbe_write_ee_hostif_X550;
+	eeprom->ops.write_buffer = ixgbe_write_ee_hostif_buffer_X550;
+	eeprom->ops.update_checksum = ixgbe_update_eeprom_checksum_X550;
+	eeprom->ops.validate_checksum = ixgbe_validate_eeprom_checksum_X550;
+
+	mac->ops.disable_mdd = ixgbe_disable_mdd_X550;
+	mac->ops.enable_mdd = ixgbe_enable_mdd_X550;
+	mac->ops.mdd_event = ixgbe_mdd_event_X550;
+	mac->ops.restore_mdd_vf = ixgbe_restore_mdd_vf_X550;
+	mac->ops.disable_rx = ixgbe_disable_rx_x550;
+	/* Manageability interface */
+	mac->ops.set_fw_drv_ver = ixgbe_set_fw_drv_ver_x550;
+	switch (hw->device_id) {
+	case IXGBE_DEV_ID_X550EM_X_1G_T:
+		hw->mac.ops.led_on = NULL;
+		hw->mac.ops.led_off = NULL;
+		break;
+	case IXGBE_DEV_ID_X550EM_X_10G_T:
+	case IXGBE_DEV_ID_X550EM_A_10G_T:
+		hw->mac.ops.led_on = ixgbe_led_on_t_X550em;
+		hw->mac.ops.led_off = ixgbe_led_off_t_X550em;
+		break;
+	default:
+		break;
 	}
-	esdp &= ~(IXGBE_ESDP_SDP0_NATIVE | IXGBE_ESDP_SDP0_DIR);
-	IXGBE_WRITE_REG(hw, IXGBE_ESDP, esdp);
-	IXGBE_WRITE_FLUSH(hw);
+	return ret_val;
 }
 
 /**
@@ -63,11 +99,10 @@ static void ixgbe_setup_mux_ctl(struct ixgbe_hw *hw)
  * @value: pointer to receive value read
  *
  * Returns status code
- */
-static s32 ixgbe_read_cs4227(struct ixgbe_hw *hw, u16 reg, u16 *value)
+ **/
+STATIC s32 ixgbe_read_cs4227(struct ixgbe_hw *hw, u16 reg, u16 *value)
 {
-	return hw->phy.ops.read_i2c_combined_unlocked(hw, IXGBE_CS4227, reg,
-						      value);
+	return hw->link.ops.read_link_unlocked(hw, hw->link.addr, reg, value);
 }
 
 /**
@@ -77,84 +112,10 @@ static s32 ixgbe_read_cs4227(struct ixgbe_hw *hw, u16 reg, u16 *value)
  * @value: value to write to register
  *
  * Returns status code
- */
-static s32 ixgbe_write_cs4227(struct ixgbe_hw *hw, u16 reg, u16 value)
-{
-	return hw->phy.ops.write_i2c_combined_unlocked(hw, IXGBE_CS4227, reg,
-						       value);
-}
-
-/**
- * ixgbe_check_cs4227_reg - Perform diag on a CS4227 register
- * @hw: pointer to hardware structure
- * @reg: the register to check
- *
- * Performs a diagnostic on a register in the CS4227 chip. Returns an error
- * if it is not operating correctly.
- * This function assumes that the caller has acquired the proper semaphore.
- */
-static s32 ixgbe_check_cs4227_reg(struct ixgbe_hw *hw, u16 reg)
-{
-	s32 status;
-	u32 retry;
-	u16 reg_val;
-
-	reg_val = (IXGBE_CS4227_EDC_MODE_DIAG << 1) | 1;
-	status = ixgbe_write_cs4227(hw, reg, reg_val);
-	if (status)
-		return status;
-	for (retry = 0; retry < IXGBE_CS4227_RETRIES; retry++) {
-		msleep(IXGBE_CS4227_CHECK_DELAY);
-		reg_val = 0xFFFF;
-		ixgbe_read_cs4227(hw, reg, &reg_val);
-		if (!reg_val)
-			break;
-	}
-	if (reg_val) {
-		hw_err(hw, "CS4227 reg 0x%04X failed diagnostic\n", reg);
-		return status;
-	}
-
-	return 0;
-}
-
-/**
- * ixgbe_get_cs4227_status - Return CS4227 status
- * @hw: pointer to hardware structure
- *
- * Performs a diagnostic on the CS4227 chip. Returns an error if it is
- * not operating correctly.
- * This function assumes that the caller has acquired the proper semaphore.
- */
-static s32 ixgbe_get_cs4227_status(struct ixgbe_hw *hw)
+ **/
+STATIC s32 ixgbe_write_cs4227(struct ixgbe_hw *hw, u16 reg, u16 value)
 {
-	s32 status;
-	u16 value = 0;
-
-	/* Exit if the diagnostic has already been performed. */
-	status = ixgbe_read_cs4227(hw, IXGBE_CS4227_SCRATCH, &value);
-	if (status)
-		return status;
-	if (value == IXGBE_CS4227_RESET_COMPLETE)
-		return 0;
-
-	/* Check port 0. */
-	status = ixgbe_check_cs4227_reg(hw, IXGBE_CS4227_LINE_SPARE24_LSB);
-	if (status)
-		return status;
-
-	status = ixgbe_check_cs4227_reg(hw, IXGBE_CS4227_HOST_SPARE24_LSB);
-	if (status)
-		return status;
-
-	/* Check port 1. */
-	status = ixgbe_check_cs4227_reg(hw, IXGBE_CS4227_LINE_SPARE24_LSB +
-					(1 << 12));
-	if (status)
-		return status;
-
-	return ixgbe_check_cs4227_reg(hw, IXGBE_CS4227_HOST_SPARE24_LSB +
-				      (1 << 12));
+	return hw->link.ops.write_link_unlocked(hw, hw->link.addr, reg, value);
 }
 
 /**
@@ -164,14 +125,15 @@ static s32 ixgbe_get_cs4227_status(struct ixgbe_hw *hw)
  * @value: pointer to receive read value
  *
  * Returns status code
- */
-static s32 ixgbe_read_pe(struct ixgbe_hw *hw, u8 reg, u8 *value)
+ **/
+STATIC s32 ixgbe_read_pe(struct ixgbe_hw *hw, u8 reg, u8 *value)
 {
 	s32 status;
 
-	status = ixgbe_read_i2c_byte_generic_unlocked(hw, reg, IXGBE_PE, value);
-	if (status)
-		hw_err(hw, "port expander access failed with %d\n", status);
+	status = ixgbe_read_i2c_byte_unlocked(hw, reg, IXGBE_PE, value);
+	if (status != IXGBE_SUCCESS)
+		ERROR_REPORT2(IXGBE_ERROR_CAUTION,
+			      "port expander access failed with %d\n", status);
 	return status;
 }
 
@@ -182,15 +144,15 @@ static s32 ixgbe_read_pe(struct ixgbe_hw *hw, u8 reg, u8 *value)
  * @value: value to write
  *
  * Returns status code
- */
-static s32 ixgbe_write_pe(struct ixgbe_hw *hw, u8 reg, u8 value)
+ **/
+STATIC s32 ixgbe_write_pe(struct ixgbe_hw *hw, u8 reg, u8 value)
 {
 	s32 status;
 
-	status = ixgbe_write_i2c_byte_generic_unlocked(hw, reg, IXGBE_PE,
-						       value);
-	if (status)
-		hw_err(hw, "port expander access failed with %d\n", status);
+	status = ixgbe_write_i2c_byte_unlocked(hw, reg, IXGBE_PE, value);
+	if (status != IXGBE_SUCCESS)
+		ERROR_REPORT2(IXGBE_ERROR_CAUTION,
+			      "port expander access failed with %d\n", status);
 	return status;
 }
 
@@ -200,8 +162,8 @@ static s32 ixgbe_write_pe(struct ixgbe_hw *hw, u8 reg, u8 value)
  *
  * This function assumes that the caller has acquired the proper semaphore.
  * Returns error code
- */
-static s32 ixgbe_reset_cs4227(struct ixgbe_hw *hw)
+ **/
+STATIC s32 ixgbe_reset_cs4227(struct ixgbe_hw *hw)
 {
 	s32 status;
 	u32 retry;
@@ -210,106 +172,117 @@ static s32 ixgbe_reset_cs4227(struct ixgbe_hw *hw)
 
 	/* Trigger hard reset. */
 	status = ixgbe_read_pe(hw, IXGBE_PE_OUTPUT, &reg);
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 	reg |= IXGBE_PE_BIT1;
 	status = ixgbe_write_pe(hw, IXGBE_PE_OUTPUT, reg);
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	status = ixgbe_read_pe(hw, IXGBE_PE_CONFIG, &reg);
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 	reg &= ~IXGBE_PE_BIT1;
 	status = ixgbe_write_pe(hw, IXGBE_PE_CONFIG, reg);
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	status = ixgbe_read_pe(hw, IXGBE_PE_OUTPUT, &reg);
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 	reg &= ~IXGBE_PE_BIT1;
 	status = ixgbe_write_pe(hw, IXGBE_PE_OUTPUT, reg);
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 
-	usleep_range(IXGBE_CS4227_RESET_HOLD, IXGBE_CS4227_RESET_HOLD + 100);
+	usec_delay(IXGBE_CS4227_RESET_HOLD);
 
 	status = ixgbe_read_pe(hw, IXGBE_PE_OUTPUT, &reg);
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 	reg |= IXGBE_PE_BIT1;
 	status = ixgbe_write_pe(hw, IXGBE_PE_OUTPUT, reg);
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	/* Wait for the reset to complete. */
-	msleep(IXGBE_CS4227_RESET_DELAY);
+	msec_delay(IXGBE_CS4227_RESET_DELAY);
 	for (retry = 0; retry < IXGBE_CS4227_RETRIES; retry++) {
 		status = ixgbe_read_cs4227(hw, IXGBE_CS4227_EFUSE_STATUS,
 					   &value);
-		if (!status && value == IXGBE_CS4227_EEPROM_LOAD_OK)
+		if (status == IXGBE_SUCCESS &&
+		    value == IXGBE_CS4227_EEPROM_LOAD_OK)
 			break;
-		msleep(IXGBE_CS4227_CHECK_DELAY);
+		msec_delay(IXGBE_CS4227_CHECK_DELAY);
 	}
 	if (retry == IXGBE_CS4227_RETRIES) {
-		hw_err(hw, "CS4227 reset did not complete\n");
+		ERROR_REPORT1(IXGBE_ERROR_INVALID_STATE,
+			"CS4227 reset did not complete.");
 		return IXGBE_ERR_PHY;
 	}
 
 	status = ixgbe_read_cs4227(hw, IXGBE_CS4227_EEPROM_STATUS, &value);
-	if (status || !(value & IXGBE_CS4227_EEPROM_LOAD_OK)) {
-		hw_err(hw, "CS4227 EEPROM did not load successfully\n");
+	if (status != IXGBE_SUCCESS ||
+	    !(value & IXGBE_CS4227_EEPROM_LOAD_OK)) {
+		ERROR_REPORT1(IXGBE_ERROR_INVALID_STATE,
+			"CS4227 EEPROM did not load successfully.");
 		return IXGBE_ERR_PHY;
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
  * ixgbe_check_cs4227 - Check CS4227 and reset as needed
  * @hw: pointer to hardware structure
- */
-static void ixgbe_check_cs4227(struct ixgbe_hw *hw)
+ **/
+STATIC void ixgbe_check_cs4227(struct ixgbe_hw *hw)
 {
+	s32 status = IXGBE_SUCCESS;
 	u32 swfw_mask = hw->phy.phy_semaphore_mask;
-	s32 status;
-	u16 value;
+	u16 value = 0;
 	u8 retry;
 
 	for (retry = 0; retry < IXGBE_CS4227_RETRIES; retry++) {
 		status = hw->mac.ops.acquire_swfw_sync(hw, swfw_mask);
-		if (status) {
-			hw_err(hw, "semaphore failed with %d\n", status);
-			msleep(IXGBE_CS4227_CHECK_DELAY);
+		if (status != IXGBE_SUCCESS) {
+			ERROR_REPORT2(IXGBE_ERROR_CAUTION,
+				"semaphore failed with %d", status);
+			msec_delay(IXGBE_CS4227_CHECK_DELAY);
 			continue;
 		}
 
 		/* Get status of reset flow. */
 		status = ixgbe_read_cs4227(hw, IXGBE_CS4227_SCRATCH, &value);
-		if (!status && value == IXGBE_CS4227_RESET_COMPLETE)
+
+		if (status == IXGBE_SUCCESS &&
+		    value == IXGBE_CS4227_RESET_COMPLETE)
 			goto out;
 
-		if (status || value != IXGBE_CS4227_RESET_PENDING)
+		if (status != IXGBE_SUCCESS ||
+		    value != IXGBE_CS4227_RESET_PENDING)
 			break;
 
 		/* Reset is pending. Wait and check again. */
 		hw->mac.ops.release_swfw_sync(hw, swfw_mask);
-		msleep(IXGBE_CS4227_CHECK_DELAY);
+		msec_delay(IXGBE_CS4227_CHECK_DELAY);
 	}
+
 	/* If still pending, assume other instance failed. */
 	if (retry == IXGBE_CS4227_RETRIES) {
 		status = hw->mac.ops.acquire_swfw_sync(hw, swfw_mask);
-		if (status) {
-			hw_err(hw, "semaphore failed with %d\n", status);
+		if (status != IXGBE_SUCCESS) {
+			ERROR_REPORT2(IXGBE_ERROR_CAUTION,
+				      "semaphore failed with %d", status);
 			return;
 		}
 	}
 
 	/* Reset the CS4227. */
 	status = ixgbe_reset_cs4227(hw);
-	if (status) {
-		hw_err(hw, "CS4227 reset failed: %d", status);
+	if (status != IXGBE_SUCCESS) {
+		ERROR_REPORT2(IXGBE_ERROR_INVALID_STATE,
+			"CS4227 reset failed: %d", status);
 		goto out;
 	}
 
@@ -319,741 +292,844 @@ static void ixgbe_check_cs4227(struct ixgbe_hw *hw)
 	ixgbe_write_cs4227(hw, IXGBE_CS4227_SCRATCH,
 			   IXGBE_CS4227_RESET_PENDING);
 	hw->mac.ops.release_swfw_sync(hw, swfw_mask);
-	usleep_range(10000, 12000);
+	msec_delay(10);
 	status = hw->mac.ops.acquire_swfw_sync(hw, swfw_mask);
-	if (status) {
-		hw_err(hw, "semaphore failed with %d", status);
+	if (status != IXGBE_SUCCESS) {
+		ERROR_REPORT2(IXGBE_ERROR_CAUTION,
+			"semaphore failed with %d", status);
 		return;
 	}
 
-	/* Is the CS4227 working correctly? */
-	status = ixgbe_get_cs4227_status(hw);
-	if (status) {
-		hw_err(hw, "CS4227 status failed: %d", status);
-		goto out;
-	}
-
 	/* Record completion for next time. */
 	status = ixgbe_write_cs4227(hw, IXGBE_CS4227_SCRATCH,
-				    IXGBE_CS4227_RESET_COMPLETE);
+		IXGBE_CS4227_RESET_COMPLETE);
 
 out:
 	hw->mac.ops.release_swfw_sync(hw, swfw_mask);
-	msleep(hw->eeprom.semaphore_delay);
+	msec_delay(hw->eeprom.semaphore_delay);
 }
 
-/** ixgbe_identify_phy_x550em - Get PHY type based on device id
- *  @hw: pointer to hardware structure
+/**
+ * ixgbe_setup_mux_ctl - Setup ESDP register for I2C mux control
+ * @hw: pointer to hardware structure
+ **/
+STATIC void ixgbe_setup_mux_ctl(struct ixgbe_hw *hw)
+{
+	u32 esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
+
+	if (hw->bus.lan_id) {
+		esdp &= ~(IXGBE_ESDP_SDP1_NATIVE | IXGBE_ESDP_SDP1);
+		esdp |= IXGBE_ESDP_SDP1_DIR;
+	}
+	esdp &= ~(IXGBE_ESDP_SDP0_NATIVE | IXGBE_ESDP_SDP0_DIR);
+	IXGBE_WRITE_REG(hw, IXGBE_ESDP, esdp);
+	IXGBE_WRITE_FLUSH(hw);
+}
+
+/**
+ * ixgbe_identify_phy_x550em - Get PHY type based on device id
+ * @hw: pointer to hardware structure
  *
- *  Returns error code
+ * Returns error code
  */
-static s32 ixgbe_identify_phy_x550em(struct ixgbe_hw *hw)
+STATIC s32 ixgbe_identify_phy_x550em(struct ixgbe_hw *hw)
 {
+	hw->mac.ops.set_lan_id(hw);
+
+	ixgbe_read_mng_if_sel_x550em(hw);
+
 	switch (hw->device_id) {
+	case IXGBE_DEV_ID_X550EM_A_SFP:
+		return ixgbe_identify_module_generic(hw);
 	case IXGBE_DEV_ID_X550EM_X_SFP:
 		/* set up for CS4227 usage */
-		hw->phy.phy_semaphore_mask = IXGBE_GSSR_SHARED_I2C_SM;
 		ixgbe_setup_mux_ctl(hw);
 		ixgbe_check_cs4227(hw);
+		/* Fallthrough */
+
+	case IXGBE_DEV_ID_X550EM_A_SFP_N:
 		return ixgbe_identify_module_generic(hw);
+		break;
 	case IXGBE_DEV_ID_X550EM_X_KX4:
 		hw->phy.type = ixgbe_phy_x550em_kx4;
 		break;
+	case IXGBE_DEV_ID_X550EM_X_XFI:
+		hw->phy.type = ixgbe_phy_x550em_xfi;
+		break;
 	case IXGBE_DEV_ID_X550EM_X_KR:
+	case IXGBE_DEV_ID_X550EM_A_KR:
+	case IXGBE_DEV_ID_X550EM_A_KR_L:
 		hw->phy.type = ixgbe_phy_x550em_kr;
 		break;
-	case IXGBE_DEV_ID_X550EM_X_1G_T:
+	case IXGBE_DEV_ID_X550EM_A_10G_T:
 	case IXGBE_DEV_ID_X550EM_X_10G_T:
 		return ixgbe_identify_phy_generic(hw);
+	case IXGBE_DEV_ID_X550EM_X_1G_T:
+		hw->phy.type = ixgbe_phy_ext_1g_t;
+		break;
+	case IXGBE_DEV_ID_X550EM_A_1G_T:
+	case IXGBE_DEV_ID_X550EM_A_1G_T_L:
+		hw->phy.type = ixgbe_phy_fw;
+		if (hw->bus.lan_id)
+			hw->phy.phy_semaphore_mask |= IXGBE_GSSR_PHY1_SM;
+		else
+			hw->phy.phy_semaphore_mask |= IXGBE_GSSR_PHY0_SM;
+		break;
 	default:
 		break;
 	}
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
-static s32 ixgbe_read_phy_reg_x550em(struct ixgbe_hw *hw, u32 reg_addr,
-				     u32 device_type, u16 *phy_data)
+/**
+ * ixgbe_fw_phy_activity - Perform an activity on a PHY
+ * @hw: pointer to hardware structure
+ * @activity: activity to perform
+ * @data: Pointer to 4 32-bit words of data
+ */
+s32 ixgbe_fw_phy_activity(struct ixgbe_hw *hw, u16 activity,
+			  u32 (*data)[FW_PHY_ACT_DATA_COUNT])
 {
-	return IXGBE_NOT_IMPLEMENTED;
+	union {
+		struct ixgbe_hic_phy_activity_req cmd;
+		struct ixgbe_hic_phy_activity_resp rsp;
+	} hic;
+	u16 retries = FW_PHY_ACT_RETRIES;
+	s32 rc;
+	u16 i;
+
+	do {
+		memset(&hic, 0, sizeof(hic));
+		hic.cmd.hdr.cmd = FW_PHY_ACT_REQ_CMD;
+		hic.cmd.hdr.buf_len = FW_PHY_ACT_REQ_LEN;
+		hic.cmd.hdr.checksum = FW_DEFAULT_CHECKSUM;
+		hic.cmd.port_number = hw->bus.lan_id;
+		hic.cmd.activity_id = IXGBE_CPU_TO_LE16(activity);
+		for (i = 0; i < FW_PHY_ACT_DATA_COUNT; ++i)
+			hic.cmd.data[i] = IXGBE_CPU_TO_BE32((*data)[i]);
+
+		rc = ixgbe_host_interface_command(hw, (u32 *)&hic.cmd,
+						  sizeof(hic.cmd),
+						  IXGBE_HI_COMMAND_TIMEOUT,
+						  true);
+		if (rc != IXGBE_SUCCESS)
+			return rc;
+		if (hic.rsp.hdr.cmd_or_resp.ret_status ==
+		    FW_CEM_RESP_STATUS_SUCCESS) {
+			for (i = 0; i < FW_PHY_ACT_DATA_COUNT; ++i)
+				(*data)[i] = IXGBE_BE32_TO_CPU(hic.rsp.data[i]);
+			return IXGBE_SUCCESS;
+		}
+		usec_delay(20);
+		--retries;
+	} while (retries > 0);
+
+	return IXGBE_ERR_HOST_INTERFACE_COMMAND;
 }
 
-static s32 ixgbe_write_phy_reg_x550em(struct ixgbe_hw *hw, u32 reg_addr,
-				      u32 device_type, u16 phy_data)
+static const struct {
+	u16 fw_speed;
+	ixgbe_link_speed phy_speed;
+} ixgbe_fw_map[] = {
+	{ FW_PHY_ACT_LINK_SPEED_10, IXGBE_LINK_SPEED_10_FULL },
+	{ FW_PHY_ACT_LINK_SPEED_100, IXGBE_LINK_SPEED_100_FULL },
+	{ FW_PHY_ACT_LINK_SPEED_1G, IXGBE_LINK_SPEED_1GB_FULL },
+	{ FW_PHY_ACT_LINK_SPEED_2_5G, IXGBE_LINK_SPEED_2_5GB_FULL },
+	{ FW_PHY_ACT_LINK_SPEED_5G, IXGBE_LINK_SPEED_5GB_FULL },
+	{ FW_PHY_ACT_LINK_SPEED_10G, IXGBE_LINK_SPEED_10GB_FULL },
+};
+
+/**
+ * ixgbe_get_phy_id_fw - Get the phy ID via firmware command
+ * @hw: pointer to hardware structure
+ *
+ * Returns error code
+ */
+static s32 ixgbe_get_phy_id_fw(struct ixgbe_hw *hw)
 {
-	return IXGBE_NOT_IMPLEMENTED;
+	u32 info[FW_PHY_ACT_DATA_COUNT] = { 0 };
+	u16 phy_speeds;
+	u16 phy_id_lo;
+	s32 rc;
+	u16 i;
+
+	rc = ixgbe_fw_phy_activity(hw, FW_PHY_ACT_GET_PHY_INFO, &info);
+	if (rc)
+		return rc;
+
+	hw->phy.speeds_supported = 0;
+	phy_speeds = info[0] & FW_PHY_INFO_SPEED_MASK;
+	for (i = 0; i < sizeof(ixgbe_fw_map) / sizeof(ixgbe_fw_map[0]); ++i) {
+		if (phy_speeds & ixgbe_fw_map[i].fw_speed)
+			hw->phy.speeds_supported |= ixgbe_fw_map[i].phy_speed;
+	}
+	if (!hw->phy.autoneg_advertised)
+		hw->phy.autoneg_advertised = hw->phy.speeds_supported;
+
+	hw->phy.id = info[0] & FW_PHY_INFO_ID_HI_MASK;
+	phy_id_lo = info[1] & FW_PHY_INFO_ID_LO_MASK;
+	hw->phy.id |= phy_id_lo & IXGBE_PHY_REVISION_MASK;
+	hw->phy.revision = phy_id_lo & ~IXGBE_PHY_REVISION_MASK;
+	if (!hw->phy.id || hw->phy.id == IXGBE_PHY_REVISION_MASK)
+		return IXGBE_ERR_PHY_ADDR_INVALID;
+	return IXGBE_SUCCESS;
 }
 
-/** ixgbe_init_eeprom_params_X550 - Initialize EEPROM params
- *  @hw: pointer to hardware structure
+/**
+ * ixgbe_identify_phy_fw - Get PHY type based on firmware command
+ * @hw: pointer to hardware structure
  *
- *  Initializes the EEPROM parameters ixgbe_eeprom_info within the
- *  ixgbe_hw struct in order to set up EEPROM access.
- **/
-static s32 ixgbe_init_eeprom_params_X550(struct ixgbe_hw *hw)
+ * Returns error code
+ */
+static s32 ixgbe_identify_phy_fw(struct ixgbe_hw *hw)
 {
-	struct ixgbe_eeprom_info *eeprom = &hw->eeprom;
-	u32 eec;
-	u16 eeprom_size;
-
-	if (eeprom->type == ixgbe_eeprom_uninitialized) {
-		eeprom->semaphore_delay = 10;
-		eeprom->type = ixgbe_flash;
-
-		eec = IXGBE_READ_REG(hw, IXGBE_EEC(hw));
-		eeprom_size = (u16)((eec & IXGBE_EEC_SIZE) >>
-				    IXGBE_EEC_SIZE_SHIFT);
-		eeprom->word_size = 1 << (eeprom_size +
-					  IXGBE_EEPROM_WORD_SIZE_SHIFT);
-
-		hw_dbg(hw, "Eeprom params: type = %d, size = %d\n",
-		       eeprom->type, eeprom->word_size);
-	}
+	if (hw->bus.lan_id)
+		hw->phy.phy_semaphore_mask = IXGBE_GSSR_PHY1_SM;
+	else
+		hw->phy.phy_semaphore_mask = IXGBE_GSSR_PHY0_SM;
 
-	return 0;
+	hw->phy.type = ixgbe_phy_fw;
+	hw->phy.ops.read_reg = NULL;
+	hw->phy.ops.write_reg = NULL;
+	return ixgbe_get_phy_id_fw(hw);
 }
 
 /**
- * ixgbe_iosf_wait - Wait for IOSF command completion
+ * ixgbe_shutdown_fw_phy - Shutdown a firmware-controlled PHY
  * @hw: pointer to hardware structure
- * @ctrl: pointer to location to receive final IOSF control value
  *
- * Return: failing status on timeout
- *
- * Note: ctrl can be NULL if the IOSF control register value is not needed
+ * Returns error code
  */
-static s32 ixgbe_iosf_wait(struct ixgbe_hw *hw, u32 *ctrl)
+s32 ixgbe_shutdown_fw_phy(struct ixgbe_hw *hw)
 {
-	u32 i, command;
+	u32 setup[FW_PHY_ACT_DATA_COUNT] = { 0 };
 
-	/* Check every 10 usec to see if the address cycle completed.
-	 * The SB IOSF BUSY bit will clear when the operation is
-	 * complete.
-	 */
-	for (i = 0; i < IXGBE_MDIO_COMMAND_TIMEOUT; i++) {
-		command = IXGBE_READ_REG(hw, IXGBE_SB_IOSF_INDIRECT_CTRL);
-		if (!(command & IXGBE_SB_IOSF_CTRL_BUSY))
-			break;
-		usleep_range(10, 20);
-	}
-	if (ctrl)
-		*ctrl = command;
-	if (i == IXGBE_MDIO_COMMAND_TIMEOUT) {
-		hw_dbg(hw, "IOSF wait timed out\n");
-		return IXGBE_ERR_PHY;
-	}
+	setup[0] = FW_PHY_ACT_FORCE_LINK_DOWN_OFF;
+	return ixgbe_fw_phy_activity(hw, FW_PHY_ACT_FORCE_LINK_DOWN, &setup);
+}
 
-	return 0;
+STATIC s32 ixgbe_read_phy_reg_x550em(struct ixgbe_hw *hw, u32 reg_addr,
+				     u32 device_type, u16 *phy_data)
+{
+	UNREFERENCED_4PARAMETER(*hw, reg_addr, device_type, *phy_data);
+	return IXGBE_NOT_IMPLEMENTED;
 }
 
-/** ixgbe_read_iosf_sb_reg_x550 - Writes a value to specified register of the
- *  IOSF device
- *  @hw: pointer to hardware structure
- *  @reg_addr: 32 bit PHY register to write
- *  @device_type: 3 bit device type
- *  @phy_data: Pointer to read data from the register
+STATIC s32 ixgbe_write_phy_reg_x550em(struct ixgbe_hw *hw, u32 reg_addr,
+				      u32 device_type, u16 phy_data)
+{
+	UNREFERENCED_4PARAMETER(*hw, reg_addr, device_type, phy_data);
+	return IXGBE_NOT_IMPLEMENTED;
+}
+
+/**
+ * ixgbe_read_i2c_combined_generic - Perform I2C read combined operation
+ * @hw: pointer to the hardware structure
+ * @addr: I2C bus address to read from
+ * @reg: I2C device register to read from
+ * @val: pointer to location to receive read value
+ *
+ * Returns an error code on error.
  **/
-static s32 ixgbe_read_iosf_sb_reg_x550(struct ixgbe_hw *hw, u32 reg_addr,
-				       u32 device_type, u32 *data)
+STATIC s32 ixgbe_read_i2c_combined_generic(struct ixgbe_hw *hw, u8 addr,
+					   u16 reg, u16 *val)
 {
-	u32 gssr = IXGBE_GSSR_PHY1_SM | IXGBE_GSSR_PHY0_SM;
-	u32 command, error;
-	s32 ret;
+	return ixgbe_read_i2c_combined_generic_int(hw, addr, reg, val, true);
+}
 
-	ret = hw->mac.ops.acquire_swfw_sync(hw, gssr);
-	if (ret)
-		return ret;
+/**
+ * ixgbe_read_i2c_combined_generic_unlocked - Do I2C read combined operation
+ * @hw: pointer to the hardware structure
+ * @addr: I2C bus address to read from
+ * @reg: I2C device register to read from
+ * @val: pointer to location to receive read value
+ *
+ * Returns an error code on error.
+ **/
+STATIC s32
+ixgbe_read_i2c_combined_generic_unlocked(struct ixgbe_hw *hw, u8 addr,
+					 u16 reg, u16 *val)
+{
+	return ixgbe_read_i2c_combined_generic_int(hw, addr, reg, val, false);
+}
 
-	ret = ixgbe_iosf_wait(hw, NULL);
-	if (ret)
-		goto out;
+/**
+ * ixgbe_write_i2c_combined_generic - Perform I2C write combined operation
+ * @hw: pointer to the hardware structure
+ * @addr: I2C bus address to write to
+ * @reg: I2C device register to write to
+ * @val: value to write
+ *
+ * Returns an error code on error.
+ **/
+STATIC s32 ixgbe_write_i2c_combined_generic(struct ixgbe_hw *hw,
+					    u8 addr, u16 reg, u16 val)
+{
+	return ixgbe_write_i2c_combined_generic_int(hw, addr, reg, val, true);
+}
 
-	command = ((reg_addr << IXGBE_SB_IOSF_CTRL_ADDR_SHIFT) |
-		   (device_type << IXGBE_SB_IOSF_CTRL_TARGET_SELECT_SHIFT));
+/**
+ * ixgbe_write_i2c_combined_generic_unlocked - Do I2C write combined operation
+ * @hw: pointer to the hardware structure
+ * @addr: I2C bus address to write to
+ * @reg: I2C device register to write to
+ * @val: value to write
+ *
+ * Returns an error code on error.
+ **/
+STATIC s32
+ixgbe_write_i2c_combined_generic_unlocked(struct ixgbe_hw *hw,
+					  u8 addr, u16 reg, u16 val)
+{
+	return ixgbe_write_i2c_combined_generic_int(hw, addr, reg, val, false);
+}
 
-	/* Write IOSF control register */
-	IXGBE_WRITE_REG(hw, IXGBE_SB_IOSF_INDIRECT_CTRL, command);
+/**
+*  ixgbe_init_ops_X550EM - Inits func ptrs and MAC type
+*  @hw: pointer to hardware structure
+*
+*  Initialize the function pointers and for MAC type X550EM.
+*  Does not touch the hardware.
+**/
+s32 ixgbe_init_ops_X550EM(struct ixgbe_hw *hw)
+{
+	struct ixgbe_mac_info *mac = &hw->mac;
+	struct ixgbe_eeprom_info *eeprom = &hw->eeprom;
+	struct ixgbe_phy_info *phy = &hw->phy;
+	s32 ret_val;
 
-	ret = ixgbe_iosf_wait(hw, &command);
+	DEBUGFUNC("ixgbe_init_ops_X550EM");
 
-	if ((command & IXGBE_SB_IOSF_CTRL_RESP_STAT_MASK) != 0) {
-		error = (command & IXGBE_SB_IOSF_CTRL_CMPL_ERR_MASK) >>
-			 IXGBE_SB_IOSF_CTRL_CMPL_ERR_SHIFT;
-		hw_dbg(hw, "Failed to read, error %x\n", error);
-		return IXGBE_ERR_PHY;
-	}
-
-	if (!ret)
-		*data = IXGBE_READ_REG(hw, IXGBE_SB_IOSF_INDIRECT_DATA);
-
-out:
-	hw->mac.ops.release_swfw_sync(hw, gssr);
-	return ret;
-}
-
-/** ixgbe_read_ee_hostif_data_X550 - Read EEPROM word using a host interface
- *  command assuming that the semaphore is already obtained.
- *  @hw: pointer to hardware structure
- *  @offset: offset of  word in the EEPROM to read
- *  @data: word read from the EEPROM
- *
- *  Reads a 16 bit word from the EEPROM using the hostif.
- **/
-static s32 ixgbe_read_ee_hostif_data_X550(struct ixgbe_hw *hw, u16 offset,
-					  u16 *data)
-{
-	s32 status;
-	struct ixgbe_hic_read_shadow_ram buffer;
+	/* Similar to X550 so start there. */
+	ret_val = ixgbe_init_ops_X550(hw);
 
-	buffer.hdr.req.cmd = FW_READ_SHADOW_RAM_CMD;
-	buffer.hdr.req.buf_lenh = 0;
-	buffer.hdr.req.buf_lenl = FW_READ_SHADOW_RAM_LEN;
-	buffer.hdr.req.checksum = FW_DEFAULT_CHECKSUM;
+	/* Since this function eventually calls
+	 * ixgbe_init_ops_540 by design, we are setting
+	 * the pointers to NULL explicitly here to overwrite
+	 * the values being set in the x540 function.
+	 */
+	/* Thermal sensor not supported in x550EM */
+	mac->ops.get_thermal_sensor_data = NULL;
+	mac->ops.init_thermal_sensor_thresh = NULL;
+	mac->thermal_sensor_enabled = false;
+
+	/* FCOE not supported in x550EM */
+	mac->ops.get_san_mac_addr = NULL;
+	mac->ops.set_san_mac_addr = NULL;
+	mac->ops.get_wwn_prefix = NULL;
+	mac->ops.get_fcoe_boot_status = NULL;
+
+	/* IPsec not supported in x550EM */
+	mac->ops.disable_sec_rx_path = NULL;
+	mac->ops.enable_sec_rx_path = NULL;
+
+	/* AUTOC register is not present in x550EM. */
+	mac->ops.prot_autoc_read = NULL;
+	mac->ops.prot_autoc_write = NULL;
+
+	/* X550EM bus type is internal*/
+	hw->bus.type = ixgbe_bus_type_internal;
+	mac->ops.get_bus_info = ixgbe_get_bus_info_X550em;
+
+
+	mac->ops.get_media_type = ixgbe_get_media_type_X550em;
+	mac->ops.setup_sfp = ixgbe_setup_sfp_modules_X550em;
+	mac->ops.get_link_capabilities = ixgbe_get_link_capabilities_X550em;
+	mac->ops.reset_hw = ixgbe_reset_hw_X550em;
+	mac->ops.get_supported_physical_layer =
+				    ixgbe_get_supported_physical_layer_X550em;
+
+	if (mac->ops.get_media_type(hw) == ixgbe_media_type_copper)
+		mac->ops.setup_fc = ixgbe_setup_fc_generic;
+	else
+		mac->ops.setup_fc = ixgbe_setup_fc_X550em;
 
-	/* convert offset from words to bytes */
-	buffer.address = cpu_to_be32(offset * 2);
-	/* one word */
-	buffer.length = cpu_to_be16(sizeof(u16));
+	/* PHY */
+	phy->ops.init = ixgbe_init_phy_ops_X550em;
+	switch (hw->device_id) {
+	case IXGBE_DEV_ID_X550EM_A_1G_T:
+	case IXGBE_DEV_ID_X550EM_A_1G_T_L:
+		mac->ops.setup_fc = NULL;
+		phy->ops.identify = ixgbe_identify_phy_fw;
+		phy->ops.set_phy_power = NULL;
+		phy->ops.get_firmware_version = NULL;
+		break;
+	case IXGBE_DEV_ID_X550EM_X_1G_T:
+		mac->ops.setup_fc = NULL;
+		phy->ops.identify = ixgbe_identify_phy_x550em;
+		phy->ops.set_phy_power = NULL;
+		break;
+	default:
+		phy->ops.identify = ixgbe_identify_phy_x550em;
+	}
 
-	status = ixgbe_host_interface_command(hw, (u32 *)&buffer,
-					      sizeof(buffer),
-					      IXGBE_HI_COMMAND_TIMEOUT, false);
-	if (status)
-		return status;
+	if (mac->ops.get_media_type(hw) != ixgbe_media_type_copper)
+		phy->ops.set_phy_power = NULL;
 
-	*data = (u16)IXGBE_READ_REG_ARRAY(hw, IXGBE_FLEX_MNG,
-					  FW_NVM_DATA_OFFSET);
+	/* EEPROM */
+	eeprom->ops.init_params = ixgbe_init_eeprom_params_X540;
+	eeprom->ops.read = ixgbe_read_ee_hostif_X550;
+	eeprom->ops.read_buffer = ixgbe_read_ee_hostif_buffer_X550;
+	eeprom->ops.write = ixgbe_write_ee_hostif_X550;
+	eeprom->ops.write_buffer = ixgbe_write_ee_hostif_buffer_X550;
+	eeprom->ops.update_checksum = ixgbe_update_eeprom_checksum_X550;
+	eeprom->ops.validate_checksum = ixgbe_validate_eeprom_checksum_X550;
+	eeprom->ops.calc_checksum = ixgbe_calc_eeprom_checksum_X550;
 
-	return 0;
+	return ret_val;
 }
 
-/** ixgbe_read_ee_hostif_buffer_X550- Read EEPROM word(s) using hostif
- *  @hw: pointer to hardware structure
- *  @offset: offset of  word in the EEPROM to read
- *  @words: number of words
- *  @data: word(s) read from the EEPROM
- *
- *  Reads a 16 bit word(s) from the EEPROM using the hostif.
- **/
-static s32 ixgbe_read_ee_hostif_buffer_X550(struct ixgbe_hw *hw,
-					    u16 offset, u16 words, u16 *data)
+/**
+ * ixgbe_setup_fw_link - Setup firmware-controlled PHYs
+ * @hw: pointer to hardware structure
+ */
+static s32 ixgbe_setup_fw_link(struct ixgbe_hw *hw)
 {
-	struct ixgbe_hic_read_shadow_ram buffer;
-	u32 current_word = 0;
-	u16 words_to_read;
-	s32 status;
-	u32 i;
+	u32 setup[FW_PHY_ACT_DATA_COUNT] = { 0 };
+	s32 rc;
+	u16 i;
 
-	/* Take semaphore for the entire operation. */
-	status = hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
-	if (status) {
-		hw_dbg(hw, "EEPROM read buffer - semaphore failed\n");
-		return status;
-	}
+	if (hw->phy.reset_disable || ixgbe_check_reset_blocked(hw))
+		return 0;
 
-	while (words) {
-		if (words > FW_MAX_READ_BUFFER_SIZE / 2)
-			words_to_read = FW_MAX_READ_BUFFER_SIZE / 2;
-		else
-			words_to_read = words;
+	if (hw->fc.strict_ieee && hw->fc.requested_mode == ixgbe_fc_rx_pause) {
+		ERROR_REPORT1(IXGBE_ERROR_UNSUPPORTED,
+			      "ixgbe_fc_rx_pause not valid in strict IEEE mode\n");
+		return IXGBE_ERR_INVALID_LINK_SETTINGS;
+	}
 
-		buffer.hdr.req.cmd = FW_READ_SHADOW_RAM_CMD;
-		buffer.hdr.req.buf_lenh = 0;
-		buffer.hdr.req.buf_lenl = FW_READ_SHADOW_RAM_LEN;
-		buffer.hdr.req.checksum = FW_DEFAULT_CHECKSUM;
+	switch (hw->fc.requested_mode) {
+	case ixgbe_fc_full:
+		setup[0] |= FW_PHY_ACT_SETUP_LINK_PAUSE_RXTX <<
+			    FW_PHY_ACT_SETUP_LINK_PAUSE_SHIFT;
+		break;
+	case ixgbe_fc_rx_pause:
+		setup[0] |= FW_PHY_ACT_SETUP_LINK_PAUSE_RX <<
+			    FW_PHY_ACT_SETUP_LINK_PAUSE_SHIFT;
+		break;
+	case ixgbe_fc_tx_pause:
+		setup[0] |= FW_PHY_ACT_SETUP_LINK_PAUSE_TX <<
+			    FW_PHY_ACT_SETUP_LINK_PAUSE_SHIFT;
+		break;
+	default:
+		break;
+	}
 
-		/* convert offset from words to bytes */
-		buffer.address = cpu_to_be32((offset + current_word) * 2);
-		buffer.length = cpu_to_be16(words_to_read * 2);
-		buffer.pad2 = 0;
-		buffer.pad3 = 0;
+	for (i = 0; i < sizeof(ixgbe_fw_map) / sizeof(ixgbe_fw_map[0]); ++i) {
+		if (hw->phy.autoneg_advertised & ixgbe_fw_map[i].phy_speed)
+			setup[0] |= ixgbe_fw_map[i].fw_speed;
+	}
+	setup[0] |= FW_PHY_ACT_SETUP_LINK_HP | FW_PHY_ACT_SETUP_LINK_AN;
 
-		status = ixgbe_host_interface_command(hw, (u32 *)&buffer,
-						      sizeof(buffer),
-						      IXGBE_HI_COMMAND_TIMEOUT,
-						      false);
-		if (status) {
-			hw_dbg(hw, "Host interface command failed\n");
-			goto out;
-		}
+	if (hw->phy.eee_speeds_advertised)
+		setup[0] |= FW_PHY_ACT_SETUP_LINK_EEE;
 
-		for (i = 0; i < words_to_read; i++) {
-			u32 reg = IXGBE_FLEX_MNG + (FW_NVM_DATA_OFFSET << 2) +
-				  2 * i;
-			u32 value = IXGBE_READ_REG(hw, reg);
+	rc = ixgbe_fw_phy_activity(hw, FW_PHY_ACT_SETUP_LINK, &setup);
+	if (rc)
+		return rc;
+	if (setup[0] == FW_PHY_ACT_SETUP_LINK_RSP_DOWN)
+		return IXGBE_ERR_OVERTEMP;
+	return IXGBE_SUCCESS;
+}
 
-			data[current_word] = (u16)(value & 0xffff);
-			current_word++;
-			i++;
-			if (i < words_to_read) {
-				value >>= 16;
-				data[current_word] = (u16)(value & 0xffff);
-				current_word++;
-			}
-		}
-		words -= words_to_read;
-	}
+/**
+ * ixgbe_fc_autoneg_fw _ Set up flow control for FW-controlled PHYs
+ * @hw: pointer to hardware structure
+ *
+ *  Called at init time to set up flow control.
+ */
+static s32 ixgbe_fc_autoneg_fw(struct ixgbe_hw *hw)
+{
+	if (hw->fc.requested_mode == ixgbe_fc_default)
+		hw->fc.requested_mode = ixgbe_fc_full;
 
-out:
-	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
-	return status;
+	return ixgbe_setup_fw_link(hw);
 }
 
-/** ixgbe_checksum_ptr_x550 - Checksum one pointer region
- *  @hw: pointer to hardware structure
- *  @ptr: pointer offset in eeprom
- *  @size: size of section pointed by ptr, if 0 first word will be used as size
- *  @csum: address of checksum to update
+/**
+ * ixgbe_setup_eee_fw - Enable/disable EEE support
+ * @hw: pointer to the HW structure
+ * @enable_eee: boolean flag to enable EEE
  *
- *  Returns error status for any failure
- **/
-static s32 ixgbe_checksum_ptr_x550(struct ixgbe_hw *hw, u16 ptr,
-				   u16 size, u16 *csum, u16 *buffer,
-				   u32 buffer_size)
+ * Enable/disable EEE based on enable_eee flag.
+ * This function controls EEE for firmware-based PHY implementations.
+ */
+static s32 ixgbe_setup_eee_fw(struct ixgbe_hw *hw, bool enable_eee)
 {
-	u16 buf[256];
-	s32 status;
-	u16 length, bufsz, i, start;
-	u16 *local_buffer;
+	if (!!hw->phy.eee_speeds_advertised == enable_eee)
+		return IXGBE_SUCCESS;
+	if (enable_eee)
+		hw->phy.eee_speeds_advertised = hw->phy.eee_speeds_supported;
+	else
+		hw->phy.eee_speeds_advertised = 0;
+	return hw->phy.ops.setup_link(hw);
+}
 
-	bufsz = sizeof(buf) / sizeof(buf[0]);
+/**
+*  ixgbe_init_ops_X550EM_a - Inits func ptrs and MAC type
+*  @hw: pointer to hardware structure
+*
+*  Initialize the function pointers and for MAC type X550EM_a.
+*  Does not touch the hardware.
+**/
+s32 ixgbe_init_ops_X550EM_a(struct ixgbe_hw *hw)
+{
+	struct ixgbe_mac_info *mac = &hw->mac;
+	s32 ret_val;
 
-	/* Read a chunk at the pointer location */
-	if (!buffer) {
-		status = ixgbe_read_ee_hostif_buffer_X550(hw, ptr, bufsz, buf);
-		if (status) {
-			hw_dbg(hw, "Failed to read EEPROM image\n");
-			return status;
-		}
-		local_buffer = buf;
+	DEBUGFUNC("ixgbe_init_ops_X550EM_a");
+
+	/* Start with generic X550EM init */
+	ret_val = ixgbe_init_ops_X550EM(hw);
+
+	if (hw->device_id == IXGBE_DEV_ID_X550EM_A_SGMII ||
+	    hw->device_id == IXGBE_DEV_ID_X550EM_A_SGMII_L) {
+		mac->ops.read_iosf_sb_reg = ixgbe_read_iosf_sb_reg_x550;
+		mac->ops.write_iosf_sb_reg = ixgbe_write_iosf_sb_reg_x550;
 	} else {
-		if (buffer_size < ptr)
-			return  IXGBE_ERR_PARAM;
-		local_buffer = &buffer[ptr];
+		mac->ops.read_iosf_sb_reg = ixgbe_read_iosf_sb_reg_x550a;
+		mac->ops.write_iosf_sb_reg = ixgbe_write_iosf_sb_reg_x550a;
 	}
+	mac->ops.acquire_swfw_sync = ixgbe_acquire_swfw_sync_X550a;
+	mac->ops.release_swfw_sync = ixgbe_release_swfw_sync_X550a;
 
-	if (size) {
-		start = 0;
-		length = size;
-	} else {
-		start = 1;
-		length = local_buffer[0];
+	switch (mac->ops.get_media_type(hw)) {
+	case ixgbe_media_type_fiber:
+		mac->ops.setup_fc = NULL;
+		mac->ops.fc_autoneg = ixgbe_fc_autoneg_fiber_x550em_a;
+		break;
+	case ixgbe_media_type_backplane:
+		mac->ops.fc_autoneg = ixgbe_fc_autoneg_backplane_x550em_a;
+		mac->ops.setup_fc = ixgbe_setup_fc_backplane_x550em_a;
+		break;
+	default:
+		break;
+	}
 
-		/* Skip pointer section if length is invalid. */
-		if (length == 0xFFFF || length == 0 ||
-		    (ptr + length) >= hw->eeprom.word_size)
-			return 0;
+	switch (hw->device_id) {
+	case IXGBE_DEV_ID_X550EM_A_1G_T:
+	case IXGBE_DEV_ID_X550EM_A_1G_T_L:
+		mac->ops.fc_autoneg = ixgbe_fc_autoneg_sgmii_x550em_a;
+		mac->ops.setup_fc = ixgbe_fc_autoneg_fw;
+		mac->ops.setup_eee = ixgbe_setup_eee_fw;
+		hw->phy.eee_speeds_supported = IXGBE_LINK_SPEED_100_FULL |
+					       IXGBE_LINK_SPEED_1GB_FULL;
+		hw->phy.eee_speeds_advertised = hw->phy.eee_speeds_supported;
+		break;
+	default:
+		break;
 	}
 
-	if (buffer && ((u32)start + (u32)length > buffer_size))
-		return IXGBE_ERR_PARAM;
+	return ret_val;
+}
 
-	for (i = start; length; i++, length--) {
-		if (i == bufsz && !buffer) {
-			ptr += bufsz;
-			i = 0;
-			if (length < bufsz)
-				bufsz = length;
+/**
+*  ixgbe_init_ops_X550EM_x - Inits func ptrs and MAC type
+*  @hw: pointer to hardware structure
+*
+*  Initialize the function pointers and for MAC type X550EM_x.
+*  Does not touch the hardware.
+**/
+s32 ixgbe_init_ops_X550EM_x(struct ixgbe_hw *hw)
+{
+	struct ixgbe_mac_info *mac = &hw->mac;
+	struct ixgbe_link_info *link = &hw->link;
+	s32 ret_val;
 
-			/* Read a chunk at the pointer location */
-			status = ixgbe_read_ee_hostif_buffer_X550(hw, ptr,
-								  bufsz, buf);
-			if (status) {
-				hw_dbg(hw, "Failed to read EEPROM image\n");
-				return status;
-			}
-		}
-		*csum += local_buffer[i];
+	DEBUGFUNC("ixgbe_init_ops_X550EM_x");
+
+	/* Start with generic X550EM init */
+	ret_val = ixgbe_init_ops_X550EM(hw);
+
+	mac->ops.read_iosf_sb_reg = ixgbe_read_iosf_sb_reg_x550;
+	mac->ops.write_iosf_sb_reg = ixgbe_write_iosf_sb_reg_x550;
+	mac->ops.acquire_swfw_sync = ixgbe_acquire_swfw_sync_X550em;
+	mac->ops.release_swfw_sync = ixgbe_release_swfw_sync_X550em;
+	link->ops.read_link = ixgbe_read_i2c_combined_generic;
+	link->ops.read_link_unlocked = ixgbe_read_i2c_combined_generic_unlocked;
+	link->ops.write_link = ixgbe_write_i2c_combined_generic;
+	link->ops.write_link_unlocked =
+				      ixgbe_write_i2c_combined_generic_unlocked;
+	link->addr = IXGBE_CS4227;
+
+	if (hw->device_id == IXGBE_DEV_ID_X550EM_X_1G_T) {
+		mac->ops.setup_fc = NULL;
+		mac->ops.setup_eee = NULL;
+		mac->ops.init_led_link_act = NULL;
 	}
-	return 0;
+
+	return ret_val;
 }
 
-/** ixgbe_calc_checksum_X550 - Calculates and returns the checksum
+/**
+ *  ixgbe_dmac_config_X550
  *  @hw: pointer to hardware structure
- *  @buffer: pointer to buffer containing calculated checksum
- *  @buffer_size: size of buffer
  *
- *  Returns a negative error code on error, or the 16-bit checksum
+ *  Configure DMA coalescing. If enabling dmac, dmac is activated.
+ *  When disabling dmac, dmac enable dmac bit is cleared.
  **/
-static s32 ixgbe_calc_checksum_X550(struct ixgbe_hw *hw, u16 *buffer,
-				    u32 buffer_size)
+s32 ixgbe_dmac_config_X550(struct ixgbe_hw *hw)
 {
-	u16 eeprom_ptrs[IXGBE_EEPROM_LAST_WORD + 1];
-	u16 *local_buffer;
-	s32 status;
-	u16 checksum = 0;
-	u16 pointer, i, size;
-
-	hw->eeprom.ops.init_params(hw);
+	u32 reg, high_pri_tc;
 
-	if (!buffer) {
-		/* Read pointer area */
-		status = ixgbe_read_ee_hostif_buffer_X550(hw, 0,
-						IXGBE_EEPROM_LAST_WORD + 1,
-						eeprom_ptrs);
-		if (status) {
-			hw_dbg(hw, "Failed to read EEPROM image\n");
-			return status;
-		}
-		local_buffer = eeprom_ptrs;
-	} else {
-		if (buffer_size < IXGBE_EEPROM_LAST_WORD)
-			return IXGBE_ERR_PARAM;
-		local_buffer = buffer;
-	}
+	DEBUGFUNC("ixgbe_dmac_config_X550");
 
-	/* For X550 hardware include 0x0-0x41 in the checksum, skip the
-	 * checksum word itself
-	 */
-	for (i = 0; i <= IXGBE_EEPROM_LAST_WORD; i++)
-		if (i != IXGBE_EEPROM_CHECKSUM)
-			checksum += local_buffer[i];
+	/* Disable DMA coalescing before configuring */
+	reg = IXGBE_READ_REG(hw, IXGBE_DMACR);
+	reg &= ~IXGBE_DMACR_DMAC_EN;
+	IXGBE_WRITE_REG(hw, IXGBE_DMACR, reg);
 
-	/* Include all data from pointers 0x3, 0x6-0xE.  This excludes the
-	 * FW, PHY module, and PCIe Expansion/Option ROM pointers.
-	 */
-	for (i = IXGBE_PCIE_ANALOG_PTR_X550; i < IXGBE_FW_PTR; i++) {
-		if (i == IXGBE_PHY_PTR || i == IXGBE_OPTION_ROM_PTR)
-			continue;
+	/* Disable DMA Coalescing if the watchdog timer is 0 */
+	if (!hw->mac.dmac_config.watchdog_timer)
+		goto out;
 
-		pointer = local_buffer[i];
+	ixgbe_dmac_config_tcs_X550(hw);
 
-		/* Skip pointer section if the pointer is invalid. */
-		if (pointer == 0xFFFF || pointer == 0 ||
-		    pointer >= hw->eeprom.word_size)
-			continue;
+	/* Configure DMA Coalescing Control Register */
+	reg = IXGBE_READ_REG(hw, IXGBE_DMACR);
 
-		switch (i) {
-		case IXGBE_PCIE_GENERAL_PTR:
-			size = IXGBE_IXGBE_PCIE_GENERAL_SIZE;
-			break;
-		case IXGBE_PCIE_CONFIG0_PTR:
-		case IXGBE_PCIE_CONFIG1_PTR:
-			size = IXGBE_PCIE_CONFIG_SIZE;
-			break;
-		default:
-			size = 0;
-			break;
-		}
+	/* Set the watchdog timer in units of 40.96 usec */
+	reg &= ~IXGBE_DMACR_DMACWT_MASK;
+	reg |= (hw->mac.dmac_config.watchdog_timer * 100) / 4096;
 
-		status = ixgbe_checksum_ptr_x550(hw, pointer, size, &checksum,
-						 buffer, buffer_size);
-		if (status)
-			return status;
+	reg &= ~IXGBE_DMACR_HIGH_PRI_TC_MASK;
+	/* If fcoe is enabled, set high priority traffic class */
+	if (hw->mac.dmac_config.fcoe_en) {
+		high_pri_tc = 1 << hw->mac.dmac_config.fcoe_tc;
+		reg |= ((high_pri_tc << IXGBE_DMACR_HIGH_PRI_TC_SHIFT) &
+			IXGBE_DMACR_HIGH_PRI_TC_MASK);
 	}
+	reg |= IXGBE_DMACR_EN_MNG_IND;
 
-	checksum = (u16)IXGBE_EEPROM_SUM - checksum;
+	/* Enable DMA coalescing after configuration */
+	reg |= IXGBE_DMACR_DMAC_EN;
+	IXGBE_WRITE_REG(hw, IXGBE_DMACR, reg);
 
-	return (s32)checksum;
+out:
+	return IXGBE_SUCCESS;
 }
 
-/** ixgbe_calc_eeprom_checksum_X550 - Calculates and returns the checksum
+/**
+ *  ixgbe_dmac_config_tcs_X550
  *  @hw: pointer to hardware structure
  *
- *  Returns a negative error code on error, or the 16-bit checksum
+ *  Configure DMA coalescing threshold per TC. The dmac enable bit must
+ *  be cleared before configuring.
  **/
-static s32 ixgbe_calc_eeprom_checksum_X550(struct ixgbe_hw *hw)
+s32 ixgbe_dmac_config_tcs_X550(struct ixgbe_hw *hw)
 {
-	return ixgbe_calc_checksum_X550(hw, NULL, 0);
-}
+	u32 tc, reg, pb_headroom, rx_pb_size, maxframe_size_kb;
 
-/** ixgbe_read_ee_hostif_X550 - Read EEPROM word using a host interface command
- *  @hw: pointer to hardware structure
- *  @offset: offset of  word in the EEPROM to read
- *  @data: word read from the EEPROM
- *
- *   Reads a 16 bit word from the EEPROM using the hostif.
- **/
-static s32 ixgbe_read_ee_hostif_X550(struct ixgbe_hw *hw, u16 offset, u16 *data)
-{
-	s32 status = 0;
+	DEBUGFUNC("ixgbe_dmac_config_tcs_X550");
 
-	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM) == 0) {
-		status = ixgbe_read_ee_hostif_data_X550(hw, offset, data);
-		hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
-	} else {
-		status = IXGBE_ERR_SWFW_SYNC;
+	/* Configure DMA coalescing enabled */
+	switch (hw->mac.dmac_config.link_speed) {
+	case IXGBE_LINK_SPEED_10_FULL:
+	case IXGBE_LINK_SPEED_100_FULL:
+		pb_headroom = IXGBE_DMACRXT_100M;
+		break;
+	case IXGBE_LINK_SPEED_1GB_FULL:
+		pb_headroom = IXGBE_DMACRXT_1G;
+		break;
+	default:
+		pb_headroom = IXGBE_DMACRXT_10G;
+		break;
 	}
 
-	return status;
+	maxframe_size_kb = ((IXGBE_READ_REG(hw, IXGBE_MAXFRS) >>
+			     IXGBE_MHADD_MFS_SHIFT) / 1024);
+
+	/* Set the per Rx packet buffer receive threshold */
+	for (tc = 0; tc < IXGBE_DCB_MAX_TRAFFIC_CLASS; tc++) {
+		reg = IXGBE_READ_REG(hw, IXGBE_DMCTH(tc));
+		reg &= ~IXGBE_DMCTH_DMACRXT_MASK;
+
+		if (tc < hw->mac.dmac_config.num_tcs) {
+			/* Get Rx PB size */
+			rx_pb_size = IXGBE_READ_REG(hw, IXGBE_RXPBSIZE(tc));
+			rx_pb_size = (rx_pb_size & IXGBE_RXPBSIZE_MASK) >>
+				IXGBE_RXPBSIZE_SHIFT;
+
+			/* Calculate receive buffer threshold in kilobytes */
+			if (rx_pb_size > pb_headroom)
+				rx_pb_size = rx_pb_size - pb_headroom;
+			else
+				rx_pb_size = 0;
+
+			/* Minimum of MFS shall be set for DMCTH */
+			reg |= (rx_pb_size > maxframe_size_kb) ?
+				rx_pb_size : maxframe_size_kb;
+		}
+		IXGBE_WRITE_REG(hw, IXGBE_DMCTH(tc), reg);
+	}
+	return IXGBE_SUCCESS;
 }
 
-/** ixgbe_validate_eeprom_checksum_X550 - Validate EEPROM checksum
+/**
+ *  ixgbe_dmac_update_tcs_X550
  *  @hw: pointer to hardware structure
- *  @checksum_val: calculated checksum
  *
- *  Performs checksum calculation and validates the EEPROM checksum.  If the
- *  caller does not need checksum_val, the value can be NULL.
+ *  Disables dmac, updates per TC settings, and then enables dmac.
  **/
-static s32 ixgbe_validate_eeprom_checksum_X550(struct ixgbe_hw *hw,
-					       u16 *checksum_val)
+s32 ixgbe_dmac_update_tcs_X550(struct ixgbe_hw *hw)
 {
-	s32 status;
-	u16 checksum;
-	u16 read_checksum = 0;
-
-	/* Read the first word from the EEPROM. If this times out or fails, do
-	 * not continue or we could be in for a very long wait while every
-	 * EEPROM read fails
-	 */
-	status = hw->eeprom.ops.read(hw, 0, &checksum);
-	if (status) {
-		hw_dbg(hw, "EEPROM read failed\n");
-		return status;
-	}
-
-	status = hw->eeprom.ops.calc_checksum(hw);
-	if (status < 0)
-		return status;
+	u32 reg;
 
-	checksum = (u16)(status & 0xffff);
+	DEBUGFUNC("ixgbe_dmac_update_tcs_X550");
 
-	status = ixgbe_read_ee_hostif_X550(hw, IXGBE_EEPROM_CHECKSUM,
-					   &read_checksum);
-	if (status)
-		return status;
+	/* Disable DMA coalescing before configuring */
+	reg = IXGBE_READ_REG(hw, IXGBE_DMACR);
+	reg &= ~IXGBE_DMACR_DMAC_EN;
+	IXGBE_WRITE_REG(hw, IXGBE_DMACR, reg);
 
-	/* Verify read checksum from EEPROM is the same as
-	 * calculated checksum
-	 */
-	if (read_checksum != checksum) {
-		status = IXGBE_ERR_EEPROM_CHECKSUM;
-		hw_dbg(hw, "Invalid EEPROM checksum");
-	}
+	ixgbe_dmac_config_tcs_X550(hw);
 
-	/* If the user cares, return the calculated checksum */
-	if (checksum_val)
-		*checksum_val = checksum;
+	/* Enable DMA coalescing after configuration */
+	reg = IXGBE_READ_REG(hw, IXGBE_DMACR);
+	reg |= IXGBE_DMACR_DMAC_EN;
+	IXGBE_WRITE_REG(hw, IXGBE_DMACR, reg);
 
-	return status;
+	return IXGBE_SUCCESS;
 }
 
-/** ixgbe_write_ee_hostif_X550 - Write EEPROM word using hostif
+/**
+ *  ixgbe_init_eeprom_params_X550 - Initialize EEPROM params
  *  @hw: pointer to hardware structure
- *  @offset: offset of  word in the EEPROM to write
- *  @data: word write to the EEPROM
  *
- *  Write a 16 bit word to the EEPROM using the hostif.
+ *  Initializes the EEPROM parameters ixgbe_eeprom_info within the
+ *  ixgbe_hw struct in order to set up EEPROM access.
  **/
-static s32 ixgbe_write_ee_hostif_data_X550(struct ixgbe_hw *hw, u16 offset,
-					   u16 data)
+s32 ixgbe_init_eeprom_params_X550(struct ixgbe_hw *hw)
 {
-	s32 status;
-	struct ixgbe_hic_write_shadow_ram buffer;
-
-	buffer.hdr.req.cmd = FW_WRITE_SHADOW_RAM_CMD;
-	buffer.hdr.req.buf_lenh = 0;
-	buffer.hdr.req.buf_lenl = FW_WRITE_SHADOW_RAM_LEN;
-	buffer.hdr.req.checksum = FW_DEFAULT_CHECKSUM;
+	struct ixgbe_eeprom_info *eeprom = &hw->eeprom;
+	u32 eec;
+	u16 eeprom_size;
 
-	/* one word */
-	buffer.length = cpu_to_be16(sizeof(u16));
-	buffer.data = data;
-	buffer.address = cpu_to_be32(offset * 2);
+	DEBUGFUNC("ixgbe_init_eeprom_params_X550");
 
-	status = ixgbe_host_interface_command(hw, (u32 *)&buffer,
-					      sizeof(buffer),
-					      IXGBE_HI_COMMAND_TIMEOUT, false);
-	return status;
-}
+	if (eeprom->type == ixgbe_eeprom_uninitialized) {
+		eeprom->semaphore_delay = 10;
+		eeprom->type = ixgbe_flash;
 
-/** ixgbe_write_ee_hostif_X550 - Write EEPROM word using hostif
- *  @hw: pointer to hardware structure
- *  @offset: offset of  word in the EEPROM to write
- *  @data: word write to the EEPROM
- *
- *  Write a 16 bit word to the EEPROM using the hostif.
- **/
-static s32 ixgbe_write_ee_hostif_X550(struct ixgbe_hw *hw, u16 offset, u16 data)
-{
-	s32 status = 0;
+		eec = IXGBE_READ_REG(hw, IXGBE_EEC);
+		eeprom_size = (u16)((eec & IXGBE_EEC_SIZE) >>
+				    IXGBE_EEC_SIZE_SHIFT);
+		eeprom->word_size = 1 << (eeprom_size +
+					  IXGBE_EEPROM_WORD_SIZE_SHIFT);
 
-	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM) == 0) {
-		status = ixgbe_write_ee_hostif_data_X550(hw, offset, data);
-		hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
-	} else {
-		hw_dbg(hw, "write ee hostif failed to get semaphore");
-		status = IXGBE_ERR_SWFW_SYNC;
+		DEBUGOUT2("Eeprom params: type = %d, size = %d\n",
+			  eeprom->type, eeprom->word_size);
 	}
 
-	return status;
-}
-
-/** ixgbe_update_flash_X550 - Instruct HW to copy EEPROM to Flash device
- *  @hw: pointer to hardware structure
- *
- *  Issue a shadow RAM dump to FW to copy EEPROM from shadow RAM to the flash.
- **/
-static s32 ixgbe_update_flash_X550(struct ixgbe_hw *hw)
-{
-	s32 status = 0;
-	union ixgbe_hic_hdr2 buffer;
-
-	buffer.req.cmd = FW_SHADOW_RAM_DUMP_CMD;
-	buffer.req.buf_lenh = 0;
-	buffer.req.buf_lenl = FW_SHADOW_RAM_DUMP_LEN;
-	buffer.req.checksum = FW_DEFAULT_CHECKSUM;
-
-	status = ixgbe_host_interface_command(hw, (u32 *)&buffer,
-					      sizeof(buffer),
-					      IXGBE_HI_COMMAND_TIMEOUT, false);
-	return status;
+	return IXGBE_SUCCESS;
 }
 
 /**
- * ixgbe_get_bus_info_X550em - Set PCI bus info
+ * ixgbe_set_source_address_pruning_X550 - Enable/Disbale source address pruning
  * @hw: pointer to hardware structure
- *
- * Sets bus link width and speed to unknown because X550em is
- * not a PCI device.
- **/
-static s32 ixgbe_get_bus_info_X550em(struct ixgbe_hw *hw)
-{
-	hw->bus.type  = ixgbe_bus_type_internal;
-	hw->bus.width = ixgbe_bus_width_unknown;
-	hw->bus.speed = ixgbe_bus_speed_unknown;
-
-	hw->mac.ops.set_lan_id(hw);
-
-	return 0;
-}
-
-/** ixgbe_disable_rx_x550 - Disable RX unit
- *
- *  Enables the Rx DMA unit for x550
+ * @enable: enable or disable source address pruning
+ * @pool: Rx pool to set source address pruning for
  **/
-static void ixgbe_disable_rx_x550(struct ixgbe_hw *hw)
+void ixgbe_set_source_address_pruning_X550(struct ixgbe_hw *hw, bool enable,
+					   unsigned int pool)
 {
-	u32 rxctrl, pfdtxgswc;
-	s32 status;
-	struct ixgbe_hic_disable_rxen fw_cmd;
+	u64 pfflp;
 
-	rxctrl = IXGBE_READ_REG(hw, IXGBE_RXCTRL);
-	if (rxctrl & IXGBE_RXCTRL_RXEN) {
-		pfdtxgswc = IXGBE_READ_REG(hw, IXGBE_PFDTXGSWC);
-		if (pfdtxgswc & IXGBE_PFDTXGSWC_VT_LBEN) {
-			pfdtxgswc &= ~IXGBE_PFDTXGSWC_VT_LBEN;
-			IXGBE_WRITE_REG(hw, IXGBE_PFDTXGSWC, pfdtxgswc);
-			hw->mac.set_lben = true;
-		} else {
-			hw->mac.set_lben = false;
-		}
+	/* max rx pool is 63 */
+	if (pool > 63)
+		return;
 
-		fw_cmd.hdr.cmd = FW_DISABLE_RXEN_CMD;
-		fw_cmd.hdr.buf_len = FW_DISABLE_RXEN_LEN;
-		fw_cmd.hdr.checksum = FW_DEFAULT_CHECKSUM;
-		fw_cmd.port_number = (u8)hw->bus.lan_id;
+	pfflp = (u64)IXGBE_READ_REG(hw, IXGBE_PFFLPL);
+	pfflp |= (u64)IXGBE_READ_REG(hw, IXGBE_PFFLPH) << 32;
 
-		status = ixgbe_host_interface_command(hw, (u32 *)&fw_cmd,
-					sizeof(struct ixgbe_hic_disable_rxen),
-					IXGBE_HI_COMMAND_TIMEOUT, true);
+	if (enable)
+		pfflp |= (1ULL << pool);
+	else
+		pfflp &= ~(1ULL << pool);
 
-		/* If we fail - disable RX using register write */
-		if (status) {
-			rxctrl = IXGBE_READ_REG(hw, IXGBE_RXCTRL);
-			if (rxctrl & IXGBE_RXCTRL_RXEN) {
-				rxctrl &= ~IXGBE_RXCTRL_RXEN;
-				IXGBE_WRITE_REG(hw, IXGBE_RXCTRL, rxctrl);
-			}
-		}
-	}
+	IXGBE_WRITE_REG(hw, IXGBE_PFFLPL, (u32)pfflp);
+	IXGBE_WRITE_REG(hw, IXGBE_PFFLPH, (u32)(pfflp >> 32));
 }
 
-/** ixgbe_update_eeprom_checksum_X550 - Updates the EEPROM checksum and flash
+/**
+ *  ixgbe_set_ethertype_anti_spoofing_X550 - Enable/Disable Ethertype anti-spoofing
  *  @hw: pointer to hardware structure
+ *  @enable: enable or disable switch for Ethertype anti-spoofing
+ *  @vf: Virtual Function pool - VF Pool to set for Ethertype anti-spoofing
  *
- *  After writing EEPROM to shadow RAM using EEWR register, software calculates
- *  checksum and updates the EEPROM and instructs the hardware to update
- *  the flash.
  **/
-static s32 ixgbe_update_eeprom_checksum_X550(struct ixgbe_hw *hw)
+void ixgbe_set_ethertype_anti_spoofing_X550(struct ixgbe_hw *hw,
+		bool enable, int vf)
 {
-	s32 status;
-	u16 checksum = 0;
-
-	/* Read the first word from the EEPROM. If this times out or fails, do
-	 * not continue or we could be in for a very long wait while every
-	 * EEPROM read fails
-	 */
-	status = ixgbe_read_ee_hostif_X550(hw, 0, &checksum);
-	if (status) {
-		hw_dbg(hw, "EEPROM read failed\n");
-		return status;
-	}
-
-	status = ixgbe_calc_eeprom_checksum_X550(hw);
-	if (status < 0)
-		return status;
-
-	checksum = (u16)(status & 0xffff);
+	int vf_target_reg = vf >> 3;
+	int vf_target_shift = vf % 8 + IXGBE_SPOOF_ETHERTYPEAS_SHIFT;
+	u32 pfvfspoof;
 
-	status = ixgbe_write_ee_hostif_X550(hw, IXGBE_EEPROM_CHECKSUM,
-					    checksum);
-	if (status)
-		return status;
+	DEBUGFUNC("ixgbe_set_ethertype_anti_spoofing_X550");
 
-	status = ixgbe_update_flash_X550(hw);
+	pfvfspoof = IXGBE_READ_REG(hw, IXGBE_PFVFSPOOF(vf_target_reg));
+	if (enable)
+		pfvfspoof |= (1 << vf_target_shift);
+	else
+		pfvfspoof &= ~(1 << vf_target_shift);
 
-	return status;
+	IXGBE_WRITE_REG(hw, IXGBE_PFVFSPOOF(vf_target_reg), pfvfspoof);
 }
 
-/** ixgbe_write_ee_hostif_buffer_X550 - Write EEPROM word(s) using hostif
- *  @hw: pointer to hardware structure
- *  @offset: offset of  word in the EEPROM to write
- *  @words: number of words
- *  @data: word(s) write to the EEPROM
+/**
+ * ixgbe_iosf_wait - Wait for IOSF command completion
+ * @hw: pointer to hardware structure
+ * @ctrl: pointer to location to receive final IOSF control value
  *
+ * Returns failing status on timeout
  *
- *  Write a 16 bit word(s) to the EEPROM using the hostif.
+ * Note: ctrl can be NULL if the IOSF control register value is not needed
  **/
-static s32 ixgbe_write_ee_hostif_buffer_X550(struct ixgbe_hw *hw,
-					     u16 offset, u16 words,
-					     u16 *data)
+STATIC s32 ixgbe_iosf_wait(struct ixgbe_hw *hw, u32 *ctrl)
 {
-	s32 status = 0;
-	u32 i = 0;
-
-	/* Take semaphore for the entire operation. */
-	status = hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
-	if (status) {
-		hw_dbg(hw, "EEPROM write buffer - semaphore failed\n");
-		return status;
-	}
+	u32 i, command = 0;
 
-	for (i = 0; i < words; i++) {
-		status = ixgbe_write_ee_hostif_data_X550(hw, offset + i,
-							 data[i]);
-		if (status) {
-			hw_dbg(hw, "Eeprom buffered write failed\n");
+	/* Check every 10 usec to see if the address cycle completed.
+	 * The SB IOSF BUSY bit will clear when the operation is
+	 * complete
+	 */
+	for (i = 0; i < IXGBE_MDIO_COMMAND_TIMEOUT; i++) {
+		command = IXGBE_READ_REG(hw, IXGBE_SB_IOSF_INDIRECT_CTRL);
+		if ((command & IXGBE_SB_IOSF_CTRL_BUSY) == 0)
 			break;
-		}
+		usec_delay(10);
+	}
+	if (ctrl)
+		*ctrl = command;
+	if (i == IXGBE_MDIO_COMMAND_TIMEOUT) {
+		ERROR_REPORT1(IXGBE_ERROR_POLLING, "Wait timed out\n");
+		return IXGBE_ERR_PHY;
 	}
 
-	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
-
-	return status;
+	return IXGBE_SUCCESS;
 }
 
-/** ixgbe_write_iosf_sb_reg_x550 - Writes a value to specified register of the
- *  IOSF device
- *
+/**
+ *  ixgbe_write_iosf_sb_reg_x550 - Writes a value to specified register
+ *  of the IOSF device
  *  @hw: pointer to hardware structure
  *  @reg_addr: 32 bit PHY register to write
  *  @device_type: 3 bit device type
  *  @data: Data to write to the register
  **/
-static s32 ixgbe_write_iosf_sb_reg_x550(struct ixgbe_hw *hw, u32 reg_addr,
-					u32 device_type, u32 data)
+s32 ixgbe_write_iosf_sb_reg_x550(struct ixgbe_hw *hw, u32 reg_addr,
+			    u32 device_type, u32 data)
 {
 	u32 gssr = IXGBE_GSSR_PHY1_SM | IXGBE_GSSR_PHY0_SM;
 	u32 command, error;
 	s32 ret;
 
-	ret = hw->mac.ops.acquire_swfw_sync(hw, gssr);
-	if (ret)
+	ret = ixgbe_acquire_swfw_semaphore(hw, gssr);
+	if (ret != IXGBE_SUCCESS)
 		return ret;
 
 	ret = ixgbe_iosf_wait(hw, NULL);
-	if (ret)
+	if (ret != IXGBE_SUCCESS)
 		goto out;
 
 	command = ((reg_addr << IXGBE_SB_IOSF_CTRL_ADDR_SHIFT) |
@@ -1070,140 +1146,397 @@ static s32 ixgbe_write_iosf_sb_reg_x550(struct ixgbe_hw *hw, u32 reg_addr,
 	if ((command & IXGBE_SB_IOSF_CTRL_RESP_STAT_MASK) != 0) {
 		error = (command & IXGBE_SB_IOSF_CTRL_CMPL_ERR_MASK) >>
 			 IXGBE_SB_IOSF_CTRL_CMPL_ERR_SHIFT;
-		hw_dbg(hw, "Failed to write, error %x\n", error);
-		return IXGBE_ERR_PHY;
+		ERROR_REPORT2(IXGBE_ERROR_POLLING,
+			      "Failed to write, error %x\n", error);
+		ret = IXGBE_ERR_PHY;
 	}
 
 out:
-	hw->mac.ops.release_swfw_sync(hw, gssr);
+	ixgbe_release_swfw_semaphore(hw, gssr);
 	return ret;
 }
 
-/** ixgbe_setup_ixfi_x550em - Configure the KR PHY for iXFI mode.
+/**
+ *  ixgbe_read_iosf_sb_reg_x550 - Reads specified register of the IOSF device
  *  @hw: pointer to hardware structure
- *  @speed: the link speed to force
- *
- *  Configures the integrated KR PHY to use iXFI mode. Used to connect an
- *  internal and external PHY at a specific speed, without autonegotiation.
+ *  @reg_addr: 32 bit PHY register to write
+ *  @device_type: 3 bit device type
+ *  @data: Pointer to read data from the register
  **/
-static s32 ixgbe_setup_ixfi_x550em(struct ixgbe_hw *hw, ixgbe_link_speed *speed)
+s32 ixgbe_read_iosf_sb_reg_x550(struct ixgbe_hw *hw, u32 reg_addr,
+			   u32 device_type, u32 *data)
 {
-	s32 status;
-	u32 reg_val;
+	u32 gssr = IXGBE_GSSR_PHY1_SM | IXGBE_GSSR_PHY0_SM;
+	u32 command, error;
+	s32 ret;
 
-	/* Disable AN and force speed to 10G Serial. */
-	status = ixgbe_read_iosf_sb_reg_x550(hw,
-					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
-					IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
-	if (status)
-		return status;
+	ret = ixgbe_acquire_swfw_semaphore(hw, gssr);
+	if (ret != IXGBE_SUCCESS)
+		return ret;
 
-	reg_val &= ~IXGBE_KRM_LINK_CTRL_1_TETH_AN_ENABLE;
-	reg_val &= ~IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_MASK;
+	ret = ixgbe_iosf_wait(hw, NULL);
+	if (ret != IXGBE_SUCCESS)
+		goto out;
 
-	/* Select forced link speed for internal PHY. */
-	switch (*speed) {
-	case IXGBE_LINK_SPEED_10GB_FULL:
-		reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_10G;
-		break;
-	case IXGBE_LINK_SPEED_1GB_FULL:
-		reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_1G;
-		break;
-	default:
-		/* Other link speeds are not supported by internal KR PHY. */
-		return IXGBE_ERR_LINK_SETUP;
+	command = ((reg_addr << IXGBE_SB_IOSF_CTRL_ADDR_SHIFT) |
+		   (device_type << IXGBE_SB_IOSF_CTRL_TARGET_SELECT_SHIFT));
+
+	/* Write IOSF control register */
+	IXGBE_WRITE_REG(hw, IXGBE_SB_IOSF_INDIRECT_CTRL, command);
+
+	ret = ixgbe_iosf_wait(hw, &command);
+
+	if ((command & IXGBE_SB_IOSF_CTRL_RESP_STAT_MASK) != 0) {
+		error = (command & IXGBE_SB_IOSF_CTRL_CMPL_ERR_MASK) >>
+			 IXGBE_SB_IOSF_CTRL_CMPL_ERR_SHIFT;
+		ERROR_REPORT2(IXGBE_ERROR_POLLING,
+				"Failed to read, error %x\n", error);
+		ret = IXGBE_ERR_PHY;
 	}
 
-	status = ixgbe_write_iosf_sb_reg_x550(hw,
-				IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
-				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
-	if (status)
-		return status;
+	if (ret == IXGBE_SUCCESS)
+		*data = IXGBE_READ_REG(hw, IXGBE_SB_IOSF_INDIRECT_DATA);
 
-	/* Disable training protocol FSM. */
-	status = ixgbe_read_iosf_sb_reg_x550(hw,
-				IXGBE_KRM_RX_TRN_LINKUP_CTRL(hw->bus.lan_id),
-				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
-	if (status)
-		return status;
+out:
+	ixgbe_release_swfw_semaphore(hw, gssr);
+	return ret;
+}
 
-	reg_val |= IXGBE_KRM_RX_TRN_LINKUP_CTRL_CONV_WO_PROTOCOL;
-	status = ixgbe_write_iosf_sb_reg_x550(hw,
-				IXGBE_KRM_RX_TRN_LINKUP_CTRL(hw->bus.lan_id),
-				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
-	if (status)
-		return status;
+/**
+ * ixgbe_get_phy_token - Get the token for shared phy access
+ * @hw: Pointer to hardware structure
+ */
 
-	/* Disable Flex from training TXFFE. */
-	status = ixgbe_read_iosf_sb_reg_x550(hw,
-				IXGBE_KRM_DSP_TXFFE_STATE_4(hw->bus.lan_id),
-				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
-	if (status)
-		return status;
+s32 ixgbe_get_phy_token(struct ixgbe_hw *hw)
+{
+	struct ixgbe_hic_phy_token_req token_cmd;
+	s32 status;
 
-	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_C0_EN;
-	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_CP1_CN1_EN;
-	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_CO_ADAPT_EN;
-	status = ixgbe_write_iosf_sb_reg_x550(hw,
-				IXGBE_KRM_DSP_TXFFE_STATE_4(hw->bus.lan_id),
-				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
-	if (status)
+	token_cmd.hdr.cmd = FW_PHY_TOKEN_REQ_CMD;
+	token_cmd.hdr.buf_len = FW_PHY_TOKEN_REQ_LEN;
+	token_cmd.hdr.cmd_or_resp.cmd_resv = 0;
+	token_cmd.hdr.checksum = FW_DEFAULT_CHECKSUM;
+	token_cmd.port_number = hw->bus.lan_id;
+	token_cmd.command_type = FW_PHY_TOKEN_REQ;
+	token_cmd.pad = 0;
+	status = ixgbe_host_interface_command(hw, (u32 *)&token_cmd,
+					      sizeof(token_cmd),
+					      IXGBE_HI_COMMAND_TIMEOUT,
+					      true);
+	if (status) {
+		DEBUGOUT1("Issuing host interface command failed with Status = %d\n",
+			  status);
 		return status;
+	}
+	if (token_cmd.hdr.cmd_or_resp.ret_status == FW_PHY_TOKEN_OK)
+		return IXGBE_SUCCESS;
+	if (token_cmd.hdr.cmd_or_resp.ret_status != FW_PHY_TOKEN_RETRY) {
+		DEBUGOUT1("Host interface command returned 0x%08x , returning IXGBE_ERR_FW_RESP_INVALID\n",
+			  token_cmd.hdr.cmd_or_resp.ret_status);
+		return IXGBE_ERR_FW_RESP_INVALID;
+	}
 
-	status = ixgbe_read_iosf_sb_reg_x550(hw,
-				IXGBE_KRM_DSP_TXFFE_STATE_5(hw->bus.lan_id),
-				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
-	if (status)
-		return status;
+	DEBUGOUT("Returning  IXGBE_ERR_TOKEN_RETRY\n");
+	return IXGBE_ERR_TOKEN_RETRY;
+}
 
-	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_C0_EN;
-	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_CP1_CN1_EN;
-	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_CO_ADAPT_EN;
-	status = ixgbe_write_iosf_sb_reg_x550(hw,
-				IXGBE_KRM_DSP_TXFFE_STATE_5(hw->bus.lan_id),
-				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
-	if (status)
-		return status;
+/**
+ * ixgbe_put_phy_token - Put the token for shared phy access
+ * @hw: Pointer to hardware structure
+ */
 
-	/* Enable override for coefficients. */
-	status = ixgbe_read_iosf_sb_reg_x550(hw,
-				IXGBE_KRM_TX_COEFF_CTRL_1(hw->bus.lan_id),
-				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
-	if (status)
-		return status;
+s32 ixgbe_put_phy_token(struct ixgbe_hw *hw)
+{
+	struct ixgbe_hic_phy_token_req token_cmd;
+	s32 status;
 
-	reg_val |= IXGBE_KRM_TX_COEFF_CTRL_1_OVRRD_EN;
-	reg_val |= IXGBE_KRM_TX_COEFF_CTRL_1_CZERO_EN;
-	reg_val |= IXGBE_KRM_TX_COEFF_CTRL_1_CPLUS1_OVRRD_EN;
-	reg_val |= IXGBE_KRM_TX_COEFF_CTRL_1_CMINUS1_OVRRD_EN;
-	status = ixgbe_write_iosf_sb_reg_x550(hw,
-				IXGBE_KRM_TX_COEFF_CTRL_1(hw->bus.lan_id),
-				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+	token_cmd.hdr.cmd = FW_PHY_TOKEN_REQ_CMD;
+	token_cmd.hdr.buf_len = FW_PHY_TOKEN_REQ_LEN;
+	token_cmd.hdr.cmd_or_resp.cmd_resv = 0;
+	token_cmd.hdr.checksum = FW_DEFAULT_CHECKSUM;
+	token_cmd.port_number = hw->bus.lan_id;
+	token_cmd.command_type = FW_PHY_TOKEN_REL;
+	token_cmd.pad = 0;
+	status = ixgbe_host_interface_command(hw, (u32 *)&token_cmd,
+					      sizeof(token_cmd),
+					      IXGBE_HI_COMMAND_TIMEOUT,
+					      true);
 	if (status)
 		return status;
+	if (token_cmd.hdr.cmd_or_resp.ret_status == FW_PHY_TOKEN_OK)
+		return IXGBE_SUCCESS;
 
-	/* Toggle port SW reset by AN reset. */
-	status = ixgbe_read_iosf_sb_reg_x550(hw,
-				IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
-				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
-	if (status)
-		return status;
+	DEBUGOUT("Put PHY Token host interface command failed");
+	return IXGBE_ERR_FW_RESP_INVALID;
+}
 
-	reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_RESTART;
-	status = ixgbe_write_iosf_sb_reg_x550(hw,
-				IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
-				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+/**
+ *  ixgbe_write_iosf_sb_reg_x550a - Writes a value to specified register
+ *  of the IOSF device
+ *  @hw: pointer to hardware structure
+ *  @reg_addr: 32 bit PHY register to write
+ *  @device_type: 3 bit device type
+ *  @data: Data to write to the register
+ **/
+s32 ixgbe_write_iosf_sb_reg_x550a(struct ixgbe_hw *hw, u32 reg_addr,
+				  u32 device_type, u32 data)
+{
+	struct ixgbe_hic_internal_phy_req write_cmd;
+	s32 status;
+	UNREFERENCED_1PARAMETER(device_type);
+
+	memset(&write_cmd, 0, sizeof(write_cmd));
+	write_cmd.hdr.cmd = FW_INT_PHY_REQ_CMD;
+	write_cmd.hdr.buf_len = FW_INT_PHY_REQ_LEN;
+	write_cmd.hdr.checksum = FW_DEFAULT_CHECKSUM;
+	write_cmd.port_number = hw->bus.lan_id;
+	write_cmd.command_type = FW_INT_PHY_REQ_WRITE;
+	write_cmd.address = IXGBE_CPU_TO_BE16(reg_addr);
+	write_cmd.write_data = IXGBE_CPU_TO_BE32(data);
+
+	status = ixgbe_host_interface_command(hw, (u32 *)&write_cmd,
+					      sizeof(write_cmd),
+					      IXGBE_HI_COMMAND_TIMEOUT, false);
+
+	return status;
+}
+
+/**
+ *  ixgbe_read_iosf_sb_reg_x550a - Reads specified register of the IOSF device
+ *  @hw: pointer to hardware structure
+ *  @reg_addr: 32 bit PHY register to write
+ *  @device_type: 3 bit device type
+ *  @data: Pointer to read data from the register
+ **/
+s32 ixgbe_read_iosf_sb_reg_x550a(struct ixgbe_hw *hw, u32 reg_addr,
+				 u32 device_type, u32 *data)
+{
+	union {
+		struct ixgbe_hic_internal_phy_req cmd;
+		struct ixgbe_hic_internal_phy_resp rsp;
+	} hic;
+	s32 status;
+	UNREFERENCED_1PARAMETER(device_type);
+
+	memset(&hic, 0, sizeof(hic));
+	hic.cmd.hdr.cmd = FW_INT_PHY_REQ_CMD;
+	hic.cmd.hdr.buf_len = FW_INT_PHY_REQ_LEN;
+	hic.cmd.hdr.checksum = FW_DEFAULT_CHECKSUM;
+	hic.cmd.port_number = hw->bus.lan_id;
+	hic.cmd.command_type = FW_INT_PHY_REQ_READ;
+	hic.cmd.address = IXGBE_CPU_TO_BE16(reg_addr);
+
+	status = ixgbe_host_interface_command(hw, (u32 *)&hic.cmd,
+					      sizeof(hic.cmd),
+					      IXGBE_HI_COMMAND_TIMEOUT, true);
+
+	/* Extract the register value from the response. */
+	*data = IXGBE_BE32_TO_CPU(hic.rsp.read_data);
 
 	return status;
 }
 
 /**
+ *  ixgbe_disable_mdd_X550
+ *  @hw: pointer to hardware structure
+ *
+ *  Disable malicious driver detection
+ **/
+void ixgbe_disable_mdd_X550(struct ixgbe_hw *hw)
+{
+	u32 reg;
+
+	DEBUGFUNC("ixgbe_disable_mdd_X550");
+
+	/* Disable MDD for TX DMA and interrupt */
+	reg = IXGBE_READ_REG(hw, IXGBE_DMATXCTL);
+	reg &= ~(IXGBE_DMATXCTL_MDP_EN | IXGBE_DMATXCTL_MBINTEN);
+	IXGBE_WRITE_REG(hw, IXGBE_DMATXCTL, reg);
+
+	/* Disable MDD for RX and interrupt */
+	reg = IXGBE_READ_REG(hw, IXGBE_RDRXCTL);
+	reg &= ~(IXGBE_RDRXCTL_MDP_EN | IXGBE_RDRXCTL_MBINTEN);
+	IXGBE_WRITE_REG(hw, IXGBE_RDRXCTL, reg);
+}
+
+/**
+ *  ixgbe_enable_mdd_X550
+ *  @hw: pointer to hardware structure
+ *
+ *  Enable malicious driver detection
+ **/
+void ixgbe_enable_mdd_X550(struct ixgbe_hw *hw)
+{
+	u32 reg;
+
+	DEBUGFUNC("ixgbe_enable_mdd_X550");
+
+	/* Enable MDD for TX DMA and interrupt */
+	reg = IXGBE_READ_REG(hw, IXGBE_DMATXCTL);
+	reg |= (IXGBE_DMATXCTL_MDP_EN | IXGBE_DMATXCTL_MBINTEN);
+	IXGBE_WRITE_REG(hw, IXGBE_DMATXCTL, reg);
+
+	/* Enable MDD for RX and interrupt */
+	reg = IXGBE_READ_REG(hw, IXGBE_RDRXCTL);
+	reg |= (IXGBE_RDRXCTL_MDP_EN | IXGBE_RDRXCTL_MBINTEN);
+	IXGBE_WRITE_REG(hw, IXGBE_RDRXCTL, reg);
+}
+
+/**
+ *  ixgbe_restore_mdd_vf_X550
+ *  @hw: pointer to hardware structure
+ *  @vf: vf index
+ *
+ *  Restore VF that was disabled during malicious driver detection event
+ **/
+void ixgbe_restore_mdd_vf_X550(struct ixgbe_hw *hw, u32 vf)
+{
+	u32 idx, reg, num_qs, start_q, bitmask;
+
+	DEBUGFUNC("ixgbe_restore_mdd_vf_X550");
+
+	/* Map VF to queues */
+	reg = IXGBE_READ_REG(hw, IXGBE_MRQC);
+	switch (reg & IXGBE_MRQC_MRQE_MASK) {
+	case IXGBE_MRQC_VMDQRT8TCEN:
+		num_qs = 8;  /* 16 VFs / pools */
+		bitmask = 0x000000FF;
+		break;
+	case IXGBE_MRQC_VMDQRSS32EN:
+	case IXGBE_MRQC_VMDQRT4TCEN:
+		num_qs = 4;  /* 32 VFs / pools */
+		bitmask = 0x0000000F;
+		break;
+	default:            /* 64 VFs / pools */
+		num_qs = 2;
+		bitmask = 0x00000003;
+		break;
+	}
+	start_q = vf * num_qs;
+
+	/* Release vf's queues by clearing WQBR_TX and WQBR_RX (RW1C) */
+	idx = start_q / 32;
+	reg = 0;
+	reg |= (bitmask << (start_q % 32));
+	IXGBE_WRITE_REG(hw, IXGBE_WQBR_TX(idx), reg);
+	IXGBE_WRITE_REG(hw, IXGBE_WQBR_RX(idx), reg);
+}
+
+/**
+ *  ixgbe_mdd_event_X550
+ *  @hw: pointer to hardware structure
+ *  @vf_bitmap: vf bitmap of malicious vfs
+ *
+ *  Handle malicious driver detection event.
+ **/
+void ixgbe_mdd_event_X550(struct ixgbe_hw *hw, u32 *vf_bitmap)
+{
+	u32 wqbr;
+	u32 i, j, reg, q, shift, vf, idx;
+
+	DEBUGFUNC("ixgbe_mdd_event_X550");
+
+	/* figure out pool size for mapping to vf's */
+	reg = IXGBE_READ_REG(hw, IXGBE_MRQC);
+	switch (reg & IXGBE_MRQC_MRQE_MASK) {
+	case IXGBE_MRQC_VMDQRT8TCEN:
+		shift = 3;  /* 16 VFs / pools */
+		break;
+	case IXGBE_MRQC_VMDQRSS32EN:
+	case IXGBE_MRQC_VMDQRT4TCEN:
+		shift = 2;  /* 32 VFs / pools */
+		break;
+	default:
+		shift = 1;  /* 64 VFs / pools */
+		break;
+	}
+
+	/* Read WQBR_TX and WQBR_RX and check for malicious queues */
+	for (i = 0; i < 4; i++) {
+		wqbr = IXGBE_READ_REG(hw, IXGBE_WQBR_TX(i));
+		wqbr |= IXGBE_READ_REG(hw, IXGBE_WQBR_RX(i));
+
+		if (!wqbr)
+			continue;
+
+		/* Get malicious queue */
+		for (j = 0; j < 32 && wqbr; j++) {
+
+			if (!(wqbr & (1 << j)))
+				continue;
+
+			/* Get queue from bitmask */
+			q = j + (i * 32);
+
+			/* Map queue to vf */
+			vf = (q >> shift);
+
+			/* Set vf bit in vf_bitmap */
+			idx = vf / 32;
+			vf_bitmap[idx] |= (1 << (vf % 32));
+			wqbr &= ~(1 << j);
+		}
+	}
+}
+
+/**
+ *  ixgbe_get_media_type_X550em - Get media type
+ *  @hw: pointer to hardware structure
+ *
+ *  Returns the media type (fiber, copper, backplane)
+ */
+enum ixgbe_media_type ixgbe_get_media_type_X550em(struct ixgbe_hw *hw)
+{
+	enum ixgbe_media_type media_type;
+
+	DEBUGFUNC("ixgbe_get_media_type_X550em");
+
+	/* Detect if there is a copper PHY attached. */
+	switch (hw->device_id) {
+	case IXGBE_DEV_ID_X550EM_X_KR:
+	case IXGBE_DEV_ID_X550EM_X_KX4:
+	case IXGBE_DEV_ID_X550EM_X_XFI:
+	case IXGBE_DEV_ID_X550EM_A_KR:
+	case IXGBE_DEV_ID_X550EM_A_KR_L:
+		media_type = ixgbe_media_type_backplane;
+		break;
+	case IXGBE_DEV_ID_X550EM_X_SFP:
+	case IXGBE_DEV_ID_X550EM_A_SFP:
+	case IXGBE_DEV_ID_X550EM_A_SFP_N:
+	case IXGBE_DEV_ID_X550EM_A_QSFP:
+	case IXGBE_DEV_ID_X550EM_A_QSFP_N:
+		media_type = ixgbe_media_type_fiber;
+		break;
+	case IXGBE_DEV_ID_X550EM_X_1G_T:
+	case IXGBE_DEV_ID_X550EM_X_10G_T:
+	case IXGBE_DEV_ID_X550EM_A_10G_T:
+		media_type = ixgbe_media_type_copper;
+		break;
+	case IXGBE_DEV_ID_X550EM_A_SGMII:
+	case IXGBE_DEV_ID_X550EM_A_SGMII_L:
+		media_type = ixgbe_media_type_backplane;
+		hw->phy.type = ixgbe_phy_sgmii;
+		break;
+	case IXGBE_DEV_ID_X550EM_A_1G_T:
+	case IXGBE_DEV_ID_X550EM_A_1G_T_L:
+		media_type = ixgbe_media_type_copper;
+		break;
+	default:
+		media_type = ixgbe_media_type_unknown;
+		break;
+	}
+	return media_type;
+}
+
+/**
  *  ixgbe_supported_sfp_modules_X550em - Check if SFP module type is supported
  *  @hw: pointer to hardware structure
  *  @linear: true if SFP module is linear
  */
-static s32 ixgbe_supported_sfp_modules_X550em(struct ixgbe_hw *hw, bool *linear)
+STATIC s32 ixgbe_supported_sfp_modules_X550em(struct ixgbe_hw *hw, bool *linear)
 {
+	DEBUGFUNC("ixgbe_supported_sfp_modules_X550em");
+
 	switch (hw->phy.sfp_type) {
 	case ixgbe_sfp_type_not_present:
 		return IXGBE_ERR_SFP_NOT_PRESENT;
@@ -1228,152 +1561,252 @@ static s32 ixgbe_supported_sfp_modules_X550em(struct ixgbe_hw *hw, bool *linear)
 		return IXGBE_ERR_SFP_NOT_SUPPORTED;
 	}
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
- *  ixgbe_setup_mac_link_sfp_x550em - Configure the KR PHY for SFP.
+ *  ixgbe_identify_sfp_module_X550em - Identifies SFP modules
  *  @hw: pointer to hardware structure
  *
- *  Configures the extern PHY and the integrated KR PHY for SFP support.
- */
-static s32
-ixgbe_setup_mac_link_sfp_x550em(struct ixgbe_hw *hw,
-				ixgbe_link_speed speed,
-				__always_unused bool autoneg_wait_to_complete)
+ *  Searches for and identifies the SFP module and assigns appropriate PHY type.
+ **/
+s32 ixgbe_identify_sfp_module_X550em(struct ixgbe_hw *hw)
 {
 	s32 status;
-	u16 slice, value;
-	bool setup_linear = false;
+	bool linear;
 
-	/* Check if SFP module is supported and linear */
-	status = ixgbe_supported_sfp_modules_X550em(hw, &setup_linear);
+	DEBUGFUNC("ixgbe_identify_sfp_module_X550em");
 
-	/* If no SFP module present, then return success. Return success since
-	 * there is no reason to configure CS4227 and SFP not present error is
-	 * not accepted in the setup MAC link flow.
-	 */
-	if (status == IXGBE_ERR_SFP_NOT_PRESENT)
-		return 0;
+	status = ixgbe_identify_module_generic(hw);
 
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 
-	/* Configure CS4227 LINE side to 10G SR. */
-	slice = IXGBE_CS4227_LINE_SPARE22_MSB + (hw->bus.lan_id << 12);
-	value = IXGBE_CS4227_SPEED_10G;
-	status = ixgbe_write_i2c_combined_generic(hw, IXGBE_CS4227, slice,
-						  value);
-
-	/* Configure CS4227 for HOST connection rate then type. */
-	slice = IXGBE_CS4227_HOST_SPARE22_MSB + (hw->bus.lan_id << 12);
-	value = speed & IXGBE_LINK_SPEED_10GB_FULL ?
-		IXGBE_CS4227_SPEED_10G : IXGBE_CS4227_SPEED_1G;
-	status = ixgbe_write_i2c_combined_generic(hw, IXGBE_CS4227, slice,
-						  value);
-
-	slice = IXGBE_CS4227_HOST_SPARE24_LSB + (hw->bus.lan_id << 12);
-	if (setup_linear)
-		value = (IXGBE_CS4227_EDC_MODE_CX1 << 1) | 1;
-	else
-		value = (IXGBE_CS4227_EDC_MODE_SR << 1) | 1;
-	status = ixgbe_write_i2c_combined_generic(hw, IXGBE_CS4227, slice,
-						  value);
-
-	/* If internal link mode is XFI, then setup XFI internal link. */
-	if (!(hw->phy.nw_mng_if_sel & IXGBE_NW_MNG_IF_SEL_INT_PHY_MODE))
-		status = ixgbe_setup_ixfi_x550em(hw, &speed);
+	/* Check if SFP module is supported */
+	status = ixgbe_supported_sfp_modules_X550em(hw, &linear);
 
 	return status;
 }
 
 /**
- * ixgbe_setup_mac_link_t_X550em - Sets the auto advertised link speed
- * @hw: pointer to hardware structure
- * @speed: new link speed
- * @autoneg_wait_to_complete: true when waiting for completion is needed
- *
- * Setup internal/external PHY link speed based on link speed, then set
- * external PHY auto advertised link speed.
- *
- * Returns error status for any failure
- **/
-static s32 ixgbe_setup_mac_link_t_X550em(struct ixgbe_hw *hw,
-					 ixgbe_link_speed speed,
-					 bool autoneg_wait)
+ *  ixgbe_setup_sfp_modules_X550em - Setup MAC link ops
+ *  @hw: pointer to hardware structure
+ */
+s32 ixgbe_setup_sfp_modules_X550em(struct ixgbe_hw *hw)
 {
 	s32 status;
-	ixgbe_link_speed force_speed;
+	bool linear;
 
-	/* Setup internal/external PHY link speed to iXFI (10G), unless
-	 * only 1G is auto advertised then setup KX link.
-	 */
-	if (speed & IXGBE_LINK_SPEED_10GB_FULL)
-		force_speed = IXGBE_LINK_SPEED_10GB_FULL;
-	else
-		force_speed = IXGBE_LINK_SPEED_1GB_FULL;
+	DEBUGFUNC("ixgbe_setup_sfp_modules_X550em");
 
-	/* If internal link mode is XFI, then setup XFI internal link. */
-	if (!(hw->phy.nw_mng_if_sel & IXGBE_NW_MNG_IF_SEL_INT_PHY_MODE)) {
-		status = ixgbe_setup_ixfi_x550em(hw, &force_speed);
+	/* Check if SFP module is supported */
+	status = ixgbe_supported_sfp_modules_X550em(hw, &linear);
 
-		if (status)
-			return status;
-	}
+	if (status != IXGBE_SUCCESS)
+		return status;
 
-	return hw->phy.ops.setup_link_speed(hw, speed, autoneg_wait);
+	ixgbe_init_mac_link_ops_X550em(hw);
+	hw->phy.ops.reset = NULL;
+
+	return IXGBE_SUCCESS;
 }
 
-/** ixgbe_check_link_t_X550em - Determine link and speed status
-  * @hw: pointer to hardware structure
-  * @speed: pointer to link speed
-  * @link_up: true when link is up
-  * @link_up_wait_to_complete: bool used to wait for link up or not
-  *
-  * Check that both the MAC and X557 external PHY have link.
-  **/
-static s32 ixgbe_check_link_t_X550em(struct ixgbe_hw *hw,
-				     ixgbe_link_speed *speed,
-				     bool *link_up,
-				     bool link_up_wait_to_complete)
+/**
+*  ixgbe_restart_an_internal_phy_x550em - restart autonegotiation for the
+*  internal PHY
+*  @hw: pointer to hardware structure
+**/
+STATIC s32 ixgbe_restart_an_internal_phy_x550em(struct ixgbe_hw *hw)
 {
-	u32 status;
-	u16 autoneg_status;
+	s32 status;
+	u32 link_ctrl;
 
-	if (hw->mac.ops.get_media_type(hw) != ixgbe_media_type_copper)
-		return IXGBE_ERR_CONFIG;
+	/* Restart auto-negotiation. */
+	status = hw->mac.ops.read_iosf_sb_reg(hw,
+				       IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+				       IXGBE_SB_IOSF_TARGET_KR_PHY, &link_ctrl);
 
-	status = ixgbe_check_mac_link_generic(hw, speed, link_up,
-					      link_up_wait_to_complete);
-
-	/* If check link fails or MAC link is not up, then return */
-	if (status || !(*link_up))
+	if (status) {
+		DEBUGOUT("Auto-negotiation did not complete\n");
 		return status;
+	}
 
-	 /* MAC link is up, so check external PHY link.
-	  * Read this twice back to back to indicate current status.
-	  */
-	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_STATUS,
-				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
-				      &autoneg_status);
-	if (status)
-		return status;
+	link_ctrl |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_RESTART;
+	status = hw->mac.ops.write_iosf_sb_reg(hw,
+					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, link_ctrl);
 
-	/* If external PHY link is not up, then indicate link not up */
-	if (!(autoneg_status & IXGBE_MDIO_AUTO_NEG_LINK_STATUS))
-		*link_up = false;
+	if (hw->mac.type == ixgbe_mac_X550EM_a) {
+		u32 flx_mask_st20;
+
+		/* Indicate to FW that AN restart has been asserted */
+		status = hw->mac.ops.read_iosf_sb_reg(hw,
+				IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, &flx_mask_st20);
+
+		if (status) {
+			DEBUGOUT("Auto-negotiation did not complete\n");
+			return status;
+		}
+
+		flx_mask_st20 |= IXGBE_KRM_PMD_FLX_MASK_ST20_FW_AN_RESTART;
+		status = hw->mac.ops.write_iosf_sb_reg(hw,
+				IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, flx_mask_st20);
+	}
+
+	return status;
+}
+
+/**
+ * ixgbe_setup_sgmii - Set up link for sgmii
+ * @hw: pointer to hardware structure
+ */
+STATIC s32 ixgbe_setup_sgmii(struct ixgbe_hw *hw, ixgbe_link_speed speed,
+			     bool autoneg_wait)
+{
+	struct ixgbe_mac_info *mac = &hw->mac;
+	u32 lval, sval, flx_val;
+	s32 rc;
+
+	rc = mac->ops.read_iosf_sb_reg(hw,
+				       IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+				       IXGBE_SB_IOSF_TARGET_KR_PHY, &lval);
+	if (rc)
+		return rc;
+
+	lval &= ~IXGBE_KRM_LINK_CTRL_1_TETH_AN_ENABLE;
+	lval &= ~IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_MASK;
+	lval |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_SGMII_EN;
+	lval |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_CLAUSE_37_EN;
+	lval |= IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_1G;
+	rc = mac->ops.write_iosf_sb_reg(hw,
+					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, lval);
+	if (rc)
+		return rc;
+
+	rc = mac->ops.read_iosf_sb_reg(hw,
+				       IXGBE_KRM_SGMII_CTRL(hw->bus.lan_id),
+				       IXGBE_SB_IOSF_TARGET_KR_PHY, &sval);
+	if (rc)
+		return rc;
+
+	sval |= IXGBE_KRM_SGMII_CTRL_MAC_TAR_FORCE_10_D;
+	sval |= IXGBE_KRM_SGMII_CTRL_MAC_TAR_FORCE_100_D;
+	rc = mac->ops.write_iosf_sb_reg(hw,
+					IXGBE_KRM_SGMII_CTRL(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, sval);
+	if (rc)
+		return rc;
+
+	rc = mac->ops.read_iosf_sb_reg(hw,
+				    IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				    IXGBE_SB_IOSF_TARGET_KR_PHY, &flx_val);
+	if (rc)
+		return rc;
+
+	flx_val &= ~IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_MASK;
+	flx_val |= IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_1G;
+	flx_val &= ~IXGBE_KRM_PMD_FLX_MASK_ST20_AN_EN;
+	flx_val |= IXGBE_KRM_PMD_FLX_MASK_ST20_SGMII_EN;
+	flx_val |= IXGBE_KRM_PMD_FLX_MASK_ST20_AN37_EN;
+
+	rc = mac->ops.write_iosf_sb_reg(hw,
+				    IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				    IXGBE_SB_IOSF_TARGET_KR_PHY, flx_val);
+	if (rc)
+		return rc;
+
+	rc = ixgbe_restart_an_internal_phy_x550em(hw);
+	if (rc)
+		return rc;
+
+	return hw->phy.ops.setup_link_speed(hw, speed, autoneg_wait);
+}
+
+/**
+ * ixgbe_setup_sgmii_fw - Set up link for internal PHY SGMII auto-negotiation
+ * @hw: pointer to hardware structure
+ */
+STATIC s32 ixgbe_setup_sgmii_fw(struct ixgbe_hw *hw, ixgbe_link_speed speed,
+				bool autoneg_wait)
+{
+	struct ixgbe_mac_info *mac = &hw->mac;
+	u32 lval, sval, flx_val;
+	s32 rc;
+
+	rc = mac->ops.read_iosf_sb_reg(hw,
+				       IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+				       IXGBE_SB_IOSF_TARGET_KR_PHY, &lval);
+	if (rc)
+		return rc;
+
+	lval &= ~IXGBE_KRM_LINK_CTRL_1_TETH_AN_ENABLE;
+	lval &= ~IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_MASK;
+	lval |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_SGMII_EN;
+	lval |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_CLAUSE_37_EN;
+	lval &= ~IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_1G;
+	rc = mac->ops.write_iosf_sb_reg(hw,
+					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, lval);
+	if (rc)
+		return rc;
+
+	rc = mac->ops.read_iosf_sb_reg(hw,
+				       IXGBE_KRM_SGMII_CTRL(hw->bus.lan_id),
+				       IXGBE_SB_IOSF_TARGET_KR_PHY, &sval);
+	if (rc)
+		return rc;
+
+	sval &= ~IXGBE_KRM_SGMII_CTRL_MAC_TAR_FORCE_10_D;
+	sval &= ~IXGBE_KRM_SGMII_CTRL_MAC_TAR_FORCE_100_D;
+	rc = mac->ops.write_iosf_sb_reg(hw,
+					IXGBE_KRM_SGMII_CTRL(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, sval);
+	if (rc)
+		return rc;
+
+	rc = mac->ops.write_iosf_sb_reg(hw,
+					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, lval);
+	if (rc)
+		return rc;
+
+	rc = mac->ops.read_iosf_sb_reg(hw,
+				    IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				    IXGBE_SB_IOSF_TARGET_KR_PHY, &flx_val);
+	if (rc)
+		return rc;
+
+	flx_val &= ~IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_MASK;
+	flx_val |= IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_AN;
+	flx_val &= ~IXGBE_KRM_PMD_FLX_MASK_ST20_AN_EN;
+	flx_val |= IXGBE_KRM_PMD_FLX_MASK_ST20_SGMII_EN;
+	flx_val |= IXGBE_KRM_PMD_FLX_MASK_ST20_AN37_EN;
+
+	rc = mac->ops.write_iosf_sb_reg(hw,
+				    IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				    IXGBE_SB_IOSF_TARGET_KR_PHY, flx_val);
+	if (rc)
+		return rc;
+
+	rc = ixgbe_restart_an_internal_phy_x550em(hw);
 
-	return 0;
+	return hw->phy.ops.setup_link_speed(hw, speed, autoneg_wait);
 }
 
-/** ixgbe_init_mac_link_ops_X550em - init mac link function pointers
+/**
+ *  ixgbe_init_mac_link_ops_X550em - init mac link function pointers
  *  @hw: pointer to hardware structure
- **/
-static void ixgbe_init_mac_link_ops_X550em(struct ixgbe_hw *hw)
+ */
+void ixgbe_init_mac_link_ops_X550em(struct ixgbe_hw *hw)
 {
 	struct ixgbe_mac_info *mac = &hw->mac;
 
-	switch (mac->ops.get_media_type(hw)) {
+	DEBUGFUNC("ixgbe_init_mac_link_ops_X550em");
+
+	switch (hw->mac.ops.get_media_type(hw)) {
 	case ixgbe_media_type_fiber:
 		/* CS4227 does not support autoneg, so disable the laser control
 		 * functions for SFP+ fiber
@@ -1382,56 +1815,76 @@ static void ixgbe_init_mac_link_ops_X550em(struct ixgbe_hw *hw)
 		mac->ops.enable_tx_laser = NULL;
 		mac->ops.flap_tx_laser = NULL;
 		mac->ops.setup_link = ixgbe_setup_mac_link_multispeed_fiber;
-		mac->ops.setup_mac_link = ixgbe_setup_mac_link_sfp_x550em;
 		mac->ops.set_rate_select_speed =
 					ixgbe_set_soft_rate_select_speed;
+
+		if ((hw->device_id == IXGBE_DEV_ID_X550EM_A_SFP_N) ||
+		    (hw->device_id == IXGBE_DEV_ID_X550EM_A_SFP))
+			mac->ops.setup_mac_link =
+						ixgbe_setup_mac_link_sfp_x550a;
+		else
+			mac->ops.setup_mac_link =
+						ixgbe_setup_mac_link_sfp_x550em;
 		break;
 	case ixgbe_media_type_copper:
-		mac->ops.setup_link = ixgbe_setup_mac_link_t_X550em;
-		mac->ops.check_link = ixgbe_check_link_t_X550em;
+		if (hw->device_id == IXGBE_DEV_ID_X550EM_X_1G_T)
+			break;
+		if (hw->mac.type == ixgbe_mac_X550EM_a) {
+			if (hw->device_id == IXGBE_DEV_ID_X550EM_A_1G_T ||
+			    hw->device_id == IXGBE_DEV_ID_X550EM_A_1G_T_L) {
+				mac->ops.setup_link = ixgbe_setup_sgmii_fw;
+				mac->ops.check_link =
+						   ixgbe_check_mac_link_generic;
+			} else {
+				mac->ops.setup_link =
+						  ixgbe_setup_mac_link_t_X550em;
+			}
+		} else {
+			mac->ops.setup_link = ixgbe_setup_mac_link_t_X550em;
+			mac->ops.check_link = ixgbe_check_link_t_X550em;
+		}
+		break;
+	case ixgbe_media_type_backplane:
+		if (hw->device_id == IXGBE_DEV_ID_X550EM_A_SGMII ||
+		    hw->device_id == IXGBE_DEV_ID_X550EM_A_SGMII_L)
+			mac->ops.setup_link = ixgbe_setup_sgmii;
 		break;
 	default:
 		break;
 	}
 }
 
-/** ixgbe_setup_sfp_modules_X550em - Setup SFP module
- * @hw: pointer to hardware structure
+/**
+ *  ixgbe_get_link_capabilities_x550em - Determines link capabilities
+ *  @hw: pointer to hardware structure
+ *  @speed: pointer to link speed
+ *  @autoneg: true when autoneg or autotry is enabled
  */
-static s32 ixgbe_setup_sfp_modules_X550em(struct ixgbe_hw *hw)
+s32 ixgbe_get_link_capabilities_X550em(struct ixgbe_hw *hw,
+				       ixgbe_link_speed *speed,
+				       bool *autoneg)
 {
-	s32 status;
-	bool linear;
-
-	/* Check if SFP module is supported */
-	status = ixgbe_supported_sfp_modules_X550em(hw, &linear);
-	if (status)
-		return status;
+	DEBUGFUNC("ixgbe_get_link_capabilities_X550em");
 
-	ixgbe_init_mac_link_ops_X550em(hw);
-	hw->phy.ops.reset = NULL;
-
-	return 0;
-}
+	if (hw->phy.type == ixgbe_phy_fw) {
+		*autoneg = true;
+		*speed = hw->phy.speeds_supported;
+		return 0;
+	}
 
-/** ixgbe_get_link_capabilities_x550em - Determines link capabilities
- * @hw: pointer to hardware structure
- * @speed: pointer to link speed
- * @autoneg: true when autoneg or autotry is enabled
- **/
-static s32 ixgbe_get_link_capabilities_X550em(struct ixgbe_hw *hw,
-					      ixgbe_link_speed *speed,
-					      bool *autoneg)
-{
 	/* SFP */
 	if (hw->phy.media_type == ixgbe_media_type_fiber) {
+
 		/* CS4227 SFP must not enable auto-negotiation */
 		*autoneg = false;
 
+		/* Check if 1G SFP module. */
 		if (hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core0 ||
-		    hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core1) {
+		    hw->phy.sfp_type == ixgbe_sfp_type_1g_sx_core1
+		    || hw->phy.sfp_type == ixgbe_sfp_type_1g_lx_core0 ||
+		    hw->phy.sfp_type == ixgbe_sfp_type_1g_lx_core1) {
 			*speed = IXGBE_LINK_SPEED_1GB_FULL;
-			return 0;
+			return IXGBE_SUCCESS;
 		}
 
 		/* Link capabilities are based on SFP */
@@ -1441,26 +1894,49 @@ static s32 ixgbe_get_link_capabilities_X550em(struct ixgbe_hw *hw,
 		else
 			*speed = IXGBE_LINK_SPEED_10GB_FULL;
 	} else {
-		*speed = IXGBE_LINK_SPEED_10GB_FULL |
-			 IXGBE_LINK_SPEED_1GB_FULL;
+		switch (hw->phy.type) {
+		case ixgbe_phy_ext_1g_t:
+		case ixgbe_phy_sgmii:
+			*speed = IXGBE_LINK_SPEED_1GB_FULL;
+			break;
+		case ixgbe_phy_x550em_kr:
+			if (hw->mac.type == ixgbe_mac_X550EM_a) {
+				/* check different backplane modes */
+				if (hw->phy.nw_mng_if_sel &
+					   IXGBE_NW_MNG_IF_SEL_PHY_SPEED_2_5G) {
+					*speed = IXGBE_LINK_SPEED_2_5GB_FULL;
+					break;
+				} else if (hw->device_id ==
+						   IXGBE_DEV_ID_X550EM_A_KR_L) {
+					*speed = IXGBE_LINK_SPEED_1GB_FULL;
+					break;
+				}
+			}
+			/* fall through */
+		default:
+			*speed = IXGBE_LINK_SPEED_10GB_FULL |
+				 IXGBE_LINK_SPEED_1GB_FULL;
+			break;
+		}
 		*autoneg = true;
 	}
-	return 0;
+
+	return IXGBE_SUCCESS;
 }
 
 /**
  * ixgbe_get_lasi_ext_t_x550em - Determime external Base T PHY interrupt cause
  * @hw: pointer to hardware structure
  * @lsc: pointer to boolean flag which indicates whether external Base T
- *	 PHY interrupt is lsc
+ *       PHY interrupt is lsc
  *
  * Determime if external Base T PHY interrupt cause is high temperature
  * failure alarm or link status change.
  *
  * Return IXGBE_ERR_OVERTEMP if interrupt is high temperature
  * failure alarm, else return PHY access status.
- **/
-static s32 ixgbe_get_lasi_ext_t_x550em(struct ixgbe_hw *hw, bool *lsc)
+ */
+STATIC s32 ixgbe_get_lasi_ext_t_x550em(struct ixgbe_hw *hw, bool *lsc)
 {
 	u32 status;
 	u16 reg;
@@ -1472,7 +1948,8 @@ static s32 ixgbe_get_lasi_ext_t_x550em(struct ixgbe_hw *hw, bool *lsc)
 				      IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
 				      &reg);
 
-	if (status || !(reg & IXGBE_MDIO_GLOBAL_VEN_ALM_INT_EN))
+	if (status != IXGBE_SUCCESS ||
+	    !(reg & IXGBE_MDIO_GLOBAL_VEN_ALM_INT_EN))
 		return status;
 
 	/* Vendor Auto-Neg alarm triggered or Global alarm 1 triggered */
@@ -1480,16 +1957,17 @@ static s32 ixgbe_get_lasi_ext_t_x550em(struct ixgbe_hw *hw, bool *lsc)
 				      IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
 				      &reg);
 
-	if (status || !(reg & (IXGBE_MDIO_GLOBAL_AN_VEN_ALM_INT_EN |
-				IXGBE_MDIO_GLOBAL_ALARM_1_INT)))
+	if (status != IXGBE_SUCCESS ||
+	    !(reg & (IXGBE_MDIO_GLOBAL_AN_VEN_ALM_INT_EN |
+	    IXGBE_MDIO_GLOBAL_ALARM_1_INT)))
 		return status;
 
-	/* High temperature failure alarm triggered */
+	/* Global alarm triggered */
 	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_GLOBAL_ALARM_1,
 				      IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
 				      &reg);
 
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	/* If high temperature failure, then return over temp error and exit */
@@ -1497,27 +1975,43 @@ static s32 ixgbe_get_lasi_ext_t_x550em(struct ixgbe_hw *hw, bool *lsc)
 		/* power down the PHY in case the PHY FW didn't already */
 		ixgbe_set_copper_phy_power(hw, false);
 		return IXGBE_ERR_OVERTEMP;
+	} else if (reg & IXGBE_MDIO_GLOBAL_ALM_1_DEV_FAULT) {
+		/*  device fault alarm triggered */
+		status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_GLOBAL_FAULT_MSG,
+					  IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
+					  &reg);
+
+		if (status != IXGBE_SUCCESS)
+			return status;
+
+		/* if device fault was due to high temp alarm handle and exit */
+		if (reg == IXGBE_MDIO_GLOBAL_FAULT_MSG_HI_TMP) {
+			/* power down the PHY in case the PHY FW didn't */
+			ixgbe_set_copper_phy_power(hw, false);
+			return IXGBE_ERR_OVERTEMP;
+		}
 	}
 
 	/* Vendor alarm 2 triggered */
 	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_GLOBAL_CHIP_STD_INT_FLAG,
 				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE, &reg);
 
-	if (status || !(reg & IXGBE_MDIO_GLOBAL_STD_ALM2_INT))
+	if (status != IXGBE_SUCCESS ||
+	    !(reg & IXGBE_MDIO_GLOBAL_STD_ALM2_INT))
 		return status;
 
 	/* link connect/disconnect event occurred */
 	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_VENDOR_TX_ALARM2,
 				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE, &reg);
 
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	/* Indicate LSC */
 	if (reg & IXGBE_MDIO_AUTO_NEG_VEN_LSC)
 		*lsc = true;
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
@@ -1528,8 +2022,8 @@ static s32 ixgbe_get_lasi_ext_t_x550em(struct ixgbe_hw *hw, bool *lsc)
  * Base T PHY
  *
  * Returns PHY access status
- **/
-static s32 ixgbe_enable_lasi_ext_t_x550em(struct ixgbe_hw *hw)
+ */
+STATIC s32 ixgbe_enable_lasi_ext_t_x550em(struct ixgbe_hw *hw)
 {
 	u32 status;
 	u16 reg;
@@ -1539,38 +2033,57 @@ static s32 ixgbe_enable_lasi_ext_t_x550em(struct ixgbe_hw *hw)
 	status = ixgbe_get_lasi_ext_t_x550em(hw, &lsc);
 
 	/* Enable link status change alarm */
-	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_PMA_TX_VEN_LASI_INT_MASK,
-				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE, &reg);
-	if (status)
-		return status;
 
-	reg |= IXGBE_MDIO_PMA_TX_VEN_LASI_INT_EN;
+	/* Enable the LASI interrupts on X552 devices to receive notifications
+	 * of the link configurations of the external PHY and correspondingly
+	 * support the configuration of the internal iXFI link, since iXFI does
+	 * not support auto-negotiation. This is not required for X553 devices
+	 * having KR support, which performs auto-negotiations and which is used
+	 * as the internal link to the external PHY. Hence adding a check here
+	 * to avoid enabling LASI interrupts for X553 devices.
+	 */
+	if (hw->mac.type != ixgbe_mac_X550EM_a) {
+		status = hw->phy.ops.read_reg(hw,
+					IXGBE_MDIO_PMA_TX_VEN_LASI_INT_MASK,
+					IXGBE_MDIO_AUTO_NEG_DEV_TYPE, &reg);
+
+		if (status != IXGBE_SUCCESS)
+			return status;
 
-	status = hw->phy.ops.write_reg(hw, IXGBE_MDIO_PMA_TX_VEN_LASI_INT_MASK,
-				       IXGBE_MDIO_AUTO_NEG_DEV_TYPE, reg);
-	if (status)
-		return status;
+		reg |= IXGBE_MDIO_PMA_TX_VEN_LASI_INT_EN;
 
-	/* Enables high temperature failure alarm */
+		status = hw->phy.ops.write_reg(hw,
+					IXGBE_MDIO_PMA_TX_VEN_LASI_INT_MASK,
+					IXGBE_MDIO_AUTO_NEG_DEV_TYPE, reg);
+
+		if (status != IXGBE_SUCCESS)
+			return status;
+	}
+
+	/* Enable high temperature failure and global fault alarms */
 	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_GLOBAL_INT_MASK,
 				      IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
 				      &reg);
-	if (status)
+
+	if (status != IXGBE_SUCCESS)
 		return status;
 
-	reg |= IXGBE_MDIO_GLOBAL_INT_HI_TEMP_EN;
+	reg |= (IXGBE_MDIO_GLOBAL_INT_HI_TEMP_EN |
+		IXGBE_MDIO_GLOBAL_INT_DEV_FAULT_EN);
 
 	status = hw->phy.ops.write_reg(hw, IXGBE_MDIO_GLOBAL_INT_MASK,
 				       IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
 				       reg);
-	if (status)
+
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	/* Enable vendor Auto-Neg alarm and Global Interrupt Mask 1 alarm */
 	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_GLOBAL_INT_CHIP_VEN_MASK,
 				      IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
 				      &reg);
-	if (status)
+
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	reg |= (IXGBE_MDIO_GLOBAL_AN_VEN_ALM_INT_EN |
@@ -1579,293 +2092,1643 @@ static s32 ixgbe_enable_lasi_ext_t_x550em(struct ixgbe_hw *hw)
 	status = hw->phy.ops.write_reg(hw, IXGBE_MDIO_GLOBAL_INT_CHIP_VEN_MASK,
 				       IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
 				       reg);
-	if (status)
+
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	/* Enable chip-wide vendor alarm */
 	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_GLOBAL_INT_CHIP_STD_MASK,
 				      IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
 				      &reg);
-	if (status)
+
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	reg |= IXGBE_MDIO_GLOBAL_VEN_ALM_INT_EN;
 
-	status = hw->phy.ops.write_reg(hw, IXGBE_MDIO_GLOBAL_INT_CHIP_STD_MASK,
-				       IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
-				       reg);
+	status = hw->phy.ops.write_reg(hw, IXGBE_MDIO_GLOBAL_INT_CHIP_STD_MASK,
+				       IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
+				       reg);
+
+	return status;
+}
+
+/**
+ *  ixgbe_setup_kr_speed_x550em - Configure the KR PHY for link speed.
+ *  @hw: pointer to hardware structure
+ *  @speed: link speed
+ *
+ *  Configures the integrated KR PHY.
+ **/
+STATIC s32 ixgbe_setup_kr_speed_x550em(struct ixgbe_hw *hw,
+				       ixgbe_link_speed speed)
+{
+	s32 status;
+	u32 reg_val;
+
+	status = hw->mac.ops.read_iosf_sb_reg(hw,
+					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+	if (status)
+		return status;
+
+	reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_ENABLE;
+	reg_val &= ~(IXGBE_KRM_LINK_CTRL_1_TETH_AN_CAP_KR |
+		     IXGBE_KRM_LINK_CTRL_1_TETH_AN_CAP_KX);
+
+	/* Advertise 10G support. */
+	if (speed & IXGBE_LINK_SPEED_10GB_FULL)
+		reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_CAP_KR;
+
+	/* Advertise 1G support. */
+	if (speed & IXGBE_LINK_SPEED_1GB_FULL)
+		reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_CAP_KX;
+
+	status = hw->mac.ops.write_iosf_sb_reg(hw,
+					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+
+	if (hw->mac.type == ixgbe_mac_X550EM_a) {
+		/* Set lane mode  to KR auto negotiation */
+		status = hw->mac.ops.read_iosf_sb_reg(hw,
+				    IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				    IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+
+		if (status)
+			return status;
+
+		reg_val &= ~IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_MASK;
+		reg_val |= IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_AN;
+		reg_val |= IXGBE_KRM_PMD_FLX_MASK_ST20_AN_EN;
+		reg_val &= ~IXGBE_KRM_PMD_FLX_MASK_ST20_AN37_EN;
+		reg_val &= ~IXGBE_KRM_PMD_FLX_MASK_ST20_SGMII_EN;
+
+		status = hw->mac.ops.write_iosf_sb_reg(hw,
+				    IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				    IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+	}
+
+	return ixgbe_restart_an_internal_phy_x550em(hw);
+}
+
+/**
+ * ixgbe_reset_phy_fw - Reset firmware-controlled PHYs
+ * @hw: pointer to hardware structure
+ */
+static s32 ixgbe_reset_phy_fw(struct ixgbe_hw *hw)
+{
+	u32 store[FW_PHY_ACT_DATA_COUNT] = { 0 };
+	s32 rc;
+
+	if (hw->phy.reset_disable || ixgbe_check_reset_blocked(hw))
+		return IXGBE_SUCCESS;
+
+	rc = ixgbe_fw_phy_activity(hw, FW_PHY_ACT_PHY_SW_RESET, &store);
+	if (rc)
+		return rc;
+	memset(store, 0, sizeof(store));
+
+	rc = ixgbe_fw_phy_activity(hw, FW_PHY_ACT_INIT_PHY, &store);
+	if (rc)
+		return rc;
+
+	return ixgbe_setup_fw_link(hw);
+}
+
+/**
+ * ixgbe_check_overtemp_fw - Check firmware-controlled PHYs for overtemp
+ * @hw: pointer to hardware structure
+ */
+static s32 ixgbe_check_overtemp_fw(struct ixgbe_hw *hw)
+{
+	u32 store[FW_PHY_ACT_DATA_COUNT] = { 0 };
+	s32 rc;
+
+	rc = ixgbe_fw_phy_activity(hw, FW_PHY_ACT_GET_LINK_INFO, &store);
+	if (rc)
+		return rc;
+
+	if (store[0] & FW_PHY_ACT_GET_LINK_INFO_TEMP) {
+		ixgbe_shutdown_fw_phy(hw);
+		return IXGBE_ERR_OVERTEMP;
+	}
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_read_mng_if_sel_x550em - Read NW_MNG_IF_SEL register
+ *  @hw: pointer to hardware structure
+ *
+ *  Read NW_MNG_IF_SEL register and save field values, and check for valid field
+ *  values.
+ **/
+STATIC s32 ixgbe_read_mng_if_sel_x550em(struct ixgbe_hw *hw)
+{
+	/* Save NW management interface connected on board. This is used
+	 * to determine internal PHY mode.
+	 */
+	hw->phy.nw_mng_if_sel = IXGBE_READ_REG(hw, IXGBE_NW_MNG_IF_SEL);
+
+	/* If X552 (X550EM_a) and MDIO is connected to external PHY, then set
+	 * PHY address. This register field was has only been used for X552.
+	 */
+	if (hw->mac.type == ixgbe_mac_X550EM_a &&
+	    hw->phy.nw_mng_if_sel & IXGBE_NW_MNG_IF_SEL_MDIO_ACT) {
+		hw->phy.addr = (hw->phy.nw_mng_if_sel &
+				IXGBE_NW_MNG_IF_SEL_MDIO_PHY_ADD) >>
+			       IXGBE_NW_MNG_IF_SEL_MDIO_PHY_ADD_SHIFT;
+	}
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_init_phy_ops_X550em - PHY/SFP specific init
+ *  @hw: pointer to hardware structure
+ *
+ *  Initialize any function pointers that were not able to be
+ *  set during init_shared_code because the PHY/SFP type was
+ *  not known.  Perform the SFP init if necessary.
+ */
+s32 ixgbe_init_phy_ops_X550em(struct ixgbe_hw *hw)
+{
+	struct ixgbe_phy_info *phy = &hw->phy;
+	s32 ret_val;
+
+	DEBUGFUNC("ixgbe_init_phy_ops_X550em");
+
+	hw->mac.ops.set_lan_id(hw);
+	ixgbe_read_mng_if_sel_x550em(hw);
+
+	if (hw->mac.ops.get_media_type(hw) == ixgbe_media_type_fiber) {
+		phy->phy_semaphore_mask = IXGBE_GSSR_SHARED_I2C_SM;
+		ixgbe_setup_mux_ctl(hw);
+		phy->ops.identify_sfp = ixgbe_identify_sfp_module_X550em;
+	}
+
+	switch (hw->device_id) {
+	case IXGBE_DEV_ID_X550EM_A_1G_T:
+	case IXGBE_DEV_ID_X550EM_A_1G_T_L:
+		phy->ops.read_reg_mdi = NULL;
+		phy->ops.write_reg_mdi = NULL;
+		hw->phy.ops.read_reg = NULL;
+		hw->phy.ops.write_reg = NULL;
+		phy->ops.check_overtemp = ixgbe_check_overtemp_fw;
+		if (hw->bus.lan_id)
+			hw->phy.phy_semaphore_mask |= IXGBE_GSSR_PHY1_SM;
+		else
+			hw->phy.phy_semaphore_mask |= IXGBE_GSSR_PHY0_SM;
+
+		break;
+	case IXGBE_DEV_ID_X550EM_A_10G_T:
+	case IXGBE_DEV_ID_X550EM_A_SFP:
+		hw->phy.ops.read_reg = ixgbe_read_phy_reg_x550a;
+		hw->phy.ops.write_reg = ixgbe_write_phy_reg_x550a;
+		if (hw->bus.lan_id)
+			hw->phy.phy_semaphore_mask |= IXGBE_GSSR_PHY1_SM;
+		else
+			hw->phy.phy_semaphore_mask |= IXGBE_GSSR_PHY0_SM;
+		break;
+	case IXGBE_DEV_ID_X550EM_X_SFP:
+		/* set up for CS4227 usage */
+		hw->phy.phy_semaphore_mask = IXGBE_GSSR_SHARED_I2C_SM;
+		break;
+	case IXGBE_DEV_ID_X550EM_X_1G_T:
+		phy->ops.read_reg_mdi = NULL;
+		phy->ops.write_reg_mdi = NULL;
+	default:
+		break;
+	}
+
+	/* Identify the PHY or SFP module */
+	ret_val = phy->ops.identify(hw);
+	if (ret_val == IXGBE_ERR_SFP_NOT_SUPPORTED ||
+	    ret_val == IXGBE_ERR_PHY_ADDR_INVALID)
+		return ret_val;
+
+	/* Setup function pointers based on detected hardware */
+	ixgbe_init_mac_link_ops_X550em(hw);
+	if (phy->sfp_type != ixgbe_sfp_type_unknown)
+		phy->ops.reset = NULL;
+
+	/* Set functions pointers based on phy type */
+	switch (hw->phy.type) {
+	case ixgbe_phy_x550em_kx4:
+		phy->ops.setup_link = NULL;
+		phy->ops.read_reg = ixgbe_read_phy_reg_x550em;
+		phy->ops.write_reg = ixgbe_write_phy_reg_x550em;
+		break;
+	case ixgbe_phy_x550em_kr:
+		phy->ops.setup_link = ixgbe_setup_kr_x550em;
+		phy->ops.read_reg = ixgbe_read_phy_reg_x550em;
+		phy->ops.write_reg = ixgbe_write_phy_reg_x550em;
+		break;
+	case ixgbe_phy_ext_1g_t:
+		/* link is managed by FW */
+		phy->ops.setup_link = NULL;
+		phy->ops.reset = NULL;
+		break;
+	case ixgbe_phy_x550em_xfi:
+		/* link is managed by HW */
+		phy->ops.setup_link = NULL;
+		phy->ops.read_reg = ixgbe_read_phy_reg_x550em;
+		phy->ops.write_reg = ixgbe_write_phy_reg_x550em;
+		break;
+	case ixgbe_phy_x550em_ext_t:
+		/* If internal link mode is XFI, then setup iXFI internal link,
+		 * else setup KR now.
+		 */
+		phy->ops.setup_internal_link =
+					      ixgbe_setup_internal_phy_t_x550em;
+
+		/* setup SW LPLU only for first revision of X550EM_x */
+		if ((hw->mac.type == ixgbe_mac_X550EM_x) &&
+		    !(IXGBE_FUSES0_REV_MASK &
+		      IXGBE_READ_REG(hw, IXGBE_FUSES0_GROUP(0))))
+			phy->ops.enter_lplu = ixgbe_enter_lplu_t_x550em;
+
+		phy->ops.handle_lasi = ixgbe_handle_lasi_ext_t_x550em;
+		phy->ops.reset = ixgbe_reset_phy_t_X550em;
+		break;
+	case ixgbe_phy_sgmii:
+		phy->ops.setup_link = NULL;
+		break;
+	case ixgbe_phy_fw:
+		phy->ops.setup_link = ixgbe_setup_fw_link;
+		phy->ops.reset = ixgbe_reset_phy_fw;
+		break;
+	default:
+		break;
+	}
+	return ret_val;
+}
+
+/**
+ * ixgbe_set_mdio_speed - Set MDIO clock speed
+ *  @hw: pointer to hardware structure
+ */
+STATIC void ixgbe_set_mdio_speed(struct ixgbe_hw *hw)
+{
+	u32 hlreg0;
+
+	switch (hw->device_id) {
+	case IXGBE_DEV_ID_X550EM_X_10G_T:
+	case IXGBE_DEV_ID_X550EM_A_SGMII:
+	case IXGBE_DEV_ID_X550EM_A_SGMII_L:
+	case IXGBE_DEV_ID_X550EM_A_10G_T:
+	case IXGBE_DEV_ID_X550EM_A_SFP:
+	case IXGBE_DEV_ID_X550EM_A_QSFP:
+		/* Config MDIO clock speed before the first MDIO PHY access */
+		hlreg0 = IXGBE_READ_REG(hw, IXGBE_HLREG0);
+		hlreg0 &= ~IXGBE_HLREG0_MDCSPD;
+		IXGBE_WRITE_REG(hw, IXGBE_HLREG0, hlreg0);
+		break;
+	case IXGBE_DEV_ID_X550EM_A_1G_T:
+	case IXGBE_DEV_ID_X550EM_A_1G_T_L:
+		/* Select fast MDIO clock speed for these devices */
+		hlreg0 = IXGBE_READ_REG(hw, IXGBE_HLREG0);
+		hlreg0 |= IXGBE_HLREG0_MDCSPD;
+		IXGBE_WRITE_REG(hw, IXGBE_HLREG0, hlreg0);
+		break;
+	default:
+		break;
+	}
+}
+
+/**
+ *  ixgbe_reset_hw_X550em - Perform hardware reset
+ *  @hw: pointer to hardware structure
+ *
+ *  Resets the hardware by resetting the transmit and receive units, masks
+ *  and clears all interrupts, perform a PHY reset, and perform a link (MAC)
+ *  reset.
+ */
+s32 ixgbe_reset_hw_X550em(struct ixgbe_hw *hw)
+{
+	ixgbe_link_speed link_speed;
+	s32 status;
+	u32 ctrl = 0;
+	u32 i;
+	bool link_up = false;
+	u32 swfw_mask = hw->phy.phy_semaphore_mask;
+
+	DEBUGFUNC("ixgbe_reset_hw_X550em");
+
+	/* Call adapter stop to disable Tx/Rx and clear interrupts */
+	status = hw->mac.ops.stop_adapter(hw);
+	if (status != IXGBE_SUCCESS) {
+		DEBUGOUT1("Failed to stop adapter, STATUS = %d\n", status);
+		return status;
+	}
+	/* flush pending Tx transactions */
+	ixgbe_clear_tx_pending(hw);
+
+	ixgbe_set_mdio_speed(hw);
+
+	/* PHY ops must be identified and initialized prior to reset */
+	status = hw->phy.ops.init(hw);
+
+	if (status)
+		DEBUGOUT1("Failed to initialize PHY ops, STATUS = %d\n",
+			  status);
+
+	if (status == IXGBE_ERR_SFP_NOT_SUPPORTED ||
+	    status == IXGBE_ERR_PHY_ADDR_INVALID) {
+		DEBUGOUT("Returning from reset HW due to PHY init failure\n");
+		return status;
+	}
+
+	/* start the external PHY */
+	if (hw->phy.type == ixgbe_phy_x550em_ext_t) {
+		status = ixgbe_init_ext_t_x550em(hw);
+		if (status) {
+			DEBUGOUT1("Failed to start the external PHY, STATUS = %d\n",
+				  status);
+			return status;
+		}
+	}
+
+	/* Setup SFP module if there is one present. */
+	if (hw->phy.sfp_setup_needed) {
+		status = hw->mac.ops.setup_sfp(hw);
+		hw->phy.sfp_setup_needed = false;
+	}
+
+	if (status == IXGBE_ERR_SFP_NOT_SUPPORTED)
+		return status;
+
+	/* Reset PHY */
+	if (!hw->phy.reset_disable && hw->phy.ops.reset) {
+		if (hw->phy.ops.reset(hw) == IXGBE_ERR_OVERTEMP)
+			return IXGBE_ERR_OVERTEMP;
+	}
+
+mac_reset_top:
+	/* Issue global reset to the MAC.  Needs to be SW reset if link is up.
+	 * If link reset is used when link is up, it might reset the PHY when
+	 * mng is using it.  If link is down or the flag to force full link
+	 * reset is set, then perform link reset.
+	 */
+	ctrl = IXGBE_CTRL_LNK_RST;
+	if (!hw->force_full_reset) {
+		hw->mac.ops.check_link(hw, &link_speed, &link_up, false);
+		if (link_up)
+			ctrl = IXGBE_CTRL_RST;
+	}
+
+	status = hw->mac.ops.acquire_swfw_sync(hw, swfw_mask);
+	if (status != IXGBE_SUCCESS) {
+		ERROR_REPORT2(IXGBE_ERROR_CAUTION,
+			"semaphore failed with %d", status);
+		return IXGBE_ERR_SWFW_SYNC;
+	}
+	ctrl |= IXGBE_READ_REG(hw, IXGBE_CTRL);
+	IXGBE_WRITE_REG(hw, IXGBE_CTRL, ctrl);
+	IXGBE_WRITE_FLUSH(hw);
+	hw->mac.ops.release_swfw_sync(hw, swfw_mask);
+
+	/* Poll for reset bit to self-clear meaning reset is complete */
+	for (i = 0; i < 10; i++) {
+		usec_delay(1);
+		ctrl = IXGBE_READ_REG(hw, IXGBE_CTRL);
+		if (!(ctrl & IXGBE_CTRL_RST_MASK))
+			break;
+	}
+
+	if (ctrl & IXGBE_CTRL_RST_MASK) {
+		status = IXGBE_ERR_RESET_FAILED;
+		DEBUGOUT("Reset polling failed to complete.\n");
+	}
+
+	msec_delay(50);
+
+	/* Double resets are required for recovery from certain error
+	 * conditions.  Between resets, it is necessary to stall to
+	 * allow time for any pending HW events to complete.
+	 */
+	if (hw->mac.flags & IXGBE_FLAGS_DOUBLE_RESET_REQUIRED) {
+		hw->mac.flags &= ~IXGBE_FLAGS_DOUBLE_RESET_REQUIRED;
+		goto mac_reset_top;
+	}
+
+	/* Store the permanent mac address */
+	hw->mac.ops.get_mac_addr(hw, hw->mac.perm_addr);
+
+	/* Store MAC address from RAR0, clear receive address registers, and
+	 * clear the multicast table.  Also reset num_rar_entries to 128,
+	 * since we modify this value when programming the SAN MAC address.
+	 */
+	hw->mac.num_rar_entries = 128;
+	hw->mac.ops.init_rx_addrs(hw);
+
+	ixgbe_set_mdio_speed(hw);
+
+	if (hw->device_id == IXGBE_DEV_ID_X550EM_X_SFP)
+		ixgbe_setup_mux_ctl(hw);
+
+	if (status != IXGBE_SUCCESS)
+		DEBUGOUT1("Reset HW failed, STATUS = %d\n", status);
+
+	return status;
+}
+
+/**
+ * ixgbe_init_ext_t_x550em - Start (unstall) the external Base T PHY.
+ * @hw: pointer to hardware structure
+ */
+s32 ixgbe_init_ext_t_x550em(struct ixgbe_hw *hw)
+{
+	u32 status;
+	u16 reg;
+
+	status = hw->phy.ops.read_reg(hw,
+				      IXGBE_MDIO_TX_VENDOR_ALARMS_3,
+				      IXGBE_MDIO_PMA_PMD_DEV_TYPE,
+				      &reg);
+
+	if (status != IXGBE_SUCCESS)
+		return status;
+
+	/* If PHY FW reset completed bit is set then this is the first
+	 * SW instance after a power on so the PHY FW must be un-stalled.
+	 */
+	if (reg & IXGBE_MDIO_TX_VENDOR_ALARMS_3_RST_MASK) {
+		status = hw->phy.ops.read_reg(hw,
+					IXGBE_MDIO_GLOBAL_RES_PR_10,
+					IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
+					&reg);
+
+		if (status != IXGBE_SUCCESS)
+			return status;
+
+		reg &= ~IXGBE_MDIO_POWER_UP_STALL;
+
+		status = hw->phy.ops.write_reg(hw,
+					IXGBE_MDIO_GLOBAL_RES_PR_10,
+					IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
+					reg);
+
+		if (status != IXGBE_SUCCESS)
+			return status;
+	}
+
+	return status;
+}
+
+/**
+ *  ixgbe_setup_kr_x550em - Configure the KR PHY.
+ *  @hw: pointer to hardware structure
+ **/
+s32 ixgbe_setup_kr_x550em(struct ixgbe_hw *hw)
+{
+	/* leave link alone for 2.5G */
+	if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_2_5GB_FULL)
+		return IXGBE_SUCCESS;
+
+	if (ixgbe_check_reset_blocked(hw))
+		return 0;
+
+	return ixgbe_setup_kr_speed_x550em(hw, hw->phy.autoneg_advertised);
+}
+
+/**
+ *  ixgbe_setup_mac_link_sfp_x550em - Setup internal/external the PHY for SFP
+ *  @hw: pointer to hardware structure
+ *
+ *  Configure the external PHY and the integrated KR PHY for SFP support.
+ **/
+s32 ixgbe_setup_mac_link_sfp_x550em(struct ixgbe_hw *hw,
+				    ixgbe_link_speed speed,
+				    bool autoneg_wait_to_complete)
+{
+	s32 ret_val;
+	u16 reg_slice, reg_val;
+	bool setup_linear = false;
+	UNREFERENCED_1PARAMETER(autoneg_wait_to_complete);
+
+	/* Check if SFP module is supported and linear */
+	ret_val = ixgbe_supported_sfp_modules_X550em(hw, &setup_linear);
+
+	/* If no SFP module present, then return success. Return success since
+	 * there is no reason to configure CS4227 and SFP not present error is
+	 * not excepted in the setup MAC link flow.
+	 */
+	if (ret_val == IXGBE_ERR_SFP_NOT_PRESENT)
+		return IXGBE_SUCCESS;
+
+	if (ret_val != IXGBE_SUCCESS)
+		return ret_val;
+
+	/* Configure internal PHY for KR/KX. */
+	ixgbe_setup_kr_speed_x550em(hw, speed);
+
+	/* Configure CS4227 LINE side to proper mode. */
+	reg_slice = IXGBE_CS4227_LINE_SPARE24_LSB +
+		    (hw->bus.lan_id << 12);
+	if (setup_linear)
+		reg_val = (IXGBE_CS4227_EDC_MODE_CX1 << 1) | 0x1;
+	else
+		reg_val = (IXGBE_CS4227_EDC_MODE_SR << 1) | 0x1;
+	ret_val = hw->link.ops.write_link(hw, hw->link.addr, reg_slice,
+					  reg_val);
+	return ret_val;
+}
+
+/**
+ *  ixgbe_setup_sfi_x550a - Configure the internal PHY for native SFI mode
+ *  @hw: pointer to hardware structure
+ *  @speed: the link speed to force
+ *
+ *  Configures the integrated PHY for native SFI mode. Used to connect the
+ *  internal PHY directly to an SFP cage, without autonegotiation.
+ **/
+STATIC s32 ixgbe_setup_sfi_x550a(struct ixgbe_hw *hw, ixgbe_link_speed *speed)
+{
+	struct ixgbe_mac_info *mac = &hw->mac;
+	s32 status;
+	u32 reg_val;
+
+	/* Disable all AN and force speed to 10G Serial. */
+	status = mac->ops.read_iosf_sb_reg(hw,
+				IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+
+	reg_val &= ~IXGBE_KRM_PMD_FLX_MASK_ST20_AN_EN;
+	reg_val &= ~IXGBE_KRM_PMD_FLX_MASK_ST20_AN37_EN;
+	reg_val &= ~IXGBE_KRM_PMD_FLX_MASK_ST20_SGMII_EN;
+	reg_val &= ~IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_MASK;
+
+	/* Select forced link speed for internal PHY. */
+	switch (*speed) {
+	case IXGBE_LINK_SPEED_10GB_FULL:
+		reg_val |= IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_10G;
+		break;
+	case IXGBE_LINK_SPEED_1GB_FULL:
+		reg_val |= IXGBE_KRM_PMD_FLX_MASK_ST20_SPEED_1G;
+		break;
+	default:
+		/* Other link speeds are not supported by internal PHY. */
+		return IXGBE_ERR_LINK_SETUP;
+	}
+
+	status = mac->ops.write_iosf_sb_reg(hw,
+				IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+
+	/* Toggle port SW reset by AN reset. */
+	status = ixgbe_restart_an_internal_phy_x550em(hw);
+
+	return status;
+}
+
+/**
+ *  ixgbe_setup_mac_link_sfp_x550a - Setup internal PHY for SFP
+ *  @hw: pointer to hardware structure
+ *
+ *  Configure the the integrated PHY for SFP support.
+ **/
+s32 ixgbe_setup_mac_link_sfp_x550a(struct ixgbe_hw *hw,
+				    ixgbe_link_speed speed,
+				    bool autoneg_wait_to_complete)
+{
+	s32 ret_val;
+	u16 reg_phy_ext;
+	bool setup_linear = false;
+	u32 reg_slice, reg_phy_int, slice_offset;
+
+	UNREFERENCED_1PARAMETER(autoneg_wait_to_complete);
+
+	/* Check if SFP module is supported and linear */
+	ret_val = ixgbe_supported_sfp_modules_X550em(hw, &setup_linear);
+
+	/* If no SFP module present, then return success. Return success since
+	 * SFP not present error is not excepted in the setup MAC link flow.
+	 */
+	if (ret_val == IXGBE_ERR_SFP_NOT_PRESENT)
+		return IXGBE_SUCCESS;
+
+	if (ret_val != IXGBE_SUCCESS)
+		return ret_val;
+
+	if (hw->device_id == IXGBE_DEV_ID_X550EM_A_SFP_N) {
+		/* Configure internal PHY for native SFI based on module type */
+		ret_val = hw->mac.ops.read_iosf_sb_reg(hw,
+				   IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				   IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_phy_int);
+
+		if (ret_val != IXGBE_SUCCESS)
+			return ret_val;
+
+		reg_phy_int &= IXGBE_KRM_PMD_FLX_MASK_ST20_SFI_10G_DA;
+		if (!setup_linear)
+			reg_phy_int |= IXGBE_KRM_PMD_FLX_MASK_ST20_SFI_10G_SR;
+
+		ret_val = hw->mac.ops.write_iosf_sb_reg(hw,
+				   IXGBE_KRM_PMD_FLX_MASK_ST20(hw->bus.lan_id),
+				   IXGBE_SB_IOSF_TARGET_KR_PHY, reg_phy_int);
+
+		if (ret_val != IXGBE_SUCCESS)
+			return ret_val;
+
+		/* Setup SFI internal link. */
+		ret_val = ixgbe_setup_sfi_x550a(hw, &speed);
+	} else {
+		/* Configure internal PHY for KR/KX. */
+		ixgbe_setup_kr_speed_x550em(hw, speed);
+
+		if (hw->phy.addr == 0x0 || hw->phy.addr == 0xFFFF) {
+			/* Find Address */
+			DEBUGOUT("Invalid NW_MNG_IF_SEL.MDIO_PHY_ADD value\n");
+			return IXGBE_ERR_PHY_ADDR_INVALID;
+		}
+
+		/* Get external PHY SKU id */
+		ret_val = hw->phy.ops.read_reg(hw, IXGBE_CS4227_EFUSE_PDF_SKU,
+					IXGBE_MDIO_ZERO_DEV_TYPE, &reg_phy_ext);
+
+		if (ret_val != IXGBE_SUCCESS)
+			return ret_val;
+
+		/* When configuring quad port CS4223, the MAC instance is part
+		 * of the slice offset.
+		 */
+		if (reg_phy_ext == IXGBE_CS4223_SKU_ID)
+			slice_offset = (hw->bus.lan_id +
+					(hw->bus.instance_id << 1)) << 12;
+		else
+			slice_offset = hw->bus.lan_id << 12;
+
+		/* Configure CS4227/CS4223 LINE side to proper mode. */
+		reg_slice = IXGBE_CS4227_LINE_SPARE24_LSB + slice_offset;
+
+		ret_val = hw->phy.ops.read_reg(hw, reg_slice,
+					IXGBE_MDIO_ZERO_DEV_TYPE, &reg_phy_ext);
+
+		if (ret_val != IXGBE_SUCCESS)
+			return ret_val;
+
+		reg_phy_ext &= ~((IXGBE_CS4227_EDC_MODE_CX1 << 1) |
+				 (IXGBE_CS4227_EDC_MODE_SR << 1));
+
+		if (setup_linear)
+			reg_phy_ext = (IXGBE_CS4227_EDC_MODE_CX1 << 1) | 0x1;
+		else
+			reg_phy_ext = (IXGBE_CS4227_EDC_MODE_SR << 1) | 0x1;
+		ret_val = hw->phy.ops.write_reg(hw, reg_slice,
+					 IXGBE_MDIO_ZERO_DEV_TYPE, reg_phy_ext);
+
+		/* Flush previous write with a read */
+		ret_val = hw->phy.ops.read_reg(hw, reg_slice,
+					IXGBE_MDIO_ZERO_DEV_TYPE, &reg_phy_ext);
+	}
+	return ret_val;
+}
+
+/**
+ *  ixgbe_setup_ixfi_x550em_x - MAC specific iXFI configuration
+ *  @hw: pointer to hardware structure
+ *
+ *  iXfI configuration needed for ixgbe_mac_X550EM_x devices.
+ **/
+STATIC s32 ixgbe_setup_ixfi_x550em_x(struct ixgbe_hw *hw)
+{
+	struct ixgbe_mac_info *mac = &hw->mac;
+	s32 status;
+	u32 reg_val;
+
+	/* Disable training protocol FSM. */
+	status = mac->ops.read_iosf_sb_reg(hw,
+				IXGBE_KRM_RX_TRN_LINKUP_CTRL(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+	reg_val |= IXGBE_KRM_RX_TRN_LINKUP_CTRL_CONV_WO_PROTOCOL;
+	status = mac->ops.write_iosf_sb_reg(hw,
+				IXGBE_KRM_RX_TRN_LINKUP_CTRL(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+
+	/* Disable Flex from training TXFFE. */
+	status = mac->ops.read_iosf_sb_reg(hw,
+				IXGBE_KRM_DSP_TXFFE_STATE_4(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_C0_EN;
+	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_CP1_CN1_EN;
+	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_CO_ADAPT_EN;
+	status = mac->ops.write_iosf_sb_reg(hw,
+				IXGBE_KRM_DSP_TXFFE_STATE_4(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+	status = mac->ops.read_iosf_sb_reg(hw,
+				IXGBE_KRM_DSP_TXFFE_STATE_5(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_C0_EN;
+	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_CP1_CN1_EN;
+	reg_val &= ~IXGBE_KRM_DSP_TXFFE_STATE_CO_ADAPT_EN;
+	status = mac->ops.write_iosf_sb_reg(hw,
+				IXGBE_KRM_DSP_TXFFE_STATE_5(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+
+	/* Enable override for coefficients. */
+	status = mac->ops.read_iosf_sb_reg(hw,
+				IXGBE_KRM_TX_COEFF_CTRL_1(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+	reg_val |= IXGBE_KRM_TX_COEFF_CTRL_1_OVRRD_EN;
+	reg_val |= IXGBE_KRM_TX_COEFF_CTRL_1_CZERO_EN;
+	reg_val |= IXGBE_KRM_TX_COEFF_CTRL_1_CPLUS1_OVRRD_EN;
+	reg_val |= IXGBE_KRM_TX_COEFF_CTRL_1_CMINUS1_OVRRD_EN;
+	status = mac->ops.write_iosf_sb_reg(hw,
+				IXGBE_KRM_TX_COEFF_CTRL_1(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+	return status;
+}
+
+/**
+ *  ixgbe_setup_ixfi_x550em - Configure the KR PHY for iXFI mode.
+ *  @hw: pointer to hardware structure
+ *  @speed: the link speed to force
+ *
+ *  Configures the integrated KR PHY to use iXFI mode. Used to connect an
+ *  internal and external PHY at a specific speed, without autonegotiation.
+ **/
+STATIC s32 ixgbe_setup_ixfi_x550em(struct ixgbe_hw *hw, ixgbe_link_speed *speed)
+{
+	struct ixgbe_mac_info *mac = &hw->mac;
+	s32 status;
+	u32 reg_val;
+
+	/* iXFI is only supported with X552 */
+	if (mac->type != ixgbe_mac_X550EM_x)
+		return IXGBE_ERR_LINK_SETUP;
+
+	/* Disable AN and force speed to 10G Serial. */
+	status = mac->ops.read_iosf_sb_reg(hw,
+					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+
+	reg_val &= ~IXGBE_KRM_LINK_CTRL_1_TETH_AN_ENABLE;
+	reg_val &= ~IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_MASK;
+
+	/* Select forced link speed for internal PHY. */
+	switch (*speed) {
+	case IXGBE_LINK_SPEED_10GB_FULL:
+		reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_10G;
+		break;
+	case IXGBE_LINK_SPEED_1GB_FULL:
+		reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_1G;
+		break;
+	default:
+		/* Other link speeds are not supported by internal KR PHY. */
+		return IXGBE_ERR_LINK_SETUP;
+	}
+
+	status = mac->ops.write_iosf_sb_reg(hw,
+					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+
+	/* Additional configuration needed for x550em_x */
+	if (hw->mac.type == ixgbe_mac_X550EM_x) {
+		status = ixgbe_setup_ixfi_x550em_x(hw);
+		if (status != IXGBE_SUCCESS)
+			return status;
+	}
+
+	/* Toggle port SW reset by AN reset. */
+	status = ixgbe_restart_an_internal_phy_x550em(hw);
+
+	return status;
+}
+
+/**
+ * ixgbe_ext_phy_t_x550em_get_link - Get ext phy link status
+ * @hw: address of hardware structure
+ * @link_up: address of boolean to indicate link status
+ *
+ * Returns error code if unable to get link status.
+ */
+STATIC s32 ixgbe_ext_phy_t_x550em_get_link(struct ixgbe_hw *hw, bool *link_up)
+{
+	u32 ret;
+	u16 autoneg_status;
+
+	*link_up = false;
+
+	/* read this twice back to back to indicate current status */
+	ret = hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_STATUS,
+				   IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+				   &autoneg_status);
+	if (ret != IXGBE_SUCCESS)
+		return ret;
+
+	ret = hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_STATUS,
+				   IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+				   &autoneg_status);
+	if (ret != IXGBE_SUCCESS)
+		return ret;
+
+	*link_up = !!(autoneg_status & IXGBE_MDIO_AUTO_NEG_LINK_STATUS);
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ * ixgbe_setup_internal_phy_t_x550em - Configure KR PHY to X557 link
+ * @hw: point to hardware structure
+ *
+ * Configures the link between the integrated KR PHY and the external X557 PHY
+ * The driver will call this function when it gets a link status change
+ * interrupt from the X557 PHY. This function configures the link speed
+ * between the PHYs to match the link speed of the BASE-T link.
+ *
+ * A return of a non-zero value indicates an error, and the base driver should
+ * not report link up.
+ */
+s32 ixgbe_setup_internal_phy_t_x550em(struct ixgbe_hw *hw)
+{
+	ixgbe_link_speed force_speed;
+	bool link_up;
+	u32 status;
+	u16 speed;
+
+	if (hw->mac.ops.get_media_type(hw) != ixgbe_media_type_copper)
+		return IXGBE_ERR_CONFIG;
+
+	if (hw->mac.type == ixgbe_mac_X550EM_x &&
+	    !(hw->phy.nw_mng_if_sel & IXGBE_NW_MNG_IF_SEL_INT_PHY_MODE)) {
+		/* If link is down, there is no setup necessary so return  */
+		status = ixgbe_ext_phy_t_x550em_get_link(hw, &link_up);
+		if (status != IXGBE_SUCCESS)
+			return status;
+
+		if (!link_up)
+			return IXGBE_SUCCESS;
+
+		status = hw->phy.ops.read_reg(hw,
+					      IXGBE_MDIO_AUTO_NEG_VENDOR_STAT,
+					      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+					      &speed);
+		if (status != IXGBE_SUCCESS)
+			return status;
+
+		/* If link is still down - no setup is required so return */
+		status = ixgbe_ext_phy_t_x550em_get_link(hw, &link_up);
+		if (status != IXGBE_SUCCESS)
+			return status;
+		if (!link_up)
+			return IXGBE_SUCCESS;
+
+		/* clear everything but the speed and duplex bits */
+		speed &= IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_MASK;
+
+		switch (speed) {
+		case IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10GB_FULL:
+			force_speed = IXGBE_LINK_SPEED_10GB_FULL;
+			break;
+		case IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_1GB_FULL:
+			force_speed = IXGBE_LINK_SPEED_1GB_FULL;
+			break;
+		default:
+			/* Internal PHY does not support anything else */
+			return IXGBE_ERR_INVALID_LINK_SETTINGS;
+		}
+
+		return ixgbe_setup_ixfi_x550em(hw, &force_speed);
+	} else {
+		speed = IXGBE_LINK_SPEED_10GB_FULL |
+			IXGBE_LINK_SPEED_1GB_FULL;
+		return ixgbe_setup_kr_speed_x550em(hw, speed);
+	}
+}
+
+/**
+ *  ixgbe_setup_phy_loopback_x550em - Configure the KR PHY for loopback.
+ *  @hw: pointer to hardware structure
+ *
+ *  Configures the integrated KR PHY to use internal loopback mode.
+ **/
+s32 ixgbe_setup_phy_loopback_x550em(struct ixgbe_hw *hw)
+{
+	s32 status;
+	u32 reg_val;
+
+	/* Disable AN and force speed to 10G Serial. */
+	status = hw->mac.ops.read_iosf_sb_reg(hw,
+					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+	reg_val &= ~IXGBE_KRM_LINK_CTRL_1_TETH_AN_ENABLE;
+	reg_val &= ~IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_MASK;
+	reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_FORCE_SPEED_10G;
+	status = hw->mac.ops.write_iosf_sb_reg(hw,
+					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+
+	/* Set near-end loopback clocks. */
+	status = hw->mac.ops.read_iosf_sb_reg(hw,
+				IXGBE_KRM_PORT_CAR_GEN_CTRL(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+	reg_val |= IXGBE_KRM_PORT_CAR_GEN_CTRL_NELB_32B;
+	reg_val |= IXGBE_KRM_PORT_CAR_GEN_CTRL_NELB_KRPCS;
+	status = hw->mac.ops.write_iosf_sb_reg(hw,
+				IXGBE_KRM_PORT_CAR_GEN_CTRL(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+
+	/* Set loopback enable. */
+	status = hw->mac.ops.read_iosf_sb_reg(hw,
+				IXGBE_KRM_PMD_DFX_BURNIN(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+	reg_val |= IXGBE_KRM_PMD_DFX_BURNIN_TX_RX_KR_LB_MASK;
+	status = hw->mac.ops.write_iosf_sb_reg(hw,
+				IXGBE_KRM_PMD_DFX_BURNIN(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+
+	/* Training bypass. */
+	status = hw->mac.ops.read_iosf_sb_reg(hw,
+				IXGBE_KRM_RX_TRN_LINKUP_CTRL(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+	if (status != IXGBE_SUCCESS)
+		return status;
+	reg_val |= IXGBE_KRM_RX_TRN_LINKUP_CTRL_PROTOCOL_BYPASS;
+	status = hw->mac.ops.write_iosf_sb_reg(hw,
+				IXGBE_KRM_RX_TRN_LINKUP_CTRL(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+
+	return status;
+}
+
+/**
+ *  ixgbe_read_ee_hostif_X550 - Read EEPROM word using a host interface command
+ *  assuming that the semaphore is already obtained.
+ *  @hw: pointer to hardware structure
+ *  @offset: offset of  word in the EEPROM to read
+ *  @data: word read from the EEPROM
+ *
+ *  Reads a 16 bit word from the EEPROM using the hostif.
+ **/
+s32 ixgbe_read_ee_hostif_X550(struct ixgbe_hw *hw, u16 offset, u16 *data)
+{
+	const u32 mask = IXGBE_GSSR_SW_MNG_SM | IXGBE_GSSR_EEP_SM;
+	struct ixgbe_hic_read_shadow_ram buffer;
+	s32 status;
+
+	DEBUGFUNC("ixgbe_read_ee_hostif_X550");
+	buffer.hdr.req.cmd = FW_READ_SHADOW_RAM_CMD;
+	buffer.hdr.req.buf_lenh = 0;
+	buffer.hdr.req.buf_lenl = FW_READ_SHADOW_RAM_LEN;
+	buffer.hdr.req.checksum = FW_DEFAULT_CHECKSUM;
+
+	/* convert offset from words to bytes */
+	buffer.address = IXGBE_CPU_TO_BE32(offset * 2);
+	/* one word */
+	buffer.length = IXGBE_CPU_TO_BE16(sizeof(u16));
+	buffer.pad2 = 0;
+	buffer.pad3 = 0;
+
+	status = hw->mac.ops.acquire_swfw_sync(hw, mask);
+	if (status)
+		return status;
+
+	status = ixgbe_hic_unlocked(hw, (u32 *)&buffer, sizeof(buffer),
+				    IXGBE_HI_COMMAND_TIMEOUT);
+	if (!status) {
+		*data = (u16)IXGBE_READ_REG_ARRAY(hw, IXGBE_FLEX_MNG,
+						  FW_NVM_DATA_OFFSET);
+	}
+
+	hw->mac.ops.release_swfw_sync(hw, mask);
+	return status;
+}
+
+/**
+ *  ixgbe_read_ee_hostif_buffer_X550- Read EEPROM word(s) using hostif
+ *  @hw: pointer to hardware structure
+ *  @offset: offset of  word in the EEPROM to read
+ *  @words: number of words
+ *  @data: word(s) read from the EEPROM
+ *
+ *  Reads a 16 bit word(s) from the EEPROM using the hostif.
+ **/
+s32 ixgbe_read_ee_hostif_buffer_X550(struct ixgbe_hw *hw,
+				     u16 offset, u16 words, u16 *data)
+{
+	const u32 mask = IXGBE_GSSR_SW_MNG_SM | IXGBE_GSSR_EEP_SM;
+	struct ixgbe_hic_read_shadow_ram buffer;
+	u32 current_word = 0;
+	u16 words_to_read;
+	s32 status;
+	u32 i;
+
+	DEBUGFUNC("ixgbe_read_ee_hostif_buffer_X550");
+
+	/* Take semaphore for the entire operation. */
+	status = hw->mac.ops.acquire_swfw_sync(hw, mask);
+	if (status) {
+		DEBUGOUT("EEPROM read buffer - semaphore failed\n");
+		return status;
+	}
+
+	while (words) {
+		if (words > FW_MAX_READ_BUFFER_SIZE / 2)
+			words_to_read = FW_MAX_READ_BUFFER_SIZE / 2;
+		else
+			words_to_read = words;
+
+		buffer.hdr.req.cmd = FW_READ_SHADOW_RAM_CMD;
+		buffer.hdr.req.buf_lenh = 0;
+		buffer.hdr.req.buf_lenl = FW_READ_SHADOW_RAM_LEN;
+		buffer.hdr.req.checksum = FW_DEFAULT_CHECKSUM;
+
+		/* convert offset from words to bytes */
+		buffer.address = IXGBE_CPU_TO_BE32((offset + current_word) * 2);
+		buffer.length = IXGBE_CPU_TO_BE16(words_to_read * 2);
+		buffer.pad2 = 0;
+		buffer.pad3 = 0;
+
+		status = ixgbe_hic_unlocked(hw, (u32 *)&buffer, sizeof(buffer),
+					    IXGBE_HI_COMMAND_TIMEOUT);
+
+		if (status) {
+			DEBUGOUT("Host interface command failed\n");
+			goto out;
+		}
+
+		for (i = 0; i < words_to_read; i++) {
+			u32 reg = IXGBE_FLEX_MNG + (FW_NVM_DATA_OFFSET << 2) +
+				  2 * i;
+			u32 value = IXGBE_READ_REG(hw, reg);
+
+			data[current_word] = (u16)(value & 0xffff);
+			current_word++;
+			i++;
+			if (i < words_to_read) {
+				value >>= 16;
+				data[current_word] = (u16)(value & 0xffff);
+				current_word++;
+			}
+		}
+		words -= words_to_read;
+	}
+
+out:
+	hw->mac.ops.release_swfw_sync(hw, mask);
+	return status;
+}
+
+/**
+ *  ixgbe_write_ee_hostif_X550 - Write EEPROM word using hostif
+ *  @hw: pointer to hardware structure
+ *  @offset: offset of  word in the EEPROM to write
+ *  @data: word write to the EEPROM
+ *
+ *  Write a 16 bit word to the EEPROM using the hostif.
+ **/
+s32 ixgbe_write_ee_hostif_data_X550(struct ixgbe_hw *hw, u16 offset,
+				    u16 data)
+{
+	s32 status;
+	struct ixgbe_hic_write_shadow_ram buffer;
+
+	DEBUGFUNC("ixgbe_write_ee_hostif_data_X550");
+
+	buffer.hdr.req.cmd = FW_WRITE_SHADOW_RAM_CMD;
+	buffer.hdr.req.buf_lenh = 0;
+	buffer.hdr.req.buf_lenl = FW_WRITE_SHADOW_RAM_LEN;
+	buffer.hdr.req.checksum = FW_DEFAULT_CHECKSUM;
+
+	 /* one word */
+	buffer.length = IXGBE_CPU_TO_BE16(sizeof(u16));
+	buffer.data = data;
+	buffer.address = IXGBE_CPU_TO_BE32(offset * 2);
+
+	status = ixgbe_host_interface_command(hw, (u32 *)&buffer,
+					      sizeof(buffer),
+					      IXGBE_HI_COMMAND_TIMEOUT, false);
+
+	return status;
+}
+
+/**
+ *  ixgbe_write_ee_hostif_X550 - Write EEPROM word using hostif
+ *  @hw: pointer to hardware structure
+ *  @offset: offset of  word in the EEPROM to write
+ *  @data: word write to the EEPROM
+ *
+ *  Write a 16 bit word to the EEPROM using the hostif.
+ **/
+s32 ixgbe_write_ee_hostif_X550(struct ixgbe_hw *hw, u16 offset,
+			       u16 data)
+{
+	s32 status = IXGBE_SUCCESS;
+
+	DEBUGFUNC("ixgbe_write_ee_hostif_X550");
+
+	if (hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM) ==
+	    IXGBE_SUCCESS) {
+		status = ixgbe_write_ee_hostif_data_X550(hw, offset, data);
+		hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
+	} else {
+		DEBUGOUT("write ee hostif failed to get semaphore");
+		status = IXGBE_ERR_SWFW_SYNC;
+	}
+
+	return status;
+}
+
+/**
+ *  ixgbe_write_ee_hostif_buffer_X550 - Write EEPROM word(s) using hostif
+ *  @hw: pointer to hardware structure
+ *  @offset: offset of  word in the EEPROM to write
+ *  @words: number of words
+ *  @data: word(s) write to the EEPROM
+ *
+ *  Write a 16 bit word(s) to the EEPROM using the hostif.
+ **/
+s32 ixgbe_write_ee_hostif_buffer_X550(struct ixgbe_hw *hw,
+				      u16 offset, u16 words, u16 *data)
+{
+	s32 status = IXGBE_SUCCESS;
+	u32 i = 0;
+
+	DEBUGFUNC("ixgbe_write_ee_hostif_buffer_X550");
+
+	/* Take semaphore for the entire operation. */
+	status = hw->mac.ops.acquire_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
+	if (status != IXGBE_SUCCESS) {
+		DEBUGOUT("EEPROM write buffer - semaphore failed\n");
+		goto out;
+	}
+
+	for (i = 0; i < words; i++) {
+		status = ixgbe_write_ee_hostif_data_X550(hw, offset + i,
+							 data[i]);
+
+		if (status != IXGBE_SUCCESS) {
+			DEBUGOUT("Eeprom buffered write failed\n");
+			break;
+		}
+	}
+
+	hw->mac.ops.release_swfw_sync(hw, IXGBE_GSSR_EEP_SM);
+out:
+
+	return status;
+}
+
+/**
+ * ixgbe_checksum_ptr_x550 - Checksum one pointer region
+ * @hw: pointer to hardware structure
+ * @ptr: pointer offset in eeprom
+ * @size: size of section pointed by ptr, if 0 first word will be used as size
+ * @csum: address of checksum to update
+ *
+ * Returns error status for any failure
+ */
+STATIC s32 ixgbe_checksum_ptr_x550(struct ixgbe_hw *hw, u16 ptr,
+				   u16 size, u16 *csum, u16 *buffer,
+				   u32 buffer_size)
+{
+	u16 buf[256];
+	s32 status;
+	u16 length, bufsz, i, start;
+	u16 *local_buffer;
+
+	bufsz = sizeof(buf) / sizeof(buf[0]);
+
+	/* Read a chunk at the pointer location */
+	if (!buffer) {
+		status = ixgbe_read_ee_hostif_buffer_X550(hw, ptr, bufsz, buf);
+		if (status) {
+			DEBUGOUT("Failed to read EEPROM image\n");
+			return status;
+		}
+		local_buffer = buf;
+	} else {
+		if (buffer_size < ptr)
+			return  IXGBE_ERR_PARAM;
+		local_buffer = &buffer[ptr];
+	}
+
+	if (size) {
+		start = 0;
+		length = size;
+	} else {
+		start = 1;
+		length = local_buffer[0];
+
+		/* Skip pointer section if length is invalid. */
+		if (length == 0xFFFF || length == 0 ||
+		    (ptr + length) >= hw->eeprom.word_size)
+			return IXGBE_SUCCESS;
+	}
+
+	if (buffer && ((u32)start + (u32)length > buffer_size))
+		return IXGBE_ERR_PARAM;
+
+	for (i = start; length; i++, length--) {
+		if (i == bufsz && !buffer) {
+			ptr += bufsz;
+			i = 0;
+			if (length < bufsz)
+				bufsz = length;
+
+			/* Read a chunk at the pointer location */
+			status = ixgbe_read_ee_hostif_buffer_X550(hw, ptr,
+								  bufsz, buf);
+			if (status) {
+				DEBUGOUT("Failed to read EEPROM image\n");
+				return status;
+			}
+		}
+		*csum += local_buffer[i];
+	}
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_calc_checksum_X550 - Calculates and returns the checksum
+ *  @hw: pointer to hardware structure
+ *  @buffer: pointer to buffer containing calculated checksum
+ *  @buffer_size: size of buffer
+ *
+ *  Returns a negative error code on error, or the 16-bit checksum
+ **/
+s32 ixgbe_calc_checksum_X550(struct ixgbe_hw *hw, u16 *buffer, u32 buffer_size)
+{
+	u16 eeprom_ptrs[IXGBE_EEPROM_LAST_WORD + 1];
+	u16 *local_buffer;
+	s32 status;
+	u16 checksum = 0;
+	u16 pointer, i, size;
+
+	DEBUGFUNC("ixgbe_calc_eeprom_checksum_X550");
+
+	hw->eeprom.ops.init_params(hw);
+
+	if (!buffer) {
+		/* Read pointer area */
+		status = ixgbe_read_ee_hostif_buffer_X550(hw, 0,
+						     IXGBE_EEPROM_LAST_WORD + 1,
+						     eeprom_ptrs);
+		if (status) {
+			DEBUGOUT("Failed to read EEPROM image\n");
+			return status;
+		}
+		local_buffer = eeprom_ptrs;
+	} else {
+		if (buffer_size < IXGBE_EEPROM_LAST_WORD)
+			return IXGBE_ERR_PARAM;
+		local_buffer = buffer;
+	}
+
+	/*
+	 * For X550 hardware include 0x0-0x41 in the checksum, skip the
+	 * checksum word itself
+	 */
+	for (i = 0; i <= IXGBE_EEPROM_LAST_WORD; i++)
+		if (i != IXGBE_EEPROM_CHECKSUM)
+			checksum += local_buffer[i];
+
+	/*
+	 * Include all data from pointers 0x3, 0x6-0xE.  This excludes the
+	 * FW, PHY module, and PCIe Expansion/Option ROM pointers.
+	 */
+	for (i = IXGBE_PCIE_ANALOG_PTR_X550; i < IXGBE_FW_PTR; i++) {
+		if (i == IXGBE_PHY_PTR || i == IXGBE_OPTION_ROM_PTR)
+			continue;
+
+		pointer = local_buffer[i];
+
+		/* Skip pointer section if the pointer is invalid. */
+		if (pointer == 0xFFFF || pointer == 0 ||
+		    pointer >= hw->eeprom.word_size)
+			continue;
+
+		switch (i) {
+		case IXGBE_PCIE_GENERAL_PTR:
+			size = IXGBE_IXGBE_PCIE_GENERAL_SIZE;
+			break;
+		case IXGBE_PCIE_CONFIG0_PTR:
+		case IXGBE_PCIE_CONFIG1_PTR:
+			size = IXGBE_PCIE_CONFIG_SIZE;
+			break;
+		default:
+			size = 0;
+			break;
+		}
+
+		status = ixgbe_checksum_ptr_x550(hw, pointer, size, &checksum,
+						buffer, buffer_size);
+		if (status)
+			return status;
+	}
+
+	checksum = (u16)IXGBE_EEPROM_SUM - checksum;
 
-	return status;
+	return (s32)checksum;
 }
 
 /**
- * ixgbe_handle_lasi_ext_t_x550em - Handle external Base T PHY interrupt
- * @hw: pointer to hardware structure
- *
- * Handle external Base T PHY interrupt. If high temperature
- * failure alarm then return error, else if link status change
- * then setup internal/external PHY link
+ *  ixgbe_calc_eeprom_checksum_X550 - Calculates and returns the checksum
+ *  @hw: pointer to hardware structure
  *
- * Return IXGBE_ERR_OVERTEMP if interrupt is high temperature
- * failure alarm, else return PHY access status.
+ *  Returns a negative error code on error, or the 16-bit checksum
  **/
-static s32 ixgbe_handle_lasi_ext_t_x550em(struct ixgbe_hw *hw)
+s32 ixgbe_calc_eeprom_checksum_X550(struct ixgbe_hw *hw)
 {
-	struct ixgbe_phy_info *phy = &hw->phy;
-	bool lsc;
-	u32 status;
-
-	status = ixgbe_get_lasi_ext_t_x550em(hw, &lsc);
-	if (status)
-		return status;
-
-	if (lsc && phy->ops.setup_internal_link)
-		return phy->ops.setup_internal_link(hw);
-
-	return 0;
+	return ixgbe_calc_checksum_X550(hw, NULL, 0);
 }
 
 /**
- * ixgbe_setup_kr_speed_x550em - Configure the KR PHY for link speed.
- * @hw: pointer to hardware structure
- * @speed: link speed
+ *  ixgbe_validate_eeprom_checksum_X550 - Validate EEPROM checksum
+ *  @hw: pointer to hardware structure
+ *  @checksum_val: calculated checksum
  *
- * Configures the integrated KR PHY.
+ *  Performs checksum calculation and validates the EEPROM checksum.  If the
+ *  caller does not need checksum_val, the value can be NULL.
  **/
-static s32 ixgbe_setup_kr_speed_x550em(struct ixgbe_hw *hw,
-				       ixgbe_link_speed speed)
+s32 ixgbe_validate_eeprom_checksum_X550(struct ixgbe_hw *hw, u16 *checksum_val)
 {
 	s32 status;
-	u32 reg_val;
+	u16 checksum;
+	u16 read_checksum = 0;
 
-	status = ixgbe_read_iosf_sb_reg_x550(hw,
-					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
-					IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
-	if (status)
+	DEBUGFUNC("ixgbe_validate_eeprom_checksum_X550");
+
+	/* Read the first word from the EEPROM. If this times out or fails, do
+	 * not continue or we could be in for a very long wait while every
+	 * EEPROM read fails
+	 */
+	status = hw->eeprom.ops.read(hw, 0, &checksum);
+	if (status) {
+		DEBUGOUT("EEPROM read failed\n");
 		return status;
+	}
 
-	reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_ENABLE;
-	reg_val &= ~(IXGBE_KRM_LINK_CTRL_1_TETH_AN_CAP_KR |
-		     IXGBE_KRM_LINK_CTRL_1_TETH_AN_CAP_KX);
+	status = hw->eeprom.ops.calc_checksum(hw);
+	if (status < 0)
+		return status;
 
-	/* Advertise 10G support. */
-	if (speed & IXGBE_LINK_SPEED_10GB_FULL)
-		reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_CAP_KR;
+	checksum = (u16)(status & 0xffff);
 
-	/* Advertise 1G support. */
-	if (speed & IXGBE_LINK_SPEED_1GB_FULL)
-		reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_CAP_KX;
+	status = ixgbe_read_ee_hostif_X550(hw, IXGBE_EEPROM_CHECKSUM,
+					   &read_checksum);
+	if (status)
+		return status;
 
-	/* Restart auto-negotiation. */
-	reg_val |= IXGBE_KRM_LINK_CTRL_1_TETH_AN_RESTART;
-	status = ixgbe_write_iosf_sb_reg_x550(hw,
-					IXGBE_KRM_LINK_CTRL_1(hw->bus.lan_id),
-					IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
+	/* Verify read checksum from EEPROM is the same as
+	 * calculated checksum
+	 */
+	if (read_checksum != checksum) {
+		status = IXGBE_ERR_EEPROM_CHECKSUM;
+		ERROR_REPORT1(IXGBE_ERROR_INVALID_STATE,
+			     "Invalid EEPROM checksum");
+	}
+
+	/* If the user cares, return the calculated checksum */
+	if (checksum_val)
+		*checksum_val = checksum;
 
 	return status;
 }
 
-/** ixgbe_setup_kx4_x550em - Configure the KX4 PHY.
- *  @hw: pointer to hardware structure
+/**
+ * ixgbe_update_eeprom_checksum_X550 - Updates the EEPROM checksum and flash
+ * @hw: pointer to hardware structure
  *
- *   Configures the integrated KX4 PHY.
+ * After writing EEPROM to shadow RAM using EEWR register, software calculates
+ * checksum and updates the EEPROM and instructs the hardware to update
+ * the flash.
  **/
-static s32 ixgbe_setup_kx4_x550em(struct ixgbe_hw *hw)
+s32 ixgbe_update_eeprom_checksum_X550(struct ixgbe_hw *hw)
 {
 	s32 status;
-	u32 reg_val;
+	u16 checksum = 0;
 
-	status = ixgbe_read_iosf_sb_reg_x550(hw, IXGBE_KX4_LINK_CNTL_1,
-					     IXGBE_SB_IOSF_TARGET_KX4_PCS0 +
-					     hw->bus.lan_id, &reg_val);
-	if (status)
-		return status;
+	DEBUGFUNC("ixgbe_update_eeprom_checksum_X550");
 
-	reg_val &= ~(IXGBE_KX4_LINK_CNTL_1_TETH_AN_CAP_KX4 |
-		     IXGBE_KX4_LINK_CNTL_1_TETH_AN_CAP_KX);
+	/* Read the first word from the EEPROM. If this times out or fails, do
+	 * not continue or we could be in for a very long wait while every
+	 * EEPROM read fails
+	 */
+	status = ixgbe_read_ee_hostif_X550(hw, 0, &checksum);
+	if (status) {
+		DEBUGOUT("EEPROM read failed\n");
+		return status;
+	}
 
-	reg_val |= IXGBE_KX4_LINK_CNTL_1_TETH_AN_ENABLE;
+	status = ixgbe_calc_eeprom_checksum_X550(hw);
+	if (status < 0)
+		return status;
 
-	/* Advertise 10G support. */
-	if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_10GB_FULL)
-		reg_val |= IXGBE_KX4_LINK_CNTL_1_TETH_AN_CAP_KX4;
+	checksum = (u16)(status & 0xffff);
 
-	/* Advertise 1G support. */
-	if (hw->phy.autoneg_advertised & IXGBE_LINK_SPEED_1GB_FULL)
-		reg_val |= IXGBE_KX4_LINK_CNTL_1_TETH_AN_CAP_KX;
+	status = ixgbe_write_ee_hostif_X550(hw, IXGBE_EEPROM_CHECKSUM,
+					    checksum);
+	if (status)
+		return status;
 
-	/* Restart auto-negotiation. */
-	reg_val |= IXGBE_KX4_LINK_CNTL_1_TETH_AN_RESTART;
-	status = ixgbe_write_iosf_sb_reg_x550(hw, IXGBE_KX4_LINK_CNTL_1,
-					      IXGBE_SB_IOSF_TARGET_KX4_PCS0 +
-					      hw->bus.lan_id, reg_val);
+	status = ixgbe_update_flash_X550(hw);
 
 	return status;
 }
 
-/**  ixgbe_setup_kr_x550em - Configure the KR PHY.
- *   @hw: pointer to hardware structure
- *
- *   Configures the integrated KR PHY.
- **/
-static s32 ixgbe_setup_kr_x550em(struct ixgbe_hw *hw)
-{
-	return ixgbe_setup_kr_speed_x550em(hw, hw->phy.autoneg_advertised);
-}
-
-/** ixgbe_ext_phy_t_x550em_get_link - Get ext phy link status
- *  @hw: address of hardware structure
- *  @link_up: address of boolean to indicate link status
+/**
+ *  ixgbe_update_flash_X550 - Instruct HW to copy EEPROM to Flash device
+ *  @hw: pointer to hardware structure
  *
- *  Returns error code if unable to get link status.
+ *  Issue a shadow RAM dump to FW to copy EEPROM from shadow RAM to the flash.
  **/
-static s32 ixgbe_ext_phy_t_x550em_get_link(struct ixgbe_hw *hw, bool *link_up)
+s32 ixgbe_update_flash_X550(struct ixgbe_hw *hw)
 {
-	u32 ret;
-	u16 autoneg_status;
-
-	*link_up = false;
+	s32 status = IXGBE_SUCCESS;
+	union ixgbe_hic_hdr2 buffer;
 
-	/* read this twice back to back to indicate current status */
-	ret = hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_STATUS,
-				   IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
-				   &autoneg_status);
-	if (ret)
-		return ret;
+	DEBUGFUNC("ixgbe_update_flash_X550");
 
-	ret = hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_STATUS,
-				   IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
-				   &autoneg_status);
-	if (ret)
-		return ret;
+	buffer.req.cmd = FW_SHADOW_RAM_DUMP_CMD;
+	buffer.req.buf_lenh = 0;
+	buffer.req.buf_lenl = FW_SHADOW_RAM_DUMP_LEN;
+	buffer.req.checksum = FW_DEFAULT_CHECKSUM;
 
-	*link_up = !!(autoneg_status & IXGBE_MDIO_AUTO_NEG_LINK_STATUS);
+	status = ixgbe_host_interface_command(hw, (u32 *)&buffer,
+					      sizeof(buffer),
+					      IXGBE_HI_COMMAND_TIMEOUT, false);
 
-	return 0;
+	return status;
 }
 
-/** ixgbe_setup_internal_phy_t_x550em - Configure KR PHY to X557 link
- *  @hw: point to hardware structure
- *
- *  Configures the link between the integrated KR PHY and the external X557 PHY
- *  The driver will call this function when it gets a link status change
- *  interrupt from the X557 PHY. This function configures the link speed
- *  between the PHYs to match the link speed of the BASE-T link.
+/**
+ *  ixgbe_get_supported_physical_layer_X550em - Returns physical layer type
+ *  @hw: pointer to hardware structure
  *
- * A return of a non-zero value indicates an error, and the base driver should
- * not report link up.
+ *  Determines physical layer capabilities of the current configuration.
  **/
-static s32 ixgbe_setup_internal_phy_t_x550em(struct ixgbe_hw *hw)
+u64 ixgbe_get_supported_physical_layer_X550em(struct ixgbe_hw *hw)
 {
-	ixgbe_link_speed force_speed;
-	bool link_up;
-	u32 status;
-	u16 speed;
-
-	if (hw->mac.ops.get_media_type(hw) != ixgbe_media_type_copper)
-		return IXGBE_ERR_CONFIG;
-
-	/* If link is not up, then there is no setup necessary so return  */
-	status = ixgbe_ext_phy_t_x550em_get_link(hw, &link_up);
-	if (status)
-		return status;
-
-	if (!link_up)
-		return 0;
-
-	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_VENDOR_STAT,
-				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
-				      &speed);
-	if (status)
-		return status;
-
-	/* If link is not still up, then no setup is necessary so return */
-	status = ixgbe_ext_phy_t_x550em_get_link(hw, &link_up);
-	if (status)
-		return status;
+	u64 physical_layer = IXGBE_PHYSICAL_LAYER_UNKNOWN;
+	u16 ext_ability = 0;
 
-	if (!link_up)
-		return 0;
+	DEBUGFUNC("ixgbe_get_supported_physical_layer_X550em");
 
-	/* clear everything but the speed and duplex bits */
-	speed &= IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_MASK;
+	hw->phy.ops.identify(hw);
 
-	switch (speed) {
-	case IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_10GB_FULL:
-		force_speed = IXGBE_LINK_SPEED_10GB_FULL;
+	switch (hw->phy.type) {
+	case ixgbe_phy_x550em_kr:
+		if (hw->mac.type == ixgbe_mac_X550EM_a) {
+			if (hw->phy.nw_mng_if_sel &
+			    IXGBE_NW_MNG_IF_SEL_PHY_SPEED_2_5G) {
+				physical_layer =
+					IXGBE_PHYSICAL_LAYER_2500BASE_KX;
+				break;
+			} else if (hw->device_id ==
+				   IXGBE_DEV_ID_X550EM_A_KR_L) {
+				physical_layer =
+					IXGBE_PHYSICAL_LAYER_1000BASE_KX;
+				break;
+			}
+		}
+		/* fall through */
+	case ixgbe_phy_x550em_xfi:
+		physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_KR |
+				 IXGBE_PHYSICAL_LAYER_1000BASE_KX;
 		break;
-	case IXGBE_MDIO_AUTO_NEG_VENDOR_STATUS_1GB_FULL:
-		force_speed = IXGBE_LINK_SPEED_1GB_FULL;
+	case ixgbe_phy_x550em_kx4:
+		physical_layer = IXGBE_PHYSICAL_LAYER_10GBASE_KX4 |
+				 IXGBE_PHYSICAL_LAYER_1000BASE_KX;
+		break;
+	case ixgbe_phy_x550em_ext_t:
+		hw->phy.ops.read_reg(hw, IXGBE_MDIO_PHY_EXT_ABILITY,
+				     IXGBE_MDIO_PMA_PMD_DEV_TYPE,
+				     &ext_ability);
+		if (ext_ability & IXGBE_MDIO_PHY_10GBASET_ABILITY)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_10GBASE_T;
+		if (ext_ability & IXGBE_MDIO_PHY_1000BASET_ABILITY)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_1000BASE_T;
+		break;
+	case ixgbe_phy_fw:
+		if (hw->phy.speeds_supported & IXGBE_LINK_SPEED_1GB_FULL)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_1000BASE_T;
+		if (hw->phy.speeds_supported & IXGBE_LINK_SPEED_100_FULL)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_100BASE_TX;
+		if (hw->phy.speeds_supported & IXGBE_LINK_SPEED_10_FULL)
+			physical_layer |= IXGBE_PHYSICAL_LAYER_10BASE_T;
+		break;
+	case ixgbe_phy_sgmii:
+		physical_layer = IXGBE_PHYSICAL_LAYER_1000BASE_KX;
+		break;
+	case ixgbe_phy_ext_1g_t:
+		physical_layer |= IXGBE_PHYSICAL_LAYER_1000BASE_T;
 		break;
 	default:
-		/* Internal PHY does not support anything else */
-		return IXGBE_ERR_INVALID_LINK_SETTINGS;
+		break;
 	}
 
-	return ixgbe_setup_ixfi_x550em(hw, &force_speed);
+	if (hw->mac.ops.get_media_type(hw) == ixgbe_media_type_fiber)
+		physical_layer = ixgbe_get_supported_phy_sfp_layer_generic(hw);
+
+	return physical_layer;
 }
 
-/** ixgbe_reset_phy_t_X550em - Performs X557 PHY reset and enables LASI
- *  @hw: pointer to hardware structure
+/**
+ * ixgbe_get_bus_info_x550em - Set PCI bus info
+ * @hw: pointer to hardware structure
+ *
+ * Sets bus link width and speed to unknown because X550em is
+ * not a PCI device.
  **/
-static s32 ixgbe_reset_phy_t_X550em(struct ixgbe_hw *hw)
+s32 ixgbe_get_bus_info_X550em(struct ixgbe_hw *hw)
 {
-	s32 status;
 
-	status = ixgbe_reset_phy_generic(hw);
+	DEBUGFUNC("ixgbe_get_bus_info_x550em");
 
-	if (status)
-		return status;
+	hw->bus.width = ixgbe_bus_width_unknown;
+	hw->bus.speed = ixgbe_bus_speed_unknown;
 
-	/* Configure Link Status Alarm and Temperature Threshold interrupts */
-	return ixgbe_enable_lasi_ext_t_x550em(hw);
+	hw->mac.ops.set_lan_id(hw);
+
+	return IXGBE_SUCCESS;
 }
 
-/** ixgbe_get_lcd_x550em - Determine lowest common denominator
- *  @hw: pointer to hardware structure
- *  @lcd_speed: pointer to lowest common link speed
+/**
+ * ixgbe_disable_rx_x550 - Disable RX unit
  *
- *  Determine lowest common link speed with link partner.
+ * Enables the Rx DMA unit for x550
  **/
-static s32 ixgbe_get_lcd_t_x550em(struct ixgbe_hw *hw,
-				  ixgbe_link_speed *lcd_speed)
+void ixgbe_disable_rx_x550(struct ixgbe_hw *hw)
 {
-	u16 an_lp_status;
+	u32 rxctrl, pfdtxgswc;
 	s32 status;
-	u16 word = hw->eeprom.ctrl_word_3;
+	struct ixgbe_hic_disable_rxen fw_cmd;
 
-	*lcd_speed = IXGBE_LINK_SPEED_UNKNOWN;
+	DEBUGFUNC("ixgbe_enable_rx_dma_x550");
 
-	status = hw->phy.ops.read_reg(hw, IXGBE_AUTO_NEG_LP_STATUS,
-				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
-				      &an_lp_status);
-	if (status)
-		return status;
+	rxctrl = IXGBE_READ_REG(hw, IXGBE_RXCTRL);
+	if (rxctrl & IXGBE_RXCTRL_RXEN) {
+		pfdtxgswc = IXGBE_READ_REG(hw, IXGBE_PFDTXGSWC);
+		if (pfdtxgswc & IXGBE_PFDTXGSWC_VT_LBEN) {
+			pfdtxgswc &= ~IXGBE_PFDTXGSWC_VT_LBEN;
+			IXGBE_WRITE_REG(hw, IXGBE_PFDTXGSWC, pfdtxgswc);
+			hw->mac.set_lben = true;
+		} else {
+			hw->mac.set_lben = false;
+		}
 
-	/* If link partner advertised 1G, return 1G */
-	if (an_lp_status & IXGBE_AUTO_NEG_LP_1000BASE_CAP) {
-		*lcd_speed = IXGBE_LINK_SPEED_1GB_FULL;
-		return status;
-	}
+		fw_cmd.hdr.cmd = FW_DISABLE_RXEN_CMD;
+		fw_cmd.hdr.buf_len = FW_DISABLE_RXEN_LEN;
+		fw_cmd.hdr.checksum = FW_DEFAULT_CHECKSUM;
+		fw_cmd.port_number = (u8)hw->bus.lan_id;
 
-	/* If 10G disabled for LPLU via NVM D10GMP, then return no valid LCD */
-	if ((hw->bus.lan_id && (word & NVM_INIT_CTRL_3_D10GMP_PORT1)) ||
-	    (word & NVM_INIT_CTRL_3_D10GMP_PORT0))
-		return status;
+		status = ixgbe_host_interface_command(hw, (u32 *)&fw_cmd,
+					sizeof(struct ixgbe_hic_disable_rxen),
+					IXGBE_HI_COMMAND_TIMEOUT, true);
 
-	/* Link partner not capable of lower speeds, return 10G */
-	*lcd_speed = IXGBE_LINK_SPEED_10GB_FULL;
-	return status;
+		/* If we fail - disable RX using register write */
+		if (status) {
+			rxctrl = IXGBE_READ_REG(hw, IXGBE_RXCTRL);
+			if (rxctrl & IXGBE_RXCTRL_RXEN) {
+				rxctrl &= ~IXGBE_RXCTRL_RXEN;
+				IXGBE_WRITE_REG(hw, IXGBE_RXCTRL, rxctrl);
+			}
+		}
+	}
 }
 
-/** ixgbe_enter_lplu_x550em - Transition to low power states
+/**
+ * ixgbe_enter_lplu_x550em - Transition to low power states
  *  @hw: pointer to hardware structure
  *
- *  Configures Low Power Link Up on transition to low power states
- *  (from D0 to non-D0). Link is required to enter LPLU so avoid resetting
- *  the X557 PHY immediately prior to entering LPLU.
+ * Configures Low Power Link Up on transition to low power states
+ * (from D0 to non-D0). Link is required to enter LPLU so avoid resetting the
+ * X557 PHY immediately prior to entering LPLU.
  **/
-static s32 ixgbe_enter_lplu_t_x550em(struct ixgbe_hw *hw)
+s32 ixgbe_enter_lplu_t_x550em(struct ixgbe_hw *hw)
 {
 	u16 an_10g_cntl_reg, autoneg_reg, speed;
 	s32 status;
@@ -1874,48 +3737,51 @@ static s32 ixgbe_enter_lplu_t_x550em(struct ixgbe_hw *hw)
 	bool link_up;
 
 	/* SW LPLU not required on later HW revisions. */
-	if (IXGBE_FUSES0_REV1 & IXGBE_READ_REG(hw, IXGBE_FUSES0_GROUP(0)))
-		return 0;
+	if ((hw->mac.type == ixgbe_mac_X550EM_x) &&
+	    (IXGBE_FUSES0_REV_MASK &
+	     IXGBE_READ_REG(hw, IXGBE_FUSES0_GROUP(0))))
+		return IXGBE_SUCCESS;
 
 	/* If blocked by MNG FW, then don't restart AN */
 	if (ixgbe_check_reset_blocked(hw))
-		return 0;
+		return IXGBE_SUCCESS;
 
 	status = ixgbe_ext_phy_t_x550em_get_link(hw, &link_up);
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return status;
 
-	status = hw->eeprom.ops.read(hw, NVM_INIT_CTRL_3,
-				     &hw->eeprom.ctrl_word_3);
-	if (status)
+	status = ixgbe_read_eeprom(hw, NVM_INIT_CTRL_3, &hw->eeprom.ctrl_word_3);
+
+	if (status != IXGBE_SUCCESS)
 		return status;
 
-	/* If link is down, LPLU disabled in NVM, WoL disabled, or
-	 * manageability disabled, then force link down by entering
-	 * low power mode.
+	/* If link is down, LPLU disabled in NVM, WoL disabled, or manageability
+	 * disabled, then force link down by entering low power mode.
 	 */
 	if (!link_up || !(hw->eeprom.ctrl_word_3 & NVM_INIT_CTRL_3_LPLU) ||
 	    !(hw->wol_enabled || ixgbe_mng_present(hw)))
-		return ixgbe_set_copper_phy_power(hw, false);
+		return ixgbe_set_copper_phy_power(hw, FALSE);
 
 	/* Determine LCD */
 	status = ixgbe_get_lcd_t_x550em(hw, &lcd_speed);
-	if (status)
+
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	/* If no valid LCD link speed, then force link down and exit. */
 	if (lcd_speed == IXGBE_LINK_SPEED_UNKNOWN)
-		return ixgbe_set_copper_phy_power(hw, false);
+		return ixgbe_set_copper_phy_power(hw, FALSE);
 
 	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_VENDOR_STAT,
 				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
 				      &speed);
-	if (status)
+
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	/* If no link now, speed is invalid so take link down */
 	status = ixgbe_ext_phy_t_x550em_get_link(hw, &link_up);
-	if (status)
+	if (status != IXGBE_SUCCESS)
 		return ixgbe_set_copper_phy_power(hw, false);
 
 	/* clear everything but the speed bits */
@@ -1932,20 +3798,23 @@ static s32 ixgbe_enter_lplu_t_x550em(struct ixgbe_hw *hw)
 	status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_VENDOR_TX_ALARM,
 				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
 				      &autoneg_reg);
-	if (status)
+
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	status = hw->phy.ops.read_reg(hw, IXGBE_MII_10GBASE_T_AUTONEG_CTRL_REG,
-				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
-				      &an_10g_cntl_reg);
-	if (status)
+			     IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+			     &an_10g_cntl_reg);
+
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	status = hw->phy.ops.read_reg(hw,
-				      IXGBE_MII_AUTONEG_VENDOR_PROVISION_1_REG,
-				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
-				      &autoneg_reg);
-	if (status)
+			     IXGBE_MII_AUTONEG_VENDOR_PROVISION_1_REG,
+			     IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+			     &autoneg_reg);
+
+	if (status != IXGBE_SUCCESS)
 		return status;
 
 	save_autoneg = hw->phy.autoneg_advertised;
@@ -1959,525 +3828,791 @@ static s32 ixgbe_enter_lplu_t_x550em(struct ixgbe_hw *hw)
 	return status;
 }
 
-/** ixgbe_init_phy_ops_X550em - PHY/SFP specific init
+/**
+ * ixgbe_get_lcd_x550em - Determine lowest common denominator
  *  @hw: pointer to hardware structure
+ *  @lcd_speed: pointer to lowest common link speed
  *
- *  Initialize any function pointers that were not able to be
- *  set during init_shared_code because the PHY/SFP type was
- *  not known.  Perform the SFP init if necessary.
+ * Determine lowest common link speed with link partner.
  **/
-static s32 ixgbe_init_phy_ops_X550em(struct ixgbe_hw *hw)
+s32 ixgbe_get_lcd_t_x550em(struct ixgbe_hw *hw, ixgbe_link_speed *lcd_speed)
 {
-	struct ixgbe_phy_info *phy = &hw->phy;
-	ixgbe_link_speed speed;
-	s32 ret_val;
+	u16 an_lp_status;
+	s32 status;
+	u16 word = hw->eeprom.ctrl_word_3;
 
-	hw->mac.ops.set_lan_id(hw);
+	*lcd_speed = IXGBE_LINK_SPEED_UNKNOWN;
 
-	if (hw->mac.ops.get_media_type(hw) == ixgbe_media_type_fiber) {
-		phy->phy_semaphore_mask = IXGBE_GSSR_SHARED_I2C_SM;
-		ixgbe_setup_mux_ctl(hw);
+	status = hw->phy.ops.read_reg(hw, IXGBE_AUTO_NEG_LP_STATUS,
+				      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+				      &an_lp_status);
 
-		/* Save NW management interface connected on board. This is used
-		 * to determine internal PHY mode.
-		 */
-		phy->nw_mng_if_sel = IXGBE_READ_REG(hw, IXGBE_NW_MNG_IF_SEL);
+	if (status != IXGBE_SUCCESS)
+		return status;
 
-		/* If internal PHY mode is KR, then initialize KR link */
-		if (phy->nw_mng_if_sel & IXGBE_NW_MNG_IF_SEL_INT_PHY_MODE) {
-			speed = IXGBE_LINK_SPEED_10GB_FULL |
-				IXGBE_LINK_SPEED_1GB_FULL;
-			ret_val = ixgbe_setup_kr_speed_x550em(hw, speed);
-		}
+	/* If link partner advertised 1G, return 1G */
+	if (an_lp_status & IXGBE_AUTO_NEG_LP_1000BASE_CAP) {
+		*lcd_speed = IXGBE_LINK_SPEED_1GB_FULL;
+		return status;
 	}
 
-	/* Identify the PHY or SFP module */
-	ret_val = phy->ops.identify(hw);
+	/* If 10G disabled for LPLU via NVM D10GMP, then return no valid LCD */
+	if ((hw->bus.lan_id && (word & NVM_INIT_CTRL_3_D10GMP_PORT1)) ||
+	    (word & NVM_INIT_CTRL_3_D10GMP_PORT0))
+		return status;
 
-	/* Setup function pointers based on detected hardware */
-	ixgbe_init_mac_link_ops_X550em(hw);
-	if (phy->sfp_type != ixgbe_sfp_type_unknown)
-		phy->ops.reset = NULL;
+	/* Link partner not capable of lower speeds, return 10G */
+	*lcd_speed = IXGBE_LINK_SPEED_10GB_FULL;
+	return status;
+}
 
-	/* Set functions pointers based on phy type */
-	switch (hw->phy.type) {
-	case ixgbe_phy_x550em_kx4:
-		phy->ops.setup_link = ixgbe_setup_kx4_x550em;
-		phy->ops.read_reg = ixgbe_read_phy_reg_x550em;
-		phy->ops.write_reg = ixgbe_write_phy_reg_x550em;
+/**
+ *  ixgbe_setup_fc_X550em - Set up flow control
+ *  @hw: pointer to hardware structure
+ *
+ *  Called at init time to set up flow control.
+ **/
+s32 ixgbe_setup_fc_X550em(struct ixgbe_hw *hw)
+{
+	s32 ret_val = IXGBE_SUCCESS;
+	u32 pause, asm_dir, reg_val;
+
+	DEBUGFUNC("ixgbe_setup_fc_X550em");
+
+	/* Validate the requested mode */
+	if (hw->fc.strict_ieee && hw->fc.requested_mode == ixgbe_fc_rx_pause) {
+		ERROR_REPORT1(IXGBE_ERROR_UNSUPPORTED,
+			"ixgbe_fc_rx_pause not valid in strict IEEE mode\n");
+		ret_val = IXGBE_ERR_INVALID_LINK_SETTINGS;
+		goto out;
+	}
+
+	/* 10gig parts do not have a word in the EEPROM to determine the
+	 * default flow control setting, so we explicitly set it to full.
+	 */
+	if (hw->fc.requested_mode == ixgbe_fc_default)
+		hw->fc.requested_mode = ixgbe_fc_full;
+
+	/* Determine PAUSE and ASM_DIR bits. */
+	switch (hw->fc.requested_mode) {
+	case ixgbe_fc_none:
+		pause = 0;
+		asm_dir = 0;
 		break;
-	case ixgbe_phy_x550em_kr:
-		phy->ops.setup_link = ixgbe_setup_kr_x550em;
-		phy->ops.read_reg = ixgbe_read_phy_reg_x550em;
-		phy->ops.write_reg = ixgbe_write_phy_reg_x550em;
+	case ixgbe_fc_tx_pause:
+		pause = 0;
+		asm_dir = 1;
 		break;
-	case ixgbe_phy_x550em_ext_t:
-		/* Save NW management interface connected on board. This is used
-		 * to determine internal PHY mode
-		 */
-		phy->nw_mng_if_sel = IXGBE_READ_REG(hw, IXGBE_NW_MNG_IF_SEL);
-
-		/* If internal link mode is XFI, then setup iXFI internal link,
-		 * else setup KR now.
+	case ixgbe_fc_rx_pause:
+		/* Rx Flow control is enabled and Tx Flow control is
+		 * disabled by software override. Since there really
+		 * isn't a way to advertise that we are capable of RX
+		 * Pause ONLY, we will advertise that we support both
+		 * symmetric and asymmetric Rx PAUSE, as such we fall
+		 * through to the fc_full statement.  Later, we will
+		 * disable the adapter's ability to send PAUSE frames.
 		 */
-		if (!(phy->nw_mng_if_sel & IXGBE_NW_MNG_IF_SEL_INT_PHY_MODE)) {
-			phy->ops.setup_internal_link =
-					ixgbe_setup_internal_phy_t_x550em;
-		} else {
-			speed = IXGBE_LINK_SPEED_10GB_FULL |
-				IXGBE_LINK_SPEED_1GB_FULL;
-			ret_val = ixgbe_setup_kr_speed_x550em(hw, speed);
-		}
+	case ixgbe_fc_full:
+		pause = 1;
+		asm_dir = 1;
+		break;
+	default:
+		ERROR_REPORT1(IXGBE_ERROR_ARGUMENT,
+			"Flow control param set incorrectly\n");
+		ret_val = IXGBE_ERR_CONFIG;
+		goto out;
+	}
 
-		/* setup SW LPLU only for first revision */
-		if (!(IXGBE_FUSES0_REV1 & IXGBE_READ_REG(hw,
-							IXGBE_FUSES0_GROUP(0))))
-			phy->ops.enter_lplu = ixgbe_enter_lplu_t_x550em;
+	switch (hw->device_id) {
+	case IXGBE_DEV_ID_X550EM_X_KR:
+	case IXGBE_DEV_ID_X550EM_A_KR:
+	case IXGBE_DEV_ID_X550EM_A_KR_L:
+		ret_val = hw->mac.ops.read_iosf_sb_reg(hw,
+					IXGBE_KRM_AN_CNTL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, &reg_val);
+		if (ret_val != IXGBE_SUCCESS)
+			goto out;
+		reg_val &= ~(IXGBE_KRM_AN_CNTL_1_SYM_PAUSE |
+			IXGBE_KRM_AN_CNTL_1_ASM_PAUSE);
+		if (pause)
+			reg_val |= IXGBE_KRM_AN_CNTL_1_SYM_PAUSE;
+		if (asm_dir)
+			reg_val |= IXGBE_KRM_AN_CNTL_1_ASM_PAUSE;
+		ret_val = hw->mac.ops.write_iosf_sb_reg(hw,
+					IXGBE_KRM_AN_CNTL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, reg_val);
 
-		phy->ops.handle_lasi = ixgbe_handle_lasi_ext_t_x550em;
-		phy->ops.reset = ixgbe_reset_phy_t_X550em;
+		/* This device does not fully support AN. */
+		hw->fc.disable_fc_autoneg = true;
+		break;
+	case IXGBE_DEV_ID_X550EM_X_XFI:
+		hw->fc.disable_fc_autoneg = true;
 		break;
 	default:
 		break;
 	}
 
+out:
 	return ret_val;
 }
 
-/** ixgbe_get_media_type_X550em - Get media type
+/**
+ *  ixgbe_fc_autoneg_backplane_x550em_a - Enable flow control IEEE clause 37
  *  @hw: pointer to hardware structure
  *
- *  Returns the media type (fiber, copper, backplane)
+ *  Enable flow control according to IEEE clause 37.
+ **/
+void ixgbe_fc_autoneg_backplane_x550em_a(struct ixgbe_hw *hw)
+{
+	u32 link_s1, lp_an_page_low, an_cntl_1;
+	s32 status = IXGBE_ERR_FC_NOT_NEGOTIATED;
+	ixgbe_link_speed speed;
+	bool link_up;
+
+	/* AN should have completed when the cable was plugged in.
+	 * Look for reasons to bail out.  Bail out if:
+	 * - FC autoneg is disabled, or if
+	 * - link is not up.
+	 */
+	if (hw->fc.disable_fc_autoneg) {
+		ERROR_REPORT1(IXGBE_ERROR_UNSUPPORTED,
+			     "Flow control autoneg is disabled");
+		goto out;
+	}
+
+	hw->mac.ops.check_link(hw, &speed, &link_up, false);
+	if (!link_up) {
+		ERROR_REPORT1(IXGBE_ERROR_SOFTWARE, "The link is down");
+		goto out;
+	}
+
+	/* Check at auto-negotiation has completed */
+	status = hw->mac.ops.read_iosf_sb_reg(hw,
+					IXGBE_KRM_LINK_S1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, &link_s1);
+
+	if (status != IXGBE_SUCCESS ||
+	    (link_s1 & IXGBE_KRM_LINK_S1_MAC_AN_COMPLETE) == 0) {
+		DEBUGOUT("Auto-Negotiation did not complete\n");
+		status = IXGBE_ERR_FC_NOT_NEGOTIATED;
+		goto out;
+	}
+
+	/* Read the 10g AN autoc and LP ability registers and resolve
+	 * local flow control settings accordingly
+	 */
+	status = hw->mac.ops.read_iosf_sb_reg(hw,
+				IXGBE_KRM_AN_CNTL_1(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, &an_cntl_1);
+
+	if (status != IXGBE_SUCCESS) {
+		DEBUGOUT("Auto-Negotiation did not complete\n");
+		goto out;
+	}
+
+	status = hw->mac.ops.read_iosf_sb_reg(hw,
+				IXGBE_KRM_LP_BASE_PAGE_HIGH(hw->bus.lan_id),
+				IXGBE_SB_IOSF_TARGET_KR_PHY, &lp_an_page_low);
+
+	if (status != IXGBE_SUCCESS) {
+		DEBUGOUT("Auto-Negotiation did not complete\n");
+		goto out;
+	}
+
+	status = ixgbe_negotiate_fc(hw, an_cntl_1, lp_an_page_low,
+				    IXGBE_KRM_AN_CNTL_1_SYM_PAUSE,
+				    IXGBE_KRM_AN_CNTL_1_ASM_PAUSE,
+				    IXGBE_KRM_LP_BASE_PAGE_HIGH_SYM_PAUSE,
+				    IXGBE_KRM_LP_BASE_PAGE_HIGH_ASM_PAUSE);
+
+out:
+	if (status == IXGBE_SUCCESS) {
+		hw->fc.fc_was_autonegged = true;
+	} else {
+		hw->fc.fc_was_autonegged = false;
+		hw->fc.current_mode = hw->fc.requested_mode;
+	}
+}
+
+/**
+ *  ixgbe_fc_autoneg_fiber_x550em_a - passthrough FC settings
+ *  @hw: pointer to hardware structure
  *
- */
-static enum ixgbe_media_type ixgbe_get_media_type_X550em(struct ixgbe_hw *hw)
+ **/
+void ixgbe_fc_autoneg_fiber_x550em_a(struct ixgbe_hw *hw)
 {
-	enum ixgbe_media_type media_type;
+	hw->fc.fc_was_autonegged = false;
+	hw->fc.current_mode = hw->fc.requested_mode;
+}
 
-	/* Detect if there is a copper PHY attached. */
-	switch (hw->device_id) {
-	case IXGBE_DEV_ID_X550EM_X_KR:
-	case IXGBE_DEV_ID_X550EM_X_KX4:
-		media_type = ixgbe_media_type_backplane;
-		break;
-	case IXGBE_DEV_ID_X550EM_X_SFP:
-		media_type = ixgbe_media_type_fiber;
-		break;
-	case IXGBE_DEV_ID_X550EM_X_1G_T:
-	case IXGBE_DEV_ID_X550EM_X_10G_T:
-		 media_type = ixgbe_media_type_copper;
-		break;
-	default:
-		media_type = ixgbe_media_type_unknown;
-		break;
+/**
+ *  ixgbe_fc_autoneg_sgmii_x550em_a - Enable flow control IEEE clause 37
+ *  @hw: pointer to hardware structure
+ *
+ *  Enable flow control according to IEEE clause 37.
+ **/
+void ixgbe_fc_autoneg_sgmii_x550em_a(struct ixgbe_hw *hw)
+{
+	s32 status = IXGBE_ERR_FC_NOT_NEGOTIATED;
+	u32 info[FW_PHY_ACT_DATA_COUNT] = { 0 };
+	ixgbe_link_speed speed;
+	bool link_up;
+
+	/* AN should have completed when the cable was plugged in.
+	 * Look for reasons to bail out.  Bail out if:
+	 * - FC autoneg is disabled, or if
+	 * - link is not up.
+	 */
+	if (hw->fc.disable_fc_autoneg) {
+		ERROR_REPORT1(IXGBE_ERROR_UNSUPPORTED,
+			     "Flow control autoneg is disabled");
+		goto out;
+	}
+
+	hw->mac.ops.check_link(hw, &speed, &link_up, false);
+	if (!link_up) {
+		ERROR_REPORT1(IXGBE_ERROR_SOFTWARE, "The link is down");
+		goto out;
+	}
+
+	/* Check if auto-negotiation has completed */
+	status = ixgbe_fw_phy_activity(hw, FW_PHY_ACT_GET_LINK_INFO, &info);
+	if (status != IXGBE_SUCCESS ||
+	    !(info[0] & FW_PHY_ACT_GET_LINK_INFO_AN_COMPLETE)) {
+		DEBUGOUT("Auto-Negotiation did not complete\n");
+		status = IXGBE_ERR_FC_NOT_NEGOTIATED;
+		goto out;
+	}
+
+	/* Negotiate the flow control */
+	status = ixgbe_negotiate_fc(hw, info[0], info[0],
+				    FW_PHY_ACT_GET_LINK_INFO_FC_RX,
+				    FW_PHY_ACT_GET_LINK_INFO_FC_TX,
+				    FW_PHY_ACT_GET_LINK_INFO_LP_FC_RX,
+				    FW_PHY_ACT_GET_LINK_INFO_LP_FC_TX);
+
+out:
+	if (status == IXGBE_SUCCESS) {
+		hw->fc.fc_was_autonegged = true;
+	} else {
+		hw->fc.fc_was_autonegged = false;
+		hw->fc.current_mode = hw->fc.requested_mode;
 	}
-	return media_type;
 }
 
-/** ixgbe_init_ext_t_x550em - Start (unstall) the external Base T PHY.
- ** @hw: pointer to hardware structure
+/**
+ *  ixgbe_setup_fc_backplane_x550em_a - Set up flow control
+ *  @hw: pointer to hardware structure
+ *
+ *  Called at init time to set up flow control.
  **/
-static s32 ixgbe_init_ext_t_x550em(struct ixgbe_hw *hw)
+s32 ixgbe_setup_fc_backplane_x550em_a(struct ixgbe_hw *hw)
 {
-	s32 status;
-	u16 reg;
+	s32 status = IXGBE_SUCCESS;
+	u32 an_cntl = 0;
 
-	status = hw->phy.ops.read_reg(hw,
-				      IXGBE_MDIO_TX_VENDOR_ALARMS_3,
-				      IXGBE_MDIO_PMA_PMD_DEV_TYPE,
-				      &reg);
-	if (status)
-		return status;
+	DEBUGFUNC("ixgbe_setup_fc_backplane_x550em_a");
 
-	/* If PHY FW reset completed bit is set then this is the first
-	 * SW instance after a power on so the PHY FW must be un-stalled.
+	/* Validate the requested mode */
+	if (hw->fc.strict_ieee && hw->fc.requested_mode == ixgbe_fc_rx_pause) {
+		ERROR_REPORT1(IXGBE_ERROR_UNSUPPORTED,
+			      "ixgbe_fc_rx_pause not valid in strict IEEE mode\n");
+		return IXGBE_ERR_INVALID_LINK_SETTINGS;
+	}
+
+	if (hw->fc.requested_mode == ixgbe_fc_default)
+		hw->fc.requested_mode = ixgbe_fc_full;
+
+	/* Set up the 1G and 10G flow control advertisement registers so the
+	 * HW will be able to do FC autoneg once the cable is plugged in.  If
+	 * we link at 10G, the 1G advertisement is harmless and vice versa.
 	 */
-	if (reg & IXGBE_MDIO_TX_VENDOR_ALARMS_3_RST_MASK) {
-		status = hw->phy.ops.read_reg(hw,
-					IXGBE_MDIO_GLOBAL_RES_PR_10,
-					IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
-					&reg);
-		if (status)
-			return status;
+	status = hw->mac.ops.read_iosf_sb_reg(hw,
+					IXGBE_KRM_AN_CNTL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, &an_cntl);
 
-		reg &= ~IXGBE_MDIO_POWER_UP_STALL;
+	if (status != IXGBE_SUCCESS) {
+		DEBUGOUT("Auto-Negotiation did not complete\n");
+		return status;
+	}
 
-		status = hw->phy.ops.write_reg(hw,
-					IXGBE_MDIO_GLOBAL_RES_PR_10,
-					IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE,
-					reg);
-		if (status)
-			return status;
+	/* The possible values of fc.requested_mode are:
+	 * 0: Flow control is completely disabled
+	 * 1: Rx flow control is enabled (we can receive pause frames,
+	 *    but not send pause frames).
+	 * 2: Tx flow control is enabled (we can send pause frames but
+	 *    we do not support receiving pause frames).
+	 * 3: Both Rx and Tx flow control (symmetric) are enabled.
+	 * other: Invalid.
+	 */
+	switch (hw->fc.requested_mode) {
+	case ixgbe_fc_none:
+		/* Flow control completely disabled by software override. */
+		an_cntl &= ~(IXGBE_KRM_AN_CNTL_1_SYM_PAUSE |
+			     IXGBE_KRM_AN_CNTL_1_ASM_PAUSE);
+		break;
+	case ixgbe_fc_tx_pause:
+		/* Tx Flow control is enabled, and Rx Flow control is
+		 * disabled by software override.
+		 */
+		an_cntl |= IXGBE_KRM_AN_CNTL_1_ASM_PAUSE;
+		an_cntl &= ~IXGBE_KRM_AN_CNTL_1_SYM_PAUSE;
+		break;
+	case ixgbe_fc_rx_pause:
+		/* Rx Flow control is enabled and Tx Flow control is
+		 * disabled by software override. Since there really
+		 * isn't a way to advertise that we are capable of RX
+		 * Pause ONLY, we will advertise that we support both
+		 * symmetric and asymmetric Rx PAUSE, as such we fall
+		 * through to the fc_full statement.  Later, we will
+		 * disable the adapter's ability to send PAUSE frames.
+		 */
+	case ixgbe_fc_full:
+		/* Flow control (both Rx and Tx) is enabled by SW override. */
+		an_cntl |= IXGBE_KRM_AN_CNTL_1_SYM_PAUSE |
+			   IXGBE_KRM_AN_CNTL_1_ASM_PAUSE;
+		break;
+	default:
+		ERROR_REPORT1(IXGBE_ERROR_ARGUMENT,
+			      "Flow control param set incorrectly\n");
+		return IXGBE_ERR_CONFIG;
 	}
 
+	status = hw->mac.ops.write_iosf_sb_reg(hw,
+					IXGBE_KRM_AN_CNTL_1(hw->bus.lan_id),
+					IXGBE_SB_IOSF_TARGET_KR_PHY, an_cntl);
+
+	/* Restart auto-negotiation. */
+	status = ixgbe_restart_an_internal_phy_x550em(hw);
+
 	return status;
 }
 
-/**  ixgbe_reset_hw_X550em - Perform hardware reset
- **  @hw: pointer to hardware structure
- **
- **  Resets the hardware by resetting the transmit and receive units, masks
- **  and clears all interrupts, perform a PHY reset, and perform a link (MAC)
- **  reset.
+/**
+ * ixgbe_set_mux - Set mux for port 1 access with CS4227
+ * @hw: pointer to hardware structure
+ * @state: set mux if 1, clear if 0
+ */
+STATIC void ixgbe_set_mux(struct ixgbe_hw *hw, u8 state)
+{
+	u32 esdp;
+
+	if (!hw->bus.lan_id)
+		return;
+	esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
+	if (state)
+		esdp |= IXGBE_ESDP_SDP1;
+	else
+		esdp &= ~IXGBE_ESDP_SDP1;
+	IXGBE_WRITE_REG(hw, IXGBE_ESDP, esdp);
+	IXGBE_WRITE_FLUSH(hw);
+}
+
+/**
+ *  ixgbe_acquire_swfw_sync_X550em - Acquire SWFW semaphore
+ *  @hw: pointer to hardware structure
+ *  @mask: Mask to specify which semaphore to acquire
+ *
+ *  Acquires the SWFW semaphore and sets the I2C MUX
  **/
-static s32 ixgbe_reset_hw_X550em(struct ixgbe_hw *hw)
+s32 ixgbe_acquire_swfw_sync_X550em(struct ixgbe_hw *hw, u32 mask)
 {
-	ixgbe_link_speed link_speed;
 	s32 status;
-	u32 ctrl = 0;
-	u32 i;
-	u32 hlreg0;
-	bool link_up = false;
 
-	/* Call adapter stop to disable Tx/Rx and clear interrupts */
-	status = hw->mac.ops.stop_adapter(hw);
-	if (status)
-		return status;
+	DEBUGFUNC("ixgbe_acquire_swfw_sync_X550em");
+
+	status = ixgbe_acquire_swfw_sync_X540(hw, mask);
+	if (status)
+		return status;
+
+	if (mask & IXGBE_GSSR_I2C_MASK)
+		ixgbe_set_mux(hw, 1);
+
+	return IXGBE_SUCCESS;
+}
+
+/**
+ *  ixgbe_release_swfw_sync_X550em - Release SWFW semaphore
+ *  @hw: pointer to hardware structure
+ *  @mask: Mask to specify which semaphore to release
+ *
+ *  Releases the SWFW semaphore and sets the I2C MUX
+ **/
+void ixgbe_release_swfw_sync_X550em(struct ixgbe_hw *hw, u32 mask)
+{
+	DEBUGFUNC("ixgbe_release_swfw_sync_X550em");
+
+	if (mask & IXGBE_GSSR_I2C_MASK)
+		ixgbe_set_mux(hw, 0);
 
-	/* flush pending Tx transactions */
-	ixgbe_clear_tx_pending(hw);
+	ixgbe_release_swfw_sync_X540(hw, mask);
+}
 
-	/* PHY ops must be identified and initialized prior to reset */
+/**
+ *  ixgbe_acquire_swfw_sync_X550a - Acquire SWFW semaphore
+ *  @hw: pointer to hardware structure
+ *  @mask: Mask to specify which semaphore to acquire
+ *
+ *  Acquires the SWFW semaphore and get the shared phy token as needed
+ */
+STATIC s32 ixgbe_acquire_swfw_sync_X550a(struct ixgbe_hw *hw, u32 mask)
+{
+	u32 hmask = mask & ~IXGBE_GSSR_TOKEN_SM;
+	int retries = FW_PHY_TOKEN_RETRIES;
+	s32 status = IXGBE_SUCCESS;
 
-	/* Identify PHY and related function pointers */
-	status = hw->phy.ops.init(hw);
+	DEBUGFUNC("ixgbe_acquire_swfw_sync_X550a");
 
-	/* start the external PHY */
-	if (hw->phy.type == ixgbe_phy_x550em_ext_t) {
-		status = ixgbe_init_ext_t_x550em(hw);
-		if (status)
+	while (--retries) {
+		status = IXGBE_SUCCESS;
+		if (hmask)
+			status = ixgbe_acquire_swfw_sync_X540(hw, hmask);
+		if (status) {
+			DEBUGOUT1("Could not acquire SWFW semaphore, Status = %d\n",
+				  status);
 			return status;
-	}
+		}
+		if (!(mask & IXGBE_GSSR_TOKEN_SM))
+			return IXGBE_SUCCESS;
 
-	/* Setup SFP module if there is one present. */
-	if (hw->phy.sfp_setup_needed) {
-		status = hw->mac.ops.setup_sfp(hw);
-		hw->phy.sfp_setup_needed = false;
-	}
+		status = ixgbe_get_phy_token(hw);
+		if (status == IXGBE_ERR_TOKEN_RETRY)
+			DEBUGOUT1("Could not acquire PHY token, Status = %d\n",
+				  status);
 
-	/* Reset PHY */
-	if (!hw->phy.reset_disable && hw->phy.ops.reset)
-		hw->phy.ops.reset(hw);
+		if (status == IXGBE_SUCCESS)
+			return IXGBE_SUCCESS;
 
-mac_reset_top:
-	/* Issue global reset to the MAC.  Needs to be SW reset if link is up.
-	 * If link reset is used when link is up, it might reset the PHY when
-	 * mng is using it.  If link is down or the flag to force full link
-	 * reset is set, then perform link reset.
-	 */
-	ctrl = IXGBE_CTRL_LNK_RST;
+		if (hmask)
+			ixgbe_release_swfw_sync_X540(hw, hmask);
 
-	if (!hw->force_full_reset) {
-		hw->mac.ops.check_link(hw, &link_speed, &link_up, false);
-		if (link_up)
-			ctrl = IXGBE_CTRL_RST;
+		if (status != IXGBE_ERR_TOKEN_RETRY) {
+			DEBUGOUT1("Unable to retry acquiring the PHY token, Status = %d\n",
+				  status);
+			return status;
+		}
 	}
 
-	ctrl |= IXGBE_READ_REG(hw, IXGBE_CTRL);
-	IXGBE_WRITE_REG(hw, IXGBE_CTRL, ctrl);
-	IXGBE_WRITE_FLUSH(hw);
+	DEBUGOUT1("Semaphore acquisition retries failed!: PHY ID = 0x%08X\n",
+		  hw->phy.id);
+	return status;
+}
 
-	/* Poll for reset bit to self-clear meaning reset is complete */
-	for (i = 0; i < 10; i++) {
-		udelay(1);
-		ctrl = IXGBE_READ_REG(hw, IXGBE_CTRL);
-		if (!(ctrl & IXGBE_CTRL_RST_MASK))
-			break;
-	}
+/**
+ *  ixgbe_release_swfw_sync_X550a - Release SWFW semaphore
+ *  @hw: pointer to hardware structure
+ *  @mask: Mask to specify which semaphore to release
+ *
+ *  Releases the SWFW semaphore and puts the shared phy token as needed
+ */
+STATIC void ixgbe_release_swfw_sync_X550a(struct ixgbe_hw *hw, u32 mask)
+{
+	u32 hmask = mask & ~IXGBE_GSSR_TOKEN_SM;
 
-	if (ctrl & IXGBE_CTRL_RST_MASK) {
-		status = IXGBE_ERR_RESET_FAILED;
-		hw_dbg(hw, "Reset polling failed to complete.\n");
-	}
+	DEBUGFUNC("ixgbe_release_swfw_sync_X550a");
 
-	msleep(50);
+	if (mask & IXGBE_GSSR_TOKEN_SM)
+		ixgbe_put_phy_token(hw);
 
-	/* Double resets are required for recovery from certain error
-	 * clear the multicast table.  Also reset num_rar_entries to 128,
-	 * since we modify this value when programming the SAN MAC address.
-	 */
-	if (hw->mac.flags & IXGBE_FLAGS_DOUBLE_RESET_REQUIRED) {
-		hw->mac.flags &= ~IXGBE_FLAGS_DOUBLE_RESET_REQUIRED;
-		goto mac_reset_top;
-	}
+	if (hmask)
+		ixgbe_release_swfw_sync_X540(hw, hmask);
+}
 
-	/* Store the permanent mac address */
-	hw->mac.ops.get_mac_addr(hw, hw->mac.perm_addr);
+/**
+ *  ixgbe_read_phy_reg_x550a  - Reads specified PHY register
+ *  @hw: pointer to hardware structure
+ *  @reg_addr: 32 bit address of PHY register to read
+ *  @phy_data: Pointer to read data from PHY register
+ *
+ *  Reads a value from a specified PHY register using the SWFW lock and PHY
+ *  Token. The PHY Token is needed since the MDIO is shared between to MAC
+ *  instances.
+ **/
+s32 ixgbe_read_phy_reg_x550a(struct ixgbe_hw *hw, u32 reg_addr,
+			       u32 device_type, u16 *phy_data)
+{
+	s32 status;
+	u32 mask = hw->phy.phy_semaphore_mask | IXGBE_GSSR_TOKEN_SM;
 
-	/* Store MAC address from RAR0, clear receive address registers, and
-	 * clear the multicast table.  Also reset num_rar_entries to 128,
-	 * since we modify this value when programming the SAN MAC address.
-	 */
-	hw->mac.num_rar_entries = 128;
-	hw->mac.ops.init_rx_addrs(hw);
+	DEBUGFUNC("ixgbe_read_phy_reg_x550a");
 
-	if (hw->device_id == IXGBE_DEV_ID_X550EM_X_10G_T) {
-		hlreg0 = IXGBE_READ_REG(hw, IXGBE_HLREG0);
-		hlreg0 &= ~IXGBE_HLREG0_MDCSPD;
-		IXGBE_WRITE_REG(hw, IXGBE_HLREG0, hlreg0);
-	}
+	if (hw->mac.ops.acquire_swfw_sync(hw, mask))
+		return IXGBE_ERR_SWFW_SYNC;
 
-	if (hw->device_id == IXGBE_DEV_ID_X550EM_X_SFP)
-		ixgbe_setup_mux_ctl(hw);
+	status = hw->phy.ops.read_reg_mdi(hw, reg_addr, device_type, phy_data);
+
+	hw->mac.ops.release_swfw_sync(hw, mask);
 
 	return status;
 }
 
-/** ixgbe_set_ethertype_anti_spoofing_X550 - Enable/Disable Ethertype
- *	anti-spoofing
- *  @hw:  pointer to hardware structure
- *  @enable: enable or disable switch for Ethertype anti-spoofing
- *  @vf: Virtual Function pool - VF Pool to set for Ethertype anti-spoofing
+/**
+ *  ixgbe_write_phy_reg_x550a - Writes specified PHY register
+ *  @hw: pointer to hardware structure
+ *  @reg_addr: 32 bit PHY register to write
+ *  @device_type: 5 bit device type
+ *  @phy_data: Data to write to the PHY register
+ *
+ *  Writes a value to specified PHY register using the SWFW lock and PHY Token.
+ *  The PHY Token is needed since the MDIO is shared between to MAC instances.
  **/
-static void ixgbe_set_ethertype_anti_spoofing_X550(struct ixgbe_hw *hw,
-						   bool enable, int vf)
+s32 ixgbe_write_phy_reg_x550a(struct ixgbe_hw *hw, u32 reg_addr,
+				u32 device_type, u16 phy_data)
 {
-	int vf_target_reg = vf >> 3;
-	int vf_target_shift = vf % 8 + IXGBE_SPOOF_ETHERTYPEAS_SHIFT;
-	u32 pfvfspoof;
+	s32 status;
+	u32 mask = hw->phy.phy_semaphore_mask | IXGBE_GSSR_TOKEN_SM;
 
-	pfvfspoof = IXGBE_READ_REG(hw, IXGBE_PFVFSPOOF(vf_target_reg));
-	if (enable)
-		pfvfspoof |= (1 << vf_target_shift);
-	else
-		pfvfspoof &= ~(1 << vf_target_shift);
+	DEBUGFUNC("ixgbe_write_phy_reg_x550a");
 
-	IXGBE_WRITE_REG(hw, IXGBE_PFVFSPOOF(vf_target_reg), pfvfspoof);
+	if (hw->mac.ops.acquire_swfw_sync(hw, mask) == IXGBE_SUCCESS) {
+		status = hw->phy.ops.write_reg_mdi(hw, reg_addr, device_type,
+						 phy_data);
+		hw->mac.ops.release_swfw_sync(hw, mask);
+	} else {
+		status = IXGBE_ERR_SWFW_SYNC;
+	}
+
+	return status;
 }
 
-/** ixgbe_set_source_address_pruning_X550 - Enable/Disbale src address pruning
- *  @hw: pointer to hardware structure
- *  @enable: enable or disable source address pruning
- *  @pool: Rx pool to set source address pruning for
- **/
-static void ixgbe_set_source_address_pruning_X550(struct ixgbe_hw *hw,
-						  bool enable,
-						  unsigned int pool)
+/**
+ * ixgbe_handle_lasi_ext_t_x550em - Handle external Base T PHY interrupt
+ * @hw: pointer to hardware structure
+ *
+ * Handle external Base T PHY interrupt. If high temperature
+ * failure alarm then return error, else if link status change
+ * then setup internal/external PHY link
+ *
+ * Return IXGBE_ERR_OVERTEMP if interrupt is high temperature
+ * failure alarm, else return PHY access status.
+ */
+s32 ixgbe_handle_lasi_ext_t_x550em(struct ixgbe_hw *hw)
 {
-	u64 pfflp;
+	bool lsc;
+	u32 status;
 
-	/* max rx pool is 63 */
-	if (pool > 63)
-		return;
+	status = ixgbe_get_lasi_ext_t_x550em(hw, &lsc);
 
-	pfflp = (u64)IXGBE_READ_REG(hw, IXGBE_PFFLPL);
-	pfflp |= (u64)IXGBE_READ_REG(hw, IXGBE_PFFLPH) << 32;
+	if (status != IXGBE_SUCCESS)
+		return status;
 
-	if (enable)
-		pfflp |= (1ULL << pool);
-	else
-		pfflp &= ~(1ULL << pool);
+	if (lsc)
+		return ixgbe_setup_internal_phy(hw);
 
-	IXGBE_WRITE_REG(hw, IXGBE_PFFLPL, (u32)pfflp);
-	IXGBE_WRITE_REG(hw, IXGBE_PFFLPH, (u32)(pfflp >> 32));
+	return IXGBE_SUCCESS;
 }
 
 /**
- * ixgbe_set_mux - Set mux for port 1 access with CS4227
+ * ixgbe_setup_mac_link_t_X550em - Sets the auto advertised link speed
  * @hw: pointer to hardware structure
- * @state: set mux if 1, clear if 0
- */
-static void ixgbe_set_mux(struct ixgbe_hw *hw, u8 state)
+ * @speed: new link speed
+ * @autoneg_wait_to_complete: true when waiting for completion is needed
+ *
+ * Setup internal/external PHY link speed based on link speed, then set
+ * external PHY auto advertised link speed.
+ *
+ * Returns error status for any failure
+ **/
+s32 ixgbe_setup_mac_link_t_X550em(struct ixgbe_hw *hw,
+				  ixgbe_link_speed speed,
+				  bool autoneg_wait_to_complete)
 {
-	u32 esdp;
+	s32 status;
+	ixgbe_link_speed force_speed;
 
-	if (!hw->bus.lan_id)
-		return;
-	esdp = IXGBE_READ_REG(hw, IXGBE_ESDP);
-	if (state)
-		esdp |= IXGBE_ESDP_SDP1;
+	DEBUGFUNC("ixgbe_setup_mac_link_t_X550em");
+
+	/* Setup internal/external PHY link speed to iXFI (10G), unless
+	 * only 1G is auto advertised then setup KX link.
+	 */
+	if (speed & IXGBE_LINK_SPEED_10GB_FULL)
+		force_speed = IXGBE_LINK_SPEED_10GB_FULL;
 	else
-		esdp &= ~IXGBE_ESDP_SDP1;
-	IXGBE_WRITE_REG(hw, IXGBE_ESDP, esdp);
-	IXGBE_WRITE_FLUSH(hw);
+		force_speed = IXGBE_LINK_SPEED_1GB_FULL;
+
+	/* If X552 and internal link mode is XFI, then setup XFI internal link.
+	 */
+	if (hw->mac.type == ixgbe_mac_X550EM_x &&
+	    !(hw->phy.nw_mng_if_sel & IXGBE_NW_MNG_IF_SEL_INT_PHY_MODE)) {
+		status = ixgbe_setup_ixfi_x550em(hw, &force_speed);
+
+		if (status != IXGBE_SUCCESS)
+			return status;
+	}
+
+	return hw->phy.ops.setup_link_speed(hw, speed, autoneg_wait_to_complete);
 }
 
 /**
- * ixgbe_acquire_swfw_sync_X550em - Acquire SWFW semaphore
+ * ixgbe_check_link_t_X550em - Determine link and speed status
  * @hw: pointer to hardware structure
- * @mask: Mask to specify which semaphore to acquire
+ * @speed: pointer to link speed
+ * @link_up: true when link is up
+ * @link_up_wait_to_complete: bool used to wait for link up or not
  *
- * Acquires the SWFW semaphore and sets the I2C MUX
- */
-static s32 ixgbe_acquire_swfw_sync_X550em(struct ixgbe_hw *hw, u32 mask)
+ * Check that both the MAC and X557 external PHY have link.
+ **/
+s32 ixgbe_check_link_t_X550em(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
+			      bool *link_up, bool link_up_wait_to_complete)
 {
-	s32 status;
+	u32 status;
+	u16 i, autoneg_status = 0;
 
-	status = ixgbe_acquire_swfw_sync_X540(hw, mask);
-	if (status)
+	if (hw->mac.ops.get_media_type(hw) != ixgbe_media_type_copper)
+		return IXGBE_ERR_CONFIG;
+
+	status = ixgbe_check_mac_link_generic(hw, speed, link_up,
+					      link_up_wait_to_complete);
+
+	/* If check link fails or MAC link is not up, then return */
+	if (status != IXGBE_SUCCESS || !(*link_up))
 		return status;
 
-	if (mask & IXGBE_GSSR_I2C_MASK)
-		ixgbe_set_mux(hw, 1);
+	/* MAC link is up, so check external PHY link.
+	 * X557 PHY. Link status is latching low, and can only be used to detect
+	 * link drop, and not the current status of the link without performing
+	 * back-to-back reads.
+	 */
+	for (i = 0; i < 2; i++) {
+		status = hw->phy.ops.read_reg(hw, IXGBE_MDIO_AUTO_NEG_STATUS,
+					      IXGBE_MDIO_AUTO_NEG_DEV_TYPE,
+					      &autoneg_status);
+
+		if (status != IXGBE_SUCCESS)
+			return status;
+	}
+
+	/* If external PHY link is not up, then indicate link not up */
+	if (!(autoneg_status & IXGBE_MDIO_AUTO_NEG_LINK_STATUS))
+		*link_up = false;
 
-	return 0;
+	return IXGBE_SUCCESS;
 }
 
 /**
- * ixgbe_release_swfw_sync_X550em - Release SWFW semaphore
- * @hw: pointer to hardware structure
- * @mask: Mask to specify which semaphore to release
- *
- * Releases the SWFW semaphore and sets the I2C MUX
- */
-static void ixgbe_release_swfw_sync_X550em(struct ixgbe_hw *hw, u32 mask)
+ *  ixgbe_reset_phy_t_X550em - Performs X557 PHY reset and enables LASI
+ *  @hw: pointer to hardware structure
+ **/
+s32 ixgbe_reset_phy_t_X550em(struct ixgbe_hw *hw)
 {
-	if (mask & IXGBE_GSSR_I2C_MASK)
-		ixgbe_set_mux(hw, 0);
+	s32 status;
 
-	ixgbe_release_swfw_sync_X540(hw, mask);
+	status = ixgbe_reset_phy_generic(hw);
+
+	if (status != IXGBE_SUCCESS)
+		return status;
+
+	/* Configure Link Status Alarm and Temperature Threshold interrupts */
+	return ixgbe_enable_lasi_ext_t_x550em(hw);
 }
 
-#define X550_COMMON_MAC \
-	.init_hw			= &ixgbe_init_hw_generic, \
-	.start_hw			= &ixgbe_start_hw_X540, \
-	.clear_hw_cntrs			= &ixgbe_clear_hw_cntrs_generic, \
-	.enable_rx_dma			= &ixgbe_enable_rx_dma_generic, \
-	.get_mac_addr			= &ixgbe_get_mac_addr_generic, \
-	.get_device_caps		= &ixgbe_get_device_caps_generic, \
-	.stop_adapter			= &ixgbe_stop_adapter_generic, \
-	.set_lan_id			= &ixgbe_set_lan_id_multi_port_pcie, \
-	.read_analog_reg8		= NULL, \
-	.write_analog_reg8		= NULL, \
-	.set_rxpba			= &ixgbe_set_rxpba_generic, \
-	.check_link			= &ixgbe_check_mac_link_generic, \
-	.led_on				= &ixgbe_led_on_generic, \
-	.led_off			= &ixgbe_led_off_generic, \
-	.blink_led_start		= &ixgbe_blink_led_start_X540, \
-	.blink_led_stop			= &ixgbe_blink_led_stop_X540, \
-	.set_rar			= &ixgbe_set_rar_generic, \
-	.clear_rar			= &ixgbe_clear_rar_generic, \
-	.set_vmdq			= &ixgbe_set_vmdq_generic, \
-	.set_vmdq_san_mac		= &ixgbe_set_vmdq_san_mac_generic, \
-	.clear_vmdq			= &ixgbe_clear_vmdq_generic, \
-	.init_rx_addrs			= &ixgbe_init_rx_addrs_generic, \
-	.update_mc_addr_list		= &ixgbe_update_mc_addr_list_generic, \
-	.enable_mc			= &ixgbe_enable_mc_generic, \
-	.disable_mc			= &ixgbe_disable_mc_generic, \
-	.clear_vfta			= &ixgbe_clear_vfta_generic, \
-	.set_vfta			= &ixgbe_set_vfta_generic, \
-	.fc_enable			= &ixgbe_fc_enable_generic, \
-	.set_fw_drv_ver			= &ixgbe_set_fw_drv_ver_generic, \
-	.init_uta_tables		= &ixgbe_init_uta_tables_generic, \
-	.set_mac_anti_spoofing		= &ixgbe_set_mac_anti_spoofing, \
-	.set_vlan_anti_spoofing		= &ixgbe_set_vlan_anti_spoofing, \
-	.set_source_address_pruning	= \
-				&ixgbe_set_source_address_pruning_X550, \
-	.set_ethertype_anti_spoofing	= \
-				&ixgbe_set_ethertype_anti_spoofing_X550, \
-	.disable_rx_buff		= &ixgbe_disable_rx_buff_generic, \
-	.enable_rx_buff			= &ixgbe_enable_rx_buff_generic, \
-	.get_thermal_sensor_data	= NULL, \
-	.init_thermal_sensor_thresh	= NULL, \
-	.prot_autoc_read		= &prot_autoc_read_generic, \
-	.prot_autoc_write		= &prot_autoc_write_generic, \
-	.enable_rx			= &ixgbe_enable_rx_generic, \
-	.disable_rx			= &ixgbe_disable_rx_x550, \
-
-static struct ixgbe_mac_operations mac_ops_X550 = {
-	X550_COMMON_MAC
-	.reset_hw		= &ixgbe_reset_hw_X540,
-	.get_media_type		= &ixgbe_get_media_type_X540,
-	.get_san_mac_addr	= &ixgbe_get_san_mac_addr_generic,
-	.get_wwn_prefix		= &ixgbe_get_wwn_prefix_generic,
-	.setup_link		= &ixgbe_setup_mac_link_X540,
-	.get_link_capabilities	= &ixgbe_get_copper_link_capabilities_generic,
-	.get_bus_info		= &ixgbe_get_bus_info_generic,
-	.setup_sfp		= NULL,
-	.acquire_swfw_sync	= &ixgbe_acquire_swfw_sync_X540,
-	.release_swfw_sync	= &ixgbe_release_swfw_sync_X540,
-};
+/**
+ *  ixgbe_led_on_t_X550em - Turns on the software controllable LEDs.
+ *  @hw: pointer to hardware structure
+ *  @led_idx: led number to turn on
+ **/
+s32 ixgbe_led_on_t_X550em(struct ixgbe_hw *hw, u32 led_idx)
+{
+	u16 phy_data;
 
-static struct ixgbe_mac_operations mac_ops_X550EM_x = {
-	X550_COMMON_MAC
-	.reset_hw		= &ixgbe_reset_hw_X550em,
-	.get_media_type		= &ixgbe_get_media_type_X550em,
-	.get_san_mac_addr	= NULL,
-	.get_wwn_prefix		= NULL,
-	.setup_link		= NULL, /* defined later */
-	.get_link_capabilities	= &ixgbe_get_link_capabilities_X550em,
-	.get_bus_info		= &ixgbe_get_bus_info_X550em,
-	.setup_sfp		= ixgbe_setup_sfp_modules_X550em,
-	.acquire_swfw_sync	= &ixgbe_acquire_swfw_sync_X550em,
-	.release_swfw_sync	= &ixgbe_release_swfw_sync_X550em,
-};
+	DEBUGFUNC("ixgbe_led_on_t_X550em");
 
-#define X550_COMMON_EEP \
-	.read			= &ixgbe_read_ee_hostif_X550, \
-	.read_buffer		= &ixgbe_read_ee_hostif_buffer_X550, \
-	.write			= &ixgbe_write_ee_hostif_X550, \
-	.write_buffer		= &ixgbe_write_ee_hostif_buffer_X550, \
-	.validate_checksum	= &ixgbe_validate_eeprom_checksum_X550, \
-	.update_checksum	= &ixgbe_update_eeprom_checksum_X550, \
-	.calc_checksum		= &ixgbe_calc_eeprom_checksum_X550, \
-
-static struct ixgbe_eeprom_operations eeprom_ops_X550 = {
-	X550_COMMON_EEP
-	.init_params		= &ixgbe_init_eeprom_params_X550,
-};
+	if (led_idx >= IXGBE_X557_MAX_LED_INDEX)
+		return IXGBE_ERR_PARAM;
 
-static struct ixgbe_eeprom_operations eeprom_ops_X550EM_x = {
-	X550_COMMON_EEP
-	.init_params		= &ixgbe_init_eeprom_params_X540,
-};
+	/* To turn on the LED, set mode to ON. */
+	ixgbe_read_phy_reg(hw, IXGBE_X557_LED_PROVISIONING + led_idx,
+			   IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE, &phy_data);
+	phy_data |= IXGBE_X557_LED_MANUAL_SET_MASK;
+	ixgbe_write_phy_reg(hw, IXGBE_X557_LED_PROVISIONING + led_idx,
+			    IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE, phy_data);
 
-#define X550_COMMON_PHY	\
-	.identify_sfp		= &ixgbe_identify_module_generic, \
-	.reset			= NULL, \
-	.setup_link_speed	= &ixgbe_setup_phy_link_speed_generic, \
-	.read_i2c_byte		= &ixgbe_read_i2c_byte_generic, \
-	.write_i2c_byte		= &ixgbe_write_i2c_byte_generic, \
-	.read_i2c_sff8472	= &ixgbe_read_i2c_sff8472_generic, \
-	.read_i2c_eeprom	= &ixgbe_read_i2c_eeprom_generic, \
-	.write_i2c_eeprom	= &ixgbe_write_i2c_eeprom_generic, \
-	.read_reg		= &ixgbe_read_phy_reg_generic, \
-	.write_reg		= &ixgbe_write_phy_reg_generic, \
-	.setup_link		= &ixgbe_setup_phy_link_generic, \
-	.set_phy_power		= NULL, \
-	.check_overtemp		= &ixgbe_tn_check_overtemp, \
-	.get_firmware_version	= &ixgbe_get_phy_firmware_version_generic,
-
-static struct ixgbe_phy_operations phy_ops_X550 = {
-	X550_COMMON_PHY
-	.init			= NULL,
-	.identify		= &ixgbe_identify_phy_generic,
-};
+	/* Some designs have the LEDs wired to the MAC */
+	return ixgbe_led_on_generic(hw, led_idx);
+}
 
-static struct ixgbe_phy_operations phy_ops_X550EM_x = {
-	X550_COMMON_PHY
-	.init			= &ixgbe_init_phy_ops_X550em,
-	.identify		= &ixgbe_identify_phy_x550em,
-	.read_i2c_combined	= &ixgbe_read_i2c_combined_generic,
-	.write_i2c_combined	= &ixgbe_write_i2c_combined_generic,
-	.read_i2c_combined_unlocked = &ixgbe_read_i2c_combined_generic_unlocked,
-	.write_i2c_combined_unlocked =
-				     &ixgbe_write_i2c_combined_generic_unlocked,
-};
+/**
+ *  ixgbe_led_off_t_X550em - Turns off the software controllable LEDs.
+ *  @hw: pointer to hardware structure
+ *  @led_idx: led number to turn off
+ **/
+s32 ixgbe_led_off_t_X550em(struct ixgbe_hw *hw, u32 led_idx)
+{
+	u16 phy_data;
 
-static const u32 ixgbe_mvals_X550[IXGBE_MVALS_IDX_LIMIT] = {
-	IXGBE_MVALS_INIT(X550)
-};
+	DEBUGFUNC("ixgbe_led_off_t_X550em");
 
-static const u32 ixgbe_mvals_X550EM_x[IXGBE_MVALS_IDX_LIMIT] = {
-	IXGBE_MVALS_INIT(X550EM_x)
-};
+	if (led_idx >= IXGBE_X557_MAX_LED_INDEX)
+		return IXGBE_ERR_PARAM;
 
-struct ixgbe_info ixgbe_X550_info = {
-	.mac			= ixgbe_mac_X550,
-	.get_invariants		= &ixgbe_get_invariants_X540,
-	.mac_ops		= &mac_ops_X550,
-	.eeprom_ops		= &eeprom_ops_X550,
-	.phy_ops		= &phy_ops_X550,
-	.mbx_ops		= &mbx_ops_generic,
-	.mvals			= ixgbe_mvals_X550,
-};
+	/* To turn on the LED, set mode to ON. */
+	ixgbe_read_phy_reg(hw, IXGBE_X557_LED_PROVISIONING + led_idx,
+			   IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE, &phy_data);
+	phy_data &= ~IXGBE_X557_LED_MANUAL_SET_MASK;
+	ixgbe_write_phy_reg(hw, IXGBE_X557_LED_PROVISIONING + led_idx,
+			    IXGBE_MDIO_VENDOR_SPECIFIC_1_DEV_TYPE, phy_data);
 
-struct ixgbe_info ixgbe_X550EM_x_info = {
-	.mac			= ixgbe_mac_X550EM_x,
-	.get_invariants		= &ixgbe_get_invariants_X550_x,
-	.mac_ops		= &mac_ops_X550EM_x,
-	.eeprom_ops		= &eeprom_ops_X550EM_x,
-	.phy_ops		= &phy_ops_X550EM_x,
-	.mbx_ops		= &mbx_ops_generic,
-	.mvals			= ixgbe_mvals_X550EM_x,
-};
+	/* Some designs have the LEDs wired to the MAC */
+	return ixgbe_led_off_generic(hw, led_idx);
+}
+
+/**
+ *  ixgbe_set_fw_drv_ver_x550 - Sends driver version to firmware
+ *  @hw: pointer to the HW structure
+ *  @maj: driver version major number
+ *  @min: driver version minor number
+ *  @build: driver version build number
+ *  @sub: driver version sub build number
+ *  @len: length of driver_ver string
+ *  @driver_ver: driver string
+ *
+ *  Sends driver version number to firmware through the manageability
+ *  block.  On success return IXGBE_SUCCESS
+ *  else returns IXGBE_ERR_SWFW_SYNC when encountering an error acquiring
+ *  semaphore or IXGBE_ERR_HOST_INTERFACE_COMMAND when command fails.
+ **/
+s32 ixgbe_set_fw_drv_ver_x550(struct ixgbe_hw *hw, u8 maj, u8 min,
+			      u8 build, u8 sub, u16 len, const char *driver_ver)
+{
+	struct ixgbe_hic_drv_info2 fw_cmd;
+	s32 ret_val = IXGBE_SUCCESS;
+	int i;
+
+	DEBUGFUNC("ixgbe_set_fw_drv_ver_x550");
+
+	if ((len == 0) || (driver_ver == NULL) ||
+	   (len > sizeof(fw_cmd.driver_string)))
+		return IXGBE_ERR_INVALID_ARGUMENT;
+
+	fw_cmd.hdr.cmd = FW_CEM_CMD_DRIVER_INFO;
+	fw_cmd.hdr.buf_len = FW_CEM_CMD_DRIVER_INFO_LEN + len;
+	fw_cmd.hdr.cmd_or_resp.cmd_resv = FW_CEM_CMD_RESERVED;
+	fw_cmd.port_num = (u8)hw->bus.func;
+	fw_cmd.ver_maj = maj;
+	fw_cmd.ver_min = min;
+	fw_cmd.ver_build = build;
+	fw_cmd.ver_sub = sub;
+	fw_cmd.hdr.checksum = 0;
+	memcpy(fw_cmd.driver_string, driver_ver, len);
+	fw_cmd.hdr.checksum = ixgbe_calculate_checksum((u8 *)&fw_cmd,
+				(FW_CEM_HDR_LEN + fw_cmd.hdr.buf_len));
+
+	for (i = 0; i <= FW_CEM_MAX_RETRIES; i++) {
+		ret_val = ixgbe_host_interface_command(hw, (u32 *)&fw_cmd,
+						       sizeof(fw_cmd),
+						       IXGBE_HI_COMMAND_TIMEOUT,
+						       true);
+		if (ret_val != IXGBE_SUCCESS)
+			continue;
+
+		if (fw_cmd.hdr.cmd_or_resp.ret_status ==
+		    FW_CEM_RESP_STATUS_SUCCESS)
+			ret_val = IXGBE_SUCCESS;
+		else
+			ret_val = IXGBE_ERR_HOST_INTERFACE_COMMAND;
+
+		break;
+	}
+
+	return ret_val;
+}
diff --git a/drivers/net/ethernet/intel/ixgbe/ixgbe_x550.h b/drivers/net/ethernet/intel/ixgbe/ixgbe_x550.h
new file mode 100644
index 00000000..ff2c4ea4
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/ixgbe_x550.h
@@ -0,0 +1,115 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#ifndef _IXGBE_X550_H_
+#define _IXGBE_X550_H_
+
+#include "ixgbe_type.h"
+
+s32 ixgbe_dmac_config_X550(struct ixgbe_hw *hw);
+s32 ixgbe_dmac_config_tcs_X550(struct ixgbe_hw *hw);
+s32 ixgbe_dmac_update_tcs_X550(struct ixgbe_hw *hw);
+
+s32 ixgbe_get_bus_info_X550em(struct ixgbe_hw *hw);
+s32 ixgbe_init_eeprom_params_X550(struct ixgbe_hw *hw);
+s32 ixgbe_update_eeprom_checksum_X550(struct ixgbe_hw *hw);
+s32 ixgbe_calc_eeprom_checksum_X550(struct ixgbe_hw *hw);
+s32 ixgbe_calc_checksum_X550(struct ixgbe_hw *hw, u16 *buffer, u32 buffer_size);
+s32 ixgbe_validate_eeprom_checksum_X550(struct ixgbe_hw *hw, u16 *checksum_val);
+s32 ixgbe_update_flash_X550(struct ixgbe_hw *hw);
+s32 ixgbe_write_ee_hostif_buffer_X550(struct ixgbe_hw *hw,
+				      u16 offset, u16 words, u16 *data);
+s32 ixgbe_write_ee_hostif_X550(struct ixgbe_hw *hw, u16 offset,
+			       u16 data);
+s32 ixgbe_read_ee_hostif_buffer_X550(struct ixgbe_hw *hw,
+				     u16 offset, u16 words, u16 *data);
+s32 ixgbe_read_ee_hostif_X550(struct ixgbe_hw *hw, u16 offset,
+u16				*data);
+s32 ixgbe_write_ee_hostif_data_X550(struct ixgbe_hw *hw, u16 offset,
+				    u16 data);
+void ixgbe_set_source_address_pruning_X550(struct ixgbe_hw *hw, bool enable,
+					   unsigned int pool);
+void ixgbe_set_ethertype_anti_spoofing_X550(struct ixgbe_hw *hw,
+					    bool enable, int vf);
+s32 ixgbe_write_iosf_sb_reg_x550(struct ixgbe_hw *hw, u32 reg_addr,
+				 u32 device_type, u32 data);
+s32 ixgbe_read_iosf_sb_reg_x550(struct ixgbe_hw *hw, u32 reg_addr,
+	u32 device_type, u32 *data);
+s32 ixgbe_set_fw_drv_ver_x550(struct ixgbe_hw *hw, u8 maj, u8 min,
+			      u8 build, u8 ver, u16 len, const char *str);
+s32 ixgbe_get_phy_token(struct ixgbe_hw *);
+s32 ixgbe_put_phy_token(struct ixgbe_hw *);
+s32 ixgbe_write_iosf_sb_reg_x550a(struct ixgbe_hw *hw, u32 reg_addr,
+	u32 device_type, u32 data);
+s32 ixgbe_read_iosf_sb_reg_x550a(struct ixgbe_hw *hw, u32 reg_addr,
+	u32 device_type, u32 *data);
+void ixgbe_disable_mdd_X550(struct ixgbe_hw *hw);
+void ixgbe_enable_mdd_X550(struct ixgbe_hw *hw);
+void ixgbe_mdd_event_X550(struct ixgbe_hw *hw, u32 *vf_bitmap);
+void ixgbe_restore_mdd_vf_X550(struct ixgbe_hw *hw, u32 vf);
+enum ixgbe_media_type ixgbe_get_media_type_X550em(struct ixgbe_hw *hw);
+s32 ixgbe_setup_sfp_modules_X550em(struct ixgbe_hw *hw);
+s32 ixgbe_get_link_capabilities_X550em(struct ixgbe_hw *hw,
+				       ixgbe_link_speed *speed, bool *autoneg);
+void ixgbe_init_mac_link_ops_X550em(struct ixgbe_hw *hw);
+s32 ixgbe_reset_hw_X550em(struct ixgbe_hw *hw);
+s32 ixgbe_init_phy_ops_X550em(struct ixgbe_hw *hw);
+s32 ixgbe_setup_kr_x550em(struct ixgbe_hw *hw);
+s32 ixgbe_init_ext_t_x550em(struct ixgbe_hw *hw);
+s32 ixgbe_setup_internal_phy_t_x550em(struct ixgbe_hw *hw);
+s32 ixgbe_setup_phy_loopback_x550em(struct ixgbe_hw *hw);
+u64 ixgbe_get_supported_physical_layer_X550em(struct ixgbe_hw *hw);
+void ixgbe_disable_rx_x550(struct ixgbe_hw *hw);
+s32 ixgbe_get_lcd_t_x550em(struct ixgbe_hw *hw, ixgbe_link_speed *lcd_speed);
+s32 ixgbe_enter_lplu_t_x550em(struct ixgbe_hw *hw);
+s32 ixgbe_acquire_swfw_sync_X550em(struct ixgbe_hw *hw, u32 mask);
+void ixgbe_release_swfw_sync_X550em(struct ixgbe_hw *hw, u32 mask);
+s32 ixgbe_setup_fc_X550em(struct ixgbe_hw *hw);
+s32 ixgbe_setup_mac_link_sfp_x550em(struct ixgbe_hw *hw,
+				    ixgbe_link_speed speed,
+				    bool autoneg_wait_to_complete);
+s32 ixgbe_setup_mac_link_sfp_x550a(struct ixgbe_hw *hw,
+				    ixgbe_link_speed speed,
+				    bool autoneg_wait_to_complete);
+s32 ixgbe_read_phy_reg_x550a(struct ixgbe_hw *hw, u32 reg_addr,
+			       u32 device_type, u16 *phy_data);
+s32 ixgbe_write_phy_reg_x550a(struct ixgbe_hw *hw, u32 reg_addr,
+				u32 device_type, u16 phy_data);
+s32 ixgbe_setup_fc_fiber_x550em_a(struct ixgbe_hw *hw);
+s32 ixgbe_setup_fc_backplane_x550em_a(struct ixgbe_hw *hw);
+s32 ixgbe_setup_fc_sgmii_x550em_a(struct ixgbe_hw *hw);
+void ixgbe_fc_autoneg_fiber_x550em_a(struct ixgbe_hw *hw);
+void ixgbe_fc_autoneg_backplane_x550em_a(struct ixgbe_hw *hw);
+void ixgbe_fc_autoneg_sgmii_x550em_a(struct ixgbe_hw *hw);
+s32 ixgbe_handle_lasi_ext_t_x550em(struct ixgbe_hw *hw);
+s32 ixgbe_setup_mac_link_t_X550em(struct ixgbe_hw *hw,
+				  ixgbe_link_speed speed,
+				  bool autoneg_wait_to_complete);
+s32 ixgbe_check_link_t_X550em(struct ixgbe_hw *hw, ixgbe_link_speed *speed,
+			      bool *link_up, bool link_up_wait_to_complete);
+s32 ixgbe_reset_phy_t_X550em(struct ixgbe_hw *hw);
+s32 ixgbe_identify_sfp_module_X550em(struct ixgbe_hw *hw);
+s32 ixgbe_led_on_t_X550em(struct ixgbe_hw *hw, u32 led_idx);
+s32 ixgbe_led_off_t_X550em(struct ixgbe_hw *hw, u32 led_idx);
+#endif /* _IXGBE_X550_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/kcompat.c b/drivers/net/ethernet/intel/ixgbe/kcompat.c
new file mode 100644
index 00000000..9766aea
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/kcompat.c
@@ -0,0 +1,2422 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#include "ixgbe.h"
+#include "kcompat.h"
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,8) ) || defined __VMKLNX__
+/* From lib/vsprintf.c */
+#include <asm/div64.h>
+
+static int skip_atoi(const char **s)
+{
+	int i=0;
+
+	while (isdigit(**s))
+		i = i*10 + *((*s)++) - '0';
+	return i;
+}
+
+#define _kc_ZEROPAD	1		/* pad with zero */
+#define _kc_SIGN	2		/* unsigned/signed long */
+#define _kc_PLUS	4		/* show plus */
+#define _kc_SPACE	8		/* space if plus */
+#define _kc_LEFT	16		/* left justified */
+#define _kc_SPECIAL	32		/* 0x */
+#define _kc_LARGE	64		/* use 'ABCDEF' instead of 'abcdef' */
+
+static char * number(char * buf, char * end, long long num, int base, int size, int precision, int type)
+{
+	char c,sign,tmp[66];
+	const char *digits;
+	const char small_digits[] = "0123456789abcdefghijklmnopqrstuvwxyz";
+	const char large_digits[] = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+	int i;
+
+	digits = (type & _kc_LARGE) ? large_digits : small_digits;
+	if (type & _kc_LEFT)
+		type &= ~_kc_ZEROPAD;
+	if (base < 2 || base > 36)
+		return 0;
+	c = (type & _kc_ZEROPAD) ? '0' : ' ';
+	sign = 0;
+	if (type & _kc_SIGN) {
+		if (num < 0) {
+			sign = '-';
+			num = -num;
+			size--;
+		} else if (type & _kc_PLUS) {
+			sign = '+';
+			size--;
+		} else if (type & _kc_SPACE) {
+			sign = ' ';
+			size--;
+		}
+	}
+	if (type & _kc_SPECIAL) {
+		if (base == 16)
+			size -= 2;
+		else if (base == 8)
+			size--;
+	}
+	i = 0;
+	if (num == 0)
+		tmp[i++]='0';
+	else while (num != 0)
+		tmp[i++] = digits[do_div(num,base)];
+	if (i > precision)
+		precision = i;
+	size -= precision;
+	if (!(type&(_kc_ZEROPAD+_kc_LEFT))) {
+		while(size-->0) {
+			if (buf <= end)
+				*buf = ' ';
+			++buf;
+		}
+	}
+	if (sign) {
+		if (buf <= end)
+			*buf = sign;
+		++buf;
+	}
+	if (type & _kc_SPECIAL) {
+		if (base==8) {
+			if (buf <= end)
+				*buf = '0';
+			++buf;
+		} else if (base==16) {
+			if (buf <= end)
+				*buf = '0';
+			++buf;
+			if (buf <= end)
+				*buf = digits[33];
+			++buf;
+		}
+	}
+	if (!(type & _kc_LEFT)) {
+		while (size-- > 0) {
+			if (buf <= end)
+				*buf = c;
+			++buf;
+		}
+	}
+	while (i < precision--) {
+		if (buf <= end)
+			*buf = '0';
+		++buf;
+	}
+	while (i-- > 0) {
+		if (buf <= end)
+			*buf = tmp[i];
+		++buf;
+	}
+	while (size-- > 0) {
+		if (buf <= end)
+			*buf = ' ';
+		++buf;
+	}
+	return buf;
+}
+
+int _kc_vsnprintf(char *buf, size_t size, const char *fmt, va_list args)
+{
+	int len;
+	unsigned long long num;
+	int i, base;
+	char *str, *end, c;
+	const char *s;
+
+	int flags;		/* flags to number() */
+
+	int field_width;	/* width of output field */
+	int precision;		/* min. # of digits for integers; max
+				   number of chars for from string */
+	int qualifier;		/* 'h', 'l', or 'L' for integer fields */
+				/* 'z' support added 23/7/1999 S.H.    */
+				/* 'z' changed to 'Z' --davidm 1/25/99 */
+
+	str = buf;
+	end = buf + size - 1;
+
+	if (end < buf - 1) {
+		end = ((void *) -1);
+		size = end - buf + 1;
+	}
+
+	for (; *fmt ; ++fmt) {
+		if (*fmt != '%') {
+			if (str <= end)
+				*str = *fmt;
+			++str;
+			continue;
+		}
+
+		/* process flags */
+		flags = 0;
+		repeat:
+			++fmt;		/* this also skips first '%' */
+			switch (*fmt) {
+				case '-': flags |= _kc_LEFT; goto repeat;
+				case '+': flags |= _kc_PLUS; goto repeat;
+				case ' ': flags |= _kc_SPACE; goto repeat;
+				case '#': flags |= _kc_SPECIAL; goto repeat;
+				case '0': flags |= _kc_ZEROPAD; goto repeat;
+			}
+
+		/* get field width */
+		field_width = -1;
+		if (isdigit(*fmt))
+			field_width = skip_atoi(&fmt);
+		else if (*fmt == '*') {
+			++fmt;
+			/* it's the next argument */
+			field_width = va_arg(args, int);
+			if (field_width < 0) {
+				field_width = -field_width;
+				flags |= _kc_LEFT;
+			}
+		}
+
+		/* get the precision */
+		precision = -1;
+		if (*fmt == '.') {
+			++fmt;
+			if (isdigit(*fmt))
+				precision = skip_atoi(&fmt);
+			else if (*fmt == '*') {
+				++fmt;
+				/* it's the next argument */
+				precision = va_arg(args, int);
+			}
+			if (precision < 0)
+				precision = 0;
+		}
+
+		/* get the conversion qualifier */
+		qualifier = -1;
+		if (*fmt == 'h' || *fmt == 'l' || *fmt == 'L' || *fmt =='Z') {
+			qualifier = *fmt;
+			++fmt;
+		}
+
+		/* default base */
+		base = 10;
+
+		switch (*fmt) {
+			case 'c':
+				if (!(flags & _kc_LEFT)) {
+					while (--field_width > 0) {
+						if (str <= end)
+							*str = ' ';
+						++str;
+					}
+				}
+				c = (unsigned char) va_arg(args, int);
+				if (str <= end)
+					*str = c;
+				++str;
+				while (--field_width > 0) {
+					if (str <= end)
+						*str = ' ';
+					++str;
+				}
+				continue;
+
+			case 's':
+				s = va_arg(args, char *);
+				if (!s)
+					s = "<NULL>";
+
+				len = strnlen(s, precision);
+
+				if (!(flags & _kc_LEFT)) {
+					while (len < field_width--) {
+						if (str <= end)
+							*str = ' ';
+						++str;
+					}
+				}
+				for (i = 0; i < len; ++i) {
+					if (str <= end)
+						*str = *s;
+					++str; ++s;
+				}
+				while (len < field_width--) {
+					if (str <= end)
+						*str = ' ';
+					++str;
+				}
+				continue;
+
+			case 'p':
+				if ('M' == *(fmt+1)) {
+					str = get_mac(str, end, va_arg(args, unsigned char *));
+					fmt++;
+				} else	{
+					if (field_width == -1) {
+						field_width = 2*sizeof(void *);
+						flags |= _kc_ZEROPAD;
+					}
+					str = number(str, end,
+							(unsigned long) va_arg(args, void *),
+							16, field_width, precision, flags);
+				}
+				continue;
+
+			case 'n':
+				/* FIXME:
+				* What does C99 say about the overflow case here? */
+				if (qualifier == 'l') {
+					long * ip = va_arg(args, long *);
+					*ip = (str - buf);
+				} else if (qualifier == 'Z') {
+					size_t * ip = va_arg(args, size_t *);
+					*ip = (str - buf);
+				} else {
+					int * ip = va_arg(args, int *);
+					*ip = (str - buf);
+				}
+				continue;
+
+			case '%':
+				if (str <= end)
+					*str = '%';
+				++str;
+				continue;
+
+				/* integer number formats - set up the flags and "break" */
+			case 'o':
+				base = 8;
+				break;
+
+			case 'X':
+				flags |= _kc_LARGE;
+			case 'x':
+				base = 16;
+				break;
+
+			case 'd':
+			case 'i':
+				flags |= _kc_SIGN;
+			case 'u':
+				break;
+
+			default:
+				if (str <= end)
+					*str = '%';
+				++str;
+				if (*fmt) {
+					if (str <= end)
+						*str = *fmt;
+					++str;
+				} else {
+					--fmt;
+				}
+				continue;
+		}
+		if (qualifier == 'L')
+			num = va_arg(args, long long);
+		else if (qualifier == 'l') {
+			num = va_arg(args, unsigned long);
+			if (flags & _kc_SIGN)
+				num = (signed long) num;
+		} else if (qualifier == 'Z') {
+			num = va_arg(args, size_t);
+		} else if (qualifier == 'h') {
+			num = (unsigned short) va_arg(args, int);
+			if (flags & _kc_SIGN)
+				num = (signed short) num;
+		} else {
+			num = va_arg(args, unsigned int);
+			if (flags & _kc_SIGN)
+				num = (signed int) num;
+		}
+		str = number(str, end, num, base,
+				field_width, precision, flags);
+	}
+	if (str <= end)
+		*str = '\0';
+	else if (size > 0)
+		/* don't write out a null byte if the buf size is zero */
+		*end = '\0';
+	/* the trailing null byte doesn't count towards the total
+	* ++str;
+	*/
+	return str-buf;
+}
+
+int _kc_snprintf(char * buf, size_t size, const char *fmt, ...)
+{
+	va_list args;
+	int i;
+
+	va_start(args, fmt);
+	i = _kc_vsnprintf(buf,size,fmt,args);
+	va_end(args);
+	return i;
+}
+#endif /* < 2.4.8 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,13) )
+
+/**************************************/
+/* PCI DMA MAPPING */
+
+#if defined(CONFIG_HIGHMEM)
+
+#ifndef PCI_DRAM_OFFSET
+#define PCI_DRAM_OFFSET 0
+#endif
+
+u64
+_kc_pci_map_page(struct pci_dev *dev, struct page *page, unsigned long offset,
+                 size_t size, int direction)
+{
+	return (((u64) (page - mem_map) << PAGE_SHIFT) + offset +
+		PCI_DRAM_OFFSET);
+}
+
+#else /* CONFIG_HIGHMEM */
+
+u64
+_kc_pci_map_page(struct pci_dev *dev, struct page *page, unsigned long offset,
+                 size_t size, int direction)
+{
+	return pci_map_single(dev, (void *)page_address(page) + offset, size,
+			      direction);
+}
+
+#endif /* CONFIG_HIGHMEM */
+
+void
+_kc_pci_unmap_page(struct pci_dev *dev, u64 dma_addr, size_t size,
+                   int direction)
+{
+	return pci_unmap_single(dev, dma_addr, size, direction);
+}
+
+#endif /* 2.4.13 => 2.4.3 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,3) )
+
+/**************************************/
+/* PCI DRIVER API */
+
+int
+_kc_pci_set_dma_mask(struct pci_dev *dev, dma_addr_t mask)
+{
+	if (!pci_dma_supported(dev, mask))
+		return -EIO;
+	dev->dma_mask = mask;
+	return 0;
+}
+
+int
+_kc_pci_request_regions(struct pci_dev *dev, char *res_name)
+{
+	int i;
+
+	for (i = 0; i < 6; i++) {
+		if (pci_resource_len(dev, i) == 0)
+			continue;
+
+		if (pci_resource_flags(dev, i) & IORESOURCE_IO) {
+			if (!request_region(pci_resource_start(dev, i), pci_resource_len(dev, i), res_name)) {
+				pci_release_regions(dev);
+				return -EBUSY;
+			}
+		} else if (pci_resource_flags(dev, i) & IORESOURCE_MEM) {
+			if (!request_mem_region(pci_resource_start(dev, i), pci_resource_len(dev, i), res_name)) {
+				pci_release_regions(dev);
+				return -EBUSY;
+			}
+		}
+	}
+	return 0;
+}
+
+void
+_kc_pci_release_regions(struct pci_dev *dev)
+{
+	int i;
+
+	for (i = 0; i < 6; i++) {
+		if (pci_resource_len(dev, i) == 0)
+			continue;
+
+		if (pci_resource_flags(dev, i) & IORESOURCE_IO)
+			release_region(pci_resource_start(dev, i), pci_resource_len(dev, i));
+
+		else if (pci_resource_flags(dev, i) & IORESOURCE_MEM)
+			release_mem_region(pci_resource_start(dev, i), pci_resource_len(dev, i));
+	}
+}
+
+/**************************************/
+/* NETWORK DRIVER API */
+
+struct net_device *
+_kc_alloc_etherdev(int sizeof_priv)
+{
+	struct net_device *dev;
+	int alloc_size;
+
+	alloc_size = sizeof(*dev) + sizeof_priv + IFNAMSIZ + 31;
+	dev = kzalloc(alloc_size, GFP_KERNEL);
+	if (!dev)
+		return NULL;
+
+	if (sizeof_priv)
+		dev->priv = (void *) (((unsigned long)(dev + 1) + 31) & ~31);
+	dev->name[0] = '\0';
+	ether_setup(dev);
+
+	return dev;
+}
+
+int
+_kc_is_valid_ether_addr(u8 *addr)
+{
+	const char zaddr[6] = { 0, };
+
+	return !(addr[0] & 1) && memcmp(addr, zaddr, 6);
+}
+
+#endif /* 2.4.3 => 2.4.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,6) )
+
+int
+_kc_pci_set_power_state(struct pci_dev *dev, int state)
+{
+	return 0;
+}
+
+int
+_kc_pci_enable_wake(struct pci_dev *pdev, u32 state, int enable)
+{
+	return 0;
+}
+
+#endif /* 2.4.6 => 2.4.3 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0) )
+void _kc_skb_fill_page_desc(struct sk_buff *skb, int i, struct page *page,
+                            int off, int size)
+{
+	skb_frag_t *frag = &skb_shinfo(skb)->frags[i];
+	frag->page = page;
+	frag->page_offset = off;
+	frag->size = size;
+	skb_shinfo(skb)->nr_frags = i + 1;
+}
+
+/*
+ * Original Copyright:
+ * find_next_bit.c: fallback find next bit implementation
+ *
+ * Copyright (C) 2004 Red Hat, Inc. All Rights Reserved.
+ * Written by David Howells (dhowells@redhat.com)
+ */
+
+/**
+ * find_next_bit - find the next set bit in a memory region
+ * @addr: The address to base the search on
+ * @offset: The bitnumber to start searching at
+ * @size: The maximum size to search
+ */
+unsigned long find_next_bit(const unsigned long *addr, unsigned long size,
+                            unsigned long offset)
+{
+	const unsigned long *p = addr + BITOP_WORD(offset);
+	unsigned long result = offset & ~(BITS_PER_LONG-1);
+	unsigned long tmp;
+
+	if (offset >= size)
+		return size;
+	size -= result;
+	offset %= BITS_PER_LONG;
+	if (offset) {
+		tmp = *(p++);
+		tmp &= (~0UL << offset);
+		if (size < BITS_PER_LONG)
+			goto found_first;
+		if (tmp)
+			goto found_middle;
+		size -= BITS_PER_LONG;
+		result += BITS_PER_LONG;
+	}
+	while (size & ~(BITS_PER_LONG-1)) {
+		if ((tmp = *(p++)))
+			goto found_middle;
+		result += BITS_PER_LONG;
+		size -= BITS_PER_LONG;
+	}
+	if (!size)
+		return result;
+	tmp = *p;
+
+found_first:
+	tmp &= (~0UL >> (BITS_PER_LONG - size));
+	if (tmp == 0UL)		/* Are any bits set? */
+		return result + size;	/* Nope. */
+found_middle:
+	return result + ffs(tmp);
+}
+
+size_t _kc_strlcpy(char *dest, const char *src, size_t size)
+{
+	size_t ret = strlen(src);
+
+	if (size) {
+		size_t len = (ret >= size) ? size - 1 : ret;
+		memcpy(dest, src, len);
+		dest[len] = '\0';
+	}
+	return ret;
+}
+
+#ifndef do_div
+#if BITS_PER_LONG == 32
+uint32_t __attribute__((weak)) _kc__div64_32(uint64_t *n, uint32_t base)
+{
+	uint64_t rem = *n;
+	uint64_t b = base;
+	uint64_t res, d = 1;
+	uint32_t high = rem >> 32;
+
+	/* Reduce the thing a bit first */
+	res = 0;
+	if (high >= base) {
+		high /= base;
+		res = (uint64_t) high << 32;
+		rem -= (uint64_t) (high*base) << 32;
+	}
+
+	while ((int64_t)b > 0 && b < rem) {
+		b = b+b;
+		d = d+d;
+	}
+
+	do {
+		if (rem >= b) {
+			rem -= b;
+			res += d;
+		}
+		b >>= 1;
+		d >>= 1;
+	} while (d);
+
+	*n = res;
+	return rem;
+}
+#endif /* BITS_PER_LONG == 32 */
+#endif /* do_div */
+#endif /* 2.6.0 => 2.4.6 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,4) )
+int _kc_scnprintf(char * buf, size_t size, const char *fmt, ...)
+{
+	va_list args;
+	int i;
+
+	va_start(args, fmt);
+	i = vsnprintf(buf, size, fmt, args);
+	va_end(args);
+	return (i >= size) ? (size - 1) : i;
+}
+#endif /* < 2.6.4 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,10) )
+DECLARE_BITMAP(_kcompat_node_online_map, MAX_NUMNODES) = {1};
+#endif /* < 2.6.10 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13) )
+char *_kc_kstrdup(const char *s, unsigned int gfp)
+{
+	size_t len;
+	char *buf;
+
+	if (!s)
+		return NULL;
+
+	len = strlen(s) + 1;
+	buf = kmalloc(len, gfp);
+	if (buf)
+		memcpy(buf, s, len);
+	return buf;
+}
+#endif /* < 2.6.13 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,14) )
+void *_kc_kzalloc(size_t size, int flags)
+{
+	void *ret = kmalloc(size, flags);
+	if (ret)
+		memset(ret, 0, size);
+	return ret;
+}
+#endif /* <= 2.6.13 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19) )
+int _kc_skb_pad(struct sk_buff *skb, int pad)
+{
+	int ntail;
+
+        /* If the skbuff is non linear tailroom is always zero.. */
+        if(!skb_cloned(skb) && skb_tailroom(skb) >= pad) {
+		memset(skb->data+skb->len, 0, pad);
+		return 0;
+        }
+
+	ntail = skb->data_len + pad - (skb->end - skb->tail);
+	if (likely(skb_cloned(skb) || ntail > 0)) {
+		if (pskb_expand_head(skb, 0, ntail, GFP_ATOMIC))
+			goto free_skb;
+	}
+
+#ifdef MAX_SKB_FRAGS
+	if (skb_is_nonlinear(skb) &&
+	    !__pskb_pull_tail(skb, skb->data_len))
+		goto free_skb;
+
+#endif
+	memset(skb->data + skb->len, 0, pad);
+        return 0;
+
+free_skb:
+	kfree_skb(skb);
+	return -ENOMEM;
+}
+
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(5,4)))
+int _kc_pci_save_state(struct pci_dev *pdev)
+{
+	struct adapter_struct *adapter = pci_get_drvdata(pdev);
+	int size = PCI_CONFIG_SPACE_LEN, i;
+	u16 pcie_cap_offset, pcie_link_status;
+
+#if ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0) )
+	/* no ->dev for 2.4 kernels */
+	WARN_ON(pdev->dev.driver_data == NULL);
+#endif
+	pcie_cap_offset = pci_find_capability(pdev, PCI_CAP_ID_EXP);
+	if (pcie_cap_offset) {
+		if (!pci_read_config_word(pdev,
+		                          pcie_cap_offset + PCIE_LINK_STATUS,
+		                          &pcie_link_status))
+		size = PCIE_CONFIG_SPACE_LEN;
+	}
+	pci_config_space_ich8lan();
+#ifdef HAVE_PCI_ERS
+	if (adapter->config_space == NULL)
+#else
+	WARN_ON(adapter->config_space != NULL);
+#endif
+		adapter->config_space = kmalloc(size, GFP_KERNEL);
+	if (!adapter->config_space) {
+		printk(KERN_ERR "Out of memory in pci_save_state\n");
+		return -ENOMEM;
+	}
+	for (i = 0; i < (size / 4); i++)
+		pci_read_config_dword(pdev, i * 4, &adapter->config_space[i]);
+	return 0;
+}
+
+void _kc_pci_restore_state(struct pci_dev *pdev)
+{
+	struct adapter_struct *adapter = pci_get_drvdata(pdev);
+	int size = PCI_CONFIG_SPACE_LEN, i;
+	u16 pcie_cap_offset;
+	u16 pcie_link_status;
+
+	if (adapter->config_space != NULL) {
+		pcie_cap_offset = pci_find_capability(pdev, PCI_CAP_ID_EXP);
+		if (pcie_cap_offset &&
+		    !pci_read_config_word(pdev,
+		                          pcie_cap_offset + PCIE_LINK_STATUS,
+		                          &pcie_link_status))
+			size = PCIE_CONFIG_SPACE_LEN;
+
+		pci_config_space_ich8lan();
+		for (i = 0; i < (size / 4); i++)
+		pci_write_config_dword(pdev, i * 4, adapter->config_space[i]);
+#ifndef HAVE_PCI_ERS
+		kfree(adapter->config_space);
+		adapter->config_space = NULL;
+#endif
+	}
+}
+#endif /* !(RHEL_RELEASE_CODE >= RHEL 5.4) */
+
+#ifdef HAVE_PCI_ERS
+void _kc_free_netdev(struct net_device *netdev)
+{
+	struct adapter_struct *adapter = netdev_priv(netdev);
+
+	kfree(adapter->config_space);
+#ifdef CONFIG_SYSFS
+	if (netdev->reg_state == NETREG_UNINITIALIZED) {
+		kfree((char *)netdev - netdev->padded);
+	} else {
+		BUG_ON(netdev->reg_state != NETREG_UNREGISTERED);
+		netdev->reg_state = NETREG_RELEASED;
+		class_device_put(&netdev->class_dev);
+	}
+#else
+	kfree((char *)netdev - netdev->padded);
+#endif
+}
+#endif
+
+void *_kc_kmemdup(const void *src, size_t len, unsigned gfp)
+{
+	void *p;
+
+	p = kzalloc(len, gfp);
+	if (p)
+		memcpy(p, src, len);
+	return p;
+}
+#endif /* <= 2.6.19 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,21) )
+struct pci_dev *_kc_netdev_to_pdev(struct net_device *netdev)
+{
+	return ((struct adapter_struct *)netdev_priv(netdev))->pdev;
+}
+#endif /* < 2.6.21 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,22) )
+/* hexdump code taken from lib/hexdump.c */
+static void _kc_hex_dump_to_buffer(const void *buf, size_t len, int rowsize,
+			int groupsize, unsigned char *linebuf,
+			size_t linebuflen, bool ascii)
+{
+	const u8 *ptr = buf;
+	u8 ch;
+	int j, lx = 0;
+	int ascii_column;
+
+	if (rowsize != 16 && rowsize != 32)
+		rowsize = 16;
+
+	if (!len)
+		goto nil;
+	if (len > rowsize)		/* limit to one line at a time */
+		len = rowsize;
+	if ((len % groupsize) != 0)	/* no mixed size output */
+		groupsize = 1;
+
+	switch (groupsize) {
+	case 8: {
+		const u64 *ptr8 = buf;
+		int ngroups = len / groupsize;
+
+		for (j = 0; j < ngroups; j++)
+			lx += scnprintf((char *)(linebuf + lx), linebuflen - lx,
+				"%s%16.16llx", j ? " " : "",
+				(unsigned long long)*(ptr8 + j));
+		ascii_column = 17 * ngroups + 2;
+		break;
+	}
+
+	case 4: {
+		const u32 *ptr4 = buf;
+		int ngroups = len / groupsize;
+
+		for (j = 0; j < ngroups; j++)
+			lx += scnprintf((char *)(linebuf + lx), linebuflen - lx,
+				"%s%8.8x", j ? " " : "", *(ptr4 + j));
+		ascii_column = 9 * ngroups + 2;
+		break;
+	}
+
+	case 2: {
+		const u16 *ptr2 = buf;
+		int ngroups = len / groupsize;
+
+		for (j = 0; j < ngroups; j++)
+			lx += scnprintf((char *)(linebuf + lx), linebuflen - lx,
+				"%s%4.4x", j ? " " : "", *(ptr2 + j));
+		ascii_column = 5 * ngroups + 2;
+		break;
+	}
+
+	default:
+		for (j = 0; (j < len) && (lx + 3) <= linebuflen; j++) {
+			ch = ptr[j];
+			linebuf[lx++] = hex_asc(ch >> 4);
+			linebuf[lx++] = hex_asc(ch & 0x0f);
+			linebuf[lx++] = ' ';
+		}
+		if (j)
+			lx--;
+
+		ascii_column = 3 * rowsize + 2;
+		break;
+	}
+	if (!ascii)
+		goto nil;
+
+	while (lx < (linebuflen - 1) && lx < (ascii_column - 1))
+		linebuf[lx++] = ' ';
+	for (j = 0; (j < len) && (lx + 2) < linebuflen; j++)
+		linebuf[lx++] = (isascii(ptr[j]) && isprint(ptr[j])) ? ptr[j]
+				: '.';
+nil:
+	linebuf[lx++] = '\0';
+}
+
+void _kc_print_hex_dump(const char *level,
+			const char *prefix_str, int prefix_type,
+			int rowsize, int groupsize,
+			const void *buf, size_t len, bool ascii)
+{
+	const u8 *ptr = buf;
+	int i, linelen, remaining = len;
+	unsigned char linebuf[200];
+
+	if (rowsize != 16 && rowsize != 32)
+		rowsize = 16;
+
+	for (i = 0; i < len; i += rowsize) {
+		linelen = min(remaining, rowsize);
+		remaining -= rowsize;
+		_kc_hex_dump_to_buffer(ptr + i, linelen, rowsize, groupsize,
+				linebuf, sizeof(linebuf), ascii);
+
+		switch (prefix_type) {
+		case DUMP_PREFIX_ADDRESS:
+			printk("%s%s%*p: %s\n", level, prefix_str,
+				(int)(2 * sizeof(void *)), ptr + i, linebuf);
+			break;
+		case DUMP_PREFIX_OFFSET:
+			printk("%s%s%.8x: %s\n", level, prefix_str, i, linebuf);
+			break;
+		default:
+			printk("%s%s%s\n", level, prefix_str, linebuf);
+			break;
+		}
+	}
+}
+
+#endif /* < 2.6.22 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,23) )
+int ixgbe_dcb_netlink_register(void)
+{
+	return 0;
+}
+
+int ixgbe_dcb_netlink_unregister(void)
+{
+	return 0;
+}
+
+int ixgbe_copy_dcb_cfg(struct ixgbe_adapter __always_unused *adapter, int __always_unused tc_max)
+{
+	return 0;
+}
+#endif /* < 2.6.23 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,24) )
+#ifdef NAPI
+struct net_device *napi_to_poll_dev(const struct napi_struct *napi)
+{
+	struct adapter_q_vector *q_vector = container_of(napi,
+	                                                struct adapter_q_vector,
+	                                                napi);
+	return &q_vector->poll_dev;
+}
+
+int __kc_adapter_clean(struct net_device *netdev, int *budget)
+{
+	int work_done;
+	int work_to_do = min(*budget, netdev->quota);
+	/* kcompat.h netif_napi_add puts napi struct in "fake netdev->priv" */
+	struct napi_struct *napi = netdev->priv;
+	work_done = napi->poll(napi, work_to_do);
+	*budget -= work_done;
+	netdev->quota -= work_done;
+	return (work_done >= work_to_do) ? 1 : 0;
+}
+#endif /* NAPI */
+#endif /* <= 2.6.24 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,26) )
+void _kc_pci_disable_link_state(struct pci_dev *pdev, int state)
+{
+	struct pci_dev *parent = pdev->bus->self;
+	u16 link_state;
+	int pos;
+
+	if (!parent)
+		return;
+
+	pos = pci_find_capability(parent, PCI_CAP_ID_EXP);
+	if (pos) {
+		pci_read_config_word(parent, pos + PCI_EXP_LNKCTL, &link_state);
+		link_state &= ~state;
+		pci_write_config_word(parent, pos + PCI_EXP_LNKCTL, link_state);
+	}
+}
+#endif /* < 2.6.26 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,27) )
+#ifdef HAVE_TX_MQ
+void _kc_netif_tx_stop_all_queues(struct net_device *netdev)
+{
+	struct adapter_struct *adapter = netdev_priv(netdev);
+	int i;
+
+	netif_stop_queue(netdev);
+	if (netif_is_multiqueue(netdev))
+		for (i = 0; i < adapter->num_tx_queues; i++)
+			netif_stop_subqueue(netdev, i);
+}
+void _kc_netif_tx_wake_all_queues(struct net_device *netdev)
+{
+	struct adapter_struct *adapter = netdev_priv(netdev);
+	int i;
+
+	netif_wake_queue(netdev);
+	if (netif_is_multiqueue(netdev))
+		for (i = 0; i < adapter->num_tx_queues; i++)
+			netif_wake_subqueue(netdev, i);
+}
+void _kc_netif_tx_start_all_queues(struct net_device *netdev)
+{
+	struct adapter_struct *adapter = netdev_priv(netdev);
+	int i;
+
+	netif_start_queue(netdev);
+	if (netif_is_multiqueue(netdev))
+		for (i = 0; i < adapter->num_tx_queues; i++)
+			netif_start_subqueue(netdev, i);
+}
+#endif /* HAVE_TX_MQ */
+
+void __kc_warn_slowpath(const char *file, int line, const char *fmt, ...)
+{
+	va_list args;
+
+	printk(KERN_WARNING "------------[ cut here ]------------\n");
+	printk(KERN_WARNING "WARNING: at %s:%d \n", file, line);
+	va_start(args, fmt);
+	vprintk(fmt, args);
+	va_end(args);
+
+	dump_stack();
+}
+#endif /* __VMKLNX__ */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,28) )
+
+int
+_kc_pci_prepare_to_sleep(struct pci_dev *dev)
+{
+	pci_power_t target_state;
+	int error;
+
+	target_state = pci_choose_state(dev, PMSG_SUSPEND);
+
+	pci_enable_wake(dev, target_state, true);
+
+	error = pci_set_power_state(dev, target_state);
+
+	if (error)
+		pci_enable_wake(dev, target_state, false);
+
+	return error;
+}
+
+int
+_kc_pci_wake_from_d3(struct pci_dev *dev, bool enable)
+{
+	int err;
+
+	err = pci_enable_wake(dev, PCI_D3cold, enable);
+	if (err)
+		goto out;
+
+	err = pci_enable_wake(dev, PCI_D3hot, enable);
+
+out:
+	return err;
+}
+#endif /* < 2.6.28 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,29) )
+static void __kc_pci_set_master(struct pci_dev *pdev, bool enable)
+{
+	u16 old_cmd, cmd;
+
+	pci_read_config_word(pdev, PCI_COMMAND, &old_cmd);
+	if (enable)
+		cmd = old_cmd | PCI_COMMAND_MASTER;
+	else
+		cmd = old_cmd & ~PCI_COMMAND_MASTER;
+	if (cmd != old_cmd) {
+		dev_dbg(pci_dev_to_dev(pdev), "%s bus mastering\n",
+			enable ? "enabling" : "disabling");
+		pci_write_config_word(pdev, PCI_COMMAND, cmd);
+	}
+#if ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,7) )
+	pdev->is_busmaster = enable;
+#endif
+}
+
+void _kc_pci_clear_master(struct pci_dev *dev)
+{
+	__kc_pci_set_master(dev, false);
+}
+#endif /* < 2.6.29 */
+
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,34) )
+#if (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(6,0))
+int _kc_pci_num_vf(struct pci_dev __maybe_unused *dev)
+{
+	int num_vf = 0;
+#ifdef CONFIG_PCI_IOV
+	struct pci_dev *vfdev;
+
+	/* loop through all ethernet devices starting at PF dev */
+	vfdev = pci_get_class(PCI_CLASS_NETWORK_ETHERNET << 8, NULL);
+	while (vfdev) {
+		if (vfdev->is_virtfn && vfdev->physfn == dev)
+			num_vf++;
+
+		vfdev = pci_get_class(PCI_CLASS_NETWORK_ETHERNET << 8, vfdev);
+	}
+
+#endif
+	return num_vf;
+}
+#endif /* RHEL_RELEASE_CODE */
+#endif /* < 2.6.34 */
+
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,35) )
+#ifdef HAVE_TX_MQ
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,0)))
+#ifndef CONFIG_NETDEVICES_MULTIQUEUE
+int _kc_netif_set_real_num_tx_queues(struct net_device *dev, unsigned int txq)
+{
+	unsigned int real_num = dev->real_num_tx_queues;
+	struct Qdisc *qdisc;
+	int i;
+
+	if (txq < 1 || txq > dev->num_tx_queues)
+		return -EINVAL;
+
+	else if (txq > real_num)
+		dev->real_num_tx_queues = txq;
+	else if (txq < real_num) {
+		dev->real_num_tx_queues = txq;
+		for (i = txq; i < dev->num_tx_queues; i++) {
+			qdisc = netdev_get_tx_queue(dev, i)->qdisc;
+			if (qdisc) {
+				spin_lock_bh(qdisc_lock(qdisc));
+				qdisc_reset(qdisc);
+				spin_unlock_bh(qdisc_lock(qdisc));
+			}
+		}
+	}
+
+	return 0;
+}
+#endif /* CONFIG_NETDEVICES_MULTIQUEUE */
+#endif /* !(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,0)) */
+#endif /* HAVE_TX_MQ */
+
+ssize_t _kc_simple_write_to_buffer(void *to, size_t available, loff_t *ppos,
+				   const void __user *from, size_t count)
+{
+        loff_t pos = *ppos;
+        size_t res;
+
+        if (pos < 0)
+                return -EINVAL;
+        if (pos >= available || !count)
+                return 0;
+        if (count > available - pos)
+                count = available - pos;
+        res = copy_from_user(to + pos, from, count);
+        if (res == count)
+                return -EFAULT;
+        count -= res;
+        *ppos = pos + count;
+        return count;
+}
+
+#endif /* < 2.6.35 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,36) )
+static const u32 _kc_flags_dup_features =
+	(ETH_FLAG_LRO | ETH_FLAG_NTUPLE | ETH_FLAG_RXHASH);
+
+u32 _kc_ethtool_op_get_flags(struct net_device *dev)
+{
+	return dev->features & _kc_flags_dup_features;
+}
+
+int _kc_ethtool_op_set_flags(struct net_device *dev, u32 data, u32 supported)
+{
+	if (data & ~supported)
+		return -EINVAL;
+
+	dev->features = ((dev->features & ~_kc_flags_dup_features) |
+			 (data & _kc_flags_dup_features));
+	return 0;
+}
+#endif /* < 2.6.36 */
+
+/******************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,39) )
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(6,0)))
+#ifdef HAVE_NETDEV_SELECT_QUEUE
+#include <net/ip.h>
+#include <linux/pkt_sched.h>
+
+u16 ___kc_skb_tx_hash(struct net_device *dev, const struct sk_buff *skb,
+		      u16 num_tx_queues)
+{
+	u32 hash;
+	u16 qoffset = 0;
+	u16 qcount = num_tx_queues;
+
+	if (skb_rx_queue_recorded(skb)) {
+		hash = skb_get_rx_queue(skb);
+		while (unlikely(hash >= num_tx_queues))
+			hash -= num_tx_queues;
+		return hash;
+	}
+
+	if (netdev_get_num_tc(dev)) {
+		struct adapter_struct *kc_adapter = netdev_priv(dev);
+
+		if (skb->priority == TC_PRIO_CONTROL) {
+			qoffset = kc_adapter->dcb_tc - 1;
+		} else {
+			qoffset = skb->vlan_tci;
+			qoffset &= IXGBE_TX_FLAGS_VLAN_PRIO_MASK;
+			qoffset >>= 13;
+		}
+
+		qcount = kc_adapter->ring_feature[RING_F_RSS].indices;
+		qoffset *= qcount;
+	}
+
+	if (skb->sk && skb->sk->sk_hash)
+		hash = skb->sk->sk_hash;
+	else
+#ifdef NETIF_F_RXHASH
+		hash = (__force u16) skb->protocol ^ skb->rxhash;
+#else
+		hash = skb->protocol;
+#endif
+
+	hash = jhash_1word(hash, _kc_hashrnd);
+
+	return (u16) (((u64) hash * qcount) >> 32) + qoffset;
+}
+#endif /* HAVE_NETDEV_SELECT_QUEUE */
+
+u8 _kc_netdev_get_num_tc(struct net_device *dev)
+{
+	struct adapter_struct *kc_adapter = netdev_priv(dev);
+	if (kc_adapter->flags & IXGBE_FLAG_DCB_ENABLED)
+		return kc_adapter->dcb_tc;
+	else
+		return 0;
+}
+
+int _kc_netdev_set_num_tc(struct net_device *dev, u8 num_tc)
+{
+	struct adapter_struct *kc_adapter = netdev_priv(dev);
+
+	if (num_tc > IXGBE_DCB_MAX_TRAFFIC_CLASS)
+		return -EINVAL;
+
+	kc_adapter->dcb_tc = num_tc;
+
+	return 0;
+}
+
+u8 _kc_netdev_get_prio_tc_map(struct net_device __maybe_unused *dev, u8 __maybe_unused up)
+{
+	struct adapter_struct *kc_adapter = netdev_priv(dev);
+
+	return ixgbe_dcb_get_tc_from_up(&kc_adapter->dcb_cfg, 0, up);
+}
+
+#endif /* !(RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(6,0)) */
+#endif /* < 2.6.39 */
+
+/******************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,4,0) )
+void _kc_skb_add_rx_frag(struct sk_buff *skb, int i, struct page *page,
+			 int off, int size, unsigned int truesize)
+{
+	skb_fill_page_desc(skb, i, page, off, size);
+	skb->len += size;
+	skb->data_len += size;
+	skb->truesize += truesize;
+}
+
+#if !(SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(11,3,0))
+int _kc_simple_open(struct inode *inode, struct file *file)
+{
+        if (inode->i_private)
+                file->private_data = inode->i_private;
+
+        return 0;
+}
+#endif /* SLE_VERSION < 11,3,0 */
+
+#endif /* < 3.4.0 */
+
+/******************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,7,0) )
+static inline int __kc_pcie_cap_version(struct pci_dev *dev)
+{
+	int pos;
+	u16 reg16;
+
+	pos = pci_find_capability(dev, PCI_CAP_ID_EXP);
+	if (!pos)
+		return 0;
+	pci_read_config_word(dev, pos + PCI_EXP_FLAGS, &reg16);
+	return reg16 & PCI_EXP_FLAGS_VERS;
+}
+
+static inline bool __kc_pcie_cap_has_devctl(const struct pci_dev __always_unused *dev)
+{
+	return true;
+}
+
+static inline bool __kc_pcie_cap_has_lnkctl(struct pci_dev *dev)
+{
+	int type = pci_pcie_type(dev);
+
+	return __kc_pcie_cap_version(dev) > 1 ||
+	       type == PCI_EXP_TYPE_ROOT_PORT ||
+	       type == PCI_EXP_TYPE_ENDPOINT ||
+	       type == PCI_EXP_TYPE_LEG_END;
+}
+
+static inline bool __kc_pcie_cap_has_sltctl(struct pci_dev *dev)
+{
+	int type = pci_pcie_type(dev);
+	int pos;
+	u16 pcie_flags_reg;
+
+	pos = pci_find_capability(dev, PCI_CAP_ID_EXP);
+	if (!pos)
+		return false;
+	pci_read_config_word(dev, pos + PCI_EXP_FLAGS, &pcie_flags_reg);
+
+	return __kc_pcie_cap_version(dev) > 1 ||
+	       type == PCI_EXP_TYPE_ROOT_PORT ||
+	       (type == PCI_EXP_TYPE_DOWNSTREAM &&
+		pcie_flags_reg & PCI_EXP_FLAGS_SLOT);
+}
+
+static inline bool __kc_pcie_cap_has_rtctl(struct pci_dev *dev)
+{
+	int type = pci_pcie_type(dev);
+
+	return __kc_pcie_cap_version(dev) > 1 ||
+	       type == PCI_EXP_TYPE_ROOT_PORT ||
+	       type == PCI_EXP_TYPE_RC_EC;
+}
+
+static bool __kc_pcie_capability_reg_implemented(struct pci_dev *dev, int pos)
+{
+	if (!pci_is_pcie(dev))
+		return false;
+
+	switch (pos) {
+	case PCI_EXP_FLAGS_TYPE:
+		return true;
+	case PCI_EXP_DEVCAP:
+	case PCI_EXP_DEVCTL:
+	case PCI_EXP_DEVSTA:
+		return __kc_pcie_cap_has_devctl(dev);
+	case PCI_EXP_LNKCAP:
+	case PCI_EXP_LNKCTL:
+	case PCI_EXP_LNKSTA:
+		return __kc_pcie_cap_has_lnkctl(dev);
+	case PCI_EXP_SLTCAP:
+	case PCI_EXP_SLTCTL:
+	case PCI_EXP_SLTSTA:
+		return __kc_pcie_cap_has_sltctl(dev);
+	case PCI_EXP_RTCTL:
+	case PCI_EXP_RTCAP:
+	case PCI_EXP_RTSTA:
+		return __kc_pcie_cap_has_rtctl(dev);
+	case PCI_EXP_DEVCAP2:
+	case PCI_EXP_DEVCTL2:
+	case PCI_EXP_LNKCAP2:
+	case PCI_EXP_LNKCTL2:
+	case PCI_EXP_LNKSTA2:
+		return __kc_pcie_cap_version(dev) > 1;
+	default:
+		return false;
+	}
+}
+
+/*
+ * Note that these accessor functions are only for the "PCI Express
+ * Capability" (see PCIe spec r3.0, sec 7.8).  They do not apply to the
+ * other "PCI Express Extended Capabilities" (AER, VC, ACS, MFVC, etc.)
+ */
+int __kc_pcie_capability_read_word(struct pci_dev *dev, int pos, u16 *val)
+{
+	int ret;
+
+	*val = 0;
+	if (pos & 1)
+		return -EINVAL;
+
+	if (__kc_pcie_capability_reg_implemented(dev, pos)) {
+		ret = pci_read_config_word(dev, pci_pcie_cap(dev) + pos, val);
+		/*
+		 * Reset *val to 0 if pci_read_config_word() fails, it may
+		 * have been written as 0xFFFF if hardware error happens
+		 * during pci_read_config_word().
+		 */
+		if (ret)
+			*val = 0;
+		return ret;
+	}
+
+	/*
+	 * For Functions that do not implement the Slot Capabilities,
+	 * Slot Status, and Slot Control registers, these spaces must
+	 * be hardwired to 0b, with the exception of the Presence Detect
+	 * State bit in the Slot Status register of Downstream Ports,
+	 * which must be hardwired to 1b.  (PCIe Base Spec 3.0, sec 7.8)
+	 */
+	if (pci_is_pcie(dev) && pos == PCI_EXP_SLTSTA &&
+	    pci_pcie_type(dev) == PCI_EXP_TYPE_DOWNSTREAM) {
+		*val = PCI_EXP_SLTSTA_PDS;
+	}
+
+	return 0;
+}
+
+int __kc_pcie_capability_write_word(struct pci_dev *dev, int pos, u16 val)
+{
+	if (pos & 1)
+		return -EINVAL;
+
+	if (!__kc_pcie_capability_reg_implemented(dev, pos))
+		return 0;
+
+	return pci_write_config_word(dev, pci_pcie_cap(dev) + pos, val);
+}
+
+int __kc_pcie_capability_clear_and_set_word(struct pci_dev *dev, int pos,
+					    u16 clear, u16 set)
+{
+	int ret;
+	u16 val;
+
+	ret = __kc_pcie_capability_read_word(dev, pos, &val);
+	if (!ret) {
+		val &= ~clear;
+		val |= set;
+		ret = __kc_pcie_capability_write_word(dev, pos, val);
+	}
+
+	return ret;
+}
+
+int __kc_pcie_capability_clear_word(struct pci_dev *dev, int pos,
+					     u16 clear)
+{
+	return __kc_pcie_capability_clear_and_set_word(dev, pos, clear, 0);
+}
+#endif /* < 3.7.0 */
+
+/******************************************************************************
+ * ripped from linux/net/ipv6/exthdrs_core.c, GPL2, no direct copyright,
+ * inferred copyright from kernel
+ */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,8,0) )
+int __kc_ipv6_find_hdr(const struct sk_buff *skb, unsigned int *offset,
+		       int target, unsigned short *fragoff, int *flags)
+{
+	unsigned int start = skb_network_offset(skb) + sizeof(struct ipv6hdr);
+	u8 nexthdr = ipv6_hdr(skb)->nexthdr;
+	unsigned int len;
+	bool found;
+
+#define __KC_IP6_FH_F_FRAG	BIT(0)
+#define __KC_IP6_FH_F_AUTH	BIT(1)
+#define __KC_IP6_FH_F_SKIP_RH	BIT(2)
+
+	if (fragoff)
+		*fragoff = 0;
+
+	if (*offset) {
+		struct ipv6hdr _ip6, *ip6;
+
+		ip6 = skb_header_pointer(skb, *offset, sizeof(_ip6), &_ip6);
+		if (!ip6 || (ip6->version != 6)) {
+			printk(KERN_ERR "IPv6 header not found\n");
+			return -EBADMSG;
+		}
+		start = *offset + sizeof(struct ipv6hdr);
+		nexthdr = ip6->nexthdr;
+	}
+	len = skb->len - start;
+
+	do {
+		struct ipv6_opt_hdr _hdr, *hp;
+		unsigned int hdrlen;
+		found = (nexthdr == target);
+
+		if ((!ipv6_ext_hdr(nexthdr)) || nexthdr == NEXTHDR_NONE) {
+			if (target < 0 || found)
+				break;
+			return -ENOENT;
+		}
+
+		hp = skb_header_pointer(skb, start, sizeof(_hdr), &_hdr);
+		if (!hp)
+			return -EBADMSG;
+
+		if (nexthdr == NEXTHDR_ROUTING) {
+			struct ipv6_rt_hdr _rh, *rh;
+
+			rh = skb_header_pointer(skb, start, sizeof(_rh),
+						&_rh);
+			if (!rh)
+				return -EBADMSG;
+
+			if (flags && (*flags & __KC_IP6_FH_F_SKIP_RH) &&
+			    rh->segments_left == 0)
+				found = false;
+		}
+
+		if (nexthdr == NEXTHDR_FRAGMENT) {
+			unsigned short _frag_off;
+			__be16 *fp;
+
+			if (flags)	/* Indicate that this is a fragment */
+				*flags |= __KC_IP6_FH_F_FRAG;
+			fp = skb_header_pointer(skb,
+						start+offsetof(struct frag_hdr,
+							       frag_off),
+						sizeof(_frag_off),
+						&_frag_off);
+			if (!fp)
+				return -EBADMSG;
+
+			_frag_off = ntohs(*fp) & ~0x7;
+			if (_frag_off) {
+				if (target < 0 &&
+				    ((!ipv6_ext_hdr(hp->nexthdr)) ||
+				     hp->nexthdr == NEXTHDR_NONE)) {
+					if (fragoff)
+						*fragoff = _frag_off;
+					return hp->nexthdr;
+				}
+				return -ENOENT;
+			}
+			hdrlen = 8;
+		} else if (nexthdr == NEXTHDR_AUTH) {
+			if (flags && (*flags & __KC_IP6_FH_F_AUTH) && (target < 0))
+				break;
+			hdrlen = (hp->hdrlen + 2) << 2;
+		} else
+			hdrlen = ipv6_optlen(hp);
+
+		if (!found) {
+			nexthdr = hp->nexthdr;
+			len -= hdrlen;
+			start += hdrlen;
+		}
+	} while (!found);
+
+	*offset = start;
+	return nexthdr;
+}
+#endif /* < 3.8.0 */
+
+/******************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,9,0) )
+#ifdef CONFIG_XPS
+#if NR_CPUS < 64
+#define _KC_MAX_XPS_CPUS	NR_CPUS
+#else
+#define _KC_MAX_XPS_CPUS	64
+#endif
+
+/*
+ * netdev_queue sysfs structures and functions.
+ */
+struct _kc_netdev_queue_attribute {
+	struct attribute attr;
+	ssize_t (*show)(struct netdev_queue *queue,
+	    struct _kc_netdev_queue_attribute *attr, char *buf);
+	ssize_t (*store)(struct netdev_queue *queue,
+	    struct _kc_netdev_queue_attribute *attr, const char *buf, size_t len);
+};
+
+#define to_kc_netdev_queue_attr(_attr) container_of(_attr,		\
+    struct _kc_netdev_queue_attribute, attr)
+
+int __kc_netif_set_xps_queue(struct net_device *dev, const struct cpumask *mask,
+			     u16 index)
+{
+	struct netdev_queue *txq = netdev_get_tx_queue(dev, index);
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,38) )
+	/* Redhat requires some odd extended netdev structures */
+	struct netdev_tx_queue_extended *txq_ext =
+					netdev_extended(dev)->_tx_ext + index;
+	struct kobj_type *ktype = txq_ext->kobj.ktype;
+#else
+	struct kobj_type *ktype = txq->kobj.ktype;
+#endif
+	struct _kc_netdev_queue_attribute *xps_attr;
+	struct attribute *attr = NULL;
+	int i, len, err;
+#define _KC_XPS_BUFLEN	(DIV_ROUND_UP(_KC_MAX_XPS_CPUS, 32) * 9)
+	char buf[_KC_XPS_BUFLEN];
+
+	if (!ktype)
+		return -ENOMEM;
+
+	/* attempt to locate the XPS attribute in the Tx queue */
+	for (i = 0; (attr = ktype->default_attrs[i]); i++) {
+		if (!strcmp("xps_cpus", attr->name))
+			break;
+	}
+
+	/* if we did not find it return an error */
+	if (!attr)
+		return -EINVAL;
+
+	/* copy the mask into a string */
+	len = bitmap_scnprintf(buf, _KC_XPS_BUFLEN,
+			       cpumask_bits(mask), _KC_MAX_XPS_CPUS);
+	if (!len)
+		return -ENOMEM;
+
+	xps_attr = to_kc_netdev_queue_attr(attr);
+
+	/* Store the XPS value using the SYSFS store call */
+	err = xps_attr->store(txq, xps_attr, buf, len);
+
+	/* we only had an error on err < 0 */
+	return (err < 0) ? err : 0;
+}
+#endif /* CONFIG_XPS */
+#ifdef HAVE_NETDEV_SELECT_QUEUE
+static inline int kc_get_xps_queue(struct net_device *dev, struct sk_buff *skb)
+{
+#ifdef CONFIG_XPS
+	struct xps_dev_maps *dev_maps;
+	struct xps_map *map;
+	int queue_index = -1;
+
+	rcu_read_lock();
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,38) )
+	/* Redhat requires some odd extended netdev structures */
+	dev_maps = rcu_dereference(netdev_extended(dev)->xps_maps);
+#else
+	dev_maps = rcu_dereference(dev->xps_maps);
+#endif
+	if (dev_maps) {
+		map = rcu_dereference(
+		    dev_maps->cpu_map[raw_smp_processor_id()]);
+		if (map) {
+			if (map->len == 1)
+				queue_index = map->queues[0];
+			else {
+				u32 hash;
+				if (skb->sk && skb->sk->sk_hash)
+					hash = skb->sk->sk_hash;
+				else
+					hash = (__force u16) skb->protocol ^
+					    skb->rxhash;
+				hash = jhash_1word(hash, _kc_hashrnd);
+				queue_index = map->queues[
+				    ((u64)hash * map->len) >> 32];
+			}
+			if (unlikely(queue_index >= dev->real_num_tx_queues))
+				queue_index = -1;
+		}
+	}
+	rcu_read_unlock();
+
+	return queue_index;
+#else
+	struct adapter_struct *kc_adapter = netdev_priv(dev);
+	int queue_index = -1;
+
+	if (kc_adapter->flags & IXGBE_FLAG_FDIR_HASH_CAPABLE) {
+		queue_index = skb_rx_queue_recorded(skb) ?
+					   skb_get_rx_queue(skb) :
+					   smp_processor_id();
+		while (unlikely(queue_index >= dev->real_num_tx_queues))
+			queue_index -= dev->real_num_tx_queues;
+		return queue_index;
+	}
+
+	return -1;
+#endif
+}
+
+u16 __kc_netdev_pick_tx(struct net_device *dev, struct sk_buff *skb)
+{
+	struct sock *sk = skb->sk;
+	int queue_index = sk_tx_queue_get(sk);
+	int new_index;
+
+	if (queue_index >= 0 && queue_index < dev->real_num_tx_queues) {
+#ifdef CONFIG_XPS
+		if (!skb->ooo_okay)
+#endif
+			return queue_index;
+	}
+
+	new_index = kc_get_xps_queue(dev, skb);
+	if (new_index < 0)
+		new_index = skb_tx_hash(dev, skb);
+
+	if (queue_index != new_index && sk) {
+		struct dst_entry *dst =
+			    rcu_dereference(sk->sk_dst_cache);
+
+		if (dst && skb_dst(skb) == dst)
+			sk_tx_queue_set(sk, new_index);
+
+	}
+
+	return new_index;
+}
+
+#endif /* HAVE_NETDEV_SELECT_QUEUE */
+#endif /* 3.9.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0) )
+#ifdef HAVE_FDB_OPS
+#ifdef USE_CONST_DEV_UC_CHAR
+int __kc_ndo_dflt_fdb_add(struct ndmsg *ndm, struct nlattr *tb[],
+			  struct net_device *dev, const unsigned char *addr,
+			  u16 flags)
+#else
+int __kc_ndo_dflt_fdb_add(struct ndmsg *ndm, struct net_device *dev,
+			  unsigned char *addr, u16 flags)
+#endif
+{
+	int err = -EINVAL;
+
+	/* If aging addresses are supported device will need to
+	 * implement its own handler for this.
+	 */
+	if (ndm->ndm_state && !(ndm->ndm_state & NUD_PERMANENT)) {
+		pr_info("%s: FDB only supports static addresses\n", dev->name);
+		return err;
+	}
+
+	if (is_unicast_ether_addr(addr) || is_link_local_ether_addr(addr))
+		err = dev_uc_add_excl(dev, addr);
+	else if (is_multicast_ether_addr(addr))
+		err = dev_mc_add_excl(dev, addr);
+
+	/* Only return duplicate errors if NLM_F_EXCL is set */
+	if (err == -EEXIST && !(flags & NLM_F_EXCL))
+		err = 0;
+
+	return err;
+}
+
+#ifdef USE_CONST_DEV_UC_CHAR
+#ifdef HAVE_FDB_DEL_NLATTR
+int __kc_ndo_dflt_fdb_del(struct ndmsg *ndm, struct nlattr *tb[],
+			  struct net_device *dev, const unsigned char *addr)
+#else
+int __kc_ndo_dflt_fdb_del(struct ndmsg *ndm, struct net_device *dev,
+			  const unsigned char *addr)
+#endif
+#else
+int __kc_ndo_dflt_fdb_del(struct ndmsg *ndm, struct net_device *dev,
+			  unsigned char *addr)
+#endif
+{
+	int err = -EINVAL;
+
+	/* If aging addresses are supported device will need to
+	 * implement its own handler for this.
+	 */
+	if (!(ndm->ndm_state & NUD_PERMANENT)) {
+		pr_info("%s: FDB only supports static addresses\n", dev->name);
+		return err;
+	}
+
+	if (is_unicast_ether_addr(addr) || is_link_local_ether_addr(addr))
+		err = dev_uc_del(dev, addr);
+	else if (is_multicast_ether_addr(addr))
+		err = dev_mc_del(dev, addr);
+
+	return err;
+}
+
+#endif /* HAVE_FDB_OPS */
+#ifdef CONFIG_PCI_IOV
+int __kc_pci_vfs_assigned(struct pci_dev __maybe_unused *dev)
+{
+	unsigned int vfs_assigned = 0;
+#ifdef HAVE_PCI_DEV_FLAGS_ASSIGNED
+	int pos;
+	struct pci_dev *vfdev;
+	unsigned short dev_id;
+
+	/* only search if we are a PF */
+	if (!dev->is_physfn)
+		return 0;
+
+	/* find SR-IOV capability */
+	pos = pci_find_ext_capability(dev, PCI_EXT_CAP_ID_SRIOV);
+	if (!pos)
+		return 0;
+
+	/*
+	 * determine the device ID for the VFs, the vendor ID will be the
+	 * same as the PF so there is no need to check for that one
+	 */
+	pci_read_config_word(dev, pos + PCI_SRIOV_VF_DID, &dev_id);
+
+	/* loop through all the VFs to see if we own any that are assigned */
+	vfdev = pci_get_device(dev->vendor, dev_id, NULL);
+	while (vfdev) {
+		/*
+		 * It is considered assigned if it is a virtual function with
+		 * our dev as the physical function and the assigned bit is set
+		 */
+		if (vfdev->is_virtfn && (vfdev->physfn == dev) &&
+		    (vfdev->dev_flags & PCI_DEV_FLAGS_ASSIGNED))
+			vfs_assigned++;
+
+		vfdev = pci_get_device(dev->vendor, dev_id, vfdev);
+	}
+
+#endif /* HAVE_PCI_DEV_FLAGS_ASSIGNED */
+	return vfs_assigned;
+}
+
+#endif /* CONFIG_PCI_IOV */
+#endif /* 3.10.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,12,0) )
+static const unsigned char pcie_link_speed[] = {
+	PCI_SPEED_UNKNOWN,      /* 0 */
+	PCIE_SPEED_2_5GT,       /* 1 */
+	PCIE_SPEED_5_0GT,       /* 2 */
+	PCIE_SPEED_8_0GT,       /* 3 */
+	PCI_SPEED_UNKNOWN,      /* 4 */
+	PCI_SPEED_UNKNOWN,      /* 5 */
+	PCI_SPEED_UNKNOWN,      /* 6 */
+	PCI_SPEED_UNKNOWN,      /* 7 */
+	PCI_SPEED_UNKNOWN,      /* 8 */
+	PCI_SPEED_UNKNOWN,      /* 9 */
+	PCI_SPEED_UNKNOWN,      /* A */
+	PCI_SPEED_UNKNOWN,      /* B */
+	PCI_SPEED_UNKNOWN,      /* C */
+	PCI_SPEED_UNKNOWN,      /* D */
+	PCI_SPEED_UNKNOWN,      /* E */
+	PCI_SPEED_UNKNOWN       /* F */
+};
+
+int __kc_pcie_get_minimum_link(struct pci_dev *dev, enum pci_bus_speed *speed,
+			       enum pcie_link_width *width)
+{
+	int ret;
+
+	*speed = PCI_SPEED_UNKNOWN;
+	*width = PCIE_LNK_WIDTH_UNKNOWN;
+
+	while (dev) {
+		u16 lnksta;
+		enum pci_bus_speed next_speed;
+		enum pcie_link_width next_width;
+
+		ret = pcie_capability_read_word(dev, PCI_EXP_LNKSTA, &lnksta);
+		if (ret)
+			return ret;
+
+		next_speed = pcie_link_speed[lnksta & PCI_EXP_LNKSTA_CLS];
+		next_width = (lnksta & PCI_EXP_LNKSTA_NLW) >>
+			PCI_EXP_LNKSTA_NLW_SHIFT;
+
+		if (next_speed < *speed)
+			*speed = next_speed;
+
+		if (next_width < *width)
+			*width = next_width;
+
+		dev = dev->bus->self;
+	}
+
+	return 0;
+}
+
+#endif
+
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,13,0) )
+int __kc_dma_set_mask_and_coherent(struct device *dev, u64 mask)
+{
+	int err = dma_set_mask(dev, mask);
+
+	if (!err)
+		/* coherent mask for the same size will always succeed if
+		 * dma_set_mask does. However we store the error anyways, due
+		 * to some kernels which use gcc's warn_unused_result on their
+		 * definition of dma_set_coherent_mask.
+		 */
+		err = dma_set_coherent_mask(dev, mask);
+	return err;
+}
+
+void __kc_netdev_rss_key_fill(void *buffer, size_t len)
+{
+	/* Set of random keys generated using kernel random number generator */
+	static const u8 seed[NETDEV_RSS_KEY_LEN] = {0xE6, 0xFA, 0x35, 0x62,
+				0x95, 0x12, 0x3E, 0xA3, 0xFB, 0x46, 0xC1, 0x5F,
+				0xB1, 0x43, 0x82, 0x5B, 0x6A, 0x49, 0x50, 0x95,
+				0xCD, 0xAB, 0xD8, 0x11, 0x8F, 0xC5, 0xBD, 0xBC,
+				0x6A, 0x4A, 0xB2, 0xD4, 0x1F, 0xFE, 0xBC, 0x41,
+				0xBF, 0xAC, 0xB2, 0x9A, 0x8F, 0x70, 0xE9, 0x2A,
+				0xD7, 0xB2, 0x80, 0xB6, 0x5B, 0xAA, 0x9D, 0x20};
+
+	BUG_ON(len > NETDEV_RSS_KEY_LEN);
+	memcpy(buffer, seed, len);
+}
+#endif /* 3.13.0 */
+
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,14,0) )
+int __kc_pci_enable_msix_range(struct pci_dev *dev, struct msix_entry *entries,
+			       int minvec, int maxvec)
+{
+        int nvec = maxvec;
+        int rc;
+
+        if (maxvec < minvec)
+                return -ERANGE;
+
+        do {
+                rc = pci_enable_msix(dev, entries, nvec);
+                if (rc < 0) {
+                        return rc;
+                } else if (rc > 0) {
+                        if (rc < minvec)
+                                return -ENOSPC;
+                        nvec = rc;
+                }
+        } while (rc);
+
+        return nvec;
+}
+#endif /* 3.14.0 */
+
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,15,0))
+char *_kc_devm_kstrdup(struct device *dev, const char *s, gfp_t gfp)
+{
+	size_t size;
+	char *buf;
+
+	if (!s)
+		return NULL;
+
+	size = strlen(s) + 1;
+	buf = devm_kzalloc(dev, size, gfp);
+	if (buf)
+		memcpy(buf, s, size);
+	return buf;
+}
+#endif /* 3.15.0 */
+
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,16,0) )
+#ifdef HAVE_SET_RX_MODE
+#ifdef NETDEV_HW_ADDR_T_UNICAST
+int __kc_hw_addr_sync_dev(struct netdev_hw_addr_list *list,
+		struct net_device *dev,
+		int (*sync)(struct net_device *, const unsigned char *),
+		int (*unsync)(struct net_device *, const unsigned char *))
+{
+	struct netdev_hw_addr *ha, *tmp;
+	int err;
+
+	/* first go through and flush out any stale entries */
+	list_for_each_entry_safe(ha, tmp, &list->list, list) {
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0) )
+		if (!ha->synced || ha->refcount != 1)
+#else
+		if (!ha->sync_cnt || ha->refcount != 1)
+#endif
+			continue;
+
+		if (unsync && unsync(dev, ha->addr))
+			continue;
+
+		list_del_rcu(&ha->list);
+		kfree_rcu(ha, rcu_head);
+		list->count--;
+	}
+
+	/* go through and sync new entries to the list */
+	list_for_each_entry_safe(ha, tmp, &list->list, list) {
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0) )
+		if (ha->synced)
+#else
+		if (ha->sync_cnt)
+#endif
+			continue;
+
+		err = sync(dev, ha->addr);
+		if (err)
+			return err;
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0) )
+		ha->synced = true;
+#else
+		ha->sync_cnt++;
+#endif
+		ha->refcount++;
+	}
+
+	return 0;
+}
+
+void __kc_hw_addr_unsync_dev(struct netdev_hw_addr_list *list,
+		struct net_device *dev,
+		int (*unsync)(struct net_device *, const unsigned char *))
+{
+	struct netdev_hw_addr *ha, *tmp;
+
+	list_for_each_entry_safe(ha, tmp, &list->list, list) {
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0) )
+		if (!ha->synced)
+#else
+		if (!ha->sync_cnt)
+#endif
+			continue;
+
+		if (unsync && unsync(dev, ha->addr))
+			continue;
+
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0) )
+		ha->synced = false;
+#else
+		ha->sync_cnt--;
+#endif
+		if (--ha->refcount)
+			continue;
+
+		list_del_rcu(&ha->list);
+		kfree_rcu(ha, rcu_head);
+		list->count--;
+	}
+}
+
+#endif /* NETDEV_HW_ADDR_T_UNICAST  */
+#ifndef NETDEV_HW_ADDR_T_MULTICAST
+int __kc_dev_addr_sync_dev(struct dev_addr_list **list, int *count,
+		struct net_device *dev,
+		int (*sync)(struct net_device *, const unsigned char *),
+		int (*unsync)(struct net_device *, const unsigned char *))
+{
+	struct dev_addr_list *da, **next = list;
+	int err;
+
+	/* first go through and flush out any stale entries */
+	while ((da = *next) != NULL) {
+		if (da->da_synced && da->da_users == 1) {
+			if (!unsync || !unsync(dev, da->da_addr)) {
+				*next = da->next;
+				kfree(da);
+				(*count)--;
+				continue;
+			}
+		}
+		next = &da->next;
+	}
+
+	/* go through and sync new entries to the list */
+	for (da = *list; da != NULL; da = da->next) {
+		if (da->da_synced)
+			continue;
+
+		err = sync(dev, da->da_addr);
+		if (err)
+			return err;
+
+		da->da_synced++;
+		da->da_users++;
+	}
+
+	return 0;
+}
+
+void __kc_dev_addr_unsync_dev(struct dev_addr_list **list, int *count,
+		struct net_device *dev,
+		int (*unsync)(struct net_device *, const unsigned char *))
+{
+	struct dev_addr_list *da;
+
+	while ((da = *list) != NULL) {
+		if (da->da_synced) {
+			if (!unsync || !unsync(dev, da->da_addr)) {
+				da->da_synced--;
+				if (--da->da_users == 0) {
+					*list = da->next;
+					kfree(da);
+					(*count)--;
+					continue;
+				}
+			}
+		}
+		list = &da->next;
+	}
+}
+#endif /* NETDEV_HW_ADDR_T_MULTICAST  */
+#endif /* HAVE_SET_RX_MODE */
+void *__kc_devm_kmemdup(struct device *dev, const void *src, size_t len,
+			unsigned int gfp)
+{
+	void *p;
+
+	p = devm_kzalloc(dev, len, gfp);
+	if (p)
+		memcpy(p, src, len);
+
+	return p;
+}
+#endif /* 3.16.0 */
+
+/******************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,17,0) )
+#endif /* 3.17.0 */
+
+/******************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,18,0) )
+#ifndef NO_PTP_SUPPORT
+static void __kc_sock_efree(struct sk_buff *skb)
+{
+	sock_put(skb->sk);
+}
+
+struct sk_buff *__kc_skb_clone_sk(struct sk_buff *skb)
+{
+	struct sock *sk = skb->sk;
+	struct sk_buff *clone;
+
+	if (!sk || !atomic_inc_not_zero(&sk->sk_refcnt))
+		return NULL;
+
+	clone = skb_clone(skb, GFP_ATOMIC);
+	if (!clone) {
+		sock_put(sk);
+		return NULL;
+	}
+
+	clone->sk = sk;
+	clone->destructor = __kc_sock_efree;
+
+	return clone;
+}
+
+void __kc_skb_complete_tx_timestamp(struct sk_buff *skb,
+				    struct skb_shared_hwtstamps *hwtstamps)
+{
+	struct sock_exterr_skb *serr;
+	struct sock *sk = skb->sk;
+	int err;
+
+	sock_hold(sk);
+
+	*skb_hwtstamps(skb) = *hwtstamps;
+
+	serr = SKB_EXT_ERR(skb);
+	memset(serr, 0, sizeof(*serr));
+	serr->ee.ee_errno = ENOMSG;
+	serr->ee.ee_origin = SO_EE_ORIGIN_TIMESTAMPING;
+
+	err = sock_queue_err_skb(sk, skb);
+	if (err)
+		kfree_skb(skb);
+
+	sock_put(sk);
+}
+#endif
+
+/* include headers needed for get_headlen function */
+#if defined(CONFIG_FCOE) || defined(CONFIG_FCOE_MODULE)
+#include <scsi/fc/fc_fcoe.h>
+#endif
+#ifdef HAVE_SCTP
+#include <linux/sctp.h>
+#endif
+
+unsigned int __kc_eth_get_headlen(unsigned char *data, unsigned int max_len)
+{
+	union {
+		unsigned char *network;
+		/* l2 headers */
+		struct ethhdr *eth;
+		struct vlan_hdr *vlan;
+		/* l3 headers */
+		struct iphdr *ipv4;
+		struct ipv6hdr *ipv6;
+	} hdr;
+	__be16 proto;
+	u8 nexthdr = 0;	/* default to not TCP */
+	u8 hlen;
+
+	/* this should never happen, but better safe than sorry */
+	if (max_len < ETH_HLEN)
+		return max_len;
+
+	/* initialize network frame pointer */
+	hdr.network = data;
+
+	/* set first protocol and move network header forward */
+	proto = hdr.eth->h_proto;
+	hdr.network += ETH_HLEN;
+
+again:
+	switch (proto) {
+	/* handle any vlan tag if present */
+	case __constant_htons(ETH_P_8021AD):
+	case __constant_htons(ETH_P_8021Q):
+		if ((hdr.network - data) > (max_len - VLAN_HLEN))
+			return max_len;
+
+		proto = hdr.vlan->h_vlan_encapsulated_proto;
+		hdr.network += VLAN_HLEN;
+		goto again;
+	/* handle L3 protocols */
+	case __constant_htons(ETH_P_IP):
+		if ((hdr.network - data) > (max_len - sizeof(struct iphdr)))
+			return max_len;
+
+		/* access ihl as a u8 to avoid unaligned access on ia64 */
+		hlen = (hdr.network[0] & 0x0F) << 2;
+
+		/* verify hlen meets minimum size requirements */
+		if (hlen < sizeof(struct iphdr))
+			return hdr.network - data;
+
+		/* record next protocol if header is present */
+		if (!(hdr.ipv4->frag_off & htons(IP_OFFSET)))
+			nexthdr = hdr.ipv4->protocol;
+
+		hdr.network += hlen;
+		break;
+#ifdef NETIF_F_TSO6
+	case __constant_htons(ETH_P_IPV6):
+		if ((hdr.network - data) > (max_len - sizeof(struct ipv6hdr)))
+			return max_len;
+
+		/* record next protocol */
+		nexthdr = hdr.ipv6->nexthdr;
+		hdr.network += sizeof(struct ipv6hdr);
+		break;
+#endif /* NETIF_F_TSO6 */
+#if defined(CONFIG_FCOE) || defined(CONFIG_FCOE_MODULE)
+	case __constant_htons(ETH_P_FCOE):
+		hdr.network += FCOE_HEADER_LEN;
+		break;
+#endif
+	default:
+		return hdr.network - data;
+	}
+
+	/* finally sort out L4 */
+	switch (nexthdr) {
+	case IPPROTO_TCP:
+		if ((hdr.network - data) > (max_len - sizeof(struct tcphdr)))
+			return max_len;
+
+		/* access doff as a u8 to avoid unaligned access on ia64 */
+		hdr.network += max_t(u8, sizeof(struct tcphdr),
+				     (hdr.network[12] & 0xF0) >> 2);
+
+		break;
+	case IPPROTO_UDP:
+	case IPPROTO_UDPLITE:
+		hdr.network += sizeof(struct udphdr);
+		break;
+#ifdef HAVE_SCTP
+	case IPPROTO_SCTP:
+		hdr.network += sizeof(struct sctphdr);
+		break;
+#endif
+	}
+
+	/*
+	 * If everything has gone correctly hdr.network should be the
+	 * data section of the packet and will be the end of the header.
+	 * If not then it probably represents the end of the last recognized
+	 * header.
+	 */
+	return min_t(unsigned int, hdr.network - data, max_len);
+}
+
+#endif /* < 3.18.0 */
+
+/******************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,19,0) )
+#ifdef HAVE_NET_GET_RANDOM_ONCE
+static u8 __kc_netdev_rss_key[NETDEV_RSS_KEY_LEN];
+
+void __kc_netdev_rss_key_fill(void *buffer, size_t len)
+{
+	BUG_ON(len > sizeof(__kc_netdev_rss_key));
+	net_get_random_once(__kc_netdev_rss_key, sizeof(__kc_netdev_rss_key));
+	memcpy(buffer, __kc_netdev_rss_key, len);
+}
+#endif
+#endif
+
+/******************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(4,1,0) )
+#if !((RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(6,8) && RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(7,0)) && \
+      (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,2)) && \
+      (SLE_VERSION_CODE > SLE_VERSION(12,1,0)))
+unsigned int _kc_cpumask_local_spread(unsigned int i, int node)
+{
+	int cpu;
+
+	/* Wrap: we always want a cpu. */
+	i %= num_online_cpus();
+
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,28) )
+	/* Kernels prior to 2.6.28 do not have for_each_cpu or
+	 * cpumask_of_node, so just use for_each_online_cpu()
+	 */
+	for_each_online_cpu(cpu)
+		if (i-- == 0)
+			return cpu;
+
+	return 0;
+#else
+	if (node == -1) {
+		for_each_cpu(cpu, cpu_online_mask)
+			if (i-- == 0)
+				return cpu;
+	} else {
+		/* NUMA first. */
+		for_each_cpu_and(cpu, cpumask_of_node(node), cpu_online_mask)
+			if (i-- == 0)
+				return cpu;
+
+		for_each_cpu(cpu, cpu_online_mask) {
+			/* Skip NUMA nodes, done above. */
+			if (cpumask_test_cpu(cpu, cpumask_of_node(node)))
+				continue;
+
+			if (i-- == 0)
+				return cpu;
+		}
+	}
+#endif /* KERNEL_VERSION >= 2.6.28 */
+	BUG();
+}
+#endif
+#endif
+
+/******************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(4,5,0) )
+#if (!(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,3)))
+#ifdef CONFIG_SPARC
+#include <asm/idprom.h>
+#include <asm/prom.h>
+#endif
+int _kc_eth_platform_get_mac_address(struct device *dev __maybe_unused,
+				     u8 *mac_addr __maybe_unused)
+{
+#if (((LINUX_VERSION_CODE < KERNEL_VERSION(3,1,0)) && defined(CONFIG_OF) && \
+      !defined(HAVE_STRUCT_DEVICE_OF_NODE) || !defined(CONFIG_OF)) && \
+     !defined(CONFIG_SPARC))
+	return -ENODEV;
+#else
+	const unsigned char *addr;
+	struct device_node *dp;
+
+	if (dev_is_pci(dev))
+		dp = pci_device_to_OF_node(to_pci_dev(dev));
+	else
+#if defined(HAVE_STRUCT_DEVICE_OF_NODE) && defined(CONFIG_OF)
+		dp = dev->of_node;
+#else
+		dp = NULL;
+#endif
+
+	addr = NULL;
+	if (dp)
+		addr = of_get_mac_address(dp);
+#ifdef CONFIG_SPARC
+	/* Kernel hasn't implemented arch_get_platform_mac_address, but we
+	 * should handle the SPARC case here since it was supported
+	 * originally. This is replaced by arch_get_platform_mac_address()
+	 * upstream.
+	 */
+	if (!addr)
+		addr = idprom->id_ethaddr;
+#endif
+	if (!addr)
+		return -ENODEV;
+
+	ether_addr_copy(mac_addr, addr);
+	return 0;
+#endif
+}
+#endif /* !(RHEL_RELEASE >= 7.3) */
+#endif
diff --git a/drivers/net/ethernet/intel/ixgbe/kcompat.h b/drivers/net/ethernet/intel/ixgbe/kcompat.h
new file mode 100644
index 00000000..4fc70d0
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/kcompat.h
@@ -0,0 +1,5683 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+#ifndef _KCOMPAT_H_
+#define _KCOMPAT_H_
+
+#ifndef LINUX_VERSION_CODE
+#include <linux/version.h>
+#else
+#define KERNEL_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
+#endif
+#include <linux/init.h>
+#include <linux/types.h>
+#include <linux/errno.h>
+#include <linux/module.h>
+#include <linux/pci.h>
+#include <linux/string.h>
+#include <linux/netdevice.h>
+#include <linux/etherdevice.h>
+#include <linux/skbuff.h>
+#include <linux/ioport.h>
+#include <linux/slab.h>
+#include <linux/list.h>
+#include <linux/delay.h>
+#include <linux/sched.h>
+#include <linux/in.h>
+#include <linux/ip.h>
+#include <linux/ipv6.h>
+#include <linux/tcp.h>
+#include <linux/udp.h>
+#include <linux/mii.h>
+#include <linux/vmalloc.h>
+#include <asm/io.h>
+#include <linux/ethtool.h>
+#include <linux/if_vlan.h>
+
+#ifndef NSEC_PER_MSEC
+#define NSEC_PER_MSEC 1000000L
+#endif
+#include <net/ipv6.h>
+/* UTS_RELEASE is in a different header starting in kernel 2.6.18 */
+#ifndef UTS_RELEASE
+/* utsrelease.h changed locations in 2.6.33 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,33) )
+#include <linux/utsrelease.h>
+#else
+#include <generated/utsrelease.h>
+#endif
+#endif
+
+/* NAPI enable/disable flags here */
+#define NAPI
+
+#define adapter_struct ixgbe_adapter
+#define adapter_q_vector ixgbe_q_vector
+
+/* and finally set defines so that the code sees the changes */
+#ifdef NAPI
+#else
+#endif /* NAPI */
+
+/* Dynamic LTR and deeper C-State support disable/enable */
+
+/* packet split disable/enable */
+#ifdef DISABLE_PACKET_SPLIT
+#ifndef CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+#define CONFIG_IXGBE_DISABLE_PACKET_SPLIT
+#endif
+#endif /* DISABLE_PACKET_SPLIT */
+
+/* MSI compatibility code for all kernels and drivers */
+#ifdef DISABLE_PCI_MSI
+#undef CONFIG_PCI_MSI
+#endif
+#ifndef CONFIG_PCI_MSI
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,8) )
+struct msix_entry {
+	u16 vector; /* kernel uses to write allocated vector */
+	u16 entry;  /* driver uses to specify entry, OS writes */
+};
+#endif
+#undef pci_enable_msi
+#define pci_enable_msi(a) -ENOTSUPP
+#undef pci_disable_msi
+#define pci_disable_msi(a) do {} while (0)
+#undef pci_enable_msix
+#define pci_enable_msix(a, b, c) -ENOTSUPP
+#undef pci_disable_msix
+#define pci_disable_msix(a) do {} while (0)
+#define msi_remove_pci_irq_vectors(a) do {} while (0)
+#endif /* CONFIG_PCI_MSI */
+#ifdef DISABLE_PM
+#undef CONFIG_PM
+#endif
+
+#ifdef DISABLE_NET_POLL_CONTROLLER
+#undef CONFIG_NET_POLL_CONTROLLER
+#endif
+
+#ifndef PMSG_SUSPEND
+#define PMSG_SUSPEND 3
+#endif
+
+/* generic boolean compatibility */
+#undef TRUE
+#undef FALSE
+#define TRUE true
+#define FALSE false
+#ifdef GCC_VERSION
+#if ( GCC_VERSION < 3000 )
+#define _Bool char
+#endif
+#else
+#define _Bool char
+#endif
+
+#undef __always_unused
+#define __always_unused __attribute__((__unused__))
+
+#undef __maybe_unused
+#define __maybe_unused __attribute__((__unused__))
+
+/* kernels less than 2.4.14 don't have this */
+#ifndef ETH_P_8021Q
+#define ETH_P_8021Q 0x8100
+#endif
+
+#ifndef module_param
+#define module_param(v,t,p) MODULE_PARM(v, "i");
+#endif
+
+#ifndef DMA_64BIT_MASK
+#define DMA_64BIT_MASK  0xffffffffffffffffULL
+#endif
+
+#ifndef DMA_32BIT_MASK
+#define DMA_32BIT_MASK  0x00000000ffffffffULL
+#endif
+
+#ifndef PCI_CAP_ID_EXP
+#define PCI_CAP_ID_EXP 0x10
+#endif
+
+#ifndef uninitialized_var
+#define uninitialized_var(x) x = x
+#endif
+
+#ifndef PCIE_LINK_STATE_L0S
+#define PCIE_LINK_STATE_L0S 1
+#endif
+#ifndef PCIE_LINK_STATE_L1
+#define PCIE_LINK_STATE_L1 2
+#endif
+
+#ifndef mmiowb
+#ifdef CONFIG_IA64
+#define mmiowb() asm volatile ("mf.a" ::: "memory")
+#else
+#define mmiowb()
+#endif
+#endif
+
+#ifndef SET_NETDEV_DEV
+#define SET_NETDEV_DEV(net, pdev)
+#endif
+
+#if !defined(HAVE_FREE_NETDEV) && ( LINUX_VERSION_CODE < KERNEL_VERSION(3,1,0) )
+#define free_netdev(x)	kfree(x)
+#endif
+
+#ifdef HAVE_POLL_CONTROLLER
+#define CONFIG_NET_POLL_CONTROLLER
+#endif
+
+#ifndef SKB_DATAREF_SHIFT
+/* if we do not have the infrastructure to detect if skb_header is cloned
+   just return false in all cases */
+#define skb_header_cloned(x) 0
+#endif
+
+#ifndef NETIF_F_GSO
+#define gso_size tso_size
+#define gso_segs tso_segs
+#endif
+
+#ifndef NETIF_F_GRO
+#define vlan_gro_receive(_napi, _vlgrp, _vlan, _skb) \
+		vlan_hwaccel_receive_skb(_skb, _vlgrp, _vlan)
+#define napi_gro_receive(_napi, _skb) netif_receive_skb(_skb)
+#endif
+
+#ifndef NETIF_F_SCTP_CSUM
+#define NETIF_F_SCTP_CSUM 0
+#endif
+
+#ifndef NETIF_F_LRO
+#define NETIF_F_LRO (1 << 15)
+#endif
+
+#ifndef NETIF_F_NTUPLE
+#define NETIF_F_NTUPLE (1 << 27)
+#endif
+
+#ifndef NETIF_F_ALL_FCOE
+#define NETIF_F_ALL_FCOE	(NETIF_F_FCOE_CRC | NETIF_F_FCOE_MTU | \
+				 NETIF_F_FSO)
+#endif
+
+#ifndef IPPROTO_SCTP
+#define IPPROTO_SCTP 132
+#endif
+
+#ifndef IPPROTO_UDPLITE
+#define IPPROTO_UDPLITE 136
+#endif
+
+#ifndef CHECKSUM_PARTIAL
+#define CHECKSUM_PARTIAL CHECKSUM_HW
+#define CHECKSUM_COMPLETE CHECKSUM_HW
+#endif
+
+#ifndef __read_mostly
+#define __read_mostly
+#endif
+
+#ifndef MII_RESV1
+#define MII_RESV1		0x17		/* Reserved...		*/
+#endif
+
+#ifndef unlikely
+#define unlikely(_x) _x
+#define likely(_x) _x
+#endif
+
+#ifndef WARN_ON
+#define WARN_ON(x)
+#endif
+
+#ifndef PCI_DEVICE
+#define PCI_DEVICE(vend,dev) \
+	.vendor = (vend), .device = (dev), \
+	.subvendor = PCI_ANY_ID, .subdevice = PCI_ANY_ID
+#endif
+
+#ifndef node_online
+#define node_online(node) ((node) == 0)
+#endif
+
+#ifndef num_online_cpus
+#define num_online_cpus() smp_num_cpus
+#endif
+
+#ifndef cpu_online
+#define cpu_online(cpuid) test_bit((cpuid), &cpu_online_map)
+#endif
+
+#ifndef _LINUX_RANDOM_H
+#include <linux/random.h>
+#endif
+
+#ifndef DECLARE_BITMAP
+#ifndef BITS_TO_LONGS
+#define BITS_TO_LONGS(bits) (((bits)+BITS_PER_LONG-1)/BITS_PER_LONG)
+#endif
+#define DECLARE_BITMAP(name,bits) long name[BITS_TO_LONGS(bits)]
+#endif
+
+#ifndef VLAN_HLEN
+#define VLAN_HLEN 4
+#endif
+
+#ifndef VLAN_ETH_HLEN
+#define VLAN_ETH_HLEN 18
+#endif
+
+#ifndef VLAN_ETH_FRAME_LEN
+#define VLAN_ETH_FRAME_LEN 1518
+#endif
+
+#ifndef DCA_GET_TAG_TWO_ARGS
+#define dca3_get_tag(a,b) dca_get_tag(b)
+#endif
+
+#ifndef CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS
+#if defined(__i386__) || defined(__x86_64__)
+#define CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS
+#endif
+#endif
+
+/* taken from 2.6.24 definition in linux/kernel.h */
+#ifndef IS_ALIGNED
+#define IS_ALIGNED(x,a)         (((x) % ((typeof(x))(a))) == 0)
+#endif
+
+#ifdef IS_ENABLED
+#undef IS_ENABLED
+#undef __ARG_PLACEHOLDER_1
+#undef config_enabled
+#undef _config_enabled
+#undef __config_enabled
+#undef ___config_enabled
+#endif
+
+#define __ARG_PLACEHOLDER_1 0,
+#define config_enabled(cfg) _config_enabled(cfg)
+#define _config_enabled(value) __config_enabled(__ARG_PLACEHOLDER_##value)
+#define __config_enabled(arg1_or_junk) ___config_enabled(arg1_or_junk 1, 0)
+#define ___config_enabled(__ignored, val, ...) val
+
+#define IS_ENABLED(option) \
+	(config_enabled(option) || config_enabled(option##_MODULE))
+
+#if !defined(NETIF_F_HW_VLAN_TX) && !defined(NETIF_F_HW_VLAN_CTAG_TX)
+struct _kc_vlan_ethhdr {
+	unsigned char	h_dest[ETH_ALEN];
+	unsigned char	h_source[ETH_ALEN];
+	__be16		h_vlan_proto;
+	__be16		h_vlan_TCI;
+	__be16		h_vlan_encapsulated_proto;
+};
+#define vlan_ethhdr _kc_vlan_ethhdr
+struct _kc_vlan_hdr {
+	__be16		h_vlan_TCI;
+	__be16		h_vlan_encapsulated_proto;
+};
+#define vlan_hdr _kc_vlan_hdr
+#define vlan_tx_tag_present(_skb) 0
+#define vlan_tx_tag_get(_skb) 0
+#endif /* NETIF_F_HW_VLAN_TX && NETIF_F_HW_VLAN_CTAG_TX */
+
+#ifndef VLAN_PRIO_SHIFT
+#define VLAN_PRIO_SHIFT 13
+#endif
+
+#ifndef PCI_EXP_LNKSTA_CLS_2_5GB
+#define PCI_EXP_LNKSTA_CLS_2_5GB 0x0001
+#endif
+
+#ifndef PCI_EXP_LNKSTA_CLS_5_0GB
+#define PCI_EXP_LNKSTA_CLS_5_0GB 0x0002
+#endif
+
+#ifndef PCI_EXP_LNKSTA_CLS_8_0GB
+#define PCI_EXP_LNKSTA_CLS_8_0GB 0x0003
+#endif
+
+#ifndef PCI_EXP_LNKSTA_NLW_X1
+#define PCI_EXP_LNKSTA_NLW_X1 0x0010
+#endif
+
+#ifndef PCI_EXP_LNKSTA_NLW_X2
+#define PCI_EXP_LNKSTA_NLW_X2 0x0020
+#endif
+
+#ifndef PCI_EXP_LNKSTA_NLW_X4
+#define PCI_EXP_LNKSTA_NLW_X4 0x0040
+#endif
+
+#ifndef PCI_EXP_LNKSTA_NLW_X8
+#define PCI_EXP_LNKSTA_NLW_X8 0x0080
+#endif
+
+#ifndef __GFP_COLD
+#define __GFP_COLD 0
+#endif
+
+#ifndef __GFP_COMP
+#define __GFP_COMP 0
+#endif
+
+#ifndef IP_OFFSET
+#define IP_OFFSET 0x1FFF /* "Fragment Offset" part */
+#endif
+
+/*****************************************************************************/
+/* Installations with ethtool version without eeprom, adapter id, or statistics
+ * support */
+
+#ifndef ETH_GSTRING_LEN
+#define ETH_GSTRING_LEN 32
+#endif
+
+#ifndef ETHTOOL_GSTATS
+#define ETHTOOL_GSTATS 0x1d
+#undef ethtool_drvinfo
+#define ethtool_drvinfo k_ethtool_drvinfo
+struct k_ethtool_drvinfo {
+	u32 cmd;
+	char driver[32];
+	char version[32];
+	char fw_version[32];
+	char bus_info[32];
+	char reserved1[32];
+	char reserved2[16];
+	u32 n_stats;
+	u32 testinfo_len;
+	u32 eedump_len;
+	u32 regdump_len;
+};
+
+struct ethtool_stats {
+	u32 cmd;
+	u32 n_stats;
+	u64 data[0];
+};
+#endif /* ETHTOOL_GSTATS */
+
+#ifndef ETHTOOL_PHYS_ID
+#define ETHTOOL_PHYS_ID 0x1c
+#endif /* ETHTOOL_PHYS_ID */
+
+#ifndef ETHTOOL_GSTRINGS
+#define ETHTOOL_GSTRINGS 0x1b
+enum ethtool_stringset {
+	ETH_SS_TEST             = 0,
+	ETH_SS_STATS,
+};
+struct ethtool_gstrings {
+	u32 cmd;            /* ETHTOOL_GSTRINGS */
+	u32 string_set;     /* string set id e.c. ETH_SS_TEST, etc*/
+	u32 len;            /* number of strings in the string set */
+	u8 data[0];
+};
+#endif /* ETHTOOL_GSTRINGS */
+
+#ifndef ETHTOOL_TEST
+#define ETHTOOL_TEST 0x1a
+enum ethtool_test_flags {
+	ETH_TEST_FL_OFFLINE	= (1 << 0),
+	ETH_TEST_FL_FAILED	= (1 << 1),
+};
+struct ethtool_test {
+	u32 cmd;
+	u32 flags;
+	u32 reserved;
+	u32 len;
+	u64 data[0];
+};
+#endif /* ETHTOOL_TEST */
+
+#ifndef ETHTOOL_GEEPROM
+#define ETHTOOL_GEEPROM 0xb
+#undef ETHTOOL_GREGS
+struct ethtool_eeprom {
+	u32 cmd;
+	u32 magic;
+	u32 offset;
+	u32 len;
+	u8 data[0];
+};
+
+struct ethtool_value {
+	u32 cmd;
+	u32 data;
+};
+#endif /* ETHTOOL_GEEPROM */
+
+#ifndef ETHTOOL_GLINK
+#define ETHTOOL_GLINK 0xa
+#endif /* ETHTOOL_GLINK */
+
+#ifndef ETHTOOL_GWOL
+#define ETHTOOL_GWOL 0x5
+#define ETHTOOL_SWOL 0x6
+#define SOPASS_MAX      6
+struct ethtool_wolinfo {
+	u32 cmd;
+	u32 supported;
+	u32 wolopts;
+	u8 sopass[SOPASS_MAX]; /* SecureOn(tm) password */
+};
+#endif /* ETHTOOL_GWOL */
+
+#ifndef ETHTOOL_GREGS
+#define ETHTOOL_GREGS		0x00000004 /* Get NIC registers */
+#define ethtool_regs _kc_ethtool_regs
+/* for passing big chunks of data */
+struct _kc_ethtool_regs {
+	u32 cmd;
+	u32 version; /* driver-specific, indicates different chips/revs */
+	u32 len; /* bytes */
+	u8 data[0];
+};
+#endif /* ETHTOOL_GREGS */
+
+#ifndef ETHTOOL_GMSGLVL
+#define ETHTOOL_GMSGLVL		0x00000007 /* Get driver message level */
+#endif
+#ifndef ETHTOOL_SMSGLVL
+#define ETHTOOL_SMSGLVL		0x00000008 /* Set driver msg level, priv. */
+#endif
+#ifndef ETHTOOL_NWAY_RST
+#define ETHTOOL_NWAY_RST	0x00000009 /* Restart autonegotiation, priv */
+#endif
+#ifndef ETHTOOL_GLINK
+#define ETHTOOL_GLINK		0x0000000a /* Get link status */
+#endif
+#ifndef ETHTOOL_GEEPROM
+#define ETHTOOL_GEEPROM		0x0000000b /* Get EEPROM data */
+#endif
+#ifndef ETHTOOL_SEEPROM
+#define ETHTOOL_SEEPROM		0x0000000c /* Set EEPROM data */
+#endif
+#ifndef ETHTOOL_GCOALESCE
+#define ETHTOOL_GCOALESCE	0x0000000e /* Get coalesce config */
+/* for configuring coalescing parameters of chip */
+#define ethtool_coalesce _kc_ethtool_coalesce
+struct _kc_ethtool_coalesce {
+	u32	cmd;	/* ETHTOOL_{G,S}COALESCE */
+
+	/* How many usecs to delay an RX interrupt after
+	 * a packet arrives.  If 0, only rx_max_coalesced_frames
+	 * is used.
+	 */
+	u32	rx_coalesce_usecs;
+
+	/* How many packets to delay an RX interrupt after
+	 * a packet arrives.  If 0, only rx_coalesce_usecs is
+	 * used.  It is illegal to set both usecs and max frames
+	 * to zero as this would cause RX interrupts to never be
+	 * generated.
+	 */
+	u32	rx_max_coalesced_frames;
+
+	/* Same as above two parameters, except that these values
+	 * apply while an IRQ is being serviced by the host.  Not
+	 * all cards support this feature and the values are ignored
+	 * in that case.
+	 */
+	u32	rx_coalesce_usecs_irq;
+	u32	rx_max_coalesced_frames_irq;
+
+	/* How many usecs to delay a TX interrupt after
+	 * a packet is sent.  If 0, only tx_max_coalesced_frames
+	 * is used.
+	 */
+	u32	tx_coalesce_usecs;
+
+	/* How many packets to delay a TX interrupt after
+	 * a packet is sent.  If 0, only tx_coalesce_usecs is
+	 * used.  It is illegal to set both usecs and max frames
+	 * to zero as this would cause TX interrupts to never be
+	 * generated.
+	 */
+	u32	tx_max_coalesced_frames;
+
+	/* Same as above two parameters, except that these values
+	 * apply while an IRQ is being serviced by the host.  Not
+	 * all cards support this feature and the values are ignored
+	 * in that case.
+	 */
+	u32	tx_coalesce_usecs_irq;
+	u32	tx_max_coalesced_frames_irq;
+
+	/* How many usecs to delay in-memory statistics
+	 * block updates.  Some drivers do not have an in-memory
+	 * statistic block, and in such cases this value is ignored.
+	 * This value must not be zero.
+	 */
+	u32	stats_block_coalesce_usecs;
+
+	/* Adaptive RX/TX coalescing is an algorithm implemented by
+	 * some drivers to improve latency under low packet rates and
+	 * improve throughput under high packet rates.  Some drivers
+	 * only implement one of RX or TX adaptive coalescing.  Anything
+	 * not implemented by the driver causes these values to be
+	 * silently ignored.
+	 */
+	u32	use_adaptive_rx_coalesce;
+	u32	use_adaptive_tx_coalesce;
+
+	/* When the packet rate (measured in packets per second)
+	 * is below pkt_rate_low, the {rx,tx}_*_low parameters are
+	 * used.
+	 */
+	u32	pkt_rate_low;
+	u32	rx_coalesce_usecs_low;
+	u32	rx_max_coalesced_frames_low;
+	u32	tx_coalesce_usecs_low;
+	u32	tx_max_coalesced_frames_low;
+
+	/* When the packet rate is below pkt_rate_high but above
+	 * pkt_rate_low (both measured in packets per second) the
+	 * normal {rx,tx}_* coalescing parameters are used.
+	 */
+
+	/* When the packet rate is (measured in packets per second)
+	 * is above pkt_rate_high, the {rx,tx}_*_high parameters are
+	 * used.
+	 */
+	u32	pkt_rate_high;
+	u32	rx_coalesce_usecs_high;
+	u32	rx_max_coalesced_frames_high;
+	u32	tx_coalesce_usecs_high;
+	u32	tx_max_coalesced_frames_high;
+
+	/* How often to do adaptive coalescing packet rate sampling,
+	 * measured in seconds.  Must not be zero.
+	 */
+	u32	rate_sample_interval;
+};
+#endif /* ETHTOOL_GCOALESCE */
+
+#ifndef ETHTOOL_SCOALESCE
+#define ETHTOOL_SCOALESCE	0x0000000f /* Set coalesce config. */
+#endif
+#ifndef ETHTOOL_GRINGPARAM
+#define ETHTOOL_GRINGPARAM	0x00000010 /* Get ring parameters */
+/* for configuring RX/TX ring parameters */
+#define ethtool_ringparam _kc_ethtool_ringparam
+struct _kc_ethtool_ringparam {
+	u32	cmd;	/* ETHTOOL_{G,S}RINGPARAM */
+
+	/* Read only attributes.  These indicate the maximum number
+	 * of pending RX/TX ring entries the driver will allow the
+	 * user to set.
+	 */
+	u32	rx_max_pending;
+	u32	rx_mini_max_pending;
+	u32	rx_jumbo_max_pending;
+	u32	tx_max_pending;
+
+	/* Values changeable by the user.  The valid values are
+	 * in the range 1 to the "*_max_pending" counterpart above.
+	 */
+	u32	rx_pending;
+	u32	rx_mini_pending;
+	u32	rx_jumbo_pending;
+	u32	tx_pending;
+};
+#endif /* ETHTOOL_GRINGPARAM */
+
+#ifndef ETHTOOL_SRINGPARAM
+#define ETHTOOL_SRINGPARAM	0x00000011 /* Set ring parameters, priv. */
+#endif
+#ifndef ETHTOOL_GPAUSEPARAM
+#define ETHTOOL_GPAUSEPARAM	0x00000012 /* Get pause parameters */
+/* for configuring link flow control parameters */
+#define ethtool_pauseparam _kc_ethtool_pauseparam
+struct _kc_ethtool_pauseparam {
+	u32	cmd;	/* ETHTOOL_{G,S}PAUSEPARAM */
+
+	/* If the link is being auto-negotiated (via ethtool_cmd.autoneg
+	 * being true) the user may set 'autoneg' here non-zero to have the
+	 * pause parameters be auto-negotiated too.  In such a case, the
+	 * {rx,tx}_pause values below determine what capabilities are
+	 * advertised.
+	 *
+	 * If 'autoneg' is zero or the link is not being auto-negotiated,
+	 * then {rx,tx}_pause force the driver to use/not-use pause
+	 * flow control.
+	 */
+	u32	autoneg;
+	u32	rx_pause;
+	u32	tx_pause;
+};
+#endif /* ETHTOOL_GPAUSEPARAM */
+
+#ifndef ETHTOOL_SPAUSEPARAM
+#define ETHTOOL_SPAUSEPARAM	0x00000013 /* Set pause parameters. */
+#endif
+#ifndef ETHTOOL_GRXCSUM
+#define ETHTOOL_GRXCSUM		0x00000014 /* Get RX hw csum enable (ethtool_value) */
+#endif
+#ifndef ETHTOOL_SRXCSUM
+#define ETHTOOL_SRXCSUM		0x00000015 /* Set RX hw csum enable (ethtool_value) */
+#endif
+#ifndef ETHTOOL_GTXCSUM
+#define ETHTOOL_GTXCSUM		0x00000016 /* Get TX hw csum enable (ethtool_value) */
+#endif
+#ifndef ETHTOOL_STXCSUM
+#define ETHTOOL_STXCSUM		0x00000017 /* Set TX hw csum enable (ethtool_value) */
+#endif
+#ifndef ETHTOOL_GSG
+#define ETHTOOL_GSG		0x00000018 /* Get scatter-gather enable
+					    * (ethtool_value) */
+#endif
+#ifndef ETHTOOL_SSG
+#define ETHTOOL_SSG		0x00000019 /* Set scatter-gather enable
+					    * (ethtool_value). */
+#endif
+#ifndef ETHTOOL_TEST
+#define ETHTOOL_TEST		0x0000001a /* execute NIC self-test, priv. */
+#endif
+#ifndef ETHTOOL_GSTRINGS
+#define ETHTOOL_GSTRINGS	0x0000001b /* get specified string set */
+#endif
+#ifndef ETHTOOL_PHYS_ID
+#define ETHTOOL_PHYS_ID		0x0000001c /* identify the NIC */
+#endif
+#ifndef ETHTOOL_GSTATS
+#define ETHTOOL_GSTATS		0x0000001d /* get NIC-specific statistics */
+#endif
+#ifndef ETHTOOL_GTSO
+#define ETHTOOL_GTSO		0x0000001e /* Get TSO enable (ethtool_value) */
+#endif
+#ifndef ETHTOOL_STSO
+#define ETHTOOL_STSO		0x0000001f /* Set TSO enable (ethtool_value) */
+#endif
+
+#ifndef ETHTOOL_BUSINFO_LEN
+#define ETHTOOL_BUSINFO_LEN	32
+#endif
+
+#ifndef SPEED_2500
+#define SPEED_2500 2500
+#endif
+#ifndef SPEED_5000
+#define SPEED_5000 5000
+#endif
+#ifndef SPEED_25000
+#define SPEED_25000 25000
+#endif
+#ifndef SPEED_50000
+#define SPEED_50000 50000
+#endif
+#ifndef SPEED_100000
+#define SPEED_100000 100000
+#endif
+
+#ifndef RHEL_RELEASE_VERSION
+#define RHEL_RELEASE_VERSION(a,b) (((a) << 8) + (b))
+#endif
+#ifndef AX_RELEASE_VERSION
+#define AX_RELEASE_VERSION(a,b) (((a) << 8) + (b))
+#endif
+
+#ifndef AX_RELEASE_CODE
+#define AX_RELEASE_CODE 0
+#endif
+
+#if (AX_RELEASE_CODE && AX_RELEASE_CODE == AX_RELEASE_VERSION(3,0))
+#define RHEL_RELEASE_CODE RHEL_RELEASE_VERSION(5,0)
+#elif (AX_RELEASE_CODE && AX_RELEASE_CODE == AX_RELEASE_VERSION(3,1))
+#define RHEL_RELEASE_CODE RHEL_RELEASE_VERSION(5,1)
+#elif (AX_RELEASE_CODE && AX_RELEASE_CODE == AX_RELEASE_VERSION(3,2))
+#define RHEL_RELEASE_CODE RHEL_RELEASE_VERSION(5,3)
+#endif
+
+#ifndef RHEL_RELEASE_CODE
+/* NOTE: RHEL_RELEASE_* introduced in RHEL4.5 */
+#define RHEL_RELEASE_CODE 0
+#endif
+
+/* RHEL 7 didn't backport the parameter change in
+ * create_singlethread_workqueue.
+ * If/when RH corrects this we will want to tighten up the version check.
+ */
+#if (RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,0))
+#undef create_singlethread_workqueue
+#define create_singlethread_workqueue(name)	\
+	alloc_ordered_workqueue("%s", WQ_MEM_RECLAIM, name)
+#endif
+
+/* Ubuntu Release ABI is the 4th digit of their kernel version. You can find
+ * it in /usr/src/linux/$(uname -r)/include/generated/utsrelease.h for new
+ * enough versions of Ubuntu. Otherwise you can simply see it in the output of
+ * uname as the 4th digit of the kernel. The UTS_UBUNTU_RELEASE_ABI is not in
+ * the linux-source package, but in the linux-headers package. It begins to
+ * appear in later releases of 14.04 and 14.10.
+ *
+ * Ex:
+ * <Ubuntu 14.04.1>
+ *  $uname -r
+ *  3.13.0-45-generic
+ * ABI is 45
+ *
+ * <Ubuntu 14.10>
+ *  $uname -r
+ *  3.16.0-23-generic
+ * ABI is 23
+ */
+#ifndef UTS_UBUNTU_RELEASE_ABI
+#define UTS_UBUNTU_RELEASE_ABI 0
+#define UBUNTU_VERSION_CODE 0
+#else
+/* Ubuntu does not provide actual release version macro, so we use the kernel
+ * version plus the ABI to generate a unique version code specific to Ubuntu.
+ * In addition, we mask the lower 8 bits of LINUX_VERSION_CODE in order to
+ * ignore differences in sublevel which are not important since we have the
+ * ABI value. Otherwise, it becomes impossible to correlate ABI to version for
+ * ordering checks.
+ */
+#define UBUNTU_VERSION_CODE (((~0xFF & LINUX_VERSION_CODE) << 8) + \
+			     UTS_UBUNTU_RELEASE_ABI)
+
+#if UTS_UBUNTU_RELEASE_ABI > 255
+#error UTS_UBUNTU_RELEASE_ABI is too large...
+#endif /* UTS_UBUNTU_RELEASE_ABI > 255 */
+
+#if ( LINUX_VERSION_CODE <= KERNEL_VERSION(3,0,0) )
+/* Our version code scheme does not make sense for non 3.x or newer kernels,
+ * and we have no support in kcompat for this scenario. Thus, treat this as a
+ * non-Ubuntu kernel. Possibly might be better to error here.
+ */
+#define UTS_UBUNTU_RELEASE_ABI 0
+#define UBUNTU_VERSION_CODE 0
+#endif
+
+#endif
+
+/* Note that the 3rd digit is always zero, and will be ignored. This is
+ * because Ubuntu kernels are based on x.y.0-ABI values, and while their linux
+ * version codes are 3 digit, this 3rd digit is superseded by the ABI value.
+ */
+#define UBUNTU_VERSION(a,b,c,d) ((KERNEL_VERSION(a,b,0) << 8) + (d))
+
+/* SuSE version macros are the same as Linux kernel version macro */
+#ifndef SLE_VERSION
+#define SLE_VERSION(a,b,c)	KERNEL_VERSION(a,b,c)
+#endif
+#define SLE_LOCALVERSION(a,b,c)	KERNEL_VERSION(a,b,c)
+#ifdef CONFIG_SUSE_KERNEL
+#if ( LINUX_VERSION_CODE == KERNEL_VERSION(2,6,27) )
+/* SLES11 GA is 2.6.27 based */
+#define SLE_VERSION_CODE SLE_VERSION(11,0,0)
+#elif ( LINUX_VERSION_CODE == KERNEL_VERSION(2,6,32) )
+/* SLES11 SP1 is 2.6.32 based */
+#define SLE_VERSION_CODE SLE_VERSION(11,1,0)
+#elif ( LINUX_VERSION_CODE == KERNEL_VERSION(3,0,13) )
+/* SLES11 SP2 GA is 3.0.13-0.27 */
+#define SLE_VERSION_CODE SLE_VERSION(11,2,0)
+#elif ((LINUX_VERSION_CODE == KERNEL_VERSION(3,0,76)))
+/* SLES11 SP3 GA is 3.0.76-0.11 */
+#define SLE_VERSION_CODE SLE_VERSION(11,3,0)
+#elif (LINUX_VERSION_CODE == KERNEL_VERSION(3,0,101))
+  #if (SLE_LOCALVERSION_CODE < SLE_LOCALVERSION(0,8,0))
+  /* some SLES11sp2 update kernels up to 3.0.101-0.7.x */
+  #define SLE_VERSION_CODE SLE_VERSION(11,2,0)
+  #elif (SLE_LOCALVERSION_CODE < SLE_LOCALVERSION(63,0,0))
+  /* most SLES11sp3 update kernels */
+  #define SLE_VERSION_CODE SLE_VERSION(11,3,0)
+  #else
+  /* SLES11 SP4 GA (3.0.101-63) and update kernels 3.0.101-63+ */
+  #define SLE_VERSION_CODE SLE_VERSION(11,4,0)
+  #endif
+#elif (LINUX_VERSION_CODE == KERNEL_VERSION(3,12,28))
+/* SLES12 GA is 3.12.28-4
+ * kernel updates 3.12.xx-<33 through 52>[.yy] */
+#define SLE_VERSION_CODE SLE_VERSION(12,0,0)
+#elif (LINUX_VERSION_CODE == KERNEL_VERSION(3,12,49))
+/* SLES12 SP1 GA is 3.12.49-11
+ * updates 3.12.xx-60.yy where xx={51..} */
+#define SLE_VERSION_CODE SLE_VERSION(12,1,0)
+#elif (LINUX_VERSION_CODE == KERNEL_VERSION(4,4,21))
+/* SLES12 SP2 GA is 4.4.21-69 */
+#define SLE_VERSION_CODE SLE_VERSION(12,2,0)
+/* SLES12 SP3 Beta3 is 4.4.68-2 */
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,4,68))
+#define SLE_VERSION_CODE SLE_VERSION(12,3,0)
+/* new SLES kernels must be added here with >= based on kernel
+ * the idea is to order from newest to oldest and just catch all
+ * of them using the >=
+ */
+#endif /* LINUX_VERSION_CODE == KERNEL_VERSION(x,y,z) */
+#endif /* CONFIG_SUSE_KERNEL */
+#ifndef SLE_VERSION_CODE
+#define SLE_VERSION_CODE 0
+#endif /* SLE_VERSION_CODE */
+#ifndef SLE_LOCALVERSION_CODE
+#define SLE_LOCALVERSION_CODE 0
+#endif /* SLE_LOCALVERSION_CODE */
+
+#ifdef __KLOCWORK__
+/* The following are not compiled into the binary driver; they are here
+ * only to tune Klocwork scans to workaround false-positive issues.
+ */
+#ifdef ARRAY_SIZE
+#undef ARRAY_SIZE
+#define ARRAY_SIZE(x) (sizeof(x) / sizeof((x)[0]))
+#endif
+
+#define memcpy(dest, src, len)	memcpy_s(dest, len, src, len)
+
+static inline int _kc_test_and_clear_bit(int nr, volatile unsigned long *addr)
+{
+	unsigned long mask = BIT_MASK(nr);
+	unsigned long *p = ((unsigned long *)addr) + BIT_WORD(nr);
+	unsigned long old;
+	unsigned long flags = 0;
+
+	_atomic_spin_lock_irqsave(p, flags);
+	old = *p;
+	*p = old & ~mask;
+	_atomic_spin_unlock_irqrestore(p, flags);
+
+	return (old & mask) != 0;
+}
+#define test_and_clear_bit(nr, addr) _kc_test_and_clear_bit(nr, addr)
+
+static inline int _kc_test_and_set_bit(int nr, volatile unsigned long *addr)
+{
+	unsigned long mask = BIT_MASK(nr);
+	unsigned long *p = ((unsigned long *)addr) + BIT_WORD(nr);
+	unsigned long old;
+	unsigned long flags = 0;
+
+	_atomic_spin_lock_irqsave(p, flags);
+	old = *p;
+	*p = old | mask;
+	_atomic_spin_unlock_irqrestore(p, flags);
+
+	return (old & mask) != 0;
+}
+#define test_and_set_bit(nr, addr) _kc_test_and_set_bit(nr, addr)
+
+#ifdef CONFIG_DYNAMIC_DEBUG
+#undef dev_dbg
+#define dev_dbg(dev, format, arg...) dev_printk(KERN_DEBUG, dev, format, ##arg)
+#endif /* CONFIG_DYNAMIC_DEBUG */
+
+#undef list_for_each_entry_safe
+#define list_for_each_entry_safe(pos, n, head, member)			   \
+	for (n = NULL, pos = list_first_entry(head, typeof(*pos), member); \
+	     &pos->member != (head);					   \
+	     pos = list_next_entry(pos, member))
+
+#undef hlist_for_each_entry_safe
+#define hlist_for_each_entry_safe(pos, n, head, member)			     \
+	for (n = NULL, pos = hlist_entry_safe((head)->first, typeof(*(pos)), \
+					      member);			     \
+	     pos;							     \
+	     pos = hlist_entry_safe((pos)->member.next, typeof(*(pos)), member))
+
+#endif /* __KLOCWORK__ */
+
+/*****************************************************************************/
+/* 2.4.3 => 2.4.0 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,3) )
+
+/**************************************/
+/* PCI DRIVER API */
+
+#ifndef pci_set_dma_mask
+#define pci_set_dma_mask _kc_pci_set_dma_mask
+extern int _kc_pci_set_dma_mask(struct pci_dev *dev, dma_addr_t mask);
+#endif
+
+#ifndef pci_request_regions
+#define pci_request_regions _kc_pci_request_regions
+extern int _kc_pci_request_regions(struct pci_dev *pdev, char *res_name);
+#endif
+
+#ifndef pci_release_regions
+#define pci_release_regions _kc_pci_release_regions
+extern void _kc_pci_release_regions(struct pci_dev *pdev);
+#endif
+
+/**************************************/
+/* NETWORK DRIVER API */
+
+#ifndef alloc_etherdev
+#define alloc_etherdev _kc_alloc_etherdev
+extern struct net_device * _kc_alloc_etherdev(int sizeof_priv);
+#endif
+
+#ifndef is_valid_ether_addr
+#define is_valid_ether_addr _kc_is_valid_ether_addr
+extern int _kc_is_valid_ether_addr(u8 *addr);
+#endif
+
+/**************************************/
+/* MISCELLANEOUS */
+
+#ifndef INIT_TQUEUE
+#define INIT_TQUEUE(_tq, _routine, _data)		\
+	do {						\
+		INIT_LIST_HEAD(&(_tq)->list);		\
+		(_tq)->sync = 0;			\
+		(_tq)->routine = _routine;		\
+		(_tq)->data = _data;			\
+	} while (0)
+#endif
+
+#endif /* 2.4.3 => 2.4.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,5) )
+/* Generic MII registers. */
+#define MII_BMCR            0x00        /* Basic mode control register */
+#define MII_BMSR            0x01        /* Basic mode status register  */
+#define MII_PHYSID1         0x02        /* PHYS ID 1                   */
+#define MII_PHYSID2         0x03        /* PHYS ID 2                   */
+#define MII_ADVERTISE       0x04        /* Advertisement control reg   */
+#define MII_LPA             0x05        /* Link partner ability reg    */
+#define MII_EXPANSION       0x06        /* Expansion register          */
+/* Basic mode control register. */
+#define BMCR_FULLDPLX           0x0100  /* Full duplex                 */
+#define BMCR_ANENABLE           0x1000  /* Enable auto negotiation     */
+/* Basic mode status register. */
+#define BMSR_ERCAP              0x0001  /* Ext-reg capability          */
+#define BMSR_ANEGCAPABLE        0x0008  /* Able to do auto-negotiation */
+#define BMSR_10HALF             0x0800  /* Can do 10mbps, half-duplex  */
+#define BMSR_10FULL             0x1000  /* Can do 10mbps, full-duplex  */
+#define BMSR_100HALF            0x2000  /* Can do 100mbps, half-duplex */
+#define BMSR_100FULL            0x4000  /* Can do 100mbps, full-duplex */
+/* Advertisement control register. */
+#define ADVERTISE_CSMA          0x0001  /* Only selector supported     */
+#define ADVERTISE_10HALF        0x0020  /* Try for 10mbps half-duplex  */
+#define ADVERTISE_10FULL        0x0040  /* Try for 10mbps full-duplex  */
+#define ADVERTISE_100HALF       0x0080  /* Try for 100mbps half-duplex */
+#define ADVERTISE_100FULL       0x0100  /* Try for 100mbps full-duplex */
+#define ADVERTISE_ALL (ADVERTISE_10HALF | ADVERTISE_10FULL | \
+                       ADVERTISE_100HALF | ADVERTISE_100FULL)
+/* Expansion register for auto-negotiation. */
+#define EXPANSION_ENABLENPAGE   0x0004  /* This enables npage words    */
+#endif
+
+/*****************************************************************************/
+/* 2.4.6 => 2.4.3 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,6) )
+
+#ifndef pci_set_power_state
+#define pci_set_power_state _kc_pci_set_power_state
+extern int _kc_pci_set_power_state(struct pci_dev *dev, int state);
+#endif
+
+#ifndef pci_enable_wake
+#define pci_enable_wake _kc_pci_enable_wake
+extern int _kc_pci_enable_wake(struct pci_dev *pdev, u32 state, int enable);
+#endif
+
+#ifndef pci_disable_device
+#define pci_disable_device _kc_pci_disable_device
+extern void _kc_pci_disable_device(struct pci_dev *pdev);
+#endif
+
+/* PCI PM entry point syntax changed, so don't support suspend/resume */
+#undef CONFIG_PM
+
+#endif /* 2.4.6 => 2.4.3 */
+
+#ifndef HAVE_PCI_SET_MWI
+#define pci_set_mwi(X) pci_write_config_word(X, \
+			       PCI_COMMAND, adapter->hw.bus.pci_cmd_word | \
+			       PCI_COMMAND_INVALIDATE);
+#define pci_clear_mwi(X) pci_write_config_word(X, \
+			       PCI_COMMAND, adapter->hw.bus.pci_cmd_word & \
+			       ~PCI_COMMAND_INVALIDATE);
+#endif
+
+/*****************************************************************************/
+/* 2.4.10 => 2.4.9 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,10) )
+
+/**************************************/
+/* MODULE API */
+
+#ifndef MODULE_LICENSE
+	#define MODULE_LICENSE(X)
+#endif
+
+/**************************************/
+/* OTHER */
+
+#undef min
+#define min(x,y) ({ \
+	const typeof(x) _x = (x);	\
+	const typeof(y) _y = (y);	\
+	(void) (&_x == &_y);		\
+	_x < _y ? _x : _y; })
+
+#undef max
+#define max(x,y) ({ \
+	const typeof(x) _x = (x);	\
+	const typeof(y) _y = (y);	\
+	(void) (&_x == &_y);		\
+	_x > _y ? _x : _y; })
+
+#define min_t(type,x,y) ({ \
+	type _x = (x); \
+	type _y = (y); \
+	_x < _y ? _x : _y; })
+
+#define max_t(type,x,y) ({ \
+	type _x = (x); \
+	type _y = (y); \
+	_x > _y ? _x : _y; })
+
+#ifndef list_for_each_safe
+#define list_for_each_safe(pos, n, head) \
+	for (pos = (head)->next, n = pos->next; pos != (head); \
+		pos = n, n = pos->next)
+#endif
+
+#ifndef ____cacheline_aligned_in_smp
+#ifdef CONFIG_SMP
+#define ____cacheline_aligned_in_smp ____cacheline_aligned
+#else
+#define ____cacheline_aligned_in_smp
+#endif /* CONFIG_SMP */
+#endif
+
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,8) )
+extern int _kc_snprintf(char * buf, size_t size, const char *fmt, ...);
+#define snprintf(buf, size, fmt, args...) _kc_snprintf(buf, size, fmt, ##args)
+extern int _kc_vsnprintf(char *buf, size_t size, const char *fmt, va_list args);
+#define vsnprintf(buf, size, fmt, args) _kc_vsnprintf(buf, size, fmt, args)
+#else /* 2.4.8 => 2.4.9 */
+extern int snprintf(char * buf, size_t size, const char *fmt, ...);
+extern int vsnprintf(char *buf, size_t size, const char *fmt, va_list args);
+#endif
+#endif /* 2.4.10 -> 2.4.6 */
+
+
+/*****************************************************************************/
+/* 2.4.12 => 2.4.10 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,12) )
+#ifndef HAVE_NETIF_MSG
+#define HAVE_NETIF_MSG 1
+enum {
+	NETIF_MSG_DRV		= 0x0001,
+	NETIF_MSG_PROBE		= 0x0002,
+	NETIF_MSG_LINK		= 0x0004,
+	NETIF_MSG_TIMER		= 0x0008,
+	NETIF_MSG_IFDOWN	= 0x0010,
+	NETIF_MSG_IFUP		= 0x0020,
+	NETIF_MSG_RX_ERR	= 0x0040,
+	NETIF_MSG_TX_ERR	= 0x0080,
+	NETIF_MSG_TX_QUEUED	= 0x0100,
+	NETIF_MSG_INTR		= 0x0200,
+	NETIF_MSG_TX_DONE	= 0x0400,
+	NETIF_MSG_RX_STATUS	= 0x0800,
+	NETIF_MSG_PKTDATA	= 0x1000,
+	NETIF_MSG_HW		= 0x2000,
+	NETIF_MSG_WOL		= 0x4000,
+};
+
+#define netif_msg_drv(p)	((p)->msg_enable & NETIF_MSG_DRV)
+#define netif_msg_probe(p)	((p)->msg_enable & NETIF_MSG_PROBE)
+#define netif_msg_link(p)	((p)->msg_enable & NETIF_MSG_LINK)
+#define netif_msg_timer(p)	((p)->msg_enable & NETIF_MSG_TIMER)
+#define netif_msg_ifdown(p)	((p)->msg_enable & NETIF_MSG_IFDOWN)
+#define netif_msg_ifup(p)	((p)->msg_enable & NETIF_MSG_IFUP)
+#define netif_msg_rx_err(p)	((p)->msg_enable & NETIF_MSG_RX_ERR)
+#define netif_msg_tx_err(p)	((p)->msg_enable & NETIF_MSG_TX_ERR)
+#define netif_msg_tx_queued(p)	((p)->msg_enable & NETIF_MSG_TX_QUEUED)
+#define netif_msg_intr(p)	((p)->msg_enable & NETIF_MSG_INTR)
+#define netif_msg_tx_done(p)	((p)->msg_enable & NETIF_MSG_TX_DONE)
+#define netif_msg_rx_status(p)	((p)->msg_enable & NETIF_MSG_RX_STATUS)
+#define netif_msg_pktdata(p)	((p)->msg_enable & NETIF_MSG_PKTDATA)
+#endif /* !HAVE_NETIF_MSG */
+#endif /* 2.4.12 => 2.4.10 */
+
+/*****************************************************************************/
+/* 2.4.13 => 2.4.12 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,13) )
+
+/**************************************/
+/* PCI DMA MAPPING */
+
+#ifndef virt_to_page
+	#define virt_to_page(v) (mem_map + (virt_to_phys(v) >> PAGE_SHIFT))
+#endif
+
+#ifndef pci_map_page
+#define pci_map_page _kc_pci_map_page
+extern u64 _kc_pci_map_page(struct pci_dev *dev, struct page *page, unsigned long offset, size_t size, int direction);
+#endif
+
+#ifndef pci_unmap_page
+#define pci_unmap_page _kc_pci_unmap_page
+extern void _kc_pci_unmap_page(struct pci_dev *dev, u64 dma_addr, size_t size, int direction);
+#endif
+
+/* pci_set_dma_mask takes dma_addr_t, which is only 32-bits prior to 2.4.13 */
+
+#undef DMA_32BIT_MASK
+#define DMA_32BIT_MASK	0xffffffff
+#undef DMA_64BIT_MASK
+#define DMA_64BIT_MASK	0xffffffff
+
+/**************************************/
+/* OTHER */
+
+#ifndef cpu_relax
+#define cpu_relax()	rep_nop()
+#endif
+
+struct vlan_ethhdr {
+	unsigned char h_dest[ETH_ALEN];
+	unsigned char h_source[ETH_ALEN];
+	unsigned short h_vlan_proto;
+	unsigned short h_vlan_TCI;
+	unsigned short h_vlan_encapsulated_proto;
+};
+#endif /* 2.4.13 => 2.4.12 */
+
+/*****************************************************************************/
+/* 2.4.17 => 2.4.12 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,17) )
+
+#ifndef __devexit_p
+	#define __devexit_p(x) &(x)
+#endif
+
+#endif /* 2.4.17 => 2.4.13 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,18) )
+#define NETIF_MSG_HW	0x2000
+#define NETIF_MSG_WOL	0x4000
+
+#ifndef netif_msg_hw
+#define netif_msg_hw(p)		((p)->msg_enable & NETIF_MSG_HW)
+#endif
+#ifndef netif_msg_wol
+#define netif_msg_wol(p)	((p)->msg_enable & NETIF_MSG_WOL)
+#endif
+#endif /* 2.4.18 */
+
+/*****************************************************************************/
+
+/*****************************************************************************/
+/* 2.4.20 => 2.4.19 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,20) )
+
+/* we won't support NAPI on less than 2.4.20 */
+#ifdef NAPI
+#undef NAPI
+#endif
+
+#endif /* 2.4.20 => 2.4.19 */
+
+/*****************************************************************************/
+/* 2.4.22 => 2.4.17 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,22) )
+#define pci_name(x)	((x)->slot_name)
+
+#ifndef SUPPORTED_10000baseT_Full
+#define SUPPORTED_10000baseT_Full	(1 << 12)
+#endif
+#ifndef ADVERTISED_10000baseT_Full
+#define ADVERTISED_10000baseT_Full	(1 << 12)
+#endif
+#endif
+
+/*****************************************************************************/
+/* 2.4.22 => 2.4.17 */
+
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,22) )
+#endif
+
+/*****************************************************************************/
+/*****************************************************************************/
+/* 2.4.23 => 2.4.22 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,23) )
+/*****************************************************************************/
+#ifdef NAPI
+#ifndef netif_poll_disable
+#define netif_poll_disable(x) _kc_netif_poll_disable(x)
+static inline void _kc_netif_poll_disable(struct net_device *netdev)
+{
+	while (test_and_set_bit(__LINK_STATE_RX_SCHED, &netdev->state)) {
+		/* No hurry */
+		current->state = TASK_INTERRUPTIBLE;
+		schedule_timeout(1);
+	}
+}
+#endif
+#ifndef netif_poll_enable
+#define netif_poll_enable(x) _kc_netif_poll_enable(x)
+static inline void _kc_netif_poll_enable(struct net_device *netdev)
+{
+	clear_bit(__LINK_STATE_RX_SCHED, &netdev->state);
+}
+#endif
+#endif /* NAPI */
+#ifndef netif_tx_disable
+#define netif_tx_disable(x) _kc_netif_tx_disable(x)
+static inline void _kc_netif_tx_disable(struct net_device *dev)
+{
+	spin_lock_bh(&dev->xmit_lock);
+	netif_stop_queue(dev);
+	spin_unlock_bh(&dev->xmit_lock);
+}
+#endif
+#else /* 2.4.23 => 2.4.22 */
+#define HAVE_SCTP
+#endif /* 2.4.23 => 2.4.22 */
+
+/*****************************************************************************/
+/* 2.6.4 => 2.6.0 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,25) || \
+    ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0) && \
+      LINUX_VERSION_CODE < KERNEL_VERSION(2,6,4) ) )
+#define ETHTOOL_OPS_COMPAT
+#endif /* 2.6.4 => 2.6.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,27) )
+#define __user
+#endif /* < 2.4.27 */
+
+/*****************************************************************************/
+/* 2.5.71 => 2.4.x */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,5,71) )
+#define sk_protocol protocol
+#define pci_get_device pci_find_device
+#endif /* 2.5.70 => 2.4.x */
+
+/*****************************************************************************/
+/* < 2.4.27 or 2.6.0 <= 2.6.5 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,27) || \
+    ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0) && \
+      LINUX_VERSION_CODE < KERNEL_VERSION(2,6,5) ) )
+
+#ifndef netif_msg_init
+#define netif_msg_init _kc_netif_msg_init
+static inline u32 _kc_netif_msg_init(int debug_value, int default_msg_enable_bits)
+{
+	/* use default */
+	if (debug_value < 0 || debug_value >= (sizeof(u32) * 8))
+		return default_msg_enable_bits;
+	if (debug_value == 0) /* no output */
+		return 0;
+	/* set low N bits */
+	return (1 << debug_value) -1;
+}
+#endif
+
+#endif /* < 2.4.27 or 2.6.0 <= 2.6.5 */
+/*****************************************************************************/
+#if (( LINUX_VERSION_CODE < KERNEL_VERSION(2,4,27) ) || \
+     (( LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0) ) && \
+      ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,3) )))
+#define netdev_priv(x) x->priv
+#endif
+
+/*****************************************************************************/
+/* <= 2.5.0 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0) )
+#include <linux/rtnetlink.h>
+#undef pci_register_driver
+#define pci_register_driver pci_module_init
+
+/*
+ * Most of the dma compat code is copied/modifed from the 2.4.37
+ * /include/linux/libata-compat.h header file
+ */
+/* These definitions mirror those in pci.h, so they can be used
+ * interchangeably with their PCI_ counterparts */
+enum dma_data_direction {
+	DMA_BIDIRECTIONAL = 0,
+	DMA_TO_DEVICE = 1,
+	DMA_FROM_DEVICE = 2,
+	DMA_NONE = 3,
+};
+
+struct device {
+	struct pci_dev pdev;
+};
+
+static inline struct pci_dev *to_pci_dev (struct device *dev)
+{
+	return (struct pci_dev *) dev;
+}
+static inline struct device *pci_dev_to_dev(struct pci_dev *pdev)
+{
+	return (struct device *) pdev;
+}
+#define pdev_printk(lvl, pdev, fmt, args...) 	\
+	printk("%s %s: " fmt, lvl, pci_name(pdev), ## args)
+#define dev_err(dev, fmt, args...)            \
+	pdev_printk(KERN_ERR, to_pci_dev(dev), fmt, ## args)
+#define dev_info(dev, fmt, args...)            \
+	pdev_printk(KERN_INFO, to_pci_dev(dev), fmt, ## args)
+#define dev_warn(dev, fmt, args...)            \
+	pdev_printk(KERN_WARNING, to_pci_dev(dev), fmt, ## args)
+#define dev_notice(dev, fmt, args...)            \
+	pdev_printk(KERN_NOTICE, to_pci_dev(dev), fmt, ## args)
+#define dev_dbg(dev, fmt, args...) \
+	pdev_printk(KERN_DEBUG, to_pci_dev(dev), fmt, ## args)
+
+/* NOTE: dangerous! we ignore the 'gfp' argument */
+#define dma_alloc_coherent(dev,sz,dma,gfp) \
+	pci_alloc_consistent(to_pci_dev(dev),(sz),(dma))
+#define dma_free_coherent(dev,sz,addr,dma_addr) \
+	pci_free_consistent(to_pci_dev(dev),(sz),(addr),(dma_addr))
+
+#define dma_map_page(dev,a,b,c,d) \
+	pci_map_page(to_pci_dev(dev),(a),(b),(c),(d))
+#define dma_unmap_page(dev,a,b,c) \
+	pci_unmap_page(to_pci_dev(dev),(a),(b),(c))
+
+#define dma_map_single(dev,a,b,c) \
+	pci_map_single(to_pci_dev(dev),(a),(b),(c))
+#define dma_unmap_single(dev,a,b,c) \
+	pci_unmap_single(to_pci_dev(dev),(a),(b),(c))
+
+#define dma_map_sg(dev, sg, nents, dir) \
+	pci_map_sg(to_pci_dev(dev), (sg), (nents), (dir)
+#define dma_unmap_sg(dev, sg, nents, dir) \
+	pci_unmap_sg(to_pci_dev(dev), (sg), (nents), (dir)
+
+#define dma_sync_single(dev,a,b,c) \
+	pci_dma_sync_single(to_pci_dev(dev),(a),(b),(c))
+
+/* for range just sync everything, that's all the pci API can do */
+#define dma_sync_single_range(dev,addr,off,sz,dir) \
+	pci_dma_sync_single(to_pci_dev(dev),(addr),(off)+(sz),(dir))
+
+#define dma_set_mask(dev,mask) \
+	pci_set_dma_mask(to_pci_dev(dev),(mask))
+
+/* hlist_* code - double linked lists */
+struct hlist_head {
+	struct hlist_node *first;
+};
+
+struct hlist_node {
+	struct hlist_node *next, **pprev;
+};
+
+static inline void __hlist_del(struct hlist_node *n)
+{
+	struct hlist_node *next = n->next;
+	struct hlist_node **pprev = n->pprev;
+	*pprev = next;
+	if (next)
+	next->pprev = pprev;
+}
+
+static inline void hlist_del(struct hlist_node *n)
+{
+	__hlist_del(n);
+	n->next = NULL;
+	n->pprev = NULL;
+}
+
+static inline void hlist_add_head(struct hlist_node *n, struct hlist_head *h)
+{
+	struct hlist_node *first = h->first;
+	n->next = first;
+	if (first)
+		first->pprev = &n->next;
+	h->first = n;
+	n->pprev = &h->first;
+}
+
+static inline int hlist_empty(const struct hlist_head *h)
+{
+	return !h->first;
+}
+#define HLIST_HEAD_INIT { .first = NULL }
+#define HLIST_HEAD(name) struct hlist_head name = {  .first = NULL }
+#define INIT_HLIST_HEAD(ptr) ((ptr)->first = NULL)
+static inline void INIT_HLIST_NODE(struct hlist_node *h)
+{
+	h->next = NULL;
+	h->pprev = NULL;
+}
+
+#ifndef might_sleep
+#define might_sleep()
+#endif
+#else
+static inline struct device *pci_dev_to_dev(struct pci_dev *pdev)
+{
+	return &pdev->dev;
+}
+#endif /* <= 2.5.0 */
+
+/*****************************************************************************/
+/* 2.5.28 => 2.4.23 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,5,28) )
+
+#include <linux/tqueue.h>
+#define work_struct tq_struct
+#undef INIT_WORK
+#define INIT_WORK(a,b) INIT_TQUEUE(a,(void (*)(void *))b,a)
+#undef container_of
+#define container_of list_entry
+#define schedule_work schedule_task
+#define flush_scheduled_work flush_scheduled_tasks
+#define cancel_work_sync(x) flush_scheduled_work()
+
+#endif /* 2.5.28 => 2.4.17 */
+
+/*****************************************************************************/
+/* 2.6.0 => 2.5.28 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0) )
+#ifndef read_barrier_depends
+#define read_barrier_depends() rmb()
+#endif
+
+#ifndef rcu_head
+struct __kc_callback_head {
+	struct __kc_callback_head *next;
+	void (*func)(struct callback_head *head);
+};
+#define rcu_head __kc_callback_head
+#endif
+
+#undef get_cpu
+#define get_cpu() smp_processor_id()
+#undef put_cpu
+#define put_cpu() do { } while(0)
+#define MODULE_INFO(version, _version)
+#ifndef CONFIG_E1000_DISABLE_PACKET_SPLIT
+#define CONFIG_E1000_DISABLE_PACKET_SPLIT 1
+#endif
+#ifndef CONFIG_IGB_DISABLE_PACKET_SPLIT
+#define CONFIG_IGB_DISABLE_PACKET_SPLIT 1
+#endif
+#ifndef CONFIG_IGC_DISABLE_PACKET_SPLIT
+#define CONFIG_IGC_DISABLE_PACKET_SPLIT 1
+#endif
+
+#define dma_set_coherent_mask(dev,mask) 1
+
+#undef dev_put
+#define dev_put(dev) __dev_put(dev)
+
+#ifndef skb_fill_page_desc
+#define skb_fill_page_desc _kc_skb_fill_page_desc
+extern void _kc_skb_fill_page_desc(struct sk_buff *skb, int i, struct page *page, int off, int size);
+#endif
+
+#undef ALIGN
+#define ALIGN(x,a) (((x)+(a)-1)&~((a)-1))
+
+#ifndef page_count
+#define page_count(p) atomic_read(&(p)->count)
+#endif
+
+#ifdef MAX_NUMNODES
+#undef MAX_NUMNODES
+#endif
+#define MAX_NUMNODES 1
+
+/* find_first_bit and find_next bit are not defined for most
+ * 2.4 kernels (except for the redhat 2.4.21 kernels
+ */
+#include <linux/bitops.h>
+#define BITOP_WORD(nr)          ((nr) / BITS_PER_LONG)
+#undef find_next_bit
+#define find_next_bit _kc_find_next_bit
+extern unsigned long _kc_find_next_bit(const unsigned long *addr,
+                                       unsigned long size,
+                                       unsigned long offset);
+#define find_first_bit(addr, size) find_next_bit((addr), (size), 0)
+
+#ifndef netdev_name
+static inline const char *_kc_netdev_name(const struct net_device *dev)
+{
+	if (strchr(dev->name, '%'))
+		return "(unregistered net_device)";
+	return dev->name;
+}
+#define netdev_name(netdev)	_kc_netdev_name(netdev)
+#endif /* netdev_name */
+
+#ifndef strlcpy
+#define strlcpy _kc_strlcpy
+extern size_t _kc_strlcpy(char *dest, const char *src, size_t size);
+#endif /* strlcpy */
+
+#ifndef do_div
+#if BITS_PER_LONG == 64
+# define do_div(n,base) ({					\
+	uint32_t __base = (base);				\
+	uint32_t __rem;						\
+	__rem = ((uint64_t)(n)) % __base;			\
+	(n) = ((uint64_t)(n)) / __base;				\
+	__rem;							\
+ })
+#elif BITS_PER_LONG == 32
+extern uint32_t _kc__div64_32(uint64_t *dividend, uint32_t divisor);
+# define do_div(n,base) ({				\
+	uint32_t __base = (base);			\
+	uint32_t __rem;					\
+	if (likely(((n) >> 32) == 0)) {			\
+		__rem = (uint32_t)(n) % __base;		\
+		(n) = (uint32_t)(n) / __base;		\
+	} else 						\
+		__rem = _kc__div64_32(&(n), __base);	\
+	__rem;						\
+ })
+#else /* BITS_PER_LONG == ?? */
+# error do_div() does not yet support the C64
+#endif /* BITS_PER_LONG */
+#endif /* do_div */
+
+#ifndef NSEC_PER_SEC
+#define NSEC_PER_SEC	1000000000L
+#endif
+
+#undef HAVE_I2C_SUPPORT
+#else /* 2.6.0 */
+
+#endif /* 2.6.0 => 2.5.28 */
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,3) )
+#define dma_pool pci_pool
+#define dma_pool_destroy pci_pool_destroy
+#define dma_pool_alloc pci_pool_alloc
+#define dma_pool_free pci_pool_free
+
+#define dma_pool_create(name,dev,size,align,allocation) \
+       pci_pool_create((name),to_pci_dev(dev),(size),(align),(allocation))
+#endif /* < 2.6.3 */
+
+/*****************************************************************************/
+/* 2.6.4 => 2.6.0 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,4) )
+#define MODULE_VERSION(_version) MODULE_INFO(version, _version)
+#endif /* 2.6.4 => 2.6.0 */
+
+/*****************************************************************************/
+/* 2.6.5 => 2.6.0 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,5) )
+#define dma_sync_single_for_cpu		dma_sync_single
+#define dma_sync_single_for_device	dma_sync_single
+#define dma_sync_single_range_for_cpu		dma_sync_single_range
+#define dma_sync_single_range_for_device	dma_sync_single_range
+#ifndef pci_dma_mapping_error
+#define pci_dma_mapping_error _kc_pci_dma_mapping_error
+static inline int _kc_pci_dma_mapping_error(dma_addr_t dma_addr)
+{
+	return dma_addr == 0;
+}
+#endif
+#endif /* 2.6.5 => 2.6.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,4) )
+extern int _kc_scnprintf(char * buf, size_t size, const char *fmt, ...);
+#define scnprintf(buf, size, fmt, args...) _kc_scnprintf(buf, size, fmt, ##args)
+#endif /* < 2.6.4 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,6) )
+/* taken from 2.6 include/linux/bitmap.h */
+#undef bitmap_zero
+#define bitmap_zero _kc_bitmap_zero
+static inline void _kc_bitmap_zero(unsigned long *dst, int nbits)
+{
+        if (nbits <= BITS_PER_LONG)
+                *dst = 0UL;
+        else {
+                int len = BITS_TO_LONGS(nbits) * sizeof(unsigned long);
+                memset(dst, 0, len);
+        }
+}
+#define page_to_nid(x) 0
+
+#endif /* < 2.6.6 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,7) )
+#undef if_mii
+#define if_mii _kc_if_mii
+static inline struct mii_ioctl_data *_kc_if_mii(struct ifreq *rq)
+{
+	return (struct mii_ioctl_data *) &rq->ifr_ifru;
+}
+
+#ifndef __force
+#define __force
+#endif
+#endif /* < 2.6.7 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,8) )
+#ifndef PCI_EXP_DEVCTL
+#define PCI_EXP_DEVCTL 8
+#endif
+#ifndef PCI_EXP_DEVCTL_CERE
+#define PCI_EXP_DEVCTL_CERE 0x0001
+#endif
+#define PCI_EXP_FLAGS		2	/* Capabilities register */
+#define PCI_EXP_FLAGS_VERS	0x000f	/* Capability version */
+#define PCI_EXP_FLAGS_TYPE	0x00f0	/* Device/Port type */
+#define  PCI_EXP_TYPE_ENDPOINT	0x0	/* Express Endpoint */
+#define  PCI_EXP_TYPE_LEG_END	0x1	/* Legacy Endpoint */
+#define  PCI_EXP_TYPE_ROOT_PORT 0x4	/* Root Port */
+#define  PCI_EXP_TYPE_DOWNSTREAM 0x6	/* Downstream Port */
+#define PCI_EXP_FLAGS_SLOT	0x0100	/* Slot implemented */
+#define PCI_EXP_DEVCAP		4	/* Device capabilities */
+#define PCI_EXP_DEVSTA		10	/* Device Status */
+#define msleep(x)	do { set_current_state(TASK_UNINTERRUPTIBLE); \
+				schedule_timeout((x * HZ)/1000 + 2); \
+			} while (0)
+
+#endif /* < 2.6.8 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,9))
+#include <net/dsfield.h>
+#define __iomem
+
+#ifndef kcalloc
+#define kcalloc(n, size, flags) _kc_kzalloc(((n) * (size)), flags)
+extern void *_kc_kzalloc(size_t size, int flags);
+#endif
+#define MSEC_PER_SEC    1000L
+static inline unsigned int _kc_jiffies_to_msecs(const unsigned long j)
+{
+#if HZ <= MSEC_PER_SEC && !(MSEC_PER_SEC % HZ)
+	return (MSEC_PER_SEC / HZ) * j;
+#elif HZ > MSEC_PER_SEC && !(HZ % MSEC_PER_SEC)
+	return (j + (HZ / MSEC_PER_SEC) - 1)/(HZ / MSEC_PER_SEC);
+#else
+	return (j * MSEC_PER_SEC) / HZ;
+#endif
+}
+static inline unsigned long _kc_msecs_to_jiffies(const unsigned int m)
+{
+	if (m > _kc_jiffies_to_msecs(MAX_JIFFY_OFFSET))
+		return MAX_JIFFY_OFFSET;
+#if HZ <= MSEC_PER_SEC && !(MSEC_PER_SEC % HZ)
+	return (m + (MSEC_PER_SEC / HZ) - 1) / (MSEC_PER_SEC / HZ);
+#elif HZ > MSEC_PER_SEC && !(HZ % MSEC_PER_SEC)
+	return m * (HZ / MSEC_PER_SEC);
+#else
+	return (m * HZ + MSEC_PER_SEC - 1) / MSEC_PER_SEC;
+#endif
+}
+
+#define msleep_interruptible _kc_msleep_interruptible
+static inline unsigned long _kc_msleep_interruptible(unsigned int msecs)
+{
+	unsigned long timeout = _kc_msecs_to_jiffies(msecs) + 1;
+
+	while (timeout && !signal_pending(current)) {
+		__set_current_state(TASK_INTERRUPTIBLE);
+		timeout = schedule_timeout(timeout);
+	}
+	return _kc_jiffies_to_msecs(timeout);
+}
+
+/* Basic mode control register. */
+#define BMCR_SPEED1000		0x0040  /* MSB of Speed (1000)         */
+
+#ifndef __le16
+#define __le16 u16
+#endif
+#ifndef __le32
+#define __le32 u32
+#endif
+#ifndef __le64
+#define __le64 u64
+#endif
+#ifndef __be16
+#define __be16 u16
+#endif
+#ifndef __be32
+#define __be32 u32
+#endif
+#ifndef __be64
+#define __be64 u64
+#endif
+
+static inline struct vlan_ethhdr *vlan_eth_hdr(const struct sk_buff *skb)
+{
+	return (struct vlan_ethhdr *)skb->mac.raw;
+}
+
+/* Wake-On-Lan options. */
+#define WAKE_PHY		(1 << 0)
+#define WAKE_UCAST		(1 << 1)
+#define WAKE_MCAST		(1 << 2)
+#define WAKE_BCAST		(1 << 3)
+#define WAKE_ARP		(1 << 4)
+#define WAKE_MAGIC		(1 << 5)
+#define WAKE_MAGICSECURE	(1 << 6) /* only meaningful if WAKE_MAGIC */
+
+#define skb_header_pointer _kc_skb_header_pointer
+static inline void *_kc_skb_header_pointer(const struct sk_buff *skb,
+					    int offset, int len, void *buffer)
+{
+	int hlen = skb_headlen(skb);
+
+	if (hlen - offset >= len)
+		return skb->data + offset;
+
+#ifdef MAX_SKB_FRAGS
+	if (skb_copy_bits(skb, offset, buffer, len) < 0)
+		return NULL;
+
+	return buffer;
+#else
+	return NULL;
+#endif
+
+#ifndef NETDEV_TX_OK
+#define NETDEV_TX_OK 0
+#endif
+#ifndef NETDEV_TX_BUSY
+#define NETDEV_TX_BUSY 1
+#endif
+#ifndef NETDEV_TX_LOCKED
+#define NETDEV_TX_LOCKED -1
+#endif
+}
+
+#ifndef __bitwise
+#define __bitwise
+#endif
+#endif /* < 2.6.9 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,10) )
+#ifdef module_param_array_named
+#undef module_param_array_named
+#define module_param_array_named(name, array, type, nump, perm)          \
+	static struct kparam_array __param_arr_##name                    \
+	= { ARRAY_SIZE(array), nump, param_set_##type, param_get_##type, \
+	    sizeof(array[0]), array };                                   \
+	module_param_call(name, param_array_set, param_array_get,        \
+			  &__param_arr_##name, perm)
+#endif /* module_param_array_named */
+/*
+ * num_online is broken for all < 2.6.10 kernels.  This is needed to support
+ * Node module parameter of ixgbe.
+ */
+#undef num_online_nodes
+#define num_online_nodes(n) 1
+extern DECLARE_BITMAP(_kcompat_node_online_map, MAX_NUMNODES);
+#undef node_online_map
+#define node_online_map _kcompat_node_online_map
+#define pci_get_class pci_find_class
+#endif /* < 2.6.10 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,11) )
+#define PCI_D0      0
+#define PCI_D1      1
+#define PCI_D2      2
+#define PCI_D3hot   3
+#define PCI_D3cold  4
+typedef int pci_power_t;
+#define pci_choose_state(pdev,state) state
+#define PMSG_SUSPEND 3
+#define PCI_EXP_LNKCTL	16
+
+#undef NETIF_F_LLTX
+
+#ifndef ARCH_HAS_PREFETCH
+#define prefetch(X)
+#endif
+
+#ifndef NET_IP_ALIGN
+#define NET_IP_ALIGN 2
+#endif
+
+#define KC_USEC_PER_SEC	1000000L
+#define usecs_to_jiffies _kc_usecs_to_jiffies
+static inline unsigned int _kc_jiffies_to_usecs(const unsigned long j)
+{
+#if HZ <= KC_USEC_PER_SEC && !(KC_USEC_PER_SEC % HZ)
+	return (KC_USEC_PER_SEC / HZ) * j;
+#elif HZ > KC_USEC_PER_SEC && !(HZ % KC_USEC_PER_SEC)
+	return (j + (HZ / KC_USEC_PER_SEC) - 1)/(HZ / KC_USEC_PER_SEC);
+#else
+	return (j * KC_USEC_PER_SEC) / HZ;
+#endif
+}
+static inline unsigned long _kc_usecs_to_jiffies(const unsigned int m)
+{
+	if (m > _kc_jiffies_to_usecs(MAX_JIFFY_OFFSET))
+		return MAX_JIFFY_OFFSET;
+#if HZ <= KC_USEC_PER_SEC && !(KC_USEC_PER_SEC % HZ)
+	return (m + (KC_USEC_PER_SEC / HZ) - 1) / (KC_USEC_PER_SEC / HZ);
+#elif HZ > KC_USEC_PER_SEC && !(HZ % KC_USEC_PER_SEC)
+	return m * (HZ / KC_USEC_PER_SEC);
+#else
+	return (m * HZ + KC_USEC_PER_SEC - 1) / KC_USEC_PER_SEC;
+#endif
+}
+
+#define PCI_EXP_LNKCAP		12	/* Link Capabilities */
+#define PCI_EXP_LNKSTA		18	/* Link Status */
+#define PCI_EXP_SLTCAP		20	/* Slot Capabilities */
+#define PCI_EXP_SLTCTL		24	/* Slot Control */
+#define PCI_EXP_SLTSTA		26	/* Slot Status */
+#define PCI_EXP_RTCTL		28	/* Root Control */
+#define PCI_EXP_RTCAP		30	/* Root Capabilities */
+#define PCI_EXP_RTSTA		32	/* Root Status */
+#endif /* < 2.6.11 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,12) )
+#include <linux/reboot.h>
+#define USE_REBOOT_NOTIFIER
+
+/* Generic MII registers. */
+#define MII_CTRL1000        0x09        /* 1000BASE-T control          */
+#define MII_STAT1000        0x0a        /* 1000BASE-T status           */
+/* Advertisement control register. */
+#define ADVERTISE_PAUSE_CAP     0x0400  /* Try for pause               */
+#define ADVERTISE_PAUSE_ASYM    0x0800  /* Try for asymmetric pause     */
+/* Link partner ability register. */
+#define LPA_PAUSE_CAP		0x0400	/* Can pause                   */
+#define LPA_PAUSE_ASYM		0x0800	/* Can pause asymetrically     */
+/* 1000BASE-T Control register */
+#define ADVERTISE_1000FULL      0x0200  /* Advertise 1000BASE-T full duplex */
+#define ADVERTISE_1000HALF	0x0100  /* Advertise 1000BASE-T half duplex */
+/* 1000BASE-T Status register */
+#define LPA_1000LOCALRXOK	0x2000	/* Link partner local receiver status */
+#define LPA_1000REMRXOK		0x1000	/* Link partner remote receiver status */
+
+#ifndef is_zero_ether_addr
+#define is_zero_ether_addr _kc_is_zero_ether_addr
+static inline int _kc_is_zero_ether_addr(const u8 *addr)
+{
+	return !(addr[0] | addr[1] | addr[2] | addr[3] | addr[4] | addr[5]);
+}
+#endif /* is_zero_ether_addr */
+#ifndef is_multicast_ether_addr
+#define is_multicast_ether_addr _kc_is_multicast_ether_addr
+static inline int _kc_is_multicast_ether_addr(const u8 *addr)
+{
+	return addr[0] & 0x01;
+}
+#endif /* is_multicast_ether_addr */
+#endif /* < 2.6.12 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13) )
+#ifndef kstrdup
+#define kstrdup _kc_kstrdup
+extern char *_kc_kstrdup(const char *s, unsigned int gfp);
+#endif
+#endif /* < 2.6.13 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,14) )
+#define pm_message_t u32
+#ifndef kzalloc
+#define kzalloc _kc_kzalloc
+extern void *_kc_kzalloc(size_t size, int flags);
+#endif
+
+/* Generic MII registers. */
+#define MII_ESTATUS	    0x0f	/* Extended Status */
+/* Basic mode status register. */
+#define BMSR_ESTATEN		0x0100	/* Extended Status in R15 */
+/* Extended status register. */
+#define ESTATUS_1000_TFULL	0x2000	/* Can do 1000BT Full */
+#define ESTATUS_1000_THALF	0x1000	/* Can do 1000BT Half */
+
+#define SUPPORTED_Pause	        (1 << 13)
+#define SUPPORTED_Asym_Pause	(1 << 14)
+#define ADVERTISED_Pause	(1 << 13)
+#define ADVERTISED_Asym_Pause	(1 << 14)
+
+#if (!(RHEL_RELEASE_CODE && \
+       (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(4,3)) && \
+       (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(5,0))))
+#if ((LINUX_VERSION_CODE == KERNEL_VERSION(2,6,9)) && !defined(gfp_t))
+#define gfp_t unsigned
+#else
+typedef unsigned gfp_t;
+#endif
+#endif /* !RHEL4.3->RHEL5.0 */
+
+#if ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,9) )
+#ifdef CONFIG_X86_64
+#define dma_sync_single_range_for_cpu(dev, addr, off, sz, dir)       \
+	dma_sync_single_for_cpu((dev), (addr), (off) + (sz), (dir))
+#define dma_sync_single_range_for_device(dev, addr, off, sz, dir)    \
+	dma_sync_single_for_device((dev), (addr), (off) + (sz), (dir))
+#endif
+#endif
+#endif /* < 2.6.14 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,15) )
+#ifndef kfree_rcu
+/* this is placed here due to a lack of rcu_barrier in previous kernels */
+#define kfree_rcu(_ptr, _offset) kfree(_ptr)
+#endif /* kfree_rcu */
+#ifndef vmalloc_node
+#define vmalloc_node(a,b) vmalloc(a)
+#endif /* vmalloc_node*/
+
+#define setup_timer(_timer, _function, _data) \
+do { \
+	(_timer)->function = _function; \
+	(_timer)->data = _data; \
+	init_timer(_timer); \
+} while (0)
+#ifndef device_can_wakeup
+#define device_can_wakeup(dev)	(1)
+#endif
+#ifndef device_set_wakeup_enable
+#define device_set_wakeup_enable(dev, val)	do{}while(0)
+#endif
+#ifndef device_init_wakeup
+#define device_init_wakeup(dev,val) do {} while (0)
+#endif
+static inline unsigned _kc_compare_ether_addr(const u8 *addr1, const u8 *addr2)
+{
+	const u16 *a = (const u16 *) addr1;
+	const u16 *b = (const u16 *) addr2;
+
+	return ((a[0] ^ b[0]) | (a[1] ^ b[1]) | (a[2] ^ b[2])) != 0;
+}
+#undef compare_ether_addr
+#define compare_ether_addr(addr1, addr2) _kc_compare_ether_addr(addr1, addr2)
+#endif /* < 2.6.15 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,16) )
+#undef DEFINE_MUTEX
+#define DEFINE_MUTEX(x)	DECLARE_MUTEX(x)
+#define mutex_lock(x)	down_interruptible(x)
+#define mutex_unlock(x)	up(x)
+
+#ifndef ____cacheline_internodealigned_in_smp
+#ifdef CONFIG_SMP
+#define ____cacheline_internodealigned_in_smp ____cacheline_aligned_in_smp
+#else
+#define ____cacheline_internodealigned_in_smp
+#endif /* CONFIG_SMP */
+#endif /* ____cacheline_internodealigned_in_smp */
+#undef HAVE_PCI_ERS
+#else /* 2.6.16 and above */
+#undef HAVE_PCI_ERS
+#define HAVE_PCI_ERS
+#if ( SLE_VERSION_CODE && SLE_VERSION_CODE == SLE_VERSION(10,4,0) )
+#ifdef device_can_wakeup
+#undef device_can_wakeup
+#endif /* device_can_wakeup */
+#define device_can_wakeup(dev) 1
+#endif /* SLE_VERSION(10,4,0) */
+#endif /* < 2.6.16 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,17) )
+#ifndef dev_notice
+#define dev_notice(dev, fmt, args...)            \
+	dev_printk(KERN_NOTICE, dev, fmt, ## args)
+#endif
+
+#ifndef first_online_node
+#define first_online_node 0
+#endif
+#ifndef NET_SKB_PAD
+#define NET_SKB_PAD 16
+#endif
+#endif /* < 2.6.17 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,18) )
+
+#ifndef IRQ_HANDLED
+#define irqreturn_t void
+#define IRQ_HANDLED
+#define IRQ_NONE
+#endif
+
+#ifndef IRQF_PROBE_SHARED
+#ifdef SA_PROBEIRQ
+#define IRQF_PROBE_SHARED SA_PROBEIRQ
+#else
+#define IRQF_PROBE_SHARED 0
+#endif
+#endif
+
+#ifndef IRQF_SHARED
+#define IRQF_SHARED SA_SHIRQ
+#endif
+
+#ifndef ARRAY_SIZE
+#define ARRAY_SIZE(x) (sizeof(x) / sizeof((x)[0]))
+#endif
+
+#ifndef FIELD_SIZEOF
+#define FIELD_SIZEOF(t, f) (sizeof(((t*)0)->f))
+#endif
+
+#ifndef skb_is_gso
+#ifdef NETIF_F_TSO
+#define skb_is_gso _kc_skb_is_gso
+static inline int _kc_skb_is_gso(const struct sk_buff *skb)
+{
+	return skb_shinfo(skb)->gso_size;
+}
+#else
+#define skb_is_gso(a) 0
+#endif
+#endif
+
+#ifndef resource_size_t
+#define resource_size_t unsigned long
+#endif
+
+#ifdef skb_pad
+#undef skb_pad
+#endif
+#define skb_pad(x,y) _kc_skb_pad(x, y)
+int _kc_skb_pad(struct sk_buff *skb, int pad);
+#ifdef skb_padto
+#undef skb_padto
+#endif
+#define skb_padto(x,y) _kc_skb_padto(x, y)
+static inline int _kc_skb_padto(struct sk_buff *skb, unsigned int len)
+{
+	unsigned int size = skb->len;
+	if(likely(size >= len))
+		return 0;
+	return _kc_skb_pad(skb, len - size);
+}
+
+#ifndef DECLARE_PCI_UNMAP_ADDR
+#define DECLARE_PCI_UNMAP_ADDR(ADDR_NAME) \
+	dma_addr_t ADDR_NAME
+#define DECLARE_PCI_UNMAP_LEN(LEN_NAME) \
+	u32 LEN_NAME
+#define pci_unmap_addr(PTR, ADDR_NAME) \
+	((PTR)->ADDR_NAME)
+#define pci_unmap_addr_set(PTR, ADDR_NAME, VAL) \
+	(((PTR)->ADDR_NAME) = (VAL))
+#define pci_unmap_len(PTR, LEN_NAME) \
+	((PTR)->LEN_NAME)
+#define pci_unmap_len_set(PTR, LEN_NAME, VAL) \
+	(((PTR)->LEN_NAME) = (VAL))
+#endif /* DECLARE_PCI_UNMAP_ADDR */
+#endif /* < 2.6.18 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19) )
+enum pcie_link_width {
+	PCIE_LNK_WIDTH_RESRV    = 0x00,
+	PCIE_LNK_X1             = 0x01,
+	PCIE_LNK_X2             = 0x02,
+	PCIE_LNK_X4             = 0x04,
+	PCIE_LNK_X8             = 0x08,
+	PCIE_LNK_X12            = 0x0C,
+	PCIE_LNK_X16            = 0x10,
+	PCIE_LNK_X32            = 0x20,
+	PCIE_LNK_WIDTH_UNKNOWN  = 0xFF,
+};
+
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(5,0)))
+#define i_private u.generic_ip
+#endif /* >= RHEL 5.0 */
+
+#ifndef DIV_ROUND_UP
+#define DIV_ROUND_UP(n,d) (((n) + (d) - 1) / (d))
+#endif
+#ifndef __ALIGN_MASK
+#define __ALIGN_MASK(x, mask) (((x) + (mask)) & ~(mask))
+#endif
+#if ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,5,0) )
+#if (!((RHEL_RELEASE_CODE && \
+        ((RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(4,4) && \
+          RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(5,0)) || \
+         (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(5,0))))))
+typedef irqreturn_t (*irq_handler_t)(int, void*, struct pt_regs *);
+#endif
+#if (RHEL_RELEASE_CODE && RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(6,0))
+#undef CONFIG_INET_LRO
+#undef CONFIG_INET_LRO_MODULE
+#undef CONFIG_FCOE
+#undef CONFIG_FCOE_MODULE
+#endif
+typedef irqreturn_t (*new_handler_t)(int, void*);
+static inline irqreturn_t _kc_request_irq(unsigned int irq, new_handler_t handler, unsigned long flags, const char *devname, void *dev_id)
+#else /* 2.4.x */
+typedef void (*irq_handler_t)(int, void*, struct pt_regs *);
+typedef void (*new_handler_t)(int, void*);
+static inline int _kc_request_irq(unsigned int irq, new_handler_t handler, unsigned long flags, const char *devname, void *dev_id)
+#endif /* >= 2.5.x */
+{
+	irq_handler_t new_handler = (irq_handler_t) handler;
+	return request_irq(irq, new_handler, flags, devname, dev_id);
+}
+
+#undef request_irq
+#define request_irq(irq, handler, flags, devname, dev_id) _kc_request_irq((irq), (handler), (flags), (devname), (dev_id))
+
+#define irq_handler_t new_handler_t
+
+#if ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,11) )
+#ifndef skb_checksum_help
+static inline int __kc_skb_checksum_help(struct sk_buff *skb)
+{
+	return skb_checksum_help(skb, 0);
+}
+#define skb_checksum_help(skb) __kc_skb_checksum_help((skb))
+#endif
+#endif /* < 2.6.19 && >= 2.6.11 */
+
+/* pci_restore_state and pci_save_state handles MSI/PCIE from 2.6.19 */
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(5,4)))
+#define PCIE_CONFIG_SPACE_LEN 256
+#define PCI_CONFIG_SPACE_LEN 64
+#define PCIE_LINK_STATUS 0x12
+#define pci_config_space_ich8lan() do {} while(0)
+#undef pci_save_state
+extern int _kc_pci_save_state(struct pci_dev *);
+#define pci_save_state(pdev) _kc_pci_save_state(pdev)
+#undef pci_restore_state
+extern void _kc_pci_restore_state(struct pci_dev *);
+#define pci_restore_state(pdev) _kc_pci_restore_state(pdev)
+#endif /* !(RHEL_RELEASE_CODE >= RHEL 5.4) */
+
+#ifdef HAVE_PCI_ERS
+#undef free_netdev
+extern void _kc_free_netdev(struct net_device *);
+#define free_netdev(netdev) _kc_free_netdev(netdev)
+#endif
+static inline int pci_enable_pcie_error_reporting(struct pci_dev __always_unused *dev)
+{
+	return 0;
+}
+#define pci_disable_pcie_error_reporting(dev) do {} while (0)
+#define pci_cleanup_aer_uncorrect_error_status(dev) do {} while (0)
+
+extern void *_kc_kmemdup(const void *src, size_t len, unsigned gfp);
+#define kmemdup(src, len, gfp) _kc_kmemdup(src, len, gfp)
+#ifndef bool
+#define bool _Bool
+#define true 1
+#define false 0
+#endif
+#else /* 2.6.19 */
+#include <linux/aer.h>
+#include <linux/pci_hotplug.h>
+
+#define NEW_SKB_CSUM_HELP
+#endif /* < 2.6.19 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,20) )
+#if ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,5,28) )
+#undef INIT_WORK
+#define INIT_WORK(_work, _func) \
+do { \
+	INIT_LIST_HEAD(&(_work)->entry); \
+	(_work)->pending = 0; \
+	(_work)->func = (void (*)(void *))_func; \
+	(_work)->data = _work; \
+	init_timer(&(_work)->timer); \
+} while (0)
+#endif
+
+#ifndef PCI_VDEVICE
+#define PCI_VDEVICE(ven, dev)        \
+	PCI_VENDOR_ID_##ven, (dev),  \
+	PCI_ANY_ID, PCI_ANY_ID, 0, 0
+#endif
+
+#ifndef PCI_VENDOR_ID_INTEL
+#define PCI_VENDOR_ID_INTEL 0x8086
+#endif
+
+#ifndef round_jiffies
+#define round_jiffies(x) x
+#endif
+
+#define csum_offset csum
+
+#define HAVE_EARLY_VMALLOC_NODE
+#define dev_to_node(dev) -1
+#undef set_dev_node
+/* remove compiler warning with b=b, for unused variable */
+#define set_dev_node(a, b) do { (b) = (b); } while(0)
+
+#if (!(RHEL_RELEASE_CODE && \
+       (((RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(4,7)) && \
+         (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(5,0))) || \
+        (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(5,6)))) && \
+     !(SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(10,2,0)))
+typedef __u16 __bitwise __sum16;
+typedef __u32 __bitwise __wsum;
+#endif
+
+#if (!(RHEL_RELEASE_CODE && \
+       (((RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(4,7)) && \
+         (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(5,0))) || \
+        (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(5,4)))) && \
+     !(SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(10,2,0)))
+static inline __wsum csum_unfold(__sum16 n)
+{
+	return (__force __wsum)n;
+}
+#endif
+
+#else /* < 2.6.20 */
+#define HAVE_DEVICE_NUMA_NODE
+#endif /* < 2.6.20 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,21) )
+#define to_net_dev(class) container_of(class, struct net_device, class_dev)
+#define NETDEV_CLASS_DEV
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(5,5)))
+#define vlan_group_get_device(vg, id) (vg->vlan_devices[id])
+#define vlan_group_set_device(vg, id, dev)		\
+	do {						\
+		if (vg) vg->vlan_devices[id] = dev;	\
+	} while (0)
+#endif /* !(RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(5,5)) */
+#define pci_channel_offline(pdev) (pdev->error_state && \
+	pdev->error_state != pci_channel_io_normal)
+#define pci_request_selected_regions(pdev, bars, name) \
+        pci_request_regions(pdev, name)
+#define pci_release_selected_regions(pdev, bars) pci_release_regions(pdev);
+
+#ifndef __aligned
+#define __aligned(x)			__attribute__((aligned(x)))
+#endif
+
+extern struct pci_dev *_kc_netdev_to_pdev(struct net_device *netdev);
+#define netdev_to_dev(netdev)	\
+	pci_dev_to_dev(_kc_netdev_to_pdev(netdev))
+#define devm_kzalloc(dev, size, flags) kzalloc(size, flags)
+#define devm_kfree(dev, p) kfree(p)
+#else /* 2.6.21 */
+static inline struct device *netdev_to_dev(struct net_device *netdev)
+{
+	return &netdev->dev;
+}
+
+#endif /* < 2.6.21 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,22) )
+#define tcp_hdr(skb) (skb->h.th)
+#define tcp_hdrlen(skb) (skb->h.th->doff << 2)
+#define skb_transport_offset(skb) (skb->h.raw - skb->data)
+#define skb_transport_header(skb) (skb->h.raw)
+#define ipv6_hdr(skb) (skb->nh.ipv6h)
+#define ip_hdr(skb) (skb->nh.iph)
+#define skb_network_offset(skb) (skb->nh.raw - skb->data)
+#define skb_network_header(skb) (skb->nh.raw)
+#define skb_tail_pointer(skb) skb->tail
+#define skb_reset_tail_pointer(skb) \
+	do { \
+		skb->tail = skb->data; \
+	} while (0)
+#define skb_set_tail_pointer(skb, offset) \
+	do { \
+		skb->tail = skb->data + offset; \
+	} while (0)
+#define skb_copy_to_linear_data(skb, from, len) \
+				memcpy(skb->data, from, len)
+#define skb_copy_to_linear_data_offset(skb, offset, from, len) \
+				memcpy(skb->data + offset, from, len)
+#define skb_network_header_len(skb) (skb->h.raw - skb->nh.raw)
+#define pci_register_driver pci_module_init
+#define skb_mac_header(skb) skb->mac.raw
+
+#ifdef NETIF_F_MULTI_QUEUE
+#ifndef alloc_etherdev_mq
+#define alloc_etherdev_mq(_a, _b) alloc_etherdev(_a)
+#endif
+#endif /* NETIF_F_MULTI_QUEUE */
+
+#ifndef ETH_FCS_LEN
+#define ETH_FCS_LEN 4
+#endif
+#define cancel_work_sync(x) flush_scheduled_work()
+#ifndef udp_hdr
+#define udp_hdr _udp_hdr
+static inline struct udphdr *_udp_hdr(const struct sk_buff *skb)
+{
+	return (struct udphdr *)skb_transport_header(skb);
+}
+#endif
+
+#ifdef cpu_to_be16
+#undef cpu_to_be16
+#endif
+#define cpu_to_be16(x) __constant_htons(x)
+
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(5,1)))
+enum {
+	DUMP_PREFIX_NONE,
+	DUMP_PREFIX_ADDRESS,
+	DUMP_PREFIX_OFFSET
+};
+#endif /* !(RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(5,1)) */
+#ifndef hex_asc
+#define hex_asc(x)	"0123456789abcdef"[x]
+#endif
+#include <linux/ctype.h>
+extern void _kc_print_hex_dump(const char *level, const char *prefix_str,
+			       int prefix_type, int rowsize, int groupsize,
+			       const void *buf, size_t len, bool ascii);
+#define print_hex_dump(lvl, s, t, r, g, b, l, a) \
+		_kc_print_hex_dump(lvl, s, t, r, g, b, l, a)
+#ifndef ADVERTISED_2500baseX_Full
+#define ADVERTISED_2500baseX_Full (1 << 15)
+#endif
+#ifndef SUPPORTED_2500baseX_Full
+#define SUPPORTED_2500baseX_Full (1 << 15)
+#endif
+
+#ifndef ETH_P_PAUSE
+#define ETH_P_PAUSE 0x8808
+#endif
+
+static inline int compound_order(struct page *page)
+{
+	return 0;
+}
+
+#ifndef SKB_WITH_OVERHEAD
+#define SKB_WITH_OVERHEAD(X) \
+	((X) - SKB_DATA_ALIGN(sizeof(struct skb_shared_info)))
+#endif
+#else /* 2.6.22 */
+#define ETH_TYPE_TRANS_SETS_DEV
+#define HAVE_NETDEV_STATS_IN_NETDEV
+#endif /* < 2.6.22 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE > KERNEL_VERSION(2,6,22) )
+#undef SET_MODULE_OWNER
+#define SET_MODULE_OWNER(dev) do { } while (0)
+#endif /* > 2.6.22 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,23) )
+#define netif_subqueue_stopped(_a, _b) 0
+#ifndef PTR_ALIGN
+#define PTR_ALIGN(p, a)         ((typeof(p))ALIGN((unsigned long)(p), (a)))
+#endif
+
+#ifndef CONFIG_PM_SLEEP
+#define CONFIG_PM_SLEEP	CONFIG_PM
+#endif
+
+#if ( LINUX_VERSION_CODE > KERNEL_VERSION(2,6,13) )
+#define HAVE_ETHTOOL_GET_PERM_ADDR
+#endif /* 2.6.14 through 2.6.22 */
+
+static inline int __kc_skb_cow_head(struct sk_buff *skb, unsigned int headroom)
+{
+	int delta = 0;
+
+	if (headroom > (skb->data - skb->head))
+		delta = headroom - (skb->data - skb->head);
+
+	if (delta || skb_header_cloned(skb))
+		return pskb_expand_head(skb, ALIGN(delta, NET_SKB_PAD), 0,
+					GFP_ATOMIC);
+	return 0;
+}
+#define skb_cow_head(s, h) __kc_skb_cow_head((s), (h))
+#endif /* < 2.6.23 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,24) )
+#ifndef ETH_FLAG_LRO
+#define ETH_FLAG_LRO NETIF_F_LRO
+#endif
+
+#ifndef ACCESS_ONCE
+#define ACCESS_ONCE(x) (*(volatile typeof(x) *)&(x))
+#endif
+
+/* if GRO is supported then the napi struct must already exist */
+#ifndef NETIF_F_GRO
+/* NAPI API changes in 2.6.24 break everything */
+struct napi_struct {
+	/* used to look up the real NAPI polling routine */
+	int (*poll)(struct napi_struct *, int);
+	struct net_device *dev;
+	int weight;
+};
+#endif
+
+#ifdef NAPI
+extern int __kc_adapter_clean(struct net_device *, int *);
+/* The following definitions are multi-queue aware, and thus we have a driver
+ * define list which determines which drivers support multiple queues, and
+ * thus need these stronger defines. If a driver does not support multi-queue
+ * functionality, you don't need to add it to this list.
+ */
+extern struct net_device *napi_to_poll_dev(const struct napi_struct *napi);
+
+static inline void __kc_mq_netif_napi_add(struct net_device *dev, struct napi_struct *napi,
+					  int (*poll)(struct napi_struct *, int), int weight)
+{
+	struct net_device *poll_dev = napi_to_poll_dev(napi);
+	poll_dev->poll = __kc_adapter_clean;
+	poll_dev->priv = napi;
+	poll_dev->weight = weight;
+	set_bit(__LINK_STATE_RX_SCHED, &poll_dev->state);
+	set_bit(__LINK_STATE_START, &poll_dev->state);
+	dev_hold(poll_dev);
+	napi->poll = poll;
+	napi->weight = weight;
+	napi->dev = dev;
+}
+#define netif_napi_add __kc_mq_netif_napi_add
+
+static inline void __kc_mq_netif_napi_del(struct napi_struct *napi)
+{
+	struct net_device *poll_dev = napi_to_poll_dev(napi);
+	WARN_ON(!test_bit(__LINK_STATE_RX_SCHED, &poll_dev->state));
+	dev_put(poll_dev);
+	memset(poll_dev, 0, sizeof(struct net_device));
+}
+
+#define netif_napi_del __kc_mq_netif_napi_del
+
+static inline bool __kc_mq_napi_schedule_prep(struct napi_struct *napi)
+{
+	return netif_running(napi->dev) &&
+		netif_rx_schedule_prep(napi_to_poll_dev(napi));
+}
+#define napi_schedule_prep __kc_mq_napi_schedule_prep
+
+static inline void __kc_mq_napi_schedule(struct napi_struct *napi)
+{
+	if (napi_schedule_prep(napi))
+		__netif_rx_schedule(napi_to_poll_dev(napi));
+}
+#define napi_schedule __kc_mq_napi_schedule
+
+#define napi_enable(_napi) netif_poll_enable(napi_to_poll_dev(_napi))
+#define napi_disable(_napi) netif_poll_disable(napi_to_poll_dev(_napi))
+#ifdef CONFIG_SMP
+static inline void napi_synchronize(const struct napi_struct *n)
+{
+	struct net_device *dev = napi_to_poll_dev(n);
+
+	while (test_bit(__LINK_STATE_RX_SCHED, &dev->state)) {
+		/* No hurry. */
+		msleep(1);
+	}
+}
+#else
+#define napi_synchronize(n)	barrier()
+#endif /* CONFIG_SMP */
+#define __napi_schedule(_napi) __netif_rx_schedule(napi_to_poll_dev(_napi))
+static inline void _kc_napi_complete(struct napi_struct *napi)
+{
+#ifdef NETIF_F_GRO
+	napi_gro_flush(napi);
+#endif
+	netif_rx_complete(napi_to_poll_dev(napi));
+}
+#define napi_complete _kc_napi_complete
+#else /* NAPI */
+
+/* The following definitions are only used if we don't support NAPI at all. */
+
+static inline __kc_netif_napi_add(struct net_device *dev, struct napi_struct *napi,
+				  int (*poll)(struct napi_struct *, int), int weight)
+{
+	dev->poll = poll;
+	dev->weight = weight;
+	napi->poll = poll;
+	napi->weight = weight;
+	napi->dev = dev;
+}
+#define netif_napi_del(_a) do {} while (0)
+#endif /* NAPI */
+
+#undef dev_get_by_name
+#define dev_get_by_name(_a, _b) dev_get_by_name(_b)
+#define __netif_subqueue_stopped(_a, _b) netif_subqueue_stopped(_a, _b)
+#ifndef DMA_BIT_MASK
+#define DMA_BIT_MASK(n)	(((n) == 64) ? DMA_64BIT_MASK : ((1ULL<<(n))-1))
+#endif
+
+#ifdef NETIF_F_TSO6
+#define skb_is_gso_v6 _kc_skb_is_gso_v6
+static inline int _kc_skb_is_gso_v6(const struct sk_buff *skb)
+{
+	return skb_shinfo(skb)->gso_type & SKB_GSO_TCPV6;
+}
+#endif /* NETIF_F_TSO6 */
+
+#ifndef KERN_CONT
+#define KERN_CONT	""
+#endif
+#ifndef pr_err
+#define pr_err(fmt, arg...) \
+	printk(KERN_ERR fmt, ##arg)
+#endif
+
+#ifndef rounddown_pow_of_two
+#define rounddown_pow_of_two(n) \
+	__builtin_constant_p(n) ? ( \
+		(n == 1) ? 0 : \
+		(1UL << ilog2(n))) : \
+		(1UL << (fls_long(n) - 1))
+#endif
+
+#ifndef BIT
+#define BIT(nr)         (1UL << (nr))
+#endif
+
+#else /* < 2.6.24 */
+#define HAVE_ETHTOOL_GET_SSET_COUNT
+#define HAVE_NETDEV_NAPI_LIST
+#endif /* < 2.6.24 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE > KERNEL_VERSION(2,6,24) )
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,2,0) )
+#define INCLUDE_PM_QOS_PARAMS_H
+#include <linux/pm_qos_params.h>
+#else /* >= 3.2.0 */
+#include <linux/pm_qos.h>
+#endif /* else >= 3.2.0 */
+#endif /* > 2.6.24 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,25) )
+#define PM_QOS_CPU_DMA_LATENCY	1
+
+#if ( LINUX_VERSION_CODE > KERNEL_VERSION(2,6,18) )
+#include <linux/latency.h>
+#define PM_QOS_DEFAULT_VALUE	INFINITE_LATENCY
+#define pm_qos_add_requirement(pm_qos_class, name, value) \
+		set_acceptable_latency(name, value)
+#define pm_qos_remove_requirement(pm_qos_class, name) \
+		remove_acceptable_latency(name)
+#define pm_qos_update_requirement(pm_qos_class, name, value) \
+		modify_acceptable_latency(name, value)
+#else
+#define PM_QOS_DEFAULT_VALUE	-1
+#define pm_qos_add_requirement(pm_qos_class, name, value)
+#define pm_qos_remove_requirement(pm_qos_class, name)
+#define pm_qos_update_requirement(pm_qos_class, name, value) { \
+	if (value != PM_QOS_DEFAULT_VALUE) { \
+		printk(KERN_WARNING "%s: unable to set PM QoS requirement\n", \
+			pci_name(adapter->pdev)); \
+	} \
+}
+
+#endif /* > 2.6.18 */
+
+#define pci_enable_device_mem(pdev) pci_enable_device(pdev)
+
+#ifndef DEFINE_PCI_DEVICE_TABLE
+#define DEFINE_PCI_DEVICE_TABLE(_table) struct pci_device_id _table[]
+#endif /* DEFINE_PCI_DEVICE_TABLE */
+
+#ifndef strict_strtol
+#define strict_strtol(s, b, r) _kc_strict_strtol(s, b, r)
+static inline int _kc_strict_strtol(const char *buf, unsigned int base, long *res)
+{
+	/* adapted from strict_strtoul() in 2.6.25 */
+	char *tail;
+	long val;
+	size_t len;
+
+	*res = 0;
+	len = strlen(buf);
+	if (!len)
+		return -EINVAL;
+	val = simple_strtol(buf, &tail, base);
+	if (tail == buf)
+		return -EINVAL;
+	if ((*tail == '\0') ||
+	    ((len == (size_t)(tail - buf) + 1) && (*tail == '\n'))) {
+		*res = val;
+		return 0;
+	}
+
+	return -EINVAL;
+}
+#endif
+
+#if ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0) )
+#ifndef IXGBE_PROCFS
+#define IXGBE_PROCFS
+#endif /* IXGBE_PROCFS */
+#endif /* >= 2.6.0 */
+
+#else /* < 2.6.25 */
+
+#ifndef IXGBE_SYSFS
+#define IXGBE_SYSFS
+#endif /* IXGBE_SYSFS */
+#if IS_ENABLED(CONFIG_HWMON)
+#ifndef IXGBE_HWMON
+#define IXGBE_HWMON
+#endif /* IXGBE_HWMON */
+#endif /* CONFIG_HWMON */
+
+#endif /* < 2.6.25 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,26) )
+#ifndef clamp_t
+#define clamp_t(type, val, min, max) ({		\
+	type __val = (val);			\
+	type __min = (min);			\
+	type __max = (max);			\
+	__val = __val < __min ? __min : __val;	\
+	__val > __max ? __max : __val; })
+#endif /* clamp_t */
+#undef kzalloc_node
+#define kzalloc_node(_size, _flags, _node) kzalloc(_size, _flags)
+
+extern void _kc_pci_disable_link_state(struct pci_dev *dev, int state);
+#define pci_disable_link_state(p, s) _kc_pci_disable_link_state(p, s)
+#else /* < 2.6.26 */
+#define NETDEV_CAN_SET_GSO_MAX_SIZE
+#include <linux/pci-aspm.h>
+#define HAVE_NETDEV_VLAN_FEATURES
+#ifndef PCI_EXP_LNKCAP_ASPMS
+#define PCI_EXP_LNKCAP_ASPMS 0x00000c00 /* ASPM Support */
+#endif /* PCI_EXP_LNKCAP_ASPMS */
+#endif /* < 2.6.26 */
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,27) )
+static inline void _kc_ethtool_cmd_speed_set(struct ethtool_cmd *ep,
+					     __u32 speed)
+{
+	ep->speed = (__u16)speed;
+	/* ep->speed_hi = (__u16)(speed >> 16); */
+}
+#define ethtool_cmd_speed_set _kc_ethtool_cmd_speed_set
+
+static inline __u32 _kc_ethtool_cmd_speed(struct ethtool_cmd *ep)
+{
+	/* no speed_hi before 2.6.27, and probably no need for it yet */
+	return (__u32)ep->speed;
+}
+#define ethtool_cmd_speed _kc_ethtool_cmd_speed
+
+#if ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,15) )
+#if ((LINUX_VERSION_CODE < KERNEL_VERSION(2,6,23)) && defined(CONFIG_PM))
+#define ANCIENT_PM 1
+#elif ((LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,23)) && \
+       (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,26)) && \
+       defined(CONFIG_PM_SLEEP))
+#define NEWER_PM 1
+#endif
+#if defined(ANCIENT_PM) || defined(NEWER_PM)
+#undef device_set_wakeup_enable
+#define device_set_wakeup_enable(dev, val) \
+	do { \
+		u16 pmc = 0; \
+		int pm = pci_find_capability(adapter->pdev, PCI_CAP_ID_PM); \
+		if (pm) { \
+			pci_read_config_word(adapter->pdev, pm + PCI_PM_PMC, \
+				&pmc); \
+		} \
+		(dev)->power.can_wakeup = !!(pmc >> 11); \
+		(dev)->power.should_wakeup = (val && (pmc >> 11)); \
+	} while (0)
+#endif /* 2.6.15-2.6.22 and CONFIG_PM or 2.6.23-2.6.25 and CONFIG_PM_SLEEP */
+#endif /* 2.6.15 through 2.6.27 */
+#ifndef netif_napi_del
+#define netif_napi_del(_a) do {} while (0)
+#ifdef NAPI
+#ifdef CONFIG_NETPOLL
+#undef netif_napi_del
+#define netif_napi_del(_a) list_del(&(_a)->dev_list);
+#endif
+#endif
+#endif /* netif_napi_del */
+#ifdef dma_mapping_error
+#undef dma_mapping_error
+#endif
+#define dma_mapping_error(dev, dma_addr) pci_dma_mapping_error(dma_addr)
+
+#ifdef CONFIG_NETDEVICES_MULTIQUEUE
+#define HAVE_TX_MQ
+#endif
+
+#ifndef DMA_ATTR_WEAK_ORDERING
+#define DMA_ATTR_WEAK_ORDERING 0
+#endif
+
+#ifdef HAVE_TX_MQ
+extern void _kc_netif_tx_stop_all_queues(struct net_device *);
+extern void _kc_netif_tx_wake_all_queues(struct net_device *);
+extern void _kc_netif_tx_start_all_queues(struct net_device *);
+#define netif_tx_stop_all_queues(a) _kc_netif_tx_stop_all_queues(a)
+#define netif_tx_wake_all_queues(a) _kc_netif_tx_wake_all_queues(a)
+#define netif_tx_start_all_queues(a) _kc_netif_tx_start_all_queues(a)
+#undef netif_stop_subqueue
+#define netif_stop_subqueue(_ndev,_qi) do { \
+	if (netif_is_multiqueue((_ndev))) \
+		netif_stop_subqueue((_ndev), (_qi)); \
+	else \
+		netif_stop_queue((_ndev)); \
+	} while (0)
+#undef netif_start_subqueue
+#define netif_start_subqueue(_ndev,_qi) do { \
+	if (netif_is_multiqueue((_ndev))) \
+		netif_start_subqueue((_ndev), (_qi)); \
+	else \
+		netif_start_queue((_ndev)); \
+	} while (0)
+#else /* HAVE_TX_MQ */
+#define netif_tx_stop_all_queues(a) netif_stop_queue(a)
+#define netif_tx_wake_all_queues(a) netif_wake_queue(a)
+#if ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,12) )
+#define netif_tx_start_all_queues(a) netif_start_queue(a)
+#else
+#define netif_tx_start_all_queues(a) do {} while (0)
+#endif
+#define netif_stop_subqueue(_ndev,_qi) netif_stop_queue((_ndev))
+#define netif_start_subqueue(_ndev,_qi) netif_start_queue((_ndev))
+#endif /* HAVE_TX_MQ */
+#ifndef NETIF_F_MULTI_QUEUE
+#define NETIF_F_MULTI_QUEUE 0
+#define netif_is_multiqueue(a) 0
+#define netif_wake_subqueue(a, b)
+#endif /* NETIF_F_MULTI_QUEUE */
+
+#ifndef __WARN_printf
+extern void __kc_warn_slowpath(const char *file, const int line,
+		const char *fmt, ...) __attribute__((format(printf, 3, 4)));
+#define __WARN_printf(arg...) __kc_warn_slowpath(__FILE__, __LINE__, arg)
+#endif /* __WARN_printf */
+
+#ifndef WARN
+#define WARN(condition, format...) ({						\
+	int __ret_warn_on = !!(condition);				\
+	if (unlikely(__ret_warn_on))					\
+		__WARN_printf(format);					\
+	unlikely(__ret_warn_on);					\
+})
+#endif /* WARN */
+#undef HAVE_IXGBE_DEBUG_FS
+#undef HAVE_IGB_DEBUG_FS
+#else /* < 2.6.27 */
+#define ethtool_cmd_speed_set _kc_ethtool_cmd_speed_set
+static inline void _kc_ethtool_cmd_speed_set(struct ethtool_cmd *ep,
+					     __u32 speed)
+{
+	ep->speed = (__u16)(speed & 0xFFFF);
+	ep->speed_hi = (__u16)(speed >> 16);
+}
+#define HAVE_TX_MQ
+#define HAVE_NETDEV_SELECT_QUEUE
+#ifdef CONFIG_DEBUG_FS
+#define HAVE_IXGBE_DEBUG_FS
+#define HAVE_IGB_DEBUG_FS
+#endif /* CONFIG_DEBUG_FS */
+#endif /* < 2.6.27 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,28) )
+#define pci_ioremap_bar(pdev, bar)	ioremap(pci_resource_start(pdev, bar), \
+					        pci_resource_len(pdev, bar))
+#define pci_wake_from_d3 _kc_pci_wake_from_d3
+#define pci_prepare_to_sleep _kc_pci_prepare_to_sleep
+extern int _kc_pci_wake_from_d3(struct pci_dev *dev, bool enable);
+extern int _kc_pci_prepare_to_sleep(struct pci_dev *dev);
+#define netdev_alloc_page(a) alloc_page(GFP_ATOMIC)
+#ifndef __skb_queue_head_init
+static inline void __kc_skb_queue_head_init(struct sk_buff_head *list)
+{
+	list->prev = list->next = (struct sk_buff *)list;
+	list->qlen = 0;
+}
+#define __skb_queue_head_init(_q) __kc_skb_queue_head_init(_q)
+#endif
+
+#define PCI_EXP_DEVCAP2		36	/* Device Capabilities 2 */
+#define PCI_EXP_DEVCTL2		40	/* Device Control 2 */
+
+#define PCI_EXP_DEVCAP_FLR	0x10000000 /* Function Level Reset */
+#define PCI_EXP_DEVCTL_BCR_FLR	0x8000 /* Bridge Configuration Retry / FLR */
+
+#endif /* < 2.6.28 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,29) )
+#ifndef swap
+#define swap(a, b) \
+	do { typeof(a) __tmp = (a); (a) = (b); (b) = __tmp; } while (0)
+#endif
+#define pci_request_selected_regions_exclusive(pdev, bars, name) \
+		pci_request_selected_regions(pdev, bars, name)
+#ifndef CONFIG_NR_CPUS
+#define CONFIG_NR_CPUS 1
+#endif /* CONFIG_NR_CPUS */
+#ifndef pcie_aspm_enabled
+#define pcie_aspm_enabled()   (1)
+#endif /* pcie_aspm_enabled */
+
+#define  PCI_EXP_SLTSTA_PDS	0x0040	/* Presence Detect State */
+
+#ifndef PCI_EXP_LNKSTA_CLS
+#define  PCI_EXP_LNKSTA_CLS    0x000f  /* Current Link Speed */
+#endif
+#ifndef PCI_EXP_LNKSTA_NLW
+#define  PCI_EXP_LNKSTA_NLW    0x03f0  /* Negotiated Link Width */
+#endif
+
+#ifndef pci_clear_master
+extern void _kc_pci_clear_master(struct pci_dev *dev);
+#define pci_clear_master(dev)	_kc_pci_clear_master(dev)
+#endif
+
+#ifndef PCI_EXP_LNKCTL_ASPMC
+#define  PCI_EXP_LNKCTL_ASPMC	0x0003	/* ASPM Control */
+#endif
+#else /* < 2.6.29 */
+#ifndef HAVE_NET_DEVICE_OPS
+#define HAVE_NET_DEVICE_OPS
+#endif
+#ifdef CONFIG_DCB
+#define HAVE_PFC_MODE_ENABLE
+#endif /* CONFIG_DCB */
+#endif /* < 2.6.29 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,30) )
+#define NO_PTP_SUPPORT
+#define skb_rx_queue_recorded(a) false
+#define skb_get_rx_queue(a) 0
+#define skb_record_rx_queue(a, b) do {} while (0)
+#define skb_tx_hash(n, s) ___kc_skb_tx_hash((n), (s), (n)->real_num_tx_queues)
+#undef CONFIG_FCOE
+#undef CONFIG_FCOE_MODULE
+#ifndef CONFIG_PCI_IOV
+#undef pci_enable_sriov
+#define pci_enable_sriov(a, b) -ENOTSUPP
+#undef pci_disable_sriov
+#define pci_disable_sriov(a) do {} while (0)
+#endif /* CONFIG_PCI_IOV */
+#ifndef pr_cont
+#define pr_cont(fmt, ...) \
+	printk(KERN_CONT fmt, ##__VA_ARGS__)
+#endif /* pr_cont */
+static inline void _kc_synchronize_irq(unsigned int a)
+{
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,5,28) )
+	synchronize_irq();
+#else /* < 2.5.28 */
+	synchronize_irq(a);
+#endif /* < 2.5.28 */
+}
+#undef synchronize_irq
+#define synchronize_irq(a) _kc_synchronize_irq(a)
+
+#define PCI_EXP_LNKCTL2		48	/* Link Control 2 */
+
+#ifdef nr_cpus_node
+#undef nr_cpus_node
+#define nr_cpus_node(node) cpumask_weight(cpumask_of_node(node))
+#endif
+
+#else /* < 2.6.30 */
+#define HAVE_ASPM_QUIRKS
+#endif /* < 2.6.30 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,31) )
+#define ETH_P_1588 0x88F7
+#define ETH_P_FIP  0x8914
+#ifndef netdev_uc_count
+#define netdev_uc_count(dev) ((dev)->uc_count)
+#endif
+#ifndef netdev_for_each_uc_addr
+#define netdev_for_each_uc_addr(uclist, dev) \
+	for (uclist = dev->uc_list; uclist; uclist = uclist->next)
+#endif
+#ifndef PORT_OTHER
+#define PORT_OTHER 0xff
+#endif
+#ifndef MDIO_PHY_ID_PRTAD
+#define MDIO_PHY_ID_PRTAD 0x03e0
+#endif
+#ifndef MDIO_PHY_ID_DEVAD
+#define MDIO_PHY_ID_DEVAD 0x001f
+#endif
+#ifndef skb_dst
+#define skb_dst(s) ((s)->dst)
+#endif
+
+#ifndef SUPPORTED_1000baseKX_Full
+#define SUPPORTED_1000baseKX_Full	(1 << 17)
+#endif
+#ifndef SUPPORTED_10000baseKX4_Full
+#define SUPPORTED_10000baseKX4_Full	(1 << 18)
+#endif
+#ifndef SUPPORTED_10000baseKR_Full
+#define SUPPORTED_10000baseKR_Full	(1 << 19)
+#endif
+
+#ifndef ADVERTISED_1000baseKX_Full
+#define ADVERTISED_1000baseKX_Full	(1 << 17)
+#endif
+#ifndef ADVERTISED_10000baseKX4_Full
+#define ADVERTISED_10000baseKX4_Full	(1 << 18)
+#endif
+#ifndef ADVERTISED_10000baseKR_Full
+#define ADVERTISED_10000baseKR_Full	(1 << 19)
+#endif
+
+static inline unsigned long dev_trans_start(struct net_device *dev)
+{
+	return dev->trans_start;
+}
+#else /* < 2.6.31 */
+#ifndef HAVE_NETDEV_STORAGE_ADDRESS
+#define HAVE_NETDEV_STORAGE_ADDRESS
+#endif
+#ifndef HAVE_NETDEV_HW_ADDR
+#define HAVE_NETDEV_HW_ADDR
+#endif
+#ifndef HAVE_TRANS_START_IN_QUEUE
+#define HAVE_TRANS_START_IN_QUEUE
+#endif
+#ifndef HAVE_INCLUDE_LINUX_MDIO_H
+#define HAVE_INCLUDE_LINUX_MDIO_H
+#endif
+#include <linux/mdio.h>
+#endif /* < 2.6.31 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,32) )
+#undef netdev_tx_t
+#define netdev_tx_t int
+#if defined(CONFIG_FCOE) || defined(CONFIG_FCOE_MODULE)
+#ifndef NETIF_F_FCOE_MTU
+#define NETIF_F_FCOE_MTU       (1 << 26)
+#endif
+#endif /* CONFIG_FCOE || CONFIG_FCOE_MODULE */
+
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0) )
+static inline int _kc_pm_runtime_get_sync()
+{
+	return 1;
+}
+#define pm_runtime_get_sync(dev)	_kc_pm_runtime_get_sync()
+#else /* 2.6.0 => 2.6.32 */
+static inline int _kc_pm_runtime_get_sync(struct device __always_unused *dev)
+{
+	return 1;
+}
+#ifndef pm_runtime_get_sync
+#define pm_runtime_get_sync(dev)	_kc_pm_runtime_get_sync(dev)
+#endif
+#endif /* 2.6.0 => 2.6.32 */
+#ifndef pm_runtime_put
+#define pm_runtime_put(dev)		do {} while (0)
+#endif
+#ifndef pm_runtime_put_sync
+#define pm_runtime_put_sync(dev)	do {} while (0)
+#endif
+#ifndef pm_runtime_resume
+#define pm_runtime_resume(dev)		do {} while (0)
+#endif
+#ifndef pm_schedule_suspend
+#define pm_schedule_suspend(dev, t)	do {} while (0)
+#endif
+#ifndef pm_runtime_set_suspended
+#define pm_runtime_set_suspended(dev)	do {} while (0)
+#endif
+#ifndef pm_runtime_disable
+#define pm_runtime_disable(dev)		do {} while (0)
+#endif
+#ifndef pm_runtime_put_noidle
+#define pm_runtime_put_noidle(dev)	do {} while (0)
+#endif
+#ifndef pm_runtime_set_active
+#define pm_runtime_set_active(dev)	do {} while (0)
+#endif
+#ifndef pm_runtime_enable
+#define pm_runtime_enable(dev)	do {} while (0)
+#endif
+#ifndef pm_runtime_get_noresume
+#define pm_runtime_get_noresume(dev)	do {} while (0)
+#endif
+#else /* < 2.6.32 */
+#if (RHEL_RELEASE_CODE && \
+     (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,2)) && \
+     (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(7,0)))
+#define HAVE_RHEL6_NET_DEVICE_EXTENDED
+#endif /* RHEL >= 6.2 && RHEL < 7.0 */
+#if (RHEL_RELEASE_CODE && \
+     (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,6)) && \
+     (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(7,0)))
+#define HAVE_RHEL6_NET_DEVICE_OPS_EXT
+#define HAVE_NDO_SET_FEATURES
+#endif /* RHEL >= 6.6 && RHEL < 7.0 */
+#if defined(CONFIG_FCOE) || defined(CONFIG_FCOE_MODULE)
+#ifndef HAVE_NETDEV_OPS_FCOE_ENABLE
+#define HAVE_NETDEV_OPS_FCOE_ENABLE
+#endif
+#endif /* CONFIG_FCOE || CONFIG_FCOE_MODULE */
+#ifdef CONFIG_DCB
+#ifndef HAVE_DCBNL_OPS_GETAPP
+#define HAVE_DCBNL_OPS_GETAPP
+#endif
+#endif /* CONFIG_DCB */
+#include <linux/pm_runtime.h>
+/* IOV bad DMA target work arounds require at least this kernel rev support */
+#define HAVE_PCIE_TYPE
+#endif /* < 2.6.32 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,33) )
+#ifndef pci_pcie_cap
+#define pci_pcie_cap(pdev) pci_find_capability(pdev, PCI_CAP_ID_EXP)
+#endif
+#ifndef IPV4_FLOW
+#define IPV4_FLOW 0x10
+#endif /* IPV4_FLOW */
+#ifndef IPV6_FLOW
+#define IPV6_FLOW 0x11
+#endif /* IPV6_FLOW */
+/* Features back-ported to RHEL6 or SLES11 SP1 after 2.6.32 */
+#if ( (RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,0)) || \
+      (SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(11,1,0)) )
+#if defined(CONFIG_FCOE) || defined(CONFIG_FCOE_MODULE)
+#ifndef HAVE_NETDEV_OPS_FCOE_GETWWN
+#define HAVE_NETDEV_OPS_FCOE_GETWWN
+#endif
+#endif /* CONFIG_FCOE || CONFIG_FCOE_MODULE */
+#endif /* RHEL6 or SLES11 SP1 */
+#ifndef __percpu
+#define __percpu
+#endif /* __percpu */
+
+#ifndef PORT_DA
+#define PORT_DA PORT_OTHER
+#endif /* PORT_DA */
+#ifndef PORT_NONE
+#define PORT_NONE PORT_OTHER
+#endif
+
+#if ((RHEL_RELEASE_CODE && \
+     (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,3)) && \
+     (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(7,0))))
+#if !defined(CONFIG_X86_32) && !defined(CONFIG_NEED_DMA_MAP_STATE)
+#undef DEFINE_DMA_UNMAP_ADDR
+#define DEFINE_DMA_UNMAP_ADDR(ADDR_NAME)	dma_addr_t ADDR_NAME
+#undef DEFINE_DMA_UNMAP_LEN
+#define DEFINE_DMA_UNMAP_LEN(LEN_NAME)		__u32 LEN_NAME
+#undef dma_unmap_addr
+#define dma_unmap_addr(PTR, ADDR_NAME)		((PTR)->ADDR_NAME)
+#undef dma_unmap_addr_set
+#define dma_unmap_addr_set(PTR, ADDR_NAME, VAL)	(((PTR)->ADDR_NAME) = (VAL))
+#undef dma_unmap_len
+#define dma_unmap_len(PTR, LEN_NAME)		((PTR)->LEN_NAME)
+#undef dma_unmap_len_set
+#define dma_unmap_len_set(PTR, LEN_NAME, VAL)	(((PTR)->LEN_NAME) = (VAL))
+#endif /* CONFIG_X86_64 && !CONFIG_NEED_DMA_MAP_STATE */
+#endif /* RHEL_RELEASE_CODE */
+
+#if (!(RHEL_RELEASE_CODE && \
+       (((RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(5,8)) && \
+         (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(6,0))) || \
+        ((RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,1)) && \
+         (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(7,0))))))
+static inline bool pci_is_pcie(struct pci_dev *dev)
+{
+	return !!pci_pcie_cap(dev);
+}
+#endif /* RHEL_RELEASE_CODE */
+
+#if (!(RHEL_RELEASE_CODE && \
+      (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,2))))
+#define sk_tx_queue_get(_sk) (-1)
+#define sk_tx_queue_set(_sk, _tx_queue) do {} while(0)
+#endif /* !(RHEL >= 6.2) */
+
+#if (RHEL_RELEASE_CODE && \
+     (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,4)) && \
+     (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(7,0)))
+#define HAVE_RHEL6_ETHTOOL_OPS_EXT_STRUCT
+#define HAVE_ETHTOOL_GRXFHINDIR_SIZE
+#define HAVE_ETHTOOL_SET_PHYS_ID
+#define HAVE_ETHTOOL_GET_TS_INFO
+#if (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(6,5))
+#define HAVE_ETHTOOL_GSRSSH
+#define HAVE_RHEL6_SRIOV_CONFIGURE
+#define HAVE_RXFH_NONCONST
+#endif /* RHEL > 6.5 */
+#endif /* RHEL >= 6.4 && RHEL < 7.0 */
+
+#else /* < 2.6.33 */
+#if defined(CONFIG_FCOE) || defined(CONFIG_FCOE_MODULE)
+#ifndef HAVE_NETDEV_OPS_FCOE_GETWWN
+#define HAVE_NETDEV_OPS_FCOE_GETWWN
+#endif
+#endif /* CONFIG_FCOE || CONFIG_FCOE_MODULE */
+#endif /* < 2.6.33 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,34) )
+#if (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(6,0))
+#ifndef pci_num_vf
+#define pci_num_vf(pdev) _kc_pci_num_vf(pdev)
+extern int _kc_pci_num_vf(struct pci_dev *dev);
+#endif
+#endif /* RHEL_RELEASE_CODE */
+
+#ifndef dev_is_pci
+#define dev_is_pci(d) ((d)->bus == &pci_bus_type)
+#endif
+
+#ifndef ETH_FLAG_NTUPLE
+#define ETH_FLAG_NTUPLE NETIF_F_NTUPLE
+#endif
+
+#ifndef netdev_mc_count
+#define netdev_mc_count(dev) ((dev)->mc_count)
+#endif
+#ifndef netdev_mc_empty
+#define netdev_mc_empty(dev) (netdev_mc_count(dev) == 0)
+#endif
+#ifndef netdev_for_each_mc_addr
+#define netdev_for_each_mc_addr(mclist, dev) \
+	for (mclist = dev->mc_list; mclist; mclist = mclist->next)
+#endif
+#ifndef netdev_uc_count
+#define netdev_uc_count(dev) ((dev)->uc.count)
+#endif
+#ifndef netdev_uc_empty
+#define netdev_uc_empty(dev) (netdev_uc_count(dev) == 0)
+#endif
+#ifndef netdev_for_each_uc_addr
+#define netdev_for_each_uc_addr(ha, dev) \
+	list_for_each_entry(ha, &dev->uc.list, list)
+#endif
+#ifndef dma_set_coherent_mask
+#define dma_set_coherent_mask(dev,mask) \
+	pci_set_consistent_dma_mask(to_pci_dev(dev),(mask))
+#endif
+#ifndef pci_dev_run_wake
+#define pci_dev_run_wake(pdev)	(0)
+#endif
+
+/* netdev logging taken from include/linux/netdevice.h */
+#ifndef netdev_name
+static inline const char *_kc_netdev_name(const struct net_device *dev)
+{
+	if (dev->reg_state != NETREG_REGISTERED)
+		return "(unregistered net_device)";
+	return dev->name;
+}
+#define netdev_name(netdev)	_kc_netdev_name(netdev)
+#endif /* netdev_name */
+
+#undef netdev_printk
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0) )
+#define netdev_printk(level, netdev, format, args...)		\
+do {								\
+	struct pci_dev *pdev = _kc_netdev_to_pdev(netdev);	\
+	printk(level "%s: " format, pci_name(pdev), ##args);	\
+} while(0)
+#elif ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,21) )
+#define netdev_printk(level, netdev, format, args...)		\
+do {								\
+	struct pci_dev *pdev = _kc_netdev_to_pdev(netdev);	\
+	struct device *dev = pci_dev_to_dev(pdev);		\
+	dev_printk(level, dev, "%s: " format,			\
+		   netdev_name(netdev), ##args);		\
+} while(0)
+#else /* 2.6.21 => 2.6.34 */
+#define netdev_printk(level, netdev, format, args...)		\
+	dev_printk(level, (netdev)->dev.parent,			\
+		   "%s: " format,				\
+		   netdev_name(netdev), ##args)
+#endif /* <2.6.0 <2.6.21 <2.6.34 */
+#undef netdev_emerg
+#define netdev_emerg(dev, format, args...)			\
+	netdev_printk(KERN_EMERG, dev, format, ##args)
+#undef netdev_alert
+#define netdev_alert(dev, format, args...)			\
+	netdev_printk(KERN_ALERT, dev, format, ##args)
+#undef netdev_crit
+#define netdev_crit(dev, format, args...)			\
+	netdev_printk(KERN_CRIT, dev, format, ##args)
+#undef netdev_err
+#define netdev_err(dev, format, args...)			\
+	netdev_printk(KERN_ERR, dev, format, ##args)
+#undef netdev_warn
+#define netdev_warn(dev, format, args...)			\
+	netdev_printk(KERN_WARNING, dev, format, ##args)
+#undef netdev_notice
+#define netdev_notice(dev, format, args...)			\
+	netdev_printk(KERN_NOTICE, dev, format, ##args)
+#undef netdev_info
+#define netdev_info(dev, format, args...)			\
+	netdev_printk(KERN_INFO, dev, format, ##args)
+#undef netdev_dbg
+#if defined(DEBUG)
+#define netdev_dbg(__dev, format, args...)			\
+	netdev_printk(KERN_DEBUG, __dev, format, ##args)
+#elif defined(CONFIG_DYNAMIC_DEBUG)
+#define netdev_dbg(__dev, format, args...)			\
+do {								\
+	dynamic_dev_dbg((__dev)->dev.parent, "%s: " format,	\
+			netdev_name(__dev), ##args);		\
+} while (0)
+#else /* DEBUG */
+#define netdev_dbg(__dev, format, args...)			\
+({								\
+	if (0)							\
+		netdev_printk(KERN_DEBUG, __dev, format, ##args); \
+	0;							\
+})
+#endif /* DEBUG */
+
+#undef netif_printk
+#define netif_printk(priv, type, level, dev, fmt, args...)	\
+do {								\
+	if (netif_msg_##type(priv))				\
+		netdev_printk(level, (dev), fmt, ##args);	\
+} while (0)
+
+#undef netif_emerg
+#define netif_emerg(priv, type, dev, fmt, args...)		\
+	netif_level(emerg, priv, type, dev, fmt, ##args)
+#undef netif_alert
+#define netif_alert(priv, type, dev, fmt, args...)		\
+	netif_level(alert, priv, type, dev, fmt, ##args)
+#undef netif_crit
+#define netif_crit(priv, type, dev, fmt, args...)		\
+	netif_level(crit, priv, type, dev, fmt, ##args)
+#undef netif_err
+#define netif_err(priv, type, dev, fmt, args...)		\
+	netif_level(err, priv, type, dev, fmt, ##args)
+#undef netif_warn
+#define netif_warn(priv, type, dev, fmt, args...)		\
+	netif_level(warn, priv, type, dev, fmt, ##args)
+#undef netif_notice
+#define netif_notice(priv, type, dev, fmt, args...)		\
+	netif_level(notice, priv, type, dev, fmt, ##args)
+#undef netif_info
+#define netif_info(priv, type, dev, fmt, args...)		\
+	netif_level(info, priv, type, dev, fmt, ##args)
+#undef netif_dbg
+#define netif_dbg(priv, type, dev, fmt, args...)		\
+	netif_level(dbg, priv, type, dev, fmt, ##args)
+
+#ifdef SET_SYSTEM_SLEEP_PM_OPS
+#define HAVE_SYSTEM_SLEEP_PM_OPS
+#endif
+
+#ifndef for_each_set_bit
+#define for_each_set_bit(bit, addr, size) \
+	for ((bit) = find_first_bit((addr), (size)); \
+		(bit) < (size); \
+		(bit) = find_next_bit((addr), (size), (bit) + 1))
+#endif /* for_each_set_bit */
+
+#ifndef DEFINE_DMA_UNMAP_ADDR
+#define DEFINE_DMA_UNMAP_ADDR DECLARE_PCI_UNMAP_ADDR
+#define DEFINE_DMA_UNMAP_LEN DECLARE_PCI_UNMAP_LEN
+#define dma_unmap_addr pci_unmap_addr
+#define dma_unmap_addr_set pci_unmap_addr_set
+#define dma_unmap_len pci_unmap_len
+#define dma_unmap_len_set pci_unmap_len_set
+#endif /* DEFINE_DMA_UNMAP_ADDR */
+
+#if (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(6,3))
+#ifdef IGB_HWMON
+#ifdef CONFIG_DEBUG_LOCK_ALLOC
+#define sysfs_attr_init(attr)				\
+	do {						\
+		static struct lock_class_key __key;	\
+		(attr)->key = &__key;			\
+	} while (0)
+#else
+#define sysfs_attr_init(attr) do {} while (0)
+#endif /* CONFIG_DEBUG_LOCK_ALLOC */
+#endif /* IGB_HWMON */
+#endif /* RHEL_RELEASE_CODE */
+
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0) )
+static inline bool _kc_pm_runtime_suspended()
+{
+	return false;
+}
+#define pm_runtime_suspended(dev)	_kc_pm_runtime_suspended()
+#else /* 2.6.0 => 2.6.34 */
+static inline bool _kc_pm_runtime_suspended(struct device __always_unused *dev)
+{
+	return false;
+}
+#ifndef pm_runtime_suspended
+#define pm_runtime_suspended(dev)	_kc_pm_runtime_suspended(dev)
+#endif
+#endif /* 2.6.0 => 2.6.34 */
+
+#ifndef pci_bus_speed
+/* override pci_bus_speed introduced in 2.6.19 with an expanded enum type */
+enum _kc_pci_bus_speed {
+	_KC_PCIE_SPEED_2_5GT		= 0x14,
+	_KC_PCIE_SPEED_5_0GT		= 0x15,
+	_KC_PCIE_SPEED_8_0GT		= 0x16,
+	_KC_PCI_SPEED_UNKNOWN		= 0xff,
+};
+#define pci_bus_speed		_kc_pci_bus_speed
+#define PCIE_SPEED_2_5GT	_KC_PCIE_SPEED_2_5GT
+#define PCIE_SPEED_5_0GT	_KC_PCIE_SPEED_5_0GT
+#define PCIE_SPEED_8_0GT	_KC_PCIE_SPEED_8_0GT
+#define PCI_SPEED_UNKNOWN	_KC_PCI_SPEED_UNKNOWN
+#endif /* pci_bus_speed */
+
+#else /* < 2.6.34 */
+#define HAVE_SYSTEM_SLEEP_PM_OPS
+#ifndef HAVE_SET_RX_MODE
+#define HAVE_SET_RX_MODE
+#endif
+
+#endif /* < 2.6.34 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,35) )
+ssize_t _kc_simple_write_to_buffer(void *to, size_t available, loff_t *ppos,
+				   const void __user *from, size_t count);
+#define simple_write_to_buffer _kc_simple_write_to_buffer
+
+#ifndef PCI_EXP_LNKSTA_NLW_SHIFT
+#define PCI_EXP_LNKSTA_NLW_SHIFT 4
+#endif
+
+#ifndef numa_node_id
+#define numa_node_id() 0
+#endif
+#ifndef numa_mem_id
+#define numa_mem_id numa_node_id
+#endif
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,0)))
+#ifdef HAVE_TX_MQ
+#include <net/sch_generic.h>
+#ifndef CONFIG_NETDEVICES_MULTIQUEUE
+int _kc_netif_set_real_num_tx_queues(struct net_device *, unsigned int);
+#else /* CONFIG_NETDEVICES_MULTI_QUEUE */
+static inline int _kc_netif_set_real_num_tx_queues(struct net_device *dev,
+						   unsigned int txq)
+{
+	dev->egress_subqueue_count = txq;
+	return 0;
+}
+#endif /* CONFIG_NETDEVICES_MULTI_QUEUE */
+#else /* HAVE_TX_MQ */
+static inline int _kc_netif_set_real_num_tx_queues(struct net_device __always_unused *dev,
+						   unsigned int __always_unused txq)
+{
+	return 0;
+}
+#endif /* HAVE_TX_MQ */
+#define netif_set_real_num_tx_queues(dev, txq) \
+	_kc_netif_set_real_num_tx_queues(dev, txq)
+#endif /* !(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,0)) */
+#ifndef ETH_FLAG_RXHASH
+#define ETH_FLAG_RXHASH (1<<28)
+#endif /* ETH_FLAG_RXHASH */
+#if (RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,0))
+#define HAVE_IRQ_AFFINITY_HINT
+#endif
+struct device_node;
+#else /* < 2.6.35 */
+#define HAVE_STRUCT_DEVICE_OF_NODE
+#define HAVE_PM_QOS_REQUEST_LIST
+#define HAVE_IRQ_AFFINITY_HINT
+#include <linux/of.h>
+#endif /* < 2.6.35 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,36) )
+extern int _kc_ethtool_op_set_flags(struct net_device *, u32, u32);
+#define ethtool_op_set_flags _kc_ethtool_op_set_flags
+extern u32 _kc_ethtool_op_get_flags(struct net_device *);
+#define ethtool_op_get_flags _kc_ethtool_op_get_flags
+
+enum {
+	WQ_UNBOUND = 0,
+	WQ_RESCUER = 0,
+};
+
+#ifdef CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS
+#ifdef NET_IP_ALIGN
+#undef NET_IP_ALIGN
+#endif
+#define NET_IP_ALIGN 0
+#endif /* CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS */
+
+#ifdef NET_SKB_PAD
+#undef NET_SKB_PAD
+#endif
+
+#if (L1_CACHE_BYTES > 32)
+#define NET_SKB_PAD L1_CACHE_BYTES
+#else
+#define NET_SKB_PAD 32
+#endif
+
+static inline struct sk_buff *_kc_netdev_alloc_skb_ip_align(struct net_device *dev,
+							    unsigned int length)
+{
+	struct sk_buff *skb;
+
+	skb = alloc_skb(length + NET_SKB_PAD + NET_IP_ALIGN, GFP_ATOMIC);
+	if (skb) {
+#if (NET_IP_ALIGN + NET_SKB_PAD)
+		skb_reserve(skb, NET_IP_ALIGN + NET_SKB_PAD);
+#endif
+		skb->dev = dev;
+	}
+	return skb;
+}
+
+#ifdef netdev_alloc_skb_ip_align
+#undef netdev_alloc_skb_ip_align
+#endif
+#define netdev_alloc_skb_ip_align(n, l) _kc_netdev_alloc_skb_ip_align(n, l)
+
+#undef netif_level
+#define netif_level(level, priv, type, dev, fmt, args...)	\
+do {								\
+	if (netif_msg_##type(priv))				\
+		netdev_##level(dev, fmt, ##args);		\
+} while (0)
+
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,3)))
+#undef usleep_range
+#define usleep_range(min, max)	msleep(DIV_ROUND_UP(min, 1000))
+#endif
+
+#define u64_stats_update_begin(a) do { } while(0)
+#define u64_stats_update_end(a) do { } while(0)
+#define u64_stats_fetch_begin(a) do { } while(0)
+#define u64_stats_fetch_retry_bh(a,b) (0)
+#define u64_stats_fetch_begin_bh(a) (0)
+
+#if (RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,1))
+#define HAVE_8021P_SUPPORT
+#endif
+
+/* RHEL6.4 and SLES11sp2 backported skb_tx_timestamp */
+#if (!(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,4)) && \
+     !(SLE_VERSION_CODE >= SLE_VERSION(11,2,0)))
+static inline void skb_tx_timestamp(struct sk_buff __always_unused *skb)
+{
+	return;
+}
+#endif
+
+#else /* < 2.6.36 */
+
+#define msleep(x)	do { if (x > 20)				\
+				msleep(x);				\
+			     else					\
+				usleep_range(1000 * x, 2000 * x);	\
+			} while (0)
+
+#define HAVE_PM_QOS_REQUEST_ACTIVE
+#define HAVE_8021P_SUPPORT
+#define HAVE_NDO_GET_STATS64
+#endif /* < 2.6.36 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,37) )
+#define HAVE_NON_CONST_PCI_DRIVER_NAME
+#ifndef netif_set_real_num_tx_queues
+static inline int _kc_netif_set_real_num_tx_queues(struct net_device *dev,
+						   unsigned int txq)
+{
+	netif_set_real_num_tx_queues(dev, txq);
+	return 0;
+}
+#define netif_set_real_num_tx_queues(dev, txq) \
+	_kc_netif_set_real_num_tx_queues(dev, txq)
+#endif
+#ifndef netif_set_real_num_rx_queues
+static inline int __kc_netif_set_real_num_rx_queues(struct net_device __always_unused *dev,
+						    unsigned int __always_unused rxq)
+{
+	return 0;
+}
+#define netif_set_real_num_rx_queues(dev, rxq) \
+	__kc_netif_set_real_num_rx_queues((dev), (rxq))
+#endif
+#ifndef ETHTOOL_RXNTUPLE_ACTION_CLEAR
+#define ETHTOOL_RXNTUPLE_ACTION_CLEAR (-2)
+#endif
+#ifndef VLAN_N_VID
+#define VLAN_N_VID	VLAN_GROUP_ARRAY_LEN
+#endif /* VLAN_N_VID */
+#ifndef ETH_FLAG_TXVLAN
+#define ETH_FLAG_TXVLAN (1 << 7)
+#endif /* ETH_FLAG_TXVLAN */
+#ifndef ETH_FLAG_RXVLAN
+#define ETH_FLAG_RXVLAN (1 << 8)
+#endif /* ETH_FLAG_RXVLAN */
+
+#define WQ_MEM_RECLAIM WQ_RESCUER
+
+static inline void _kc_skb_checksum_none_assert(struct sk_buff *skb)
+{
+	WARN_ON(skb->ip_summed != CHECKSUM_NONE);
+}
+#define skb_checksum_none_assert(skb) _kc_skb_checksum_none_assert(skb)
+
+static inline void *_kc_vzalloc_node(unsigned long size, int node)
+{
+	void *addr = vmalloc_node(size, node);
+	if (addr)
+		memset(addr, 0, size);
+	return addr;
+}
+#define vzalloc_node(_size, _node) _kc_vzalloc_node(_size, _node)
+
+static inline void *_kc_vzalloc(unsigned long size)
+{
+	void *addr = vmalloc(size);
+	if (addr)
+		memset(addr, 0, size);
+	return addr;
+}
+#define vzalloc(_size) _kc_vzalloc(_size)
+
+#if (!(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(5,7)) || \
+     (RHEL_RELEASE_CODE == RHEL_RELEASE_VERSION(6,0)))
+static inline __be16 vlan_get_protocol(const struct sk_buff *skb)
+{
+	if (vlan_tx_tag_present(skb) ||
+	    skb->protocol != cpu_to_be16(ETH_P_8021Q))
+		return skb->protocol;
+
+	if (skb_headlen(skb) < sizeof(struct vlan_ethhdr))
+		return 0;
+
+	return ((struct vlan_ethhdr*)skb->data)->h_vlan_encapsulated_proto;
+}
+#endif /* !RHEL5.7+ || RHEL6.0 */
+
+#ifdef HAVE_HW_TIME_STAMP
+#define SKBTX_HW_TSTAMP (1 << 0)
+#define SKBTX_IN_PROGRESS (1 << 2)
+#define SKB_SHARED_TX_IS_UNION
+#endif
+
+#ifndef device_wakeup_enable
+#define device_wakeup_enable(dev)	device_set_wakeup_enable(dev, true)
+#endif
+
+#if ( LINUX_VERSION_CODE > KERNEL_VERSION(2,4,18) )
+#ifndef HAVE_VLAN_RX_REGISTER
+#define HAVE_VLAN_RX_REGISTER
+#endif
+#endif /* > 2.4.18 */
+#endif /* < 2.6.37 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,38) )
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,22) )
+#define skb_checksum_start_offset(skb) skb_transport_offset(skb)
+#else /* 2.6.22 -> 2.6.37 */
+static inline int _kc_skb_checksum_start_offset(const struct sk_buff *skb)
+{
+        return skb->csum_start - skb_headroom(skb);
+}
+#define skb_checksum_start_offset(skb) _kc_skb_checksum_start_offset(skb)
+#endif /* 2.6.22 -> 2.6.37 */
+#if IS_ENABLED(CONFIG_DCB)
+#ifndef IEEE_8021QAZ_MAX_TCS
+#define IEEE_8021QAZ_MAX_TCS 8
+#endif
+#ifndef DCB_CAP_DCBX_HOST
+#define DCB_CAP_DCBX_HOST		0x01
+#endif
+#ifndef DCB_CAP_DCBX_LLD_MANAGED
+#define DCB_CAP_DCBX_LLD_MANAGED	0x02
+#endif
+#ifndef DCB_CAP_DCBX_VER_CEE
+#define DCB_CAP_DCBX_VER_CEE		0x04
+#endif
+#ifndef DCB_CAP_DCBX_VER_IEEE
+#define DCB_CAP_DCBX_VER_IEEE		0x08
+#endif
+#ifndef DCB_CAP_DCBX_STATIC
+#define DCB_CAP_DCBX_STATIC		0x10
+#endif
+#endif /* CONFIG_DCB */
+#if (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,2))
+#define CONFIG_XPS
+#endif /* RHEL_RELEASE_VERSION(6,2) */
+#endif /* < 2.6.38 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,39) )
+#ifndef TC_BITMASK
+#define TC_BITMASK 15
+#endif
+#ifndef NETIF_F_RXCSUM
+#define NETIF_F_RXCSUM		(1 << 29)
+#endif
+#ifndef skb_queue_reverse_walk_safe
+#define skb_queue_reverse_walk_safe(queue, skb, tmp)				\
+		for (skb = (queue)->prev, tmp = skb->prev;			\
+		     skb != (struct sk_buff *)(queue);				\
+		     skb = tmp, tmp = skb->prev)
+#endif
+#if defined(CONFIG_FCOE) || defined(CONFIG_FCOE_MODULE)
+#ifndef FCOE_MTU
+#define FCOE_MTU	2158
+#endif
+#endif
+#if IS_ENABLED(CONFIG_DCB)
+#ifndef IEEE_8021QAZ_APP_SEL_ETHERTYPE
+#define IEEE_8021QAZ_APP_SEL_ETHERTYPE	1
+#endif
+#endif
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,4)))
+#define kstrtoul(a, b, c)  ((*(c)) = simple_strtoul((a), NULL, (b)), 0)
+#define kstrtouint(a, b, c)  ((*(c)) = simple_strtoul((a), NULL, (b)), 0)
+#define kstrtou32(a, b, c)  ((*(c)) = simple_strtoul((a), NULL, (b)), 0)
+#endif /* !(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,4)) */
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(6,0)))
+extern u16 ___kc_skb_tx_hash(struct net_device *, const struct sk_buff *, u16);
+#define __skb_tx_hash(n, s, q) ___kc_skb_tx_hash((n), (s), (q))
+extern u8 _kc_netdev_get_num_tc(struct net_device *dev);
+#define netdev_get_num_tc(dev) _kc_netdev_get_num_tc(dev)
+extern int _kc_netdev_set_num_tc(struct net_device *dev, u8 num_tc);
+#define netdev_set_num_tc(dev, tc) _kc_netdev_set_num_tc((dev), (tc))
+#define netdev_reset_tc(dev) _kc_netdev_set_num_tc((dev), 0)
+#define netdev_set_tc_queue(dev, tc, cnt, off) do {} while (0)
+extern u8 _kc_netdev_get_prio_tc_map(struct net_device *dev, u8 up);
+#define netdev_get_prio_tc_map(dev, up) _kc_netdev_get_prio_tc_map(dev, up)
+#define netdev_set_prio_tc_map(dev, up, tc) do {} while (0)
+#else /* RHEL6.1 or greater */
+#ifndef HAVE_MQPRIO
+#define HAVE_MQPRIO
+#endif /* HAVE_MQPRIO */
+#if IS_ENABLED(CONFIG_DCB)
+#ifndef HAVE_DCBNL_IEEE
+#define HAVE_DCBNL_IEEE
+#ifndef IEEE_8021QAZ_TSA_STRICT
+#define IEEE_8021QAZ_TSA_STRICT		0
+#endif
+#ifndef IEEE_8021QAZ_TSA_ETS
+#define IEEE_8021QAZ_TSA_ETS		2
+#endif
+#ifndef IEEE_8021QAZ_APP_SEL_ETHERTYPE
+#define IEEE_8021QAZ_APP_SEL_ETHERTYPE	1
+#endif
+#endif
+#endif /* CONFIG_DCB */
+#endif /* !(RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(6,0)) */
+
+#ifndef udp_csum
+#define udp_csum __kc_udp_csum
+static inline __wsum __kc_udp_csum(struct sk_buff *skb)
+{
+	__wsum csum = csum_partial(skb_transport_header(skb),
+				   sizeof(struct udphdr), skb->csum);
+
+	for (skb = skb_shinfo(skb)->frag_list; skb; skb = skb->next) {
+		csum = csum_add(csum, skb->csum);
+	}
+	return csum;
+}
+#endif /* udp_csum */
+#else /* < 2.6.39 */
+#if defined(CONFIG_FCOE) || defined(CONFIG_FCOE_MODULE)
+#ifndef HAVE_NETDEV_OPS_FCOE_DDP_TARGET
+#define HAVE_NETDEV_OPS_FCOE_DDP_TARGET
+#endif
+#endif /* CONFIG_FCOE || CONFIG_FCOE_MODULE */
+#ifndef HAVE_MQPRIO
+#define HAVE_MQPRIO
+#endif
+#ifndef HAVE_SETUP_TC
+#define HAVE_SETUP_TC
+#endif
+#ifdef CONFIG_DCB
+#ifndef HAVE_DCBNL_IEEE
+#define HAVE_DCBNL_IEEE
+#endif
+#endif /* CONFIG_DCB */
+#ifndef HAVE_NDO_SET_FEATURES
+#define HAVE_NDO_SET_FEATURES
+#endif
+#define HAVE_IRQ_AFFINITY_NOTIFY
+#endif /* < 2.6.39 */
+
+/*****************************************************************************/
+/* use < 2.6.40 because of a Fedora 15 kernel update where they
+ * updated the kernel version to 2.6.40.x and they back-ported 3.0 features
+ * like set_phys_id for ethtool.
+ */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,40) )
+#ifdef ETHTOOL_GRXRINGS
+#ifndef FLOW_EXT
+#define	FLOW_EXT	0x80000000
+union _kc_ethtool_flow_union {
+	struct ethtool_tcpip4_spec		tcp_ip4_spec;
+	struct ethtool_usrip4_spec		usr_ip4_spec;
+	__u8					hdata[60];
+};
+struct _kc_ethtool_flow_ext {
+	__be16	vlan_etype;
+	__be16	vlan_tci;
+	__be32	data[2];
+};
+struct _kc_ethtool_rx_flow_spec {
+	__u32		flow_type;
+	union _kc_ethtool_flow_union h_u;
+	struct _kc_ethtool_flow_ext h_ext;
+	union _kc_ethtool_flow_union m_u;
+	struct _kc_ethtool_flow_ext m_ext;
+	__u64		ring_cookie;
+	__u32		location;
+};
+#define ethtool_rx_flow_spec _kc_ethtool_rx_flow_spec
+#endif /* FLOW_EXT */
+#endif
+
+#define pci_disable_link_state_locked pci_disable_link_state
+
+#ifndef PCI_LTR_VALUE_MASK
+#define  PCI_LTR_VALUE_MASK	0x000003ff
+#endif
+#ifndef PCI_LTR_SCALE_MASK
+#define  PCI_LTR_SCALE_MASK	0x00001c00
+#endif
+#ifndef PCI_LTR_SCALE_SHIFT
+#define  PCI_LTR_SCALE_SHIFT	10
+#endif
+
+#else /* < 2.6.40 */
+#define HAVE_ETHTOOL_SET_PHYS_ID
+#endif /* < 2.6.40 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,0,0) )
+#define USE_LEGACY_PM_SUPPORT
+#ifndef kfree_rcu
+#define kfree_rcu(_ptr, _rcu_head) kfree(_ptr)
+#endif /* kfree_rcu */
+#ifndef kstrtol_from_user
+#define kstrtol_from_user(s, c, b, r) _kc_kstrtol_from_user(s, c, b, r)
+static inline int _kc_kstrtol_from_user(const char __user *s, size_t count,
+					unsigned int base, long *res)
+{
+	/* sign, base 2 representation, newline, terminator */
+	char buf[1 + sizeof(long) * 8 + 1 + 1];
+
+	count = min(count, sizeof(buf) - 1);
+	if (copy_from_user(buf, s, count))
+		return -EFAULT;
+	buf[count] = '\0';
+	return strict_strtol(buf, base, res);
+}
+#endif
+
+/* 20000base_blah_full Supported and Advertised Registers */
+#define SUPPORTED_20000baseMLD2_Full	(1 << 21)
+#define SUPPORTED_20000baseKR2_Full	(1 << 22)
+#define ADVERTISED_20000baseMLD2_Full	(1 << 21)
+#define ADVERTISED_20000baseKR2_Full	(1 << 22)
+#endif /* < 3.0.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,1,0) )
+#ifndef __netdev_alloc_skb_ip_align
+#define __netdev_alloc_skb_ip_align(d,l,_g) netdev_alloc_skb_ip_align(d,l)
+#endif /* __netdev_alloc_skb_ip_align */
+#define dcb_ieee_setapp(dev, app) dcb_setapp(dev, app)
+#define dcb_ieee_delapp(dev, app) 0
+#define dcb_ieee_getapp_mask(dev, app) (1 << app->priority)
+
+/* 1000BASE-T Control register */
+#define CTL1000_AS_MASTER	0x0800
+#define CTL1000_ENABLE_MASTER	0x1000
+
+/* kernels less than 3.0.0 don't have this */
+#ifndef ETH_P_8021AD
+#define ETH_P_8021AD	0x88A8
+#endif
+
+/* Stub definition for !CONFIG_OF is introduced later */
+#ifdef CONFIG_OF
+static inline struct device_node *
+pci_device_to_OF_node(struct pci_dev __maybe_unused *pdev)
+{
+#ifdef HAVE_STRUCT_DEVICE_OF_NODE
+	return pdev ? pdev->dev.of_node : NULL;
+#else
+	return NULL;
+#endif /* !HAVE_STRUCT_DEVICE_OF_NODE */
+}
+#endif /* CONFIG_OF */
+#else /* < 3.1.0 */
+#ifndef HAVE_DCBNL_IEEE_DELAPP
+#define HAVE_DCBNL_IEEE_DELAPP
+#endif
+#endif /* < 3.1.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,2,0) )
+#ifndef dma_zalloc_coherent
+#define dma_zalloc_coherent(d, s, h, f) _kc_dma_zalloc_coherent(d, s, h, f)
+static inline void *_kc_dma_zalloc_coherent(struct device *dev, size_t size,
+					    dma_addr_t *dma_handle, gfp_t flag)
+{
+	void *ret = dma_alloc_coherent(dev, size, dma_handle, flag);
+	if (ret)
+		memset(ret, 0, size);
+	return ret;
+}
+#endif
+#ifdef ETHTOOL_GRXRINGS
+#define HAVE_ETHTOOL_GET_RXNFC_VOID_RULE_LOCS
+#endif /* ETHTOOL_GRXRINGS */
+
+#ifndef skb_frag_size
+#define skb_frag_size(frag)	_kc_skb_frag_size(frag)
+static inline unsigned int _kc_skb_frag_size(const skb_frag_t *frag)
+{
+	return frag->size;
+}
+#endif /* skb_frag_size */
+
+#ifndef skb_frag_size_sub
+#define skb_frag_size_sub(frag, delta)	_kc_skb_frag_size_sub(frag, delta)
+static inline void _kc_skb_frag_size_sub(skb_frag_t *frag, int delta)
+{
+	frag->size -= delta;
+}
+#endif /* skb_frag_size_sub */
+
+#ifndef skb_frag_page
+#define skb_frag_page(frag)	_kc_skb_frag_page(frag)
+static inline struct page *_kc_skb_frag_page(const skb_frag_t *frag)
+{
+	return frag->page;
+}
+#endif /* skb_frag_page */
+
+#ifndef skb_frag_address
+#define skb_frag_address(frag)	_kc_skb_frag_address(frag)
+static inline void *_kc_skb_frag_address(const skb_frag_t *frag)
+{
+	return page_address(skb_frag_page(frag)) + frag->page_offset;
+}
+#endif /* skb_frag_address */
+
+#ifndef skb_frag_dma_map
+#if ( LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0) )
+#include <linux/dma-mapping.h>
+#endif
+#define skb_frag_dma_map(dev,frag,offset,size,dir) \
+		_kc_skb_frag_dma_map(dev,frag,offset,size,dir)
+static inline dma_addr_t _kc_skb_frag_dma_map(struct device *dev,
+					      const skb_frag_t *frag,
+					      size_t offset, size_t size,
+					      enum dma_data_direction dir)
+{
+	return dma_map_page(dev, skb_frag_page(frag),
+			    frag->page_offset + offset, size, dir);
+}
+#endif /* skb_frag_dma_map */
+
+#ifndef __skb_frag_unref
+#define __skb_frag_unref(frag) __kc_skb_frag_unref(frag)
+static inline void __kc_skb_frag_unref(skb_frag_t *frag)
+{
+	put_page(skb_frag_page(frag));
+}
+#endif /* __skb_frag_unref */
+
+#ifndef SPEED_UNKNOWN
+#define SPEED_UNKNOWN	-1
+#endif
+#ifndef DUPLEX_UNKNOWN
+#define DUPLEX_UNKNOWN	0xff
+#endif
+#if ((RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,3)) ||\
+     (SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(11,3,0)))
+#ifndef HAVE_PCI_DEV_FLAGS_ASSIGNED
+#define HAVE_PCI_DEV_FLAGS_ASSIGNED
+#endif
+#endif
+#else /* < 3.2.0 */
+#ifndef HAVE_PCI_DEV_FLAGS_ASSIGNED
+#define HAVE_PCI_DEV_FLAGS_ASSIGNED
+#define HAVE_VF_SPOOFCHK_CONFIGURE
+#endif
+#ifndef HAVE_SKB_L4_RXHASH
+#define HAVE_SKB_L4_RXHASH
+#endif
+#define HAVE_IOMMU_PRESENT
+#define HAVE_PM_QOS_REQUEST_LIST_NEW
+#endif /* < 3.2.0 */
+
+#if (RHEL_RELEASE_CODE && RHEL_RELEASE_CODE == RHEL_RELEASE_VERSION(6,2))
+#undef ixgbe_get_netdev_tc_txq
+#define ixgbe_get_netdev_tc_txq(dev, tc) (&netdev_extended(dev)->qos_data.tc_to_txq[tc])
+#endif
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,3,0) )
+/* NOTE: the order of parameters to _kc_alloc_workqueue() is different than
+ * alloc_workqueue() to avoid compiler warning from -Wvarargs
+ */
+static inline struct workqueue_struct * __attribute__ ((format(printf, 3, 4)))
+_kc_alloc_workqueue(__maybe_unused int flags, __maybe_unused int max_active,
+		    const char *fmt, ...)
+{
+	struct workqueue_struct *wq;
+	va_list args, temp;
+	unsigned int len;
+	char *p;
+
+	va_start(args, fmt);
+	va_copy(temp, args);
+	len = vsnprintf(NULL, 0, fmt, temp);
+	va_end(temp);
+
+	p = kmalloc(len + 1, GFP_KERNEL);
+	if (!p) {
+		va_end(args);
+		return NULL;
+	}
+
+	vsnprintf(p, len + 1, fmt, args);
+	va_end(args);
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,36) )
+	wq = create_workqueue(p);
+#else
+	wq = alloc_workqueue(p, flags, max_active);
+#endif
+	kfree(p);
+
+	return wq;
+}
+#ifdef alloc_workqueue
+#undef alloc_workqueue
+#endif
+#define alloc_workqueue(fmt, flags, max_active, args...) \
+	_kc_alloc_workqueue(flags, max_active, fmt, ##args)
+
+#if !(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,5))
+typedef u32 netdev_features_t;
+#endif
+#undef PCI_EXP_TYPE_RC_EC
+#define  PCI_EXP_TYPE_RC_EC	0xa	/* Root Complex Event Collector */
+#ifndef CONFIG_BQL
+#define netdev_tx_completed_queue(_q, _p, _b) do {} while (0)
+#define netdev_completed_queue(_n, _p, _b) do {} while (0)
+#define netdev_tx_sent_queue(_q, _b) do {} while (0)
+#define netdev_sent_queue(_n, _b) do {} while (0)
+#define netdev_tx_reset_queue(_q) do {} while (0)
+#define netdev_reset_queue(_n) do {} while (0)
+#endif
+#if (SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(11,3,0))
+#define HAVE_ETHTOOL_GRXFHINDIR_SIZE
+#endif /* SLE_VERSION(11,3,0) */
+#define netif_xmit_stopped(_q) netif_tx_queue_stopped(_q)
+#if !(SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(11,4,0))
+static inline int __kc_ipv6_skip_exthdr(const struct sk_buff *skb, int start,
+					u8 *nexthdrp,
+					__be16 __always_unused *frag_offp)
+{
+	return ipv6_skip_exthdr(skb, start, nexthdrp);
+}
+#undef ipv6_skip_exthdr
+#define ipv6_skip_exthdr(a,b,c,d) __kc_ipv6_skip_exthdr((a), (b), (c), (d))
+#endif /* !SLES11sp4 or greater */
+
+#if (!(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,4)) && \
+     !(SLE_VERSION_CODE >= SLE_VERSION(11,3,0)))
+static inline u32 ethtool_rxfh_indir_default(u32 index, u32 n_rx_rings)
+{
+	return index % n_rx_rings;
+}
+#endif
+
+#else /* ! < 3.3.0 */
+#define HAVE_ETHTOOL_GRXFHINDIR_SIZE
+#define HAVE_INT_NDO_VLAN_RX_ADD_VID
+#ifdef ETHTOOL_SRXNTUPLE
+#undef ETHTOOL_SRXNTUPLE
+#endif
+#endif /* < 3.3.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,4,0) )
+#ifndef NETIF_F_RXFCS
+#define NETIF_F_RXFCS	0
+#endif /* NETIF_F_RXFCS */
+#ifndef NETIF_F_RXALL
+#define NETIF_F_RXALL	0
+#endif /* NETIF_F_RXALL */
+
+#if !(SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(11,3,0))
+#define NUMTCS_RETURNS_U8
+
+int _kc_simple_open(struct inode *inode, struct file *file);
+#define simple_open _kc_simple_open
+#endif /* !(SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(11,3,0)) */
+
+#ifndef skb_add_rx_frag
+#define skb_add_rx_frag _kc_skb_add_rx_frag
+extern void _kc_skb_add_rx_frag(struct sk_buff *, int, struct page *,
+				int, int, unsigned int);
+#endif
+#ifdef NET_ADDR_RANDOM
+#define eth_hw_addr_random(N) do { \
+	eth_random_addr(N->dev_addr); \
+	N->addr_assign_type |= NET_ADDR_RANDOM; \
+	} while (0)
+#else /* NET_ADDR_RANDOM */
+#define eth_hw_addr_random(N) eth_random_addr(N->dev_addr)
+#endif /* NET_ADDR_RANDOM */
+
+#ifndef for_each_set_bit_from
+#define for_each_set_bit_from(bit, addr, size) \
+	for ((bit) = find_next_bit((addr), (size), (bit)); \
+			(bit) < (size); \
+			(bit) = find_next_bit((addr), (size), (bit) + 1))
+#endif /* for_each_set_bit_from */
+
+#else /* < 3.4.0 */
+#include <linux/kconfig.h>
+#endif /* >= 3.4.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE >= KERNEL_VERSION(3,0,0) ) || \
+    ( RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,4) )
+#if !defined(NO_PTP_SUPPORT) && IS_ENABLED(CONFIG_PTP_1588_CLOCK)
+#define HAVE_PTP_1588_CLOCK
+#endif /* !NO_PTP_SUPPORT && IS_ENABLED(CONFIG_PTP_1588_CLOCK) */
+#endif /* >= 3.0.0 || RHEL_RELEASE > 6.4 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,5,0) )
+
+#ifndef BITS_PER_LONG_LONG
+#define BITS_PER_LONG_LONG 64
+#endif
+
+#ifndef ether_addr_equal
+static inline bool __kc_ether_addr_equal(const u8 *addr1, const u8 *addr2)
+{
+	return !compare_ether_addr(addr1, addr2);
+}
+#define ether_addr_equal(_addr1, _addr2) __kc_ether_addr_equal((_addr1),(_addr2))
+#endif
+
+/* Definitions for !CONFIG_OF_NET are introduced in 3.10 */
+#ifdef CONFIG_OF_NET
+static inline int of_get_phy_mode(struct device_node __always_unused *np)
+{
+	return -ENODEV;
+}
+
+static inline const void *
+of_get_mac_address(struct device_node __always_unused *np)
+{
+	return NULL;
+}
+#endif
+#else
+#include <linux/of_net.h>
+#define HAVE_FDB_OPS
+#define HAVE_ETHTOOL_GET_TS_INFO
+#endif /* < 3.5.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,6,0) )
+#define PCI_EXP_LNKCAP2		44	/* Link Capability 2 */
+
+#ifndef MDIO_EEE_100TX
+#define MDIO_EEE_100TX		0x0002	/* 100TX EEE cap */
+#endif
+#ifndef MDIO_EEE_1000T
+#define MDIO_EEE_1000T		0x0004	/* 1000T EEE cap */
+#endif
+#ifndef MDIO_EEE_10GT
+#define MDIO_EEE_10GT		0x0008	/* 10GT EEE cap */
+#endif
+#ifndef MDIO_EEE_1000KX
+#define MDIO_EEE_1000KX		0x0010	/* 1000KX EEE cap */
+#endif
+#ifndef MDIO_EEE_10GKX4
+#define MDIO_EEE_10GKX4		0x0020	/* 10G KX4 EEE cap */
+#endif
+#ifndef MDIO_EEE_10GKR
+#define MDIO_EEE_10GKR		0x0040	/* 10G KR EEE cap */
+#endif
+
+#ifndef __GFP_MEMALLOC
+#define __GFP_MEMALLOC 0
+#endif
+
+#ifndef eth_broadcast_addr
+#define eth_broadcast_addr _kc_eth_broadcast_addr
+static inline void _kc_eth_broadcast_addr(u8 *addr)
+{
+	memset(addr, 0xff, ETH_ALEN);
+}
+#endif
+
+#ifndef eth_random_addr
+#define eth_random_addr _kc_eth_random_addr
+static inline void _kc_eth_random_addr(u8 *addr)
+{
+        get_random_bytes(addr, ETH_ALEN);
+        addr[0] &= 0xfe; /* clear multicast */
+        addr[0] |= 0x02; /* set local assignment */
+}
+#endif /* eth_random_addr */
+
+#ifndef DMA_ATTR_SKIP_CPU_SYNC
+#define DMA_ATTR_SKIP_CPU_SYNC 0
+#endif
+#else /* < 3.6.0 */
+#define HAVE_STRUCT_PAGE_PFMEMALLOC
+#endif /* < 3.6.0 */
+
+/******************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,7,0) )
+#ifndef ADVERTISED_40000baseKR4_Full
+/* these defines were all added in one commit, so should be safe
+ * to trigger activiation on one define
+ */
+#define SUPPORTED_40000baseKR4_Full	(1 << 23)
+#define SUPPORTED_40000baseCR4_Full	(1 << 24)
+#define SUPPORTED_40000baseSR4_Full	(1 << 25)
+#define SUPPORTED_40000baseLR4_Full	(1 << 26)
+#define ADVERTISED_40000baseKR4_Full	(1 << 23)
+#define ADVERTISED_40000baseCR4_Full	(1 << 24)
+#define ADVERTISED_40000baseSR4_Full	(1 << 25)
+#define ADVERTISED_40000baseLR4_Full	(1 << 26)
+#endif
+
+#ifndef mmd_eee_cap_to_ethtool_sup_t
+/**
+ * mmd_eee_cap_to_ethtool_sup_t
+ * @eee_cap: value of the MMD EEE Capability register
+ *
+ * A small helper function that translates MMD EEE Capability (3.20) bits
+ * to ethtool supported settings.
+ */
+static inline u32 __kc_mmd_eee_cap_to_ethtool_sup_t(u16 eee_cap)
+{
+	u32 supported = 0;
+
+	if (eee_cap & MDIO_EEE_100TX)
+		supported |= SUPPORTED_100baseT_Full;
+	if (eee_cap & MDIO_EEE_1000T)
+		supported |= SUPPORTED_1000baseT_Full;
+	if (eee_cap & MDIO_EEE_10GT)
+		supported |= SUPPORTED_10000baseT_Full;
+	if (eee_cap & MDIO_EEE_1000KX)
+		supported |= SUPPORTED_1000baseKX_Full;
+	if (eee_cap & MDIO_EEE_10GKX4)
+		supported |= SUPPORTED_10000baseKX4_Full;
+	if (eee_cap & MDIO_EEE_10GKR)
+		supported |= SUPPORTED_10000baseKR_Full;
+
+	return supported;
+}
+#define mmd_eee_cap_to_ethtool_sup_t(eee_cap) \
+	__kc_mmd_eee_cap_to_ethtool_sup_t(eee_cap)
+#endif /* mmd_eee_cap_to_ethtool_sup_t */
+
+#ifndef mmd_eee_adv_to_ethtool_adv_t
+/**
+ * mmd_eee_adv_to_ethtool_adv_t
+ * @eee_adv: value of the MMD EEE Advertisement/Link Partner Ability registers
+ *
+ * A small helper function that translates the MMD EEE Advertisement (7.60)
+ * and MMD EEE Link Partner Ability (7.61) bits to ethtool advertisement
+ * settings.
+ */
+static inline u32 __kc_mmd_eee_adv_to_ethtool_adv_t(u16 eee_adv)
+{
+	u32 adv = 0;
+
+	if (eee_adv & MDIO_EEE_100TX)
+		adv |= ADVERTISED_100baseT_Full;
+	if (eee_adv & MDIO_EEE_1000T)
+		adv |= ADVERTISED_1000baseT_Full;
+	if (eee_adv & MDIO_EEE_10GT)
+		adv |= ADVERTISED_10000baseT_Full;
+	if (eee_adv & MDIO_EEE_1000KX)
+		adv |= ADVERTISED_1000baseKX_Full;
+	if (eee_adv & MDIO_EEE_10GKX4)
+		adv |= ADVERTISED_10000baseKX4_Full;
+	if (eee_adv & MDIO_EEE_10GKR)
+		adv |= ADVERTISED_10000baseKR_Full;
+
+	return adv;
+}
+
+#define mmd_eee_adv_to_ethtool_adv_t(eee_adv) \
+	__kc_mmd_eee_adv_to_ethtool_adv_t(eee_adv)
+#endif /* mmd_eee_adv_to_ethtool_adv_t */
+
+#ifndef ethtool_adv_to_mmd_eee_adv_t
+/**
+ * ethtool_adv_to_mmd_eee_adv_t
+ * @adv: the ethtool advertisement settings
+ *
+ * A small helper function that translates ethtool advertisement settings
+ * to EEE advertisements for the MMD EEE Advertisement (7.60) and
+ * MMD EEE Link Partner Ability (7.61) registers.
+ */
+static inline u16 __kc_ethtool_adv_to_mmd_eee_adv_t(u32 adv)
+{
+	u16 reg = 0;
+
+	if (adv & ADVERTISED_100baseT_Full)
+		reg |= MDIO_EEE_100TX;
+	if (adv & ADVERTISED_1000baseT_Full)
+		reg |= MDIO_EEE_1000T;
+	if (adv & ADVERTISED_10000baseT_Full)
+		reg |= MDIO_EEE_10GT;
+	if (adv & ADVERTISED_1000baseKX_Full)
+		reg |= MDIO_EEE_1000KX;
+	if (adv & ADVERTISED_10000baseKX4_Full)
+		reg |= MDIO_EEE_10GKX4;
+	if (adv & ADVERTISED_10000baseKR_Full)
+		reg |= MDIO_EEE_10GKR;
+
+	return reg;
+}
+#define ethtool_adv_to_mmd_eee_adv_t(adv) __kc_ethtool_adv_to_mmd_eee_adv_t(adv)
+#endif /* ethtool_adv_to_mmd_eee_adv_t */
+
+#ifndef pci_pcie_type
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(2,6,24) )
+static inline u8 pci_pcie_type(struct pci_dev *pdev)
+{
+	int pos;
+	u16 reg16;
+
+	pos = pci_find_capability(pdev, PCI_CAP_ID_EXP);
+	BUG_ON(!pos);
+	pci_read_config_word(pdev, pos + PCI_EXP_FLAGS, &reg16);
+	return (reg16 & PCI_EXP_FLAGS_TYPE) >> 4;
+}
+#else /* < 2.6.24 */
+#define pci_pcie_type(x)	(x)->pcie_type
+#endif /* < 2.6.24 */
+#endif /* pci_pcie_type */
+
+#if ( ! ( RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,4) ) ) && \
+    ( ! ( SLE_VERSION_CODE >= SLE_VERSION(11,3,0) ) ) && \
+    ( LINUX_VERSION_CODE >= KERNEL_VERSION(3,0,0) )
+#define ptp_clock_register(caps, args...) ptp_clock_register(caps)
+#endif
+
+#ifndef pcie_capability_read_word
+int __kc_pcie_capability_read_word(struct pci_dev *dev, int pos, u16 *val);
+#define pcie_capability_read_word(d,p,v) __kc_pcie_capability_read_word(d,p,v)
+#endif /* pcie_capability_read_word */
+
+#ifndef pcie_capability_write_word
+int __kc_pcie_capability_write_word(struct pci_dev *dev, int pos, u16 val);
+#define pcie_capability_write_word(d,p,v) __kc_pcie_capability_write_word(d,p,v)
+#endif /* pcie_capability_write_word */
+
+#ifndef pcie_capability_clear_and_set_word
+int __kc_pcie_capability_clear_and_set_word(struct pci_dev *dev, int pos,
+					    u16 clear, u16 set);
+#define pcie_capability_clear_and_set_word(d,p,c,s) \
+	__kc_pcie_capability_clear_and_set_word(d,p,c,s)
+#endif /* pcie_capability_clear_and_set_word */
+
+#ifndef pcie_capability_clear_word
+int __kc_pcie_capability_clear_word(struct pci_dev *dev, int pos,
+					     u16 clear);
+#define pcie_capability_clear_word(d, p, c) \
+	__kc_pcie_capability_clear_word(d, p, c)
+#endif /* pcie_capability_clear_word */
+
+#ifndef PCI_EXP_LNKSTA2
+#define PCI_EXP_LNKSTA2		50	/* Link Status 2 */
+#endif
+
+#if (SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(11,3,0))
+#define USE_CONST_DEV_UC_CHAR
+#endif
+
+#if !(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,8))
+#define napi_gro_flush(_napi, _flush_old) napi_gro_flush(_napi)
+#endif /* !RHEL6.8+ */
+
+#if (RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,6))
+#include <linux/hashtable.h>
+#else
+
+#define DEFINE_HASHTABLE(name, bits)						\
+	struct hlist_head name[1 << (bits)] =					\
+			{ [0 ... ((1 << (bits)) - 1)] = HLIST_HEAD_INIT }
+
+#define DEFINE_READ_MOSTLY_HASHTABLE(name, bits)				\
+	struct hlist_head name[1 << (bits)] __read_mostly =			\
+			{ [0 ... ((1 << (bits)) - 1)] = HLIST_HEAD_INIT }
+
+#define DECLARE_HASHTABLE(name, bits)                                   	\
+	struct hlist_head name[1 << (bits)]
+
+#define HASH_SIZE(name) (ARRAY_SIZE(name))
+#define HASH_BITS(name) ilog2(HASH_SIZE(name))
+
+/* Use hash_32 when possible to allow for fast 32bit hashing in 64bit kernels. */
+#define hash_min(val, bits)							\
+	(sizeof(val) <= 4 ? hash_32(val, bits) : hash_long(val, bits))
+
+static inline void __hash_init(struct hlist_head *ht, unsigned int sz)
+{
+	unsigned int i;
+
+	for (i = 0; i < sz; i++)
+		INIT_HLIST_HEAD(&ht[i]);
+}
+
+#define hash_init(hashtable) __hash_init(hashtable, HASH_SIZE(hashtable))
+
+#define hash_add(hashtable, node, key)						\
+	hlist_add_head(node, &hashtable[hash_min(key, HASH_BITS(hashtable))])
+
+static inline bool hash_hashed(struct hlist_node *node)
+{
+	return !hlist_unhashed(node);
+}
+
+static inline bool __hash_empty(struct hlist_head *ht, unsigned int sz)
+{
+	unsigned int i;
+
+	for (i = 0; i < sz; i++)
+		if (!hlist_empty(&ht[i]))
+			return false;
+
+	return true;
+}
+
+#define hash_empty(hashtable) __hash_empty(hashtable, HASH_SIZE(hashtable))
+
+static inline void hash_del(struct hlist_node *node)
+{
+	hlist_del_init(node);
+}
+#endif /* RHEL >= 6.6 */
+
+#else /* >= 3.7.0 */
+#include <linux/hashtable.h>
+#define HAVE_CONST_STRUCT_PCI_ERROR_HANDLERS
+#define USE_CONST_DEV_UC_CHAR
+#endif /* >= 3.7.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,8,0) )
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,5)) && \
+     !(SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(11,4,0)))
+#ifndef pci_sriov_set_totalvfs
+static inline int __kc_pci_sriov_set_totalvfs(struct pci_dev __always_unused *dev, u16 __always_unused numvfs)
+{
+	return 0;
+}
+#define pci_sriov_set_totalvfs(a, b) __kc_pci_sriov_set_totalvfs((a), (b))
+#endif
+#endif /* !(RHEL_RELEASE_CODE >= 6.5 && SLE_VERSION_CODE >= 11.4) */
+#ifndef PCI_EXP_LNKCTL_ASPM_L0S
+#define  PCI_EXP_LNKCTL_ASPM_L0S  0x01	/* L0s Enable */
+#endif
+#ifndef PCI_EXP_LNKCTL_ASPM_L1
+#define  PCI_EXP_LNKCTL_ASPM_L1   0x02	/* L1 Enable */
+#endif
+#define HAVE_CONFIG_HOTPLUG
+/* Reserved Ethernet Addresses per IEEE 802.1Q */
+static const u8 eth_reserved_addr_base[ETH_ALEN] __aligned(2) = {
+	0x01, 0x80, 0xc2, 0x00, 0x00, 0x00 };
+
+#ifndef is_link_local_ether_addr
+static inline bool __kc_is_link_local_ether_addr(const u8 *addr)
+{
+	__be16 *a = (__be16 *)addr;
+	static const __be16 *b = (const __be16 *)eth_reserved_addr_base;
+	static const __be16 m = cpu_to_be16(0xfff0);
+
+	return ((a[0] ^ b[0]) | (a[1] ^ b[1]) | ((a[2] ^ b[2]) & m)) == 0;
+}
+#define is_link_local_ether_addr(addr) __kc_is_link_local_ether_addr(addr)
+#endif /* is_link_local_ether_addr */
+int __kc_ipv6_find_hdr(const struct sk_buff *skb, unsigned int *offset,
+		       int target, unsigned short *fragoff, int *flags);
+#define ipv6_find_hdr(a, b, c, d, e) __kc_ipv6_find_hdr((a), (b), (c), (d), (e))
+
+#ifndef FLOW_MAC_EXT
+#define FLOW_MAC_EXT	0x40000000
+#endif /* FLOW_MAC_EXT */
+
+#if (SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(11,4,0))
+#define HAVE_SRIOV_CONFIGURE
+#endif
+
+#else /* >= 3.8.0 */
+#ifndef __devinit
+#define __devinit
+#endif
+
+#ifndef __devinitdata
+#define __devinitdata
+#endif
+
+#ifndef __devinitconst
+#define __devinitconst
+#endif
+
+#ifndef __devexit
+#define __devexit
+#endif
+
+#ifndef __devexit_p
+#define __devexit_p
+#endif
+
+#ifndef HAVE_ENCAP_CSUM_OFFLOAD
+#define HAVE_ENCAP_CSUM_OFFLOAD
+#endif
+
+#ifndef HAVE_GRE_ENCAP_OFFLOAD
+#define HAVE_GRE_ENCAP_OFFLOAD
+#endif
+
+#ifndef HAVE_SRIOV_CONFIGURE
+#define HAVE_SRIOV_CONFIGURE
+#endif
+
+#define HAVE_BRIDGE_ATTRIBS
+#ifndef BRIDGE_MODE_VEB
+#define BRIDGE_MODE_VEB		0	/* Default loopback mode */
+#endif /* BRIDGE_MODE_VEB */
+#ifndef BRIDGE_MODE_VEPA
+#define BRIDGE_MODE_VEPA	1	/* 802.1Qbg defined VEPA mode */
+#endif /* BRIDGE_MODE_VEPA */
+#endif /* >= 3.8.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,9,0) )
+
+#undef BUILD_BUG_ON
+#ifdef __CHECKER__
+#define BUILD_BUG_ON(condition) (0)
+#else /* __CHECKER__ */
+#ifndef __compiletime_warning
+#if defined(__GNUC__) && ((__GNUC__ * 10000 + __GNUC_MINOR__ * 100) >= 40400)
+#define __compiletime_warning(message) __attribute__((warning(message)))
+#else /* __GNUC__ */
+#define __compiletime_warning(message)
+#endif /* __GNUC__ */
+#endif /* __compiletime_warning */
+#ifndef __compiletime_error
+#if defined(__GNUC__) && ((__GNUC__ * 10000 + __GNUC_MINOR__ * 100) >= 40400)
+#define __compiletime_error(message) __attribute__((error(message)))
+#define __compiletime_error_fallback(condition) do { } while (0)
+#else /* __GNUC__ */
+#define __compiletime_error(message)
+#define __compiletime_error_fallback(condition) \
+	do { ((void)sizeof(char[1 - 2 * condition])); } while (0)
+#endif /* __GNUC__ */
+#else /* __compiletime_error */
+#define __compiletime_error_fallback(condition) do { } while (0)
+#endif /* __compiletime_error */
+#define __compiletime_assert(condition, msg, prefix, suffix)		\
+	do {								\
+		bool __cond = !(condition);				\
+		extern void prefix ## suffix(void) __compiletime_error(msg); \
+		if (__cond)						\
+			prefix ## suffix();				\
+		__compiletime_error_fallback(__cond);			\
+	} while (0)
+
+#define _compiletime_assert(condition, msg, prefix, suffix) \
+	__compiletime_assert(condition, msg, prefix, suffix)
+#define compiletime_assert(condition, msg) \
+	_compiletime_assert(condition, msg, __compiletime_assert_, __LINE__)
+#define BUILD_BUG_ON_MSG(cond, msg) compiletime_assert(!(cond), msg)
+#ifndef __OPTIMIZE__
+#define BUILD_BUG_ON(condition) ((void)sizeof(char[1 - 2*!!(condition)]))
+#else /* __OPTIMIZE__ */
+#define BUILD_BUG_ON(condition) \
+	BUILD_BUG_ON_MSG(condition, "BUILD_BUG_ON failed: " #condition)
+#endif /* __OPTIMIZE__ */
+#endif /* __CHECKER__ */
+
+#undef hlist_entry
+#define hlist_entry(ptr, type, member) container_of(ptr,type,member)
+
+#undef hlist_entry_safe
+#define hlist_entry_safe(ptr, type, member) \
+	({ typeof(ptr) ____ptr = (ptr); \
+	   ____ptr ? hlist_entry(____ptr, type, member) : NULL; \
+	})
+
+#undef hlist_for_each_entry
+#define hlist_for_each_entry(pos, head, member)                             \
+	for (pos = hlist_entry_safe((head)->first, typeof(*(pos)), member); \
+	     pos;                                                           \
+	     pos = hlist_entry_safe((pos)->member.next, typeof(*(pos)), member))
+
+#undef hlist_for_each_entry_safe
+#define hlist_for_each_entry_safe(pos, n, head, member) 		    \
+	for (pos = hlist_entry_safe((head)->first, typeof(*pos), member);   \
+	     pos && ({ n = pos->member.next; 1; });			    \
+	     pos = hlist_entry_safe(n, typeof(*pos), member))
+
+#undef hlist_for_each_entry_continue
+#define hlist_for_each_entry_continue(pos, member)			\
+	for (pos = hlist_entry_safe((pos)->member.next, typeof(*(pos)), member);\
+	     pos;							\
+	     pos = hlist_entry_safe((pos)->member.next, typeof(*(pos)), member))
+
+#undef hlist_for_each_entry_from
+#define hlist_for_each_entry_from(pos, member)				\
+	for (; pos;							\
+	     pos = hlist_entry_safe((pos)->member.next, typeof(*(pos)), member))
+
+#undef hash_for_each
+#define hash_for_each(name, bkt, obj, member)				\
+	for ((bkt) = 0, obj = NULL; obj == NULL && (bkt) < HASH_SIZE(name);\
+			(bkt)++)\
+		hlist_for_each_entry(obj, &name[bkt], member)
+
+#undef hash_for_each_safe
+#define hash_for_each_safe(name, bkt, tmp, obj, member)			\
+	for ((bkt) = 0, obj = NULL; obj == NULL && (bkt) < HASH_SIZE(name);\
+			(bkt)++)\
+		hlist_for_each_entry_safe(obj, tmp, &name[bkt], member)
+
+#undef hash_for_each_possible
+#define hash_for_each_possible(name, obj, member, key)			\
+	hlist_for_each_entry(obj, &name[hash_min(key, HASH_BITS(name))], member)
+
+#undef hash_for_each_possible_safe
+#define hash_for_each_possible_safe(name, obj, tmp, member, key)	\
+	hlist_for_each_entry_safe(obj, tmp,\
+		&name[hash_min(key, HASH_BITS(name))], member)
+
+#ifdef CONFIG_XPS
+extern int __kc_netif_set_xps_queue(struct net_device *, const struct cpumask *, u16);
+#define netif_set_xps_queue(_dev, _mask, _idx) __kc_netif_set_xps_queue((_dev), (_mask), (_idx))
+#else /* CONFIG_XPS */
+#define netif_set_xps_queue(_dev, _mask, _idx) do {} while (0)
+#endif /* CONFIG_XPS */
+
+#ifdef HAVE_NETDEV_SELECT_QUEUE
+#define _kc_hashrnd 0xd631614b /* not so random hash salt */
+extern u16 __kc_netdev_pick_tx(struct net_device *dev, struct sk_buff *skb);
+#define __netdev_pick_tx __kc_netdev_pick_tx
+#endif /* HAVE_NETDEV_SELECT_QUEUE */
+#else
+#define HAVE_BRIDGE_FILTER
+#define HAVE_FDB_DEL_NLATTR
+#endif /* < 3.9.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0) )
+#ifndef NAPI_POLL_WEIGHT
+#define NAPI_POLL_WEIGHT 64
+#endif
+#ifdef CONFIG_PCI_IOV
+extern int __kc_pci_vfs_assigned(struct pci_dev *dev);
+#else
+static inline int __kc_pci_vfs_assigned(struct pci_dev __always_unused *dev)
+{
+	return 0;
+}
+#endif
+#define pci_vfs_assigned(dev) __kc_pci_vfs_assigned(dev)
+
+#ifndef list_first_entry_or_null
+#define list_first_entry_or_null(ptr, type, member) \
+	(!list_empty(ptr) ? list_first_entry(ptr, type, member) : NULL)
+#endif
+
+#ifndef VLAN_TX_COOKIE_MAGIC
+static inline struct sk_buff *__kc__vlan_hwaccel_put_tag(struct sk_buff *skb,
+							 u16 vlan_tci)
+{
+#ifdef VLAN_TAG_PRESENT
+	vlan_tci |= VLAN_TAG_PRESENT;
+#endif
+	skb->vlan_tci = vlan_tci;
+        return skb;
+}
+#define __vlan_hwaccel_put_tag(skb, vlan_proto, vlan_tci) \
+	__kc__vlan_hwaccel_put_tag(skb, vlan_tci)
+#endif
+
+#ifdef HAVE_FDB_OPS
+#ifdef USE_CONST_DEV_UC_CHAR
+extern int __kc_ndo_dflt_fdb_add(struct ndmsg *ndm, struct nlattr *tb[],
+				 struct net_device *dev,
+				 const unsigned char *addr, u16 flags);
+#ifdef HAVE_FDB_DEL_NLATTR
+extern int __kc_ndo_dflt_fdb_del(struct ndmsg *ndm, struct nlattr *tb[],
+				 struct net_device *dev,
+				 const unsigned char *addr);
+#else
+extern int __kc_ndo_dflt_fdb_del(struct ndmsg *ndm, struct net_device *dev,
+				 const unsigned char *addr);
+#endif
+#else
+extern int __kc_ndo_dflt_fdb_add(struct ndmsg *ndm, struct net_device *dev,
+				 unsigned char *addr, u16 flags);
+extern int __kc_ndo_dflt_fdb_del(struct ndmsg *ndm, struct net_device *dev,
+				 unsigned char *addr);
+#endif
+#define ndo_dflt_fdb_add __kc_ndo_dflt_fdb_add
+#define ndo_dflt_fdb_del __kc_ndo_dflt_fdb_del
+#endif /* HAVE_FDB_OPS */
+
+#ifndef PCI_DEVID
+#define PCI_DEVID(bus, devfn)  ((((u16)(bus)) << 8) | (devfn))
+#endif
+
+/* The definitions for these functions when CONFIG_OF_NET is defined are
+ * pulled in from <linux/of_net.h>. For kernels older than 3.5 we already have
+ * backports for when CONFIG_OF_NET is true. These are separated and
+ * duplicated in order to cover all cases so that all kernels get either the
+ * real definitions (when CONFIG_OF_NET is defined) or the stub definitions
+ * (when CONFIG_OF_NET is not defined, or the kernel is too old to have real
+ * definitions).
+ */
+#ifndef CONFIG_OF_NET
+static inline int of_get_phy_mode(struct device_node __always_unused *np)
+{
+	return -ENODEV;
+}
+
+static inline const void *
+of_get_mac_address(struct device_node __always_unused *np)
+{
+	return NULL;
+}
+#endif
+
+#else /* >= 3.10.0 */
+#define HAVE_ENCAP_TSO_OFFLOAD
+#define USE_DEFAULT_FDB_DEL_DUMP
+#define HAVE_SKB_INNER_NETWORK_HEADER
+#if (RHEL_RELEASE_CODE && \
+     (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,0)) && \
+     (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(8,0)))
+#define HAVE_RHEL7_PCI_DRIVER_RH
+#if (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,2))
+#define HAVE_RHEL7_PCI_RESET_NOTIFY
+#endif /* RHEL >= 7.2 */
+#if (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,3))
+#define HAVE_RHEL7_NET_DEVICE_OPS_EXT
+#define HAVE_GENEVE_RX_OFFLOAD
+#if !defined(HAVE_UDP_ENC_TUNNEL) && IS_ENABLED(CONFIG_GENEVE)
+#define HAVE_UDP_ENC_TUNNEL
+#endif
+#ifdef ETHTOOL_GLINKSETTINGS
+#define HAVE_ETHTOOL_25G_BITS
+#endif /* ETHTOOL_GLINKSETTINGS */
+#endif /* RHEL >= 7.3 */
+
+/* new hooks added to net_device_ops_extended in RHEL7.4 */
+#if (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,4))
+#define HAVE_RHEL7_NETDEV_OPS_EXT_NDO_SET_VF_VLAN
+#define HAVE_RHEL7_NETDEV_OPS_EXT_NDO_UDP_TUNNEL
+#define HAVE_UDP_ENC_RX_OFFLOAD
+#endif /* RHEL >= 7.4 */
+
+#endif /* RHEL >= 7.0 && RHEL < 8.0 */
+#endif /* >= 3.10.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,11,0) )
+#define netdev_notifier_info_to_dev(ptr) ptr
+#if ((RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,6)) ||\
+     (SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(11,4,0)))
+#define HAVE_NDO_SET_VF_LINK_STATE
+#endif
+#if RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,2))
+#define HAVE_NDO_SELECT_QUEUE_ACCEL_FALLBACK
+#endif
+#else /* >= 3.11.0 */
+#define HAVE_NDO_SET_VF_LINK_STATE
+#define HAVE_SKB_INNER_PROTOCOL
+#define HAVE_MPLS_FEATURES
+#endif /* >= 3.11.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,12,0) )
+extern int __kc_pcie_get_minimum_link(struct pci_dev *dev,
+				      enum pci_bus_speed *speed,
+				      enum pcie_link_width *width);
+#ifndef pcie_get_minimum_link
+#define pcie_get_minimum_link(_p, _s, _w) __kc_pcie_get_minimum_link(_p, _s, _w)
+#endif
+#else /* >= 3.12.0 */
+#if ( SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(12,0,0))
+#define HAVE_NDO_SELECT_QUEUE_ACCEL_FALLBACK
+#endif
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(4,8,0) )
+#define HAVE_VXLAN_RX_OFFLOAD
+#if !defined(HAVE_UDP_ENC_TUNNEL) && IS_ENABLED(CONFIG_VXLAN)
+#define HAVE_UDP_ENC_TUNNEL
+#endif
+#endif /* < 4.8.0 */
+#define HAVE_NDO_GET_PHYS_PORT_ID
+#define HAVE_NETIF_SET_XPS_QUEUE_CONST_MASK
+#endif /* >= 3.12.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,13,0) )
+#define dma_set_mask_and_coherent(_p, _m) __kc_dma_set_mask_and_coherent(_p, _m)
+extern int __kc_dma_set_mask_and_coherent(struct device *dev, u64 mask);
+#ifndef u64_stats_init
+#define u64_stats_init(a) do { } while(0)
+#endif
+#ifndef BIT_ULL
+#define BIT_ULL(n) (1ULL << (n))
+#endif
+
+#if (SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(12,1,0))
+#undef HAVE_STRUCT_PAGE_PFMEMALLOC
+#define HAVE_DCBNL_OPS_SETAPP_RETURN_INT
+#endif
+#ifndef list_next_entry
+#define list_next_entry(pos, member) \
+	list_entry((pos)->member.next, typeof(*(pos)), member)
+#endif
+#ifndef list_prev_entry
+#define list_prev_entry(pos, member) \
+	list_entry((pos)->member.prev, typeof(*(pos)), member)
+#endif
+
+#if ( LINUX_VERSION_CODE > KERNEL_VERSION(2,6,20) )
+#define devm_kcalloc(dev, cnt, size, flags) \
+	devm_kzalloc(dev, cnt * size, flags)
+#endif /* > 2.6.20 */
+
+#else /* >= 3.13.0 */
+#define HAVE_VXLAN_CHECKS
+#if (UBUNTU_VERSION_CODE && UBUNTU_VERSION_CODE >= UBUNTU_VERSION(3,13,0,24))
+#define HAVE_NDO_SELECT_QUEUE_ACCEL_FALLBACK
+#else
+#define HAVE_NDO_SELECT_QUEUE_ACCEL
+#endif
+#define HAVE_NET_GET_RANDOM_ONCE
+#define HAVE_HWMON_DEVICE_REGISTER_WITH_GROUPS
+#endif
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,14,0) )
+
+#ifndef U16_MAX
+#define U16_MAX ((u16)~0U)
+#endif
+
+#ifndef U32_MAX
+#define U32_MAX ((u32)~0U)
+#endif
+
+#define dev_consume_skb_any(x) dev_kfree_skb_any(x)
+
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,0)) && \
+     !(SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(12,0,0)))
+
+/* it isn't expected that this would be a #define unless we made it so */
+#ifndef skb_set_hash
+
+#define PKT_HASH_TYPE_NONE	0
+#define PKT_HASH_TYPE_L2	1
+#define PKT_HASH_TYPE_L3	2
+#define PKT_HASH_TYPE_L4	3
+
+enum _kc_pkt_hash_types {
+	_KC_PKT_HASH_TYPE_NONE = PKT_HASH_TYPE_NONE,
+	_KC_PKT_HASH_TYPE_L2 = PKT_HASH_TYPE_L2,
+	_KC_PKT_HASH_TYPE_L3 = PKT_HASH_TYPE_L3,
+	_KC_PKT_HASH_TYPE_L4 = PKT_HASH_TYPE_L4,
+};
+#define pkt_hash_types         _kc_pkt_hash_types
+
+#define skb_set_hash __kc_skb_set_hash
+static inline void __kc_skb_set_hash(struct sk_buff __maybe_unused *skb,
+				     u32 __maybe_unused hash,
+				     int __maybe_unused type)
+{
+#ifdef HAVE_SKB_L4_RXHASH
+	skb->l4_rxhash = (type == PKT_HASH_TYPE_L4);
+#endif
+#ifdef NETIF_F_RXHASH
+	skb->rxhash = hash;
+#endif
+}
+#endif /* !skb_set_hash */
+
+#else	/* RHEL_RELEASE_CODE >= 7.0 || SLE_VERSION_CODE >= 12.0 */
+
+#ifndef HAVE_VXLAN_RX_OFFLOAD
+#define HAVE_VXLAN_RX_OFFLOAD
+#endif /* HAVE_VXLAN_RX_OFFLOAD */
+
+#if !defined(HAVE_UDP_ENC_TUNNEL) && IS_ENABLED(CONFIG_VXLAN)
+#define HAVE_UDP_ENC_TUNNEL
+#endif
+
+#ifndef HAVE_VXLAN_CHECKS
+#define HAVE_VXLAN_CHECKS
+#endif /* HAVE_VXLAN_CHECKS */
+#endif /* !(RHEL_RELEASE_CODE >= 7.0 && SLE_VERSION_CODE >= 12.0) */
+
+#if ((RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,3)) ||\
+     (SLE_VERSION_CODE && SLE_VERSION_CODE >= SLE_VERSION(12,0,0)))
+#define HAVE_NDO_DFWD_OPS
+#endif
+
+#ifndef pci_enable_msix_range
+extern int __kc_pci_enable_msix_range(struct pci_dev *dev,
+				      struct msix_entry *entries,
+				      int minvec, int maxvec);
+#define pci_enable_msix_range __kc_pci_enable_msix_range
+#endif
+
+#ifndef ether_addr_copy
+#define ether_addr_copy __kc_ether_addr_copy
+static inline void __kc_ether_addr_copy(u8 *dst, const u8 *src)
+{
+#if defined(CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS)
+	*(u32 *)dst = *(const u32 *)src;
+	*(u16 *)(dst + 4) = *(const u16 *)(src + 4);
+#else
+	u16 *a = (u16 *)dst;
+	const u16 *b = (const u16 *)src;
+
+	a[0] = b[0];
+	a[1] = b[1];
+	a[2] = b[2];
+#endif
+}
+#endif /* ether_addr_copy */
+
+#else /* >= 3.14.0 */
+
+/* for ndo_dfwd_ ops add_station, del_station and _start_xmit */
+#ifndef HAVE_NDO_DFWD_OPS
+#define HAVE_NDO_DFWD_OPS
+#endif
+#define HAVE_NDO_SELECT_QUEUE_ACCEL_FALLBACK
+#endif /* 3.14.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,15,0) )
+
+#if (!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,1)) && \
+     !(UBUNTU_VERSION_CODE && UBUNTU_VERSION_CODE >= UBUNTU_VERSION(3,13,0,30)))
+#define u64_stats_fetch_begin_irq u64_stats_fetch_begin_bh
+#define u64_stats_fetch_retry_irq u64_stats_fetch_retry_bh
+#endif
+
+char *_kc_devm_kstrdup(struct device *dev, const char *s, gfp_t gfp);
+#define devm_kstrdup(dev, s, gfp) _kc_devm_kstrdup(dev, s, gfp)
+
+#else
+#define HAVE_PTP_1588_CLOCK_PINS
+#define HAVE_NETDEV_PORT
+#endif /* 3.15.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,16,0) )
+#ifndef smp_mb__before_atomic
+#define smp_mb__before_atomic() smp_mb()
+#define smp_mb__after_atomic()  smp_mb()
+#endif
+#ifndef __dev_uc_sync
+#ifdef HAVE_SET_RX_MODE
+#ifdef NETDEV_HW_ADDR_T_UNICAST
+int __kc_hw_addr_sync_dev(struct netdev_hw_addr_list *list,
+		struct net_device *dev,
+		int (*sync)(struct net_device *, const unsigned char *),
+		int (*unsync)(struct net_device *, const unsigned char *));
+void __kc_hw_addr_unsync_dev(struct netdev_hw_addr_list *list,
+		struct net_device *dev,
+		int (*unsync)(struct net_device *, const unsigned char *));
+#endif
+#ifndef NETDEV_HW_ADDR_T_MULTICAST
+int __kc_dev_addr_sync_dev(struct dev_addr_list **list, int *count,
+		struct net_device *dev,
+		int (*sync)(struct net_device *, const unsigned char *),
+		int (*unsync)(struct net_device *, const unsigned char *));
+void __kc_dev_addr_unsync_dev(struct dev_addr_list **list, int *count,
+		struct net_device *dev,
+		int (*unsync)(struct net_device *, const unsigned char *));
+#endif
+#endif /* HAVE_SET_RX_MODE */
+
+static inline int __kc_dev_uc_sync(struct net_device __maybe_unused *dev,
+				   int __maybe_unused (*sync)(struct net_device *, const unsigned char *),
+				   int __maybe_unused (*unsync)(struct net_device *, const unsigned char *))
+{
+#ifdef NETDEV_HW_ADDR_T_UNICAST
+	return __kc_hw_addr_sync_dev(&dev->uc, dev, sync, unsync);
+#elif defined(HAVE_SET_RX_MODE)
+	return __kc_dev_addr_sync_dev(&dev->uc_list, &dev->uc_count,
+				      dev, sync, unsync);
+#else
+	return 0;
+#endif
+}
+#define __dev_uc_sync __kc_dev_uc_sync
+
+static inline void __kc_dev_uc_unsync(struct net_device __maybe_unused *dev,
+				      int __maybe_unused (*unsync)(struct net_device *, const unsigned char *))
+{
+#ifdef HAVE_SET_RX_MODE
+#ifdef NETDEV_HW_ADDR_T_UNICAST
+	__kc_hw_addr_unsync_dev(&dev->uc, dev, unsync);
+#else /* NETDEV_HW_ADDR_T_MULTICAST */
+	__kc_dev_addr_unsync_dev(&dev->uc_list, &dev->uc_count, dev, unsync);
+#endif /* NETDEV_HW_ADDR_T_UNICAST */
+#endif /* HAVE_SET_RX_MODE */
+}
+#define __dev_uc_unsync __kc_dev_uc_unsync
+
+static inline int __kc_dev_mc_sync(struct net_device __maybe_unused *dev,
+				   int __maybe_unused (*sync)(struct net_device *, const unsigned char *),
+				   int __maybe_unused (*unsync)(struct net_device *, const unsigned char *))
+{
+#ifdef NETDEV_HW_ADDR_T_MULTICAST
+	return __kc_hw_addr_sync_dev(&dev->mc, dev, sync, unsync);
+#elif defined(HAVE_SET_RX_MODE)
+	return __kc_dev_addr_sync_dev(&dev->mc_list, &dev->mc_count,
+				      dev, sync, unsync);
+#else
+	return 0;
+#endif
+
+}
+#define __dev_mc_sync __kc_dev_mc_sync
+
+static inline void __kc_dev_mc_unsync(struct net_device __maybe_unused *dev,
+				      int __maybe_unused (*unsync)(struct net_device *, const unsigned char *))
+{
+#ifdef HAVE_SET_RX_MODE
+#ifdef NETDEV_HW_ADDR_T_MULTICAST
+	__kc_hw_addr_unsync_dev(&dev->mc, dev, unsync);
+#else /* NETDEV_HW_ADDR_T_MULTICAST */
+	__kc_dev_addr_unsync_dev(&dev->mc_list, &dev->mc_count, dev, unsync);
+#endif /* NETDEV_HW_ADDR_T_MULTICAST */
+#endif /* HAVE_SET_RX_MODE */
+}
+#define __dev_mc_unsync __kc_dev_mc_unsync
+#endif /* __dev_uc_sync */
+
+#if RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,1))
+#define HAVE_NDO_SET_VF_MIN_MAX_TX_RATE
+#endif
+
+#ifndef NETIF_F_GSO_UDP_TUNNEL_CSUM
+/* if someone backports this, hopefully they backport as a #define.
+ * declare it as zero on older kernels so that if it get's or'd in
+ * it won't effect anything, therefore preventing core driver changes
+ */
+#define NETIF_F_GSO_UDP_TUNNEL_CSUM 0
+#define SKB_GSO_UDP_TUNNEL_CSUM 0
+#endif
+extern void *__kc_devm_kmemdup(struct device *dev, const void *src, size_t len,
+			       unsigned int gfp);
+#define devm_kmemdup __kc_devm_kmemdup
+
+#else
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(4,13,0) )
+#define HAVE_PCI_ERROR_HANDLER_RESET_NOTIFY
+#endif /* >= 3.16.0 && < 4.13.0 */
+#define HAVE_NDO_SET_VF_MIN_MAX_TX_RATE
+#endif /* 3.16.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,17,0) )
+#if !(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,8) && \
+      RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(7,0)) && \
+    !(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,2))
+#ifndef timespec64
+#define timespec64 timespec
+static inline struct timespec64 timespec_to_timespec64(const struct timespec ts)
+{
+	return ts;
+}
+static inline struct timespec timespec64_to_timespec(const struct timespec64 ts64)
+{
+	return ts64;
+}
+#define timespec64_equal timespec_equal
+#define timespec64_compare timespec_compare
+#define set_normalized_timespec64 set_normalized_timespec
+#define timespec64_add_safe timespec_add_safe
+#define timespec64_add timespec_add
+#define timespec64_sub timespec_sub
+#define timespec64_valid timespec_valid
+#define timespec64_valid_strict timespec_valid_strict
+#define timespec64_to_ns timespec_to_ns
+#define ns_to_timespec64 ns_to_timespec
+#define ktime_to_timespec64 ktime_to_timespec
+#define timespec64_add_ns timespec_add_ns
+#endif /* timespec64 */
+#endif /* !(RHEL6.8<RHEL7.0) && !RHEL7.2+ */
+
+#if !(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,4))
+#define hlist_add_behind(_a, _b) hlist_add_after(_b, _a)
+#endif
+
+#else
+#define HAVE_DCBNL_OPS_SETAPP_RETURN_INT
+#include <linux/time64.h>
+#endif /* 3.17.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,18,0) )
+#ifndef NO_PTP_SUPPORT
+#include <linux/errqueue.h>
+extern struct sk_buff *__kc_skb_clone_sk(struct sk_buff *skb);
+extern void __kc_skb_complete_tx_timestamp(struct sk_buff *skb,
+				struct skb_shared_hwtstamps *hwtstamps);
+#define skb_clone_sk __kc_skb_clone_sk
+#define skb_complete_tx_timestamp __kc_skb_complete_tx_timestamp
+#endif
+extern unsigned int __kc_eth_get_headlen(unsigned char *data, unsigned int max_len);
+#define eth_get_headlen __kc_eth_get_headlen
+#ifndef ETH_P_XDSA
+#define ETH_P_XDSA 0x00F8
+#endif
+/* RHEL 7.1 backported csum_level, but SLES 12 and 12-SP1 did not */
+#if RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,1))
+#define HAVE_SKBUFF_CSUM_LEVEL
+#endif /* >= RH 7.1 */
+
+/* RHEL 7.3 backported xmit_more */
+#if (RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,3))
+#define HAVE_SKB_XMIT_MORE
+#endif /* >= RH 7.3 */
+
+#undef GENMASK
+#define GENMASK(h, l) \
+	(((~0UL) << (l)) & (~0UL >> (BITS_PER_LONG - 1 - (h))))
+#undef GENMASK_ULL
+#define GENMASK_ULL(h, l) \
+	(((~0ULL) << (l)) & (~0ULL >> (BITS_PER_LONG_LONG - 1 - (h))))
+
+#else /*  3.18.0 */
+#define HAVE_SKBUFF_CSUM_LEVEL
+#define HAVE_SKB_XMIT_MORE
+#define HAVE_SKB_INNER_PROTOCOL_TYPE
+#endif /* 3.18.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,18,4) )
+#else
+#define HAVE_NDO_FEATURES_CHECK
+#endif /* 3.18.4 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,19,0) )
+/* netdev_phys_port_id renamed to netdev_phys_item_id */
+#define netdev_phys_item_id netdev_phys_port_id
+
+static inline void _kc_napi_complete_done(struct napi_struct *napi,
+					  int __always_unused work_done) {
+	napi_complete(napi);
+}
+#define napi_complete_done _kc_napi_complete_done
+
+#ifndef NETDEV_RSS_KEY_LEN
+#define NETDEV_RSS_KEY_LEN (13 * 4)
+#endif
+#if ( !(RHEL_RELEASE_CODE && \
+	(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(6,7) && \
+	(RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(7,0)))) )
+#define netdev_rss_key_fill(buffer, len) __kc_netdev_rss_key_fill(buffer, len)
+#endif /* RHEL_RELEASE_CODE */
+extern void __kc_netdev_rss_key_fill(void *buffer, size_t len);
+#define SPEED_20000 20000
+#define SPEED_40000 40000
+#ifndef dma_rmb
+#define dma_rmb() rmb()
+#endif
+#ifndef dev_alloc_pages
+#define dev_alloc_pages(_order) alloc_pages_node(NUMA_NO_NODE, (GFP_ATOMIC | __GFP_COLD | __GFP_COMP | __GFP_MEMALLOC), (_order))
+#endif
+#ifndef dev_alloc_page
+#define dev_alloc_page() dev_alloc_pages(0)
+#endif
+#if !defined(eth_skb_pad) && !defined(skb_put_padto)
+/**
+ *     __kc_skb_put_padto - increase size and pad an skbuff up to a minimal size
+ *     @skb: buffer to pad
+ *     @len: minimal length
+ *
+ *     Pads up a buffer to ensure the trailing bytes exist and are
+ *     blanked. If the buffer already contains sufficient data it
+ *     is untouched. Otherwise it is extended. Returns zero on
+ *     success. The skb is freed on error.
+ */
+static inline int __kc_skb_put_padto(struct sk_buff *skb, unsigned int len)
+{
+	unsigned int size = skb->len;
+
+	if (unlikely(size < len)) {
+		len -= size;
+		if (skb_pad(skb, len))
+			return -ENOMEM;
+		__skb_put(skb, len);
+	}
+	return 0;
+}
+#define skb_put_padto(skb, len) __kc_skb_put_padto(skb, len)
+
+static inline int __kc_eth_skb_pad(struct sk_buff *skb)
+{
+	return __kc_skb_put_padto(skb, ETH_ZLEN);
+}
+#define eth_skb_pad(skb) __kc_eth_skb_pad(skb)
+#endif /* eth_skb_pad && skb_put_padto */
+
+#ifndef SKB_ALLOC_NAPI
+/* RHEL 7.2 backported napi_alloc_skb and friends */
+static inline struct sk_buff *__kc_napi_alloc_skb(struct napi_struct *napi, unsigned int length)
+{
+	return netdev_alloc_skb_ip_align(napi->dev, length);
+}
+#define napi_alloc_skb(napi,len) __kc_napi_alloc_skb(napi,len)
+#define __napi_alloc_skb(napi,len,mask) __kc_napi_alloc_skb(napi,len)
+#endif /* SKB_ALLOC_NAPI */
+#define HAVE_CONFIG_PM_RUNTIME
+#if (RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(6,7)) && \
+     (RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(7,0)))
+#define HAVE_RXFH_HASHFUNC
+#endif /* 6.7 < RHEL < 7.0 */
+#if RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,1))
+#define HAVE_RXFH_HASHFUNC
+#define NDO_DFLT_BRIDGE_GETLINK_HAS_BRFLAGS
+#endif /* RHEL > 7.1 */
+#ifndef napi_schedule_irqoff
+#define napi_schedule_irqoff	napi_schedule
+#endif
+#ifndef READ_ONCE
+#define READ_ONCE(_x) ACCESS_ONCE(_x)
+#endif
+#if RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,2))
+#define HAVE_NDO_FDB_ADD_VID
+#endif
+#ifndef ETH_MODULE_SFF_8636
+#define ETH_MODULE_SFF_8636		0x3
+#endif
+#ifndef ETH_MODULE_SFF_8636_LEN
+#define ETH_MODULE_SFF_8636_LEN		256
+#endif
+#ifndef ETH_MODULE_SFF_8436
+#define ETH_MODULE_SFF_8436		0x4
+#endif
+#ifndef ETH_MODULE_SFF_8436_LEN
+#define ETH_MODULE_SFF_8436_LEN		256
+#endif
+#else /* 3.19.0 */
+#define HAVE_NDO_FDB_ADD_VID
+#define HAVE_RXFH_HASHFUNC
+#define NDO_DFLT_BRIDGE_GETLINK_HAS_BRFLAGS
+#endif /* 3.19.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(3,20,0) )
+/* vlan_tx_xx functions got renamed to skb_vlan */
+#ifndef skb_vlan_tag_get
+#define skb_vlan_tag_get vlan_tx_tag_get
+#endif
+#ifndef skb_vlan_tag_present
+#define skb_vlan_tag_present vlan_tx_tag_present
+#endif
+#if RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,1))
+#define HAVE_INCLUDE_LINUX_TIMECOUNTER_H
+#endif
+#if RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,2))
+#define HAVE_NDO_BRIDGE_SET_DEL_LINK_FLAGS
+#endif
+#else
+#define HAVE_INCLUDE_LINUX_TIMECOUNTER_H
+#define HAVE_NDO_BRIDGE_SET_DEL_LINK_FLAGS
+#endif /* 3.20.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(4,0,0) )
+/* Definition for CONFIG_OF was introduced earlier */
+#if !defined(CONFIG_OF) && \
+    !(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,2))
+static inline struct device_node *
+pci_device_to_OF_node(const struct pci_dev __always_unused *pdev) { return NULL; }
+#endif /* !CONFIG_OF && RHEL < 7.3 */
+#endif /* < 4.0 */
+
+/*****************************************************************************/
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(4,1,0) )
+#ifndef NO_PTP_SUPPORT
+#ifdef HAVE_INCLUDE_LINUX_TIMECOUNTER_H
+#include <linux/timecounter.h>
+#else
+#include <linux/clocksource.h>
+#endif
+static inline void __kc_timecounter_adjtime(struct timecounter *tc, s64 delta)
+{
+	tc->nsec += delta;
+}
+
+static inline struct net_device *
+of_find_net_device_by_node(struct device_node __always_unused *np)
+{
+	return NULL;
+}
+
+#define timecounter_adjtime __kc_timecounter_adjtime
+#endif
+#if ((RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,2))) || \
+     (SLE_VERSION_CODE && (SLE_VERSION_CODE >= SLE_VERSION(12,2,0))))
+#define HAVE_NDO_SET_VF_RSS_QUERY_EN
+#endif
+#if RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,2))
+#define HAVE_NDO_BRIDGE_GETLINK_NLFLAGS
+#endif
+#if !((RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(6,8) && RHEL_RELEASE_CODE < RHEL_RELEASE_VERSION(7,0)) && \
+      (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,2)) && \
+      (SLE_VERSION_CODE > SLE_VERSION(12,1,0)))
+extern unsigned int _kc_cpumask_local_spread(unsigned int i, int node);
+#define cpumask_local_spread _kc_cpumask_local_spread
+#endif
+#else /* >= 4,1,0 */
+#define HAVE_PTP_CLOCK_INFO_GETTIME64
+#define HAVE_NDO_BRIDGE_GETLINK_NLFLAGS
+#define HAVE_PASSTHRU_FEATURES_CHECK
+#define HAVE_NDO_SET_VF_RSS_QUERY_EN
+#endif /* 4,1,0 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,1,9))
+#if (!(RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,2)) && \
+     !((SLE_VERSION_CODE == SLE_VERSION(11,3,0)) && \
+       (SLE_LOCALVERSION_CODE >= SLE_LOCALVERSION(0,47,71))) && \
+     !((SLE_VERSION_CODE == SLE_VERSION(11,4,0)) && \
+       (SLE_LOCALVERSION_CODE >= SLE_LOCALVERSION(65,0,0))) && \
+     !(SLE_VERSION_CODE >= SLE_VERSION(12,1,0)))
+static inline bool page_is_pfmemalloc(struct page __maybe_unused *page)
+{
+#ifdef HAVE_STRUCT_PAGE_PFMEMALLOC
+	return page->pfmemalloc;
+#else
+	return false;
+#endif
+}
+#endif /* !RHEL7.2+ && !SLES11sp3(3.0.101-0.47.71+ update) && !SLES11sp4(3.0.101-65+ update) & !SLES12sp1+ */
+#else
+#undef HAVE_STRUCT_PAGE_PFMEMALLOC
+#endif /* 4.1.9 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,2,0))
+#if (!(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,2)) && \
+     !(SLE_VERSION_CODE >= SLE_VERSION(12,1,0)))
+#define ETHTOOL_RX_FLOW_SPEC_RING	0x00000000FFFFFFFFULL
+#define ETHTOOL_RX_FLOW_SPEC_RING_VF	0x000000FF00000000ULL
+#define ETHTOOL_RX_FLOW_SPEC_RING_VF_OFF 32
+static inline __u64 ethtool_get_flow_spec_ring(__u64 ring_cookie)
+{
+	return ETHTOOL_RX_FLOW_SPEC_RING & ring_cookie;
+};
+
+static inline __u64 ethtool_get_flow_spec_ring_vf(__u64 ring_cookie)
+{
+	return (ETHTOOL_RX_FLOW_SPEC_RING_VF & ring_cookie) >>
+				ETHTOOL_RX_FLOW_SPEC_RING_VF_OFF;
+};
+#endif /* ! RHEL >= 7.2 && ! SLES >= 12.1 */
+#if (RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,4))
+#define HAVE_NDO_DFLT_BRIDGE_GETLINK_VLAN_SUPPORT
+#endif
+#else
+#define HAVE_NDO_DFLT_BRIDGE_GETLINK_VLAN_SUPPORT
+#endif /* 4.2.0 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,4,0))
+#if (RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,3))
+#define HAVE_NDO_SET_VF_TRUST
+#endif /* (RHEL_RELEASE >= 7.3) */
+#ifndef CONFIG_64BIT
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#include <asm-generic/io-64-nonatomic-lo-hi.h>	/* 32-bit readq/writeq */
+#else /* 3.3.0 => 4.3.x */
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,26))
+#include <asm-generic/int-ll64.h>
+#endif /* 2.6.26 => 3.3.0 */
+#ifndef readq
+static inline __u64 readq(const volatile void __iomem *addr)
+{
+	const volatile u32 __iomem *p = addr;
+	u32 low, high;
+
+	low = readl(p);
+	high = readl(p + 1);
+
+	return low + ((u64)high << 32);
+}
+#define readq readq
+#endif
+
+#ifndef writeq
+static inline void writeq(__u64 val, volatile void __iomem *addr)
+{
+	writel(val, addr);
+	writel(val >> 32, addr + 4);
+}
+#define writeq writeq
+#endif
+#endif /* < 3.3.0 */
+#endif /* !CONFIG_64BIT */
+#else /* < 4.4.0 */
+#define HAVE_NDO_SET_VF_TRUST
+
+#ifndef CONFIG_64BIT
+#include <linux/io-64-nonatomic-lo-hi.h>	/* 32-bit readq/writeq */
+#endif /* !CONFIG_64BIT */
+#endif /* 4.4.0 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,5,0))
+/* protect against a likely backport */
+#ifndef NETIF_F_CSUM_MASK
+#define NETIF_F_CSUM_MASK NETIF_F_ALL_CSUM
+#endif /* NETIF_F_CSUM_MASK */
+#ifndef NETIF_F_SCTP_CRC
+#define NETIF_F_SCTP_CRC NETIF_F_SCTP_CSUM
+#endif /* NETIF_F_SCTP_CRC */
+#if (!(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,3)))
+#define eth_platform_get_mac_address _kc_eth_platform_get_mac_address
+extern int _kc_eth_platform_get_mac_address(struct device *dev __maybe_unused,
+					    u8 *mac_addr __maybe_unused);
+#endif /* !(RHEL_RELEASE >= 7.3) */
+#else /* 4.5.0 */
+#if ( LINUX_VERSION_CODE < KERNEL_VERSION(4,8,0) )
+#define HAVE_GENEVE_RX_OFFLOAD
+#if !defined(HAVE_UDP_ENC_TUNNEL) && IS_ENABLED(CONFIG_GENEVE)
+#define HAVE_UDP_ENC_TUNNEL
+#endif
+#endif /* < 4.8.0 */
+#define HAVE_NETIF_NAPI_ADD_CALLS_NAPI_HASH_ADD
+#endif /* 4.5.0 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,6,0))
+#if !(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,3))
+static inline unsigned char *skb_checksum_start(const struct sk_buff *skb)
+{
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,22))
+	return skb->head + skb->csum_start;
+#else /* < 2.6.22 */
+	return skb_transport_header(skb);
+#endif
+}
+#endif
+
+#if !(UBUNTU_VERSION_CODE && \
+		UBUNTU_VERSION_CODE >= UBUNTU_VERSION(4,4,0,21)) && \
+	!(RHEL_RELEASE_CODE && \
+		(RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,2))) && \
+	!(SLE_VERSION_CODE && (SLE_VERSION_CODE >= SLE_VERSION(12,3,0)))
+static inline void napi_consume_skb(struct sk_buff *skb,
+				    int __always_unused budget)
+{
+	dev_consume_skb_any(skb);
+}
+
+#endif /* UBUNTU 4,4,0,21, RHEL 7.2, SLES12 SP3 */
+#if !(SLE_VERSION_CODE && (SLE_VERSION_CODE >= SLE_VERSION(12,3,0))) && \
+	!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,4))
+static inline void csum_replace_by_diff(__sum16 *sum, __wsum diff)
+{
+	* sum = csum_fold(csum_add(diff, ~csum_unfold(*sum)));
+}
+#endif
+
+#if !(RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE > RHEL_RELEASE_VERSION(7,2)))
+static inline void page_ref_inc(struct page *page)
+{
+	get_page(page);
+}
+#else
+#define HAVE_PAGE_COUNT_BULK_UPDATE
+#endif
+
+#else /* 4.6.0 */
+#define HAVE_PAGE_COUNT_BULK_UPDATE
+#endif /* 4.6.0 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,7,0))
+#if (SLE_VERSION_CODE && (SLE_VERSION_CODE >= SLE_VERSION(12,3,0))) ||\
+	(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,4))
+#define HAVE_NETIF_TRANS_UPDATE
+#endif
+#else /* 4.7.0 */
+#define HAVE_NETIF_TRANS_UPDATE
+#define HAVE_ETHTOOL_CONVERT_U32_AND_LINK_MODE
+#ifdef ETHTOOL_GLINKSETTINGS
+#define HAVE_ETHTOOL_25G_BITS
+#endif /* ETHTOOL_GLINKSETTINGS */
+#endif /* 4.7.0 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,8,0))
+#if !(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,4))
+enum udp_parsable_tunnel_type {
+	UDP_TUNNEL_TYPE_VXLAN,
+	UDP_TUNNEL_TYPE_GENEVE,
+};
+struct udp_tunnel_info {
+	unsigned short type;
+	sa_family_t sa_family;
+	__be16 port;
+};
+#endif
+
+#if !(SLE_VERSION_CODE && (SLE_VERSION_CODE >= SLE_VERSION(12,3,0))) &&\
+	!(RHEL_RELEASE_CODE && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,4))
+static inline int
+#ifdef HAVE_NON_CONST_PCI_DRIVER_NAME
+pci_request_io_regions(struct pci_dev *pdev, char *name)
+#else
+pci_request_io_regions(struct pci_dev *pdev, const char *name)
+#endif
+{
+	return pci_request_selected_regions(pdev,
+			    pci_select_bars(pdev, IORESOURCE_IO), name);
+}
+
+static inline void
+pci_release_io_regions(struct pci_dev *pdev)
+{
+	return pci_release_selected_regions(pdev,
+			    pci_select_bars(pdev, IORESOURCE_IO));
+}
+
+static inline int
+#ifdef HAVE_NON_CONST_PCI_DRIVER_NAME
+pci_request_mem_regions(struct pci_dev *pdev, char *name)
+#else
+pci_request_mem_regions(struct pci_dev *pdev, const char *name)
+#endif
+{
+	return pci_request_selected_regions(pdev,
+			    pci_select_bars(pdev, IORESOURCE_MEM), name);
+}
+
+static inline void
+pci_release_mem_regions(struct pci_dev *pdev)
+{
+	return pci_release_selected_regions(pdev,
+			    pci_select_bars(pdev, IORESOURCE_MEM));
+}
+#endif /* !SLE_VERSION(12,3,0) */
+#else
+#define HAVE_UDP_ENC_RX_OFFLOAD
+#endif /* 4.8.0 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,9,0))
+#if (RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,4)))
+#define HAVE_ETHTOOL_NEW_10G_BITS
+#endif /* RHEL */
+#else
+#define HAVE_ETHTOOL_NEW_10G_BITS
+#endif /* 4.9.0 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,10,0))
+#if (RHEL_RELEASE_CODE && (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(7,4)))
+#define HAVE_DEV_WALK_API
+#endif
+#if (SLE_VERSION_CODE && (SLE_VERSION_CODE >= SLE_VERSION(12,3,0)))
+#define HAVE_STRUCT_DMA_ATTRS
+#define HAVE_NETDEVICE_MIN_MAX_MTU
+#endif
+
+#if !(SLE_VERSION_CODE && (SLE_VERSION_CODE >= SLE_VERSION(12,3,0)))
+#ifndef dma_map_page_attrs
+#define dma_map_page_attrs __kc_dma_map_page_attrs
+static inline dma_addr_t __kc_dma_map_page_attrs(struct device *dev,
+						 struct page *page,
+						 size_t offset, size_t size,
+						 enum dma_data_direction dir,
+						 unsigned long __always_unused attrs)
+{
+	return dma_map_page(dev, page, offset, size, dir);
+}
+#endif
+
+#ifndef dma_unmap_page_attrs
+#define dma_unmap_page_attrs __kc_dma_unmap_page_attrs
+static inline void __kc_dma_unmap_page_attrs(struct device *dev,
+					     dma_addr_t addr, size_t size,
+					     enum dma_data_direction dir,
+					     unsigned long __always_unused attrs)
+{
+	dma_unmap_page(dev, addr, size, dir);
+}
+#endif
+
+static inline void __page_frag_cache_drain(struct page *page,
+					   unsigned int count)
+{
+#ifdef HAVE_PAGE_COUNT_BULK_UPDATE
+	if (!page_ref_sub_and_test(page, count))
+		return;
+
+	init_page_count(page);
+#else
+	BUG_ON(count > 1);
+	if (!count)
+		return;
+#endif
+	__free_pages(page, compound_order(page));
+}
+#endif /* !SLE_VERSION(12,3,0) */
+#ifndef ETH_MIN_MTU
+#define ETH_MIN_MTU 68
+#endif /* ETH_MIN_MTU */
+#else /* >= 4.10 */
+#define HAVE_NETDEVICE_MIN_MAX_MTU
+#define HAVE_SWIOTLB_SKIP_CPU_SYNC
+#define HAVE_NETDEV_TC_RESETS_XPS
+#define HAVE_XPS_QOS_SUPPORT
+#define HAVE_DEV_WALK_API
+#endif /* 4.10.0 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,11,0))
+#ifdef CONFIG_NET_RX_BUSY_POLL
+#define HAVE_NDO_BUSY_POLL
+#if (SLE_VERSION_CODE && (SLE_VERSION_CODE >= SLE_VERSION(12,3,0)))
+#define HAVE_VOID_NDO_GET_STATS64
+#endif
+#endif
+#else /* > 4.11 */
+#define HAVE_VOID_NDO_GET_STATS64
+#define HAVE_VM_OPS_FAULT_NO_VMA
+#endif /* 4.11.0 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,13,0))
+#else /* > 4.13 */
+#define HAVE_HWTSTAMP_FILTER_NTP_ALL
+#define HAVE_NDO_SETUP_TC_CHAIN_INDEX
+#define HAVE_PCI_ERROR_HANDLER_RESET_PREPARE
+#define HAVE_PTP_CLOCK_DO_AUX_WORK
+#endif /* 4.13.0 */
+
+/*****************************************************************************/
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,14,0))
+#else /* > 4.14 */
+#define HAVE_NDO_SETUP_TC_REMOVE_TC_TO_NETDEV
+#endif /* 4.14.0 */
+
+#endif /* _KCOMPAT_H_ */
diff --git a/drivers/net/ethernet/intel/ixgbe/kcompat_ethtool.c b/drivers/net/ethernet/intel/ixgbe/kcompat_ethtool.c
new file mode 100644
index 00000000..16fbd74
--- /dev/null
+++ b/drivers/net/ethernet/intel/ixgbe/kcompat_ethtool.c
@@ -0,0 +1,1169 @@
+/*******************************************************************************
+
+  Intel(R) 10GbE PCI Express Linux Network Driver
+  Copyright(c) 1999 - 2017 Intel Corporation.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms and conditions of the GNU General Public License,
+  version 2, as published by the Free Software Foundation.
+
+  This program is distributed in the hope it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+  more details.
+
+  The full GNU General Public License is included in this distribution in
+  the file called "COPYING".
+
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  e1000-devel Mailing List <e1000-devel@lists.sourceforge.net>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+
+*******************************************************************************/
+
+/*
+ * net/core/ethtool.c - Ethtool ioctl handler
+ * Copyright (c) 2003 Matthew Wilcox <matthew@wil.cx>
+ *
+ * This file is where we call all the ethtool_ops commands to get
+ * the information ethtool needs.  We fall back to calling do_ioctl()
+ * for drivers which haven't been converted to ethtool_ops yet.
+ *
+ * It's GPL, stupid.
+ *
+ * Modification by sfeldma@pobox.com to work as backward compat
+ * solution for pre-ethtool_ops kernels.
+ * 	- copied struct ethtool_ops from ethtool.h
+ * 	- defined SET_ETHTOOL_OPS
+ * 	- put in some #ifndef NETIF_F_xxx wrappers
+ * 	- changes refs to dev->ethtool_ops to ethtool_ops
+ * 	- changed dev_ethtool to ethtool_ioctl
+ *      - remove EXPORT_SYMBOL()s
+ *      - added _kc_ prefix in built-in ethtool_op_xxx ops.
+ */
+
+#include <linux/module.h>
+#include <linux/types.h>
+#include <linux/errno.h>
+#include <linux/mii.h>
+#include <linux/ethtool.h>
+#include <linux/netdevice.h>
+#include <asm/uaccess.h>
+
+#include "kcompat.h"
+
+#undef SUPPORTED_10000baseT_Full
+#define SUPPORTED_10000baseT_Full	(1 << 12)
+#undef ADVERTISED_10000baseT_Full
+#define ADVERTISED_10000baseT_Full	(1 << 12)
+#undef SPEED_10000
+#define SPEED_10000		10000
+
+#undef ethtool_ops
+#define ethtool_ops _kc_ethtool_ops
+
+struct _kc_ethtool_ops {
+	int  (*get_settings)(struct net_device *, struct ethtool_cmd *);
+	int  (*set_settings)(struct net_device *, struct ethtool_cmd *);
+	void (*get_drvinfo)(struct net_device *, struct ethtool_drvinfo *);
+	int  (*get_regs_len)(struct net_device *);
+	void (*get_regs)(struct net_device *, struct ethtool_regs *, void *);
+	void (*get_wol)(struct net_device *, struct ethtool_wolinfo *);
+	int  (*set_wol)(struct net_device *, struct ethtool_wolinfo *);
+	u32  (*get_msglevel)(struct net_device *);
+	void (*set_msglevel)(struct net_device *, u32);
+	int  (*nway_reset)(struct net_device *);
+	u32  (*get_link)(struct net_device *);
+	int  (*get_eeprom_len)(struct net_device *);
+	int  (*get_eeprom)(struct net_device *, struct ethtool_eeprom *, u8 *);
+	int  (*set_eeprom)(struct net_device *, struct ethtool_eeprom *, u8 *);
+	int  (*get_coalesce)(struct net_device *, struct ethtool_coalesce *);
+	int  (*set_coalesce)(struct net_device *, struct ethtool_coalesce *);
+	void (*get_ringparam)(struct net_device *, struct ethtool_ringparam *);
+	int  (*set_ringparam)(struct net_device *, struct ethtool_ringparam *);
+	void (*get_pauseparam)(struct net_device *,
+	                       struct ethtool_pauseparam*);
+	int  (*set_pauseparam)(struct net_device *,
+	                       struct ethtool_pauseparam*);
+	u32  (*get_rx_csum)(struct net_device *);
+	int  (*set_rx_csum)(struct net_device *, u32);
+	u32  (*get_tx_csum)(struct net_device *);
+	int  (*set_tx_csum)(struct net_device *, u32);
+	u32  (*get_sg)(struct net_device *);
+	int  (*set_sg)(struct net_device *, u32);
+	u32  (*get_tso)(struct net_device *);
+	int  (*set_tso)(struct net_device *, u32);
+	int  (*self_test_count)(struct net_device *);
+	void (*self_test)(struct net_device *, struct ethtool_test *, u64 *);
+	void (*get_strings)(struct net_device *, u32 stringset, u8 *);
+	int  (*phys_id)(struct net_device *, u32);
+	int  (*get_stats_count)(struct net_device *);
+	void (*get_ethtool_stats)(struct net_device *, struct ethtool_stats *,
+	                          u64 *);
+} *ethtool_ops = NULL;
+
+#undef SET_ETHTOOL_OPS
+#define SET_ETHTOOL_OPS(netdev, ops) (ethtool_ops = (ops))
+
+/*
+ * Some useful ethtool_ops methods that are device independent. If we find that
+ * all drivers want to do the same thing here, we can turn these into dev_()
+ * function calls.
+ */
+
+#undef ethtool_op_get_link
+#define ethtool_op_get_link _kc_ethtool_op_get_link
+u32 _kc_ethtool_op_get_link(struct net_device *dev)
+{
+	return netif_carrier_ok(dev) ? 1 : 0;
+}
+
+#undef ethtool_op_get_tx_csum
+#define ethtool_op_get_tx_csum _kc_ethtool_op_get_tx_csum
+u32 _kc_ethtool_op_get_tx_csum(struct net_device *dev)
+{
+#ifdef NETIF_F_IP_CSUM
+	return (dev->features & NETIF_F_IP_CSUM) != 0;
+#else
+	return 0;
+#endif
+}
+
+#undef ethtool_op_set_tx_csum
+#define ethtool_op_set_tx_csum _kc_ethtool_op_set_tx_csum
+int _kc_ethtool_op_set_tx_csum(struct net_device *dev, u32 data)
+{
+#ifdef NETIF_F_IP_CSUM
+	if (data)
+#ifdef NETIF_F_IPV6_CSUM
+		dev->features |= (NETIF_F_IP_CSUM | NETIF_F_IPV6_CSUM);
+	else
+		dev->features &= ~(NETIF_F_IP_CSUM | NETIF_F_IPV6_CSUM);
+#else
+		dev->features |= NETIF_F_IP_CSUM;
+	else
+		dev->features &= ~NETIF_F_IP_CSUM;
+#endif
+#endif
+
+	return 0;
+}
+
+#undef ethtool_op_get_sg
+#define ethtool_op_get_sg _kc_ethtool_op_get_sg
+u32 _kc_ethtool_op_get_sg(struct net_device *dev)
+{
+#ifdef NETIF_F_SG
+	return (dev->features & NETIF_F_SG) != 0;
+#else
+	return 0;
+#endif
+}
+
+#undef ethtool_op_set_sg
+#define ethtool_op_set_sg _kc_ethtool_op_set_sg
+int _kc_ethtool_op_set_sg(struct net_device *dev, u32 data)
+{
+#ifdef NETIF_F_SG
+	if (data)
+		dev->features |= NETIF_F_SG;
+	else
+		dev->features &= ~NETIF_F_SG;
+#endif
+
+	return 0;
+}
+
+#undef ethtool_op_get_tso
+#define ethtool_op_get_tso _kc_ethtool_op_get_tso
+u32 _kc_ethtool_op_get_tso(struct net_device *dev)
+{
+#ifdef NETIF_F_TSO
+	return (dev->features & NETIF_F_TSO) != 0;
+#else
+	return 0;
+#endif
+}
+
+#undef ethtool_op_set_tso
+#define ethtool_op_set_tso _kc_ethtool_op_set_tso
+int _kc_ethtool_op_set_tso(struct net_device *dev, u32 data)
+{
+#ifdef NETIF_F_TSO
+	if (data)
+		dev->features |= NETIF_F_TSO;
+	else
+		dev->features &= ~NETIF_F_TSO;
+#endif
+
+	return 0;
+}
+
+/* Handlers for each ethtool command */
+
+static int ethtool_get_settings(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_cmd cmd = { ETHTOOL_GSET };
+	int err;
+
+	if (!ethtool_ops->get_settings)
+		return -EOPNOTSUPP;
+
+	err = ethtool_ops->get_settings(dev, &cmd);
+	if (err < 0)
+		return err;
+
+	if (copy_to_user(useraddr, &cmd, sizeof(cmd)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_set_settings(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_cmd cmd;
+
+	if (!ethtool_ops->set_settings)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&cmd, useraddr, sizeof(cmd)))
+		return -EFAULT;
+
+	return ethtool_ops->set_settings(dev, &cmd);
+}
+
+static int ethtool_get_drvinfo(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_drvinfo info;
+	struct ethtool_ops *ops = ethtool_ops;
+
+	if (!ops->get_drvinfo)
+		return -EOPNOTSUPP;
+
+	memset(&info, 0, sizeof(info));
+	info.cmd = ETHTOOL_GDRVINFO;
+	ops->get_drvinfo(dev, &info);
+
+	if (ops->self_test_count)
+		info.testinfo_len = ops->self_test_count(dev);
+	if (ops->get_stats_count)
+		info.n_stats = ops->get_stats_count(dev);
+	if (ops->get_regs_len)
+		info.regdump_len = ops->get_regs_len(dev);
+	if (ops->get_eeprom_len)
+		info.eedump_len = ops->get_eeprom_len(dev);
+
+	if (copy_to_user(useraddr, &info, sizeof(info)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_get_regs(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_regs regs;
+	struct ethtool_ops *ops = ethtool_ops;
+	void *regbuf;
+	int reglen, ret;
+
+	if (!ops->get_regs || !ops->get_regs_len)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&regs, useraddr, sizeof(regs)))
+		return -EFAULT;
+
+	reglen = ops->get_regs_len(dev);
+	if (regs.len > reglen)
+		regs.len = reglen;
+
+	regbuf = kmalloc(reglen, GFP_USER);
+	if (!regbuf)
+		return -ENOMEM;
+
+	ops->get_regs(dev, &regs, regbuf);
+
+	ret = -EFAULT;
+	if (copy_to_user(useraddr, &regs, sizeof(regs)))
+		goto out;
+	useraddr += offsetof(struct ethtool_regs, data);
+	if (copy_to_user(useraddr, regbuf, reglen))
+		goto out;
+	ret = 0;
+
+out:
+	kfree(regbuf);
+	return ret;
+}
+
+static int ethtool_get_wol(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_wolinfo wol = { ETHTOOL_GWOL };
+
+	if (!ethtool_ops->get_wol)
+		return -EOPNOTSUPP;
+
+	ethtool_ops->get_wol(dev, &wol);
+
+	if (copy_to_user(useraddr, &wol, sizeof(wol)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_set_wol(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_wolinfo wol;
+
+	if (!ethtool_ops->set_wol)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&wol, useraddr, sizeof(wol)))
+		return -EFAULT;
+
+	return ethtool_ops->set_wol(dev, &wol);
+}
+
+static int ethtool_get_msglevel(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_value edata = { ETHTOOL_GMSGLVL };
+
+	if (!ethtool_ops->get_msglevel)
+		return -EOPNOTSUPP;
+
+	edata.data = ethtool_ops->get_msglevel(dev);
+
+	if (copy_to_user(useraddr, &edata, sizeof(edata)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_set_msglevel(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_value edata;
+
+	if (!ethtool_ops->set_msglevel)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&edata, useraddr, sizeof(edata)))
+		return -EFAULT;
+
+	ethtool_ops->set_msglevel(dev, edata.data);
+	return 0;
+}
+
+static int ethtool_nway_reset(struct net_device *dev)
+{
+	if (!ethtool_ops->nway_reset)
+		return -EOPNOTSUPP;
+
+	return ethtool_ops->nway_reset(dev);
+}
+
+static int ethtool_get_link(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_value edata = { ETHTOOL_GLINK };
+
+	if (!ethtool_ops->get_link)
+		return -EOPNOTSUPP;
+
+	edata.data = ethtool_ops->get_link(dev);
+
+	if (copy_to_user(useraddr, &edata, sizeof(edata)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_get_eeprom(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_eeprom eeprom;
+	struct ethtool_ops *ops = ethtool_ops;
+	u8 *data;
+	int ret;
+
+	if (!ops->get_eeprom || !ops->get_eeprom_len)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&eeprom, useraddr, sizeof(eeprom)))
+		return -EFAULT;
+
+	/* Check for wrap and zero */
+	if (eeprom.offset + eeprom.len <= eeprom.offset)
+		return -EINVAL;
+
+	/* Check for exceeding total eeprom len */
+	if (eeprom.offset + eeprom.len > ops->get_eeprom_len(dev))
+		return -EINVAL;
+
+	data = kmalloc(eeprom.len, GFP_USER);
+	if (!data)
+		return -ENOMEM;
+
+	ret = -EFAULT;
+	if (copy_from_user(data, useraddr + sizeof(eeprom), eeprom.len))
+		goto out;
+
+	ret = ops->get_eeprom(dev, &eeprom, data);
+	if (ret)
+		goto out;
+
+	ret = -EFAULT;
+	if (copy_to_user(useraddr, &eeprom, sizeof(eeprom)))
+		goto out;
+	if (copy_to_user(useraddr + sizeof(eeprom), data, eeprom.len))
+		goto out;
+	ret = 0;
+
+out:
+	kfree(data);
+	return ret;
+}
+
+static int ethtool_set_eeprom(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_eeprom eeprom;
+	struct ethtool_ops *ops = ethtool_ops;
+	u8 *data;
+	int ret;
+
+	if (!ops->set_eeprom || !ops->get_eeprom_len)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&eeprom, useraddr, sizeof(eeprom)))
+		return -EFAULT;
+
+	/* Check for wrap and zero */
+	if (eeprom.offset + eeprom.len <= eeprom.offset)
+		return -EINVAL;
+
+	/* Check for exceeding total eeprom len */
+	if (eeprom.offset + eeprom.len > ops->get_eeprom_len(dev))
+		return -EINVAL;
+
+	data = kmalloc(eeprom.len, GFP_USER);
+	if (!data)
+		return -ENOMEM;
+
+	ret = -EFAULT;
+	if (copy_from_user(data, useraddr + sizeof(eeprom), eeprom.len))
+		goto out;
+
+	ret = ops->set_eeprom(dev, &eeprom, data);
+	if (ret)
+		goto out;
+
+	if (copy_to_user(useraddr + sizeof(eeprom), data, eeprom.len))
+		ret = -EFAULT;
+
+out:
+	kfree(data);
+	return ret;
+}
+
+static int ethtool_get_coalesce(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_coalesce coalesce = { ETHTOOL_GCOALESCE };
+
+	if (!ethtool_ops->get_coalesce)
+		return -EOPNOTSUPP;
+
+	ethtool_ops->get_coalesce(dev, &coalesce);
+
+	if (copy_to_user(useraddr, &coalesce, sizeof(coalesce)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_set_coalesce(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_coalesce coalesce;
+
+	if (!ethtool_ops->get_coalesce)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&coalesce, useraddr, sizeof(coalesce)))
+		return -EFAULT;
+
+	return ethtool_ops->set_coalesce(dev, &coalesce);
+}
+
+static int ethtool_get_ringparam(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_ringparam ringparam = { ETHTOOL_GRINGPARAM };
+
+	if (!ethtool_ops->get_ringparam)
+		return -EOPNOTSUPP;
+
+	ethtool_ops->get_ringparam(dev, &ringparam);
+
+	if (copy_to_user(useraddr, &ringparam, sizeof(ringparam)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_set_ringparam(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_ringparam ringparam;
+
+	if (!ethtool_ops->get_ringparam)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&ringparam, useraddr, sizeof(ringparam)))
+		return -EFAULT;
+
+	return ethtool_ops->set_ringparam(dev, &ringparam);
+}
+
+static int ethtool_get_pauseparam(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_pauseparam pauseparam = { ETHTOOL_GPAUSEPARAM };
+
+	if (!ethtool_ops->get_pauseparam)
+		return -EOPNOTSUPP;
+
+	ethtool_ops->get_pauseparam(dev, &pauseparam);
+
+	if (copy_to_user(useraddr, &pauseparam, sizeof(pauseparam)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_set_pauseparam(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_pauseparam pauseparam;
+
+	if (!ethtool_ops->get_pauseparam)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&pauseparam, useraddr, sizeof(pauseparam)))
+		return -EFAULT;
+
+	return ethtool_ops->set_pauseparam(dev, &pauseparam);
+}
+
+static int ethtool_get_rx_csum(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_value edata = { ETHTOOL_GRXCSUM };
+
+	if (!ethtool_ops->get_rx_csum)
+		return -EOPNOTSUPP;
+
+	edata.data = ethtool_ops->get_rx_csum(dev);
+
+	if (copy_to_user(useraddr, &edata, sizeof(edata)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_set_rx_csum(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_value edata;
+
+	if (!ethtool_ops->set_rx_csum)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&edata, useraddr, sizeof(edata)))
+		return -EFAULT;
+
+	ethtool_ops->set_rx_csum(dev, edata.data);
+	return 0;
+}
+
+static int ethtool_get_tx_csum(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_value edata = { ETHTOOL_GTXCSUM };
+
+	if (!ethtool_ops->get_tx_csum)
+		return -EOPNOTSUPP;
+
+	edata.data = ethtool_ops->get_tx_csum(dev);
+
+	if (copy_to_user(useraddr, &edata, sizeof(edata)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_set_tx_csum(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_value edata;
+
+	if (!ethtool_ops->set_tx_csum)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&edata, useraddr, sizeof(edata)))
+		return -EFAULT;
+
+	return ethtool_ops->set_tx_csum(dev, edata.data);
+}
+
+static int ethtool_get_sg(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_value edata = { ETHTOOL_GSG };
+
+	if (!ethtool_ops->get_sg)
+		return -EOPNOTSUPP;
+
+	edata.data = ethtool_ops->get_sg(dev);
+
+	if (copy_to_user(useraddr, &edata, sizeof(edata)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_set_sg(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_value edata;
+
+	if (!ethtool_ops->set_sg)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&edata, useraddr, sizeof(edata)))
+		return -EFAULT;
+
+	return ethtool_ops->set_sg(dev, edata.data);
+}
+
+static int ethtool_get_tso(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_value edata = { ETHTOOL_GTSO };
+
+	if (!ethtool_ops->get_tso)
+		return -EOPNOTSUPP;
+
+	edata.data = ethtool_ops->get_tso(dev);
+
+	if (copy_to_user(useraddr, &edata, sizeof(edata)))
+		return -EFAULT;
+	return 0;
+}
+
+static int ethtool_set_tso(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_value edata;
+
+	if (!ethtool_ops->set_tso)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&edata, useraddr, sizeof(edata)))
+		return -EFAULT;
+
+	return ethtool_ops->set_tso(dev, edata.data);
+}
+
+static int ethtool_self_test(struct net_device *dev, char *useraddr)
+{
+	struct ethtool_test test;
+	struct ethtool_ops *ops = ethtool_ops;
+	u64 *data;
+	int ret;
+
+	if (!ops->self_test || !ops->self_test_count)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&test, useraddr, sizeof(test)))
+		return -EFAULT;
+
+	test.len = ops->self_test_count(dev);
+	data = kmalloc(test.len * sizeof(u64), GFP_USER);
+	if (!data)
+		return -ENOMEM;
+
+	ops->self_test(dev, &test, data);
+
+	ret = -EFAULT;
+	if (copy_to_user(useraddr, &test, sizeof(test)))
+		goto out;
+	useraddr += sizeof(test);
+	if (copy_to_user(useraddr, data, test.len * sizeof(u64)))
+		goto out;
+	ret = 0;
+
+out:
+	kfree(data);
+	return ret;
+}
+
+static int ethtool_get_strings(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_gstrings gstrings;
+	struct ethtool_ops *ops = ethtool_ops;
+	u8 *data;
+	int ret;
+
+	if (!ops->get_strings)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&gstrings, useraddr, sizeof(gstrings)))
+		return -EFAULT;
+
+	switch (gstrings.string_set) {
+	case ETH_SS_TEST:
+		if (!ops->self_test_count)
+			return -EOPNOTSUPP;
+		gstrings.len = ops->self_test_count(dev);
+		break;
+	case ETH_SS_STATS:
+		if (!ops->get_stats_count)
+			return -EOPNOTSUPP;
+		gstrings.len = ops->get_stats_count(dev);
+		break;
+	default:
+		return -EINVAL;
+	}
+
+	data = kmalloc(gstrings.len * ETH_GSTRING_LEN, GFP_USER);
+	if (!data)
+		return -ENOMEM;
+
+	ops->get_strings(dev, gstrings.string_set, data);
+
+	ret = -EFAULT;
+	if (copy_to_user(useraddr, &gstrings, sizeof(gstrings)))
+		goto out;
+	useraddr += sizeof(gstrings);
+	if (copy_to_user(useraddr, data, gstrings.len * ETH_GSTRING_LEN))
+		goto out;
+	ret = 0;
+
+out:
+	kfree(data);
+	return ret;
+}
+
+static int ethtool_phys_id(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_value id;
+
+	if (!ethtool_ops->phys_id)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&id, useraddr, sizeof(id)))
+		return -EFAULT;
+
+	return ethtool_ops->phys_id(dev, id.data);
+}
+
+static int ethtool_get_stats(struct net_device *dev, void *useraddr)
+{
+	struct ethtool_stats stats;
+	struct ethtool_ops *ops = ethtool_ops;
+	u64 *data;
+	int ret;
+
+	if (!ops->get_ethtool_stats || !ops->get_stats_count)
+		return -EOPNOTSUPP;
+
+	if (copy_from_user(&stats, useraddr, sizeof(stats)))
+		return -EFAULT;
+
+	stats.n_stats = ops->get_stats_count(dev);
+	data = kmalloc(stats.n_stats * sizeof(u64), GFP_USER);
+	if (!data)
+		return -ENOMEM;
+
+	ops->get_ethtool_stats(dev, &stats, data);
+
+	ret = -EFAULT;
+	if (copy_to_user(useraddr, &stats, sizeof(stats)))
+		goto out;
+	useraddr += sizeof(stats);
+	if (copy_to_user(useraddr, data, stats.n_stats * sizeof(u64)))
+		goto out;
+	ret = 0;
+
+out:
+	kfree(data);
+	return ret;
+}
+
+/* The main entry point in this file.  Called from net/core/dev.c */
+
+#define ETHTOOL_OPS_COMPAT
+int ethtool_ioctl(struct ifreq *ifr)
+{
+	struct net_device *dev = __dev_get_by_name(ifr->ifr_name);
+	void *useraddr = (void *) ifr->ifr_data;
+	u32 ethcmd;
+
+	/*
+	 * XXX: This can be pushed down into the ethtool_* handlers that
+	 * need it.  Keep existing behavior for the moment.
+	 */
+	if (!capable(CAP_NET_ADMIN))
+		return -EPERM;
+
+	if (!dev || !netif_device_present(dev))
+		return -ENODEV;
+
+	if (copy_from_user(&ethcmd, useraddr, sizeof (ethcmd)))
+		return -EFAULT;
+
+	switch (ethcmd) {
+	case ETHTOOL_GSET:
+		return ethtool_get_settings(dev, useraddr);
+	case ETHTOOL_SSET:
+		return ethtool_set_settings(dev, useraddr);
+	case ETHTOOL_GDRVINFO:
+		return ethtool_get_drvinfo(dev, useraddr);
+	case ETHTOOL_GREGS:
+		return ethtool_get_regs(dev, useraddr);
+	case ETHTOOL_GWOL:
+		return ethtool_get_wol(dev, useraddr);
+	case ETHTOOL_SWOL:
+		return ethtool_set_wol(dev, useraddr);
+	case ETHTOOL_GMSGLVL:
+		return ethtool_get_msglevel(dev, useraddr);
+	case ETHTOOL_SMSGLVL:
+		return ethtool_set_msglevel(dev, useraddr);
+	case ETHTOOL_NWAY_RST:
+		return ethtool_nway_reset(dev);
+	case ETHTOOL_GLINK:
+		return ethtool_get_link(dev, useraddr);
+	case ETHTOOL_GEEPROM:
+		return ethtool_get_eeprom(dev, useraddr);
+	case ETHTOOL_SEEPROM:
+		return ethtool_set_eeprom(dev, useraddr);
+	case ETHTOOL_GCOALESCE:
+		return ethtool_get_coalesce(dev, useraddr);
+	case ETHTOOL_SCOALESCE:
+		return ethtool_set_coalesce(dev, useraddr);
+	case ETHTOOL_GRINGPARAM:
+		return ethtool_get_ringparam(dev, useraddr);
+	case ETHTOOL_SRINGPARAM:
+		return ethtool_set_ringparam(dev, useraddr);
+	case ETHTOOL_GPAUSEPARAM:
+		return ethtool_get_pauseparam(dev, useraddr);
+	case ETHTOOL_SPAUSEPARAM:
+		return ethtool_set_pauseparam(dev, useraddr);
+	case ETHTOOL_GRXCSUM:
+		return ethtool_get_rx_csum(dev, useraddr);
+	case ETHTOOL_SRXCSUM:
+		return ethtool_set_rx_csum(dev, useraddr);
+	case ETHTOOL_GTXCSUM:
+		return ethtool_get_tx_csum(dev, useraddr);
+	case ETHTOOL_STXCSUM:
+		return ethtool_set_tx_csum(dev, useraddr);
+	case ETHTOOL_GSG:
+		return ethtool_get_sg(dev, useraddr);
+	case ETHTOOL_SSG:
+		return ethtool_set_sg(dev, useraddr);
+	case ETHTOOL_GTSO:
+		return ethtool_get_tso(dev, useraddr);
+	case ETHTOOL_STSO:
+		return ethtool_set_tso(dev, useraddr);
+	case ETHTOOL_TEST:
+		return ethtool_self_test(dev, useraddr);
+	case ETHTOOL_GSTRINGS:
+		return ethtool_get_strings(dev, useraddr);
+	case ETHTOOL_PHYS_ID:
+		return ethtool_phys_id(dev, useraddr);
+	case ETHTOOL_GSTATS:
+		return ethtool_get_stats(dev, useraddr);
+	default:
+		return -EOPNOTSUPP;
+	}
+
+	return -EOPNOTSUPP;
+}
+
+#define mii_if_info _kc_mii_if_info
+struct _kc_mii_if_info {
+	int phy_id;
+	int advertising;
+	int phy_id_mask;
+	int reg_num_mask;
+
+	unsigned int full_duplex : 1;	/* is full duplex? */
+	unsigned int force_media : 1;	/* is autoneg. disabled? */
+
+	struct net_device *dev;
+	int (*mdio_read) (struct net_device *dev, int phy_id, int location);
+	void (*mdio_write) (struct net_device *dev, int phy_id, int location, int val);
+};
+
+struct ethtool_cmd;
+struct mii_ioctl_data;
+
+#undef mii_link_ok
+#define mii_link_ok _kc_mii_link_ok
+#undef mii_nway_restart
+#define mii_nway_restart _kc_mii_nway_restart
+#undef mii_ethtool_gset
+#define mii_ethtool_gset _kc_mii_ethtool_gset
+#undef mii_ethtool_sset
+#define mii_ethtool_sset _kc_mii_ethtool_sset
+#undef mii_check_link
+#define mii_check_link _kc_mii_check_link
+extern int _kc_mii_link_ok (struct mii_if_info *mii);
+extern int _kc_mii_nway_restart (struct mii_if_info *mii);
+extern int _kc_mii_ethtool_gset(struct mii_if_info *mii,
+                                struct ethtool_cmd *ecmd);
+extern int _kc_mii_ethtool_sset(struct mii_if_info *mii,
+                                struct ethtool_cmd *ecmd);
+extern void _kc_mii_check_link (struct mii_if_info *mii);
+#if ( LINUX_VERSION_CODE > KERNEL_VERSION(2,4,6) )
+#undef generic_mii_ioctl
+#define generic_mii_ioctl _kc_generic_mii_ioctl
+extern int _kc_generic_mii_ioctl(struct mii_if_info *mii_if,
+                                 struct mii_ioctl_data *mii_data, int cmd,
+                                 unsigned int *duplex_changed);
+#endif /* > 2.4.6 */
+
+
+struct _kc_pci_dev_ext {
+	struct pci_dev *dev;
+	void *pci_drvdata;
+	struct pci_driver *driver;
+};
+
+struct _kc_net_dev_ext {
+	struct net_device *dev;
+	unsigned int carrier;
+};
+
+
+/**************************************/
+/* mii support */
+
+int _kc_mii_ethtool_gset(struct mii_if_info *mii, struct ethtool_cmd *ecmd)
+{
+	struct net_device *dev = mii->dev;
+	u32 advert, bmcr, lpa, nego;
+
+	ecmd->supported =
+	    (SUPPORTED_10baseT_Half | SUPPORTED_10baseT_Full |
+	     SUPPORTED_100baseT_Half | SUPPORTED_100baseT_Full |
+	     SUPPORTED_Autoneg | SUPPORTED_TP | SUPPORTED_MII);
+
+	/* only supports twisted-pair */
+	ecmd->port = PORT_MII;
+
+	/* only supports internal transceiver */
+	ecmd->transceiver = XCVR_INTERNAL;
+
+	/* this isn't fully supported at higher layers */
+	ecmd->phy_address = mii->phy_id;
+
+	ecmd->advertising = ADVERTISED_TP | ADVERTISED_MII;
+	advert = mii->mdio_read(dev, mii->phy_id, MII_ADVERTISE);
+	if (advert & ADVERTISE_10HALF)
+		ecmd->advertising |= ADVERTISED_10baseT_Half;
+	if (advert & ADVERTISE_10FULL)
+		ecmd->advertising |= ADVERTISED_10baseT_Full;
+	if (advert & ADVERTISE_100HALF)
+		ecmd->advertising |= ADVERTISED_100baseT_Half;
+	if (advert & ADVERTISE_100FULL)
+		ecmd->advertising |= ADVERTISED_100baseT_Full;
+
+	bmcr = mii->mdio_read(dev, mii->phy_id, MII_BMCR);
+	lpa = mii->mdio_read(dev, mii->phy_id, MII_LPA);
+	if (bmcr & BMCR_ANENABLE) {
+		ecmd->advertising |= ADVERTISED_Autoneg;
+		ecmd->autoneg = AUTONEG_ENABLE;
+
+		nego = mii_nway_result(advert & lpa);
+		if (nego == LPA_100FULL || nego == LPA_100HALF)
+			ecmd->speed = SPEED_100;
+		else
+			ecmd->speed = SPEED_10;
+		if (nego == LPA_100FULL || nego == LPA_10FULL) {
+			ecmd->duplex = DUPLEX_FULL;
+			mii->full_duplex = 1;
+		} else {
+			ecmd->duplex = DUPLEX_HALF;
+			mii->full_duplex = 0;
+		}
+	} else {
+		ecmd->autoneg = AUTONEG_DISABLE;
+
+		ecmd->speed = (bmcr & BMCR_SPEED100) ? SPEED_100 : SPEED_10;
+		ecmd->duplex = (bmcr & BMCR_FULLDPLX) ? DUPLEX_FULL : DUPLEX_HALF;
+	}
+
+	/* ignore maxtxpkt, maxrxpkt for now */
+
+	return 0;
+}
+
+int _kc_mii_ethtool_sset(struct mii_if_info *mii, struct ethtool_cmd *ecmd)
+{
+	struct net_device *dev = mii->dev;
+
+	if (ecmd->speed != SPEED_10 && ecmd->speed != SPEED_100)
+		return -EINVAL;
+	if (ecmd->duplex != DUPLEX_HALF && ecmd->duplex != DUPLEX_FULL)
+		return -EINVAL;
+	if (ecmd->port != PORT_MII)
+		return -EINVAL;
+	if (ecmd->transceiver != XCVR_INTERNAL)
+		return -EINVAL;
+	if (ecmd->phy_address != mii->phy_id)
+		return -EINVAL;
+	if (ecmd->autoneg != AUTONEG_DISABLE && ecmd->autoneg != AUTONEG_ENABLE)
+		return -EINVAL;
+
+	/* ignore supported, maxtxpkt, maxrxpkt */
+
+	if (ecmd->autoneg == AUTONEG_ENABLE) {
+		u32 bmcr, advert, tmp;
+
+		if ((ecmd->advertising & (ADVERTISED_10baseT_Half |
+					  ADVERTISED_10baseT_Full |
+					  ADVERTISED_100baseT_Half |
+					  ADVERTISED_100baseT_Full)) == 0)
+			return -EINVAL;
+
+		/* advertise only what has been requested */
+		advert = mii->mdio_read(dev, mii->phy_id, MII_ADVERTISE);
+		tmp = advert & ~(ADVERTISE_ALL | ADVERTISE_100BASE4);
+		if (ADVERTISED_10baseT_Half)
+			tmp |= ADVERTISE_10HALF;
+		if (ADVERTISED_10baseT_Full)
+			tmp |= ADVERTISE_10FULL;
+		if (ADVERTISED_100baseT_Half)
+			tmp |= ADVERTISE_100HALF;
+		if (ADVERTISED_100baseT_Full)
+			tmp |= ADVERTISE_100FULL;
+		if (advert != tmp) {
+			mii->mdio_write(dev, mii->phy_id, MII_ADVERTISE, tmp);
+			mii->advertising = tmp;
+		}
+
+		/* turn on autonegotiation, and force a renegotiate */
+		bmcr = mii->mdio_read(dev, mii->phy_id, MII_BMCR);
+		bmcr |= (BMCR_ANENABLE | BMCR_ANRESTART);
+		mii->mdio_write(dev, mii->phy_id, MII_BMCR, bmcr);
+
+		mii->force_media = 0;
+	} else {
+		u32 bmcr, tmp;
+
+		/* turn off auto negotiation, set speed and duplexity */
+		bmcr = mii->mdio_read(dev, mii->phy_id, MII_BMCR);
+		tmp = bmcr & ~(BMCR_ANENABLE | BMCR_SPEED100 | BMCR_FULLDPLX);
+		if (ecmd->speed == SPEED_100)
+			tmp |= BMCR_SPEED100;
+		if (ecmd->duplex == DUPLEX_FULL) {
+			tmp |= BMCR_FULLDPLX;
+			mii->full_duplex = 1;
+		} else
+			mii->full_duplex = 0;
+		if (bmcr != tmp)
+			mii->mdio_write(dev, mii->phy_id, MII_BMCR, tmp);
+
+		mii->force_media = 1;
+	}
+	return 0;
+}
+
+int _kc_mii_link_ok (struct mii_if_info *mii)
+{
+	/* first, a dummy read, needed to latch some MII phys */
+	mii->mdio_read(mii->dev, mii->phy_id, MII_BMSR);
+	if (mii->mdio_read(mii->dev, mii->phy_id, MII_BMSR) & BMSR_LSTATUS)
+		return 1;
+	return 0;
+}
+
+int _kc_mii_nway_restart (struct mii_if_info *mii)
+{
+	int bmcr;
+	int r = -EINVAL;
+
+	/* if autoneg is off, it's an error */
+	bmcr = mii->mdio_read(mii->dev, mii->phy_id, MII_BMCR);
+
+	if (bmcr & BMCR_ANENABLE) {
+		bmcr |= BMCR_ANRESTART;
+		mii->mdio_write(mii->dev, mii->phy_id, MII_BMCR, bmcr);
+		r = 0;
+	}
+
+	return r;
+}
+
+void _kc_mii_check_link (struct mii_if_info *mii)
+{
+	int cur_link = mii_link_ok(mii);
+	int prev_link = netif_carrier_ok(mii->dev);
+
+	if (cur_link && !prev_link)
+		netif_carrier_on(mii->dev);
+	else if (prev_link && !cur_link)
+		netif_carrier_off(mii->dev);
+}
+
+#if ( LINUX_VERSION_CODE > KERNEL_VERSION(2,4,6) )
+int _kc_generic_mii_ioctl(struct mii_if_info *mii_if,
+                          struct mii_ioctl_data *mii_data, int cmd,
+                          unsigned int *duplex_chg_out)
+{
+	int rc = 0;
+	unsigned int duplex_changed = 0;
+
+	if (duplex_chg_out)
+		*duplex_chg_out = 0;
+
+	mii_data->phy_id &= mii_if->phy_id_mask;
+	mii_data->reg_num &= mii_if->reg_num_mask;
+
+	switch(cmd) {
+	case SIOCDEVPRIVATE:	/* binary compat, remove in 2.5 */
+	case SIOCGMIIPHY:
+		mii_data->phy_id = mii_if->phy_id;
+		/* fall through */
+
+	case SIOCDEVPRIVATE + 1:/* binary compat, remove in 2.5 */
+	case SIOCGMIIREG:
+		mii_data->val_out =
+			mii_if->mdio_read(mii_if->dev, mii_data->phy_id,
+					  mii_data->reg_num);
+		break;
+
+	case SIOCDEVPRIVATE + 2:/* binary compat, remove in 2.5 */
+	case SIOCSMIIREG: {
+		u16 val = mii_data->val_in;
+
+		if (!capable(CAP_NET_ADMIN))
+			return -EPERM;
+
+		if (mii_data->phy_id == mii_if->phy_id) {
+			switch(mii_data->reg_num) {
+			case MII_BMCR: {
+				unsigned int new_duplex = 0;
+				if (val & (BMCR_RESET|BMCR_ANENABLE))
+					mii_if->force_media = 0;
+				else
+					mii_if->force_media = 1;
+				if (mii_if->force_media &&
+				    (val & BMCR_FULLDPLX))
+					new_duplex = 1;
+				if (mii_if->full_duplex != new_duplex) {
+					duplex_changed = 1;
+					mii_if->full_duplex = new_duplex;
+				}
+				break;
+			}
+			case MII_ADVERTISE:
+				mii_if->advertising = val;
+				break;
+			default:
+				/* do nothing */
+				break;
+			}
+		}
+
+		mii_if->mdio_write(mii_if->dev, mii_data->phy_id,
+				   mii_data->reg_num, val);
+		break;
+	}
+
+	default:
+		rc = -EOPNOTSUPP;
+		break;
+	}
+
+	if ((rc == 0) && (duplex_chg_out) && (duplex_changed))
+		*duplex_chg_out = 1;
+
+	return rc;
+}
+#endif /* > 2.4.6 */
+
diff --git a/drivers/net/phy/phy.c b/drivers/net/phy/phy.c
index 7d069043..8ae4dec 100644
--- a/drivers/net/phy/phy.c
+++ b/drivers/net/phy/phy.c
@@ -35,6 +35,9 @@
 #include <linux/io.h>
 #include <linux/uaccess.h>
 #include <linux/atomic.h>
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+#include "buffalo/kernevnt.h"
+#endif
 
 #include <asm/irq.h>
 
@@ -805,6 +808,45 @@ void phy_start(struct phy_device *phydev)
 }
 EXPORT_SYMBOL(phy_start);
 
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+extern int phy_deferred_linkdown;
+/* phy_adjust_link() : wrapper of phydev->adjust_link() function to generate
+ * 'lanact' kernelevent by generic way.
+ */
+static void phy_adjust_link(struct phy_device *phydev)
+{
+	struct net_device *netdev = phydev->attached_dev;
+	int new_state = 0;
+	unsigned int max_linkdown = max(phy_deferred_linkdown, 1);
+
+	BUG_ON(!netdev);
+	phydev->adjust_link(netdev);
+	/* prepare for called just after initialization */
+	if (phydev->state_cache.downcnt == ~0U) {
+		phydev->state_cache.downcnt = max_linkdown;
+	}
+	if (phydev->link) {
+		/* issue event when link-down count was expired */
+		new_state += (phydev->link != phydev->state_cache.link);
+		new_state += (phydev->speed != phydev->state_cache.speed);
+		new_state += (phydev->duplex != phydev->state_cache.duplex);
+		phydev->state_cache.link = 1;
+		phydev->state_cache.downcnt = 0;
+		phydev->state_cache.speed = phydev->speed;
+		phydev->state_cache.duplex = phydev->duplex;
+	} else {
+		/* issue event only when link-down count was overflow */
+		phydev->state_cache.downcnt++;
+		if (phydev->state_cache.downcnt >= max_linkdown) {
+			new_state += (phydev->state_cache.link != 0);
+			phydev->state_cache.link = 0;
+		}
+	}
+	if (new_state) {
+		kernevnt_LanAct(phydev);
+	}
+}
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 /**
  * phy_state_machine - Handle the state machine
  * @work: work_struct that describes the work to be done
@@ -847,7 +889,11 @@ void phy_state_machine(struct work_struct *work)
 		if (!phydev->link) {
 			phydev->state = PHY_NOLINK;
 			netif_carrier_off(phydev->attached_dev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+			phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			break;
 		}
 
@@ -860,7 +906,11 @@ void phy_state_machine(struct work_struct *work)
 		if (err > 0) {
 			phydev->state = PHY_RUNNING;
 			netif_carrier_on(phydev->attached_dev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+			phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 
 		} else if (0 == phydev->link_timeout--)
 			needs_aneg = true;
@@ -887,8 +937,15 @@ void phy_state_machine(struct work_struct *work)
 			}
 			phydev->state = PHY_RUNNING;
 			netif_carrier_on(phydev->attached_dev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+			/* everytime call adjust_link */
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 		}
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+		phy_adjust_link(phydev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 		break;
 	case PHY_FORCING:
 		err = genphy_update_link(phydev);
@@ -903,7 +960,11 @@ void phy_state_machine(struct work_struct *work)
 				needs_aneg = true;
 		}
 
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+		phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 		phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 		break;
 	case PHY_RUNNING:
 		/* Only register a CHANGE if we are polling or ignoring
@@ -941,7 +1002,11 @@ void phy_state_machine(struct work_struct *work)
 			netif_carrier_off(phydev->attached_dev);
 		}
 
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+		phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 		phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 
 		if (phy_interrupt_is_valid(phydev))
 			err = phy_config_interrupt(phydev,
@@ -951,7 +1016,11 @@ void phy_state_machine(struct work_struct *work)
 		if (phydev->link) {
 			phydev->link = 0;
 			netif_carrier_off(phydev->attached_dev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+			phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			do_suspend = true;
 		}
 		break;
@@ -975,7 +1044,11 @@ void phy_state_machine(struct work_struct *work)
 				} else	{
 					phydev->state = PHY_NOLINK;
 				}
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+				phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 				phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			} else {
 				phydev->state = PHY_AN;
 				phydev->link_timeout = PHY_AN_TIMEOUT;
@@ -991,7 +1064,11 @@ void phy_state_machine(struct work_struct *work)
 			} else	{
 				phydev->state = PHY_NOLINK;
 			}
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+			phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 		}
 		break;
 	}
diff --git a/drivers/net/phy/phy_device.c b/drivers/net/phy/phy_device.c
index 8179727..6349a31 100644
--- a/drivers/net/phy/phy_device.c
+++ b/drivers/net/phy/phy_device.c
@@ -40,6 +40,11 @@
 MODULE_DESCRIPTION("PHY library");
 MODULE_AUTHOR("Andy Fleming");
 MODULE_LICENSE("GPL");
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+int phy_deferred_linkdown = 1;
+module_param_named(deferred_linkdown, phy_deferred_linkdown, int, 0600);
+MODULE_PARM_DESC(deferred_linkdown, "Max linkdown count for lanact event");
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 
 void phy_device_free(struct phy_device *phydev)
 {
@@ -167,6 +172,12 @@ struct phy_device *phy_device_create(struct mii_bus *bus, int addr, int phy_id,
 	dev->asym_pause = 0;
 	dev->link = 1;
 	dev->interface = PHY_INTERFACE_MODE_GMII;
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	dev->state_cache.speed = 0;
+	dev->state_cache.duplex = -1;
+	dev->state_cache.link = 1;
+	dev->state_cache.downcnt = ~0U;
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 
 	dev->autoneg = AUTONEG_ENABLE;
 
diff --git a/drivers/pinctrl/intel/Kconfig b/drivers/pinctrl/intel/Kconfig
index 4d2efad..a7c8d9c 100644
--- a/drivers/pinctrl/intel/Kconfig
+++ b/drivers/pinctrl/intel/Kconfig
@@ -26,6 +26,18 @@ config PINCTRL_CHERRYVIEW
 	  Cherryview/Braswell pinctrl driver provides an interface that
 	  allows configuring of SoC pins and using them as GPIOs.
 
+config PINCTRL_DENVERTON
+	tristate "Intel Denverton pinctrl and GPIO driver"
+	depends on ACPI
+	select PINMUX
+	select PINCONF
+	select GENERIC_PINCONF
+	select GPIOLIB
+	select GPIOLIB_IRQCHIP
+	help
+	  Denverton pinctrl driver provides an interface that allows
+	  configuring of SoC pins and using them as GPIOs.
+
 config PINCTRL_INTEL
 	tristate
 	select PINMUX
diff --git a/drivers/pinctrl/intel/Makefile b/drivers/pinctrl/intel/Makefile
index 03bc68e..c36739e 100644
--- a/drivers/pinctrl/intel/Makefile
+++ b/drivers/pinctrl/intel/Makefile
@@ -4,4 +4,5 @@ obj-$(CONFIG_PINCTRL_BAYTRAIL)		+= pinctrl-baytrail.o
 obj-$(CONFIG_PINCTRL_CHERRYVIEW)	+= pinctrl-cherryview.o
 obj-$(CONFIG_PINCTRL_INTEL)		+= pinctrl-intel.o
 obj-$(CONFIG_PINCTRL_BROXTON)		+= pinctrl-broxton.o
+obj-$(CONFIG_PINCTRL_DENVERTON)		+= pinctrl-denverton-usi.o
 obj-$(CONFIG_PINCTRL_SUNRISEPOINT)	+= pinctrl-sunrisepoint.o
diff --git a/drivers/pinctrl/intel/pinctrl-denverton-usi.c b/drivers/pinctrl/intel/pinctrl-denverton-usi.c
new file mode 100644
index 00000000..90f8544
--- /dev/null
+++ b/drivers/pinctrl/intel/pinctrl-denverton-usi.c
@@ -0,0 +1,873 @@
+/*
+ * Pinctrl GPIO driver for Intel Denverton
+ * Copyright (c) 2012-2013, Intel Corporation.
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
+ */
+
+#include <linux/kernel.h>
+#include <linux/module.h>
+#include <linux/init.h>
+#include <linux/types.h>
+#include <linux/bitops.h>
+#include <linux/interrupt.h>
+#include <linux/gpio.h>
+#include <linux/acpi.h>
+#include <linux/platform_device.h>
+#include <linux/seq_file.h>
+#include <linux/io.h>
+#include <linux/pm_runtime.h>
+#include <linux/pinctrl/pinctrl.h>
+#include <linux/sizes.h>
+
+/* memory mapped register offsets */
+#define DNV_PAD_CONF0_REG	0x0
+#define DNV_PAD_CONF1_REG       0x4
+#define DNV_GPI_GPE_EN		0x160
+#define DNV_GPI_GPE_STS		0x140
+#define DNV_HOSTSW_OWN		0xC0
+#define DNV_PADCFGLOCK		0x90
+
+/* DNV_PAD_CONF0_REG register bits */
+#define DNV_RXEVCFG_26		BIT(26)
+#define DNV_RXEVCFG_25		BIT(25)
+#define DNV_RXINV		BIT(23)
+#define DNV_GPIROUTSCI		BIT(19)
+#define DNV_PMODE1		BIT(11)
+#define DNV_PMODE0		BIT(10)
+#define DNV_INPUT_DIS		BIT(9)  /* 0: input enabled (active low)*/
+#define DNV_OUTPUT_DIS		BIT(8)  /* 0: output enabled (active low)*/
+#define DNV_RXSTATE		BIT(1)
+#define DNV_LEVEL		BIT(0)
+
+#define DNV_TRIG_LVL		~(DNV_RXEVCFG_25 | DNV_RXEVCFG_26)
+#define DNV_TRIG_EDGE		DNV_RXEVCFG_25
+
+/* Restore */
+#define DNV_DIR_MASK		(BIT(8) | BIT(9))
+#define DNV_CONF0_RESTORE_MASK	(DNV_LEVEL | DNV_DIR_MASK | DNV_PMODE0 | DNV_PMODE1	\
+				 | DNV_GPIROUTSCI | DNV_RXINV | DNV_RXEVCFG_25		\
+				 | DNV_RXEVCFG_26 | BIT(28) | BIT(29) | BIT(30)		\
+				 | BIT(31))
+#define DNV_CONF1_RESTORE_MASK	(BIT(10) | BIT(11) | BIT(12) | BIT(13))
+
+#define DNV_NGPIO		153
+#define DNV_GPIO_NUM_HOLE	0xFFFF
+
+static int gpio_base = 0;
+module_param(gpio_base, int, 0);
+
+/*
+ * Denverton gpio controller consist of two separate Sideband.
+ *
+ * GPIO numbering is _not_ ordered meaning that gpio # 0 in ACPI namespace does
+ * _not_ correspond to the first gpio register at controller's gpio base.
+ * There is no logic or pattern in mapping gpio numbers to registers (pads) so
+ * each sub-controller needs to have its own mapping table
+ */
+
+/* DNV_pins[gpio_nr] = pad_nr */
+
+static unsigned const DNV_pins[DNV_NGPIO] = {
+	27, 33, 34, 612, 545, 546, 547, 548, 557, 558,
+	598, 599, 518, 519, 0, 1, 2, 3, 4, 5,
+	6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
+	16, 17, 18, 19, 20, 21, 22, 23, 24, 25,
+	26, 28, 29, 30, 31, 32, DNV_GPIO_NUM_HOLE, 35, 36, 37,
+	38, 39, 40, 500, 501, 502, 503, 504, 505, 506,
+	507, 508, 509, 510, 590, 591, 592, 593, 594, 595,
+	596, 597, 582, 583, 584, 585, 586, 587, 588, 571,
+	572, 573, 574, 575, 576, 577, 578, 579, 580, 581,
+	549, 550, 551, 552, 553, 554, 555, 556, 520, 521,
+	522, 523, 524, 525, 526, 527, 528, 529, 530, 531,
+	532, 533, 534, 535, 536, 537, 538, 539, 540, 541,
+	542, 543, 544, 601, 602, 603, 604, 605, 606, 607,
+	608, 609, 610, 611, 511, 512, 513, 514, 515, 516,
+	517, DNV_GPIO_NUM_HOLE, DNV_GPIO_NUM_HOLE, DNV_GPIO_NUM_HOLE, DNV_GPIO_NUM_HOLE, DNV_GPIO_NUM_HOLE, 564, 565, 566, 567,
+	568, 560, 570,
+};
+
+static struct pinctrl_gpio_range dnv_ranges[] = {
+	{
+		.name = "0",
+		.npins = DNV_NGPIO,
+		.pins = DNV_pins,
+	},
+	{
+	},
+};
+
+struct dnv_gpio_pin_context {
+	u32 conf0;
+	u32 conf1;
+};
+
+struct dnv_gpio {
+	struct gpio_chip		chip;
+	struct platform_device		*pdev;
+	raw_spinlock_t			lock;
+	void __iomem			*reg_base;
+	struct pinctrl_gpio_range	*range;
+	struct dnv_gpio_pin_context	*saved_context;
+};
+
+#define to_dnv_gpio(c)	container_of(c, struct dnv_gpio, chip)
+
+static void __iomem *dnv_gpio_reg(struct gpio_chip *chip, unsigned offset,
+		int reg)
+{
+	struct dnv_gpio *vg = to_dnv_gpio(chip);
+	u32 reg_offset;
+
+	reg_offset = vg->range->pins[offset];
+
+	if ((reg == DNV_GPI_GPE_EN) || (reg == DNV_GPI_GPE_STS) || (reg == DNV_HOSTSW_OWN))
+	{
+		if(reg_offset < 500)
+			return vg->reg_base + reg + (reg_offset / 32) * 4;
+		/* C5 */
+		if((reg_offset >= 500) && (reg_offset < 518))
+			return vg->reg_base + 0x30000 + reg + 0x0 + ((reg_offset - 500) / 32) * 4;
+		if((reg_offset >= 518) && (reg_offset < 571))
+			return vg->reg_base + 0x30000 + reg + 0x4 + ((reg_offset - 518) / 32) * 4;
+		if((reg_offset >= 571) && (reg_offset <= 612))
+			return vg->reg_base + 0x30000 + reg + 0xc + ((reg_offset - 571) / 32) * 4;
+	}
+	else if (reg == DNV_PADCFGLOCK)
+	{
+		if(reg_offset < 500)
+			return vg->reg_base + reg + (reg_offset / 32) * 8;
+		/* C5 */
+		if((reg_offset >= 500) && (reg_offset < 518))
+			return vg->reg_base + 0x30000 + reg + 0x0 + ((reg_offset - 500) / 32) * 8;
+		if((reg_offset >= 518) && (reg_offset < 571))
+			return vg->reg_base + 0x30000 + reg + 0x8 + ((reg_offset - 518) / 32) * 8;
+		if((reg_offset >= 571) && (reg_offset <= 612))
+			return vg->reg_base + 0x30000 + reg + 0x18 + ((reg_offset - 571) / 32) * 8;
+	}
+	else if ((reg == DNV_PAD_CONF0_REG) || (reg == DNV_PAD_CONF1_REG))
+	{
+		if(reg_offset < 500)
+			return vg->reg_base + 0x400 + (reg_offset << 3) + reg;
+		/* C5 */
+		if(reg_offset >= 500 && reg_offset <= 612)
+			return vg->reg_base + 0x30400 + ((reg_offset - 500) << 3) + reg;
+
+	}
+
+	return 0;/* Error!!! */
+}
+
+static void dnv_gpio_clear_triggering(struct dnv_gpio *vg, unsigned offset)
+{
+	void __iomem *reg = dnv_gpio_reg(&vg->chip, offset, DNV_PAD_CONF0_REG);
+	unsigned long flags;
+	u32 value, tmp, bit_offset = 0;
+
+	if(reg == 0)
+		return;
+	raw_spin_lock_irqsave(&vg->lock, flags);
+	value = readl(reg);
+	value &= ~(DNV_GPIROUTSCI);
+	writel(value, reg);
+
+	/* EN */
+	reg = dnv_gpio_reg(&vg->chip, offset, DNV_GPI_GPE_EN);
+	value = readl(reg);
+
+	tmp = vg->range->pins[offset];
+	if(tmp < 500)
+		bit_offset = tmp % 32;
+	/* C5 */
+	if((tmp >= 500) && (tmp < 518))
+		bit_offset = (tmp - 500) % 32;
+	if((tmp >= 518) && (tmp < 571))
+		bit_offset = (tmp - 518) % 32;
+	if((tmp >= 571) && (tmp <= 612))
+		bit_offset = (tmp - 571) % 32;
+
+	value &= ~(1 << bit_offset);
+	writel(value, reg);
+
+	/* STS */
+	reg = dnv_gpio_reg(&vg->chip, offset, DNV_GPI_GPE_STS);
+	value = readl(reg);
+	value |= (1 << bit_offset);
+	writel(value, reg);
+
+	raw_spin_unlock_irqrestore(&vg->lock, flags);
+}
+
+static int dnv_gpio_request(struct gpio_chip *chip, unsigned offset)
+{
+	struct dnv_gpio *vg = to_dnv_gpio(chip);
+	void __iomem *reg = dnv_gpio_reg(chip, offset, DNV_PAD_CONF0_REG);
+	u32 value;
+	unsigned long flags;
+
+	if(reg == 0)
+		return -EINVAL;
+
+	raw_spin_lock_irqsave(&vg->lock, flags);
+
+	/*
+	 * In most cases, func pin mux 000 means GPIO function.
+	 * But, some pins may have func pin mux 001 represents
+	 * GPIO function.
+	 *
+	 * Because there are devices out there where some pins were not
+	 * configured correctly we allow changing the mux value from
+	 * request (but print out warning about that).
+	 */
+	value = readl(reg) & DNV_PMODE0;
+	if (WARN_ON(0 != value)) {
+		value = readl(reg) & ~DNV_PMODE0;
+		writel(value, reg);
+
+		dev_warn(&vg->pdev->dev,
+				"pin %u forcibly re-configured as GPIO\n", offset);
+	}
+
+	raw_spin_unlock_irqrestore(&vg->lock, flags);
+
+	pm_runtime_get(&vg->pdev->dev);
+
+	return 0;
+}
+
+static void dnv_gpio_free(struct gpio_chip *chip, unsigned offset)
+{
+	struct dnv_gpio *vg = to_dnv_gpio(chip);
+
+	dnv_gpio_clear_triggering(vg, offset);
+	pm_runtime_put(&vg->pdev->dev);
+}
+
+static int dnv_irq_type(struct irq_data *d, unsigned type)
+{
+	struct dnv_gpio *vg = to_dnv_gpio(irq_data_get_irq_chip_data(d));
+	u32 offset = irqd_to_hwirq(d);
+	u32 value;
+	unsigned long flags;
+	void __iomem *reg = dnv_gpio_reg(&vg->chip, offset, DNV_PAD_CONF0_REG);
+
+	if (offset >= vg->chip.ngpio || reg == 0)
+		return -EINVAL;
+
+	raw_spin_lock_irqsave(&vg->lock, flags);
+	value = readl(reg);
+
+	/* For level trigges the DNV_TRIG_EDGE and DNV_TRIG_NEG bits
+	 * are used to indicate high and low level triggering
+	 */
+	value &= ~(DNV_RXEVCFG_25 | DNV_RXEVCFG_26);
+	value |= DNV_RXEVCFG_26;/* 2h = Drive '0' */
+	writel(value, reg);
+
+	if (type & IRQ_TYPE_EDGE_BOTH)
+		irq_set_handler_locked(d, handle_edge_irq);
+	else if (type & IRQ_TYPE_LEVEL_MASK)
+		irq_set_handler_locked(d, handle_level_irq);
+
+	raw_spin_unlock_irqrestore(&vg->lock, flags);
+
+	return 0;
+}
+
+static int dnv_gpio_get(struct gpio_chip *chip, unsigned offset)
+{
+	void __iomem *reg = dnv_gpio_reg(chip, offset, DNV_PAD_CONF0_REG);
+	struct dnv_gpio *vg = to_dnv_gpio(chip);
+	unsigned long flags;
+	u32 val;
+
+        if(reg == 0)
+                return -EINVAL;
+
+	raw_spin_lock_irqsave(&vg->lock, flags);
+	val = readl(reg);
+	raw_spin_unlock_irqrestore(&vg->lock, flags);
+	if (DNV_INPUT_DIS & val)
+		return val & DNV_LEVEL;
+
+	return val & DNV_RXSTATE;
+}
+
+static void dnv_gpio_set(struct gpio_chip *chip, unsigned offset, int value)
+{
+	struct dnv_gpio *vg = to_dnv_gpio(chip);
+	void __iomem *reg = dnv_gpio_reg(chip, offset, DNV_PAD_CONF0_REG);
+	unsigned long flags;
+	u32 old_val;
+
+        if(reg == 0)
+                return;
+
+	raw_spin_lock_irqsave(&vg->lock, flags);
+
+	old_val = readl(reg);
+
+	if (value)
+		writel(old_val | DNV_LEVEL, reg);
+	else
+		writel(old_val & ~DNV_LEVEL, reg);
+
+	raw_spin_unlock_irqrestore(&vg->lock, flags);
+}
+
+static int dnv_gpio_direction_input(struct gpio_chip *chip, unsigned offset)
+{
+	struct dnv_gpio *vg = to_dnv_gpio(chip);
+	void __iomem *reg = dnv_gpio_reg(chip, offset, DNV_PAD_CONF0_REG);
+	unsigned long flags;
+	u32 value;
+
+        if(reg == 0)
+                return -EINVAL;
+
+	raw_spin_lock_irqsave(&vg->lock, flags);
+
+	value = readl(reg) | DNV_DIR_MASK;
+	value &= ~DNV_INPUT_DIS;	/* active low */
+	writel(value, reg);
+
+	raw_spin_unlock_irqrestore(&vg->lock, flags);
+
+	return 0;
+}
+
+static int dnv_gpio_direction_output(struct gpio_chip *chip,
+				     unsigned gpio, int value)
+{
+	struct dnv_gpio *vg = to_dnv_gpio(chip);
+	void __iomem *reg = dnv_gpio_reg(chip, gpio, DNV_PAD_CONF0_REG);
+	unsigned long flags;
+	u32 reg_val;
+
+        if(reg == 0)
+                return -EINVAL;
+
+	raw_spin_lock_irqsave(&vg->lock, flags);
+
+	reg_val = readl(reg) | DNV_DIR_MASK;
+	reg_val &= ~DNV_OUTPUT_DIS;
+
+	if (value)
+		writel(reg_val | DNV_LEVEL, reg);
+	else
+		writel(reg_val & ~DNV_LEVEL, reg);
+
+	raw_spin_unlock_irqrestore(&vg->lock, flags);
+
+	return 0;
+}
+
+static void dnv_gpio_dbg_show(struct seq_file *s, struct gpio_chip *chip)
+{
+	struct dnv_gpio *vg = to_dnv_gpio(chip);
+	int i;
+	u32 conf0, conf1;
+
+	for (i = 0; i < vg->chip.ngpio; i++) {
+		unsigned long flags;
+		const char *label;
+		if(vg->range->pins[i] == DNV_GPIO_NUM_HOLE)
+			continue;
+		raw_spin_lock_irqsave(&vg->lock, flags);
+		conf0 = readl(dnv_gpio_reg(chip, i, DNV_PAD_CONF0_REG));
+		conf1 = readl(dnv_gpio_reg(chip, i, DNV_PAD_CONF1_REG));
+		raw_spin_unlock_irqrestore(&vg->lock, flags);
+
+		label = gpiochip_is_requested(chip, i);
+		if (!label)
+			label = "Unrequested";
+
+
+		seq_printf(s,
+			   " gpio-%-3d (%-20.20s) pad-%-3d conf0:0x%08x conf1:0x%08x ",
+			   i, label, vg->range->pins[i], conf0, conf1
+			   );
+
+		seq_puts(s, "\n");
+	}
+}
+#if 0
+static void dnv_gpio_irq_handler(struct irq_desc *desc)
+{
+	struct irq_data *data = irq_desc_get_irq_data(desc);
+	struct dnv_gpio *vg = to_dnv_gpio(irq_desc_get_handler_data(desc));
+	struct irq_chip *chip = irq_data_get_irq_chip(data);
+#else
+static irqreturn_t dnv_gpio_irq_handler(int irq, void *dev_id)
+{
+	struct dnv_gpio *vg = (struct dnv_gpio *)dev_id;
+#endif
+	void __iomem *reg;
+	void __iomem *reg_conf0;
+	unsigned virq;
+	u32 pin, value, tmp, ret = 0, bit_offset = 0, conf0 = 0;
+	/* check from GPIO controller which pin triggered the interrupt */
+
+	for (pin = 0; pin < vg->chip.ngpio; pin++) {
+		tmp = vg->range->pins[pin];
+		if(tmp == DNV_GPIO_NUM_HOLE)
+			continue;
+		if(tmp < 500)
+			bit_offset = tmp % 32;
+		/* C5 */
+		if((tmp >= 500) && (tmp < 518))
+			bit_offset = (tmp - 500) % 32;
+		if((tmp >= 518) && (tmp < 571))
+			bit_offset = (tmp - 518) % 32;
+		if((tmp >= 571) && (tmp <= 612))
+			bit_offset = (tmp - 571) % 32;
+
+		/* STS */
+		reg = dnv_gpio_reg(&vg->chip, pin, DNV_GPI_GPE_STS);
+		value = readl(reg);
+		value &= (1 << bit_offset);
+		if (value)
+		{
+			reg_conf0 = dnv_gpio_reg(&vg->chip, pin, DNV_PAD_CONF0_REG);
+			conf0 = readl(reg_conf0);
+			writel((DNV_RXINV & conf0)?(conf0 & ~DNV_RXINV):(conf0 | DNV_RXINV), reg_conf0);
+			ret = 1;
+			writel(value, reg);//libolibo write to clear
+			virq = irq_find_mapping(vg->chip.irqdomain, pin);
+			generic_handle_irq(virq);
+		}
+	}
+#if 0
+	chip->irq_eoi(data);
+#else
+	if (ret)
+		return IRQ_HANDLED;
+	else
+		return IRQ_NONE;
+#endif
+}
+
+static void dnv_irq_ack(struct irq_data *d)
+{
+	struct gpio_chip *gc = irq_data_get_irq_chip_data(d);
+	struct dnv_gpio *vg = to_dnv_gpio(gc);
+	unsigned offset = irqd_to_hwirq(d);
+	void __iomem *reg;
+	u32 value, tmp, bit_offset = 0;
+
+	tmp = vg->range->pins[offset];
+	if(tmp < 500)
+		bit_offset = tmp % 32;
+	/* C5 */
+	if((tmp >= 500) && (tmp < 518))
+		bit_offset = (tmp - 500) % 32;
+	if((tmp >= 518) && (tmp < 571))
+		bit_offset = (tmp - 518) % 32;
+	if((tmp >= 571) && (tmp <= 612))
+		bit_offset = (tmp - 571) % 32;
+	if(tmp == DNV_GPIO_NUM_HOLE)
+		return;
+
+	raw_spin_lock(&vg->lock);
+
+	/* STS */
+	reg = dnv_gpio_reg(&vg->chip, offset, DNV_GPI_GPE_STS);
+	value = readl(reg);
+	value |= (1 << bit_offset);
+	writel(value, reg);
+
+	raw_spin_unlock(&vg->lock);
+}
+
+static void dnv_irq_unmask(struct irq_data *d)
+{
+	struct gpio_chip *gc = irq_data_get_irq_chip_data(d);
+	struct dnv_gpio *vg = to_dnv_gpio(gc);
+	unsigned offset = irqd_to_hwirq(d);
+	unsigned long flags;
+	void __iomem *reg;
+	u32 value, tmp, bit_offset = 0;
+
+	reg = dnv_gpio_reg(&vg->chip, offset, DNV_PAD_CONF0_REG);
+        if(reg == 0)
+                return;
+
+	raw_spin_lock_irqsave(&vg->lock, flags);
+	value = readl(reg);
+
+	/* Clean Level/Edge configuration bits */
+	value &= ~(DNV_RXEVCFG_25 | DNV_RXEVCFG_26);
+	switch (irqd_get_trigger_type(d)) {
+	//case IRQ_TYPE_LEVEL_HIGH:
+	//	value |= DNV_TRIG_LVL;
+	//case IRQ_TYPE_EDGE_RISING:
+	//	value |= DNV_TRIG_EDGE;
+	//	break;
+	//case IRQ_TYPE_LEVEL_LOW:
+	//	value |= DNV_TRIG_LVL;
+	//case IRQ_TYPE_EDGE_FALLING:
+	//	value |= DNV_TRIG_NEG;
+	//	break;
+	case IRQ_TYPE_LEVEL_MASK:
+		value |= (DNV_TRIG_LVL);
+		break;
+	case IRQ_TYPE_EDGE_BOTH:
+		value |= (DNV_TRIG_EDGE);
+		break;
+	}
+
+	/* Set the RXINV for make sure the first interrupt vaild */
+	value |= ((value & DNV_RXSTATE) ? DNV_RXINV : 0);
+
+	value |= DNV_GPIROUTSCI;
+	writel(value, reg);
+
+	reg = dnv_gpio_reg(&vg->chip, offset, DNV_GPI_GPE_EN);
+	value = readl(reg);
+
+	tmp = vg->range->pins[offset];
+	if(tmp < 500)
+		bit_offset = tmp % 32;
+	/* C5 */
+	if((tmp >= 500) && (tmp < 518))
+		bit_offset = (tmp - 500) % 32;
+	if((tmp >= 518) && (tmp < 571))
+		bit_offset = (tmp - 518) % 32;
+	if((tmp >= 571) && (tmp <= 612))
+		bit_offset = (tmp - 571) % 32;
+
+	value |= (1 << bit_offset);
+	writel(value, reg);
+
+	reg = dnv_gpio_reg(&vg->chip, offset, DNV_HOSTSW_OWN);
+	value = readl(reg);
+	value &= ~(1 << bit_offset);
+	writel(value, reg);
+
+	raw_spin_unlock_irqrestore(&vg->lock, flags);
+}
+
+static void dnv_irq_mask(struct irq_data *d)
+{
+	struct gpio_chip *gc = irq_data_get_irq_chip_data(d);
+	struct dnv_gpio *vg = to_dnv_gpio(gc);
+
+	dnv_gpio_clear_triggering(vg, irqd_to_hwirq(d));
+}
+
+static struct irq_chip dnv_irqchip = {
+	.name = "DNV-GPIO",
+	.irq_ack = dnv_irq_ack,
+	.irq_mask = dnv_irq_mask,
+	.irq_unmask = dnv_irq_unmask,
+	.irq_set_type = dnv_irq_type,
+	.flags = IRQCHIP_SKIP_SET_WAKE,
+};
+
+static void dnv_gpio_irq_init_hw(struct dnv_gpio *vg)
+{
+	int i;
+
+	/*
+	 * Clear interrupt triggers for all pins that are GPIOs and
+	 * do not use direct IRQ mode. This will prevent spurious
+	 * interrupts from misconfigured pins.
+	 */
+	for (i = 0; i < vg->chip.ngpio; i++) {
+		if (vg->range->pins[i] == DNV_GPIO_NUM_HOLE)
+			continue;
+		dnv_gpio_clear_triggering(vg, i);
+		dev_dbg(&vg->pdev->dev, "disabling GPIO %d\n", i);
+	}
+
+}
+
+static int dnv_gpio_probe(struct platform_device *pdev)
+{
+	struct dnv_gpio *vg;
+	struct gpio_chip *gc;
+	struct resource *mem_rc, *irq_rc;
+	struct device *dev = &pdev->dev;
+	//struct acpi_device *acpi_dev;
+	struct pinctrl_gpio_range *range;
+	//acpi_handle handle = ACPI_HANDLE(dev);
+	int ret;
+
+	//if (acpi_bus_get_device(handle, &acpi_dev))
+		//return -ENODEV;
+
+	vg = devm_kzalloc(dev, sizeof(struct dnv_gpio), GFP_KERNEL);
+	if (!vg) {
+		dev_err(&pdev->dev, "can't allocate dnv_gpio chip data\n");
+		return -ENOMEM;
+	}
+
+	for (range = dnv_ranges; range->name; range++) {
+			vg->chip.ngpio = range->npins;
+			vg->range = range;
+	}
+
+	if (!vg->chip.ngpio || !vg->range)
+		return -ENODEV;
+
+	vg->pdev = pdev;
+	platform_set_drvdata(pdev, vg);
+
+	mem_rc = platform_get_resource(pdev, IORESOURCE_MEM, 0);
+	vg->reg_base = devm_ioremap_resource(dev, mem_rc);
+	if (IS_ERR(vg->reg_base))
+		return PTR_ERR(vg->reg_base);
+	raw_spin_lock_init(&vg->lock);
+
+	gc = &vg->chip;
+	gc->label = dev_name(&pdev->dev);
+	gc->owner = THIS_MODULE;
+	gc->request = dnv_gpio_request;
+	gc->free = dnv_gpio_free;
+	gc->direction_input = dnv_gpio_direction_input;
+	gc->direction_output = dnv_gpio_direction_output;
+	gc->get = dnv_gpio_get;
+	gc->set = dnv_gpio_set;
+	gc->dbg_show = dnv_gpio_dbg_show;
+	gc->base = gpio_base;
+	gc->can_sleep = false;
+	gc->dev = dev;
+
+#ifdef CONFIG_PM_SLEEP
+	vg->saved_context = devm_kcalloc(&pdev->dev, gc->ngpio,
+				       sizeof(*vg->saved_context), GFP_KERNEL);
+#endif
+
+	ret = gpiochip_add(gc);
+	if (ret) {
+		dev_err(&pdev->dev, "failed adding dnv-gpio chip\n");
+		return ret;
+	}
+
+	/* set up interrupts  */
+	irq_rc = platform_get_resource(pdev, IORESOURCE_IRQ, 0);
+	if (irq_rc && irq_rc->start) {
+		dnv_gpio_irq_init_hw(vg);
+		ret = gpiochip_irqchip_add(gc, &dnv_irqchip, 0,
+					   handle_simple_irq, IRQ_TYPE_NONE);
+		if (ret) {
+			dev_err(dev, "failed to add irqchip\n");
+			gpiochip_remove(gc);
+			return ret;
+		}
+#if 0
+		gpiochip_set_chained_irqchip(gc, &dnv_irqchip,
+				(unsigned)irq_rc->start,
+				dnv_gpio_irq_handler);
+#else
+		ret = request_irq((unsigned)irq_rc->start, dnv_gpio_irq_handler,
+					IRQF_SHARED, "gpio-dnv", gc);
+		if (ret)
+		{
+			dev_err(dev, "failed to request parent irq\n");
+			gpiochip_remove(gc);
+			return ret;
+		}
+
+#endif
+	}
+
+	pm_runtime_enable(dev);
+
+	return 0;
+}
+
+#ifdef CONFIG_PM_SLEEP
+static int dnv_gpio_suspend(struct device *dev)
+{
+	struct platform_device *pdev = to_platform_device(dev);
+	struct dnv_gpio *vg = platform_get_drvdata(pdev);
+	int pin;
+	u32 value, tmp, bit_offset = 0;
+	void __iomem *reg;
+
+        for (pin = 0; pin < vg->chip.ngpio; pin++) {
+                tmp = vg->range->pins[pin];
+                if(tmp == DNV_GPIO_NUM_HOLE)
+                        continue;
+
+                if(tmp < 500)
+                        bit_offset = tmp % 32;
+                /* C5 */
+                if((tmp >= 500) && (tmp < 518))
+                        bit_offset = (tmp - 500) % 32;
+                if((tmp >= 518) && (tmp < 571))
+                        bit_offset = (tmp - 518) % 32;
+                if((tmp >= 571) && (tmp <= 612))
+                        bit_offset = (tmp - 571) % 32;
+
+                /* LOCK */
+                reg = dnv_gpio_reg(&vg->chip, pin, DNV_PADCFGLOCK);
+                value = readl(reg);
+                value &= (1 << bit_offset);
+                if (value)	/* Locked */
+			continue;
+
+		reg = dnv_gpio_reg(&vg->chip, pin, DNV_PAD_CONF0_REG);
+		value = readl(reg) & DNV_CONF0_RESTORE_MASK;
+		vg->saved_context[pin].conf0 = value;
+
+		reg = dnv_gpio_reg(&vg->chip, pin, DNV_PAD_CONF1_REG);
+		value = readl(reg) & DNV_CONF1_RESTORE_MASK;
+		vg->saved_context[pin].conf1 = value;
+        }
+
+	return 0;
+}
+
+static int dnv_gpio_resume(struct device *dev)
+{
+	struct platform_device *pdev = to_platform_device(dev);
+	struct dnv_gpio *vg = platform_get_drvdata(pdev);
+	int pin;
+	u32 value, tmp, bit_offset = 0;
+	void __iomem *reg;
+
+        for (pin = 0; pin < vg->chip.ngpio; pin++) {
+                tmp = vg->range->pins[pin];
+                if(tmp == DNV_GPIO_NUM_HOLE)
+                        continue;
+
+                if(tmp < 500)
+                        bit_offset = tmp % 32;
+                /* C5 */
+                if((tmp >= 500) && (tmp < 518))
+                        bit_offset = (tmp - 500) % 32;
+                if((tmp >= 518) && (tmp < 571))
+                        bit_offset = (tmp - 518) % 32;
+                if((tmp >= 571) && (tmp <= 612))
+                        bit_offset = (tmp - 571) % 32;
+
+                /* LOCK */
+                reg = dnv_gpio_reg(&vg->chip, pin, DNV_PADCFGLOCK);
+                value = readl(reg);
+                value &= (1 << bit_offset);
+                if (value)	/* Locked */
+			continue;
+
+		reg = dnv_gpio_reg(&vg->chip, pin, DNV_PAD_CONF0_REG);
+		value = readl(reg);
+		if ((value & DNV_CONF0_RESTORE_MASK) !=
+		     vg->saved_context[pin].conf0) {
+			value &= ~DNV_CONF0_RESTORE_MASK;
+			value |= vg->saved_context[pin].conf0;
+			writel(value, reg);
+			dev_info(dev, "restored pin %d conf0 %#08x", pin, value);
+		}
+		reg = dnv_gpio_reg(&vg->chip, pin, DNV_PAD_CONF1_REG);
+		value = readl(reg);
+		if ((value & DNV_CONF1_RESTORE_MASK) !=
+		     vg->saved_context[pin].conf1) {
+			value &= ~DNV_CONF1_RESTORE_MASK;
+			value |= vg->saved_context[pin].conf1;
+			writel(value, reg);
+			dev_info(dev, "restored pin %d conf1 %#08x", pin, value);
+		}
+        }
+	return 0;
+}
+#endif
+
+#ifdef CONFIG_PM
+static int dnv_gpio_runtime_suspend(struct device *dev)
+{
+	return 0;
+}
+
+static int dnv_gpio_runtime_resume(struct device *dev)
+{
+	return 0;
+}
+#endif
+
+static const struct dev_pm_ops dnv_gpio_pm_ops = {
+	SET_LATE_SYSTEM_SLEEP_PM_OPS(dnv_gpio_suspend, dnv_gpio_resume)
+	SET_RUNTIME_PM_OPS(dnv_gpio_runtime_suspend, dnv_gpio_runtime_resume,
+			   NULL)
+};
+#if 0
+static const struct acpi_device_id dnv_gpio_acpi_match[] = {
+	{ "INT33B2", 0 },
+	{ "INT33FC", 0 },
+	{ }
+};
+MODULE_DEVICE_TABLE(acpi, dnv_gpio_acpi_match);
+#endif
+static int dnv_gpio_remove(struct platform_device *pdev)
+{
+	struct dnv_gpio *vg = platform_get_drvdata(pdev);
+
+	pm_runtime_disable(&pdev->dev);
+	gpiochip_remove(&vg->chip);
+
+	return 0;
+}
+
+static struct platform_driver dnv_gpio_driver = {
+	.probe          = dnv_gpio_probe,
+	.remove         = dnv_gpio_remove,
+	.driver         = {
+		.name   = "dnv_gpio",
+		.pm	= &dnv_gpio_pm_ops,
+		.owner	= THIS_MODULE,
+		//.acpi_match_table = ACPI_PTR(dnv_gpio_acpi_match),
+	},
+};
+
+static struct resource dnv_gpio_resources[] = {
+	{
+		.name   = "dnv_gpio",
+		.start  = 0xfdc20000,
+		.end    = 0xfdc20000 + SZ_256K - 1,
+		.flags  = IORESOURCE_MEM,
+	},
+	{
+		.name   = "dnv_gpio_int",
+		.start  = 9,
+		.flags  = IORESOURCE_IRQ,
+	},
+};
+
+static const struct platform_device_info pi __initconst = {
+        .name           = "dnv_gpio",
+        .id             = 0,
+        .res            = dnv_gpio_resources,
+        .num_res        = ARRAY_SIZE(dnv_gpio_resources),
+};
+
+static struct platform_device *dnv_pdev;
+static int __init dnv_gpio_init(void)
+{
+
+        dnv_pdev = platform_device_register_full(&pi);
+        if (IS_ERR(dnv_pdev)) {
+                return PTR_ERR(dnv_pdev);
+        }
+
+	return platform_driver_register(&dnv_gpio_driver);
+}
+subsys_initcall(dnv_gpio_init);
+
+static void __exit dnv_gpio_exit(void)
+{
+	platform_device_unregister(dnv_pdev);
+	platform_driver_unregister(&dnv_gpio_driver);
+}
+module_exit(dnv_gpio_exit);
+
+MODULE_AUTHOR("LiBo <bo_li@usish.com>");
+MODULE_DESCRIPTION("Intel Denverton pinctrl/GPIO core driver");
+MODULE_LICENSE("GPL v2");
+
diff --git a/drivers/rtc/Kconfig b/drivers/rtc/Kconfig
index 2a52424..3b1da5e 100644
--- a/drivers/rtc/Kconfig
+++ b/drivers/rtc/Kconfig
@@ -575,6 +575,16 @@ config RTC_DRV_RX8025
 	  This driver can also be built as a module. If so, the module
 	  will be called rtc-rx8025.
 
+config RTC_DRV_RX8010
+	tristate "Epson RX-8010SJ"
+	help
+	  If you say yes here you get support for the Epson
+	  RX-8010SJ RTC chips.
+
+	  This driver can also be built as a module. If so, the module
+	  will be called rtc-rx8010.
+
+
 config RTC_DRV_EM3027
 	tristate "EM Microelectronic EM3027"
 	help
diff --git a/drivers/rtc/Makefile b/drivers/rtc/Makefile
index 231f764..1e15e05 100644
--- a/drivers/rtc/Makefile
+++ b/drivers/rtc/Makefile
@@ -129,6 +129,7 @@ obj-$(CONFIG_RTC_DRV_RV3029C2)	+= rtc-rv3029c2.o
 obj-$(CONFIG_RTC_DRV_RV8803)	+= rtc-rv8803.o
 obj-$(CONFIG_RTC_DRV_RX4581)	+= rtc-rx4581.o
 obj-$(CONFIG_RTC_DRV_RX8025)	+= rtc-rx8025.o
+obj-$(CONFIG_RTC_DRV_RX8010)	+= rtc-rx8010.o
 obj-$(CONFIG_RTC_DRV_RX8581)	+= rtc-rx8581.o
 obj-$(CONFIG_RTC_DRV_S35390A)	+= rtc-s35390a.o
 obj-$(CONFIG_RTC_DRV_S3C)	+= rtc-s3c.o
diff --git a/drivers/rtc/rtc-rx8010.c b/drivers/rtc/rtc-rx8010.c
new file mode 100644
index 00000000..80f7506
--- /dev/null
+++ b/drivers/rtc/rtc-rx8010.c
@@ -0,0 +1,965 @@
+//======================================================================
+// Driver for the Epson RTC module RX-8010 SJ
+// 
+// Copyright(C) SEIKO EPSON CORPORATION 2013. All rights reserved.
+// 
+// Derived from RX-8025 driver: 
+// Copyright (C) 2009 Wolfgang Grandegger <wg@grandegger.com>
+// 
+// Copyright (C) 2005 by Digi International Inc.
+// All rights reserved.
+// 
+// Modified by fengjh at rising.com.cn
+// <http://lists.lm-sensors.org/mailman/listinfo/lm-sensors>
+// 2006.11
+// 
+// Code cleanup by Sergei Poselenov, <sposelenov@emcraft.com>
+// Converted to new style by Wolfgang Grandegger <wg@grandegger.com>
+// Alarm and periodic interrupt added by Dmitry Rakhchev <rda@emcraft.com>
+//
+// 
+// This driver software is distributed as is, without any warranty of any kind,
+// either express or implied as further specified in the GNU Public License. This
+// software may be used and distributed according to the terms of the GNU Public
+// License, version 2 as published by the Free Software Foundation.
+// See the file COPYING in the main directory of this archive for more details.
+//
+// You should have received a copy of the GNU General Public License along with
+// this program. If not, see <http://www.gnu.org/licenses/>.
+//======================================================================
+
+#if 0
+#define DEBUG
+#include <linux/device.h>
+#undef DEBUG
+#endif 
+
+#include <linux/kernel.h>
+#include <linux/module.h>
+#include <linux/slab.h>
+#include <linux/init.h>
+#include <linux/bcd.h>
+#include <linux/i2c.h>
+#include <linux/list.h>
+#include <linux/rtc.h>
+#include <linux/of_gpio.h>
+
+#include <linux/of.h>
+#include <linux/of_device.h>
+#include <linux/of_irq.h>
+#include <linux/interrupt.h>
+#include <linux/input.h>
+
+
+// RX-8010 Register definitions
+#define RX8010_REG_SEC		0x10
+#define RX8010_REG_MIN		0x11
+#define RX8010_REG_HOUR		0x12
+#define RX8010_REG_WDAY		0x13
+#define RX8010_REG_MDAY		0x14
+#define RX8010_REG_MONTH	0x15
+#define RX8010_REG_YEAR		0x16
+// 0x17 is reserved
+#define RX8010_REG_ALMIN	0x18
+#define RX8010_REG_ALHOUR	0x19
+#define RX8010_REG_ALWDAY	0x1A
+#define RX8010_REG_TCOUNT0	0x1B
+#define RX8010_REG_TCOUNT1	0x1C
+#define RX8010_REG_EXT		0x1D
+#define RX8010_REG_FLAG		0x1E
+#define RX8010_REG_CTRL		0x1F
+#define RX8010_REG_USER0	0x20
+#define RX8010_REG_USER1	0x21
+#define RX8010_REG_USER2	0x22
+#define RX8010_REG_USER3	0x23
+#define RX8010_REG_USER4	0x24
+#define RX8010_REG_USER5	0x25
+#define RX8010_REG_USER6	0x26
+#define RX8010_REG_USER7	0x27
+#define RX8010_REG_USER8	0x28
+#define RX8010_REG_USER9	0x29
+#define RX8010_REG_USERA	0x2A
+#define RX8010_REG_USERB	0x2B
+#define RX8010_REG_USERC	0x2C
+#define RX8010_REG_USERD	0x2D
+#define RX8010_REG_USERE	0x2E
+#define RX8010_REG_USERF	0x2F
+// 0x30 is reserved
+// 0x31 is reserved
+#define RX8010_REG_IRQ		0x32
+
+// Extension Register (1Dh) bit positions
+#define RX8010_BIT_EXT_TSEL		(7 << 0)
+#define RX8010_BIT_EXT_WADA		(1 << 3)
+#define RX8010_BIT_EXT_TE		(1 << 4)
+#define RX8010_BIT_EXT_USEL		(1 << 5)
+#define RX8010_BIT_EXT_FSEL		(3 << 6)
+
+// Flag Register (1Eh) bit positions
+#define RX8010_BIT_FLAG_VLF		(1 << 1)
+#define RX8010_BIT_FLAG_AF		(1 << 3)
+#define RX8010_BIT_FLAG_TF		(1 << 4)
+#define RX8010_BIT_FLAG_UF		(1 << 5)
+
+// Control Register (1Fh) bit positions
+#define RX8010_BIT_CTRL_TSTP	(1 << 2)
+#define RX8010_BIT_CTRL_AIE		(1 << 3)
+#define RX8010_BIT_CTRL_TIE		(1 << 4)
+#define RX8010_BIT_CTRL_UIE		(1 << 5)
+#define RX8010_BIT_CTRL_STOP	(1 << 6)
+#define RX8010_BIT_CTRL_TEST	(1 << 7)
+
+
+static const struct i2c_device_id rx8010_id[] = {
+	{ "rx8010", 0 },
+	{ }
+};
+MODULE_DEVICE_TABLE(i2c, rx8010_id);
+
+struct rx8010_data {
+	struct i2c_client *client;
+	struct rtc_device *rtc;
+	struct work_struct work_1;
+	struct work_struct work_2;
+	u8 ctrlreg;
+	int irq_1;
+	int irq_2;
+	unsigned exiting:1;
+};
+
+typedef struct {
+	u8 number;
+	u8 value;
+}reg_data;
+
+#define SE_RTC_REG_READ		_IOWR('p', 0x20, reg_data)		
+#define SE_RTC_REG_WRITE	_IOW('p',  0x21, reg_data)	
+
+//----------------------------------------------------------------------
+// rx8010_read_reg()
+// reads a rx8010 register (see Register defines)
+// See also rx8010_read_regs() to read multiple registers.
+//
+//----------------------------------------------------------------------
+static int rx8010_read_reg(struct i2c_client *client, int number, u8 *value)
+{
+	int ret = i2c_smbus_read_byte_data(client, number) ;
+
+	//check for error
+	if (ret < 0) {
+		dev_err(&client->dev, "Unable to read register #%d\n", number);
+		return ret;
+	}
+
+	*value = ret;
+	return 0;
+}
+
+//----------------------------------------------------------------------
+// rx8010_read_regs()
+// reads a specified number of rx8010 registers (see Register defines)
+// See also rx8010_read_reg() to read single register.
+//
+//----------------------------------------------------------------------
+static int rx8010_read_regs(struct i2c_client *client, int number, u8 length, u8 *values)
+{
+	int ret = i2c_smbus_read_i2c_block_data(client, number, length, values);
+
+	//check for length error
+	if (ret != length) {
+		dev_err(&client->dev, "Unable to read registers #%d..#%d\n", number, number + length - 1);
+		return ret < 0 ? ret : -EIO;
+	}
+
+	return 0;
+}
+
+//----------------------------------------------------------------------
+// rx8010_write_reg()
+// writes a rx8010 register (see Register defines)
+// See also rx8010_write_regs() to write multiple registers.
+//
+//----------------------------------------------------------------------
+static int rx8010_write_reg(struct i2c_client *client, int number, u8 value)
+{
+	int ret = i2c_smbus_write_byte_data(client, number, value);
+
+	//check for error
+	if (ret)
+		dev_err(&client->dev, "Unable to write register #%d\n", number);
+
+	return ret;
+}
+
+//----------------------------------------------------------------------
+// rx8010_write_regs()
+// writes a specified number of rx8010 registers (see Register defines)
+// See also rx8010_write_reg() to write a single register.
+//
+//----------------------------------------------------------------------
+static int rx8010_write_regs(struct i2c_client *client, int number, u8 length, u8 *values)
+{
+	int ret = i2c_smbus_write_i2c_block_data(client, number, length, values);
+
+	//check for error
+	if (ret)
+		dev_err(&client->dev, "Unable to write registers #%d..#%d\n", number, number + length - 1);
+
+	return ret;
+}
+
+//----------------------------------------------------------------------
+// rx8010_irq_1()
+// irq handler
+//
+//----------------------------------------------------------------------
+static irqreturn_t rx8010_irq_1(int irq, void *dev_id)
+{
+	struct i2c_client *client = dev_id;
+	struct rx8010_data *rx8010 = i2c_get_clientdata(client);
+
+	disable_irq_nosync(irq);
+	schedule_work(&rx8010->work_1);
+
+
+	return IRQ_HANDLED;
+}
+
+//----------------------------------------------------------------------
+// rx8010_work_1()
+//
+//----------------------------------------------------------------------
+static void rx8010_work_1(struct work_struct *work)
+{
+	struct rx8010_data *rx8010 = container_of(work, struct rx8010_data, work_1);
+	struct i2c_client *client = rx8010->client;
+	struct mutex *lock = &rx8010->rtc->ops_lock;
+	u8 status;
+
+	mutex_lock(lock);
+	
+	if (rx8010_read_reg(client, RX8010_REG_FLAG, &status))
+		goto out;
+
+	// check VLF
+	if ((status & RX8010_BIT_FLAG_VLF))
+		dev_warn(&client->dev, "Frequency stop was detected, probably due to a supply voltage drop\n");
+			 
+	dev_dbg(&client->dev, "%s: RX8010_REG_FLAG: %xh\n", __func__, status);
+
+	// periodic "fixed-cycle" timer
+	if (status & RX8010_BIT_FLAG_TF) {
+		status &= ~RX8010_BIT_FLAG_TF;
+		local_irq_disable();
+		rtc_update_irq(rx8010->rtc, 1, RTC_PF | RTC_IRQF);
+		local_irq_enable();
+	}
+
+	// alarm function
+	if (status & RX8010_BIT_FLAG_AF) {
+		status &= ~RX8010_BIT_FLAG_AF;
+		local_irq_disable();
+		rtc_update_irq(rx8010->rtc, 1, RTC_AF | RTC_IRQF);
+		local_irq_enable();
+	}
+	
+	// time update function
+	if (status & RX8010_BIT_FLAG_UF) {
+		status &= ~RX8010_BIT_FLAG_UF;
+		local_irq_disable();
+		rtc_update_irq(rx8010->rtc, 1, RTC_UF | RTC_IRQF);
+		local_irq_enable();
+	}
+
+	// acknowledge IRQ (clear flags)
+	rx8010_write_reg(client, RX8010_REG_FLAG, status);		
+
+out:
+	if (!rx8010->exiting)
+	{
+		if (rx8010->irq_1 > 0)
+			enable_irq(rx8010->irq_1);
+		else
+			enable_irq(client->irq);
+	}	
+
+	mutex_unlock(lock);
+}
+
+//----------------------------------------------------------------------
+// rx8010_irq_2()
+// irq handler
+//
+//----------------------------------------------------------------------
+static irqreturn_t rx8010_irq_2(int irq, void *dev_id)
+{
+	struct i2c_client *client = dev_id;
+	struct rx8010_data *rx8010 = i2c_get_clientdata(client);
+
+	disable_irq_nosync(irq);
+	schedule_work(&rx8010->work_2);
+
+
+	return IRQ_HANDLED;
+}
+
+//----------------------------------------------------------------------
+// rx8010_work_2()
+//
+//----------------------------------------------------------------------
+static void rx8010_work_2(struct work_struct *work)
+{
+	struct rx8010_data *rx8010 = container_of(work, struct rx8010_data, work_2);
+	struct i2c_client *client = rx8010->client;
+	struct mutex *lock = &rx8010->rtc->ops_lock;
+	u8 status;
+
+	mutex_lock(lock);
+	
+	if (rx8010_read_reg(client, RX8010_REG_FLAG, &status))
+		goto out;
+
+	// check VLF
+	if ((status & RX8010_BIT_FLAG_VLF))
+		dev_warn(&client->dev, "Frequency stop was detected, \
+								probably due to a supply voltage drop\n");
+			 
+	dev_dbg(&client->dev, "%s: RX8010_REG_FLAG: %xh\n", __func__, status);
+
+	// periodic "fixed-cycle" timer
+	if (status & RX8010_BIT_FLAG_TF) {
+		status &= ~RX8010_BIT_FLAG_TF;
+		local_irq_disable();
+		rtc_update_irq(rx8010->rtc, 1, RTC_PF | RTC_IRQF);
+		local_irq_enable();
+	}
+
+	// acknowledge IRQ (clear flags)
+	rx8010_write_reg(client, RX8010_REG_FLAG, status);		
+
+out:
+	if (!rx8010->exiting)
+	{
+		if (rx8010->irq_2 > 0)
+			enable_irq(rx8010->irq_2);
+		else
+			enable_irq(client->irq);
+	}	
+
+	mutex_unlock(lock);
+}
+
+//----------------------------------------------------------------------
+// rx8010_get_time()
+// gets the current time from the rx8010 registers
+//
+//----------------------------------------------------------------------
+static int rx8010_get_time(struct device *dev, struct rtc_time *dt)
+{
+	struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	u8 date[7];
+	int err;
+
+	err = rx8010_read_regs(rx8010->client, RX8010_REG_SEC, 7, date);
+	if (err)
+		return err;
+
+	dev_dbg(dev, "%s: read 0x%02x 0x%02x "
+		"0x%02x 0x%02x 0x%02x 0x%02x 0x%02x\n", __func__,
+		date[0], date[1], date[2], date[3], date[4], date[5], date[6]);
+
+	//Note: need to subtract 0x10 for index as register offset starts at 0x10
+	dt->tm_sec = bcd2bin(date[RX8010_REG_SEC-0x10] & 0x7f);
+	dt->tm_min = bcd2bin(date[RX8010_REG_MIN-0x10] & 0x7f);
+	dt->tm_hour = bcd2bin(date[RX8010_REG_HOUR-0x10] & 0x3f);	//only 24-hour clock
+	dt->tm_mday = bcd2bin(date[RX8010_REG_MDAY-0x10] & 0x3f);
+	dt->tm_mon = bcd2bin(date[RX8010_REG_MONTH-0x10] & 0x1f) - 1;
+	dt->tm_year = bcd2bin(date[RX8010_REG_YEAR-0x10]);
+	dt->tm_wday = bcd2bin(date[RX8010_REG_WDAY-0x10] & 0x7f);
+
+	if (dt->tm_year < 70)
+		dt->tm_year += 100;
+
+	dev_dbg(dev, "%s: date %ds %dm %dh %dmd %dm %dy\n", __func__,
+		dt->tm_sec, dt->tm_min, dt->tm_hour,
+		dt->tm_mday, dt->tm_mon, dt->tm_year);
+
+	return rtc_valid_tm(dt);
+}
+
+//----------------------------------------------------------------------
+// rx8010_set_time()
+// Sets the current time in the rx8010 registers
+//
+// BUG: The HW assumes every year that is a multiple of 4 to be a leap
+// year. Next time this is wrong is 2100, which will not be a leap year
+//
+// Note: If STOP is not set/cleared, the clock will start when the seconds
+//       register is written
+//
+//----------------------------------------------------------------------
+static int rx8010_set_time(struct device *dev, struct rtc_time *dt)
+{
+	struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	u8 date[7];
+	u8 ctrl;
+	int ret;
+
+	//set STOP bit before changing clock/calendar
+	rx8010_read_reg(rx8010->client, RX8010_REG_CTRL, &ctrl);
+	rx8010->ctrlreg = ctrl | RX8010_BIT_CTRL_STOP;
+	rx8010_write_reg(rx8010->client, RX8010_REG_CTRL, rx8010->ctrlreg);
+	
+	//Note: need to subtract 0x10 for index as register offset starts at 0x10
+	date[RX8010_REG_SEC-0x10] = bin2bcd(dt->tm_sec);
+	date[RX8010_REG_MIN-0x10] = bin2bcd(dt->tm_min);
+	date[RX8010_REG_HOUR-0x10] = bin2bcd(dt->tm_hour);		//only 24hr time
+
+	date[RX8010_REG_MDAY-0x10] = bin2bcd(dt->tm_mday);
+	date[RX8010_REG_MONTH-0x10] = bin2bcd(dt->tm_mon + 1);
+	date[RX8010_REG_YEAR-0x10] = bin2bcd(dt->tm_year % 100);
+	date[RX8010_REG_WDAY-0x10] = bin2bcd(dt->tm_wday);
+
+	dev_dbg(dev, "%s: write 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x\n",
+		__func__, date[0], date[1], date[2], date[3], date[4], date[5], date[6]);
+
+	ret =  rx8010_write_regs(rx8010->client, RX8010_REG_SEC, 7, date);
+
+	//clear STOP bit after changing clock/calendar
+	rx8010_read_reg(rx8010->client, RX8010_REG_CTRL, &ctrl);
+	rx8010->ctrlreg = ctrl & ~RX8010_BIT_CTRL_STOP;
+	rx8010_write_reg(rx8010->client, RX8010_REG_CTRL, rx8010->ctrlreg);
+
+	return ret;
+}
+
+//----------------------------------------------------------------------
+// rx8010_init_client()
+// initializes the rx8010
+//
+//----------------------------------------------------------------------
+static int rx8010_init_client(struct i2c_client *client, int *need_reset)
+{
+	struct rx8010_data *rx8010 = i2c_get_clientdata(client);
+	u8 ctrl[3];
+	int need_clear = 0;
+	int err;
+
+	//set reserved register 0x17 with specified value of 0xD8
+	err = rx8010_write_reg(client, 0x17, 0xD8);
+	if (err)
+		goto out;
+	
+	//set reserved register 0x30 with specified value of 0x00
+	err = rx8010_write_reg(client, 0x30, 0x00);
+	if (err)
+		goto out;
+
+	//set reserved register 0x31 with specified value of 0x08
+	err = rx8010_write_reg(client, 0x31, 0x08);
+	if (err)
+		goto out;
+		
+	//set reserved register 0x32 with default value
+	err = rx8010_write_reg(client, RX8010_REG_IRQ, 0x00);
+	if (err)
+		goto out;		
+		
+
+	//get current extension, flag, control register values
+	err = rx8010_read_regs(rx8010->client, RX8010_REG_EXT, 3, ctrl);
+	if (err)
+		goto out;
+	
+	//check for VLF Flag (set at power-on)
+	if ((ctrl[1] & RX8010_BIT_FLAG_VLF)) {
+		dev_warn(&client->dev, "Frequency stop was detected, probably due to a supply voltage drop\n");
+		*need_reset = 1;
+	}
+
+	//check for Alarm Flag
+	if (ctrl[1] & RX8010_BIT_FLAG_AF) {
+		dev_warn(&client->dev, "Alarm was detected\n");
+		need_clear = 1;
+	}
+
+	//check for Periodic Timer Flag
+	if (ctrl[1] & RX8010_BIT_FLAG_TF) {
+		dev_warn(&client->dev, "Periodic timer was detected\n");
+		need_clear = 1;
+	}
+	
+	//check for Update Timer Flag
+	if (ctrl[1] & RX8010_BIT_FLAG_UF) {
+		dev_warn(&client->dev, "Update timer was detected\n");
+		need_clear = 1;
+	}
+
+	//reset or clear needed?
+	if (*need_reset) {
+		//clear 1d, 1e, 1f registers
+		ctrl[0] = ctrl[1] = ctrl[2] = 0;
+		err = rx8010_write_regs(client, RX8010_REG_EXT, 3, ctrl);
+		if (err)
+			goto out;
+	}
+	else if(need_clear){
+		//clear flag register
+		err = rx8010_write_reg(client, RX8010_REG_FLAG, 0x00);
+		if (err)
+			goto out;
+	}
+	
+	//set "test bit" and reserved bits of control register zero
+	rx8010->ctrlreg = (ctrl[2] & ~RX8010_BIT_CTRL_TEST);		
+out:
+	return err;
+}
+
+//----------------------------------------------------------------------
+// rx8010_read_alarm()
+// reads current Alarm 
+//
+// Notes: - currently filters the AE bits (bit 7)
+//        - assumes WADA setting is week (week/day) 
+//----------------------------------------------------------------------
+static int rx8010_read_alarm(struct device *dev, struct rtc_wkalrm *t)
+{
+	struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	struct i2c_client *client = rx8010->client;
+	u8 alarmvals[3];		//minute, hour, week/day values
+	u8 ctrl[3];				//extension, flag, control values
+	int err;
+
+	if (client->irq <= 0)
+		return -EINVAL;
+
+	//get current minute, hour, week/day alarm values
+	err = rx8010_read_regs(client, RX8010_REG_ALMIN, 3, alarmvals);
+	if (err)
+		return err;
+	dev_dbg(dev, "%s: minutes:0x%02x hours:0x%02x week/day:0x%02x\n",
+		__func__, alarmvals[0], alarmvals[1], alarmvals[2]);
+
+	
+	//get current extension, flag, control register values
+	err = rx8010_read_regs(client, RX8010_REG_EXT, 3, ctrl);
+	if (err)
+		return err;
+	dev_dbg(dev, "%s: extension:0x%02x flag:0x%02x control:0x%02x \n",
+		__func__, ctrl[0], ctrl[1], ctrl[2]);
+
+	// Hardware alarm precision is 1 minute
+	t->time.tm_sec = 0;
+	t->time.tm_min = bcd2bin(alarmvals[0] & 0x7f);		//0x7f filters AE bit currently
+	t->time.tm_hour = bcd2bin(alarmvals[1] & 0x3f);		//0x3f filters AE bit currently, also 24hr only
+
+	t->time.tm_wday = -1;
+	t->time.tm_mday = -1;
+	t->time.tm_mon = -1;
+	t->time.tm_year = -1;
+
+	dev_dbg(dev, "%s: date: %ds %dm %dh %dmd %dm %dy\n",
+		__func__,
+		t->time.tm_sec, t->time.tm_min, t->time.tm_hour,
+		t->time.tm_mday, t->time.tm_mon, t->time.tm_year);
+		
+	t->enabled = !!(rx8010->ctrlreg & RX8010_BIT_CTRL_AIE);		//check if interrupt is enabled
+	t->pending = (ctrl[1] & RX8010_BIT_FLAG_AF) && t->enabled;	//check if flag is triggered
+
+	return err;
+}
+
+//----------------------------------------------------------------------
+// rx8010_set_alarm()
+// sets Alarm 
+//
+// Notes: - currently filters the AE bits (bit 7)
+//        - assumes WADA setting is week (week/day) 
+//----------------------------------------------------------------------
+static int rx8010_set_alarm(struct device *dev, struct rtc_wkalrm *t)
+{
+	struct i2c_client *client = to_i2c_client(dev);
+	struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	u8 alarmvals[3];		//minute, hour, day
+	u8 extreg;				//extension register
+	u8 flagreg;				//flag register
+	int err;
+	 
+	if (client->irq <= 0)
+		return -EINVAL;
+		
+	//get current extension register
+	err = rx8010_read_reg(client, RX8010_REG_EXT, &extreg);
+	if (err <0)
+		return err;
+	
+	//get current flag register
+	err = rx8010_read_reg(client, RX8010_REG_FLAG, &flagreg);
+	if (err <0)
+		return err;
+
+	// Hardware alarm precision is 1 minute
+	alarmvals[0] = bin2bcd(t->time.tm_min);
+	alarmvals[1] = bin2bcd(t->time.tm_hour);
+	alarmvals[2] = bin2bcd(t->time.tm_mday);
+	dev_dbg(dev, "%s: write 0x%02x 0x%02x 0x%02x\n", __func__, alarmvals[0], alarmvals[1], alarmvals[2]);
+
+	//check interrupt enable and disable
+	if (rx8010->ctrlreg & RX8010_BIT_CTRL_AIE) {
+		rx8010->ctrlreg &= ~RX8010_BIT_CTRL_AIE;
+		err = rx8010_write_reg(rx8010->client, RX8010_REG_CTRL, rx8010->ctrlreg);
+		if (err)
+			return err;
+	}
+	
+	//write the new minute and hour values
+	//Note:assume minute and hour values will be enabled. Bit 7 of each of the
+	//     minute, hour, week/day register can be set which will "disable" the
+	//     register from triggering an alarm. See the RX8010 spec for more information
+	err = rx8010_write_regs(rx8010->client, RX8010_REG_ALMIN, 2, alarmvals);
+	if (err)
+		return err;
+
+	//set Week/Day bit
+	// Week setting is typically not used, so we will assume "day" setting
+	extreg |= RX8010_BIT_EXT_WADA;		//set to "day of month"
+	err = rx8010_write_reg(rx8010->client, RX8010_REG_EXT, extreg);
+	if (err)
+		return err;
+
+	//set Day of Month register
+	if (alarmvals[2] == 0) {
+		alarmvals[2] |= 0x80;	//turn on AE bit to ignore day of month (no zero day)
+		err = rx8010_write_reg(rx8010->client, RX8010_REG_ALWDAY, alarmvals[2]);
+	}
+	else {
+		err = rx8010_write_reg(rx8010->client, RX8010_REG_ALWDAY, alarmvals[2]);
+	}
+	if (err)
+		return err;
+
+	//clear Alarm Flag
+	flagreg &= ~RX8010_BIT_FLAG_AF;
+	err = rx8010_write_reg(rx8010->client, RX8010_REG_FLAG, flagreg);
+	if (err)
+		return err;
+
+	//re-enable interrupt if required
+	if (t->enabled) {
+
+		if ( rx8010->rtc->uie_rtctimer.enabled )
+			rx8010->ctrlreg |= RX8010_BIT_CTRL_UIE;								//set update interrupt enable
+		if ( rx8010->rtc->aie_timer.enabled )
+			rx8010->ctrlreg |= (RX8010_BIT_CTRL_AIE | RX8010_BIT_CTRL_UIE);		//set alarm interrupt enable
+			
+		err = rx8010_write_reg(rx8010->client, RX8010_REG_CTRL, rx8010->ctrlreg);
+		if (err)
+			return err;
+	}
+
+	return 0;
+}
+
+//----------------------------------------------------------------------
+// rx8010_alarm_irq_enable()
+// sets enables Alarm IRQ
+//
+// Todo: - 
+//
+//----------------------------------------------------------------------
+static int rx8010_alarm_irq_enable(struct device *dev, unsigned int enabled)
+{
+	struct i2c_client *client = to_i2c_client(dev);
+	struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	u8 flagreg;
+	u8 ctrl;
+	int err;
+	
+	//get the current ctrl settings
+	ctrl = rx8010->ctrlreg;
+
+	if (enabled)
+	{
+		if ( rx8010->rtc->uie_rtctimer.enabled )
+			ctrl |= RX8010_BIT_CTRL_UIE;								//set update interrupt enable
+		if ( rx8010->rtc->aie_timer.enabled )
+			ctrl |= (RX8010_BIT_CTRL_AIE | RX8010_BIT_CTRL_UIE);		//set alarm interrupt enable		
+	}
+	else
+	{
+		if ( ! rx8010->rtc->uie_rtctimer.enabled )
+			ctrl &= ~RX8010_BIT_CTRL_UIE;								//clear update interrupt enable
+		if ( ! rx8010->rtc->aie_timer.enabled )
+		{
+			if ( rx8010->rtc->uie_rtctimer.enabled )
+				ctrl &= ~RX8010_BIT_CTRL_AIE;
+			else
+				ctrl &= ~(RX8010_BIT_CTRL_AIE | RX8010_BIT_CTRL_UIE);	//clear alarm interrupt enable
+		}		
+	}
+
+	//clear alarm flag
+	err = rx8010_read_reg(client, RX8010_REG_FLAG, &flagreg);
+	if (err <0)
+		return err;
+	flagreg &= ~RX8010_BIT_FLAG_AF;
+	err = rx8010_write_reg(rx8010->client, RX8010_REG_FLAG, flagreg);
+	if (err)
+		return err;
+	
+	//update the Control register if the setting changed
+	if (ctrl != rx8010->ctrlreg) {
+		rx8010->ctrlreg = ctrl;
+		err = rx8010_write_reg(rx8010->client, RX8010_REG_CTRL, rx8010->ctrlreg);
+		if (err)
+			return err;
+	}
+	
+	return 0;
+}
+
+//---------------------------------------------------------------------------
+// rx8010_ioctl()
+//
+//---------------------------------------------------------------------------
+static int rx8010_ioctl(struct device *dev, unsigned int cmd, unsigned long arg)
+{
+	struct i2c_client *client = to_i2c_client(dev);
+	//struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	//struct mutex *lock = &rx8010->rtc->ops_lock;
+	int ret = 0;
+	int tmp;
+	void __user *argp = (void __user *)arg;
+	reg_data reg;
+	
+	dev_dbg(dev, "%s: cmd=%x\n", __func__, cmd);
+
+	switch (cmd) {
+		case SE_RTC_REG_READ:
+			if (copy_from_user(&reg, argp, sizeof(reg)))
+				return -EFAULT;
+			if ( reg.number < RX8010_REG_SEC || reg.number > RX8010_REG_IRQ )
+				return -EFAULT;
+			//mutex_lock(lock);
+			ret = rx8010_read_reg(client, reg.number, &reg.value);
+			//mutex_unlock(lock);
+			if (! ret )				
+				return copy_to_user(argp, &reg, sizeof(reg)) ? -EFAULT : 0;
+			break;
+			
+		case SE_RTC_REG_WRITE:
+			if (copy_from_user(&reg, argp, sizeof(reg)))
+				return -EFAULT;
+			if ( reg.number < RX8010_REG_SEC || reg.number > RX8010_REG_IRQ )
+				return -EFAULT;				
+			//mutex_lock(lock);
+			ret = rx8010_write_reg(client, reg.number, reg.value);
+			//mutex_unlock(lock);
+			break;
+	
+		case RTC_VL_READ:
+			//mutex_lock(lock);
+			ret = rx8010_read_reg(client, RX8010_REG_FLAG, &reg.value);
+			//mutex_unlock(lock);
+			if (! ret)	
+			{
+				tmp = !!(reg.value & RX8010_BIT_FLAG_VLF);
+				return copy_to_user(argp, &tmp, sizeof(tmp)) ? -EFAULT : 0;
+			}			
+			break;			
+				
+		case RTC_VL_CLR:
+			//mutex_lock(lock);
+			ret = rx8010_read_reg(client, RX8010_REG_FLAG, &reg.value);
+			if (! ret)
+			{
+				reg.value &= ~RX8010_BIT_FLAG_VLF;
+				ret = rx8010_write_reg(client, RX8010_REG_FLAG, reg.value);
+			}
+			//mutex_unlock(lock);
+			break;
+			
+		default:
+			return -ENOIOCTLCMD;			
+	}
+	
+	return ret;
+}
+
+static struct rtc_class_ops rx8010_rtc_ops = {
+	.read_time = rx8010_get_time,
+	.set_time = rx8010_set_time,
+	.read_alarm = rx8010_read_alarm,
+	.set_alarm = rx8010_set_alarm,
+	.alarm_irq_enable = rx8010_alarm_irq_enable,
+	.ioctl = rx8010_ioctl,
+};
+
+//----------------------------------------------------------------------
+// rx8010_probe()
+// probe routine for the rx8010 driver
+//
+//----------------------------------------------------------------------
+static int rx8010_probe(struct i2c_client *client, const struct i2c_device_id *id)
+{
+	struct device_node *np = client->dev.of_node; 
+	struct i2c_adapter *adapter = to_i2c_adapter(client->dev.parent);
+	struct rx8010_data *rx8010;
+	int err, gpio, i, irqs_success = 0, need_reset = 0;
+	const char * irq_name[2] = {"rx8010-irq_1", "rx8010-irq_2"};
+
+	if (!i2c_check_functionality(adapter, I2C_FUNC_SMBUS_BYTE_DATA | I2C_FUNC_SMBUS_I2C_BLOCK)) {
+		dev_err(&adapter->dev, "doesn't support required functionality\n");
+		err = -EIO;
+		goto errout;
+	}
+
+	rx8010 = devm_kzalloc(&client->dev, sizeof(struct rx8010_data), GFP_KERNEL);
+	if (!rx8010) {
+		dev_err(&adapter->dev, "failed to alloc memory\n");
+		err = -ENOMEM;
+		goto errout;
+	}
+
+	rx8010->client = client;
+	i2c_set_clientdata(client, rx8010);
+
+	err = rx8010_init_client(client, &need_reset);
+	if (err)
+		goto errout;
+
+
+	if (need_reset) {
+		struct rtc_time tm;
+		rtc_time_to_tm(0, &tm);		// set to 1970/1/1
+		rx8010_set_time(&client->dev, &tm);
+		dev_warn(&client->dev, " - time reset to 1970/1/1\n");
+	}
+
+	rx8010->rtc = rtc_device_register(client->name, &client->dev, &rx8010_rtc_ops, THIS_MODULE);
+	
+	if (IS_ERR(rx8010->rtc)) {
+		err = PTR_ERR(rx8010->rtc);
+		dev_err(&client->dev, "unable to register the class device\n");
+		goto errout;
+	}
+
+	// get interrupts
+	rx8010->irq_1 = rx8010->irq_2 = -1;
+	for ( i=0; i < 2; i++ )
+	{
+		gpio = of_get_named_gpio(np, irq_name[i], 0);
+		if (gpio_is_valid(gpio)) {
+			int irq;
+			err = devm_gpio_request_one(&client->dev, gpio, GPIOF_DIR_IN, 
+															irq_name[i]);
+			if (err) {
+				dev_err(&client->dev, "cannot request %s\n", irq_name[i]);
+				goto errout_reg;
+			}
+			irq = gpio_to_irq(gpio);
+			dev_dbg(&client->dev, "%s %d\n", irq_name[i], irq);
+			if (irq <= 0) {
+				dev_warn(&client->dev, "Failed to "
+					"convert gpio #%d to %s\n",
+					gpio, irq_name[i]);
+				goto errout_reg;
+			}
+			err = devm_request_threaded_irq(&client->dev,irq, NULL, 
+											i==0 ? rx8010_irq_1 : rx8010_irq_2, 
+											IRQF_TRIGGER_LOW | IRQF_ONESHOT,
+											irq_name[i], 
+											client);	
+			if (err) {
+				dev_err(&client->dev, "unable to request %s\n", irq_name[i]);
+				goto errout_reg;
+			}
+			if (i == 0)
+			{
+				rx8010->irq_1 = irq;
+				INIT_WORK(&rx8010->work_1, rx8010_work_1);
+			}
+			else
+			{
+				rx8010->irq_2 = irq;
+				INIT_WORK(&rx8010->work_2, rx8010_work_2);
+			}
+			irqs_success++;		
+		} else {
+				dev_warn(&client->dev, "%s missing or invalid\n", 
+										irq_name[i]);
+		}
+	}
+	
+	// another irq request try if one failed above
+	if ( ! irqs_success && client->irq > 0 ){
+		dev_info(&client->dev, "IRQ %d supplied\n", client->irq);
+		err = devm_request_threaded_irq(&client->dev,client->irq, NULL, 
+										rx8010_irq_1, 
+										IRQF_TRIGGER_LOW | IRQF_ONESHOT,
+										"rx8010", client);
+		
+		if (err) {
+			dev_err(&client->dev, "unable to request IRQ\n");
+			goto errout_reg;
+		}
+		INIT_WORK(&rx8010->work_1, rx8010_work_1);	
+	}
+		
+
+	rx8010->rtc->irq_freq = 1;
+	rx8010->rtc->max_user_freq = 1;
+		
+	return 0;
+
+errout_reg:
+	rtc_device_unregister(rx8010->rtc);
+
+errout:
+	dev_err(&adapter->dev, "probing for rx8010 failed\n");
+	return err;
+}
+
+//----------------------------------------------------------------------
+// rx8010_remove()
+// remove routine for the rx8010 driver
+//
+//----------------------------------------------------------------------
+static int rx8010_remove(struct i2c_client *client)
+{
+	struct rx8010_data *rx8010 = i2c_get_clientdata(client);
+	struct mutex *lock = &rx8010->rtc->ops_lock;
+
+	if (client->irq > 0 || rx8010->irq_1 > 0 || rx8010->irq_2 > 0) {
+		mutex_lock(lock);
+		rx8010->exiting = 1;
+		mutex_unlock(lock);
+
+		//cancel_work
+		if (rx8010->irq_1 > 0 || client->irq > 0)
+			cancel_work_sync(&rx8010->work_1);
+		if (rx8010->irq_2 > 0)
+			cancel_work_sync(&rx8010->work_2);
+	}
+
+	rtc_device_unregister(rx8010->rtc);
+	
+	return 0;
+}
+
+static struct i2c_driver rx8010_driver = {
+	.driver = {
+		.name = "rtc-rx8010",
+		.owner = THIS_MODULE,
+	},
+	.probe		= rx8010_probe,
+	.remove		= rx8010_remove,
+	.id_table	= rx8010_id,
+};
+
+module_i2c_driver(rx8010_driver);
+
+MODULE_AUTHOR("Dennis Henderson <henderson.dennis@erd.epson.com>");
+MODULE_DESCRIPTION("RX-8010 SJ RTC driver");
+MODULE_LICENSE("GPL");
diff --git a/drivers/scsi/scsi_lib.c b/drivers/scsi/scsi_lib.c
index 887045a..53725bb 100644
--- a/drivers/scsi/scsi_lib.c
+++ b/drivers/scsi/scsi_lib.c
@@ -1694,6 +1694,10 @@ static int scsi_dispatch_cmd(struct scsi_cmnd *cmd)
 
 	/* Store the LUN value in cmnd, if needed. */
 	if (cmd->device->lun_in_cdb)
+#ifdef CONFIG_BUFFALO_IGNORE_LUN
+		/* support for AVU2 */
+		if (cmd->device->ignore_lun || !(cmd->cmnd[0] & 0xc0))
+#endif /* CONFIG_BUFFALO_IGNORE_LUN */
 		cmd->cmnd[1] = (cmd->cmnd[1] & 0x1f) |
 			       (cmd->device->lun << 5 & 0xe0);
 
diff --git a/drivers/scsi/scsi_scan.c b/drivers/scsi/scsi_scan.c
index 692445b..45c8ce0 100644
--- a/drivers/scsi/scsi_scan.c
+++ b/drivers/scsi/scsi_scan.c
@@ -1309,6 +1309,9 @@ static int scsi_report_lun_scan(struct scsi_target *starget, int bflags,
 	struct Scsi_Host *shost = dev_to_shost(&starget->dev);
 	int ret = 0;
 
+#ifdef CONFIG_BUFFALO_IGNORE_LUN
+	return 1;
+#endif	/* CONFIG_BUFFALO_IGNORE_LUN */
 	/*
 	 * Only support SCSI-3 and up devices if BLIST_NOREPORTLUN is not set.
 	 * Also allow SCSI-2 if BLIST_REPORTLUN2 is set and host adapter does
diff --git a/drivers/scsi/scsi_sysfs.c b/drivers/scsi/scsi_sysfs.c
index 4477e99..f831990 100644
--- a/drivers/scsi/scsi_sysfs.c
+++ b/drivers/scsi/scsi_sysfs.c
@@ -593,6 +593,9 @@ sdev_rd_attr (scsi_level, "%d\n");
 sdev_rd_attr (vendor, "%.8s\n");
 sdev_rd_attr (model, "%.16s\n");
 sdev_rd_attr (rev, "%.4s\n");
+#ifdef CONFIG_BUFFALO_IGNORE_LUN
+sdev_rw_attr (ignore_lun, "%d\n");
+#endif	/* CONFIG_BUFFALO_IGNORE_LUN */
 
 static ssize_t
 sdev_show_device_busy(struct device *dev, struct device_attribute *attr,
@@ -957,6 +960,9 @@ static struct attribute *scsi_sdev_attrs[] = {
 	&dev_attr_vendor.attr,
 	&dev_attr_model.attr,
 	&dev_attr_rev.attr,
+#ifdef CONFIG_BUFFALO_IGNORE_LUN
+	&dev_attr_ignore_lun,
+#endif	/* CONFIG_BUFFALO_IGNORE_LUN */
 	&dev_attr_rescan.attr,
 	&dev_attr_delete.attr,
 	&dev_attr_state.attr,
diff --git a/drivers/scsi/sd.c b/drivers/scsi/sd.c
index dd72205..35628a3 100644
--- a/drivers/scsi/sd.c
+++ b/drivers/scsi/sd.c
@@ -3025,6 +3025,10 @@ static void sd_probe_async(void *data, async_cookie_t cookie)
 	gd->fops = &sd_fops;
 	gd->private_data = &sdkp->driver;
 	gd->queue = sdkp->device->request_queue;
+#ifdef CONFIG_BUFFALO_IOERRS
+	gd->io_errors = 0;
+	gd->limit_io_errors = 1000;	/* default limit *//* XXX: should use MAXERR_CNT_DEFAULT in dirivers/md/md.h ? but it is not reasonable to include drivers/md/md.h ... */
+#endif	/* CONFIG_BUFFALO_IOERRS */
 
 	/* defaults, until the device tells us otherwise */
 	sdp->sector_size = 512;
diff --git a/drivers/scsi/sd.h b/drivers/scsi/sd.h
index 765a6f1..a58f110 100644
--- a/drivers/scsi/sd.h
+++ b/drivers/scsi/sd.h
@@ -11,7 +11,11 @@
 /*
  * Time out in seconds for disks and Magneto-opticals (which are slower).
  */
+#ifdef CONFIG_BUFFALO_PLATFORM
+#define SD_TIMEOUT		(120 * HZ)
+#else	/* CONFIG_BUFFALO_PLATFORM */
 #define SD_TIMEOUT		(30 * HZ)
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 #define SD_MOD_TIMEOUT		(75 * HZ)
 /*
  * Flush timeout is a multiplier over the standard device timeout which is
diff --git a/drivers/target/iscsi/Kconfig b/drivers/target/iscsi/Kconfig
index 8345fb4..014bbf5 100644
--- a/drivers/target/iscsi/Kconfig
+++ b/drivers/target/iscsi/Kconfig
@@ -7,3 +7,12 @@ config ISCSI_TARGET
 	help
 	Say M here to enable the ConfigFS enabled Linux-iSCSI.org iSCSI
 	Target Mode Stack.
+
+config ISCSI_CHAP_BASE64_SUPPORT
+	bool "Enable to apply iSCSI CHAP(Base64) support patch"
+	depends on ISCSI_TARGET
+	help
+	  Enable CHAP(Base64) authentication supports.
+	  Must be enabled to pass MicroSoft's iSCSI Target Mutual CHAP Test (LOGO)
+
+	  If unsure, say N.
\ No newline at end of file
diff --git a/drivers/target/iscsi/Makefile b/drivers/target/iscsi/Makefile
index 0f43be9c..71ec64e 100644
--- a/drivers/target/iscsi/Makefile
+++ b/drivers/target/iscsi/Makefile
@@ -18,3 +18,5 @@ iscsi_target_mod-y +=		iscsi_target_parameters.o \
 				iscsi_target_transport.o
 
 obj-$(CONFIG_ISCSI_TARGET)	+= iscsi_target_mod.o
+
+ccflags-$(CONFIG_ISCSI_CHAP_BASE64_SUPPORT) += -DISCSI_CHAP_BASE64_SUPPORT
diff --git a/drivers/target/iscsi/iscsi_target.c b/drivers/target/iscsi/iscsi_target.c
index 58fe277..b12ea57 100644
--- a/drivers/target/iscsi/iscsi_target.c
+++ b/drivers/target/iscsi/iscsi_target.c
@@ -46,6 +46,18 @@
 #include <target/iscsi/iscsi_target_stat.h>
 
 #include <target/iscsi/iscsi_transport.h>
+#ifdef CONFIG_BUFFALO_PLATFORM
+#include <linux/proc_fs.h>
+#endif /*CONFIG_BUFFALO_PLATFORM*/
+#ifdef MODULE
+/* To avoid link-error caused by 64-bit dividend in module. */
+#ifdef __arm__
+u_int64_t __aeabi_uldivmod(u_int64_t a, u_int64_t b)
+{
+	return div64_u64(a, b);
+}
+#endif /*__arm__*/
+#endif /*MODULE*/
 
 static LIST_HEAD(g_tiqn_list);
 static LIST_HEAD(g_np_list);
@@ -524,6 +536,186 @@ static struct iscsit_transport iscsi_target_transport = {
 	.iscsit_get_sup_prot_ops = iscsit_get_sup_prot_ops,
 };
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+static struct proc_dir_entry *proc_iscsi_target_dir_entry = NULL,
+                             *proc_status_dir_entry = NULL,
+                             *proc_session_dir_entry = NULL,
+                             *proc_conn_dir_entry = NULL;
+
+static int session_show(struct seq_file *seq, void *v)
+{
+        struct iscsi_tiqn *tiqn = NULL;
+        struct iscsi_portal_group *tpg = NULL;
+        struct se_session *se_sess = NULL;
+        struct iscsi_session *sess = NULL;
+        struct timespec ts;
+	int inst = 1;
+
+        seq_printf(seq, "inst node sid intr_name tgt_name creation_time\n");
+
+        spin_lock(iscsit_global->tiqn_lock);
+        list_for_each_entry(tiqn, iscsit_global->tiqn_list, tiqn_list) {
+                spin_lock(&tiqn->tiqn_tpg_lock);
+                list_for_each_entry(tpg, &tiqn->tiqn_tpg_list, tpg_list) {
+                        spin_lock(&tpg->tpg_se_tpg.session_lock);
+                        list_for_each_entry(se_sess,
+                                            &tpg->tpg_se_tpg.tpg_sess_list,
+                                            sess_list) {
+                                sess = (struct iscsi_session *)
+                                       se_sess->fabric_sess_ptr;
+				getnstimeofday(&ts);
+                                seq_printf(seq,
+                                               "%d %d %d %s %s %llu\n",
+                                               inst++, tiqn->tiqn_index,
+                                               sess->sid,
+                                               sess->sess_ops->InitiatorName,
+                                               sess->sess_ops->TargetName,
+                                               (ts.tv_sec + ts.tv_nsec / 1000000000) -
+                                               ((get_jiffies_64() - INITIAL_JIFFIES) / HZ) +
+                                               ((sess->creation_time - INITIAL_JIFFIES) / HZ));
+                        }
+                        spin_unlock(&tpg->tpg_se_tpg.session_lock);
+                }
+                spin_unlock(&tiqn->tiqn_tpg_lock);
+        }
+        spin_unlock(iscsit_global->tiqn_lock);
+
+	return 0;
+}
+
+static int session_seq_open(struct inode *inode, struct file *file)
+{
+	return single_open(file, session_show, NULL);
+}
+
+static struct file_operations session_proc_fops = {
+        .owner = THIS_MODULE,
+        .open = session_seq_open,
+        .read = seq_read,
+        .llseek = seq_lseek,
+        .release = single_release,
+};
+
+static int connection_show(struct seq_file *seq, void *v)
+{
+	struct iscsi_tiqn *tiqn = NULL;
+        struct iscsi_portal_group *tpg = NULL;
+        struct se_session *se_sess = NULL;
+        struct iscsi_session *sess = NULL;
+        struct iscsi_conn *conn = NULL;
+        int inst = 1;
+        struct sockaddr_in6 *sock_in6 = NULL;
+        struct sockaddr_in *sock_in = NULL;
+        char *local_ip = NULL;
+        char *login_ip = NULL;
+        u16 local_port = 0;
+        u16 login_port = 0;
+
+        seq_printf(seq, "inst node sid cid addr_type local_ip local_port rem_ip rem_port\n");
+
+        spin_lock(iscsit_global->tiqn_lock);
+        list_for_each_entry(tiqn, iscsit_global->tiqn_list, tiqn_list) {
+                spin_lock(&tiqn->tiqn_tpg_lock);
+                list_for_each_entry(tpg, &tiqn->tiqn_tpg_list, tpg_list) {
+                        spin_lock(&tpg->tpg_se_tpg.session_lock);
+                        list_for_each_entry(se_sess,
+                                            &tpg->tpg_se_tpg.tpg_sess_list,
+                                            sess_list) {
+                                sess = (struct iscsi_session *)
+                                       se_sess->fabric_sess_ptr;
+                                list_for_each_entry(conn,
+                                                    &sess->sess_conn_list,
+                                                    conn_list) {
+                                        if (conn->login_family == AF_INET6) {
+                                                sock_in6 = (struct sockaddr_in6 *)&conn->local_sockaddr;
+                                                local_ip = &sock_in6->sin6_addr;
+                                                local_port = ntohs(sock_in6->sin6_port);
+                                                sock_in6 = (struct sockaddr_in6 *)&conn->login_sockaddr;
+                                                login_ip = &sock_in6->sin6_addr;
+                                                login_port = ntohs(sock_in6->sin6_port);
+                                        } else {
+                                                sock_in = (struct sockaddr_in *)&conn->local_sockaddr;
+                                                local_ip = &sock_in->sin_addr;
+                                                local_port = ntohs(sock_in->sin_port);
+                                                sock_in = (struct sockaddr_in *)&conn->login_sockaddr;
+                                                login_ip = &sock_in->sin_addr;
+                                                login_port = ntohs(sock_in->sin_port);
+                                        }
+                                        seq_printf(seq,
+                                               conn->login_family == AF_INET6
+                                                   ? "%d %d %d %d %s %pI6 %d %pI6 %d\n"
+                                                   : "%d %d %d %d %s %pI4 %d %pI4 %d\n",
+                                               inst++, tiqn->tiqn_index,
+                                               sess->sid, conn->cid,
+                                               conn->login_family == AF_INET6 ? "ipv6" : "ipv4",
+                                               local_ip,
+                                               local_port,
+                                               login_ip,
+                                               login_port);
+                                }
+                        }
+                        spin_unlock(&tpg->tpg_se_tpg.session_lock);
+                }
+                spin_unlock(&tiqn->tiqn_tpg_lock);
+        }
+        spin_unlock(iscsit_global->tiqn_lock);
+
+	return 0;
+}
+
+static int connection_seq_open(struct inode *inode, struct file *file)
+{
+        return single_open(file, connection_show, NULL);
+}
+
+static struct file_operations connection_proc_fops = {
+	.owner = THIS_MODULE,
+	.open = connection_seq_open,
+	.read = seq_read,
+	.llseek = seq_lseek,
+	.release = single_release,
+};
+
+static void create_proc_entries(void)
+{
+	proc_iscsi_target_dir_entry = proc_mkdir("iscsi_target", NULL);
+	if (proc_iscsi_target_dir_entry == NULL) {
+		pr_err("Failed to create proc 'iscsi_target' dir\n");
+	}
+	else {
+		proc_status_dir_entry =
+			proc_mkdir("status", proc_iscsi_target_dir_entry);
+		if (proc_status_dir_entry == NULL) {
+			pr_err("Failed to create proc 'iscsi_target/status' dir\n");
+		}
+		else {
+			proc_session_dir_entry =
+				proc_create("session", 0444,
+                                            proc_status_dir_entry, &session_proc_fops);
+			proc_conn_dir_entry =
+				proc_create("connection", 0444,
+                                            proc_status_dir_entry, &connection_proc_fops);
+		}
+	}
+}
+
+static void remove_proc_entries(void)
+{
+	if (proc_session_dir_entry != NULL) {
+		proc_remove(proc_session_dir_entry);
+	}
+	if (proc_conn_dir_entry != NULL) {
+		proc_remove(proc_conn_dir_entry);
+	}
+	if (proc_status_dir_entry != NULL) {
+		proc_remove(proc_status_dir_entry);
+	}
+	if (proc_iscsi_target_dir_entry != NULL) {
+		proc_remove(proc_iscsi_target_dir_entry);
+	}
+}
+#endif /*CONFIG_BUFFALO_PLATFORM*/
+
 static int __init iscsi_target_init_module(void)
 {
 	int ret = 0, size;
@@ -535,6 +727,12 @@ static int __init iscsi_target_init_module(void)
 		pr_err("Unable to allocate memory for iscsit_global\n");
 		return -1;
 	}
+#ifdef CONFIG_BUFFALO_PLATFORM
+	iscsit_global->tiqn_list = &g_tiqn_list;
+	iscsit_global->np_list = &g_np_list;
+	iscsit_global->tiqn_lock = &tiqn_lock;
+	iscsit_global->np_lock = &np_lock;
+#endif /*CONFIG_BUFFALO_PLATFORM*/
 	spin_lock_init(&iscsit_global->ts_bitmap_lock);
 	mutex_init(&auth_id_lock);
 	spin_lock_init(&sess_idr_lock);
@@ -592,6 +790,9 @@ static int __init iscsi_target_init_module(void)
 
 	if (iscsit_load_discovery_tpg() < 0)
 		goto r2t_out;
+#ifdef CONFIG_BUFFALO_PLATFORM
+	create_proc_entries();
+#endif /*CONFIG_BUFFALO_PLATFORM*/
 
 	return ret;
 r2t_out:
@@ -617,6 +818,9 @@ out:
 
 static void __exit iscsi_target_cleanup_module(void)
 {
+#ifdef CONFIG_BUFFALO_PLATFORM
+	remove_proc_entries();
+#endif /*CONFIG_BUFFALO_PLATFORM*/
 	iscsit_release_discovery_tpg();
 	iscsit_unregister_transport(&iscsi_target_transport);
 	kmem_cache_destroy(lio_qr_cache);
diff --git a/drivers/target/iscsi/iscsi_target_auth.c b/drivers/target/iscsi/iscsi_target_auth.c
index 47e249d..fbac6c5 100644
--- a/drivers/target/iscsi/iscsi_target_auth.c
+++ b/drivers/target/iscsi/iscsi_target_auth.c
@@ -26,6 +26,131 @@
 #include "iscsi_target_nego.h"
 #include "iscsi_target_auth.h"
 
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+// Base64 decoding, taken from UNH-iSCSI "Base64codeToNumber()"
+static unsigned char decode_base64_digit(const char base64)
+{
+	switch (base64) {
+	case '=':
+		return 64;
+	case '/':
+		return 63;
+	case '+':
+		return 62;
+	default:
+		if ((base64 >= 'A') && (base64 <= 'Z')) {
+			return base64 - 'A';
+		} else if ((base64 >= 'a') && (base64 <= 'z')) {
+			return 26 + (base64 - 'a');
+		} else if ((base64 >= '0') && (base64 <= '9')) {
+			return 52 + (base64 - '0');
+		} else {
+			return -1;
+		}
+	}
+}
+
+// Base64 decoding, taken from UNH-iSCSI "Base64StringToInteger()"
+static void decode_base64_string(const char* string, unsigned char* int_num, const int int_len)
+{
+	int len = -1;
+	int count = 0;
+	int intptr = 0;
+	unsigned char num[4] = {0};
+	int octets = -1;
+
+	if (!string || !int_num) {
+		return;
+	}
+
+	if (0 == (len = strlen(string))) {
+		return;
+	}
+
+	if (0 != (len % 4)) {
+		return;
+	}
+
+	while (count < len - 4) {
+		num[0] = decode_base64_digit(string[count]);
+		num[1] = decode_base64_digit(string[count + 1]);
+		num[2] = decode_base64_digit(string[count + 2]);
+		num[3] = decode_base64_digit(string[count + 3]);
+		if ((65 == num[0]) || (65 == num[1]) || (65 == num[2]) || (65 == num[3])) {
+			return;
+		}
+		count += 4;
+		octets = (num[0] << 18) | (num[1] << 12) | (num[2] << 6) | num[3];
+		int_num[intptr] = (octets & 0xFF0000) >> 16;
+		int_num[intptr + 1] = (octets & 0x00FF00) >> 8;
+		int_num[intptr + 2] = octets & 0x0000FF;
+		intptr += 3;
+	}
+	num[0] = decode_base64_digit(string[count]);
+	num[1] = decode_base64_digit(string[count + 1]);
+	num[2] = decode_base64_digit(string[count + 2]);
+	num[3] = decode_base64_digit(string[count + 3]);
+	if ((64 == num[0]) || (64 == num[1])) {
+		return;
+	}
+	if (64 == num[2]) {
+		if (64 != num[3]) {
+			return;
+		}
+		int_num[intptr] = (num[0] << 2) | (num[1] >> 4);
+	} else if (num[3] == 64) {
+		int_num[intptr] = (num[0] << 2) | (num[1] >> 4);
+		int_num[intptr + 1] = (num[1] << 4) | (num[2] >> 2);
+	} else {
+		octets = (num[0] << 18) | (num[1] << 12) | (num[2] << 6) | num[3];
+		int_num[intptr] = (octets & 0xFF0000) >> 16;
+		int_num[intptr + 1] = (octets & 0x00FF00) >> 8;
+		int_num[intptr + 2] = octets & 0x0000FF;
+	}
+}
+
+// Base64 encoding, taken from UNH iSCSI "IntegerToBase64String()"
+static void encode_base64_string(char* string, const unsigned char* int_num, const long int_len)
+{
+	int count = 0, octets = 0, strptr = 0, delta = -1;
+	static const char base64code[] = {
+		'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
+		'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
+		'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm',
+		'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z',
+		'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '+', '/', '='
+	};
+
+	if (!int_num || !string || !int_len) {
+		return;
+	}
+
+	while (2 < (delta = (int_len - count))) {
+		octets = (int_num[count] << 16) | (int_num[count + 1] << 8) | int_num[count + 2];
+		string[strptr] = base64code[(octets & 0xfc0000) >> 18];
+		string[strptr + 1] = base64code[(octets & 0x03f000) >> 12];
+		string[strptr + 2] = base64code[(octets & 0x000fc0) >> 6];
+		string[strptr + 3] = base64code[octets & 0x00003f];
+		count += 3;
+		strptr += 4;
+	}
+	if (delta == 1) {
+		string[strptr] = base64code[(int_num[count] & 0xfc) >> 2];
+		string[strptr + 1] = base64code[(int_num[count] & 0x03) << 4];
+		string[strptr + 2] = base64code[64];
+		string[strptr + 3] = base64code[64];
+		strptr += 4;
+	} else if (delta == 2) {
+		string[strptr] = base64code[(int_num[count] & 0xfc) >> 2];
+		string[strptr + 1] = base64code[((int_num[count] & 0x03) << 4) | ((int_num[count + 1] & 0xf0) >> 4)];
+		string[strptr + 2] = base64code[(int_num[count + 1] & 0x0f) << 2];
+		string[strptr + 3] = base64code[64];
+		strptr += 4;
+	}
+	string[strptr] = '\0';
+}
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
+
 static int chap_string_to_hex(unsigned char *dst, unsigned char *src, int len)
 {
 	int j = DIV_ROUND_UP(len, 2), rc;
@@ -237,13 +362,25 @@ static int chap_server_compute_md5(
 		pr_err("Could not find CHAP_R.\n");
 		goto out;
 	}
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type != HEX && type != BASE64) {
+#else
 	if (type != HEX) {
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 		pr_err("Could not find CHAP_R.\n");
 		goto out;
 	}
 
 	pr_debug("[server] Got CHAP_R=%s\n", chap_r);
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type == HEX) {
+		chap_string_to_hex(client_digest, chap_r, strlen(chap_r));
+	} else {
+		decode_base64_string(chap_r, client_digest, MD5_SIGNATURE_SIZE);
+	}
+#else
 	chap_string_to_hex(client_digest, chap_r, strlen(chap_r));
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 
 	tfm = crypto_alloc_hash("md5", 0, CRYPTO_ALG_ASYNC);
 	if (IS_ERR(tfm)) {
@@ -318,7 +455,11 @@ static int chap_server_compute_md5(
 		goto out;
 	}
 
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type == HEX || type == BASE64)
+#else
 	if (type == HEX)
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 		ret = kstrtoul(&identifier[2], 0, &id);
 	else
 		ret = kstrtoul(identifier, 0, &id);
@@ -344,13 +485,42 @@ static int chap_server_compute_md5(
 		goto out;
 	}
 
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type != HEX && type != BASE64) {
+#else
 	if (type != HEX) {
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 		pr_err("Could not find CHAP_C.\n");
 		goto out;
 	}
 	pr_debug("[server] Got CHAP_C=%s\n", challenge);
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type == HEX) {
+		challenge_len = chap_string_to_hex(challenge_binhex, challenge, strlen(challenge));
+	} else {
+		int len = strlen(challenge);
+		if (len % 4) {
+			pr_err("invalid length: %zu\n", strlen(challenge));
+			goto out;
+		}
+
+		if (len < 2) {
+			pr_err("length is shorter than 2: %zu\n", strlen(challenge));
+			goto out;
+		}
+
+		challenge_len = strlen(challenge) / 4 * 3;
+		if (challenge[len - 1] == '=')
+			challenge_len--;
+		if (challenge[len - 2] == '=')
+			challenge_len--;
+
+		decode_base64_string(challenge, challenge_binhex, challenge_len);
+	}
+#else
 	challenge_len = chap_string_to_hex(challenge_binhex, challenge,
 				strlen(challenge));
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 	if (!challenge_len) {
 		pr_err("Unable to convert incoming challenge\n");
 		goto out;
@@ -430,6 +600,25 @@ static int chap_server_compute_md5(
 	*nr_out_len = sprintf(nr_out_ptr, "CHAP_N=%s", auth->userid_mutual);
 	*nr_out_len += 1;
 	pr_debug("[server] Sending CHAP_N=%s\n", auth->userid_mutual);
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type == HEX) {
+		/*
+		 * Convert response from binary hex to ascii hext.
+		 */
+
+		chap_binaryhex_to_asciihex(response, digest, MD5_SIGNATURE_SIZE);
+		*nr_out_len += sprintf(nr_out_ptr + *nr_out_len, "CHAP_R=0x%s",
+				response);
+		*nr_out_len += 1;
+		pr_debug("[server] Sending CHAP_R=0x%s\n", response);
+	} else {
+		encode_base64_string(response, digest, MD5_SIGNATURE_SIZE);
+		*nr_out_len += sprintf(nr_out_ptr + *nr_out_len, "CHAP_R=0b%s",
+			response);
+		*nr_out_len += 1;
+		pr_debug("[server] Sending CHAP_R=0b%s\n", response);
+	}
+#else
 	/*
 	 * Convert response from binary hex to ascii hext.
 	 */
@@ -438,6 +627,7 @@ static int chap_server_compute_md5(
 			response);
 	*nr_out_len += 1;
 	pr_debug("[server] Sending CHAP_R=0x%s\n", response);
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 	auth_ret = 0;
 out:
 	kfree(challenge);
diff --git a/drivers/target/iscsi/iscsi_target_login.c b/drivers/target/iscsi/iscsi_target_login.c
index bc2cbff..70a6084 100644
--- a/drivers/target/iscsi/iscsi_target_login.c
+++ b/drivers/target/iscsi/iscsi_target_login.c
@@ -492,13 +492,14 @@ static int iscsi_login_non_zero_tsih_s1(
  */
 static int iscsi_login_non_zero_tsih_s2(
 	struct iscsi_conn *conn,
-	unsigned char *buf)
+	unsigned char *p)
 {
 	struct iscsi_portal_group *tpg = conn->tpg;
 	struct iscsi_session *sess = NULL, *sess_p = NULL;
 	struct se_portal_group *se_tpg = &tpg->tpg_se_tpg;
 	struct se_session *se_sess, *se_sess_tmp;
-	struct iscsi_login_req *pdu = (struct iscsi_login_req *)buf;
+	struct iscsi_login_req *pdu = (struct iscsi_login_req *)p;
+	unsigned char buf[32];
 	bool iser = false;
 
 	spin_lock_bh(&se_tpg->session_lock);
diff --git a/drivers/target/iscsi/iscsi_target_nego.c b/drivers/target/iscsi/iscsi_target_nego.c
index 58c629a..bcbaa8c 100644
--- a/drivers/target/iscsi/iscsi_target_nego.c
+++ b/drivers/target/iscsi/iscsi_target_nego.c
@@ -82,6 +82,11 @@ int extract_param(
 	if (*ptr == '0' && (*(ptr+1) == 'x' || *(ptr+1) == 'X')) {
 		ptr += 2; /* skip 0x */
 		*type = HEX;
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	} else if (*ptr == '0' && (*(ptr+1) == 'b' || *(ptr+1) == 'B')) {
+		ptr += 2; /* skip 0b */
+		*type = BASE64;
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 	} else
 		*type = DECIMAL;
 
diff --git a/drivers/target/iscsi/iscsi_target_nego.h b/drivers/target/iscsi/iscsi_target_nego.h
index f021cbd..54d5cd5 100644
--- a/drivers/target/iscsi/iscsi_target_nego.h
+++ b/drivers/target/iscsi/iscsi_target_nego.h
@@ -3,6 +3,9 @@
 
 #define DECIMAL         0
 #define HEX             1
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+#define BASE64          2
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 
 extern void convert_null_to_semi(char *, int);
 extern int extract_param(const char *, const char *, unsigned int, char *,
diff --git a/drivers/ts6k/Kconfig b/drivers/ts6k/Kconfig
new file mode 100644
index 00000000..32d93e7
--- /dev/null
+++ b/drivers/ts6k/Kconfig
@@ -0,0 +1,28 @@
+#
+# TS6000 support configuration
+#
+menu "TS6000 Drivers Support"
+
+config TS6000
+	tristate "TS6000 Drivers Support"
+	help
+	  This is a special driver for Baffulo's TS6000 project.
+
+if TS6000
+
+config TS6000_CMOS_DRIVER
+	tristate "TS6000 CMOS read/write support"
+	help
+	  This is a special driver to read/write below CMOS data for Baffulo 
+	  TS6000 project.
+	  
+	  - AC Power Loss  :  /dev/bios_laststate
+	  - Wake On LAN    :  /dev/bios_wol
+
+	  To compile this driver as a module, choose M here: the module
+	  will be called ts6k_cmos_dev.ko.
+
+endif    # TS6000
+
+endmenu
+
diff --git a/drivers/ts6k/Makefile b/drivers/ts6k/Makefile
new file mode 100644
index 00000000..4ed1048
--- /dev/null
+++ b/drivers/ts6k/Makefile
@@ -0,0 +1,7 @@
+#
+# Makefile for the TS6000 drivers.
+#
+
+obj-$(CONFIG_TS6000_CMOS_DRIVER) += ts6k-cmos-dev.o
+
+
diff --git a/drivers/ts6k/ts6k-cmos-dev.c b/drivers/ts6k/ts6k-cmos-dev.c
new file mode 100644
index 00000000..971a7b4
--- /dev/null
+++ b/drivers/ts6k/ts6k-cmos-dev.c
@@ -0,0 +1,301 @@
+#include <linux/init.h>
+#include <linux/kernel.h>
+#include <linux/module.h>
+#include <linux/io.h>
+#include <linux/errno.h>
+#include <linux/ioport.h>
+#include <linux/slab.h>
+#include <linux/gpio.h>
+#include <linux/irq.h>
+#include <linux/interrupt.h>
+#include <linux/device.h>
+#include <linux/cdev.h>
+#include <linux/fs.h>
+#include <linux/sched.h>
+#include <linux/mutex.h>
+#include <linux/miscdevice.h>
+#include <linux/platform_device.h>
+#include <linux/rwsem.h>
+
+
+#define DRV_NAME "ts6k-cmos-dev"
+
+#define DEBUG
+
+
+struct TS6K_CMOS_DATA_T {
+	u8  reg70h_wake_on_lan;
+	u8  reg71h_last_state;
+	u8  reg75h_gbe_lan_boot;
+};
+
+static struct TS6K_CMOS_DATA_T  s_cmos_data = { 0 };
+
+DECLARE_RWSEM(sem);
+
+static int read_cmos_data( struct TS6K_CMOS_DATA_T  *pData)
+{
+	int k, try_cnt;
+	u8 ret = 0;
+
+	if( pData == 0 )	return -1;
+
+	for( ret = 0, try_cnt=0; (try_cnt<3) && (0x40 != ret) ; try_cnt++ )
+	{
+		printk("clear CMOS offset 73h ... \n");
+		outb( 0x73, 0x70 );
+		outb( 0x00, 0x71 );
+
+		outb( 0x76, 0xB2 );
+	
+		for ( k=0 ; ( k<10 ) && ( 0x40!=ret ) ; k++ )
+		{
+			//usleep(1000);
+			outb( 0x73, 0x70 );	
+			ret = inb(0x71);
+		}
+	}
+	if( 0x40 != ret ) {	return -2;	}
+
+	outb( 0x70, 0x70 );	pData->reg70h_wake_on_lan   = inb(0x71);
+	outb( 0x71, 0x70 );	pData->reg71h_last_state    = inb(0x71);
+	outb( 0x75, 0x70 );	pData->reg75h_gbe_lan_boot  = inb(0x71);
+
+	return 0;
+}
+
+static int write_cmos_data( const struct TS6K_CMOS_DATA_T  *pData)
+{
+	int k, try_cnt;
+	u8 chksum, ret = 0;
+
+	if( pData == 0 )	return -1;
+
+	chksum = 0xBF - ( pData->reg70h_wake_on_lan 
+			+ 2 * pData->reg71h_last_state 
+			+ 6 * pData->reg75h_gbe_lan_boot);
+	printk(" %s : check sum   = %02X \n", __FUNCTION__, chksum );
+
+	for( ret = 0, try_cnt=0; (try_cnt<3) && (0x40 != ret) ; try_cnt++ )
+	{
+		outb( 0x70, 0x70 );	outb( pData->reg70h_wake_on_lan  , 0x71);
+		outb( 0x71, 0x70 );	outb( pData->reg71h_last_state   , 0x71);
+		outb( 0x75, 0x70 );	outb( pData->reg75h_gbe_lan_boot , 0x71);
+		outb( 0x73, 0x70 );	outb( chksum, 0x71 );
+
+		outb( 0x77, 0xB2 );
+	
+		for ( k=0 ; ( k<10 ) && ( 0x40!=ret ) ; k++ )
+		{
+			//usleep(1000);
+			outb( 0x73, 0x70 );	
+			ret = inb(0x71);
+		}
+	}
+	if( 0x40 != ret ) {	return -2;	}
+	
+	return 0;
+}
+
+static ssize_t bios_laststate_read(struct file *filp, char __user *buffer, size_t count, loff_t *offset)
+{
+	u8 v[2];
+	u64 pos = *offset;
+
+	if( read_cmos_data( &s_cmos_data ) ) {
+		printk(" Error! ts6k_cmos_dev : failed to read data from CMOS.\n");
+		return -1;
+	}
+	if( 0 == pos )
+	{
+		down_read(&sem);
+		switch ( s_cmos_data.reg71h_last_state ) {
+			case 0:		v[0] = '1';		break;
+			case 1:		v[0] = '0';		break;
+			case 2:		v[0] = '2';		break;
+			default :   v[0] = 'E';		break;
+		}
+		v[1] = '\n';
+
+		if( ! copy_to_user(buffer, v, 2) )
+		{
+			*offset = 2;
+		} else {
+			return -1;
+		}
+		up_read(&sem);
+		return 2;
+	}
+	return 0;
+}
+
+
+static ssize_t bios_laststate_write(struct file *filp, const char __user *buffer, size_t count,loff_t *offset)
+{
+	u8  c, v;
+	u64 pos = *offset;
+
+	if( read_cmos_data( &s_cmos_data ) ) {
+		printk(" Error! ts6k_cmos_dev : failed to read data from CMOS.\n");
+		return -1;
+	}
+	if( 0 == pos )
+	{
+		down_write(&sem);
+		if (copy_from_user(&c ,buffer, 1)) {
+			return -EFAULT;
+		}
+
+#ifdef DEBUG
+		printk("%s, will set reg71h_last_state to %c\n",__func__, c );
+#endif
+		*offset = ++pos;
+		v = c - '0';
+		switch( v )
+		{
+		case 0:
+		case 1:
+			v = !v;
+		case 2:
+			s_cmos_data.reg71h_last_state = v;
+			write_cmos_data( &s_cmos_data );
+			break;
+		default:
+#ifdef DEBUG
+			printk("%s, set reg71h_last_state to %c, invalid value, ignored \n",__func__, v);
+#endif	
+			break;
+		}
+		up_write(&sem);
+	}
+	return count;
+}
+
+static const struct file_operations bios_laststate_fops = {
+	.owner = THIS_MODULE,
+	.read  = bios_laststate_read,
+	.write = bios_laststate_write,
+};
+
+static ssize_t bios_wol_read(struct file *filp, char __user *buffer, size_t count, loff_t *offset)
+{
+	u8 v[2];
+	u64 pos = *offset;
+
+	if( read_cmos_data( &s_cmos_data ) ) {
+		printk(" Error! ts6k_cmos_dev : failed to read data from CMOS.\n");
+		return -1;
+	}
+	if( 0 == pos )
+	{
+		down_read(&sem);
+		v[0] = '0' + !!s_cmos_data.reg70h_wake_on_lan;
+		v[1] = '\n';
+
+		if( ! copy_to_user(buffer, v, 2) )
+		{
+			*offset = 2;
+		} else {
+			return -1;
+		}
+		up_read(&sem);
+		return 2;
+	}
+	return 0;
+}
+
+
+static ssize_t bios_wol_write(struct file *filp, const char __user *buffer, size_t count,loff_t *offset)
+{
+	u8  v;
+	u64 pos = *offset;
+
+	if( read_cmos_data( &s_cmos_data ) ) {
+		printk(" Error! ts6k_cmos_dev : failed to read data from CMOS.\n");
+		return -1;
+	}
+	if( 0 == pos )
+	{
+		down_write(&sem);
+		if (copy_from_user(&v ,buffer, 1)) {
+			return -EFAULT;
+		}
+
+		*offset = ++pos;
+#ifdef DEBUG
+		printk("%s, v=0x%02X\n",__func__, v);
+#endif	
+		switch( v )
+		{
+		case '0':
+		case '1':
+			s_cmos_data.reg70h_wake_on_lan = v - '0';
+			write_cmos_data( &s_cmos_data );
+			break;
+		default:
+			break;
+		}
+		up_write(&sem);
+	}
+	return count;
+}
+
+static const struct file_operations bios_wol_fops = {
+	.owner = THIS_MODULE,
+	.read  = bios_wol_read,
+	.write = bios_wol_write,
+};
+
+
+static struct miscdevice ts6k_cmos_dev_dev_arr[] = {
+	{
+	.minor = MISC_DYNAMIC_MINOR,
+	.name  = "bios_laststate",
+	.fops  = &bios_laststate_fops,
+	},
+	{
+	.minor = MISC_DYNAMIC_MINOR,
+	.name  = "bios_wol",
+	.fops  = &bios_wol_fops,
+	},
+};
+
+
+static int __init ts6k_cmos_dev_init(void)
+{
+	int error, idx;
+
+	
+	if( 0 && read_cmos_data( &s_cmos_data ) ) {
+		printk(" Error! ts6k_cmos_dev : failed to read data from CMOS.\n");
+		return -1;
+	}
+	for (idx=0 ; idx < ARRAY_SIZE(ts6k_cmos_dev_dev_arr) ; idx++ ) {
+		error = misc_register(ts6k_cmos_dev_dev_arr+idx);
+		if( error ) {
+			for( ; idx >= 0 ; idx-- ) {
+				misc_deregister(ts6k_cmos_dev_dev_arr+idx);
+			}
+		}
+	}
+	printk(" ts6k_cmos_dev loaded, error=%d\n", error);
+
+	return error;
+}
+
+static void __exit ts6k_cmos_dev_exit(void)
+{
+	int idx;
+
+	printk(" ts6k_cmos_dev unloaded\n");
+	for (idx=0 ; idx < ARRAY_SIZE(ts6k_cmos_dev_dev_arr) ; idx++ ) {
+		misc_deregister(ts6k_cmos_dev_dev_arr+idx);
+	}
+}
+
+module_init(ts6k_cmos_dev_init);
+module_exit(ts6k_cmos_dev_exit);
+
+MODULE_DESCRIPTION("support I/F to edit CMOS settings for ac power loss, wake on lan, gbe lan boot ");
+MODULE_AUTHOR("tony_liu@usiglobal.com");
+MODULE_LICENSE("GPL");
diff --git a/drivers/tty/serial/8250/8250_pnp.c b/drivers/tty/serial/8250/8250_pnp.c
index 658b392..06e9e61 100644
--- a/drivers/tty/serial/8250/8250_pnp.c
+++ b/drivers/tty/serial/8250/8250_pnp.c
@@ -434,6 +434,15 @@ static int serial_pnp_guess_board(struct pnp_dev *dev)
 	return -ENODEV;
 }
 
+#ifdef CONFIG_BUFFALO_DISCONIRQ
+static bool __read_mostly conirq_disabled = false;
+static int __init conirq_disabled_setup(char *str)
+{
+	conirq_disabled = true;
+	return 1;
+}
+__setup("disconirq", conirq_disabled_setup);
+#endif /* CONFIG_BUFFALO_DISCONIRQ */
 static int
 serial_pnp_probe(struct pnp_dev *dev, const struct pnp_device_id *dev_id)
 {
@@ -449,6 +458,13 @@ serial_pnp_probe(struct pnp_dev *dev, const struct pnp_device_id *dev_id)
 	memset(&uart, 0, sizeof(uart));
 	if (pnp_irq_valid(dev, 0))
 		uart.port.irq = pnp_irq(dev, 0);
+#ifdef CONFIG_BUFFALO_DISCONIRQ
+	if (conirq_disabled && uart.port.irq == 11) {
+		pr_info("%s: overwrite to port.irq from %d to 0\n",
+			__func__, uart.port.irq);
+		uart.port.irq = 0;
+	}
+#endif /* CONFIG_BUFFALO_DISCONIRQ */
 	if ((flags & CIR_PORT) && pnp_port_valid(dev, 2)) {
 		uart.port.iobase = pnp_port_start(dev, 2);
 		uart.port.iotype = UPIO_PORT;
diff --git a/drivers/usb/host/ehci-pci.c b/drivers/usb/host/ehci-pci.c
index 2a5d2fd..ccd0a4d 100644
--- a/drivers/usb/host/ehci-pci.c
+++ b/drivers/usb/host/ehci-pci.c
@@ -106,6 +106,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 
 	ehci->caps = hcd->regs;
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (hcd->self.controller->bus == &pci_bus_type) {
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 	/*
 	 * ehci_init() causes memory for DMA transfers to be
 	 * allocated.  Thus, any vendor-specific workarounds based on
@@ -230,6 +233,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 		ehci->frame_index_bug = 1;
 		break;
 	}
+#ifdef CONFIG_BUFFALO_PLATFORM
+	}
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 
 	/* optional debug port, normally in the first BAR */
 	temp = pci_find_capability(pdev, PCI_CAP_ID_DBG);
@@ -255,6 +261,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 	if (retval)
 		return retval;
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (hcd->self.controller->bus == &pci_bus_type) {
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 	/* These workarounds need to be applied after ehci_setup() */
 	switch (pdev->vendor) {
 	case PCI_VENDOR_ID_NEC:
@@ -278,6 +287,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 		}
 		break;
 	}
+#ifdef CONFIG_BUFFALO_PLATFORM
+	}
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 
 	/* at least the Genesys GL880S needs fixup here */
 	temp = HCS_N_CC(ehci->hcs_params) * HCS_N_PCC(ehci->hcs_params);
@@ -289,6 +301,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 			HCS_N_PCC(ehci->hcs_params),
 			HCS_N_PORTS(ehci->hcs_params));
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+		if (hcd->self.controller->bus == &pci_bus_type) {
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 		switch (pdev->vendor) {
 		case 0x17a0:		/* GENESYS */
 			/* GL880S: should be PORTS=2 */
@@ -299,8 +314,14 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 			/* NF4: should be PCC=10 */
 			break;
 		}
+#ifdef CONFIG_BUFFALO_PLATFORM
+		}
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 	}
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (hcd->self.controller->bus == &pci_bus_type) {
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 	/* Serial Bus Release Number is at PCI 0x60 offset */
 	if (pdev->vendor == PCI_VENDOR_ID_STMICRO
 	    && pdev->device == PCI_DEVICE_ID_STMICRO_USB_HOST)
@@ -329,6 +350,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 #endif
 
 	retval = ehci_pci_reinit(ehci, pdev);
+#ifdef CONFIG_BUFFALO_PLATFORM
+	}
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 done:
 	return retval;
 }
diff --git a/drivers/usb/storage/scsiglue.c b/drivers/usb/storage/scsiglue.c
index dba5136..721c3c7 100644
--- a/drivers/usb/storage/scsiglue.c
+++ b/drivers/usb/storage/scsiglue.c
@@ -449,6 +449,29 @@ void usb_stor_report_bus_reset(struct us_data *us)
 /***********************************************************************
  * /proc/scsi/ functions
  ***********************************************************************/
+#ifdef CONFIG_BUFFALO_SCSI_GUID
+#define GUID(x)			__u32 x[3]
+#define GUID_EQUAL(x, y)	(x[0] == y[0] && x[1] == y[1] && x[2] == y[2])
+#define GUID_CLEAR(x)		x[0] = x[1] = x[2] = 0;
+#define GUID_NONE(x)		(!x[0] && !x[1] && !x[2])
+#define GUID_FORMAT		"%08x%08x%08x"
+#define GUID_ARGS(x)		x[0], x[1], x[2]
+static inline void
+make_guid( __u32 *pg, __u16 vendor, __u16 product, char *serial)
+{
+	pg[0] = (vendor << 16) | product;
+	pg[1] = pg[2] = 0;
+	while (*serial) {
+		pg[1] <<= 4;
+		pg[1] |= pg[2] >> 28;
+		pg[2] <<= 4;
+		if (*serial >= 'a')
+			*serial -= 'a' - 'A';
+		pg[2] |= (*serial <= '9' && *serial >= '0') ? *serial - '0' : *serial - 'A' + 10;
+		serial++;
+	}
+}
+#endif	/* CONFIG_BUFFALO_SCSI_GUID */
 
 static int write_info(struct Scsi_Host *host, char *buffer, int length)
 {
@@ -489,6 +512,34 @@ static int show_info (struct seq_file *m, struct Scsi_Host *host)
 	seq_printf(m, "     Protocol: %s\n", us->protocol_name);
 	seq_printf(m, "    Transport: %s\n", us->transport_name);
 
+#ifdef CONFIG_BUFFALO_SCSI_GUID
+	{
+		char serial[USB_STOR_STRING_LEN];       /* serial number */
+
+		GUID(guid);                     /* Global Unique Identifier */
+		GUID_CLEAR(guid);
+		memset(serial,0,sizeof(serial));
+
+		if (us->pusb_dev->descriptor.iSerialNumber /* && !(flags & US_FL_IGNORE_SER)*/)
+			usb_string(us->pusb_dev,
+				   us->pusb_dev->descriptor.iSerialNumber,
+				   serial, sizeof(serial));
+
+		/* Create a GUID for this device */
+		if (us->pusb_dev->descriptor.iSerialNumber && serial[0]) {
+			/* If we have a serial number, and it's a non-NULL string */
+			make_guid(guid, us->pusb_dev->descriptor.idVendor,
+				  us->pusb_dev->descriptor.idProduct, serial);
+		} else {
+			/* We don't have a serial number, so we use 0 */
+			make_guid(guid, us->pusb_dev->descriptor.idVendor,
+				  us->pusb_dev->descriptor.idProduct, "0");
+		}
+		/* show the GUID of the device */
+		seq_printf(m, "         GUID: " GUID_FORMAT "\n", GUID_ARGS(guid));
+	}
+#endif	/* CONFIG_BUFFALO_SCSI_GUID */
+
 	/* show the device flags */
 	seq_printf(m, "       Quirks:");
 
diff --git a/fs/btrfs/Kconfig b/fs/btrfs/Kconfig
index 80e9c18..32b05e4 100644
--- a/fs/btrfs/Kconfig
+++ b/fs/btrfs/Kconfig
@@ -89,3 +89,55 @@ config BTRFS_ASSERT
 	  any of the assertions trip.  This is meant for btrfs developers only.
 
 	  If unsure, say N.
+
+config BUFFALO_BTRFS_DROP_UNNECESSARY_QRECORD
+	bool "Enable to apply Buffalo.Inc Btrfs patch"
+	depends on BTRFS_FS
+	help
+		During recaluculation of qgroup, btrfs-transaction is blocked. (= cause of soft-lockup)
+		When snapshot is dropped, too many qgroup dirty extents (qrecords) are queued.
+		And the recalculation of these qrecords causes soft-lockup.
+		Since BUFFALO F/W does not use exclusive size,
+		This means that snapshot drops will not affect other quotas.
+		Therefore, qrecord of the snapshot can be dropped.
+
+		If unsure, say N.
+
+config BUFFALO_BTRFS_DISABLE_QGROUP_EXCLUSIVE_SIZE
+	bool "Enable to apply Buffalo.Inc Btrfs patch"
+	depends on BTRFS_FS
+	help
+		During recaluculation of qgroup, btrfs-transaction is blocked. (= cause of soft-lockup)
+		Buffalo F/W does not use exclusive size for quota.
+		To reduce qgroup calculation time, disable qgroup exclusive-size feature.
+
+		If unsure, say N.
+
+config BUFFALO_BTRFS_REMOVE_UNUSED_QGROUP
+	bool "Enable to apply Synology.Inc Btrfs patch"
+	depends on BTRFS_FS
+	help
+		Enable to apply Synology.Inc Btrfs patch.
+
+		If unsure, say N.
+
+config BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+	bool "Enable to apply Synology.Inc Btrfs patch"
+	depends on BTRFS_FS
+	help
+		Enable to apply Synology.Inc Btrfs patch.
+
+		If unsure, say N.
+
+config BUFFALO_BTRFS_QRECORD_THRESHOLD
+	bool "Enable to apply Buffalo's Btrfs patch"
+	depends on BTRFS_FS
+	help
+	  Enable to apply Buffalo's Btrfs patch.
+	  If there are many references in the extent (= there are many snapshots),
+	  a soft lockup will occur when dropping an extent. (= delete files, delete snapshots, etc...).
+	  To avoid long-term soft lockup,
+	  Countup the number of qgroup dirty extents
+	  and limit the number of qgroup dirty extents that can be processed with 1 transaction.
+
+	  If unsure, say N.
diff --git a/fs/btrfs/Makefile b/fs/btrfs/Makefile
index 6d1d0b9..96746c1 100644
--- a/fs/btrfs/Makefile
+++ b/fs/btrfs/Makefile
@@ -17,3 +17,10 @@ btrfs-$(CONFIG_BTRFS_FS_CHECK_INTEGRITY) += check-integrity.o
 btrfs-$(CONFIG_BTRFS_FS_RUN_SANITY_TESTS) += tests/free-space-tests.o \
 	tests/extent-buffer-tests.o tests/btrfs-tests.o \
 	tests/extent-io-tests.o tests/inode-tests.o tests/qgroup-tests.o
+
+ccflags-$(CONFIG_BUFFALO_BTRFS_DROP_UNNECESSARY_QRECORD) += -DBUFFALO_BTRFS_DROP_UNNECESSARY_QRECORD
+ccflags-$(CONFIG_BUFFALO_BTRFS_DISABLE_QGROUP_EXCLUSIVE_SIZE) += -DBUFFALO_BTRFS_DISABLE_QGROUP_EXCLUSIVE_SIZE
+ccflags-$(CONFIG_BUFFALO_BTRFS_QRECORD_THRESHOLD) += -DBUFFALO_BTRFS_QRECORD_THRESHOLD
+
+ccflags-$(CONFIG_BUFFALO_BTRFS_REMOVE_UNUSED_QGROUP) += -DBUFFALO_BTRFS_REMOVE_UNUSED_QGROUP
+ccflags-$(CONFIG_BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD) += -DBUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
diff --git a/fs/btrfs/backref.c b/fs/btrfs/backref.c
index e2f659d..b842c4c 100644
--- a/fs/btrfs/backref.c
+++ b/fs/btrfs/backref.c
@@ -17,6 +17,7 @@
  */
 
 #include <linux/vmalloc.h>
+#include <linux/rbtree.h>
 #include "ctree.h"
 #include "disk-io.h"
 #include "backref.h"
@@ -34,6 +35,265 @@ struct extent_inode_elem {
 	struct extent_inode_elem *next;
 };
 
+/*
+ * ref_root is used as the root of the ref tree that hold a collection
+ * of unique references.
+ */
+struct ref_root {
+	struct rb_root rb_root;
+
+	/*
+	 * The unique_refs represents the number of ref_nodes with a positive
+	 * count stored in the tree. Even if a ref_node (the count is greater
+	 * than one) is added, the unique_refs will only increase by one.
+	 */
+	unsigned int unique_refs;
+};
+
+/* ref_node is used to store a unique reference to the ref tree. */
+struct ref_node {
+	struct rb_node rb_node;
+
+	/* For NORMAL_REF, otherwise all these fields should be set to 0 */
+	u64 root_id;
+	u64 object_id;
+	u64 offset;
+
+	/* For SHARED_REF, otherwise parent field should be set to 0 */
+	u64 parent;
+
+	/* Ref to the ref_mod of btrfs_delayed_ref_node */
+	int ref_mod;
+};
+
+/* Dynamically allocate and initialize a ref_root */
+static struct ref_root *ref_root_alloc(void)
+{
+	struct ref_root *ref_tree;
+
+	ref_tree = kmalloc(sizeof(*ref_tree), GFP_NOFS);
+	if (!ref_tree)
+		return NULL;
+
+	ref_tree->rb_root = RB_ROOT;
+	ref_tree->unique_refs = 0;
+
+	return ref_tree;
+}
+
+/* Free all nodes in the ref tree, and reinit ref_root */
+static void ref_root_fini(struct ref_root *ref_tree)
+{
+	struct ref_node *node;
+	struct rb_node *next;
+
+	while ((next = rb_first(&ref_tree->rb_root)) != NULL) {
+		node = rb_entry(next, struct ref_node, rb_node);
+		rb_erase(next, &ref_tree->rb_root);
+		kfree(node);
+	}
+
+	ref_tree->rb_root = RB_ROOT;
+	ref_tree->unique_refs = 0;
+}
+
+static void ref_root_free(struct ref_root *ref_tree)
+{
+	if (!ref_tree)
+		return;
+
+	ref_root_fini(ref_tree);
+	kfree(ref_tree);
+}
+
+/*
+ * Compare ref_node with (root_id, object_id, offset, parent)
+ *
+ * The function compares two ref_node a and b. It returns an integer less
+ * than, equal to, or greater than zero , respectively, to be less than, to
+ * equal, or be greater than b.
+ */
+static int ref_node_cmp(struct ref_node *a, struct ref_node *b)
+{
+	if (a->root_id < b->root_id)
+		return -1;
+	else if (a->root_id > b->root_id)
+		return 1;
+
+	if (a->object_id < b->object_id)
+		return -1;
+	else if (a->object_id > b->object_id)
+		return 1;
+
+	if (a->offset < b->offset)
+		return -1;
+	else if (a->offset > b->offset)
+		return 1;
+
+	if (a->parent < b->parent)
+		return -1;
+	else if (a->parent > b->parent)
+		return 1;
+
+	return 0;
+}
+
+/*
+ * Search ref_node with (root_id, object_id, offset, parent) in the tree
+ *
+ * if found, the pointer of the ref_node will be returned;
+ * if not found, NULL will be returned and pos will point to the rb_node for
+ * insert, pos_parent will point to pos'parent for insert;
+*/
+static struct ref_node *__ref_tree_search(struct ref_root *ref_tree,
+					  struct rb_node ***pos,
+					  struct rb_node **pos_parent,
+					  u64 root_id, u64 object_id,
+					  u64 offset, u64 parent)
+{
+	struct ref_node *cur = NULL;
+	struct ref_node entry;
+	int ret;
+
+	entry.root_id = root_id;
+	entry.object_id = object_id;
+	entry.offset = offset;
+	entry.parent = parent;
+
+	*pos = &ref_tree->rb_root.rb_node;
+
+	while (**pos) {
+		*pos_parent = **pos;
+		cur = rb_entry(*pos_parent, struct ref_node, rb_node);
+
+		ret = ref_node_cmp(cur, &entry);
+		if (ret > 0)
+			*pos = &(**pos)->rb_left;
+		else if (ret < 0)
+			*pos = &(**pos)->rb_right;
+		else
+			return cur;
+	}
+
+	return NULL;
+}
+
+/*
+ * Insert a ref_node to the ref tree
+ * @pos used for specifiy the position to insert
+ * @pos_parent for specifiy pos's parent
+ *
+ * success, return 0;
+ * ref_node already exists, return -EEXIST;
+*/
+static int ref_tree_insert(struct ref_root *ref_tree, struct rb_node **pos,
+			   struct rb_node *pos_parent, struct ref_node *ins)
+{
+	struct rb_node **p = NULL;
+	struct rb_node *parent = NULL;
+	struct ref_node *cur = NULL;
+
+	if (!pos) {
+		cur = __ref_tree_search(ref_tree, &p, &parent, ins->root_id,
+					ins->object_id, ins->offset,
+					ins->parent);
+		if (cur)
+			return -EEXIST;
+	} else {
+		p = pos;
+		parent = pos_parent;
+	}
+
+	rb_link_node(&ins->rb_node, parent, p);
+	rb_insert_color(&ins->rb_node, &ref_tree->rb_root);
+
+	return 0;
+}
+
+/* Erase and free ref_node, caller should update ref_root->unique_refs */
+static void ref_tree_remove(struct ref_root *ref_tree, struct ref_node *node)
+{
+	rb_erase(&node->rb_node, &ref_tree->rb_root);
+	kfree(node);
+}
+
+/*
+ * Update ref_root->unique_refs
+ *
+ * Call __ref_tree_search
+ *	1. if ref_node doesn't exist, ref_tree_insert this node, and update
+ *	ref_root->unique_refs:
+ *		if ref_node->ref_mod > 0, ref_root->unique_refs++;
+ *		if ref_node->ref_mod < 0, do noting;
+ *
+ *	2. if ref_node is found, then get origin ref_node->ref_mod, and update
+ *	ref_node->ref_mod.
+ *		if ref_node->ref_mod is equal to 0,then call ref_tree_remove
+ *
+ *		according to origin_mod and new_mod, update ref_root->items
+ *		+----------------+--------------+-------------+
+ *		|		 |new_count <= 0|new_count > 0|
+ *		+----------------+--------------+-------------+
+ *		|origin_count < 0|       0      |      1      |
+ *		+----------------+--------------+-------------+
+ *		|origin_count > 0|      -1      |      0      |
+ *		+----------------+--------------+-------------+
+ *
+ * In case of allocation failure, -ENOMEM is returned and the ref_tree stays
+ * unaltered.
+ * Success, return 0
+ */
+static int ref_tree_add(struct ref_root *ref_tree, u64 root_id, u64 object_id,
+			u64 offset, u64 parent, int count)
+{
+	struct ref_node *node = NULL;
+	struct rb_node **pos = NULL;
+	struct rb_node *pos_parent = NULL;
+	int origin_count;
+	int ret;
+
+	if (!count)
+		return 0;
+
+	node = __ref_tree_search(ref_tree, &pos, &pos_parent, root_id,
+				 object_id, offset, parent);
+	if (node == NULL) {
+		node = kmalloc(sizeof(*node), GFP_NOFS);
+		if (!node)
+			return -ENOMEM;
+
+		node->root_id = root_id;
+		node->object_id = object_id;
+		node->offset = offset;
+		node->parent = parent;
+		node->ref_mod = count;
+
+		ret = ref_tree_insert(ref_tree, pos, pos_parent, node);
+		ASSERT(!ret);
+		if (ret) {
+			kfree(node);
+			return ret;
+		}
+
+		ref_tree->unique_refs += node->ref_mod > 0 ? 1 : 0;
+
+		return 0;
+	}
+
+	origin_count = node->ref_mod;
+	node->ref_mod += count;
+
+	if (node->ref_mod > 0)
+		ref_tree->unique_refs += origin_count > 0 ? 0 : 1;
+	else if (node->ref_mod <= 0)
+		ref_tree->unique_refs += origin_count > 0 ? -1 : 0;
+
+	if (!node->ref_mod)
+		ref_tree_remove(ref_tree, node);
+
+	return 0;
+}
+
 static int check_extent_in_eb(struct btrfs_key *key, struct extent_buffer *eb,
 				struct btrfs_file_extent_item *fi,
 				u64 extent_item_pos,
@@ -604,6 +864,7 @@ static void __merge_refs(struct list_head *head, int mode)
 
 			list_del(&ref2->list);
 			kmem_cache_free(btrfs_prelim_ref_cache, ref2);
+			cond_resched();
 		}
 
 	}
@@ -714,6 +975,7 @@ static int __add_delayed_refs(struct btrfs_delayed_ref_head *head, u64 seq,
 static int __add_inline_refs(struct btrfs_fs_info *fs_info,
 			     struct btrfs_path *path, u64 bytenr,
 			     int *info_level, struct list_head *prefs,
+			     struct ref_root *ref_tree,
 			     u64 *total_refs, u64 inum)
 {
 	int ret = 0;
@@ -781,6 +1043,13 @@ static int __add_inline_refs(struct btrfs_fs_info *fs_info,
 			count = btrfs_shared_data_ref_count(leaf, sdref);
 			ret = __add_prelim_ref(prefs, 0, NULL, 0, offset,
 					       bytenr, count, GFP_NOFS);
+			if (ref_tree) {
+				if (!ret)
+					ret = ref_tree_add(ref_tree, 0, 0, 0,
+							   bytenr, count);
+				if (!ret && ref_tree->unique_refs > 1)
+					ret = BACKREF_FOUND_SHARED;
+			}
 			break;
 		}
 		case BTRFS_TREE_BLOCK_REF_KEY:
@@ -808,6 +1077,15 @@ static int __add_inline_refs(struct btrfs_fs_info *fs_info,
 			root = btrfs_extent_data_ref_root(leaf, dref);
 			ret = __add_prelim_ref(prefs, root, &key, 0, 0,
 					       bytenr, count, GFP_NOFS);
+			if (ref_tree) {
+				if (!ret)
+					ret = ref_tree_add(ref_tree, root,
+							   key.objectid,
+							   key.offset, 0,
+							   count);
+				if (!ret && ref_tree->unique_refs > 1)
+					ret = BACKREF_FOUND_SHARED;
+			}
 			break;
 		}
 		default:
@@ -826,7 +1104,8 @@ static int __add_inline_refs(struct btrfs_fs_info *fs_info,
  */
 static int __add_keyed_refs(struct btrfs_fs_info *fs_info,
 			    struct btrfs_path *path, u64 bytenr,
-			    int info_level, struct list_head *prefs, u64 inum)
+			    int info_level, struct list_head *prefs,
+			    struct ref_root *ref_tree, u64 inum)
 {
 	struct btrfs_root *extent_root = fs_info->extent_root;
 	int ret;
@@ -869,6 +1148,13 @@ static int __add_keyed_refs(struct btrfs_fs_info *fs_info,
 			count = btrfs_shared_data_ref_count(leaf, sdref);
 			ret = __add_prelim_ref(prefs, 0, NULL, 0, key.offset,
 						bytenr, count, GFP_NOFS);
+			if (ref_tree) {
+				if (!ret)
+					ret = ref_tree_add(ref_tree, 0, 0, 0,
+							   bytenr, count);
+				if (!ret && ref_tree->unique_refs > 1)
+					ret = BACKREF_FOUND_SHARED;
+			}
 			break;
 		}
 		case BTRFS_TREE_BLOCK_REF_KEY:
@@ -897,6 +1183,15 @@ static int __add_keyed_refs(struct btrfs_fs_info *fs_info,
 			root = btrfs_extent_data_ref_root(leaf, dref);
 			ret = __add_prelim_ref(prefs, root, &key, 0, 0,
 					       bytenr, count, GFP_NOFS);
+			if (ref_tree) {
+				if (!ret)
+					ret = ref_tree_add(ref_tree, root,
+							   key.objectid,
+							   key.offset, 0,
+							   count);
+				if (!ret && ref_tree->unique_refs > 1)
+					ret = BACKREF_FOUND_SHARED;
+			}
 			break;
 		}
 		default:
@@ -923,13 +1218,16 @@ static int __add_keyed_refs(struct btrfs_fs_info *fs_info,
  * commit root.
  * The special case is for qgroup to search roots in commit_transaction().
  *
+ * If check_shared is set to 1, any extent has more than one ref item, will
+ * be returned BACKREF_FOUND_SHARED immediately.
+ *
  * FIXME some caching might speed things up
  */
 static int find_parent_nodes(struct btrfs_trans_handle *trans,
 			     struct btrfs_fs_info *fs_info, u64 bytenr,
 			     u64 time_seq, struct ulist *refs,
 			     struct ulist *roots, const u64 *extent_item_pos,
-			     u64 root_objectid, u64 inum)
+			     u64 root_objectid, u64 inum, int check_shared)
 {
 	struct btrfs_key key;
 	struct btrfs_path *path;
@@ -941,6 +1239,7 @@ static int find_parent_nodes(struct btrfs_trans_handle *trans,
 	struct list_head prefs;
 	struct __prelim_ref *ref;
 	struct extent_inode_elem *eie = NULL;
+	struct ref_root *ref_tree = NULL;
 	u64 total_refs = 0;
 
 	INIT_LIST_HEAD(&prefs);
@@ -972,6 +1271,18 @@ static int find_parent_nodes(struct btrfs_trans_handle *trans,
 again:
 	head = NULL;
 
+	if (check_shared) {
+		if (!ref_tree) {
+			ref_tree = ref_root_alloc();
+			if (!ref_tree) {
+				ret = -ENOMEM;
+				goto out;
+			}
+		} else {
+			ref_root_fini(ref_tree);
+		}
+	}
+
 	ret = btrfs_search_slot(trans, fs_info->extent_root, &key, path, 0, 0);
 	if (ret < 0)
 		goto out;
@@ -1016,6 +1327,36 @@ again:
 		} else {
 			spin_unlock(&delayed_refs->lock);
 		}
+
+		if (check_shared && !list_empty(&prefs_delayed)) {
+			/*
+			 * Add all delay_ref to the ref_tree and check if there
+			 * are multiple ref items added.
+			 */
+			list_for_each_entry(ref, &prefs_delayed, list) {
+				if (ref->key_for_search.type) {
+					ret = ref_tree_add(ref_tree,
+						ref->root_id,
+						ref->key_for_search.objectid,
+						ref->key_for_search.offset,
+						0, ref->count);
+					if (ret)
+						goto out;
+				} else {
+					ret = ref_tree_add(ref_tree, 0, 0, 0,
+						     ref->parent, ref->count);
+					if (ret)
+						goto out;
+				}
+
+			}
+
+			if (ref_tree->unique_refs > 1) {
+				ret = BACKREF_FOUND_SHARED;
+				goto out;
+			}
+
+		}
 	}
 
 	if (path->slots[0]) {
@@ -1031,11 +1372,13 @@ again:
 		     key.type == BTRFS_METADATA_ITEM_KEY)) {
 			ret = __add_inline_refs(fs_info, path, bytenr,
 						&info_level, &prefs,
-						&total_refs, inum);
+						ref_tree, &total_refs,
+						inum);
 			if (ret)
 				goto out;
 			ret = __add_keyed_refs(fs_info, path, bytenr,
-					       info_level, &prefs, inum);
+					       info_level, &prefs,
+					       ref_tree, inum);
 			if (ret)
 				goto out;
 		}
@@ -1120,6 +1463,7 @@ again:
 
 out:
 	btrfs_free_path(path);
+	ref_root_free(ref_tree);
 	while (!list_empty(&prefs)) {
 		ref = list_first_entry(&prefs, struct __prelim_ref, list);
 		list_del(&ref->list);
@@ -1173,8 +1517,8 @@ static int btrfs_find_all_leafs(struct btrfs_trans_handle *trans,
 	if (!*leafs)
 		return -ENOMEM;
 
-	ret = find_parent_nodes(trans, fs_info, bytenr,
-				time_seq, *leafs, NULL, extent_item_pos, 0, 0);
+	ret = find_parent_nodes(trans, fs_info, bytenr, time_seq,
+				*leafs, NULL, extent_item_pos, 0, 0, 0);
 	if (ret < 0 && ret != -ENOENT) {
 		free_leaf_list(*leafs);
 		return ret;
@@ -1216,8 +1560,8 @@ static int __btrfs_find_all_roots(struct btrfs_trans_handle *trans,
 
 	ULIST_ITER_INIT(&uiter);
 	while (1) {
-		ret = find_parent_nodes(trans, fs_info, bytenr,
-					time_seq, tmp, *roots, NULL, 0, 0);
+		ret = find_parent_nodes(trans, fs_info, bytenr, time_seq,
+					tmp, *roots, NULL, 0, 0, 0);
 		if (ret < 0 && ret != -ENOENT) {
 			ulist_free(tmp);
 			ulist_free(*roots);
@@ -1287,7 +1631,7 @@ int btrfs_check_shared(struct btrfs_trans_handle *trans,
 	ULIST_ITER_INIT(&uiter);
 	while (1) {
 		ret = find_parent_nodes(trans, fs_info, bytenr, elem.seq, tmp,
-					roots, NULL, root_objectid, inum);
+					roots, NULL, root_objectid, inum, 1);
 		if (ret == BACKREF_FOUND_SHARED) {
 			/* this is the only condition under which we return 1 */
 			ret = 1;
diff --git a/fs/btrfs/ctree.h b/fs/btrfs/ctree.h
index e847573..30b5498 100644
--- a/fs/btrfs/ctree.h
+++ b/fs/btrfs/ctree.h
@@ -1733,6 +1733,15 @@ struct btrfs_fs_info {
 	 */
 	unsigned int quota_enabled:1;
 
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+	int ordered_extent_nr;
+	int delalloc_inodes_nr;
+	int flushoncommit_threshold;
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+	int qrecord_threshold;
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
+
 	/*
 	 * quota_enabled only changes state after a commit. This holds the
 	 * next state.
diff --git a/fs/btrfs/delayed-ref.c b/fs/btrfs/delayed-ref.c
index e06dd75..e1918c1 100644
--- a/fs/btrfs/delayed-ref.c
+++ b/fs/btrfs/delayed-ref.c
@@ -189,6 +189,8 @@ static inline void drop_delayed_ref(struct btrfs_trans_handle *trans,
 	} else {
 		assert_spin_locked(&head->lock);
 		list_del(&ref->list);
+		if (!list_empty(&ref->add_list))
+			list_del(&ref->add_list);
 	}
 	ref->in_tree = 0;
 	btrfs_put_delayed_ref(ref);
@@ -430,6 +432,15 @@ add_delayed_ref_tail_merge(struct btrfs_trans_handle *trans,
 			exist->action = ref->action;
 			mod = -exist->ref_mod;
 			exist->ref_mod = ref->ref_mod;
+			if (ref->action == BTRFS_ADD_DELAYED_REF)
+				list_add_tail(&exist->add_list,
+					      &href->ref_add_list);
+			else if (ref->action == BTRFS_DROP_DELAYED_REF) {
+				ASSERT(!list_empty(&exist->add_list));
+				list_del(&exist->add_list);
+			} else {
+				ASSERT(0);
+			}
 		} else
 			mod = -ref->ref_mod;
 	}
@@ -443,6 +454,8 @@ add_delayed_ref_tail_merge(struct btrfs_trans_handle *trans,
 
 add_tail:
 	list_add_tail(&ref->list, &href->ref_list);
+	if (ref->action == BTRFS_ADD_DELAYED_REF)
+		list_add_tail(&ref->add_list, &href->ref_add_list);
 	atomic_inc(&root->num_entries);
 	trans->delayed_ref_updates++;
 	spin_unlock(&href->lock);
@@ -590,6 +603,7 @@ add_delayed_ref_head(struct btrfs_fs_info *fs_info,
 	head_ref->must_insert_reserved = must_insert_reserved;
 	head_ref->is_data = is_data;
 	INIT_LIST_HEAD(&head_ref->ref_list);
+	INIT_LIST_HEAD(&head_ref->ref_add_list);
 	head_ref->processing = 0;
 	head_ref->total_ref_mod = count_mod;
 	head_ref->qgroup_reserved = 0;
@@ -672,6 +686,8 @@ add_delayed_tree_ref(struct btrfs_fs_info *fs_info,
 	ref->is_head = 0;
 	ref->in_tree = 1;
 	ref->seq = seq;
+	INIT_LIST_HEAD(&ref->list);
+	INIT_LIST_HEAD(&ref->add_list);
 
 	full_ref = btrfs_delayed_node_to_tree_ref(ref);
 	full_ref->parent = parent;
@@ -727,6 +743,8 @@ add_delayed_data_ref(struct btrfs_fs_info *fs_info,
 	ref->is_head = 0;
 	ref->in_tree = 1;
 	ref->seq = seq;
+	INIT_LIST_HEAD(&ref->list);
+	INIT_LIST_HEAD(&ref->add_list);
 
 	full_ref = btrfs_delayed_node_to_data_ref(ref);
 	full_ref->parent = parent;
diff --git a/fs/btrfs/delayed-ref.h b/fs/btrfs/delayed-ref.h
index 00ed02c..c45c5b5 100644
--- a/fs/btrfs/delayed-ref.h
+++ b/fs/btrfs/delayed-ref.h
@@ -42,6 +42,12 @@ struct btrfs_delayed_ref_node {
 
 	/*data/tree ref use list, stored in ref_head->ref_list. */
 	struct list_head list;
+	/*
+	 * If action is BTRFS_ADD_DELAYED_REF, also link this node to
+	 * ref_head->ref_add_list, then we do not need to iterate the
+	 * whole ref_head->ref_list to find BTRFS_ADD_DELAYED_REF nodes.
+	 */
+	struct list_head add_list;
 
 	/* the starting bytenr of the extent */
 	u64 bytenr;
@@ -99,6 +105,8 @@ struct btrfs_delayed_ref_head {
 
 	spinlock_t lock;
 	struct list_head ref_list;
+	/* accumulate add BTRFS_ADD_DELAYED_REF nodes to this ref_add_list. */
+	struct list_head ref_add_list;
 
 	struct rb_node href_node;
 
@@ -161,6 +169,11 @@ struct btrfs_delayed_ref_root {
 	/* dirty extent records */
 	struct rb_root dirty_extent_root;
 
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+	/* how many qrecords we've queued, used by the throttling code */
+	atomic_t num_qrecords;
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
+
 	/* this spin lock protects the rbtree and the entries inside */
 	spinlock_t lock;
 
diff --git a/fs/btrfs/disk-io.c b/fs/btrfs/disk-io.c
index 85b207d..cc301eb 100644
--- a/fs/btrfs/disk-io.c
+++ b/fs/btrfs/disk-io.c
@@ -2647,6 +2647,19 @@ int open_ctree(struct super_block *sb,
 	sema_init(&fs_info->uuid_tree_rescan_sem, 1);
 
 	btrfs_init_dev_replace_locks(fs_info);
+
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+	fs_info->ordered_extent_nr = 0;
+	fs_info->delalloc_inodes_nr = 0;
+	if (totalram_pages > ((2ULL*1024*1024*1024)/PAGE_SIZE))
+		fs_info->flushoncommit_threshold = 0;
+	else
+		fs_info->flushoncommit_threshold = 1000;
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+	fs_info->qrecord_threshold = 0;
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
+
 	btrfs_init_qgroup(fs_info);
 
 	btrfs_init_free_cluster(&fs_info->meta_alloc_cluster);
@@ -4214,6 +4227,8 @@ static int btrfs_destroy_delayed_refs(struct btrfs_transaction *trans,
 						 list) {
 			ref->in_tree = 0;
 			list_del(&ref->list);
+			if (!list_empty(&ref->add_list))
+				list_del(&ref->add_list);
 			atomic_dec(&delayed_refs->num_entries);
 			btrfs_put_delayed_ref(ref);
 		}
diff --git a/fs/btrfs/extent-tree.c b/fs/btrfs/extent-tree.c
index 260f94b..e4a0676 100644
--- a/fs/btrfs/extent-tree.c
+++ b/fs/btrfs/extent-tree.c
@@ -2437,13 +2437,14 @@ select_delayed_ref(struct btrfs_delayed_ref_head *head)
 	 * the extent item from the extent tree, when there still are references
 	 * to add, which would fail because they would not find the extent item.
 	 */
-	list_for_each_entry(ref, &head->ref_list, list) {
-		if (ref->action == BTRFS_ADD_DELAYED_REF)
-			return ref;
-	}
+	if (!list_empty(&head->ref_add_list))
+		return list_first_entry(&head->ref_add_list,
+				struct btrfs_delayed_ref_node, add_list);
 
-	return list_entry(head->ref_list.next, struct btrfs_delayed_ref_node,
-			  list);
+	ref = list_first_entry(&head->ref_list, struct btrfs_delayed_ref_node,
+			       list);
+	ASSERT(list_empty(&ref->add_list));
+	return ref;
 }
 
 /*
@@ -2604,6 +2605,8 @@ static noinline int __btrfs_run_delayed_refs(struct btrfs_trans_handle *trans,
 			actual_count++;
 			ref->in_tree = 0;
 			list_del(&ref->list);
+			if (!list_empty(&ref->add_list))
+				list_del(&ref->add_list);
 		}
 		atomic_dec(&delayed_refs->num_entries);
 
@@ -8125,6 +8128,12 @@ static int record_one_subtree_extent(struct btrfs_trans_handle *trans,
 	struct btrfs_qgroup_extent_record *qrecord;
 	struct btrfs_delayed_ref_root *delayed_refs;
 
+#ifdef BUFFALO_BTRFS_DROP_UNNECESSARY_QRECORD
+	if(btrfs_should_drop_qrecord(root)){
+		return 0;
+	}
+#endif /* BUFFALO_BTRFS_DROP_UNNECESSARY_QRECORD */
+
 	qrecord = kmalloc(sizeof(*qrecord), GFP_NOFS);
 	if (!qrecord)
 		return -ENOMEM;
@@ -8813,6 +8822,10 @@ int btrfs_drop_snapshot(struct btrfs_root *root,
 	int ret;
 	int level;
 	bool root_dropped = false;
+#ifdef BUFFALO_BTRFS_REMOVE_UNUSED_QGROUP
+	struct btrfs_fs_info *fs_info = root->fs_info;
+	u64 qgroupid = root->root_key.objectid;
+#endif /* BUFFALO_BTRFS_REMOVE_UNUSED_QGROUP */
 
 	btrfs_debug(root->fs_info, "Drop subvolume %llu", root->objectid);
 
@@ -8961,6 +8974,23 @@ int btrfs_drop_snapshot(struct btrfs_root *root,
 	if (err)
 		goto out_end_trans;
 
+#ifdef BUFFALO_BTRFS_REMOVE_UNUSED_QGROUP
+	if (fs_info->quota_enabled && !for_reloc) {
+		ret = btrfs_remove_qgroup(trans, fs_info, qgroupid);
+		if (0 != ret) {
+			if (-ENOENT == ret) {
+				btrfs_err(fs_info, "cannot find qgroup item, qgroupid=%llu !\n", qgroupid);
+			} else if (-EBUSY == ret) {
+				btrfs_err(fs_info, "cannot remove qgroup item, it relates to other qgroup, qgroupid=%llu !\n", qgroupid);
+			} else {
+				btrfs_abort_transaction(trans, tree_root, ret);
+				err = ret;
+				goto out_end_trans;
+			}
+		}
+	}
+#endif /* BUFFALO_BTRFS_REMOVE_UNUSED_QGROUP */
+
 	ret = btrfs_del_root(trans, tree_root, &root->root_key);
 	if (ret) {
 		btrfs_abort_transaction(trans, tree_root, ret);
diff --git a/fs/btrfs/extent_io.c b/fs/btrfs/extent_io.c
index e767f34..866f63f 100644
--- a/fs/btrfs/extent_io.c
+++ b/fs/btrfs/extent_io.c
@@ -20,6 +20,7 @@
 #include "locking.h"
 #include "rcu-string.h"
 #include "backref.h"
+#include "transaction.h"
 
 static struct kmem_cache *extent_state_cache;
 static struct kmem_cache *extent_buffer_cache;
@@ -4587,21 +4588,36 @@ int extent_fiemap(struct inode *inode, struct fiemap_extent_info *fieinfo,
 			flags |= (FIEMAP_EXTENT_DELALLOC |
 				  FIEMAP_EXTENT_UNKNOWN);
 		} else if (fieinfo->fi_extents_max) {
+			struct btrfs_trans_handle *trans;
+
 			u64 bytenr = em->block_start -
 				(em->start - em->orig_start);
 
 			disko = em->block_start + offset_in_extent;
 
 			/*
+			 * We need a trans handle to get delayed refs
+			 */
+			trans = btrfs_join_transaction(root);
+			/*
+			 * It's OK if we can't start a trans we can still check
+			 * from commit_root
+			 */
+			if (IS_ERR(trans))
+				trans = NULL;
+
+			/*
 			 * As btrfs supports shared space, this information
 			 * can be exported to userspace tools via
 			 * flag FIEMAP_EXTENT_SHARED.  If fi_extents_max == 0
 			 * then we're just getting a count and we can skip the
 			 * lookup stuff.
 			 */
-			ret = btrfs_check_shared(NULL, root->fs_info,
+			ret = btrfs_check_shared(trans, root->fs_info,
 						 root->objectid,
 						 btrfs_ino(inode), bytenr);
+			if (trans)
+				btrfs_end_transaction(trans, root);
 			if (ret < 0)
 				goto out_free;
 			if (ret)
diff --git a/fs/btrfs/inode.c b/fs/btrfs/inode.c
index af1da85..26544a7 100644
--- a/fs/btrfs/inode.c
+++ b/fs/btrfs/inode.c
@@ -1658,6 +1658,9 @@ static void btrfs_add_delalloc_inodes(struct btrfs_root *root,
 		set_bit(BTRFS_INODE_IN_DELALLOC_LIST,
 			&BTRFS_I(inode)->runtime_flags);
 		root->nr_delalloc_inodes++;
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+		root->fs_info->delalloc_inodes_nr++;
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
 		if (root->nr_delalloc_inodes == 1) {
 			spin_lock(&root->fs_info->delalloc_root_lock);
 			BUG_ON(!list_empty(&root->delalloc_root));
@@ -1678,6 +1681,9 @@ static void btrfs_del_delalloc_inode(struct btrfs_root *root,
 		clear_bit(BTRFS_INODE_IN_DELALLOC_LIST,
 			  &BTRFS_I(inode)->runtime_flags);
 		root->nr_delalloc_inodes--;
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+		root->fs_info->delalloc_inodes_nr--;
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
 		if (!root->nr_delalloc_inodes) {
 			spin_lock(&root->fs_info->delalloc_root_lock);
 			BUG_ON(list_empty(&root->delalloc_root));
@@ -4079,7 +4085,16 @@ static int btrfs_unlink(struct inode *dir, struct dentry *dentry)
 	}
 
 out:
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+	if(btrfs_should_throttle_qrecords(trans, root)) {
+		pr_debug("btrfs_unlink (%llu): throttle qrecords. Commit transaction.\n", trans->transid);
+		btrfs_commit_transaction(trans, root);
+	} else {
+		btrfs_end_transaction(trans, root);
+	}
+#else
 	btrfs_end_transaction(trans, root);
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
 	btrfs_btree_balance_dirty(root);
 	return ret;
 }
@@ -5306,7 +5321,16 @@ void btrfs_evict_inode(struct inode *inode)
 	      root->root_key.objectid == BTRFS_TREE_RELOC_OBJECTID))
 		btrfs_return_ino(root, btrfs_ino(inode));
 
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+	if(btrfs_should_throttle_qrecords(trans, root)) {
+		pr_debug("btrfs_evict_inode (%llu): throttle qrecords. Commit transaction.\n", trans->transid);
+		btrfs_commit_transaction(trans, root);
+	} else {
+		btrfs_end_transaction(trans, root);
+	}
+#else
 	btrfs_end_transaction(trans, root);
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
 	btrfs_btree_balance_dirty(root);
 no_delete:
 	btrfs_remove_delayed_node(inode);
diff --git a/fs/btrfs/ioctl.c b/fs/btrfs/ioctl.c
index 9c3b9d0..62ad0da 100644
--- a/fs/btrfs/ioctl.c
+++ b/fs/btrfs/ioctl.c
@@ -2098,8 +2098,6 @@ static noinline int search_ioctl(struct inode *inode,
 		key.offset = (u64)-1;
 		root = btrfs_read_fs_root_no_name(info, &key);
 		if (IS_ERR(root)) {
-			btrfs_err(info, "could not find root %llu",
-			       sk->tree_id);
 			btrfs_free_path(path);
 			return -ENOENT;
 		}
diff --git a/fs/btrfs/ordered-data.c b/fs/btrfs/ordered-data.c
index 8c27292..c5653db 100644
--- a/fs/btrfs/ordered-data.c
+++ b/fs/btrfs/ordered-data.c
@@ -231,6 +231,9 @@ static int __btrfs_add_ordered_extent(struct inode *inode, u64 file_offset,
 	spin_lock(&root->ordered_extent_lock);
 	list_add_tail(&entry->root_extent_list,
 		      &root->ordered_extents);
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+	root->fs_info->ordered_extent_nr++;
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
 	root->nr_ordered_extents++;
 	if (root->nr_ordered_extents == 1) {
 		spin_lock(&root->fs_info->ordered_root_lock);
@@ -633,6 +636,9 @@ void btrfs_remove_ordered_extent(struct inode *inode,
 
 	spin_lock(&root->ordered_extent_lock);
 	list_del_init(&entry->root_extent_list);
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+	root->fs_info->ordered_extent_nr--;
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
 	root->nr_ordered_extents--;
 
 	trace_btrfs_ordered_extent_remove(inode, entry);
diff --git a/fs/btrfs/qgroup.c b/fs/btrfs/qgroup.c
index 88d9b66..939b570 100644
--- a/fs/btrfs/qgroup.c
+++ b/fs/btrfs/qgroup.c
@@ -1422,36 +1422,15 @@ out:
 	return ret;
 }
 
-int btrfs_qgroup_prepare_account_extents(struct btrfs_trans_handle *trans,
-					 struct btrfs_fs_info *fs_info)
+#ifdef BUFFALO_BTRFS_DROP_UNNECESSARY_QRECORD
+bool btrfs_should_drop_qrecord(struct btrfs_root *root)
 {
-	struct btrfs_qgroup_extent_record *record;
-	struct btrfs_delayed_ref_root *delayed_refs;
-	struct rb_node *node;
-	u64 qgroup_to_skip;
-	int ret = 0;
-
-	delayed_refs = &trans->transaction->delayed_refs;
-	qgroup_to_skip = delayed_refs->qgroup_to_skip;
-
-	/*
-	 * No need to do lock, since this function will only be called in
-	 * btrfs_commmit_transaction().
-	 */
-	node = rb_first(&delayed_refs->dirty_extent_root);
-	while (node) {
-		record = rb_entry(node, struct btrfs_qgroup_extent_record,
-				  node);
-		ret = btrfs_find_all_roots(NULL, fs_info, record->bytenr, 0,
-					   &record->old_roots);
-		if (ret < 0)
-			break;
-		if (qgroup_to_skip)
-			ulist_del(record->old_roots, qgroup_to_skip, 0);
-		node = rb_next(node);
+	if(btrfs_root_readonly(root)){
+		return true;
 	}
-	return ret;
+	return false;
 }
+#endif /* BUFFALO_BTRFS_DROP_UNNECESSARY_QRECORD */
 
 struct btrfs_qgroup_extent_record
 *btrfs_qgroup_insert_dirty_extent(struct btrfs_delayed_ref_root *delayed_refs,
@@ -1478,6 +1457,9 @@ struct btrfs_qgroup_extent_record
 
 	rb_link_node(&record->node, parent_node, p);
 	rb_insert_color(&record->node, &delayed_refs->dirty_extent_root);
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+	atomic_inc(&delayed_refs->num_qrecords);
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
 	return NULL;
 }
 
@@ -1606,6 +1588,9 @@ static int qgroup_update_counters(struct btrfs_fs_info *fs_info,
 			dirty = true;
 		}
 
+#ifdef BUFFALO_BTRFS_DISABLE_QGROUP_EXCLUSIVE_SIZE
+		//In BUFFALO F/W, exclusive size is not used for quota.
+#else
 		/* Excl update part */
 		/* Exclusive/none -> shared case */
 		if (cur_old_count == nr_old_roots &&
@@ -1654,6 +1639,7 @@ static int qgroup_update_counters(struct btrfs_fs_info *fs_info,
 				/* Exclusive -> exclusive, nothing changed */
 			}
 		}
+#endif /* BUFFALO_BTRFS_DISABLE_QGROUP_EXCLUSIVE_SIZE */
 
 		if (dirty)
 			qgroup_dirty(fs_info, qg);
@@ -1754,6 +1740,17 @@ int btrfs_qgroup_account_extents(struct btrfs_trans_handle *trans,
 
 		if (!ret) {
 			/*
+			 * Old roots should be searched when inserting qgroup
+			 * extent record
+			 */
+			/* Search commit root to find old_roots */
+			ret = btrfs_find_all_roots(NULL, fs_info,
+					record->bytenr, 0,
+					&record->old_roots);
+			if (ret < 0)
+				goto cleanup;
+
+			/*
 			 * Use (u64)-1 as time_seq to do special search, which
 			 * doesn't lock tree or delayed_refs and search current
 			 * root. It's safe inside commit_transaction().
@@ -1762,8 +1759,11 @@ int btrfs_qgroup_account_extents(struct btrfs_trans_handle *trans,
 					record->bytenr, (u64)-1, &new_roots);
 			if (ret < 0)
 				goto cleanup;
-			if (qgroup_to_skip)
+			if (qgroup_to_skip) {
 				ulist_del(new_roots, qgroup_to_skip, 0);
+				ulist_del(record->old_roots, qgroup_to_skip,
+					  0);
+			}
 			ret = btrfs_qgroup_account_extent(trans, fs_info,
 					record->bytenr, record->num_bytes,
 					record->old_roots, new_roots);
@@ -1775,6 +1775,9 @@ cleanup:
 		ulist_free(new_roots);
 		new_roots = NULL;
 		rb_erase(node, &delayed_refs->dirty_extent_root);
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+		atomic_dec(&delayed_refs->num_qrecords);
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
 		kfree(record);
 
 	}
@@ -2693,3 +2696,20 @@ void btrfs_qgroup_check_reserved_leak(struct inode *inode)
 	}
 	ulist_free(changeset.range_changed);
 }
+
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+int btrfs_should_throttle_qrecords(struct btrfs_trans_handle *trans, struct btrfs_root *root)
+{
+	struct btrfs_fs_info *fs_info = root->fs_info;
+	u64 num_qrecords;
+
+	if (!fs_info->quota_enabled)
+		return 0;
+	
+	num_qrecords = atomic_read(&trans->transaction->delayed_refs.num_qrecords);
+	if(fs_info->qrecord_threshold && (num_qrecords >= fs_info->qrecord_threshold)){
+		return 1;
+	}
+	return 0;
+}
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
diff --git a/fs/btrfs/qgroup.h b/fs/btrfs/qgroup.h
index 3d73e4c..15b60e3 100644
--- a/fs/btrfs/qgroup.h
+++ b/fs/btrfs/qgroup.h
@@ -59,11 +59,13 @@ int btrfs_remove_qgroup(struct btrfs_trans_handle *trans,
 int btrfs_limit_qgroup(struct btrfs_trans_handle *trans,
 		       struct btrfs_fs_info *fs_info, u64 qgroupid,
 		       struct btrfs_qgroup_limit *limit);
+#ifdef BUFFALO_BTRFS_DROP_UNNECESSARY_QRECORD
+bool btrfs_should_drop_qrecord(struct btrfs_root *root);
+#endif /* BUFFALO_BTRFS_DROP_UNNECESSARY_QRECORD */
 int btrfs_read_qgroup_config(struct btrfs_fs_info *fs_info);
 void btrfs_free_qgroup_config(struct btrfs_fs_info *fs_info);
 struct btrfs_delayed_extent_op;
-int btrfs_qgroup_prepare_account_extents(struct btrfs_trans_handle *trans,
-					 struct btrfs_fs_info *fs_info);
+
 struct btrfs_qgroup_extent_record
 *btrfs_qgroup_insert_dirty_extent(struct btrfs_delayed_ref_root *delayed_refs,
 				  struct btrfs_qgroup_extent_record *record);
@@ -107,4 +109,9 @@ int btrfs_qgroup_reserve_meta(struct btrfs_root *root, int num_bytes);
 void btrfs_qgroup_free_meta_all(struct btrfs_root *root);
 void btrfs_qgroup_free_meta(struct btrfs_root *root, int num_bytes);
 void btrfs_qgroup_check_reserved_leak(struct inode *inode);
+
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+int btrfs_should_throttle_qrecords(struct btrfs_trans_handle *trans, struct btrfs_root *root);
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
+
 #endif /* __BTRFS_QGROUP__ */
diff --git a/fs/btrfs/super.c b/fs/btrfs/super.c
index 3bd2233..f7b7e85 100644
--- a/fs/btrfs/super.c
+++ b/fs/btrfs/super.c
@@ -303,6 +303,12 @@ enum {
 	Opt_commit_interval, Opt_barrier, Opt_nodefrag, Opt_nodiscard,
 	Opt_noenospc_debug, Opt_noflushoncommit, Opt_acl, Opt_datacow,
 	Opt_datasum, Opt_treelog, Opt_noinode_cache,
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+	Opt_flushoncommit_threshold,
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+	Opt_qrecord_threshold,
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
 #ifdef CONFIG_BTRFS_DEBUG
 	Opt_fragment_data, Opt_fragment_metadata, Opt_fragment_all,
 #endif
@@ -336,6 +342,12 @@ static match_table_t tokens = {
 	{Opt_treelog, "treelog"},
 	{Opt_flushoncommit, "flushoncommit"},
 	{Opt_noflushoncommit, "noflushoncommit"},
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+	{Opt_flushoncommit_threshold, "flushoncommit_threshold=%d"},
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+	{Opt_qrecord_threshold,"qrecord_threshold=%d"},
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
 	{Opt_ratio, "metadata_ratio=%d"},
 	{Opt_discard, "discard"},
 	{Opt_nodiscard, "nodiscard"},
@@ -587,6 +599,32 @@ int btrfs_parse_options(struct btrfs_root *root, char *options)
 			btrfs_clear_and_info(root, NOTREELOG,
 					     "enabling tree log");
 			break;
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+		case Opt_flushoncommit_threshold:
+			ret = match_int(&args[0], &intarg);
+			if (ret) {
+				goto out;
+			} else if (intarg >= 0) {
+				info->flushoncommit_threshold = intarg;
+			} else {
+				ret = -EINVAL;
+				goto out;
+			}
+			break;
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+		case Opt_qrecord_threshold:
+			ret = match_int(&args[0],&intarg);
+			if(ret){
+				goto out;
+			} else if (intarg >= 0){
+				info->qrecord_threshold = intarg;
+			} else {
+				ret = -EINVAL;
+				goto out;
+			}
+			break;
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
 		case Opt_flushoncommit:
 			btrfs_set_and_info(root, FLUSHONCOMMIT,
 					   "turning on flush-on-commit");
@@ -1189,6 +1227,16 @@ static int btrfs_show_options(struct seq_file *seq, struct dentry *dentry)
 		seq_printf(seq, ",check_int_print_mask=%d",
 				info->check_integrity_print_mask);
 #endif
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+	if (info->flushoncommit_threshold)
+		seq_printf(seq, ",flushoncommit_threshold=%d",
+				info->flushoncommit_threshold);
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+	if (info->qrecord_threshold)
+		seq_printf(seq, ",qrecord_threshold=%d",
+				info->qrecord_threshold);
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
 	if (info->metadata_ratio)
 		seq_printf(seq, ",metadata_ratio=%d",
 				info->metadata_ratio);
diff --git a/fs/btrfs/transaction.c b/fs/btrfs/transaction.c
index be8eae8..7b49460 100644
--- a/fs/btrfs/transaction.c
+++ b/fs/btrfs/transaction.c
@@ -247,6 +247,9 @@ loop:
 
 	cur_trans->delayed_refs.href_root = RB_ROOT;
 	cur_trans->delayed_refs.dirty_extent_root = RB_ROOT;
+#ifdef BUFFALO_BTRFS_QRECORD_THRESHOLD
+	atomic_set(&cur_trans->delayed_refs.num_qrecords, 0);
+#endif /* BUFFALO_BTRFS_QRECORD_THRESHOLD */
 	atomic_set(&cur_trans->delayed_refs.num_entries, 0);
 
 	/*
@@ -1539,9 +1542,6 @@ static noinline int create_pending_snapshot(struct btrfs_trans_handle *trans,
 	/*
 	 * account qgroup counters before qgroup_inherit()
 	 */
-	ret = btrfs_qgroup_prepare_account_extents(trans, fs_info);
-	if (ret)
-		goto fail;
 	ret = btrfs_qgroup_account_extents(trans, fs_info);
 	if (ret)
 		goto fail;
@@ -1790,6 +1790,10 @@ static inline int btrfs_start_delalloc_flush(struct btrfs_fs_info *fs_info)
 {
 	if (btrfs_test_opt(fs_info->tree_root, FLUSHONCOMMIT))
 		return btrfs_start_delalloc_roots(fs_info, 1, -1);
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+	else if (fs_info->flushoncommit_threshold && fs_info->delalloc_inodes_nr > fs_info->flushoncommit_threshold)
+		return btrfs_start_delalloc_roots(fs_info, 1, -1);
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
 	return 0;
 }
 
@@ -1797,6 +1801,11 @@ static inline void btrfs_wait_delalloc_flush(struct btrfs_fs_info *fs_info)
 {
 	if (btrfs_test_opt(fs_info->tree_root, FLUSHONCOMMIT))
 		btrfs_wait_ordered_roots(fs_info, -1);
+#ifdef BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD
+	else if (fs_info->flushoncommit_threshold && fs_info->ordered_extent_nr > fs_info->flushoncommit_threshold) {
+		btrfs_wait_ordered_roots(fs_info, -1);
+	}
+#endif /* BUFFALO_BTRFS_FLUSHONCOMMIT_THRESHOLD */
 }
 
 static inline void
@@ -1999,13 +2008,6 @@ int btrfs_commit_transaction(struct btrfs_trans_handle *trans,
 		goto scrub_continue;
 	}
 
-	/* Reocrd old roots for later qgroup accounting */
-	ret = btrfs_qgroup_prepare_account_extents(trans, root->fs_info);
-	if (ret) {
-		mutex_unlock(&root->fs_info->reloc_mutex);
-		goto scrub_continue;
-	}
-
 	/*
 	 * make sure none of the code above managed to slip in a
 	 * delayed item
diff --git a/fs/cifs/asn1.c b/fs/cifs/asn1.c
index a3b5654..ae1f281 100644
--- a/fs/cifs/asn1.c
+++ b/fs/cifs/asn1.c
@@ -541,8 +541,8 @@ decode_negTokenInit(unsigned char *security_blob, int length,
 		return 0;
 	} else if ((cls != ASN1_CTX) || (con != ASN1_CON)
 		   || (tag != ASN1_EOC)) {
-		cifs_dbg(FYI, "cls = %d con = %d tag = %d end = %p (%d) exit 0\n",
-			 cls, con, tag, end, *end);
+		cifs_dbg(FYI, "cls = %d con = %d tag = %d end = %p exit 0\n",
+			 cls, con, tag, end);
 		return 0;
 	}
 
@@ -552,8 +552,8 @@ decode_negTokenInit(unsigned char *security_blob, int length,
 		return 0;
 	} else if ((cls != ASN1_UNI) || (con != ASN1_CON)
 		   || (tag != ASN1_SEQ)) {
-		cifs_dbg(FYI, "cls = %d con = %d tag = %d end = %p (%d) exit 1\n",
-			 cls, con, tag, end, *end);
+		cifs_dbg(FYI, "cls = %d con = %d tag = %d end = %p exit 1\n",
+			 cls, con, tag, end);
 		return 0;
 	}
 
@@ -563,8 +563,8 @@ decode_negTokenInit(unsigned char *security_blob, int length,
 		return 0;
 	} else if ((cls != ASN1_CTX) || (con != ASN1_CON)
 		   || (tag != ASN1_EOC)) {
-		cifs_dbg(FYI, "cls = %d con = %d tag = %d end = %p (%d) exit 0\n",
-			 cls, con, tag, end, *end);
+		cifs_dbg(FYI, "cls = %d con = %d tag = %d end = %p exit 0\n",
+			 cls, con, tag, end);
 		return 0;
 	}
 
@@ -575,8 +575,8 @@ decode_negTokenInit(unsigned char *security_blob, int length,
 		return 0;
 	} else if ((cls != ASN1_UNI) || (con != ASN1_CON)
 		   || (tag != ASN1_SEQ)) {
-		cifs_dbg(FYI, "cls = %d con = %d tag = %d end = %p (%d) exit 1\n",
-			 cls, con, tag, end, *end);
+		cifs_dbg(FYI, "cls = %d con = %d tag = %d sequence_end = %p exit 1\n",
+			 cls, con, tag, sequence_end);
 		return 0;
 	}
 
diff --git a/fs/cifs/cifs_debug.c b/fs/cifs/cifs_debug.c
index 0a3544f..7bc6d27 100644
--- a/fs/cifs/cifs_debug.c
+++ b/fs/cifs/cifs_debug.c
@@ -123,25 +123,41 @@ static int cifs_debug_data_proc_show(struct seq_file *m, void *v)
 	seq_printf(m, "CIFS Version %s\n", CIFS_VERSION);
 	seq_printf(m, "Features:");
 #ifdef CONFIG_CIFS_DFS_UPCALL
-	seq_printf(m, " dfs");
+	seq_printf(m, " DFS");
 #endif
 #ifdef CONFIG_CIFS_FSCACHE
-	seq_printf(m, " fscache");
+	seq_printf(m, ",FSCACHE");
+#endif
+#ifdef CONFIG_CIFS_SMB_DIRECT
+	seq_printf(m, ",SMB_DIRECT");
+#endif
+#ifdef CONFIG_CIFS_STATS2
+	seq_printf(m, ",STATS2");
+#elif defined(CONFIG_CIFS_STATS)
+	seq_printf(m, ",STATS");
+#endif
+#ifdef CONFIG_CIFS_DEBUG2
+	seq_printf(m, ",DEBUG2");
+#elif defined(CONFIG_CIFS_DEBUG)
+	seq_printf(m, ",DEBUG");
+#endif
+#ifdef CONFIG_CIFS_ALLOW_INSECURE_LEGACY
+	seq_printf(m, ",ALLOW_INSECURE_LEGACY");
 #endif
 #ifdef CONFIG_CIFS_WEAK_PW_HASH
-	seq_printf(m, " lanman");
+	seq_printf(m, ",WEAK_PW_HASH");
 #endif
 #ifdef CONFIG_CIFS_POSIX
-	seq_printf(m, " posix");
+	seq_printf(m, ",CIFS_POSIX");
 #endif
 #ifdef CONFIG_CIFS_UPCALL
-	seq_printf(m, " spnego");
+	seq_printf(m, ",UPCALL(SPNEGO)");
 #endif
 #ifdef CONFIG_CIFS_XATTR
-	seq_printf(m, " xattr");
+	seq_printf(m, ",XATTR");
 #endif
 #ifdef CONFIG_CIFS_ACL
-	seq_printf(m, " acl");
+	seq_printf(m, ",ACL");
 #endif
 	seq_putc(m, '\n');
 	seq_printf(m, "Active VFS Requests: %d\n", GlobalTotalActiveXid);
@@ -269,6 +285,13 @@ static ssize_t cifs_stats_proc_write(struct file *file,
 		atomic_set(&totBufAllocCount, 0);
 		atomic_set(&totSmBufAllocCount, 0);
 #endif /* CONFIG_CIFS_STATS2 */
+		atomic_set(&tcpSesReconnectCount, 0);
+		atomic_set(&tconInfoReconnectCount, 0);
+
+		spin_lock(&GlobalMid_Lock);
+		GlobalMaxActiveXid = 0;
+		GlobalCurrentXid = 0;
+		spin_unlock(&GlobalMid_Lock);
 		spin_lock(&cifs_tcp_ses_lock);
 		list_for_each(tmp1, &cifs_tcp_ses_list) {
 			server = list_entry(tmp1, struct TCP_Server_Info,
@@ -281,6 +304,10 @@ static ssize_t cifs_stats_proc_write(struct file *file,
 							  struct cifs_tcon,
 							  tcon_list);
 					atomic_set(&tcon->num_smbs_sent, 0);
+					spin_lock(&tcon->stat_lock);
+					tcon->bytes_read = 0;
+					tcon->bytes_written = 0;
+					spin_unlock(&tcon->stat_lock);
 					if (server->ops->clear_stats)
 						server->ops->clear_stats(tcon);
 				}
diff --git a/fs/cifs/cifs_dfs_ref.c b/fs/cifs/cifs_dfs_ref.c
index 7dc886c..1ea643f 100644
--- a/fs/cifs/cifs_dfs_ref.c
+++ b/fs/cifs/cifs_dfs_ref.c
@@ -266,9 +266,9 @@ static void dump_referral(const struct dfs_info3_param *ref)
 {
 	cifs_dbg(FYI, "DFS: ref path: %s\n", ref->path_name);
 	cifs_dbg(FYI, "DFS: node path: %s\n", ref->node_name);
-	cifs_dbg(FYI, "DFS: fl: %hd, srv_type: %hd\n",
+	cifs_dbg(FYI, "DFS: fl: %d, srv_type: %d\n",
 		 ref->flags, ref->server_type);
-	cifs_dbg(FYI, "DFS: ref_flags: %hd, path_consumed: %hd\n",
+	cifs_dbg(FYI, "DFS: ref_flags: %d, path_consumed: %d\n",
 		 ref->ref_flag, ref->path_consumed);
 }
 
diff --git a/fs/cifs/cifs_spnego.c b/fs/cifs/cifs_spnego.c
index 6908080..e3f2b73 100644
--- a/fs/cifs/cifs_spnego.c
+++ b/fs/cifs/cifs_spnego.c
@@ -143,8 +143,10 @@ cifs_get_spnego_key(struct cifs_ses *sesInfo)
 		sprintf(dp, ";sec=krb5");
 	else if (server->sec_mskerberos)
 		sprintf(dp, ";sec=mskrb5");
-	else
-		goto out;
+	else {
+		cifs_dbg(VFS, "unknown or missing server auth type, use krb5\n");
+		sprintf(dp, ";sec=krb5");
+	}
 
 	dp = description + strlen(description);
 	sprintf(dp, ";uid=0x%x",
diff --git a/fs/cifs/cifs_unicode.c b/fs/cifs/cifs_unicode.c
index a0b3e7d..9428742 100644
--- a/fs/cifs/cifs_unicode.c
+++ b/fs/cifs/cifs_unicode.c
@@ -101,9 +101,6 @@ convert_sfm_char(const __u16 src_char, char *target)
 	case SFM_LESSTHAN:
 		*target = '<';
 		break;
-	case SFM_SLASH:
-		*target = '\\';
-		break;
 	case SFM_SPACE:
 		*target = ' ';
 		break;
@@ -496,7 +493,13 @@ cifsConvertToUTF16(__le16 *target, const char *source, int srclen,
 		else if (map_chars == SFM_MAP_UNI_RSVD) {
 			bool end_of_string;
 
-			if (i == srclen - 1)
+			/**
+			 * Remap spaces and periods found at the end of every
+			 * component of the path. The special cases of '.' and
+			 * '..' do not need to be dealt with explicitly because
+			 * they are addressed in namei.c:link_path_walk().
+			 **/
+			if ((i == srclen - 1) || (source[i+1] == '\\'))
 				end_of_string = true;
 			else
 				end_of_string = false;
diff --git a/fs/cifs/cifsacl.c b/fs/cifs/cifsacl.c
index 3f9312591..f5b87a8 100644
--- a/fs/cifs/cifsacl.c
+++ b/fs/cifs/cifsacl.c
@@ -480,7 +480,7 @@ static void access_flags_to_mode(__le32 ace_flags, int type, umode_t *pmode,
 			((flags & FILE_EXEC_RIGHTS) == FILE_EXEC_RIGHTS))
 		*pmode |= (S_IXUGO & (*pbits_to_set));
 
-	cifs_dbg(NOISY, "access flags 0x%x mode now 0x%x\n", flags, *pmode);
+	cifs_dbg(NOISY, "access flags 0x%x mode now %04o\n", flags, *pmode);
 	return;
 }
 
@@ -509,7 +509,7 @@ static void mode_to_access_flags(umode_t mode, umode_t bits_to_use,
 	if (mode & S_IXUGO)
 		*pace_flags |= SET_FILE_EXEC_RIGHTS;
 
-	cifs_dbg(NOISY, "mode: 0x%x, access flags now 0x%x\n",
+	cifs_dbg(NOISY, "mode: %04o, access flags now 0x%x\n",
 		 mode, *pace_flags);
 	return;
 }
diff --git a/fs/cifs/cifsencrypt.c b/fs/cifs/cifsencrypt.c
index 4acbc39..1d707a6 100644
--- a/fs/cifs/cifsencrypt.c
+++ b/fs/cifs/cifsencrypt.c
@@ -306,9 +306,8 @@ int calc_lanman_hash(const char *password, const char *cryptkey, bool encrypt,
 {
 	int i;
 	int rc;
-	char password_with_pad[CIFS_ENCPWD_SIZE];
+	char password_with_pad[CIFS_ENCPWD_SIZE] = {0};
 
-	memset(password_with_pad, 0, CIFS_ENCPWD_SIZE);
 	if (password)
 		strncpy(password_with_pad, password, CIFS_ENCPWD_SIZE);
 
diff --git a/fs/cifs/cifsfs.c b/fs/cifs/cifsfs.c
index 4f4fc9f..7b6021c 100644
--- a/fs/cifs/cifsfs.c
+++ b/fs/cifs/cifsfs.c
@@ -683,26 +683,22 @@ cifs_do_mount(struct file_system_type *fs_type,
 	cifs_sb->mountdata = kstrndup(data, PAGE_SIZE, GFP_KERNEL);
 	if (cifs_sb->mountdata == NULL) {
 		root = ERR_PTR(-ENOMEM);
-		goto out_cifs_sb;
+		goto out_free;
 	}
 
-	if (volume_info->prepath) {
-		cifs_sb->prepath = kstrdup(volume_info->prepath, GFP_KERNEL);
-		if (cifs_sb->prepath == NULL) {
-			root = ERR_PTR(-ENOMEM);
-			goto out_cifs_sb;
-		}
+	rc = cifs_setup_cifs_sb(volume_info, cifs_sb);
+	if (rc) {
+		root = ERR_PTR(rc);
+		goto out_free;
 	}
 
-	cifs_setup_cifs_sb(volume_info, cifs_sb);
-
 	rc = cifs_mount(cifs_sb, volume_info);
 	if (rc) {
 		if (!(flags & MS_SILENT))
 			cifs_dbg(VFS, "cifs_mount failed w/return code = %d\n",
 				 rc);
 		root = ERR_PTR(rc);
-		goto out_mountdata;
+		goto out_free;
 	}
 
 	mnt_data.vol = volume_info;
@@ -749,9 +745,9 @@ out:
 	cifs_cleanup_volume_info(volume_info);
 	return root;
 
-out_mountdata:
+out_free:
+	kfree(cifs_sb->prepath);
 	kfree(cifs_sb->mountdata);
-out_cifs_sb:
 	kfree(cifs_sb);
 out_nls:
 	unload_nls(volume_info->local_nls);
diff --git a/fs/cifs/cifsglob.h b/fs/cifs/cifsglob.h
index 8225de3..6b61d4a 100644
--- a/fs/cifs/cifsglob.h
+++ b/fs/cifs/cifsglob.h
@@ -1152,6 +1152,11 @@ void cifsFileInfo_put(struct cifsFileInfo *cifs_file);
 struct cifsInodeInfo {
 	bool can_cache_brlcks;
 	struct list_head llist;	/* locks helb by this inode */
+	/*
+	 * NOTE: Some code paths call down_read(lock_sem) twice, so
+	 * we must always use use cifs_down_write() instead of down_write()
+	 * for this semaphore to avoid deadlocks.
+	 */
 	struct rw_semaphore lock_sem;	/* protect the fields above */
 	/* BB add in lists for dirty pages i.e. write caching info for oplock */
 	struct list_head openFileList;
diff --git a/fs/cifs/cifsproto.h b/fs/cifs/cifsproto.h
index 54590fd..2107b25 100644
--- a/fs/cifs/cifsproto.h
+++ b/fs/cifs/cifsproto.h
@@ -138,6 +138,7 @@ extern int cifs_unlock_range(struct cifsFileInfo *cfile,
 			     struct file_lock *flock, const unsigned int xid);
 extern int cifs_push_mandatory_locks(struct cifsFileInfo *cfile);
 
+extern void cifs_down_write(struct rw_semaphore *sem);
 extern struct cifsFileInfo *cifs_new_fileinfo(struct cifs_fid *fid,
 					      struct file *file,
 					      struct tcon_link *tlink,
@@ -185,7 +186,7 @@ extern int cifs_read_from_socket(struct TCP_Server_Info *server, char *buf,
 extern int cifs_readv_from_socket(struct TCP_Server_Info *server,
 		struct kvec *iov_orig, unsigned int nr_segs,
 		unsigned int to_read);
-extern void cifs_setup_cifs_sb(struct smb_vol *pvolume_info,
+extern int cifs_setup_cifs_sb(struct smb_vol *pvolume_info,
 			       struct cifs_sb_info *cifs_sb);
 extern int cifs_match_super(struct super_block *, void *);
 extern void cifs_cleanup_volume_info(struct smb_vol *pvolume_info);
diff --git a/fs/cifs/cifssmb.c b/fs/cifs/cifssmb.c
index 0c92af1..fa07f7c 100644
--- a/fs/cifs/cifssmb.c
+++ b/fs/cifs/cifssmb.c
@@ -150,8 +150,14 @@ cifs_reconnect_tcon(struct cifs_tcon *tcon, int smb_command)
 	 * greater than cifs socket timeout which is 7 seconds
 	 */
 	while (server->tcpStatus == CifsNeedReconnect) {
-		wait_event_interruptible_timeout(server->response_q,
-			(server->tcpStatus != CifsNeedReconnect), 10 * HZ);
+		rc = wait_event_interruptible_timeout(server->response_q,
+						      (server->tcpStatus != CifsNeedReconnect),
+						      10 * HZ);
+		if (rc < 0) {
+			cifs_dbg(FYI, "%s: aborting reconnect due to a received"
+				 " signal by the process\n", __func__);
+			return -ERESTARTSYS;
+		}
 
 		/* are we still trying to reconnect? */
 		if (server->tcpStatus != CifsNeedReconnect)
@@ -178,6 +184,18 @@ cifs_reconnect_tcon(struct cifs_tcon *tcon, int smb_command)
 	 * reconnect the same SMB session
 	 */
 	mutex_lock(&ses->session_mutex);
+
+	/*
+	 * Recheck after acquire mutex. If another thread is negotiating
+	 * and the server never sends an answer the socket will be closed
+	 * and tcpStatus set to reconnect.
+	 */
+	if (server->tcpStatus == CifsNeedReconnect) {
+		rc = -EHOSTDOWN;
+		mutex_unlock(&ses->session_mutex);
+		goto out;
+	}
+
 	rc = cifs_negotiate_protocol(0, ses);
 	if (rc == 0 && ses->need_reconnect)
 		rc = cifs_setup_session(0, ses, nls_codepage);
@@ -571,10 +589,15 @@ CIFSSMBNegotiate(const unsigned int xid, struct cifs_ses *ses)
 	}
 
 	count = 0;
+	/*
+	 * We know that all the name entries in the protocols array
+	 * are short (< 16 bytes anyway) and are NUL terminated.
+	 */
 	for (i = 0; i < CIFS_NUM_PROT; i++) {
-		strncpy(pSMB->DialectsArray+count, protocols[i].name, 16);
-		count += strlen(protocols[i].name) + 1;
-		/* null at end of source and target buffers anyway */
+		size_t len = strlen(protocols[i].name) + 1;
+
+		memcpy(pSMB->DialectsArray+count, protocols[i].name, len);
+		count += len;
 	}
 	inc_rfc1001_len(pSMB, count);
 	pSMB->ByteCount = cpu_to_le16(count);
@@ -6421,9 +6444,7 @@ SetEARetry:
 	pSMB->InformationLevel =
 		cpu_to_le16(SMB_SET_FILE_EA);
 
-	parm_data =
-		(struct fealist *) (((char *) &pSMB->hdr.Protocol) +
-				       offset);
+	parm_data = (void *)pSMB + offsetof(struct smb_hdr, Protocol) + offset;
 	pSMB->ParameterOffset = cpu_to_le16(param_offset);
 	pSMB->DataOffset = cpu_to_le16(offset);
 	pSMB->SetupCount = 1;
diff --git a/fs/cifs/connect.c b/fs/cifs/connect.c
index 0a2bf94..1d47ea8 100644
--- a/fs/cifs/connect.c
+++ b/fs/cifs/connect.c
@@ -48,6 +48,7 @@
 #include "cifs_unicode.h"
 #include "cifs_debug.h"
 #include "cifs_fs_sb.h"
+#include "dns_resolve.h"
 #include "ntlmssp.h"
 #include "nterr.h"
 #include "rfc1002pdu.h"
@@ -304,6 +305,55 @@ static int cifs_setup_volume_info(struct smb_vol *volume_info, char *mount_data,
 					const char *devname);
 
 /*
+ * Resolve hostname and set ip addr in tcp ses. Useful for hostnames that may
+ * get their ip addresses changed at some point.
+ *
+ * This should be called with server->srv_mutex held.
+ */
+#ifdef CONFIG_CIFS_DFS_UPCALL
+static int reconn_set_ipaddr(struct TCP_Server_Info *server)
+{
+	int rc;
+	int len;
+	char *unc, *ipaddr = NULL;
+
+	if (!server->hostname)
+		return -EINVAL;
+
+	len = strlen(server->hostname) + 3;
+
+	unc = kmalloc(len, GFP_KERNEL);
+	if (!unc) {
+		cifs_dbg(FYI, "%s: failed to create UNC path\n", __func__);
+		return -ENOMEM;
+	}
+	snprintf(unc, len, "\\\\%s", server->hostname);
+
+	rc = dns_resolve_server_name_to_ip(unc, &ipaddr);
+	kfree(unc);
+
+	if (rc < 0) {
+		cifs_dbg(FYI, "%s: failed to resolve server part of %s to IP: %d\n",
+			 __func__, server->hostname, rc);
+		return rc;
+	}
+
+	spin_lock(&cifs_tcp_ses_lock);
+	rc = cifs_convert_address((struct sockaddr *)&server->dstaddr, ipaddr,
+				  strlen(ipaddr));
+	spin_unlock(&cifs_tcp_ses_lock);
+	kfree(ipaddr);
+
+	return !rc ? -1 : 0;
+}
+#else
+static inline int reconn_set_ipaddr(struct TCP_Server_Info *server)
+{
+	return 0;
+}
+#endif
+
+/*
  * cifs tcp session reconnection
  *
  * mark tcp session as reconnecting so temporarily locked
@@ -400,6 +450,11 @@ cifs_reconnect(struct TCP_Server_Info *server)
 		rc = generic_ip_connect(server);
 		if (rc) {
 			cifs_dbg(FYI, "reconnect error %d\n", rc);
+			rc = reconn_set_ipaddr(server);
+			if (rc) {
+				cifs_dbg(FYI, "%s: failed to resolve hostname: %d\n",
+					 __func__, rc);
+			}
 			mutex_unlock(&server->srv_mutex);
 			msleep(3000);
 		} else {
@@ -493,20 +548,21 @@ static bool
 server_unresponsive(struct TCP_Server_Info *server)
 {
 	/*
-	 * We need to wait 2 echo intervals to make sure we handle such
+	 * We need to wait 3 echo intervals to make sure we handle such
 	 * situations right:
 	 * 1s  client sends a normal SMB request
-	 * 2s  client gets a response
+	 * 3s  client gets a response
 	 * 30s echo workqueue job pops, and decides we got a response recently
 	 *     and don't need to send another
 	 * ...
 	 * 65s kernel_recvmsg times out, and we see that we haven't gotten
 	 *     a response in >60s.
 	 */
-	if (server->tcpStatus == CifsGood &&
-	    time_after(jiffies, server->lstrp + 2 * SMB_ECHO_INTERVAL)) {
+	if ((server->tcpStatus == CifsGood ||
+	    server->tcpStatus == CifsNeedNegotiate) &&
+	    time_after(jiffies, server->lstrp + 3 * SMB_ECHO_INTERVAL)) {
 		cifs_dbg(VFS, "Server %s has not responded in %d seconds. Reconnecting...\n",
-			 server->hostname, (2 * SMB_ECHO_INTERVAL) / HZ);
+			 server->hostname, (3 * SMB_ECHO_INTERVAL) / HZ);
 		cifs_reconnect(server);
 		wake_up(&server->response_q);
 		return true;
@@ -727,6 +783,8 @@ static void clean_demultiplex_info(struct TCP_Server_Info *server)
 	list_del_init(&server->tcp_ses_list);
 	spin_unlock(&cifs_tcp_ses_lock);
 
+	cancel_delayed_work_sync(&server->echo);
+
 	spin_lock(&GlobalMid_Lock);
 	server->tcpStatus = CifsExiting;
 	spin_unlock(&GlobalMid_Lock);
@@ -886,6 +944,7 @@ cifs_demultiplex_thread(void *p)
 		mempool_resize(cifs_req_poolp, length + cifs_min_rcv);
 
 	set_freezable();
+	allow_signal(SIGKILL);
 	while (server->tcpStatus != CifsExiting) {
 		if (try_to_freeze())
 			continue;
@@ -1202,6 +1261,11 @@ cifs_parse_devname(const char *devname, struct smb_vol *vol)
 	const char *delims = "/\\";
 	size_t len;
 
+	if (unlikely(!devname || !*devname)) {
+		cifs_dbg(VFS, "Device name not specified.\n");
+		return -EINVAL;
+	}
+
 	/* make sure we have a valid UNC double delimiter prefix */
 	len = strspn(devname, delims);
 	if (len != 2)
@@ -1695,7 +1759,7 @@ cifs_parse_mount_options(const char *mountdata, const char *devname,
 			tmp_end++;
 			if (!(tmp_end < end && tmp_end[1] == delim)) {
 				/* No it is not. Set the password to NULL */
-				kfree(vol->password);
+				kzfree(vol->password);
 				vol->password = NULL;
 				break;
 			}
@@ -1733,7 +1797,7 @@ cifs_parse_mount_options(const char *mountdata, const char *devname,
 					options = end;
 			}
 
-			kfree(vol->password);
+			kzfree(vol->password);
 			/* Now build new password string */
 			temp_len = strlen(value);
 			vol->password = kzalloc(temp_len+1, GFP_KERNEL);
@@ -2188,7 +2252,7 @@ cifs_put_tcp_session(struct TCP_Server_Info *server, int from_reconnect)
 
 	task = xchg(&server->tsk, NULL);
 	if (task)
-		force_sig(SIGKILL, task);
+		send_sig(SIGKILL, task, 1);
 }
 
 static struct TCP_Server_Info *
@@ -2408,6 +2472,7 @@ static int
 cifs_set_cifscreds(struct smb_vol *vol, struct cifs_ses *ses)
 {
 	int rc = 0;
+	int is_domain = 0;
 	const char *delim, *payload;
 	char *desc;
 	ssize_t len;
@@ -2455,6 +2520,7 @@ cifs_set_cifscreds(struct smb_vol *vol, struct cifs_ses *ses)
 			rc = PTR_ERR(key);
 			goto out_err;
 		}
+		is_domain = 1;
 	}
 
 	down_read(&key->sem);
@@ -2512,6 +2578,26 @@ cifs_set_cifscreds(struct smb_vol *vol, struct cifs_ses *ses)
 		goto out_key_put;
 	}
 
+	/*
+	 * If we have a domain key then we must set the domainName in the
+	 * for the request.
+	 */
+	if (is_domain && ses->domainName) {
+		vol->domainname = kstrndup(ses->domainName,
+					   strlen(ses->domainName),
+					   GFP_KERNEL);
+		if (!vol->domainname) {
+			cifs_dbg(FYI, "Unable to allocate %zd bytes for "
+				 "domain\n", len);
+			rc = -ENOMEM;
+			kfree(vol->username);
+			vol->username = NULL;
+			kzfree(vol->password);
+			vol->password = NULL;
+			goto out_key_put;
+		}
+	}
+
 out_key_put:
 	up_read(&key->sem);
 	key_put(key);
@@ -3302,7 +3388,7 @@ void reset_cifs_unix_caps(unsigned int xid, struct cifs_tcon *tcon,
 	}
 }
 
-void cifs_setup_cifs_sb(struct smb_vol *pvolume_info,
+int cifs_setup_cifs_sb(struct smb_vol *pvolume_info,
 			struct cifs_sb_info *cifs_sb)
 {
 	INIT_DELAYED_WORK(&cifs_sb->prune_tlinks, cifs_prune_tlinks);
@@ -3321,7 +3407,7 @@ void cifs_setup_cifs_sb(struct smb_vol *pvolume_info,
 	cifs_sb->mnt_gid = pvolume_info->linux_gid;
 	cifs_sb->mnt_file_mode = pvolume_info->file_mode;
 	cifs_sb->mnt_dir_mode = pvolume_info->dir_mode;
-	cifs_dbg(FYI, "file mode: 0x%hx  dir mode: 0x%hx\n",
+	cifs_dbg(FYI, "file mode: %04ho  dir mode: %04ho\n",
 		 cifs_sb->mnt_file_mode, cifs_sb->mnt_dir_mode);
 
 	cifs_sb->actimeo = pvolume_info->actimeo;
@@ -3396,6 +3482,14 @@ void cifs_setup_cifs_sb(struct smb_vol *pvolume_info,
 
 	if ((pvolume_info->cifs_acl) && (pvolume_info->dynperm))
 		cifs_dbg(VFS, "mount option dynperm ignored if cifsacl mount option supported\n");
+
+	if (pvolume_info->prepath) {
+		cifs_sb->prepath = kstrdup(pvolume_info->prepath, GFP_KERNEL);
+		if (cifs_sb->prepath == NULL)
+			return -ENOMEM;
+	}
+
+	return 0;
 }
 
 static void
@@ -3674,6 +3768,9 @@ try_mount_again:
 	if (IS_ERR(tcon)) {
 		rc = PTR_ERR(tcon);
 		tcon = NULL;
+		if (rc == -EACCES)
+			goto mount_fail_check;
+
 		goto remote_path_check;
 	}
 
@@ -4116,9 +4213,12 @@ cifs_construct_tcon(struct cifs_sb_info *cifs_sb, kuid_t fsuid)
 	vol_info->retry = master_tcon->retry;
 	vol_info->nocase = master_tcon->nocase;
 	vol_info->local_lease = master_tcon->local_lease;
+	vol_info->resilient = master_tcon->use_resilient;
+	vol_info->persistent = master_tcon->use_persistent;
 	vol_info->no_linux_ext = !master_tcon->unix_ext;
 	vol_info->sectype = master_tcon->ses->sectype;
 	vol_info->sign = master_tcon->ses->sign;
+	vol_info->seal = master_tcon->seal;
 
 	rc = cifs_set_vol_auth(vol_info, master_tcon->ses);
 	if (rc) {
@@ -4148,7 +4248,7 @@ cifs_construct_tcon(struct cifs_sb_info *cifs_sb, kuid_t fsuid)
 		reset_cifs_unix_caps(0, tcon, NULL, vol_info);
 out:
 	kfree(vol_info->username);
-	kfree(vol_info->password);
+	kzfree(vol_info->password);
 	kfree(vol_info);
 
 	return tcon;
diff --git a/fs/cifs/dir.c b/fs/cifs/dir.c
index 49a0d6b..be16da3 100644
--- a/fs/cifs/dir.c
+++ b/fs/cifs/dir.c
@@ -163,7 +163,7 @@ cifs_bp_rename_retry:
 
 		cifs_dbg(FYI, "using cifs_sb prepath <%s>\n", cifs_sb->prepath);
 		memcpy(full_path+dfsplen+1, cifs_sb->prepath, pplen-1);
-		full_path[dfsplen] = '\\';
+		full_path[dfsplen] = dirsep;
 		for (i = 0; i < pplen-1; i++)
 			if (full_path[dfsplen+1+i] == '/')
 				full_path[dfsplen+1+i] = CIFS_DIR_SEP(cifs_sb);
@@ -673,6 +673,9 @@ int cifs_mknod(struct inode *inode, struct dentry *direntry, umode_t mode,
 		goto mknod_out;
 	}
 
+	if (!S_ISCHR(mode) && !S_ISBLK(mode))
+		goto mknod_out;
+
 	if (!(cifs_sb->mnt_cifs_flags & CIFS_MOUNT_UNX_EMUL))
 		goto mknod_out;
 
@@ -681,10 +684,8 @@ int cifs_mknod(struct inode *inode, struct dentry *direntry, umode_t mode,
 
 	buf = kmalloc(sizeof(FILE_ALL_INFO), GFP_KERNEL);
 	if (buf == NULL) {
-		kfree(full_path);
 		rc = -ENOMEM;
-		free_xid(xid);
-		return rc;
+		goto mknod_out;
 	}
 
 	if (backup_cred(cifs_sb))
@@ -731,7 +732,7 @@ int cifs_mknod(struct inode *inode, struct dentry *direntry, umode_t mode,
 		pdev->minor = cpu_to_le64(MINOR(device_number));
 		rc = tcon->ses->server->ops->sync_write(xid, &fid, &io_parms,
 							&bytes_written, iov, 1);
-	} /* else if (S_ISFIFO) */
+	}
 	tcon->ses->server->ops->close(xid, tcon, &fid);
 	d_drop(direntry);
 
@@ -829,10 +830,16 @@ lookup_out:
 static int
 cifs_d_revalidate(struct dentry *direntry, unsigned int flags)
 {
+	struct inode *inode;
+
 	if (flags & LOOKUP_RCU)
 		return -ECHILD;
 
 	if (d_really_is_positive(direntry)) {
+		inode = d_inode(direntry);
+		if ((flags & LOOKUP_REVAL) && !CIFS_CACHE_READ(CIFS_I(inode)))
+			CIFS_I(inode)->time = 0; /* force reval */
+
 		if (cifs_revalidate_dentry(direntry))
 			return 0;
 		else {
@@ -843,7 +850,7 @@ cifs_d_revalidate(struct dentry *direntry, unsigned int flags)
 			 * attributes will have been updated by
 			 * cifs_revalidate_dentry().
 			 */
-			if (IS_AUTOMOUNT(d_inode(direntry)) &&
+			if (IS_AUTOMOUNT(inode) &&
 			   !(direntry->d_flags & DCACHE_NEED_AUTOMOUNT)) {
 				spin_lock(&direntry->d_lock);
 				direntry->d_flags |= DCACHE_NEED_AUTOMOUNT;
diff --git a/fs/cifs/file.c b/fs/cifs/file.c
index ec2d07b..b5a0509 100644
--- a/fs/cifs/file.c
+++ b/fs/cifs/file.c
@@ -252,6 +252,12 @@ cifs_nt_open(char *full_path, struct inode *inode, struct cifs_sb_info *cifs_sb,
 		rc = cifs_get_inode_info(&inode, full_path, buf, inode->i_sb,
 					 xid, fid);
 
+	if (rc) {
+		server->ops->close(xid, tcon, fid);
+		if (rc == -ESTALE)
+			rc = -EOPENSTALE;
+	}
+
 out:
 	kfree(buf);
 	return rc;
@@ -274,6 +280,13 @@ cifs_has_mand_locks(struct cifsInodeInfo *cinode)
 	return has_locks;
 }
 
+void
+cifs_down_write(struct rw_semaphore *sem)
+{
+	while (!down_write_trylock(sem))
+		msleep(10);
+}
+
 struct cifsFileInfo *
 cifs_new_fileinfo(struct cifs_fid *fid, struct file *file,
 		  struct tcon_link *tlink, __u32 oplock)
@@ -299,9 +312,6 @@ cifs_new_fileinfo(struct cifs_fid *fid, struct file *file,
 	INIT_LIST_HEAD(&fdlocks->locks);
 	fdlocks->cfile = cfile;
 	cfile->llist = fdlocks;
-	down_write(&cinode->lock_sem);
-	list_add(&fdlocks->llist, &cinode->llist);
-	up_write(&cinode->lock_sem);
 
 	cfile->count = 1;
 	cfile->pid = current->tgid;
@@ -325,6 +335,10 @@ cifs_new_fileinfo(struct cifs_fid *fid, struct file *file,
 		oplock = 0;
 	}
 
+	cifs_down_write(&cinode->lock_sem);
+	list_add(&fdlocks->llist, &cinode->llist);
+	up_write(&cinode->lock_sem);
+
 	spin_lock(&tcon->open_file_lock);
 	if (fid->pending_open->oplock != CIFS_OPLOCK_NO_CHANGE && oplock)
 		oplock = fid->pending_open->oplock;
@@ -432,7 +446,7 @@ void cifsFileInfo_put(struct cifsFileInfo *cifs_file)
 	 * Delete any outstanding lock records. We'll lose them when the file
 	 * is closed anyway.
 	 */
-	down_write(&cifsi->lock_sem);
+	cifs_down_write(&cifsi->lock_sem);
 	list_for_each_entry_safe(li, tmp, &cifs_file->llist->locks, llist) {
 		list_del(&li->llist);
 		cifs_del_lock_waiters(li);
@@ -589,7 +603,7 @@ cifs_relock_file(struct cifsFileInfo *cfile)
 	struct cifs_tcon *tcon = tlink_tcon(cfile->tlink);
 	int rc = 0;
 
-	down_read(&cinode->lock_sem);
+	down_read_nested(&cinode->lock_sem, SINGLE_DEPTH_NESTING);
 	if (cinode->can_cache_brlcks) {
 		/* can cache locks - no need to relock */
 		up_read(&cinode->lock_sem);
@@ -689,6 +703,13 @@ cifs_reopen_file(struct cifsFileInfo *cfile, bool can_flush)
 	if (backup_cred(cifs_sb))
 		create_options |= CREATE_OPEN_BACKUP_INTENT;
 
+	/* O_SYNC also has bit for O_DSYNC so following check picks up either */
+	if (cfile->f_flags & O_SYNC)
+		create_options |= CREATE_WRITE_THROUGH;
+
+	if (cfile->f_flags & O_DIRECT)
+		create_options |= CREATE_NO_BUFFER;
+
 	if (server->ops->get_lease_key)
 		server->ops->get_lease_key(inode, &cfile->fid);
 
@@ -941,7 +962,7 @@ static void
 cifs_lock_add(struct cifsFileInfo *cfile, struct cifsLockInfo *lock)
 {
 	struct cifsInodeInfo *cinode = CIFS_I(d_inode(cfile->dentry));
-	down_write(&cinode->lock_sem);
+	cifs_down_write(&cinode->lock_sem);
 	list_add_tail(&lock->llist, &cfile->llist->locks);
 	up_write(&cinode->lock_sem);
 }
@@ -963,7 +984,7 @@ cifs_lock_add_if(struct cifsFileInfo *cfile, struct cifsLockInfo *lock,
 
 try_again:
 	exist = false;
-	down_write(&cinode->lock_sem);
+	cifs_down_write(&cinode->lock_sem);
 
 	exist = cifs_find_lock_conflict(cfile, lock->offset, lock->length,
 					lock->type, &conf_lock, CIFS_LOCK_OP);
@@ -985,7 +1006,7 @@ try_again:
 					(lock->blist.next == &lock->blist));
 		if (!rc)
 			goto try_again;
-		down_write(&cinode->lock_sem);
+		cifs_down_write(&cinode->lock_sem);
 		list_del_init(&lock->blist);
 	}
 
@@ -1038,7 +1059,7 @@ cifs_posix_lock_set(struct file *file, struct file_lock *flock)
 		return rc;
 
 try_again:
-	down_write(&cinode->lock_sem);
+	cifs_down_write(&cinode->lock_sem);
 	if (!cinode->can_cache_brlcks) {
 		up_write(&cinode->lock_sem);
 		return rc;
@@ -1073,14 +1094,18 @@ cifs_push_mandatory_locks(struct cifsFileInfo *cfile)
 
 	/*
 	 * Accessing maxBuf is racy with cifs_reconnect - need to store value
-	 * and check it for zero before using.
+	 * and check it before using.
 	 */
 	max_buf = tcon->ses->server->maxBuf;
-	if (!max_buf) {
+	if (max_buf < (sizeof(struct smb_hdr) + sizeof(LOCKING_ANDX_RANGE))) {
 		free_xid(xid);
 		return -EINVAL;
 	}
 
+	BUILD_BUG_ON(sizeof(struct smb_hdr) + sizeof(LOCKING_ANDX_RANGE) >
+		     PAGE_SIZE);
+	max_buf = min_t(unsigned int, max_buf - sizeof(struct smb_hdr),
+			PAGE_SIZE);
 	max_num = (max_buf - sizeof(struct smb_hdr)) /
 						sizeof(LOCKING_ANDX_RANGE);
 	buf = kcalloc(max_num, sizeof(LOCKING_ANDX_RANGE), GFP_KERNEL);
@@ -1232,7 +1257,7 @@ cifs_push_locks(struct cifsFileInfo *cfile)
 	int rc = 0;
 
 	/* we are going to update can_cache_brlcks here - need a write access */
-	down_write(&cinode->lock_sem);
+	cifs_down_write(&cinode->lock_sem);
 	if (!cinode->can_cache_brlcks) {
 		up_write(&cinode->lock_sem);
 		return rc;
@@ -1404,19 +1429,23 @@ cifs_unlock_range(struct cifsFileInfo *cfile, struct file_lock *flock,
 
 	/*
 	 * Accessing maxBuf is racy with cifs_reconnect - need to store value
-	 * and check it for zero before using.
+	 * and check it before using.
 	 */
 	max_buf = tcon->ses->server->maxBuf;
-	if (!max_buf)
+	if (max_buf < (sizeof(struct smb_hdr) + sizeof(LOCKING_ANDX_RANGE)))
 		return -EINVAL;
 
+	BUILD_BUG_ON(sizeof(struct smb_hdr) + sizeof(LOCKING_ANDX_RANGE) >
+		     PAGE_SIZE);
+	max_buf = min_t(unsigned int, max_buf - sizeof(struct smb_hdr),
+			PAGE_SIZE);
 	max_num = (max_buf - sizeof(struct smb_hdr)) /
 						sizeof(LOCKING_ANDX_RANGE);
 	buf = kcalloc(max_num, sizeof(LOCKING_ANDX_RANGE), GFP_KERNEL);
 	if (!buf)
 		return -ENOMEM;
 
-	down_write(&cinode->lock_sem);
+	cifs_down_write(&cinode->lock_sem);
 	for (i = 0; i < 2; i++) {
 		cur = buf;
 		num = 0;
@@ -1566,8 +1595,20 @@ cifs_setlk(struct file *file, struct file_lock *flock, __u32 type,
 		rc = server->ops->mand_unlock_range(cfile, flock, xid);
 
 out:
-	if (flock->fl_flags & FL_POSIX && !rc)
+	if (flock->fl_flags & FL_POSIX) {
+		/*
+		 * If this is a request to remove all locks because we
+		 * are closing the file, it doesn't matter if the
+		 * unlocking failed as both cifs.ko and the SMB server
+		 * remove the lock on file close
+		 */
+		if (rc) {
+			cifs_dbg(VFS, "%s failed rc=%d\n", __func__, rc);
+			if (!(flock->fl_flags & FL_CLOSE))
+				return rc;
+		}
 		rc = locks_lock_file_wait(file, flock);
+	}
 	return rc;
 }
 
@@ -2745,14 +2786,16 @@ cifs_strict_writev(struct kiocb *iocb, struct iov_iter *from)
 	 * these pages but not on the region from pos to ppos+len-1.
 	 */
 	written = cifs_user_writev(iocb, from);
-	if (written > 0 && CIFS_CACHE_READ(cinode)) {
+	if (CIFS_CACHE_READ(cinode)) {
 		/*
-		 * Windows 7 server can delay breaking level2 oplock if a write
-		 * request comes - break it on the client to prevent reading
-		 * an old data.
+		 * We have read level caching and we have just sent a write
+		 * request to the server thus making data in the cache stale.
+		 * Zap the cache and set oplock/lease level to NONE to avoid
+		 * reading stale data from the cache. All subsequent read
+		 * operations will read new data from the server.
 		 */
 		cifs_zap_mapping(inode);
-		cifs_dbg(FYI, "Set no oplock for inode=%p after a write operation\n",
+		cifs_dbg(FYI, "Set Oplock/Lease to NONE for inode=%p after write\n",
 			 inode);
 		cinode->oplock = 0;
 	}
@@ -2807,7 +2850,9 @@ cifs_read_allocate_pages(struct cifs_readdata *rdata, unsigned int nr_pages)
 	}
 
 	if (rc) {
-		for (i = 0; i < nr_pages; i++) {
+		unsigned int nr_page_failed = i;
+
+		for (i = 0; i < nr_page_failed; i++) {
 			put_page(rdata->pages[i]);
 			rdata->pages[i] = NULL;
 		}
@@ -3185,7 +3230,7 @@ cifs_read(struct file *file, char *read_data, size_t read_size, loff_t *offset)
 			 * than it negotiated since it will refuse the read
 			 * then.
 			 */
-			if ((tcon->ses) && !(tcon->ses->capabilities &
+			if (!(tcon->ses->capabilities &
 				tcon->ses->server->vals->cap_large_files)) {
 				current_read_size = min_t(uint,
 					current_read_size, CIFSMaxBufSize);
@@ -3241,20 +3286,18 @@ static const struct vm_operations_struct cifs_file_vm_ops = {
 
 int cifs_file_strict_mmap(struct file *file, struct vm_area_struct *vma)
 {
-	int rc, xid;
+	int xid, rc = 0;
 	struct inode *inode = file_inode(file);
 
 	xid = get_xid();
 
-	if (!CIFS_CACHE_READ(CIFS_I(inode))) {
+	if (!CIFS_CACHE_READ(CIFS_I(inode)))
 		rc = cifs_zap_mapping(inode);
-		if (rc)
-			return rc;
-	}
-
-	rc = generic_file_mmap(file, vma);
-	if (rc == 0)
+	if (!rc)
+		rc = generic_file_mmap(file, vma);
+	if (!rc)
 		vma->vm_ops = &cifs_file_vm_ops;
+
 	free_xid(xid);
 	return rc;
 }
@@ -3264,16 +3307,16 @@ int cifs_file_mmap(struct file *file, struct vm_area_struct *vma)
 	int rc, xid;
 
 	xid = get_xid();
+
 	rc = cifs_revalidate_file(file);
-	if (rc) {
+	if (rc)
 		cifs_dbg(FYI, "Validation prior to mmap failed, error=%d\n",
 			 rc);
-		free_xid(xid);
-		return rc;
-	}
-	rc = generic_file_mmap(file, vma);
-	if (rc == 0)
+	if (!rc)
+		rc = generic_file_mmap(file, vma);
+	if (!rc)
 		vma->vm_ops = &cifs_file_vm_ops;
+
 	free_xid(xid);
 	return rc;
 }
diff --git a/fs/cifs/inode.c b/fs/cifs/inode.c
index 9cdeb02..c18c26a 100644
--- a/fs/cifs/inode.c
+++ b/fs/cifs/inode.c
@@ -405,6 +405,7 @@ int cifs_get_inode_info_unix(struct inode **pinode,
 		/* if uniqueid is different, return error */
 		if (unlikely(cifs_sb->mnt_cifs_flags & CIFS_MOUNT_SERVER_INUM &&
 		    CIFS_I(*pinode)->uniqueid != fattr.cf_uniqueid)) {
+			CIFS_I(*pinode)->time = 0; /* force reval */
 			rc = -ESTALE;
 			goto cgiiu_exit;
 		}
@@ -412,6 +413,7 @@ int cifs_get_inode_info_unix(struct inode **pinode,
 		/* if filetype is different, return error */
 		if (unlikely(((*pinode)->i_mode & S_IFMT) !=
 		    (fattr.cf_mode & S_IFMT))) {
+			CIFS_I(*pinode)->time = 0; /* force reval */
 			rc = -ESTALE;
 			goto cgiiu_exit;
 		}
@@ -756,38 +758,53 @@ cifs_get_inode_info(struct inode **inode, const char *full_path,
 	} else if (rc == -EREMOTE) {
 		cifs_create_dfs_fattr(&fattr, sb);
 		rc = 0;
-	} else if (rc == -EACCES && backup_cred(cifs_sb)) {
-			srchinf = kzalloc(sizeof(struct cifs_search_info),
-						GFP_KERNEL);
-			if (srchinf == NULL) {
-				rc = -ENOMEM;
-				goto cgii_exit;
-			}
+	} else if ((rc == -EACCES) && backup_cred(cifs_sb) &&
+		   (strcmp(server->vals->version_string, SMB1_VERSION_STRING)
+		      == 0)) {
+		/*
+		 * For SMB2 and later the backup intent flag is already
+		 * sent if needed on open and there is no path based
+		 * FindFirst operation to use to retry with
+		 */
+
+		srchinf = kzalloc(sizeof(struct cifs_search_info),
+					GFP_KERNEL);
+		if (srchinf == NULL) {
+			rc = -ENOMEM;
+			goto cgii_exit;
+		}
 
-			srchinf->endOfSearch = false;
+		srchinf->endOfSearch = false;
+		if (tcon->unix_ext)
+			srchinf->info_level = SMB_FIND_FILE_UNIX;
+		else if ((tcon->ses->capabilities &
+			 tcon->ses->server->vals->cap_nt_find) == 0)
+			srchinf->info_level = SMB_FIND_FILE_INFO_STANDARD;
+		else if (cifs_sb->mnt_cifs_flags & CIFS_MOUNT_SERVER_INUM)
 			srchinf->info_level = SMB_FIND_FILE_ID_FULL_DIR_INFO;
+		else /* no srvino useful for fallback to some netapp */
+			srchinf->info_level = SMB_FIND_FILE_DIRECTORY_INFO;
 
-			srchflgs = CIFS_SEARCH_CLOSE_ALWAYS |
-					CIFS_SEARCH_CLOSE_AT_END |
-					CIFS_SEARCH_BACKUP_SEARCH;
+		srchflgs = CIFS_SEARCH_CLOSE_ALWAYS |
+				CIFS_SEARCH_CLOSE_AT_END |
+				CIFS_SEARCH_BACKUP_SEARCH;
 
-			rc = CIFSFindFirst(xid, tcon, full_path,
-				cifs_sb, NULL, srchflgs, srchinf, false);
-			if (!rc) {
-				data =
-				(FILE_ALL_INFO *)srchinf->srch_entries_start;
+		rc = CIFSFindFirst(xid, tcon, full_path,
+			cifs_sb, NULL, srchflgs, srchinf, false);
+		if (!rc) {
+			data = (FILE_ALL_INFO *)srchinf->srch_entries_start;
 
-				cifs_dir_info_to_fattr(&fattr,
-				(FILE_DIRECTORY_INFO *)data, cifs_sb);
-				fattr.cf_uniqueid = le64_to_cpu(
-				((SEARCH_ID_FULL_DIR_INFO *)data)->UniqueId);
-				validinum = true;
+			cifs_dir_info_to_fattr(&fattr,
+			(FILE_DIRECTORY_INFO *)data, cifs_sb);
+			fattr.cf_uniqueid = le64_to_cpu(
+			((SEARCH_ID_FULL_DIR_INFO *)data)->UniqueId);
+			validinum = true;
 
-				cifs_buf_release(srchinf->ntwrk_buf_start);
-			}
-			kfree(srchinf);
-			if (rc)
-				goto cgii_exit;
+			cifs_buf_release(srchinf->ntwrk_buf_start);
+		}
+		kfree(srchinf);
+		if (rc)
+			goto cgii_exit;
 	} else
 		goto cgii_exit;
 
@@ -814,8 +831,21 @@ cifs_get_inode_info(struct inode **inode, const char *full_path,
 			}
 		} else
 			fattr.cf_uniqueid = iunique(sb, ROOT_I);
-	} else
-		fattr.cf_uniqueid = CIFS_I(*inode)->uniqueid;
+	} else {
+		if ((cifs_sb->mnt_cifs_flags & CIFS_MOUNT_SERVER_INUM) &&
+		    validinum == false && server->ops->get_srv_inum) {
+			/*
+			 * Pass a NULL tcon to ensure we don't make a round
+			 * trip to the server. This only works for SMB2+.
+			 */
+			tmprc = server->ops->get_srv_inum(xid,
+				NULL, cifs_sb, full_path,
+				&fattr.cf_uniqueid, data);
+			if (tmprc)
+				fattr.cf_uniqueid = CIFS_I(*inode)->uniqueid;
+		} else
+			fattr.cf_uniqueid = CIFS_I(*inode)->uniqueid;
+	}
 
 	/* query for SFU type info if supported and needed */
 	if (fattr.cf_cifsattrs & ATTR_SYSTEM &&
@@ -856,9 +886,18 @@ cifs_get_inode_info(struct inode **inode, const char *full_path,
 	} else {
 		/* we already have inode, update it */
 
+		/* if uniqueid is different, return error */
+		if (unlikely(cifs_sb->mnt_cifs_flags & CIFS_MOUNT_SERVER_INUM &&
+		    CIFS_I(*inode)->uniqueid != fattr.cf_uniqueid)) {
+			CIFS_I(*inode)->time = 0; /* force reval */
+			rc = -ESTALE;
+			goto cgii_exit;
+		}
+
 		/* if filetype is different, return error */
 		if (unlikely(((*inode)->i_mode & S_IFMT) !=
 		    (fattr.cf_mode & S_IFMT))) {
+			CIFS_I(*inode)->time = 0; /* force reval */
 			rc = -ESTALE;
 			goto cgii_exit;
 		}
@@ -1063,6 +1102,8 @@ cifs_set_file_info(struct inode *inode, struct iattr *attrs, unsigned int xid,
 	if (!server->ops->set_file_info)
 		return -ENOSYS;
 
+	info_buf.Pad = 0;
+
 	if (attrs->ia_valid & ATTR_ATIME) {
 		set_time = true;
 		info_buf.LastAccessTime =
@@ -1499,7 +1540,7 @@ int cifs_mkdir(struct inode *inode, struct dentry *direntry, umode_t mode)
 	struct TCP_Server_Info *server;
 	char *full_path;
 
-	cifs_dbg(FYI, "In cifs_mkdir, mode = 0x%hx inode = 0x%p\n",
+	cifs_dbg(FYI, "In cifs_mkdir, mode = %04ho inode = 0x%p\n",
 		 mode, inode);
 
 	cifs_sb = CIFS_SB(inode->i_sb);
@@ -1652,6 +1693,10 @@ cifs_do_rename(const unsigned int xid, struct dentry *from_dentry,
 	if (rc == 0 || rc != -EBUSY)
 		goto do_rename_exit;
 
+	/* Don't fall back to using SMB on SMB 2+ mount */
+	if (server->vals->protocol_id != 0)
+		goto do_rename_exit;
+
 	/* open-file renames don't work across directories */
 	if (to_dentry->d_parent != from_dentry->d_parent)
 		goto do_rename_exit;
@@ -1912,6 +1957,7 @@ int cifs_revalidate_dentry_attr(struct dentry *dentry)
 	struct inode *inode = d_inode(dentry);
 	struct super_block *sb = dentry->d_sb;
 	char *full_path = NULL;
+	int count = 0;
 
 	if (inode == NULL)
 		return -ENOENT;
@@ -1933,15 +1979,18 @@ int cifs_revalidate_dentry_attr(struct dentry *dentry)
 		 full_path, inode, inode->i_count.counter,
 		 dentry, dentry->d_time, jiffies);
 
+again:
 	if (cifs_sb_master_tcon(CIFS_SB(sb))->unix_ext)
 		rc = cifs_get_inode_info_unix(&inode, full_path, sb, xid);
 	else
 		rc = cifs_get_inode_info(&inode, full_path, NULL, sb,
 					 xid, NULL);
-
+	if (rc == -EAGAIN && count++ < 10)
+		goto again;
 out:
 	kfree(full_path);
 	free_xid(xid);
+
 	return rc;
 }
 
diff --git a/fs/cifs/link.c b/fs/cifs/link.c
index e3548f7..728289c 100644
--- a/fs/cifs/link.c
+++ b/fs/cifs/link.c
@@ -419,7 +419,7 @@ smb3_query_mf_symlink(unsigned int xid, struct cifs_tcon *tcon,
 	struct cifs_io_parms io_parms;
 	int buf_type = CIFS_NO_BUFFER;
 	__le16 *utf16_path;
-	__u8 oplock = SMB2_OPLOCK_LEVEL_II;
+	__u8 oplock = SMB2_OPLOCK_LEVEL_NONE;
 	struct smb2_file_all_info *pfile_info = NULL;
 
 	oparms.tcon = tcon;
@@ -481,7 +481,7 @@ smb3_create_mf_symlink(unsigned int xid, struct cifs_tcon *tcon,
 	struct cifs_io_parms io_parms;
 	int create_options = CREATE_NOT_DIR;
 	__le16 *utf16_path;
-	__u8 oplock = SMB2_OPLOCK_LEVEL_EXCLUSIVE;
+	__u8 oplock = SMB2_OPLOCK_LEVEL_NONE;
 	struct kvec iov[2];
 
 	if (backup_cred(cifs_sb))
diff --git a/fs/cifs/misc.c b/fs/cifs/misc.c
index 2396ab0..61a09ab 100644
--- a/fs/cifs/misc.c
+++ b/fs/cifs/misc.c
@@ -99,14 +99,11 @@ sesInfoFree(struct cifs_ses *buf_to_free)
 	kfree(buf_to_free->serverOS);
 	kfree(buf_to_free->serverDomain);
 	kfree(buf_to_free->serverNOS);
-	if (buf_to_free->password) {
-		memset(buf_to_free->password, 0, strlen(buf_to_free->password));
-		kfree(buf_to_free->password);
-	}
+	kzfree(buf_to_free->password);
 	kfree(buf_to_free->user_name);
 	kfree(buf_to_free->domainName);
-	kfree(buf_to_free->auth_key.response);
-	kfree(buf_to_free);
+	kzfree(buf_to_free->auth_key.response);
+	kzfree(buf_to_free);
 }
 
 struct cifs_tcon *
@@ -137,10 +134,7 @@ tconInfoFree(struct cifs_tcon *buf_to_free)
 	}
 	atomic_dec(&tconInfoAllocCount);
 	kfree(buf_to_free->nativeFileSystem);
-	if (buf_to_free->password) {
-		memset(buf_to_free->password, 0, strlen(buf_to_free->password));
-		kfree(buf_to_free->password);
-	}
+	kzfree(buf_to_free->password);
 	kfree(buf_to_free);
 }
 
@@ -412,9 +406,17 @@ is_valid_oplock_break(char *buffer, struct TCP_Server_Info *srv)
 			(struct smb_com_transaction_change_notify_rsp *)buf;
 		struct file_notify_information *pnotify;
 		__u32 data_offset = 0;
+		size_t len = srv->total_read - sizeof(pSMBr->hdr.smb_buf_length);
+
 		if (get_bcc(buf) > sizeof(struct file_notify_information)) {
 			data_offset = le32_to_cpu(pSMBr->DataOffset);
 
+			if (data_offset >
+			    len - sizeof(struct file_notify_information)) {
+				cifs_dbg(FYI, "invalid data_offset %u\n",
+					 data_offset);
+				return true;
+			}
 			pnotify = (struct file_notify_information *)
 				((char *)&pSMBr->hdr.Protocol + data_offset);
 			cifs_dbg(FYI, "dnotify on %s Action: 0x%x\n",
diff --git a/fs/cifs/netmisc.c b/fs/cifs/netmisc.c
index abae6dd..bed9733 100644
--- a/fs/cifs/netmisc.c
+++ b/fs/cifs/netmisc.c
@@ -130,10 +130,6 @@ static const struct smb_to_posix_error mapping_table_ERRSRV[] = {
 	{0, 0}
 };
 
-static const struct smb_to_posix_error mapping_table_ERRHRD[] = {
-	{0, 0}
-};
-
 /*
  * Convert a string containing text IPv4 or IPv6 address to binary form.
  *
@@ -980,10 +976,10 @@ struct timespec cnvrtDosUnixTm(__le16 le_date, __le16 le_time, int offset)
 		cifs_dbg(VFS, "illegal hours %d\n", st->Hours);
 	days = sd->Day;
 	month = sd->Month;
-	if ((days > 31) || (month > 12)) {
+	if (days < 1 || days > 31 || month < 1 || month > 12) {
 		cifs_dbg(VFS, "illegal date, month %d day: %d\n", month, days);
-		if (month > 12)
-			month = 12;
+		days = clamp(days, 1, 31);
+		month = clamp(month, 1, 12);
 	}
 	month -= 1;
 	days += total_days_of_prev_months[month];
diff --git a/fs/cifs/readdir.c b/fs/cifs/readdir.c
index 97d1a15..43fa471 100644
--- a/fs/cifs/readdir.c
+++ b/fs/cifs/readdir.c
@@ -373,8 +373,15 @@ static char *nxt_dir_entry(char *old_entry, char *end_of_smb, int level)
 
 		new_entry = old_entry + sizeof(FIND_FILE_STANDARD_INFO) +
 				pfData->FileNameLength;
-	} else
-		new_entry = old_entry + le32_to_cpu(pDirInfo->NextEntryOffset);
+	} else {
+		u32 next_offset = le32_to_cpu(pDirInfo->NextEntryOffset);
+
+		if (old_entry + next_offset < old_entry) {
+			cifs_dbg(VFS, "invalid offset %u\n", next_offset);
+			return NULL;
+		}
+		new_entry = old_entry + next_offset;
+	}
 	cifs_dbg(FYI, "new entry %p old entry %p\n", new_entry, old_entry);
 	/* validate that new_entry is not past end of SMB */
 	if (new_entry >= end_of_smb) {
@@ -645,7 +652,14 @@ find_cifs_entry(const unsigned int xid, struct cifs_tcon *tcon, loff_t pos,
 		/* scan and find it */
 		int i;
 		char *cur_ent;
-		char *end_of_smb = cfile->srch_inf.ntwrk_buf_start +
+		char *end_of_smb;
+
+		if (cfile->srch_inf.ntwrk_buf_start == NULL) {
+			cifs_dbg(VFS, "ntwrk_buf_start is NULL during readdir\n");
+			return -EIO;
+		}
+
+		end_of_smb = cfile->srch_inf.ntwrk_buf_start +
 			server->ops->calc_smb_size(
 					cfile->srch_inf.ntwrk_buf_start);
 
diff --git a/fs/cifs/sess.c b/fs/cifs/sess.c
index e88ffe1..9bc7a29 100644
--- a/fs/cifs/sess.c
+++ b/fs/cifs/sess.c
@@ -344,13 +344,12 @@ void build_ntlmssp_negotiate_blob(unsigned char *pbuffer,
 	/* BB is NTLMV2 session security format easier to use here? */
 	flags = NTLMSSP_NEGOTIATE_56 |	NTLMSSP_REQUEST_TARGET |
 		NTLMSSP_NEGOTIATE_128 | NTLMSSP_NEGOTIATE_UNICODE |
-		NTLMSSP_NEGOTIATE_NTLM | NTLMSSP_NEGOTIATE_EXTENDED_SEC;
-	if (ses->server->sign) {
+		NTLMSSP_NEGOTIATE_NTLM | NTLMSSP_NEGOTIATE_EXTENDED_SEC |
+		NTLMSSP_NEGOTIATE_SEAL;
+	if (ses->server->sign)
 		flags |= NTLMSSP_NEGOTIATE_SIGN;
-		if (!ses->server->session_estab ||
-				ses->ntlmssp->sesskey_per_smbsess)
-			flags |= NTLMSSP_NEGOTIATE_KEY_XCH;
-	}
+	if (!ses->server->session_estab || ses->ntlmssp->sesskey_per_smbsess)
+		flags |= NTLMSSP_NEGOTIATE_KEY_XCH;
 
 	sec_blob->NegotiateFlags = cpu_to_le32(flags);
 
@@ -399,6 +398,12 @@ int build_ntlmssp_auth_blob(unsigned char **pbuffer,
 		goto setup_ntlmv2_ret;
 	}
 	*pbuffer = kmalloc(size_of_ntlmssp_blob(ses), GFP_KERNEL);
+	if (!*pbuffer) {
+		rc = -ENOMEM;
+		cifs_dbg(VFS, "Error %d during NTLMSSP allocation\n", rc);
+		*buflen = 0;
+		goto setup_ntlmv2_ret;
+	}
 	sec_blob = (AUTHENTICATE_MESSAGE *)*pbuffer;
 
 	memcpy(sec_blob->Signature, NTLMSSP_SIGNATURE, 8);
@@ -407,13 +412,12 @@ int build_ntlmssp_auth_blob(unsigned char **pbuffer,
 	flags = NTLMSSP_NEGOTIATE_56 |
 		NTLMSSP_REQUEST_TARGET | NTLMSSP_NEGOTIATE_TARGET_INFO |
 		NTLMSSP_NEGOTIATE_128 | NTLMSSP_NEGOTIATE_UNICODE |
-		NTLMSSP_NEGOTIATE_NTLM | NTLMSSP_NEGOTIATE_EXTENDED_SEC;
-	if (ses->server->sign) {
+		NTLMSSP_NEGOTIATE_NTLM | NTLMSSP_NEGOTIATE_EXTENDED_SEC |
+		NTLMSSP_NEGOTIATE_SEAL;
+	if (ses->server->sign)
 		flags |= NTLMSSP_NEGOTIATE_SIGN;
-		if (!ses->server->session_estab ||
-				ses->ntlmssp->sesskey_per_smbsess)
-			flags |= NTLMSSP_NEGOTIATE_KEY_XCH;
-	}
+	if (!ses->server->session_estab || ses->ntlmssp->sesskey_per_smbsess)
+		flags |= NTLMSSP_NEGOTIATE_KEY_XCH;
 
 	tmp = *pbuffer + sizeof(AUTHENTICATE_MESSAGE);
 	sec_blob->NegotiateFlags = cpu_to_le32(flags);
diff --git a/fs/cifs/smb1ops.c b/fs/cifs/smb1ops.c
index efd72e1..6f5d78b 100644
--- a/fs/cifs/smb1ops.c
+++ b/fs/cifs/smb1ops.c
@@ -180,6 +180,9 @@ cifs_get_next_mid(struct TCP_Server_Info *server)
 	/* we do not want to loop forever */
 	last_mid = cur_mid;
 	cur_mid++;
+	/* avoid 0xFFFF MID */
+	if (cur_mid == 0xffff)
+		cur_mid++;
 
 	/*
 	 * This nested loop looks more expensive than it is.
@@ -305,7 +308,7 @@ coalesce_t2(char *second_buf, struct smb_hdr *target_hdr)
 	remaining = tgt_total_cnt - total_in_tgt;
 
 	if (remaining < 0) {
-		cifs_dbg(FYI, "Server sent too much data. tgt_total_cnt=%hu total_in_tgt=%hu\n",
+		cifs_dbg(FYI, "Server sent too much data. tgt_total_cnt=%hu total_in_tgt=%u\n",
 			 tgt_total_cnt, total_in_tgt);
 		return -EPROTO;
 	}
diff --git a/fs/cifs/smb2file.c b/fs/cifs/smb2file.c
index b2aff0c..4dcce3f 100644
--- a/fs/cifs/smb2file.c
+++ b/fs/cifs/smb2file.c
@@ -69,7 +69,7 @@ smb2_open_file(const unsigned int xid, struct cifs_open_parms *oparms,
 		goto out;
 
 
-	 if (oparms->tcon->use_resilient) {
+	if (oparms->tcon->use_resilient) {
 		nr_ioctl_req.Timeout = 0; /* use server default (120 seconds) */
 		nr_ioctl_req.Reserved = 0;
 		rc = SMB2_ioctl(xid, oparms->tcon, fid->persistent_fid,
@@ -123,12 +123,14 @@ smb2_unlock_range(struct cifsFileInfo *cfile, struct file_lock *flock,
 
 	/*
 	 * Accessing maxBuf is racy with cifs_reconnect - need to store value
-	 * and check it for zero before using.
+	 * and check it before using.
 	 */
 	max_buf = tcon->ses->server->maxBuf;
-	if (!max_buf)
+	if (max_buf < sizeof(struct smb2_lock_element))
 		return -EINVAL;
 
+	BUILD_BUG_ON(sizeof(struct smb2_lock_element) > PAGE_SIZE);
+	max_buf = min_t(unsigned int, max_buf, PAGE_SIZE);
 	max_num = max_buf / sizeof(struct smb2_lock_element);
 	buf = kcalloc(max_num, sizeof(struct smb2_lock_element), GFP_KERNEL);
 	if (!buf)
@@ -136,7 +138,7 @@ smb2_unlock_range(struct cifsFileInfo *cfile, struct file_lock *flock,
 
 	cur = buf;
 
-	down_write(&cinode->lock_sem);
+	cifs_down_write(&cinode->lock_sem);
 	list_for_each_entry_safe(li, tmp, &cfile->llist->locks, llist) {
 		if (flock->fl_start > li->offset ||
 		    (flock->fl_start + length) <
@@ -265,6 +267,8 @@ smb2_push_mandatory_locks(struct cifsFileInfo *cfile)
 		return -EINVAL;
 	}
 
+	BUILD_BUG_ON(sizeof(struct smb2_lock_element) > PAGE_SIZE);
+	max_buf = min_t(unsigned int, max_buf, PAGE_SIZE);
 	max_num = max_buf / sizeof(struct smb2_lock_element);
 	buf = kcalloc(max_num, sizeof(struct smb2_lock_element), GFP_KERNEL);
 	if (!buf) {
diff --git a/fs/cifs/smb2inode.c b/fs/cifs/smb2inode.c
index 1238cd3..0267d8c 100644
--- a/fs/cifs/smb2inode.c
+++ b/fs/cifs/smb2inode.c
@@ -267,7 +267,7 @@ smb2_set_file_info(struct inode *inode, const char *full_path,
 	int rc;
 
 	if ((buf->CreationTime == 0) && (buf->LastAccessTime == 0) &&
-	    (buf->LastWriteTime == 0) && (buf->ChangeTime) &&
+	    (buf->LastWriteTime == 0) && (buf->ChangeTime == 0) &&
 	    (buf->Attributes == 0))
 		return 0; /* would be a no op, no sense sending this */
 
diff --git a/fs/cifs/smb2maperror.c b/fs/cifs/smb2maperror.c
index 8257a5a..4d0d407 100644
--- a/fs/cifs/smb2maperror.c
+++ b/fs/cifs/smb2maperror.c
@@ -377,8 +377,8 @@ static const struct status_to_posix_error smb2_error_map_table[] = {
 	{STATUS_NONEXISTENT_EA_ENTRY, -EIO, "STATUS_NONEXISTENT_EA_ENTRY"},
 	{STATUS_NO_EAS_ON_FILE, -ENODATA, "STATUS_NO_EAS_ON_FILE"},
 	{STATUS_EA_CORRUPT_ERROR, -EIO, "STATUS_EA_CORRUPT_ERROR"},
-	{STATUS_FILE_LOCK_CONFLICT, -EIO, "STATUS_FILE_LOCK_CONFLICT"},
-	{STATUS_LOCK_NOT_GRANTED, -EIO, "STATUS_LOCK_NOT_GRANTED"},
+	{STATUS_FILE_LOCK_CONFLICT, -EACCES, "STATUS_FILE_LOCK_CONFLICT"},
+	{STATUS_LOCK_NOT_GRANTED, -EACCES, "STATUS_LOCK_NOT_GRANTED"},
 	{STATUS_DELETE_PENDING, -ENOENT, "STATUS_DELETE_PENDING"},
 	{STATUS_CTL_FILE_NOT_SUPPORTED, -ENOSYS,
 	"STATUS_CTL_FILE_NOT_SUPPORTED"},
@@ -455,7 +455,7 @@ static const struct status_to_posix_error smb2_error_map_table[] = {
 	{STATUS_FILE_INVALID, -EIO, "STATUS_FILE_INVALID"},
 	{STATUS_ALLOTTED_SPACE_EXCEEDED, -EIO,
 	"STATUS_ALLOTTED_SPACE_EXCEEDED"},
-	{STATUS_INSUFFICIENT_RESOURCES, -EREMOTEIO,
+	{STATUS_INSUFFICIENT_RESOURCES, -EAGAIN,
 				"STATUS_INSUFFICIENT_RESOURCES"},
 	{STATUS_DFS_EXIT_PATH_FOUND, -EIO, "STATUS_DFS_EXIT_PATH_FOUND"},
 	{STATUS_DEVICE_DATA_ERROR, -EIO, "STATUS_DEVICE_DATA_ERROR"},
@@ -1034,7 +1034,8 @@ static const struct status_to_posix_error smb2_error_map_table[] = {
 	{STATUS_UNFINISHED_CONTEXT_DELETED, -EIO,
 	"STATUS_UNFINISHED_CONTEXT_DELETED"},
 	{STATUS_NO_TGT_REPLY, -EIO, "STATUS_NO_TGT_REPLY"},
-	{STATUS_OBJECTID_NOT_FOUND, -EIO, "STATUS_OBJECTID_NOT_FOUND"},
+	/* Note that ENOATTTR and ENODATA are the same errno */
+	{STATUS_OBJECTID_NOT_FOUND, -ENODATA, "STATUS_OBJECTID_NOT_FOUND"},
 	{STATUS_NO_IP_ADDRESSES, -EIO, "STATUS_NO_IP_ADDRESSES"},
 	{STATUS_WRONG_CREDENTIAL_HANDLE, -EIO,
 	"STATUS_WRONG_CREDENTIAL_HANDLE"},
diff --git a/fs/cifs/smb2misc.c b/fs/cifs/smb2misc.c
index 76ccf20..44198b9 100644
--- a/fs/cifs/smb2misc.c
+++ b/fs/cifs/smb2misc.c
@@ -185,6 +185,13 @@ smb2_check_message(char *buf, unsigned int length)
 			return 0;
 
 		/*
+		 * Some windows servers (win2016) will pad also the final
+		 * PDU in a compound to 8 bytes.
+		 */
+		if (((clc_len + 7) & ~7) == len)
+			return 0;
+
+		/*
 		 * MacOS server pads after SMB2.1 write response with 3 bytes
 		 * of junk. Other servers match RFC1001 len to actual
 		 * SMB2/SMB3 frame length (header + smb2 response specific data)
@@ -575,10 +582,10 @@ smb2_is_valid_oplock_break(char *buffer, struct TCP_Server_Info *server)
 	spin_lock(&cifs_tcp_ses_lock);
 	list_for_each(tmp, &server->smb_ses_list) {
 		ses = list_entry(tmp, struct cifs_ses, smb_ses_list);
+
 		list_for_each(tmp1, &ses->tcon_list) {
 			tcon = list_entry(tmp1, struct cifs_tcon, tcon_list);
 
-			cifs_stats_inc(&tcon->stats.cifs_stats.num_oplock_brks);
 			spin_lock(&tcon->open_file_lock);
 			list_for_each(tmp2, &tcon->openFileList) {
 				cfile = list_entry(tmp2, struct cifsFileInfo,
@@ -590,6 +597,8 @@ smb2_is_valid_oplock_break(char *buffer, struct TCP_Server_Info *server)
 					continue;
 
 				cifs_dbg(FYI, "file id match, oplock break\n");
+				cifs_stats_inc(
+				    &tcon->stats.cifs_stats.num_oplock_brks);
 				cinode = CIFS_I(d_inode(cfile->dentry));
 				spin_lock(&cfile->file_info_lock);
 				if (!CIFS_CACHE_WRITE(cinode) &&
@@ -621,9 +630,6 @@ smb2_is_valid_oplock_break(char *buffer, struct TCP_Server_Info *server)
 				return true;
 			}
 			spin_unlock(&tcon->open_file_lock);
-			spin_unlock(&cifs_tcp_ses_lock);
-			cifs_dbg(FYI, "No matching file for oplock break\n");
-			return true;
 		}
 	}
 	spin_unlock(&cifs_tcp_ses_lock);
diff --git a/fs/cifs/smb2ops.c b/fs/cifs/smb2ops.c
index e6b1795..087261c 100644
--- a/fs/cifs/smb2ops.c
+++ b/fs/cifs/smb2ops.c
@@ -143,14 +143,14 @@ smb2_wait_mtu_credits(struct TCP_Server_Info *server, unsigned int size,
 
 			scredits = server->credits;
 			/* can deadlock with reopen */
-			if (scredits == 1) {
+			if (scredits <= 8) {
 				*num = SMB2_MAX_BUFFER_SIZE;
 				*credits = 0;
 				break;
 			}
 
-			/* leave one credit for a possible reopen */
-			scredits--;
+			/* leave some credits for reopen and other ops */
+			scredits -= 8;
 			*num = min_t(unsigned int, size,
 				     scredits * SMB2_MAX_BUFFER_SIZE);
 
@@ -914,7 +914,7 @@ smb2_query_dir_first(const unsigned int xid, struct cifs_tcon *tcon,
 	}
 
 	srch_inf->entries_in_buffer = 0;
-	srch_inf->index_of_last_entry = 0;
+	srch_inf->index_of_last_entry = 2;
 
 	rc = SMB2_query_directory(xid, tcon, fid->persistent_fid,
 				  fid->volatile_fid, 0, srch_inf);
@@ -1145,6 +1145,12 @@ static long smb3_zero_range(struct file *file, struct cifs_tcon *tcon,
 	inode = d_inode(cfile->dentry);
 	cifsi = CIFS_I(inode);
 
+	/*
+	 * We zero the range through ioctl, so we need remove the page caches
+	 * first, otherwise the data may be inconsistent with the server.
+	 */
+	truncate_pagecache_range(inode, offset, offset + len - 1);
+
 	/* if file not oplocked can't be sure whether asking to extend size */
 	if (!CIFS_CACHE_READ(cifsi))
 		if (keep_size == false)
@@ -1201,6 +1207,12 @@ static long smb3_punch_hole(struct file *file, struct cifs_tcon *tcon,
 	if (!smb2_set_sparse(xid, tcon, cfile, inode, set_sparse))
 		return -EOPNOTSUPP;
 
+	/*
+	 * We implement the punch hole through ioctl, so we need remove the page
+	 * caches first, otherwise the data may be inconsistent with the server.
+	 */
+	truncate_pagecache_range(inode, offset, offset + len - 1);
+
 	cifs_dbg(FYI, "offset %lld len %lld", offset, len);
 
 	fsctl_buf.FileOffset = cpu_to_le64(offset);
@@ -1329,26 +1341,33 @@ smb21_set_oplock_level(struct cifsInodeInfo *cinode, __u32 oplock,
 		       unsigned int epoch, bool *purge_cache)
 {
 	char message[5] = {0};
+	unsigned int new_oplock = 0;
 
 	oplock &= 0xFF;
 	if (oplock == SMB2_OPLOCK_LEVEL_NOCHANGE)
 		return;
 
-	cinode->oplock = 0;
+	/* Check if the server granted an oplock rather than a lease */
+	if (oplock & SMB2_OPLOCK_LEVEL_EXCLUSIVE)
+		return smb2_set_oplock_level(cinode, oplock, epoch,
+					     purge_cache);
+
 	if (oplock & SMB2_LEASE_READ_CACHING_HE) {
-		cinode->oplock |= CIFS_CACHE_READ_FLG;
+		new_oplock |= CIFS_CACHE_READ_FLG;
 		strcat(message, "R");
 	}
 	if (oplock & SMB2_LEASE_HANDLE_CACHING_HE) {
-		cinode->oplock |= CIFS_CACHE_HANDLE_FLG;
+		new_oplock |= CIFS_CACHE_HANDLE_FLG;
 		strcat(message, "H");
 	}
 	if (oplock & SMB2_LEASE_WRITE_CACHING_HE) {
-		cinode->oplock |= CIFS_CACHE_WRITE_FLG;
+		new_oplock |= CIFS_CACHE_WRITE_FLG;
 		strcat(message, "W");
 	}
-	if (!cinode->oplock)
-		strcat(message, "None");
+	if (!new_oplock)
+		strncpy(message, "None", sizeof(message));
+
+	cinode->oplock = new_oplock;
 	cifs_dbg(FYI, "%s Lease granted on inode %p\n", message,
 		 &cinode->vfs_inode);
 }
diff --git a/fs/cifs/smb2pdu.c b/fs/cifs/smb2pdu.c
index f2ff60e..a187daa 100644
--- a/fs/cifs/smb2pdu.c
+++ b/fs/cifs/smb2pdu.c
@@ -158,7 +158,7 @@ out:
 static int
 smb2_reconnect(__le16 smb2_command, struct cifs_tcon *tcon)
 {
-	int rc = 0;
+	int rc;
 	struct nls_table *nls_codepage;
 	struct cifs_ses *ses;
 	struct TCP_Server_Info *server;
@@ -169,10 +169,10 @@ smb2_reconnect(__le16 smb2_command, struct cifs_tcon *tcon)
 	 * for those three - in the calling routine.
 	 */
 	if (tcon == NULL)
-		return rc;
+		return 0;
 
-	if (smb2_command == SMB2_TREE_CONNECT)
-		return rc;
+	if (smb2_command == SMB2_TREE_CONNECT || smb2_command == SMB2_IOCTL)
+		return 0;
 
 	if (tcon->tidStatus == CifsExiting) {
 		/*
@@ -215,8 +215,14 @@ smb2_reconnect(__le16 smb2_command, struct cifs_tcon *tcon)
 			return -EAGAIN;
 		}
 
-		wait_event_interruptible_timeout(server->response_q,
-			(server->tcpStatus != CifsNeedReconnect), 10 * HZ);
+		rc = wait_event_interruptible_timeout(server->response_q,
+						      (server->tcpStatus != CifsNeedReconnect),
+						      10 * HZ);
+		if (rc < 0) {
+			cifs_dbg(FYI, "%s: aborting reconnect due to a received"
+				 " signal by the process\n", __func__);
+			return -ERESTARTSYS;
+		}
 
 		/* are we still trying to reconnect? */
 		if (server->tcpStatus != CifsNeedReconnect)
@@ -234,7 +240,7 @@ smb2_reconnect(__le16 smb2_command, struct cifs_tcon *tcon)
 	}
 
 	if (!tcon->ses->need_reconnect && !tcon->need_reconnect)
-		return rc;
+		return 0;
 
 	nls_codepage = load_nls_default();
 
@@ -243,10 +249,27 @@ smb2_reconnect(__le16 smb2_command, struct cifs_tcon *tcon)
 	 * the same SMB session
 	 */
 	mutex_lock(&tcon->ses->session_mutex);
+
+	/*
+	 * Recheck after acquire mutex. If another thread is negotiating
+	 * and the server never sends an answer the socket will be closed
+	 * and tcpStatus set to reconnect.
+	 */
+	if (server->tcpStatus == CifsNeedReconnect) {
+		rc = -EHOSTDOWN;
+		mutex_unlock(&tcon->ses->session_mutex);
+		goto out;
+	}
+
 	rc = cifs_negotiate_protocol(0, tcon->ses);
-	if (!rc && tcon->ses->need_reconnect)
+	if (!rc && tcon->ses->need_reconnect) {
 		rc = cifs_setup_session(0, tcon->ses, nls_codepage);
-
+		if ((rc == -EACCES) && !tcon->retry) {
+			rc = -EHOSTDOWN;
+			mutex_unlock(&tcon->ses->session_mutex);
+			goto failed;
+		}
+	}
 	if (rc || !tcon->need_reconnect) {
 		mutex_unlock(&tcon->ses->session_mutex);
 		goto out;
@@ -280,6 +303,7 @@ out:
 	case SMB2_SET_INFO:
 		rc = -EAGAIN;
 	}
+failed:
 	unload_nls(nls_codepage);
 	return rc;
 }
@@ -309,7 +333,7 @@ small_smb2_init(__le16 smb2_command, struct cifs_tcon *tcon,
 	smb2_hdr_assemble((struct smb2_hdr *) *request_buf, smb2_command, tcon);
 
 	if (tcon != NULL) {
-#ifdef CONFIG_CIFS_STATS2
+#ifdef CONFIG_CIFS_STATS
 		uint16_t com_code = le16_to_cpu(smb2_command);
 		cifs_stats_inc(&tcon->stats.smb2_stats.smb2_com_sent[com_code]);
 #endif
@@ -519,7 +543,7 @@ int smb3_validate_negotiate(const unsigned int xid, struct cifs_tcon *tcon)
 {
 	int rc = 0;
 	struct validate_negotiate_info_req vneg_inbuf;
-	struct validate_negotiate_info_rsp *pneg_rsp;
+	struct validate_negotiate_info_rsp *pneg_rsp = NULL;
 	u32 rsplen;
 
 	cifs_dbg(FYI, "validate negotiate\n");
@@ -576,12 +600,11 @@ int smb3_validate_negotiate(const unsigned int xid, struct cifs_tcon *tcon)
 
 		/* relax check since Mac returns max bufsize allowed on ioctl */
 		if (rsplen > CIFSMaxBufSize)
-			return -EIO;
+			goto err_rsp_free;
 	}
 
 	/* check validate negotiate info response matches what we got earlier */
-	if (pneg_rsp->Dialect !=
-			cpu_to_le16(tcon->ses->server->vals->protocol_id))
+	if (pneg_rsp->Dialect != cpu_to_le16(tcon->ses->server->dialect))
 		goto vneg_out;
 
 	if (pneg_rsp->SecurityMode != cpu_to_le16(tcon->ses->server->sec_mode))
@@ -595,10 +618,13 @@ int smb3_validate_negotiate(const unsigned int xid, struct cifs_tcon *tcon)
 
 	/* validate negotiate successful */
 	cifs_dbg(FYI, "validate negotiate info successful\n");
+	kfree(pneg_rsp);
 	return 0;
 
 vneg_out:
 	cifs_dbg(VFS, "protocol revalidation - security settings mismatch\n");
+err_rsp_free:
+	kfree(pneg_rsp);
 	return -EIO;
 }
 
@@ -672,7 +698,12 @@ ssetup_ntlmssp_authenticate:
 	else
 		req->SecurityMode = 0;
 
+#ifdef CONFIG_CIFS_DFS_UPCALL
+	req->Capabilities = cpu_to_le32(SMB2_GLOBAL_CAP_DFS);
+#else
 	req->Capabilities = 0;
+#endif /* DFS_UPCALL */
+
 	req->Channel = 0; /* MBZ */
 
 	iov[0].iov_base = (char *)req;
@@ -833,10 +864,8 @@ ssetup_exit:
 
 	if (!rc) {
 		mutex_lock(&server->srv_mutex);
-		if (server->sign && server->ops->generate_signingkey) {
+		if (server->ops->generate_signingkey) {
 			rc = server->ops->generate_signingkey(ses);
-			kfree(ses->auth_key.response);
-			ses->auth_key.response = NULL;
 			if (rc) {
 				cifs_dbg(FYI,
 					"SMB3 session key generation failed\n");
@@ -858,10 +887,6 @@ ssetup_exit:
 	}
 
 keygen_exit:
-	if (!server->sign) {
-		kfree(ses->auth_key.response);
-		ses->auth_key.response = NULL;
-	}
 	if (spnego_key) {
 		key_invalidate(spnego_key);
 		key_put(spnego_key);
@@ -1006,15 +1031,19 @@ SMB2_tcon(const unsigned int xid, struct cifs_ses *ses, const char *tree,
 		goto tcon_exit;
 	}
 
-	if (rsp->ShareType & SMB2_SHARE_TYPE_DISK)
+	switch (rsp->ShareType) {
+	case SMB2_SHARE_TYPE_DISK:
 		cifs_dbg(FYI, "connection to disk share\n");
-	else if (rsp->ShareType & SMB2_SHARE_TYPE_PIPE) {
+		break;
+	case SMB2_SHARE_TYPE_PIPE:
 		tcon->ipc = true;
 		cifs_dbg(FYI, "connection to pipe share\n");
-	} else if (rsp->ShareType & SMB2_SHARE_TYPE_PRINT) {
-		tcon->print = true;
+		break;
+	case SMB2_SHARE_TYPE_PRINT:
+		tcon->ipc = true;
 		cifs_dbg(FYI, "connection to printer\n");
-	} else {
+		break;
+	default:
 		cifs_dbg(VFS, "unknown share type %d\n", rsp->ShareType);
 		rc = -EOPNOTSUPP;
 		goto tcon_error_exit;
@@ -1382,8 +1411,10 @@ SMB2_open(const unsigned int xid, struct cifs_open_parms *oparms, __le16 *path,
 			copy_size += 8;
 
 		copy_path = kzalloc(copy_size, GFP_KERNEL);
-		if (!copy_path)
+		if (!copy_path) {
+			cifs_small_buf_release(req);
 			return -ENOMEM;
+		}
 		memcpy((char *)copy_path, (const char *)path,
 			uni_path_len);
 		uni_path_len = copy_size;
@@ -1559,6 +1590,9 @@ SMB2_ioctl(const unsigned int xid, struct cifs_tcon *tcon, u64 persistent_fid,
 	} else
 		iov[0].iov_len = get_rfc1002_length(req) + 4;
 
+	/* validate negotiate request must be signed - see MS-SMB2 3.2.5.5 */
+	if (opcode == FSCTL_VALIDATE_NEGOTIATE_INFO)
+		req->hdr.Flags |= SMB2_FLAGS_SIGNED;
 
 	rc = SendReceive2(xid, ses, iov, num_iovecs, &resp_buftype, 0);
 	rsp = (struct smb2_ioctl_rsp *)iov[0].iov_base;
@@ -2396,33 +2430,38 @@ num_entries(char *bufstart, char *end_of_buf, char **lastentry, size_t size)
 	int len;
 	unsigned int entrycount = 0;
 	unsigned int next_offset = 0;
-	FILE_DIRECTORY_INFO *entryptr;
+	char *entryptr;
+	FILE_DIRECTORY_INFO *dir_info;
 
 	if (bufstart == NULL)
 		return 0;
 
-	entryptr = (FILE_DIRECTORY_INFO *)bufstart;
+	entryptr = bufstart;
 
 	while (1) {
-		entryptr = (FILE_DIRECTORY_INFO *)
-					((char *)entryptr + next_offset);
-
-		if ((char *)entryptr + size > end_of_buf) {
+		if (entryptr + next_offset < entryptr ||
+		    entryptr + next_offset > end_of_buf ||
+		    entryptr + next_offset + size > end_of_buf) {
 			cifs_dbg(VFS, "malformed search entry would overflow\n");
 			break;
 		}
 
-		len = le32_to_cpu(entryptr->FileNameLength);
-		if ((char *)entryptr + len + size > end_of_buf) {
+		entryptr = entryptr + next_offset;
+		dir_info = (FILE_DIRECTORY_INFO *)entryptr;
+
+		len = le32_to_cpu(dir_info->FileNameLength);
+		if (entryptr + len < entryptr ||
+		    entryptr + len > end_of_buf ||
+		    entryptr + len + size > end_of_buf) {
 			cifs_dbg(VFS, "directory entry name would overflow frame end of buf %p\n",
 				 end_of_buf);
 			break;
 		}
 
-		*lastentry = (char *)entryptr;
+		*lastentry = entryptr;
 		entrycount++;
 
-		next_offset = le32_to_cpu(entryptr->NextEntryOffset);
+		next_offset = le32_to_cpu(dir_info->NextEntryOffset);
 		if (!next_offset)
 			break;
 	}
@@ -2512,8 +2551,8 @@ SMB2_query_directory(const unsigned int xid, struct cifs_tcon *tcon,
 		if (rc == -ENODATA && rsp->hdr.Status == STATUS_NO_MORE_FILES) {
 			srch_inf->endOfSearch = true;
 			rc = 0;
-		}
-		cifs_stats_fail_inc(tcon, SMB2_QUERY_DIRECTORY_HE);
+		} else
+			cifs_stats_fail_inc(tcon, SMB2_QUERY_DIRECTORY_HE);
 		goto qdir_exit;
 	}
 
diff --git a/fs/cifs/smb2pdu.h b/fs/cifs/smb2pdu.h
index aacb15b..f087158 100644
--- a/fs/cifs/smb2pdu.h
+++ b/fs/cifs/smb2pdu.h
@@ -82,8 +82,8 @@
 
 #define NUMBER_OF_SMB2_COMMANDS	0x0013
 
-/* 4 len + 52 transform hdr + 64 hdr + 56 create rsp */
-#define MAX_SMB2_HDR_SIZE 0x00b0
+/* 52 transform hdr + 64 hdr + 88 create rsp */
+#define MAX_SMB2_HDR_SIZE 204
 
 #define SMB2_PROTO_NUMBER cpu_to_le32(0x424d53fe)
 
diff --git a/fs/cifs/transport.c b/fs/cifs/transport.c
index 54af102..1cf0a33 100644
--- a/fs/cifs/transport.c
+++ b/fs/cifs/transport.c
@@ -360,7 +360,7 @@ uncork:
 	if (rc < 0 && rc != -EINTR)
 		cifs_dbg(VFS, "Error %d sending data on socket to server\n",
 			 rc);
-	else
+	else if (rc > 0)
 		rc = 0;
 
 	return rc;
diff --git a/fs/ext2/super.c b/fs/ext2/super.c
index 748d35a..de576db 100644
--- a/fs/ext2/super.c
+++ b/fs/ext2/super.c
@@ -849,7 +849,12 @@ static int ext2_fill_super(struct super_block *sb, void *data, int silent)
 	sbi->s_es = es;
 	sb->s_magic = le16_to_cpu(es->s_magic);
 
+#ifdef CONFIG_BUFFALO_EXT23_EXTENSION
+	if ((sb->s_magic != EXT2_SUPER_MAGIC) &&
+	    (sb->s_magic != MEL_EXT2_SUPER_MAGIC))
+#else	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 	if (sb->s_magic != EXT2_SUPER_MAGIC)
+#endif	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 		goto cantfind_ext2;
 
 	/* Set defaults before we parse the mount options */
@@ -951,7 +956,12 @@ static int ext2_fill_super(struct super_block *sb, void *data, int silent)
 		}
 		es = (struct ext2_super_block *) (((char *)bh->b_data) + offset);
 		sbi->s_es = es;
+#ifdef CONFIG_BUFFALO_EXT23_EXTENSION
+		if ((sb->s_magic != cpu_to_le16(EXT2_SUPER_MAGIC)) &&
+		    (sb->s_magic != cpu_to_le16(MEL_EXT2_SUPER_MAGIC))) {
+#else	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 		if (es->s_magic != cpu_to_le16(EXT2_SUPER_MAGIC)) {
+#endif	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 			ext2_msg(sb, KERN_ERR, "error: magic mismatch");
 			goto failed_mount;
 		}
@@ -1002,7 +1012,12 @@ static int ext2_fill_super(struct super_block *sb, void *data, int silent)
 	sbi->s_desc_per_block_bits =
 		ilog2 (EXT2_DESC_PER_BLOCK(sb));
 
+#ifdef CONFIG_BUFFALO_EXT23_EXTENSION
+	if ((sb->s_magic != EXT2_SUPER_MAGIC) &&
+	    (sb->s_magic != MEL_EXT2_SUPER_MAGIC))
+#else	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 	if (sb->s_magic != EXT2_SUPER_MAGIC)
+#endif	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 		goto cantfind_ext2;
 
 	if (sb->s_blocksize != bh->b_size) {
diff --git a/fs/xfs/xfs_buf_item.c b/fs/xfs/xfs_buf_item.c
index 7e986da..1efaf67 100644
--- a/fs/xfs/xfs_buf_item.c
+++ b/fs/xfs/xfs_buf_item.c
@@ -1079,6 +1079,15 @@ xfs_buf_iodone_callbacks(
 	}
 	lasttarg = bp->b_target;
 
+	/* At unmount we may treat errors differently */
+	if ((mp->m_flags & XFS_MOUNT_UNMOUNTING)) {
+		xfs_force_shutdown(mp, SHUTDOWN_META_IO_ERROR);
+		xfs_buf_stale(bp);
+		XFS_BUF_DONE(bp);
+		trace_xfs_buf_item_iodone(bp, _RET_IP_);
+		goto do_callbacks;
+	}
+
 	/*
 	 * If the write was asynchronous then no one will be looking for the
 	 * error.  Clear the error state and write the buffer out again.
diff --git a/fs/xfs/xfs_mount.c b/fs/xfs/xfs_mount.c
index bb753b3..5c1f0fe 100644
--- a/fs/xfs/xfs_mount.c
+++ b/fs/xfs/xfs_mount.c
@@ -975,6 +975,7 @@ xfs_mountfs(
 	cancel_delayed_work_sync(&mp->m_reclaim_work);
 	xfs_reclaim_inodes(mp, SYNC_WAIT);
  out_log_dealloc:
+	mp->m_flags |= XFS_MOUNT_UNMOUNTING;
 	xfs_log_mount_cancel(mp);
  out_fail_wait:
 	if (mp->m_logdev_targp && mp->m_logdev_targp != mp->m_ddev_targp)
@@ -1024,6 +1025,14 @@ xfs_unmountfs(
 	xfs_log_force(mp, XFS_LOG_SYNC);
 
 	/*
+	 * We now need to tell the world we are unmounting. This will allow
+	 * us to detect that the filesystem is going away and we should error
+	 * out anything that we have been retrying in the background. This will
+	 * prevent neverending retries in AIL pushing from hanging the unmount.
+	 */
+	mp->m_flags |= XFS_MOUNT_UNMOUNTING;
+
+	/*
 	 * Flush all pending changes from the AIL.
 	 */
 	xfs_ail_push_all_sync(mp->m_ail);
diff --git a/fs/xfs/xfs_mount.h b/fs/xfs/xfs_mount.h
index b570984..a35b56d 100644
--- a/fs/xfs/xfs_mount.h
+++ b/fs/xfs/xfs_mount.h
@@ -155,6 +155,7 @@ typedef struct xfs_mount {
 #define XFS_MOUNT_WSYNC		(1ULL << 0)	/* for nfs - all metadata ops
 						   must be synchronous except
 						   for space allocations */
+#define XFS_MOUNT_UNMOUNTING	(1ULL << 1)     /* filesystem is unmounting */
 #define XFS_MOUNT_WAS_CLEAN	(1ULL << 3)
 #define XFS_MOUNT_FS_SHUTDOWN	(1ULL << 4)	/* atomic stop of all filesystem
 						   operations, typically for
diff --git a/include/linux/genhd.h b/include/linux/genhd.h
index 5012fcd..824aae2 100644
--- a/include/linux/genhd.h
+++ b/include/linux/genhd.h
@@ -213,6 +213,14 @@ struct gendisk {
 	struct kobject integrity_kobj;
 #endif	/* CONFIG_BLK_DEV_INTEGRITY */
 	int node_id;
+#ifdef	CONFIG_BUFFALO_IOERRS
+	unsigned io_errors;		/* I/O error counter */
+	unsigned limit_io_errors;	/* I/O error limit */
+#ifdef	CONFIG_BUFFALO_ERRCNT
+	atomic_t nr_errs;		/* number of errors occur during
+					 * Block I/O execution. */
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#endif	/* CONFIG_BUFFALO_IOERRS */
 };
 
 static inline struct gendisk *part_to_disk(struct hd_struct *part)
diff --git a/include/linux/phy.h b/include/linux/phy.h
index dbfd5ce..61f5b8e 100644
--- a/include/linux/phy.h
+++ b/include/linux/phy.h
@@ -430,6 +430,14 @@ struct phy_device {
 	u8 mdix;
 
 	void (*adjust_link)(struct net_device *dev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	struct {
+		int speed;
+		int duplex;
+		unsigned link : 1;
+		unsigned downcnt : 31;
+	} state_cache;
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 };
 #define to_phy_device(d) container_of(d, struct phy_device, dev)
 
diff --git a/include/scsi/scsi_device.h b/include/scsi/scsi_device.h
index 293b9a7..8a164bc 100644
--- a/include/scsi/scsi_device.h
+++ b/include/scsi/scsi_device.h
@@ -200,6 +200,9 @@ struct scsi_device {
 	void			*handler_data;
 
 	enum scsi_device_state sdev_state;
+#ifdef CONFIG_BUFFALO_IGNORE_LUN
+	int ignore_lun;
+#endif	/* CONFIG_BUFFALO_IGNORE_LUN */
 	unsigned long		sdev_data[0];
 } __attribute__((aligned(sizeof(unsigned long))));
 
diff --git a/include/target/iscsi/iscsi_target_core.h b/include/target/iscsi/iscsi_target_core.h
index 22f442a..83a6d1d 100644
--- a/include/target/iscsi/iscsi_target_core.h
+++ b/include/target/iscsi/iscsi_target_core.h
@@ -885,6 +885,12 @@ struct iscsit_global {
 	/* Used for iSCSI discovery session authentication */
 	struct iscsi_node_acl	discovery_acl;
 	struct iscsi_portal_group	*discovery_tpg;
+#ifdef CONFIG_BUFFALO_PLATFORM
+	struct list_head	*tiqn_list;
+	struct list_head	*np_list;
+	spinlock_t		*tiqn_lock;
+	spinlock_t		*np_lock;
+#endif /*CONFIG_BUFFALO_PLATFORM*/
 };
 
 static inline u32 session_get_next_ttt(struct iscsi_session *session)
diff --git a/include/uapi/linux/magic.h b/include/uapi/linux/magic.h
index accb036..ead4138 100644
--- a/include/uapi/linux/magic.h
+++ b/include/uapi/linux/magic.h
@@ -20,6 +20,10 @@
 #define EFS_SUPER_MAGIC		0x414A53
 #define EXT2_SUPER_MAGIC	0xEF53
 #define EXT3_SUPER_MAGIC	0xEF53
+#ifdef CONFIG_BUFFALO_EXT23_EXTENSION
+#define MEL_EXT2_SUPER_MAGIC	0xEF54
+#define MEL_EXT3_SUPER_MAGIC	0xEF54
+#endif	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 #define XENFS_SUPER_MAGIC	0xabba1974
 #define EXT4_SUPER_MAGIC	0xEF53
 #define BTRFS_SUPER_MAGIC	0x9123683E
diff --git a/include/uapi/linux/sysctl.h b/include/uapi/linux/sysctl.h
index 0956373..a8ac565 100644
--- a/include/uapi/linux/sysctl.h
+++ b/include/uapi/linux/sysctl.h
@@ -869,7 +869,17 @@ enum {
 /* /proc/sys/dev/raid */
 enum {
 	DEV_RAID_SPEED_LIMIT_MIN=1,
+#ifdef CONFIG_BUFFALO_PLATFORM
+	DEV_RAID_SPEED_LIMIT_MAX=2,
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+	DEV_RAID_SKIP_RESYNC=3,
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
+#ifdef CONFIG_BUFFALO_USE_MD_KERNEVNT
+	DEV_RAID_USE_KERNELEVENT=4,
+#endif	/* CONFIG_BUFFALO_USE_MD_KERNEVNT */
+#else	/* CONFIG_BUFFALO_PLATFORM */
 	DEV_RAID_SPEED_LIMIT_MAX=2
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 };
 
 /* /proc/sys/dev/parport/default */
diff --git a/scripts/kconfig/Makefile b/scripts/kconfig/Makefile
index ebced77..01978ac 100644
--- a/scripts/kconfig/Makefile
+++ b/scripts/kconfig/Makefile
@@ -107,7 +107,11 @@ endif
 endif
 
 %_defconfig: $(obj)/conf
-	$(Q)$< $(silent) --defconfig=arch/$(SRCARCH)/configs/$@ $(Kconfig)
+	$(Q)if [ -f $(srctree)/buffalo/arch/$(SRCARCH)/configs/$@ ]; then \
+		$< $(silent) --defconfig=buffalo/arch/$(SRCARCH)/configs/$@ $(Kconfig) ; \
+	else \
+		$< $(silent) --defconfig=arch/$(SRCARCH)/configs/$@ $(Kconfig) ; \
+	fi ;
 
 configfiles=$(wildcard $(srctree)/kernel/configs/$@ $(srctree)/arch/$(SRCARCH)/configs/$@)
 
